"""Sauter--Schwab quadrature rule."""

import numpy as np
import numpy.typing as npt
from quadraturerules.domain import Domain
import typing


def sauter_schwab(
    domain: Domain,
    order: int,
) -> typing.Tuple[npt.NDArray[np.float64], npt.NDArray[np.float64], npt.NDArray[np.float64]]:
    """Get a Sauter--Schwab quadrature rule."""
    match domain:
        case Domain.Interval:
            match order:
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.Quadrilateral:
            match order:
                case 1:
                    return (
                        np.array(
                            [
                                [0.46875, 0.15625, 0.28125, 0.09375],
                                [0.46875, 0.28125, 0.15625, 0.09375],
                                [0.28125, 0.09375, 0.46875, 0.15625],
                                [0.15625, 0.09375, 0.46875, 0.28125],
                                [0.15625, 0.46875, 0.09375, 0.28125],
                                [0.28125, 0.46875, 0.09375, 0.15625],
                                [0.09375, 0.28125, 0.15625, 0.46875],
                                [0.09375, 0.15625, 0.28125, 0.46875],
                            ]
                        ),
                        np.array(
                            [
                                [0.09375, 0.28125, 0.15625, 0.46875],
                                [0.09375, 0.15625, 0.28125, 0.46875],
                                [0.15625, 0.46875, 0.09375, 0.28125],
                                [0.28125, 0.46875, 0.09375, 0.15625],
                                [0.28125, 0.09375, 0.46875, 0.15625],
                                [0.15625, 0.09375, 0.46875, 0.28125],
                                [0.46875, 0.15625, 0.28125, 0.09375],
                                [0.46875, 0.28125, 0.15625, 0.09375],
                            ]
                        ),
                        np.array([0.1875, 0.1875, 0.1875, 0.1875, 0.1875, 0.1875, 0.1875, 0.1875]),
                    )
                case 2:
                    return (
                        np.array(
                            [
                                [
                                    0.6650937686937239,
                                    0.1330187537387448,
                                    0.16823956463960932,
                                    0.03364791292792187,
                                ],
                                [
                                    0.6650937686937239,
                                    0.16823956463960932,
                                    0.1330187537387448,
                                    0.03364791292792187,
                                ],
                                [
                                    0.6278786030782902,
                                    0.12557572061565808,
                                    0.20545473025504302,
                                    0.04109094605100861,
                                ],
                                [
                                    0.49643274731248804,
                                    0.12557572061565805,
                                    0.3016797751199807,
                                    0.07631175695187314,
                                ],
                                [
                                    0.49643274731248804,
                                    0.3016797751199807,
                                    0.12557572061565805,
                                    0.07631175695187314,
                                ],
                                [
                                    0.6278786030782902,
                                    0.20545473025504302,
                                    0.12557572061565808,
                                    0.04109094605100861,
                                ],
                                [
                                    0.4686549695347103,
                                    0.284799354159238,
                                    0.15335349839343582,
                                    0.09319217791261582,
                                ],
                                [
                                    0.4686549695347103,
                                    0.15335349839343582,
                                    0.284799354159238,
                                    0.09319217791261582,
                                ],
                                [
                                    0.7871022366218702,
                                    0.036793708873807174,
                                    0.16823956463960932,
                                    0.007864489864713277,
                                ],
                                [
                                    0.7871022366218702,
                                    0.16823956463960932,
                                    0.036793708873807174,
                                    0.007864489864713277,
                                ],
                                [
                                    0.6278786030782902,
                                    0.029350675750720437,
                                    0.32746319818318925,
                                    0.015307522987800021,
                                ],
                                [
                                    0.1373159909159462,
                                    0.029350675750720426,
                                    0.6865799545797312,
                                    0.14675337875360217,
                                ],
                                [
                                    0.1373159909159462,
                                    0.6865799545797312,
                                    0.029350675750720426,
                                    0.14675337875360217,
                                ],
                                [
                                    0.6278786030782902,
                                    0.32746319818318925,
                                    0.029350675750720437,
                                    0.015307522987800021,
                                ],
                                [
                                    0.10953821313816843,
                                    0.5476910656908422,
                                    0.0571284535284982,
                                    0.28564226764249107,
                                ],
                                [
                                    0.10953821313816843,
                                    0.0571284535284982,
                                    0.5476910656908422,
                                    0.28564226764249107,
                                ],
                                [
                                    0.3016797751199806,
                                    0.49643274731248815,
                                    0.07631175695187313,
                                    0.12557572061565808,
                                ],
                                [
                                    0.3016797751199806,
                                    0.07631175695187313,
                                    0.49643274731248815,
                                    0.12557572061565808,
                                ],
                                [
                                    0.28479935415923796,
                                    0.4686549695347104,
                                    0.0931921779126158,
                                    0.15335349839343584,
                                ],
                                [
                                    0.13301875373874478,
                                    0.03364791292792186,
                                    0.665093768693724,
                                    0.16823956463960935,
                                ],
                                [
                                    0.13301875373874478,
                                    0.665093768693724,
                                    0.03364791292792186,
                                    0.16823956463960935,
                                ],
                                [
                                    0.28479935415923796,
                                    0.0931921779126158,
                                    0.4686549695347104,
                                    0.15335349839343584,
                                ],
                                [
                                    0.12557572061565803,
                                    0.6278786030782904,
                                    0.041090946051008596,
                                    0.20545473025504304,
                                ],
                                [
                                    0.12557572061565803,
                                    0.041090946051008596,
                                    0.6278786030782904,
                                    0.20545473025504304,
                                ],
                                [
                                    0.6865799545797311,
                                    0.13731599091594623,
                                    0.14675337875360214,
                                    0.029350675750720437,
                                ],
                                [
                                    0.6865799545797311,
                                    0.14675337875360214,
                                    0.13731599091594623,
                                    0.029350675750720437,
                                ],
                                [
                                    0.5476910656908422,
                                    0.10953821313816847,
                                    0.28564226764249107,
                                    0.05712845352849822,
                                ],
                                [
                                    0.036793708873807125,
                                    0.007864489864713265,
                                    0.7871022366218702,
                                    0.16823956463960932,
                                ],
                                [
                                    0.036793708873807125,
                                    0.7871022366218702,
                                    0.007864489864713265,
                                    0.16823956463960932,
                                ],
                                [
                                    0.5476910656908422,
                                    0.28564226764249107,
                                    0.10953821313816847,
                                    0.05712845352849822,
                                ],
                                [
                                    0.029350675750720395,
                                    0.6278786030782904,
                                    0.015307522987799999,
                                    0.32746319818318925,
                                ],
                                [
                                    0.029350675750720395,
                                    0.015307522987799999,
                                    0.6278786030782904,
                                    0.32746319818318925,
                                ],
                                [
                                    0.2054547302550431,
                                    0.041090946051008624,
                                    0.6278786030782901,
                                    0.12557572061565805,
                                ],
                                [
                                    0.2054547302550431,
                                    0.6278786030782901,
                                    0.041090946051008624,
                                    0.12557572061565805,
                                ],
                                [
                                    0.16823956463960935,
                                    0.03364791292792187,
                                    0.6650937686937239,
                                    0.1330187537387448,
                                ],
                                [
                                    0.15335349839343587,
                                    0.46865496953471025,
                                    0.09319217791261585,
                                    0.28479935415923796,
                                ],
                                [
                                    0.15335349839343587,
                                    0.09319217791261585,
                                    0.46865496953471025,
                                    0.28479935415923796,
                                ],
                                [
                                    0.16823956463960935,
                                    0.6650937686937239,
                                    0.03364791292792187,
                                    0.1330187537387448,
                                ],
                                [
                                    0.12557572061565805,
                                    0.07631175695187314,
                                    0.49643274731248804,
                                    0.3016797751199807,
                                ],
                                [
                                    0.12557572061565805,
                                    0.49643274731248804,
                                    0.07631175695187314,
                                    0.3016797751199807,
                                ],
                                [
                                    0.32746319818318936,
                                    0.015307522987800025,
                                    0.6278786030782901,
                                    0.02935067575072043,
                                ],
                                [
                                    0.32746319818318936,
                                    0.6278786030782901,
                                    0.015307522987800025,
                                    0.02935067575072043,
                                ],
                                [
                                    0.16823956463960937,
                                    0.007864489864713279,
                                    0.7871022366218702,
                                    0.036793708873807174,
                                ],
                                [
                                    0.05712845352849822,
                                    0.10953821313816842,
                                    0.2856422676424912,
                                    0.5476910656908422,
                                ],
                                [
                                    0.05712845352849822,
                                    0.2856422676424912,
                                    0.10953821313816842,
                                    0.5476910656908422,
                                ],
                                [
                                    0.16823956463960937,
                                    0.7871022366218702,
                                    0.007864489864713279,
                                    0.036793708873807174,
                                ],
                                [
                                    0.029350675750720433,
                                    0.14675337875360223,
                                    0.1373159909159462,
                                    0.6865799545797312,
                                ],
                                [
                                    0.029350675750720433,
                                    0.1373159909159462,
                                    0.14675337875360223,
                                    0.6865799545797312,
                                ],
                                [
                                    0.09319217791261583,
                                    0.1533534983934359,
                                    0.28479935415923796,
                                    0.4686549695347103,
                                ],
                                [
                                    0.09319217791261583,
                                    0.28479935415923796,
                                    0.1533534983934359,
                                    0.4686549695347103,
                                ],
                                [
                                    0.07631175695187313,
                                    0.12557572061565808,
                                    0.3016797751199806,
                                    0.49643274731248815,
                                ],
                                [
                                    0.04109094605100861,
                                    0.12557572061565803,
                                    0.20545473025504313,
                                    0.6278786030782902,
                                ],
                                [
                                    0.04109094605100861,
                                    0.20545473025504313,
                                    0.12557572061565803,
                                    0.6278786030782902,
                                ],
                                [
                                    0.07631175695187313,
                                    0.3016797751199806,
                                    0.12557572061565808,
                                    0.49643274731248815,
                                ],
                                [
                                    0.033647912927921866,
                                    0.16823956463960937,
                                    0.13301875373874478,
                                    0.665093768693724,
                                ],
                                [
                                    0.033647912927921866,
                                    0.13301875373874478,
                                    0.16823956463960937,
                                    0.665093768693724,
                                ],
                                [
                                    0.2856422676424911,
                                    0.05712845352849824,
                                    0.5476910656908421,
                                    0.10953821313816844,
                                ],
                                [
                                    0.2856422676424911,
                                    0.5476910656908421,
                                    0.05712845352849824,
                                    0.10953821313816844,
                                ],
                                [
                                    0.1467533787536022,
                                    0.029350675750720444,
                                    0.6865799545797311,
                                    0.13731599091594623,
                                ],
                                [
                                    0.015307522987800004,
                                    0.02935067575072039,
                                    0.32746319818318936,
                                    0.6278786030782902,
                                ],
                                [
                                    0.015307522987800004,
                                    0.32746319818318936,
                                    0.02935067575072039,
                                    0.6278786030782902,
                                ],
                                [
                                    0.1467533787536022,
                                    0.6865799545797311,
                                    0.029350675750720444,
                                    0.13731599091594623,
                                ],
                                [
                                    0.007864489864713269,
                                    0.16823956463960937,
                                    0.036793708873807125,
                                    0.7871022366218702,
                                ],
                                [
                                    0.007864489864713269,
                                    0.036793708873807125,
                                    0.16823956463960937,
                                    0.7871022366218702,
                                ],
                                [
                                    0.6865799545797311,
                                    0.13731599091594623,
                                    0.14675337875360214,
                                    0.029350675750720437,
                                ],
                                [
                                    0.6865799545797311,
                                    0.14675337875360214,
                                    0.13731599091594623,
                                    0.029350675750720437,
                                ],
                                [
                                    0.5476910656908422,
                                    0.10953821313816847,
                                    0.28564226764249107,
                                    0.05712845352849822,
                                ],
                                [
                                    0.5124702547899777,
                                    0.10953821313816843,
                                    0.31142569070569964,
                                    0.06656584136615415,
                                ],
                                [
                                    0.5124702547899777,
                                    0.31142569070569964,
                                    0.10953821313816843,
                                    0.06656584136615415,
                                ],
                                [
                                    0.5476910656908422,
                                    0.28564226764249107,
                                    0.10953821313816847,
                                    0.05712845352849822,
                                ],
                                [
                                    0.4088021768019533,
                                    0.24842710202705737,
                                    0.2132062911261928,
                                    0.12956443004479645,
                                ],
                                [
                                    0.4088021768019533,
                                    0.2132062911261928,
                                    0.24842710202705737,
                                    0.12956443004479645,
                                ],
                                [
                                    0.8790300443096064,
                                    0.04109094605100861,
                                    0.07631175695187313,
                                    0.0035672526875118456,
                                ],
                                [
                                    0.8790300443096064,
                                    0.07631175695187313,
                                    0.04109094605100861,
                                    0.0035672526875118456,
                                ],
                                [
                                    0.2847993541592379,
                                    0.013313168273230829,
                                    0.6705424471022415,
                                    0.03134503046528963,
                                ],
                                [
                                    0.1533534983934358,
                                    0.013313168273230827,
                                    0.7667674919671792,
                                    0.06656584136615415,
                                ],
                                [
                                    0.1533534983934358,
                                    0.7667674919671792,
                                    0.013313168273230827,
                                    0.06656584136615415,
                                ],
                                [
                                    0.2847993541592379,
                                    0.6705424471022415,
                                    0.013313168273230829,
                                    0.03134503046528963,
                                ],
                                [
                                    0.04968542040541145,
                                    0.2484271020270573,
                                    0.11698124626125518,
                                    0.5849062313062761,
                                ],
                                [
                                    0.04968542040541145,
                                    0.11698124626125518,
                                    0.2484271020270573,
                                    0.5849062313062761,
                                ],
                                [
                                    0.3114256907056996,
                                    0.5124702547899778,
                                    0.06656584136615414,
                                    0.10953821313816846,
                                ],
                                [
                                    0.3114256907056996,
                                    0.06656584136615414,
                                    0.5124702547899778,
                                    0.10953821313816846,
                                ],
                                [
                                    0.24842710202705734,
                                    0.4088021768019534,
                                    0.12956443004479642,
                                    0.21320629112619285,
                                ],
                                [
                                    0.1373159909159462,
                                    0.029350675750720426,
                                    0.6865799545797312,
                                    0.14675337875360217,
                                ],
                                [
                                    0.1373159909159462,
                                    0.6865799545797312,
                                    0.029350675750720426,
                                    0.14675337875360217,
                                ],
                                [
                                    0.24842710202705734,
                                    0.12956443004479642,
                                    0.4088021768019534,
                                    0.21320629112619285,
                                ],
                                [
                                    0.10953821313816843,
                                    0.5476910656908422,
                                    0.0571284535284982,
                                    0.28564226764249107,
                                ],
                                [
                                    0.10953821313816843,
                                    0.0571284535284982,
                                    0.5476910656908422,
                                    0.28564226764249107,
                                ],
                                [
                                    0.7667674919671791,
                                    0.15335349839343584,
                                    0.06656584136615414,
                                    0.01331316827323083,
                                ],
                                [
                                    0.7667674919671791,
                                    0.06656584136615414,
                                    0.15335349839343584,
                                    0.01331316827323083,
                                ],
                                [
                                    0.24842710202705728,
                                    0.04968542040541147,
                                    0.584906231306276,
                                    0.11698124626125522,
                                ],
                                [
                                    0.041090946051008555,
                                    0.0035672526875118403,
                                    0.8790300443096064,
                                    0.07631175695187313,
                                ],
                                [
                                    0.041090946051008555,
                                    0.8790300443096064,
                                    0.0035672526875118403,
                                    0.07631175695187313,
                                ],
                                [
                                    0.24842710202705728,
                                    0.584906231306276,
                                    0.04968542040541147,
                                    0.11698124626125522,
                                ],
                                [
                                    0.01331316827323081,
                                    0.28479935415923796,
                                    0.03134503046528959,
                                    0.6705424471022416,
                                ],
                                [
                                    0.01331316827323081,
                                    0.03134503046528959,
                                    0.28479935415923796,
                                    0.6705424471022416,
                                ],
                                [
                                    0.2856422676424911,
                                    0.05712845352849824,
                                    0.5476910656908421,
                                    0.10953821313816844,
                                ],
                                [
                                    0.2856422676424911,
                                    0.5476910656908421,
                                    0.05712845352849824,
                                    0.10953821313816844,
                                ],
                                [
                                    0.1467533787536022,
                                    0.029350675750720444,
                                    0.6865799545797311,
                                    0.13731599091594623,
                                ],
                                [
                                    0.21320629112619288,
                                    0.40880217680195324,
                                    0.1295644300447965,
                                    0.2484271020270573,
                                ],
                                [
                                    0.21320629112619288,
                                    0.1295644300447965,
                                    0.40880217680195324,
                                    0.2484271020270573,
                                ],
                                [
                                    0.1467533787536022,
                                    0.6865799545797311,
                                    0.029350675750720444,
                                    0.13731599091594623,
                                ],
                                [
                                    0.10953821313816847,
                                    0.06656584136615416,
                                    0.5124702547899777,
                                    0.31142569070569964,
                                ],
                                [
                                    0.10953821313816847,
                                    0.5124702547899777,
                                    0.06656584136615416,
                                    0.31142569070569964,
                                ],
                                [
                                    0.6705424471022415,
                                    0.03134503046528963,
                                    0.2847993541592379,
                                    0.013313168273230829,
                                ],
                                [
                                    0.6705424471022415,
                                    0.2847993541592379,
                                    0.03134503046528963,
                                    0.013313168273230829,
                                ],
                                [
                                    0.07631175695187314,
                                    0.003567252687511846,
                                    0.8790300443096064,
                                    0.04109094605100861,
                                ],
                                [
                                    0.11698124626125518,
                                    0.04968542040541145,
                                    0.5849062313062761,
                                    0.2484271020270573,
                                ],
                                [
                                    0.11698124626125518,
                                    0.5849062313062761,
                                    0.04968542040541145,
                                    0.2484271020270573,
                                ],
                                [
                                    0.07631175695187314,
                                    0.8790300443096064,
                                    0.003567252687511846,
                                    0.04109094605100861,
                                ],
                                [
                                    0.013313168273230829,
                                    0.06656584136615416,
                                    0.1533534983934358,
                                    0.7667674919671792,
                                ],
                                [
                                    0.013313168273230829,
                                    0.1533534983934358,
                                    0.06656584136615416,
                                    0.7667674919671792,
                                ],
                                [
                                    0.12956443004479648,
                                    0.2132062911261929,
                                    0.24842710202705728,
                                    0.4088021768019533,
                                ],
                                [
                                    0.12956443004479648,
                                    0.24842710202705728,
                                    0.2132062911261929,
                                    0.4088021768019533,
                                ],
                                [
                                    0.06656584136615416,
                                    0.10953821313816849,
                                    0.3114256907056996,
                                    0.5124702547899778,
                                ],
                                [
                                    0.05712845352849822,
                                    0.10953821313816842,
                                    0.2856422676424912,
                                    0.5476910656908422,
                                ],
                                [
                                    0.05712845352849822,
                                    0.2856422676424912,
                                    0.10953821313816842,
                                    0.5476910656908422,
                                ],
                                [
                                    0.06656584136615416,
                                    0.3114256907056996,
                                    0.10953821313816849,
                                    0.5124702547899778,
                                ],
                                [
                                    0.029350675750720433,
                                    0.14675337875360223,
                                    0.1373159909159462,
                                    0.6865799545797312,
                                ],
                                [
                                    0.029350675750720433,
                                    0.1373159909159462,
                                    0.14675337875360223,
                                    0.6865799545797312,
                                ],
                                [
                                    0.584906231306276,
                                    0.11698124626125522,
                                    0.24842710202705728,
                                    0.04968542040541147,
                                ],
                                [
                                    0.584906231306276,
                                    0.24842710202705728,
                                    0.11698124626125522,
                                    0.04968542040541147,
                                ],
                                [
                                    0.06656584136615415,
                                    0.013313168273230834,
                                    0.7667674919671791,
                                    0.15335349839343584,
                                ],
                                [
                                    0.03134503046528959,
                                    0.01331316827323081,
                                    0.6705424471022416,
                                    0.28479935415923796,
                                ],
                                [
                                    0.03134503046528959,
                                    0.6705424471022416,
                                    0.01331316827323081,
                                    0.28479935415923796,
                                ],
                                [
                                    0.06656584136615415,
                                    0.7667674919671791,
                                    0.013313168273230834,
                                    0.15335349839343584,
                                ],
                                [
                                    0.0035672526875118412,
                                    0.07631175695187314,
                                    0.041090946051008555,
                                    0.8790300443096064,
                                ],
                                [
                                    0.0035672526875118412,
                                    0.041090946051008555,
                                    0.07631175695187314,
                                    0.8790300443096064,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.4686549695347103,
                                    0.284799354159238,
                                    0.15335349839343582,
                                    0.09319217791261582,
                                ],
                                [
                                    0.4686549695347103,
                                    0.15335349839343582,
                                    0.284799354159238,
                                    0.09319217791261582,
                                ],
                                [
                                    0.49643274731248804,
                                    0.3016797751199807,
                                    0.12557572061565805,
                                    0.07631175695187314,
                                ],
                                [
                                    0.6278786030782902,
                                    0.20545473025504302,
                                    0.12557572061565808,
                                    0.04109094605100861,
                                ],
                                [
                                    0.6278786030782902,
                                    0.12557572061565808,
                                    0.20545473025504302,
                                    0.04109094605100861,
                                ],
                                [
                                    0.49643274731248804,
                                    0.12557572061565805,
                                    0.3016797751199807,
                                    0.07631175695187314,
                                ],
                                [
                                    0.6650937686937239,
                                    0.1330187537387448,
                                    0.16823956463960932,
                                    0.03364791292792187,
                                ],
                                [
                                    0.6650937686937239,
                                    0.16823956463960932,
                                    0.1330187537387448,
                                    0.03364791292792187,
                                ],
                                [
                                    0.10953821313816843,
                                    0.5476910656908422,
                                    0.0571284535284982,
                                    0.28564226764249107,
                                ],
                                [
                                    0.10953821313816843,
                                    0.0571284535284982,
                                    0.5476910656908422,
                                    0.28564226764249107,
                                ],
                                [
                                    0.1373159909159462,
                                    0.6865799545797312,
                                    0.029350675750720426,
                                    0.14675337875360217,
                                ],
                                [
                                    0.6278786030782902,
                                    0.32746319818318925,
                                    0.029350675750720437,
                                    0.015307522987800021,
                                ],
                                [
                                    0.6278786030782902,
                                    0.029350675750720437,
                                    0.32746319818318925,
                                    0.015307522987800021,
                                ],
                                [
                                    0.1373159909159462,
                                    0.029350675750720426,
                                    0.6865799545797312,
                                    0.14675337875360217,
                                ],
                                [
                                    0.7871022366218702,
                                    0.036793708873807174,
                                    0.16823956463960932,
                                    0.007864489864713277,
                                ],
                                [
                                    0.7871022366218702,
                                    0.16823956463960932,
                                    0.036793708873807174,
                                    0.007864489864713277,
                                ],
                                [
                                    0.12557572061565803,
                                    0.6278786030782904,
                                    0.041090946051008596,
                                    0.20545473025504304,
                                ],
                                [
                                    0.12557572061565803,
                                    0.041090946051008596,
                                    0.6278786030782904,
                                    0.20545473025504304,
                                ],
                                [
                                    0.13301875373874478,
                                    0.665093768693724,
                                    0.03364791292792186,
                                    0.16823956463960935,
                                ],
                                [
                                    0.28479935415923796,
                                    0.0931921779126158,
                                    0.4686549695347104,
                                    0.15335349839343584,
                                ],
                                [
                                    0.28479935415923796,
                                    0.4686549695347104,
                                    0.0931921779126158,
                                    0.15335349839343584,
                                ],
                                [
                                    0.13301875373874478,
                                    0.03364791292792186,
                                    0.665093768693724,
                                    0.16823956463960935,
                                ],
                                [
                                    0.3016797751199806,
                                    0.49643274731248815,
                                    0.07631175695187313,
                                    0.12557572061565808,
                                ],
                                [
                                    0.3016797751199806,
                                    0.07631175695187313,
                                    0.49643274731248815,
                                    0.12557572061565808,
                                ],
                                [
                                    0.029350675750720395,
                                    0.6278786030782904,
                                    0.015307522987799999,
                                    0.32746319818318925,
                                ],
                                [
                                    0.029350675750720395,
                                    0.015307522987799999,
                                    0.6278786030782904,
                                    0.32746319818318925,
                                ],
                                [
                                    0.036793708873807125,
                                    0.7871022366218702,
                                    0.007864489864713265,
                                    0.16823956463960932,
                                ],
                                [
                                    0.5476910656908422,
                                    0.28564226764249107,
                                    0.10953821313816847,
                                    0.05712845352849822,
                                ],
                                [
                                    0.5476910656908422,
                                    0.10953821313816847,
                                    0.28564226764249107,
                                    0.05712845352849822,
                                ],
                                [
                                    0.036793708873807125,
                                    0.007864489864713265,
                                    0.7871022366218702,
                                    0.16823956463960932,
                                ],
                                [
                                    0.6865799545797311,
                                    0.13731599091594623,
                                    0.14675337875360214,
                                    0.029350675750720437,
                                ],
                                [
                                    0.6865799545797311,
                                    0.14675337875360214,
                                    0.13731599091594623,
                                    0.029350675750720437,
                                ],
                                [
                                    0.12557572061565805,
                                    0.07631175695187314,
                                    0.49643274731248804,
                                    0.3016797751199807,
                                ],
                                [
                                    0.12557572061565805,
                                    0.49643274731248804,
                                    0.07631175695187314,
                                    0.3016797751199807,
                                ],
                                [
                                    0.15335349839343587,
                                    0.09319217791261585,
                                    0.46865496953471025,
                                    0.28479935415923796,
                                ],
                                [
                                    0.16823956463960935,
                                    0.6650937686937239,
                                    0.03364791292792187,
                                    0.1330187537387448,
                                ],
                                [
                                    0.16823956463960935,
                                    0.03364791292792187,
                                    0.6650937686937239,
                                    0.1330187537387448,
                                ],
                                [
                                    0.15335349839343587,
                                    0.46865496953471025,
                                    0.09319217791261585,
                                    0.28479935415923796,
                                ],
                                [
                                    0.2054547302550431,
                                    0.041090946051008624,
                                    0.6278786030782901,
                                    0.12557572061565805,
                                ],
                                [
                                    0.2054547302550431,
                                    0.6278786030782901,
                                    0.041090946051008624,
                                    0.12557572061565805,
                                ],
                                [
                                    0.029350675750720433,
                                    0.14675337875360223,
                                    0.1373159909159462,
                                    0.6865799545797312,
                                ],
                                [
                                    0.029350675750720433,
                                    0.1373159909159462,
                                    0.14675337875360223,
                                    0.6865799545797312,
                                ],
                                [
                                    0.05712845352849822,
                                    0.2856422676424912,
                                    0.10953821313816842,
                                    0.5476910656908422,
                                ],
                                [
                                    0.16823956463960937,
                                    0.7871022366218702,
                                    0.007864489864713279,
                                    0.036793708873807174,
                                ],
                                [
                                    0.16823956463960937,
                                    0.007864489864713279,
                                    0.7871022366218702,
                                    0.036793708873807174,
                                ],
                                [
                                    0.05712845352849822,
                                    0.10953821313816842,
                                    0.2856422676424912,
                                    0.5476910656908422,
                                ],
                                [
                                    0.32746319818318936,
                                    0.015307522987800025,
                                    0.6278786030782901,
                                    0.02935067575072043,
                                ],
                                [
                                    0.32746319818318936,
                                    0.6278786030782901,
                                    0.015307522987800025,
                                    0.02935067575072043,
                                ],
                                [
                                    0.033647912927921866,
                                    0.16823956463960937,
                                    0.13301875373874478,
                                    0.665093768693724,
                                ],
                                [
                                    0.033647912927921866,
                                    0.13301875373874478,
                                    0.16823956463960937,
                                    0.665093768693724,
                                ],
                                [
                                    0.04109094605100861,
                                    0.20545473025504313,
                                    0.12557572061565803,
                                    0.6278786030782902,
                                ],
                                [
                                    0.07631175695187313,
                                    0.3016797751199806,
                                    0.12557572061565808,
                                    0.49643274731248815,
                                ],
                                [
                                    0.07631175695187313,
                                    0.12557572061565808,
                                    0.3016797751199806,
                                    0.49643274731248815,
                                ],
                                [
                                    0.04109094605100861,
                                    0.12557572061565803,
                                    0.20545473025504313,
                                    0.6278786030782902,
                                ],
                                [
                                    0.09319217791261583,
                                    0.1533534983934359,
                                    0.28479935415923796,
                                    0.4686549695347103,
                                ],
                                [
                                    0.09319217791261583,
                                    0.28479935415923796,
                                    0.1533534983934359,
                                    0.4686549695347103,
                                ],
                                [
                                    0.007864489864713269,
                                    0.16823956463960937,
                                    0.036793708873807125,
                                    0.7871022366218702,
                                ],
                                [
                                    0.007864489864713269,
                                    0.036793708873807125,
                                    0.16823956463960937,
                                    0.7871022366218702,
                                ],
                                [
                                    0.015307522987800004,
                                    0.32746319818318936,
                                    0.02935067575072039,
                                    0.6278786030782902,
                                ],
                                [
                                    0.1467533787536022,
                                    0.6865799545797311,
                                    0.029350675750720444,
                                    0.13731599091594623,
                                ],
                                [
                                    0.1467533787536022,
                                    0.029350675750720444,
                                    0.6865799545797311,
                                    0.13731599091594623,
                                ],
                                [
                                    0.015307522987800004,
                                    0.02935067575072039,
                                    0.32746319818318936,
                                    0.6278786030782902,
                                ],
                                [
                                    0.2856422676424911,
                                    0.05712845352849824,
                                    0.5476910656908421,
                                    0.10953821313816844,
                                ],
                                [
                                    0.2856422676424911,
                                    0.5476910656908421,
                                    0.05712845352849824,
                                    0.10953821313816844,
                                ],
                                [
                                    0.4088021768019533,
                                    0.24842710202705737,
                                    0.2132062911261928,
                                    0.12956443004479645,
                                ],
                                [
                                    0.4088021768019533,
                                    0.2132062911261928,
                                    0.24842710202705737,
                                    0.12956443004479645,
                                ],
                                [
                                    0.5124702547899777,
                                    0.31142569070569964,
                                    0.10953821313816843,
                                    0.06656584136615415,
                                ],
                                [
                                    0.5476910656908422,
                                    0.28564226764249107,
                                    0.10953821313816847,
                                    0.05712845352849822,
                                ],
                                [
                                    0.5476910656908422,
                                    0.10953821313816847,
                                    0.28564226764249107,
                                    0.05712845352849822,
                                ],
                                [
                                    0.5124702547899777,
                                    0.10953821313816843,
                                    0.31142569070569964,
                                    0.06656584136615415,
                                ],
                                [
                                    0.6865799545797311,
                                    0.13731599091594623,
                                    0.14675337875360214,
                                    0.029350675750720437,
                                ],
                                [
                                    0.6865799545797311,
                                    0.14675337875360214,
                                    0.13731599091594623,
                                    0.029350675750720437,
                                ],
                                [
                                    0.04968542040541145,
                                    0.2484271020270573,
                                    0.11698124626125518,
                                    0.5849062313062761,
                                ],
                                [
                                    0.04968542040541145,
                                    0.11698124626125518,
                                    0.2484271020270573,
                                    0.5849062313062761,
                                ],
                                [
                                    0.1533534983934358,
                                    0.7667674919671792,
                                    0.013313168273230827,
                                    0.06656584136615415,
                                ],
                                [
                                    0.2847993541592379,
                                    0.6705424471022415,
                                    0.013313168273230829,
                                    0.03134503046528963,
                                ],
                                [
                                    0.2847993541592379,
                                    0.013313168273230829,
                                    0.6705424471022415,
                                    0.03134503046528963,
                                ],
                                [
                                    0.1533534983934358,
                                    0.013313168273230827,
                                    0.7667674919671792,
                                    0.06656584136615415,
                                ],
                                [
                                    0.8790300443096064,
                                    0.04109094605100861,
                                    0.07631175695187313,
                                    0.0035672526875118456,
                                ],
                                [
                                    0.8790300443096064,
                                    0.07631175695187313,
                                    0.04109094605100861,
                                    0.0035672526875118456,
                                ],
                                [
                                    0.10953821313816843,
                                    0.5476910656908422,
                                    0.0571284535284982,
                                    0.28564226764249107,
                                ],
                                [
                                    0.10953821313816843,
                                    0.0571284535284982,
                                    0.5476910656908422,
                                    0.28564226764249107,
                                ],
                                [
                                    0.1373159909159462,
                                    0.6865799545797312,
                                    0.029350675750720426,
                                    0.14675337875360217,
                                ],
                                [
                                    0.24842710202705734,
                                    0.12956443004479642,
                                    0.4088021768019534,
                                    0.21320629112619285,
                                ],
                                [
                                    0.24842710202705734,
                                    0.4088021768019534,
                                    0.12956443004479642,
                                    0.21320629112619285,
                                ],
                                [
                                    0.1373159909159462,
                                    0.029350675750720426,
                                    0.6865799545797312,
                                    0.14675337875360217,
                                ],
                                [
                                    0.3114256907056996,
                                    0.5124702547899778,
                                    0.06656584136615414,
                                    0.10953821313816846,
                                ],
                                [
                                    0.3114256907056996,
                                    0.06656584136615414,
                                    0.5124702547899778,
                                    0.10953821313816846,
                                ],
                                [
                                    0.01331316827323081,
                                    0.28479935415923796,
                                    0.03134503046528959,
                                    0.6705424471022416,
                                ],
                                [
                                    0.01331316827323081,
                                    0.03134503046528959,
                                    0.28479935415923796,
                                    0.6705424471022416,
                                ],
                                [
                                    0.041090946051008555,
                                    0.8790300443096064,
                                    0.0035672526875118403,
                                    0.07631175695187313,
                                ],
                                [
                                    0.24842710202705728,
                                    0.584906231306276,
                                    0.04968542040541147,
                                    0.11698124626125522,
                                ],
                                [
                                    0.24842710202705728,
                                    0.04968542040541147,
                                    0.584906231306276,
                                    0.11698124626125522,
                                ],
                                [
                                    0.041090946051008555,
                                    0.0035672526875118403,
                                    0.8790300443096064,
                                    0.07631175695187313,
                                ],
                                [
                                    0.7667674919671791,
                                    0.15335349839343584,
                                    0.06656584136615414,
                                    0.01331316827323083,
                                ],
                                [
                                    0.7667674919671791,
                                    0.06656584136615414,
                                    0.15335349839343584,
                                    0.01331316827323083,
                                ],
                                [
                                    0.10953821313816847,
                                    0.06656584136615416,
                                    0.5124702547899777,
                                    0.31142569070569964,
                                ],
                                [
                                    0.10953821313816847,
                                    0.5124702547899777,
                                    0.06656584136615416,
                                    0.31142569070569964,
                                ],
                                [
                                    0.21320629112619288,
                                    0.1295644300447965,
                                    0.40880217680195324,
                                    0.2484271020270573,
                                ],
                                [
                                    0.1467533787536022,
                                    0.6865799545797311,
                                    0.029350675750720444,
                                    0.13731599091594623,
                                ],
                                [
                                    0.1467533787536022,
                                    0.029350675750720444,
                                    0.6865799545797311,
                                    0.13731599091594623,
                                ],
                                [
                                    0.21320629112619288,
                                    0.40880217680195324,
                                    0.1295644300447965,
                                    0.2484271020270573,
                                ],
                                [
                                    0.2856422676424911,
                                    0.05712845352849824,
                                    0.5476910656908421,
                                    0.10953821313816844,
                                ],
                                [
                                    0.2856422676424911,
                                    0.5476910656908421,
                                    0.05712845352849824,
                                    0.10953821313816844,
                                ],
                                [
                                    0.013313168273230829,
                                    0.06656584136615416,
                                    0.1533534983934358,
                                    0.7667674919671792,
                                ],
                                [
                                    0.013313168273230829,
                                    0.1533534983934358,
                                    0.06656584136615416,
                                    0.7667674919671792,
                                ],
                                [
                                    0.11698124626125518,
                                    0.5849062313062761,
                                    0.04968542040541145,
                                    0.2484271020270573,
                                ],
                                [
                                    0.07631175695187314,
                                    0.8790300443096064,
                                    0.003567252687511846,
                                    0.04109094605100861,
                                ],
                                [
                                    0.07631175695187314,
                                    0.003567252687511846,
                                    0.8790300443096064,
                                    0.04109094605100861,
                                ],
                                [
                                    0.11698124626125518,
                                    0.04968542040541145,
                                    0.5849062313062761,
                                    0.2484271020270573,
                                ],
                                [
                                    0.6705424471022415,
                                    0.03134503046528963,
                                    0.2847993541592379,
                                    0.013313168273230829,
                                ],
                                [
                                    0.6705424471022415,
                                    0.2847993541592379,
                                    0.03134503046528963,
                                    0.013313168273230829,
                                ],
                                [
                                    0.029350675750720433,
                                    0.14675337875360223,
                                    0.1373159909159462,
                                    0.6865799545797312,
                                ],
                                [
                                    0.029350675750720433,
                                    0.1373159909159462,
                                    0.14675337875360223,
                                    0.6865799545797312,
                                ],
                                [
                                    0.05712845352849822,
                                    0.2856422676424912,
                                    0.10953821313816842,
                                    0.5476910656908422,
                                ],
                                [
                                    0.06656584136615416,
                                    0.3114256907056996,
                                    0.10953821313816849,
                                    0.5124702547899778,
                                ],
                                [
                                    0.06656584136615416,
                                    0.10953821313816849,
                                    0.3114256907056996,
                                    0.5124702547899778,
                                ],
                                [
                                    0.05712845352849822,
                                    0.10953821313816842,
                                    0.2856422676424912,
                                    0.5476910656908422,
                                ],
                                [
                                    0.12956443004479648,
                                    0.2132062911261929,
                                    0.24842710202705728,
                                    0.4088021768019533,
                                ],
                                [
                                    0.12956443004479648,
                                    0.24842710202705728,
                                    0.2132062911261929,
                                    0.4088021768019533,
                                ],
                                [
                                    0.0035672526875118412,
                                    0.07631175695187314,
                                    0.041090946051008555,
                                    0.8790300443096064,
                                ],
                                [
                                    0.0035672526875118412,
                                    0.041090946051008555,
                                    0.07631175695187314,
                                    0.8790300443096064,
                                ],
                                [
                                    0.03134503046528959,
                                    0.6705424471022416,
                                    0.01331316827323081,
                                    0.28479935415923796,
                                ],
                                [
                                    0.06656584136615415,
                                    0.7667674919671791,
                                    0.013313168273230834,
                                    0.15335349839343584,
                                ],
                                [
                                    0.06656584136615415,
                                    0.013313168273230834,
                                    0.7667674919671791,
                                    0.15335349839343584,
                                ],
                                [
                                    0.03134503046528959,
                                    0.01331316827323081,
                                    0.6705424471022416,
                                    0.28479935415923796,
                                ],
                                [
                                    0.584906231306276,
                                    0.11698124626125522,
                                    0.24842710202705728,
                                    0.04968542040541147,
                                ],
                                [
                                    0.584906231306276,
                                    0.24842710202705728,
                                    0.11698124626125522,
                                    0.04968542040541147,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.009951477096473746,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.008680555555555556,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                                0.003937411792415144,
                            ]
                        ),
                    )
                case 3:
                    return (
                        np.array(
                            [
                                [
                                    0.7998568501158667,
                                    0.0888729833462074,
                                    0.10014314988413324,
                                    0.01112701665379258,
                                ],
                                [
                                    0.7998568501158667,
                                    0.10014314988413324,
                                    0.0888729833462074,
                                    0.01112701665379258,
                                ],
                                [
                                    0.7884253512745344,
                                    0.08760281680828158,
                                    0.11157464872546571,
                                    0.012397183191718411,
                                ],
                                [
                                    0.6996955178124601,
                                    0.08760281680828158,
                                    0.18903431564961404,
                                    0.023667349729644238,
                                ],
                                [
                                    0.6996955178124601,
                                    0.18903431564961404,
                                    0.08760281680828158,
                                    0.023667349729644238,
                                ],
                                [
                                    0.7884253512745344,
                                    0.11157464872546571,
                                    0.08760281680828158,
                                    0.012397183191718411,
                                ],
                                [
                                    0.6896955178124602,
                                    0.18633265027035573,
                                    0.09760281680828158,
                                    0.02636901510890255,
                                ],
                                [
                                    0.6896955178124602,
                                    0.09760281680828158,
                                    0.18633265027035573,
                                    0.02636901510890255,
                                ],
                                [
                                    0.8432912926000377,
                                    0.05035787471033311,
                                    0.1003578747103331,
                                    0.005992957979296034,
                                ],
                                [
                                    0.8432912926000377,
                                    0.1003578747103331,
                                    0.05035787471033311,
                                    0.005992957979296034,
                                ],
                                [
                                    0.7901158762552232,
                                    0.047182458365518536,
                                    0.15353329105514768,
                                    0.009168374324110612,
                                ],
                                [
                                    0.3964667089448523,
                                    0.047182458365518536,
                                    0.4971824583655185,
                                    0.0591683743241106,
                                ],
                                [
                                    0.3964667089448523,
                                    0.4971824583655185,
                                    0.047182458365518536,
                                    0.0591683743241106,
                                ],
                                [
                                    0.7901158762552232,
                                    0.15353329105514768,
                                    0.047182458365518536,
                                    0.009168374324110612,
                                ],
                                [
                                    0.3714667089448523,
                                    0.46583162567588937,
                                    0.07218245836551854,
                                    0.09051920701373975,
                                ],
                                [
                                    0.3714667089448523,
                                    0.07218245836551854,
                                    0.46583162567588937,
                                    0.09051920701373975,
                                ],
                                [
                                    0.8871551847366084,
                                    0.011413316422059075,
                                    0.10014314988413324,
                                    0.001288348957199232,
                                ],
                                [
                                    0.8871551847366084,
                                    0.10014314988413324,
                                    0.011413316422059075,
                                    0.001288348957199232,
                                ],
                                [
                                    0.7884253512745343,
                                    0.010143149884133245,
                                    0.1988729833462074,
                                    0.0025585154951250624,
                                ],
                                [
                                    0.08985685011586673,
                                    0.010143149884133245,
                                    0.8087116510428007,
                                    0.09128834895719923,
                                ],
                                [
                                    0.08985685011586673,
                                    0.8087116510428007,
                                    0.010143149884133245,
                                    0.09128834895719923,
                                ],
                                [
                                    0.7884253512745343,
                                    0.1988729833462074,
                                    0.010143149884133245,
                                    0.0025585154951250624,
                                ],
                                [
                                    0.07985685011586674,
                                    0.7187116510428008,
                                    0.02014314988413324,
                                    0.18128834895719922,
                                ],
                                [
                                    0.07985685011586674,
                                    0.02014314988413324,
                                    0.7187116510428008,
                                    0.18128834895719922,
                                ],
                                [
                                    0.4944455828827404,
                                    0.39428425057933375,
                                    0.06190524980688874,
                                    0.04936491673103708,
                                ],
                                [
                                    0.4944455828827404,
                                    0.06190524980688874,
                                    0.39428425057933375,
                                    0.04936491673103708,
                                ],
                                [
                                    0.48737900077244506,
                                    0.38864916731037086,
                                    0.06897183191718413,
                                    0.05499999999999999,
                                ],
                                [
                                    0.39428425057933375,
                                    0.04936491673103708,
                                    0.4944455828827404,
                                    0.06190524980688874,
                                ],
                                [
                                    0.39428425057933375,
                                    0.4944455828827404,
                                    0.04936491673103708,
                                    0.06190524980688874,
                                ],
                                [
                                    0.48737900077244506,
                                    0.06897183191718413,
                                    0.38864916731037086,
                                    0.05499999999999999,
                                ],
                                [
                                    0.38864916731037086,
                                    0.48737900077244506,
                                    0.05499999999999999,
                                    0.06897183191718413,
                                ],
                                [
                                    0.38864916731037086,
                                    0.05499999999999999,
                                    0.48737900077244506,
                                    0.06897183191718413,
                                ],
                                [
                                    0.6702368754827781,
                                    0.2234122918275927,
                                    0.07976312451722185,
                                    0.026587708172407284,
                                ],
                                [
                                    0.6702368754827781,
                                    0.07976312451722185,
                                    0.2234122918275927,
                                    0.026587708172407284,
                                ],
                                [
                                    0.6279737509655563,
                                    0.20932458365518541,
                                    0.12202624903444372,
                                    0.04067541634481457,
                                ],
                                [
                                    0.2234122918275927,
                                    0.026587708172407284,
                                    0.6702368754827781,
                                    0.07976312451722185,
                                ],
                                [
                                    0.2234122918275927,
                                    0.6702368754827781,
                                    0.026587708172407284,
                                    0.07976312451722185,
                                ],
                                [
                                    0.6279737509655563,
                                    0.12202624903444372,
                                    0.20932458365518541,
                                    0.04067541634481457,
                                ],
                                [
                                    0.20932458365518541,
                                    0.6279737509655563,
                                    0.04067541634481457,
                                    0.12202624903444372,
                                ],
                                [
                                    0.20932458365518541,
                                    0.04067541634481457,
                                    0.6279737509655563,
                                    0.12202624903444372,
                                ],
                                [
                                    0.8479334178897046,
                                    0.050635083268962905,
                                    0.09571574942066623,
                                    0.005715749420666239,
                                ],
                                [
                                    0.8479334178897046,
                                    0.09571574942066623,
                                    0.050635083268962905,
                                    0.005715749420666239,
                                ],
                                [
                                    0.7535685011586675,
                                    0.04499999999999999,
                                    0.1900806661517033,
                                    0.011350832689629154,
                                ],
                                [
                                    0.050635083268962905,
                                    0.005715749420666239,
                                    0.8479334178897046,
                                    0.09571574942066623,
                                ],
                                [
                                    0.050635083268962905,
                                    0.8479334178897046,
                                    0.005715749420666239,
                                    0.09571574942066623,
                                ],
                                [
                                    0.7535685011586675,
                                    0.1900806661517033,
                                    0.04499999999999999,
                                    0.011350832689629154,
                                ],
                                [
                                    0.04499999999999999,
                                    0.7535685011586675,
                                    0.011350832689629154,
                                    0.1900806661517033,
                                ],
                                [
                                    0.04499999999999999,
                                    0.011350832689629154,
                                    0.7535685011586675,
                                    0.1900806661517033,
                                ],
                                [
                                    0.18903431564961404,
                                    0.6996955178124601,
                                    0.023667349729644238,
                                    0.08760281680828158,
                                ],
                                [
                                    0.18903431564961404,
                                    0.023667349729644238,
                                    0.6996955178124601,
                                    0.08760281680828158,
                                ],
                                [
                                    0.18633265027035573,
                                    0.6896955178124602,
                                    0.02636901510890255,
                                    0.09760281680828158,
                                ],
                                [
                                    0.0888729833462074,
                                    0.011127016653792579,
                                    0.7998568501158667,
                                    0.10014314988413324,
                                ],
                                [
                                    0.0888729833462074,
                                    0.7998568501158667,
                                    0.011127016653792579,
                                    0.10014314988413324,
                                ],
                                [
                                    0.18633265027035573,
                                    0.02636901510890255,
                                    0.6896955178124602,
                                    0.09760281680828158,
                                ],
                                [
                                    0.08760281680828157,
                                    0.7884253512745344,
                                    0.01239718319171841,
                                    0.11157464872546571,
                                ],
                                [
                                    0.08760281680828157,
                                    0.01239718319171841,
                                    0.7884253512745344,
                                    0.11157464872546571,
                                ],
                                [
                                    0.4971824583655185,
                                    0.3964667089448523,
                                    0.0591683743241106,
                                    0.047182458365518536,
                                ],
                                [
                                    0.4971824583655185,
                                    0.0591683743241106,
                                    0.3964667089448523,
                                    0.047182458365518536,
                                ],
                                [
                                    0.46583162567588937,
                                    0.3714667089448523,
                                    0.09051920701373975,
                                    0.07218245836551854,
                                ],
                                [
                                    0.05035787471033311,
                                    0.005992957979296034,
                                    0.8432912926000377,
                                    0.1003578747103331,
                                ],
                                [
                                    0.05035787471033311,
                                    0.8432912926000377,
                                    0.005992957979296034,
                                    0.1003578747103331,
                                ],
                                [
                                    0.46583162567588937,
                                    0.09051920701373975,
                                    0.3714667089448523,
                                    0.07218245836551854,
                                ],
                                [
                                    0.047182458365518536,
                                    0.7901158762552232,
                                    0.009168374324110612,
                                    0.15353329105514768,
                                ],
                                [
                                    0.047182458365518536,
                                    0.009168374324110612,
                                    0.7901158762552232,
                                    0.15353329105514768,
                                ],
                                [
                                    0.8087116510428007,
                                    0.08985685011586673,
                                    0.09128834895719923,
                                    0.010143149884133246,
                                ],
                                [
                                    0.8087116510428007,
                                    0.09128834895719923,
                                    0.08985685011586673,
                                    0.010143149884133246,
                                ],
                                [
                                    0.7187116510428008,
                                    0.07985685011586674,
                                    0.18128834895719922,
                                    0.020143149884133245,
                                ],
                                [
                                    0.011413316422059087,
                                    0.001288348957199233,
                                    0.8871551847366084,
                                    0.10014314988413324,
                                ],
                                [
                                    0.011413316422059087,
                                    0.8871551847366084,
                                    0.001288348957199233,
                                    0.10014314988413324,
                                ],
                                [
                                    0.7187116510428008,
                                    0.18128834895719922,
                                    0.07985685011586674,
                                    0.020143149884133245,
                                ],
                                [
                                    0.010143149884133255,
                                    0.7884253512745343,
                                    0.002558515495125065,
                                    0.1988729833462074,
                                ],
                                [
                                    0.010143149884133255,
                                    0.002558515495125065,
                                    0.7884253512745343,
                                    0.1988729833462074,
                                ],
                                [
                                    0.4557157494206662,
                                    0.050635083268962905,
                                    0.44428425057933374,
                                    0.04936491673103708,
                                ],
                                [
                                    0.4557157494206662,
                                    0.44428425057933374,
                                    0.050635083268962905,
                                    0.04936491673103708,
                                ],
                                [
                                    0.4442842505793338,
                                    0.04936491673103709,
                                    0.4557157494206662,
                                    0.050635083268962905,
                                ],
                                [
                                    0.3986491673103708,
                                    0.38864916731037086,
                                    0.10770166537925828,
                                    0.10499999999999998,
                                ],
                                [
                                    0.3986491673103708,
                                    0.10770166537925828,
                                    0.38864916731037086,
                                    0.10499999999999998,
                                ],
                                [
                                    0.4442842505793338,
                                    0.4557157494206662,
                                    0.04936491673103709,
                                    0.050635083268962905,
                                ],
                                [
                                    0.3886491673103709,
                                    0.105,
                                    0.3986491673103708,
                                    0.10770166537925828,
                                ],
                                [
                                    0.3886491673103709,
                                    0.3986491673103708,
                                    0.105,
                                    0.10770166537925828,
                                ],
                                [
                                    0.4984122918275927,
                                    0.029763124517221864,
                                    0.4452368754827781,
                                    0.026587708172407284,
                                ],
                                [
                                    0.4984122918275927,
                                    0.4452368754827781,
                                    0.029763124517221864,
                                    0.026587708172407284,
                                ],
                                [
                                    0.4452368754827781,
                                    0.026587708172407284,
                                    0.4984122918275927,
                                    0.029763124517221864,
                                ],
                                [
                                    0.23432458365518544,
                                    0.20932458365518541,
                                    0.29385083268962914,
                                    0.2625,
                                ],
                                [
                                    0.23432458365518544,
                                    0.29385083268962914,
                                    0.20932458365518541,
                                    0.2625,
                                ],
                                [
                                    0.4452368754827781,
                                    0.4984122918275927,
                                    0.026587708172407284,
                                    0.029763124517221864,
                                ],
                                [
                                    0.20932458365518541,
                                    0.2625,
                                    0.23432458365518544,
                                    0.29385083268962914,
                                ],
                                [
                                    0.20932458365518541,
                                    0.23432458365518544,
                                    0.2625,
                                    0.29385083268962914,
                                ],
                                [
                                    0.5430140840414079,
                                    0.00698591595859207,
                                    0.44428425057933374,
                                    0.005715749420666239,
                                ],
                                [
                                    0.5430140840414079,
                                    0.44428425057933374,
                                    0.00698591595859207,
                                    0.005715749420666239,
                                ],
                                [
                                    0.44428425057933374,
                                    0.005715749420666238,
                                    0.5430140840414079,
                                    0.00698591595859207,
                                ],
                                [
                                    0.05499999999999999,
                                    0.04499999999999999,
                                    0.49500000000000005,
                                    0.405,
                                ],
                                [
                                    0.05499999999999999,
                                    0.49500000000000005,
                                    0.04499999999999999,
                                    0.405,
                                ],
                                [
                                    0.44428425057933374,
                                    0.5430140840414079,
                                    0.005715749420666238,
                                    0.00698591595859207,
                                ],
                                [
                                    0.044999999999999984,
                                    0.40499999999999997,
                                    0.05499999999999999,
                                    0.49500000000000005,
                                ],
                                [
                                    0.044999999999999984,
                                    0.05499999999999999,
                                    0.40499999999999997,
                                    0.49500000000000005,
                                ],
                                [
                                    0.28170870739996223,
                                    0.22464212528966687,
                                    0.27464212528966686,
                                    0.21900704202070398,
                                ],
                                [
                                    0.28170870739996223,
                                    0.27464212528966686,
                                    0.22464212528966687,
                                    0.21900704202070398,
                                ],
                                [
                                    0.2746421252896669,
                                    0.21900704202070398,
                                    0.28170870739996223,
                                    0.22464212528966687,
                                ],
                                [
                                    0.22464212528966687,
                                    0.21900704202070398,
                                    0.28170870739996223,
                                    0.27464212528966686,
                                ],
                                [
                                    0.22464212528966687,
                                    0.28170870739996223,
                                    0.21900704202070398,
                                    0.27464212528966686,
                                ],
                                [
                                    0.2746421252896669,
                                    0.28170870739996223,
                                    0.21900704202070398,
                                    0.22464212528966687,
                                ],
                                [
                                    0.21900704202070398,
                                    0.2746421252896669,
                                    0.22464212528966687,
                                    0.28170870739996223,
                                ],
                                [
                                    0.21900704202070398,
                                    0.22464212528966687,
                                    0.2746421252896669,
                                    0.28170870739996223,
                                ],
                                [
                                    0.3961315622586109,
                                    0.13204385408620364,
                                    0.3538684377413891,
                                    0.11795614591379636,
                                ],
                                [
                                    0.3961315622586109,
                                    0.3538684377413891,
                                    0.13204385408620364,
                                    0.11795614591379636,
                                ],
                                [
                                    0.3538684377413891,
                                    0.11795614591379636,
                                    0.3961315622586109,
                                    0.13204385408620364,
                                ],
                                [
                                    0.13204385408620364,
                                    0.11795614591379636,
                                    0.3961315622586109,
                                    0.3538684377413891,
                                ],
                                [
                                    0.13204385408620364,
                                    0.3961315622586109,
                                    0.11795614591379636,
                                    0.3538684377413891,
                                ],
                                [
                                    0.3538684377413891,
                                    0.3961315622586109,
                                    0.11795614591379636,
                                    0.13204385408620364,
                                ],
                                [
                                    0.11795614591379636,
                                    0.3538684377413891,
                                    0.13204385408620364,
                                    0.3961315622586109,
                                ],
                                [
                                    0.11795614591379636,
                                    0.13204385408620364,
                                    0.3538684377413891,
                                    0.3961315622586109,
                                ],
                                [
                                    0.519007042020704,
                                    0.030992957979296035,
                                    0.4246421252896669,
                                    0.025357874710333118,
                                ],
                                [
                                    0.519007042020704,
                                    0.4246421252896669,
                                    0.030992957979296035,
                                    0.025357874710333118,
                                ],
                                [
                                    0.4246421252896668,
                                    0.025357874710333114,
                                    0.519007042020704,
                                    0.030992957979296035,
                                ],
                                [
                                    0.030992957979296035,
                                    0.025357874710333118,
                                    0.519007042020704,
                                    0.4246421252896669,
                                ],
                                [
                                    0.030992957979296035,
                                    0.519007042020704,
                                    0.025357874710333118,
                                    0.4246421252896669,
                                ],
                                [
                                    0.4246421252896668,
                                    0.519007042020704,
                                    0.025357874710333114,
                                    0.030992957979296035,
                                ],
                                [
                                    0.025357874710333114,
                                    0.4246421252896668,
                                    0.030992957979296035,
                                    0.519007042020704,
                                ],
                                [
                                    0.025357874710333114,
                                    0.030992957979296035,
                                    0.4246421252896668,
                                    0.519007042020704,
                                ],
                                [
                                    0.10770166537925828,
                                    0.3986491673103708,
                                    0.10499999999999998,
                                    0.38864916731037086,
                                ],
                                [
                                    0.10770166537925828,
                                    0.10499999999999998,
                                    0.3986491673103708,
                                    0.38864916731037086,
                                ],
                                [
                                    0.105,
                                    0.3886491673103709,
                                    0.10770166537925828,
                                    0.3986491673103708,
                                ],
                                [
                                    0.0506350832689629,
                                    0.04936491673103707,
                                    0.4557157494206662,
                                    0.44428425057933374,
                                ],
                                [
                                    0.0506350832689629,
                                    0.4557157494206662,
                                    0.04936491673103707,
                                    0.44428425057933374,
                                ],
                                [
                                    0.105,
                                    0.10770166537925828,
                                    0.3886491673103709,
                                    0.3986491673103708,
                                ],
                                [
                                    0.04936491673103708,
                                    0.4442842505793338,
                                    0.0506350832689629,
                                    0.4557157494206662,
                                ],
                                [
                                    0.04936491673103708,
                                    0.0506350832689629,
                                    0.4442842505793338,
                                    0.4557157494206662,
                                ],
                                [
                                    0.29385083268962914,
                                    0.23432458365518544,
                                    0.2625,
                                    0.20932458365518541,
                                ],
                                [
                                    0.29385083268962914,
                                    0.2625,
                                    0.23432458365518544,
                                    0.20932458365518541,
                                ],
                                [
                                    0.2625,
                                    0.20932458365518541,
                                    0.29385083268962914,
                                    0.23432458365518544,
                                ],
                                [
                                    0.029763124517221864,
                                    0.026587708172407284,
                                    0.4984122918275927,
                                    0.4452368754827781,
                                ],
                                [
                                    0.029763124517221864,
                                    0.4984122918275927,
                                    0.026587708172407284,
                                    0.4452368754827781,
                                ],
                                [
                                    0.2625,
                                    0.29385083268962914,
                                    0.20932458365518541,
                                    0.23432458365518544,
                                ],
                                [
                                    0.026587708172407284,
                                    0.4452368754827781,
                                    0.029763124517221864,
                                    0.4984122918275927,
                                ],
                                [
                                    0.026587708172407284,
                                    0.029763124517221864,
                                    0.4452368754827781,
                                    0.4984122918275927,
                                ],
                                [0.49500000000000005, 0.055, 0.405, 0.045],
                                [0.49500000000000005, 0.405, 0.055, 0.045],
                                [
                                    0.40499999999999997,
                                    0.04499999999999999,
                                    0.49500000000000005,
                                    0.055,
                                ],
                                [
                                    0.006985915958592077,
                                    0.005715749420666244,
                                    0.5430140840414079,
                                    0.44428425057933374,
                                ],
                                [
                                    0.006985915958592077,
                                    0.5430140840414079,
                                    0.005715749420666244,
                                    0.44428425057933374,
                                ],
                                [
                                    0.40499999999999997,
                                    0.49500000000000005,
                                    0.04499999999999999,
                                    0.055,
                                ],
                                [
                                    0.005715749420666243,
                                    0.44428425057933374,
                                    0.006985915958592077,
                                    0.5430140840414079,
                                ],
                                [
                                    0.005715749420666243,
                                    0.006985915958592077,
                                    0.44428425057933374,
                                    0.5430140840414079,
                                ],
                                [
                                    0.11157464872546567,
                                    0.012397183191718408,
                                    0.7884253512745344,
                                    0.08760281680828158,
                                ],
                                [
                                    0.11157464872546567,
                                    0.7884253512745344,
                                    0.012397183191718408,
                                    0.08760281680828158,
                                ],
                                [
                                    0.10014314988413318,
                                    0.011127016653792576,
                                    0.7998568501158668,
                                    0.08887298334620741,
                                ],
                                [
                                    0.09760281680828155,
                                    0.6896955178124602,
                                    0.02636901510890254,
                                    0.18633265027035573,
                                ],
                                [
                                    0.09760281680828155,
                                    0.02636901510890254,
                                    0.6896955178124602,
                                    0.18633265027035573,
                                ],
                                [
                                    0.10014314988413318,
                                    0.7998568501158668,
                                    0.011127016653792576,
                                    0.08887298334620741,
                                ],
                                [
                                    0.08760281680828154,
                                    0.023667349729644228,
                                    0.6996955178124602,
                                    0.18903431564961404,
                                ],
                                [
                                    0.08760281680828154,
                                    0.6996955178124602,
                                    0.023667349729644228,
                                    0.18903431564961404,
                                ],
                                [
                                    0.15353329105514774,
                                    0.009168374324110613,
                                    0.7901158762552232,
                                    0.047182458365518536,
                                ],
                                [
                                    0.15353329105514774,
                                    0.7901158762552232,
                                    0.009168374324110613,
                                    0.047182458365518536,
                                ],
                                [
                                    0.10035787471033315,
                                    0.005992957979296037,
                                    0.8432912926000377,
                                    0.05035787471033311,
                                ],
                                [
                                    0.07218245836551855,
                                    0.3714667089448523,
                                    0.09051920701373979,
                                    0.46583162567588937,
                                ],
                                [
                                    0.07218245836551855,
                                    0.09051920701373979,
                                    0.3714667089448523,
                                    0.46583162567588937,
                                ],
                                [
                                    0.10035787471033315,
                                    0.8432912926000377,
                                    0.005992957979296037,
                                    0.05035787471033311,
                                ],
                                [
                                    0.047182458365518556,
                                    0.05916837432411064,
                                    0.3964667089448523,
                                    0.4971824583655185,
                                ],
                                [
                                    0.047182458365518556,
                                    0.3964667089448523,
                                    0.05916837432411064,
                                    0.4971824583655185,
                                ],
                                [
                                    0.19887298334620743,
                                    0.002558515495125063,
                                    0.7884253512745343,
                                    0.010143149884133245,
                                ],
                                [
                                    0.19887298334620743,
                                    0.7884253512745343,
                                    0.002558515495125063,
                                    0.010143149884133245,
                                ],
                                [
                                    0.10014314988413328,
                                    0.0012883489571992323,
                                    0.8871551847366084,
                                    0.011413316422059075,
                                ],
                                [
                                    0.020143149884133245,
                                    0.07985685011586674,
                                    0.18128834895719925,
                                    0.7187116510428008,
                                ],
                                [
                                    0.020143149884133245,
                                    0.18128834895719925,
                                    0.07985685011586674,
                                    0.7187116510428008,
                                ],
                                [
                                    0.10014314988413328,
                                    0.8871551847366084,
                                    0.0012883489571992323,
                                    0.011413316422059075,
                                ],
                                [
                                    0.01014314988413325,
                                    0.09128834895719927,
                                    0.08985685011586673,
                                    0.8087116510428007,
                                ],
                                [
                                    0.01014314988413325,
                                    0.08985685011586673,
                                    0.09128834895719927,
                                    0.8087116510428007,
                                ],
                                [
                                    0.0689718319171841,
                                    0.05499999999999997,
                                    0.48737900077244506,
                                    0.38864916731037086,
                                ],
                                [
                                    0.0689718319171841,
                                    0.48737900077244506,
                                    0.05499999999999997,
                                    0.38864916731037086,
                                ],
                                [
                                    0.06190524980688871,
                                    0.04936491673103705,
                                    0.49444558288274043,
                                    0.3942842505793338,
                                ],
                                [
                                    0.05499999999999997,
                                    0.38864916731037086,
                                    0.0689718319171841,
                                    0.48737900077244506,
                                ],
                                [
                                    0.05499999999999997,
                                    0.0689718319171841,
                                    0.38864916731037086,
                                    0.48737900077244506,
                                ],
                                [
                                    0.06190524980688871,
                                    0.49444558288274043,
                                    0.04936491673103705,
                                    0.3942842505793338,
                                ],
                                [
                                    0.04936491673103705,
                                    0.06190524980688871,
                                    0.3942842505793338,
                                    0.49444558288274043,
                                ],
                                [
                                    0.04936491673103705,
                                    0.3942842505793338,
                                    0.06190524980688871,
                                    0.49444558288274043,
                                ],
                                [
                                    0.12202624903444376,
                                    0.040675416344814586,
                                    0.6279737509655563,
                                    0.20932458365518541,
                                ],
                                [
                                    0.12202624903444376,
                                    0.6279737509655563,
                                    0.040675416344814586,
                                    0.20932458365518541,
                                ],
                                [
                                    0.0797631245172219,
                                    0.0265877081724073,
                                    0.6702368754827781,
                                    0.2234122918275927,
                                ],
                                [
                                    0.040675416344814586,
                                    0.20932458365518541,
                                    0.12202624903444376,
                                    0.6279737509655563,
                                ],
                                [
                                    0.040675416344814586,
                                    0.12202624903444376,
                                    0.20932458365518541,
                                    0.6279737509655563,
                                ],
                                [
                                    0.0797631245172219,
                                    0.6702368754827781,
                                    0.0265877081724073,
                                    0.2234122918275927,
                                ],
                                [
                                    0.0265877081724073,
                                    0.0797631245172219,
                                    0.2234122918275927,
                                    0.6702368754827781,
                                ],
                                [
                                    0.0265877081724073,
                                    0.2234122918275927,
                                    0.0797631245172219,
                                    0.6702368754827781,
                                ],
                                [
                                    0.19008066615170333,
                                    0.011350832689629154,
                                    0.7535685011586675,
                                    0.04499999999999999,
                                ],
                                [
                                    0.19008066615170333,
                                    0.7535685011586675,
                                    0.011350832689629154,
                                    0.04499999999999999,
                                ],
                                [
                                    0.09571574942066627,
                                    0.005715749420666241,
                                    0.8479334178897046,
                                    0.050635083268962905,
                                ],
                                [
                                    0.011350832689629154,
                                    0.04499999999999999,
                                    0.19008066615170333,
                                    0.7535685011586675,
                                ],
                                [
                                    0.011350832689629154,
                                    0.19008066615170333,
                                    0.04499999999999999,
                                    0.7535685011586675,
                                ],
                                [
                                    0.09571574942066627,
                                    0.8479334178897046,
                                    0.005715749420666241,
                                    0.050635083268962905,
                                ],
                                [
                                    0.005715749420666241,
                                    0.09571574942066627,
                                    0.050635083268962905,
                                    0.8479334178897046,
                                ],
                                [
                                    0.005715749420666241,
                                    0.050635083268962905,
                                    0.09571574942066627,
                                    0.8479334178897046,
                                ],
                                [
                                    0.02636901510890254,
                                    0.09760281680828155,
                                    0.18633265027035573,
                                    0.6896955178124602,
                                ],
                                [
                                    0.02636901510890254,
                                    0.18633265027035573,
                                    0.09760281680828155,
                                    0.6896955178124602,
                                ],
                                [
                                    0.023667349729644228,
                                    0.08760281680828154,
                                    0.18903431564961404,
                                    0.6996955178124602,
                                ],
                                [
                                    0.012397183191718406,
                                    0.08760281680828157,
                                    0.11157464872546567,
                                    0.7884253512745344,
                                ],
                                [
                                    0.012397183191718406,
                                    0.11157464872546567,
                                    0.08760281680828157,
                                    0.7884253512745344,
                                ],
                                [
                                    0.023667349729644228,
                                    0.18903431564961404,
                                    0.08760281680828154,
                                    0.6996955178124602,
                                ],
                                [
                                    0.011127016653792574,
                                    0.10014314988413318,
                                    0.0888729833462074,
                                    0.7998568501158668,
                                ],
                                [
                                    0.011127016653792574,
                                    0.0888729833462074,
                                    0.10014314988413318,
                                    0.7998568501158668,
                                ],
                                [
                                    0.09051920701373979,
                                    0.07218245836551855,
                                    0.46583162567588937,
                                    0.3714667089448523,
                                ],
                                [
                                    0.09051920701373979,
                                    0.46583162567588937,
                                    0.07218245836551855,
                                    0.3714667089448523,
                                ],
                                [
                                    0.05916837432411064,
                                    0.047182458365518556,
                                    0.4971824583655185,
                                    0.3964667089448523,
                                ],
                                [
                                    0.009168374324110613,
                                    0.047182458365518536,
                                    0.15353329105514774,
                                    0.7901158762552232,
                                ],
                                [
                                    0.009168374324110613,
                                    0.15353329105514774,
                                    0.047182458365518536,
                                    0.7901158762552232,
                                ],
                                [
                                    0.05916837432411064,
                                    0.4971824583655185,
                                    0.047182458365518556,
                                    0.3964667089448523,
                                ],
                                [
                                    0.005992957979296037,
                                    0.10035787471033315,
                                    0.05035787471033311,
                                    0.8432912926000377,
                                ],
                                [
                                    0.005992957979296037,
                                    0.05035787471033311,
                                    0.10035787471033315,
                                    0.8432912926000377,
                                ],
                                [
                                    0.18128834895719925,
                                    0.02014314988413325,
                                    0.7187116510428008,
                                    0.07985685011586674,
                                ],
                                [
                                    0.18128834895719925,
                                    0.7187116510428008,
                                    0.02014314988413325,
                                    0.07985685011586674,
                                ],
                                [
                                    0.09128834895719927,
                                    0.01014314988413325,
                                    0.8087116510428007,
                                    0.08985685011586673,
                                ],
                                [
                                    0.0025585154951250654,
                                    0.010143149884133255,
                                    0.19887298334620743,
                                    0.7884253512745343,
                                ],
                                [
                                    0.0025585154951250654,
                                    0.19887298334620743,
                                    0.010143149884133255,
                                    0.7884253512745343,
                                ],
                                [
                                    0.09128834895719927,
                                    0.8087116510428007,
                                    0.01014314988413325,
                                    0.08985685011586673,
                                ],
                                [
                                    0.0012883489571992336,
                                    0.10014314988413328,
                                    0.011413316422059087,
                                    0.8871551847366084,
                                ],
                                [
                                    0.0012883489571992336,
                                    0.011413316422059087,
                                    0.10014314988413328,
                                    0.8871551847366084,
                                ],
                                [
                                    0.8042842505793337,
                                    0.08936491673103707,
                                    0.09571574942066623,
                                    0.010635083268962913,
                                ],
                                [
                                    0.8042842505793337,
                                    0.09571574942066623,
                                    0.08936491673103707,
                                    0.010635083268962913,
                                ],
                                [
                                    0.7535685011586675,
                                    0.08372983346207416,
                                    0.14643149884133247,
                                    0.016270166537925828,
                                ],
                                [
                                    0.7035685011586675,
                                    0.08372983346207416,
                                    0.1900806661517033,
                                    0.022620999227554978,
                                ],
                                [
                                    0.7035685011586675,
                                    0.1900806661517033,
                                    0.08372983346207416,
                                    0.022620999227554978,
                                ],
                                [
                                    0.7535685011586675,
                                    0.14643149884133247,
                                    0.08372983346207416,
                                    0.016270166537925828,
                                ],
                                [
                                    0.6592035844276305,
                                    0.17809475019311122,
                                    0.12809475019311123,
                                    0.034606915186147044,
                                ],
                                [
                                    0.6592035844276305,
                                    0.12809475019311123,
                                    0.17809475019311122,
                                    0.034606915186147044,
                                ],
                                [
                                    0.863886042793149,
                                    0.051587708172407286,
                                    0.07976312451722185,
                                    0.004763124517221866,
                                ],
                                [
                                    0.863886042793149,
                                    0.07976312451722185,
                                    0.051587708172407286,
                                    0.004763124517221866,
                                ],
                                [
                                    0.6279737509655563,
                                    0.0375,
                                    0.31567541634481455,
                                    0.018850832689629154,
                                ],
                                [
                                    0.4061491673103709,
                                    0.0375,
                                    0.5093245836551854,
                                    0.047026249034443725,
                                ],
                                [
                                    0.4061491673103709,
                                    0.5093245836551854,
                                    0.0375,
                                    0.047026249034443725,
                                ],
                                [
                                    0.6279737509655563,
                                    0.31567541634481455,
                                    0.0375,
                                    0.018850832689629154,
                                ],
                                [
                                    0.29523687548277816,
                                    0.3702368754827781,
                                    0.14841229182759272,
                                    0.186113957206851,
                                ],
                                [
                                    0.29523687548277816,
                                    0.14841229182759272,
                                    0.3702368754827781,
                                    0.186113957206851,
                                ],
                                [
                                    0.925393084813853,
                                    0.011905249806888745,
                                    0.061905249806888746,
                                    0.0007964155723695645,
                                ],
                                [
                                    0.925393084813853,
                                    0.061905249806888746,
                                    0.011905249806888745,
                                    0.0007964155723695645,
                                ],
                                [
                                    0.48737900077244506,
                                    0.00627016653792583,
                                    0.4999193338482966,
                                    0.0064314988413324775,
                                ],
                                [
                                    0.09372983346207416,
                                    0.0062701665379258295,
                                    0.8435685011586675,
                                    0.05643149884133248,
                                ],
                                [
                                    0.09372983346207416,
                                    0.8435685011586675,
                                    0.0062701665379258295,
                                    0.05643149884133248,
                                ],
                                [
                                    0.48737900077244506,
                                    0.4999193338482966,
                                    0.00627016653792583,
                                    0.0064314988413324775,
                                ],
                                [
                                    0.04936491673103708,
                                    0.4442842505793338,
                                    0.0506350832689629,
                                    0.4557157494206662,
                                ],
                                [
                                    0.04936491673103708,
                                    0.0506350832689629,
                                    0.4442842505793338,
                                    0.4557157494206662,
                                ],
                                [
                                    0.4971824583655185,
                                    0.3964667089448523,
                                    0.0591683743241106,
                                    0.047182458365518536,
                                ],
                                [
                                    0.4971824583655185,
                                    0.0591683743241106,
                                    0.3964667089448523,
                                    0.047182458365518536,
                                ],
                                [
                                    0.46583162567588937,
                                    0.3714667089448523,
                                    0.09051920701373975,
                                    0.07218245836551854,
                                ],
                                [
                                    0.3964667089448523,
                                    0.047182458365518536,
                                    0.4971824583655185,
                                    0.0591683743241106,
                                ],
                                [
                                    0.3964667089448523,
                                    0.4971824583655185,
                                    0.047182458365518536,
                                    0.0591683743241106,
                                ],
                                [
                                    0.46583162567588937,
                                    0.09051920701373975,
                                    0.3714667089448523,
                                    0.07218245836551854,
                                ],
                                [
                                    0.3714667089448523,
                                    0.46583162567588937,
                                    0.07218245836551854,
                                    0.09051920701373975,
                                ],
                                [
                                    0.3714667089448523,
                                    0.07218245836551854,
                                    0.46583162567588937,
                                    0.09051920701373975,
                                ],
                                [
                                    0.6866053132241672,
                                    0.22886843774138907,
                                    0.06339468677583279,
                                    0.02113156225861093,
                                ],
                                [
                                    0.6866053132241672,
                                    0.06339468677583279,
                                    0.22886843774138907,
                                    0.02113156225861093,
                                ],
                                [
                                    0.4991053132241672,
                                    0.16636843774138907,
                                    0.2508946867758328,
                                    0.08363156225861093,
                                ],
                                [
                                    0.22886843774138907,
                                    0.02113156225861093,
                                    0.6866053132241672,
                                    0.06339468677583279,
                                ],
                                [
                                    0.22886843774138907,
                                    0.6866053132241672,
                                    0.02113156225861093,
                                    0.06339468677583279,
                                ],
                                [
                                    0.4991053132241672,
                                    0.2508946867758328,
                                    0.16636843774138907,
                                    0.08363156225861093,
                                ],
                                [
                                    0.16636843774138907,
                                    0.4991053132241672,
                                    0.08363156225861093,
                                    0.2508946867758328,
                                ],
                                [
                                    0.16636843774138907,
                                    0.08363156225861093,
                                    0.4991053132241672,
                                    0.2508946867758328,
                                ],
                                [
                                    0.8844807929862603,
                                    0.052817541634481456,
                                    0.05916837432411061,
                                    0.003533291055147697,
                                ],
                                [
                                    0.8844807929862603,
                                    0.05916837432411061,
                                    0.052817541634481456,
                                    0.003533291055147697,
                                ],
                                [
                                    0.4658316256758894,
                                    0.027817541634481458,
                                    0.4778175416344814,
                                    0.02853329105514769,
                                ],
                                [
                                    0.052817541634481456,
                                    0.003533291055147697,
                                    0.8844807929862603,
                                    0.05916837432411061,
                                ],
                                [
                                    0.052817541634481456,
                                    0.8844807929862603,
                                    0.003533291055147697,
                                    0.05916837432411061,
                                ],
                                [
                                    0.4658316256758894,
                                    0.4778175416344814,
                                    0.027817541634481458,
                                    0.02853329105514769,
                                ],
                                [
                                    0.027817541634481458,
                                    0.4658316256758894,
                                    0.02853329105514769,
                                    0.4778175416344814,
                                ],
                                [
                                    0.027817541634481458,
                                    0.02853329105514769,
                                    0.4658316256758894,
                                    0.4778175416344814,
                                ],
                                [
                                    0.1900806661517033,
                                    0.7035685011586675,
                                    0.022620999227554978,
                                    0.08372983346207416,
                                ],
                                [
                                    0.1900806661517033,
                                    0.022620999227554978,
                                    0.7035685011586675,
                                    0.08372983346207416,
                                ],
                                [
                                    0.17809475019311122,
                                    0.6592035844276305,
                                    0.034606915186147044,
                                    0.12809475019311123,
                                ],
                                [
                                    0.08936491673103707,
                                    0.010635083268962911,
                                    0.8042842505793337,
                                    0.09571574942066623,
                                ],
                                [
                                    0.08936491673103707,
                                    0.8042842505793337,
                                    0.010635083268962911,
                                    0.09571574942066623,
                                ],
                                [
                                    0.17809475019311122,
                                    0.034606915186147044,
                                    0.6592035844276305,
                                    0.12809475019311123,
                                ],
                                [
                                    0.08372983346207415,
                                    0.7535685011586675,
                                    0.016270166537925825,
                                    0.14643149884133247,
                                ],
                                [
                                    0.08372983346207415,
                                    0.016270166537925825,
                                    0.7535685011586675,
                                    0.14643149884133247,
                                ],
                                [
                                    0.5093245836551854,
                                    0.4061491673103709,
                                    0.047026249034443725,
                                    0.0375,
                                ],
                                [
                                    0.5093245836551854,
                                    0.047026249034443725,
                                    0.4061491673103709,
                                    0.0375,
                                ],
                                [
                                    0.3702368754827781,
                                    0.29523687548277816,
                                    0.186113957206851,
                                    0.14841229182759272,
                                ],
                                [
                                    0.051587708172407286,
                                    0.004763124517221866,
                                    0.863886042793149,
                                    0.07976312451722185,
                                ],
                                [
                                    0.051587708172407286,
                                    0.863886042793149,
                                    0.004763124517221866,
                                    0.07976312451722185,
                                ],
                                [
                                    0.3702368754827781,
                                    0.186113957206851,
                                    0.29523687548277816,
                                    0.14841229182759272,
                                ],
                                [
                                    0.0375,
                                    0.6279737509655563,
                                    0.018850832689629154,
                                    0.31567541634481455,
                                ],
                                [
                                    0.0375,
                                    0.018850832689629154,
                                    0.6279737509655563,
                                    0.31567541634481455,
                                ],
                                [
                                    0.8435685011586675,
                                    0.09372983346207417,
                                    0.05643149884133248,
                                    0.00627016653792583,
                                ],
                                [
                                    0.8435685011586675,
                                    0.05643149884133248,
                                    0.09372983346207417,
                                    0.00627016653792583,
                                ],
                                [
                                    0.4442842505793338,
                                    0.04936491673103709,
                                    0.4557157494206662,
                                    0.050635083268962905,
                                ],
                                [
                                    0.011905249806888755,
                                    0.0007964155723695652,
                                    0.925393084813853,
                                    0.061905249806888746,
                                ],
                                [
                                    0.011905249806888755,
                                    0.925393084813853,
                                    0.0007964155723695652,
                                    0.061905249806888746,
                                ],
                                [
                                    0.4442842505793338,
                                    0.4557157494206662,
                                    0.04936491673103709,
                                    0.050635083268962905,
                                ],
                                [
                                    0.0062701665379258364,
                                    0.48737900077244506,
                                    0.006431498841332484,
                                    0.4999193338482966,
                                ],
                                [
                                    0.0062701665379258364,
                                    0.006431498841332484,
                                    0.48737900077244506,
                                    0.4999193338482966,
                                ],
                                [
                                    0.47535787471033314,
                                    0.052817541634481456,
                                    0.4246421252896669,
                                    0.047182458365518536,
                                ],
                                [
                                    0.47535787471033314,
                                    0.4246421252896669,
                                    0.052817541634481456,
                                    0.047182458365518536,
                                ],
                                [
                                    0.4246421252896669,
                                    0.047182458365518536,
                                    0.47535787471033314,
                                    0.052817541634481456,
                                ],
                                [
                                    0.4158316256758894,
                                    0.37146670894485234,
                                    0.11234379066892518,
                                    0.1003578747103331,
                                ],
                                [
                                    0.4158316256758894,
                                    0.11234379066892518,
                                    0.37146670894485234,
                                    0.1003578747103331,
                                ],
                                [
                                    0.4246421252896669,
                                    0.47535787471033314,
                                    0.047182458365518536,
                                    0.052817541634481456,
                                ],
                                [
                                    0.37146670894485234,
                                    0.1003578747103331,
                                    0.4158316256758894,
                                    0.11234379066892518,
                                ],
                                [
                                    0.37146670894485234,
                                    0.4158316256758894,
                                    0.1003578747103331,
                                    0.11234379066892518,
                                ],
                                [
                                    0.5897807295689818,
                                    0.03521927043101822,
                                    0.3538684377413891,
                                    0.02113156225861093,
                                ],
                                [
                                    0.5897807295689818,
                                    0.3538684377413891,
                                    0.03521927043101822,
                                    0.02113156225861093,
                                ],
                                [
                                    0.3538684377413891,
                                    0.02113156225861093,
                                    0.5897807295689818,
                                    0.03521927043101822,
                                ],
                                [
                                    0.27728072956898175,
                                    0.16636843774138907,
                                    0.34771927043101825,
                                    0.20863156225861093,
                                ],
                                [
                                    0.27728072956898175,
                                    0.34771927043101825,
                                    0.16636843774138907,
                                    0.20863156225861093,
                                ],
                                [
                                    0.3538684377413891,
                                    0.5897807295689818,
                                    0.02113156225861093,
                                    0.03521927043101822,
                                ],
                                [
                                    0.16636843774138907,
                                    0.20863156225861093,
                                    0.27728072956898175,
                                    0.34771927043101825,
                                ],
                                [
                                    0.16636843774138907,
                                    0.27728072956898175,
                                    0.20863156225861093,
                                    0.34771927043101825,
                                ],
                                [
                                    0.7126562093310748,
                                    0.009168374324110612,
                                    0.27464212528966686,
                                    0.0035332910551476968,
                                ],
                                [
                                    0.7126562093310748,
                                    0.27464212528966686,
                                    0.009168374324110612,
                                    0.0035332910551476968,
                                ],
                                [
                                    0.27464212528966686,
                                    0.0035332910551476968,
                                    0.7126562093310748,
                                    0.009168374324110612,
                                ],
                                [
                                    0.07218245836551852,
                                    0.02781754163448145,
                                    0.6496421252896669,
                                    0.2503578747103331,
                                ],
                                [
                                    0.07218245836551852,
                                    0.6496421252896669,
                                    0.02781754163448145,
                                    0.2503578747103331,
                                ],
                                [
                                    0.27464212528966686,
                                    0.7126562093310748,
                                    0.0035332910551476968,
                                    0.009168374324110612,
                                ],
                                [
                                    0.02781754163448145,
                                    0.2503578747103331,
                                    0.07218245836551852,
                                    0.6496421252896669,
                                ],
                                [
                                    0.02781754163448145,
                                    0.07218245836551852,
                                    0.2503578747103331,
                                    0.6496421252896669,
                                ],
                                [
                                    0.29385083268962914,
                                    0.23432458365518544,
                                    0.2625,
                                    0.20932458365518541,
                                ],
                                [
                                    0.29385083268962914,
                                    0.2625,
                                    0.23432458365518544,
                                    0.20932458365518541,
                                ],
                                [
                                    0.2625,
                                    0.20932458365518541,
                                    0.29385083268962914,
                                    0.23432458365518544,
                                ],
                                [
                                    0.23432458365518544,
                                    0.20932458365518541,
                                    0.29385083268962914,
                                    0.2625,
                                ],
                                [
                                    0.23432458365518544,
                                    0.29385083268962914,
                                    0.20932458365518541,
                                    0.2625,
                                ],
                                [
                                    0.2625,
                                    0.29385083268962914,
                                    0.20932458365518541,
                                    0.23432458365518544,
                                ],
                                [
                                    0.20932458365518541,
                                    0.2625,
                                    0.23432458365518544,
                                    0.29385083268962914,
                                ],
                                [
                                    0.20932458365518541,
                                    0.23432458365518544,
                                    0.2625,
                                    0.29385083268962914,
                                ],
                                [0.46875, 0.15625, 0.28125, 0.09375],
                                [0.46875, 0.28125, 0.15625, 0.09375],
                                [0.28125, 0.09375, 0.46875, 0.15625],
                                [0.15625, 0.09375, 0.46875, 0.28125],
                                [0.15625, 0.46875, 0.09375, 0.28125],
                                [0.28125, 0.46875, 0.09375, 0.15625],
                                [0.09375, 0.28125, 0.15625, 0.46875],
                                [0.09375, 0.15625, 0.28125, 0.46875],
                                [
                                    0.6811491673103709,
                                    0.04067541634481457,
                                    0.2625,
                                    0.015675416344814577,
                                ],
                                [
                                    0.6811491673103709,
                                    0.2625,
                                    0.04067541634481457,
                                    0.015675416344814577,
                                ],
                                [
                                    0.2625,
                                    0.015675416344814577,
                                    0.6811491673103709,
                                    0.04067541634481457,
                                ],
                                [
                                    0.04067541634481457,
                                    0.015675416344814577,
                                    0.6811491673103709,
                                    0.2625,
                                ],
                                [
                                    0.04067541634481457,
                                    0.6811491673103709,
                                    0.015675416344814577,
                                    0.2625,
                                ],
                                [
                                    0.2625,
                                    0.6811491673103709,
                                    0.015675416344814577,
                                    0.04067541634481457,
                                ],
                                [
                                    0.015675416344814577,
                                    0.2625,
                                    0.04067541634481457,
                                    0.6811491673103709,
                                ],
                                [
                                    0.015675416344814577,
                                    0.04067541634481457,
                                    0.2625,
                                    0.6811491673103709,
                                ],
                                [
                                    0.11234379066892518,
                                    0.4158316256758894,
                                    0.1003578747103331,
                                    0.37146670894485234,
                                ],
                                [
                                    0.11234379066892518,
                                    0.1003578747103331,
                                    0.4158316256758894,
                                    0.37146670894485234,
                                ],
                                [
                                    0.1003578747103331,
                                    0.37146670894485234,
                                    0.11234379066892518,
                                    0.4158316256758894,
                                ],
                                [
                                    0.05281754163448145,
                                    0.04718245836551853,
                                    0.47535787471033314,
                                    0.4246421252896669,
                                ],
                                [
                                    0.05281754163448145,
                                    0.47535787471033314,
                                    0.04718245836551853,
                                    0.4246421252896669,
                                ],
                                [
                                    0.1003578747103331,
                                    0.11234379066892518,
                                    0.37146670894485234,
                                    0.4158316256758894,
                                ],
                                [
                                    0.04718245836551853,
                                    0.4246421252896669,
                                    0.05281754163448145,
                                    0.47535787471033314,
                                ],
                                [
                                    0.04718245836551853,
                                    0.05281754163448145,
                                    0.4246421252896669,
                                    0.47535787471033314,
                                ],
                                [
                                    0.34771927043101825,
                                    0.27728072956898175,
                                    0.20863156225861093,
                                    0.16636843774138907,
                                ],
                                [
                                    0.34771927043101825,
                                    0.20863156225861093,
                                    0.27728072956898175,
                                    0.16636843774138907,
                                ],
                                [
                                    0.20863156225861093,
                                    0.16636843774138907,
                                    0.34771927043101825,
                                    0.27728072956898175,
                                ],
                                [
                                    0.03521927043101822,
                                    0.02113156225861093,
                                    0.5897807295689818,
                                    0.3538684377413891,
                                ],
                                [
                                    0.03521927043101822,
                                    0.5897807295689818,
                                    0.02113156225861093,
                                    0.3538684377413891,
                                ],
                                [
                                    0.20863156225861093,
                                    0.34771927043101825,
                                    0.16636843774138907,
                                    0.27728072956898175,
                                ],
                                [
                                    0.02113156225861093,
                                    0.3538684377413891,
                                    0.03521927043101822,
                                    0.5897807295689818,
                                ],
                                [
                                    0.02113156225861093,
                                    0.03521927043101822,
                                    0.3538684377413891,
                                    0.5897807295689818,
                                ],
                                [
                                    0.6496421252896669,
                                    0.07218245836551854,
                                    0.2503578747103331,
                                    0.027817541634481455,
                                ],
                                [
                                    0.6496421252896669,
                                    0.2503578747103331,
                                    0.07218245836551854,
                                    0.027817541634481455,
                                ],
                                [
                                    0.2503578747103331,
                                    0.027817541634481455,
                                    0.6496421252896669,
                                    0.07218245836551854,
                                ],
                                [
                                    0.00916837432411062,
                                    0.0035332910551477002,
                                    0.7126562093310748,
                                    0.27464212528966686,
                                ],
                                [
                                    0.00916837432411062,
                                    0.7126562093310748,
                                    0.0035332910551477002,
                                    0.27464212528966686,
                                ],
                                [
                                    0.2503578747103331,
                                    0.6496421252896669,
                                    0.027817541634481455,
                                    0.07218245836551854,
                                ],
                                [
                                    0.0035332910551477002,
                                    0.27464212528966686,
                                    0.00916837432411062,
                                    0.7126562093310748,
                                ],
                                [
                                    0.0035332910551477002,
                                    0.00916837432411062,
                                    0.27464212528966686,
                                    0.7126562093310748,
                                ],
                                [
                                    0.14643149884133252,
                                    0.01627016653792583,
                                    0.7535685011586675,
                                    0.08372983346207416,
                                ],
                                [
                                    0.14643149884133252,
                                    0.7535685011586675,
                                    0.01627016653792583,
                                    0.08372983346207416,
                                ],
                                [
                                    0.09571574942066628,
                                    0.010635083268962918,
                                    0.8042842505793337,
                                    0.08936491673103707,
                                ],
                                [
                                    0.12809475019311128,
                                    0.6592035844276305,
                                    0.03460691518614706,
                                    0.17809475019311122,
                                ],
                                [
                                    0.12809475019311128,
                                    0.03460691518614706,
                                    0.6592035844276305,
                                    0.17809475019311122,
                                ],
                                [
                                    0.09571574942066628,
                                    0.8042842505793337,
                                    0.010635083268962918,
                                    0.08936491673103707,
                                ],
                                [
                                    0.0837298334620742,
                                    0.02262099922755499,
                                    0.7035685011586675,
                                    0.1900806661517033,
                                ],
                                [
                                    0.0837298334620742,
                                    0.7035685011586675,
                                    0.02262099922755499,
                                    0.1900806661517033,
                                ],
                                [
                                    0.31567541634481455,
                                    0.018850832689629154,
                                    0.6279737509655563,
                                    0.0375,
                                ],
                                [
                                    0.31567541634481455,
                                    0.6279737509655563,
                                    0.018850832689629154,
                                    0.0375,
                                ],
                                [
                                    0.07976312451722185,
                                    0.004763124517221866,
                                    0.863886042793149,
                                    0.051587708172407286,
                                ],
                                [
                                    0.14841229182759272,
                                    0.29523687548277816,
                                    0.186113957206851,
                                    0.3702368754827781,
                                ],
                                [
                                    0.14841229182759272,
                                    0.186113957206851,
                                    0.29523687548277816,
                                    0.3702368754827781,
                                ],
                                [
                                    0.07976312451722185,
                                    0.863886042793149,
                                    0.004763124517221866,
                                    0.051587708172407286,
                                ],
                                [
                                    0.0375,
                                    0.047026249034443725,
                                    0.4061491673103709,
                                    0.5093245836551854,
                                ],
                                [
                                    0.0375,
                                    0.4061491673103709,
                                    0.047026249034443725,
                                    0.5093245836551854,
                                ],
                                [
                                    0.4999193338482966,
                                    0.0064314988413324775,
                                    0.487379000772445,
                                    0.0062701665379258295,
                                ],
                                [
                                    0.4999193338482966,
                                    0.487379000772445,
                                    0.0064314988413324775,
                                    0.0062701665379258295,
                                ],
                                [
                                    0.06190524980688869,
                                    0.0007964155723695638,
                                    0.925393084813853,
                                    0.011905249806888745,
                                ],
                                [
                                    0.0506350832689629,
                                    0.04936491673103707,
                                    0.4557157494206662,
                                    0.44428425057933374,
                                ],
                                [
                                    0.0506350832689629,
                                    0.4557157494206662,
                                    0.04936491673103707,
                                    0.44428425057933374,
                                ],
                                [
                                    0.06190524980688869,
                                    0.925393084813853,
                                    0.0007964155723695638,
                                    0.011905249806888745,
                                ],
                                [
                                    0.006270166537925824,
                                    0.05643149884133243,
                                    0.09372983346207416,
                                    0.8435685011586675,
                                ],
                                [
                                    0.006270166537925824,
                                    0.09372983346207416,
                                    0.05643149884133243,
                                    0.8435685011586675,
                                ],
                                [
                                    0.09051920701373979,
                                    0.07218245836551855,
                                    0.46583162567588937,
                                    0.3714667089448523,
                                ],
                                [
                                    0.09051920701373979,
                                    0.46583162567588937,
                                    0.07218245836551855,
                                    0.3714667089448523,
                                ],
                                [
                                    0.05916837432411064,
                                    0.047182458365518556,
                                    0.4971824583655185,
                                    0.3964667089448523,
                                ],
                                [
                                    0.07218245836551855,
                                    0.3714667089448523,
                                    0.09051920701373979,
                                    0.46583162567588937,
                                ],
                                [
                                    0.07218245836551855,
                                    0.09051920701373979,
                                    0.3714667089448523,
                                    0.46583162567588937,
                                ],
                                [
                                    0.05916837432411064,
                                    0.4971824583655185,
                                    0.047182458365518556,
                                    0.3964667089448523,
                                ],
                                [
                                    0.047182458365518556,
                                    0.05916837432411064,
                                    0.3964667089448523,
                                    0.4971824583655185,
                                ],
                                [
                                    0.047182458365518556,
                                    0.3964667089448523,
                                    0.05916837432411064,
                                    0.4971824583655185,
                                ],
                                [
                                    0.2508946867758328,
                                    0.08363156225861093,
                                    0.4991053132241672,
                                    0.16636843774138907,
                                ],
                                [
                                    0.2508946867758328,
                                    0.4991053132241672,
                                    0.08363156225861093,
                                    0.16636843774138907,
                                ],
                                [
                                    0.06339468677583279,
                                    0.02113156225861093,
                                    0.6866053132241672,
                                    0.22886843774138907,
                                ],
                                [
                                    0.08363156225861093,
                                    0.16636843774138907,
                                    0.2508946867758328,
                                    0.4991053132241672,
                                ],
                                [
                                    0.08363156225861093,
                                    0.2508946867758328,
                                    0.16636843774138907,
                                    0.4991053132241672,
                                ],
                                [
                                    0.06339468677583279,
                                    0.6866053132241672,
                                    0.02113156225861093,
                                    0.22886843774138907,
                                ],
                                [
                                    0.02113156225861093,
                                    0.06339468677583279,
                                    0.22886843774138907,
                                    0.6866053132241672,
                                ],
                                [
                                    0.02113156225861093,
                                    0.22886843774138907,
                                    0.06339468677583279,
                                    0.6866053132241672,
                                ],
                                [
                                    0.4778175416344814,
                                    0.02853329105514769,
                                    0.46583162567588937,
                                    0.027817541634481455,
                                ],
                                [
                                    0.4778175416344814,
                                    0.46583162567588937,
                                    0.02853329105514769,
                                    0.027817541634481455,
                                ],
                                [
                                    0.05916837432411056,
                                    0.003533291055147694,
                                    0.8844807929862603,
                                    0.052817541634481456,
                                ],
                                [
                                    0.02853329105514769,
                                    0.027817541634481455,
                                    0.4778175416344814,
                                    0.46583162567588937,
                                ],
                                [
                                    0.02853329105514769,
                                    0.4778175416344814,
                                    0.027817541634481455,
                                    0.46583162567588937,
                                ],
                                [
                                    0.05916837432411056,
                                    0.8844807929862603,
                                    0.003533291055147694,
                                    0.052817541634481456,
                                ],
                                [
                                    0.003533291055147694,
                                    0.05916837432411056,
                                    0.052817541634481456,
                                    0.8844807929862603,
                                ],
                                [
                                    0.003533291055147694,
                                    0.052817541634481456,
                                    0.05916837432411056,
                                    0.8844807929862603,
                                ],
                                [
                                    0.03460691518614706,
                                    0.12809475019311128,
                                    0.17809475019311122,
                                    0.6592035844276305,
                                ],
                                [
                                    0.03460691518614706,
                                    0.17809475019311122,
                                    0.12809475019311128,
                                    0.6592035844276305,
                                ],
                                [
                                    0.02262099922755499,
                                    0.0837298334620742,
                                    0.1900806661517033,
                                    0.7035685011586675,
                                ],
                                [
                                    0.01627016653792583,
                                    0.08372983346207415,
                                    0.14643149884133252,
                                    0.7535685011586675,
                                ],
                                [
                                    0.01627016653792583,
                                    0.14643149884133252,
                                    0.08372983346207415,
                                    0.7535685011586675,
                                ],
                                [
                                    0.02262099922755499,
                                    0.1900806661517033,
                                    0.0837298334620742,
                                    0.7035685011586675,
                                ],
                                [
                                    0.010635083268962916,
                                    0.09571574942066628,
                                    0.08936491673103707,
                                    0.8042842505793337,
                                ],
                                [
                                    0.010635083268962916,
                                    0.08936491673103707,
                                    0.09571574942066628,
                                    0.8042842505793337,
                                ],
                                [
                                    0.186113957206851,
                                    0.14841229182759272,
                                    0.3702368754827781,
                                    0.29523687548277816,
                                ],
                                [
                                    0.186113957206851,
                                    0.3702368754827781,
                                    0.14841229182759272,
                                    0.29523687548277816,
                                ],
                                [
                                    0.047026249034443725,
                                    0.0375,
                                    0.5093245836551854,
                                    0.4061491673103709,
                                ],
                                [
                                    0.018850832689629154,
                                    0.0375,
                                    0.31567541634481455,
                                    0.6279737509655563,
                                ],
                                [
                                    0.018850832689629154,
                                    0.31567541634481455,
                                    0.0375,
                                    0.6279737509655563,
                                ],
                                [
                                    0.047026249034443725,
                                    0.5093245836551854,
                                    0.0375,
                                    0.4061491673103709,
                                ],
                                [
                                    0.004763124517221866,
                                    0.07976312451722185,
                                    0.051587708172407286,
                                    0.863886042793149,
                                ],
                                [
                                    0.004763124517221866,
                                    0.051587708172407286,
                                    0.07976312451722185,
                                    0.863886042793149,
                                ],
                                [
                                    0.4557157494206662,
                                    0.050635083268962905,
                                    0.44428425057933374,
                                    0.04936491673103708,
                                ],
                                [
                                    0.4557157494206662,
                                    0.44428425057933374,
                                    0.050635083268962905,
                                    0.04936491673103708,
                                ],
                                [
                                    0.05643149884133243,
                                    0.006270166537925825,
                                    0.8435685011586675,
                                    0.09372983346207417,
                                ],
                                [
                                    0.006431498841332484,
                                    0.006270166537925836,
                                    0.4999193338482966,
                                    0.487379000772445,
                                ],
                                [
                                    0.006431498841332484,
                                    0.4999193338482966,
                                    0.006270166537925836,
                                    0.487379000772445,
                                ],
                                [
                                    0.05643149884133243,
                                    0.8435685011586675,
                                    0.006270166537925825,
                                    0.09372983346207417,
                                ],
                                [
                                    0.0007964155723695646,
                                    0.06190524980688869,
                                    0.011905249806888755,
                                    0.925393084813853,
                                ],
                                [
                                    0.0007964155723695646,
                                    0.011905249806888755,
                                    0.06190524980688869,
                                    0.925393084813853,
                                ],
                                [
                                    0.8087116510428007,
                                    0.08985685011586673,
                                    0.09128834895719923,
                                    0.010143149884133246,
                                ],
                                [
                                    0.8087116510428007,
                                    0.09128834895719923,
                                    0.08985685011586673,
                                    0.010143149884133246,
                                ],
                                [
                                    0.7187116510428008,
                                    0.07985685011586674,
                                    0.18128834895719922,
                                    0.020143149884133245,
                                ],
                                [
                                    0.707441484504875,
                                    0.07985685011586675,
                                    0.19112701665379253,
                                    0.021574648725465724,
                                ],
                                [
                                    0.707441484504875,
                                    0.19112701665379253,
                                    0.07985685011586675,
                                    0.021574648725465724,
                                ],
                                [
                                    0.7187116510428008,
                                    0.18128834895719922,
                                    0.07985685011586674,
                                    0.020143149884133245,
                                ],
                                [
                                    0.6287116510428008,
                                    0.1698568501158667,
                                    0.15858668357794092,
                                    0.042844815263391546,
                                ],
                                [
                                    0.6287116510428008,
                                    0.15858668357794092,
                                    0.1698568501158667,
                                    0.042844815263391546,
                                ],
                                [
                                    0.8844807929862603,
                                    0.052817541634481456,
                                    0.05916837432411061,
                                    0.003533291055147697,
                                ],
                                [
                                    0.8844807929862603,
                                    0.05916837432411061,
                                    0.052817541634481456,
                                    0.003533291055147697,
                                ],
                                [
                                    0.4658316256758894,
                                    0.027817541634481458,
                                    0.4778175416344814,
                                    0.02853329105514769,
                                ],
                                [
                                    0.41583162567588944,
                                    0.027817541634481458,
                                    0.5214667089448524,
                                    0.034884123744776854,
                                ],
                                [
                                    0.41583162567588944,
                                    0.5214667089448524,
                                    0.027817541634481458,
                                    0.034884123744776854,
                                ],
                                [
                                    0.4658316256758894,
                                    0.4778175416344814,
                                    0.027817541634481458,
                                    0.02853329105514769,
                                ],
                                [
                                    0.21900704202070398,
                                    0.2746421252896669,
                                    0.22464212528966687,
                                    0.28170870739996223,
                                ],
                                [
                                    0.21900704202070398,
                                    0.22464212528966687,
                                    0.2746421252896669,
                                    0.28170870739996223,
                                ],
                                [
                                    0.9636309848910974,
                                    0.012397183191718411,
                                    0.023667349729644238,
                                    0.00030448218753989704,
                                ],
                                [
                                    0.9636309848910974,
                                    0.023667349729644238,
                                    0.012397183191718411,
                                    0.00030448218753989704,
                                ],
                                [
                                    0.18633265027035575,
                                    0.0023971831917184135,
                                    0.800965684350386,
                                    0.010304482187539894,
                                ],
                                [
                                    0.09760281680828156,
                                    0.002397183191718413,
                                    0.8784253512745344,
                                    0.021574648725465724,
                                ],
                                [
                                    0.09760281680828156,
                                    0.8784253512745344,
                                    0.002397183191718413,
                                    0.021574648725465724,
                                ],
                                [
                                    0.18633265027035575,
                                    0.800965684350386,
                                    0.0023971831917184135,
                                    0.010304482187539894,
                                ],
                                [
                                    0.018872983346207413,
                                    0.16985685011586676,
                                    0.08112701665379257,
                                    0.7301431498841333,
                                ],
                                [
                                    0.018872983346207413,
                                    0.08112701665379257,
                                    0.16985685011586676,
                                    0.7301431498841333,
                                ],
                                [
                                    0.4999193338482967,
                                    0.3986491673103708,
                                    0.05643149884133247,
                                    0.045,
                                ],
                                [
                                    0.4999193338482967,
                                    0.05643149884133247,
                                    0.3986491673103708,
                                    0.045,
                                ],
                                [
                                    0.44428425057933374,
                                    0.35428425057933377,
                                    0.11206658211029538,
                                    0.08936491673103708,
                                ],
                                [
                                    0.3986491673103708,
                                    0.045,
                                    0.4999193338482967,
                                    0.05643149884133247,
                                ],
                                [
                                    0.3986491673103708,
                                    0.4999193338482967,
                                    0.045,
                                    0.05643149884133247,
                                ],
                                [
                                    0.44428425057933374,
                                    0.11206658211029538,
                                    0.35428425057933377,
                                    0.08936491673103708,
                                ],
                                [
                                    0.35428425057933377,
                                    0.44428425057933374,
                                    0.08936491673103708,
                                    0.11206658211029538,
                                ],
                                [
                                    0.35428425057933377,
                                    0.08936491673103708,
                                    0.44428425057933374,
                                    0.11206658211029538,
                                ],
                                [
                                    0.7029737509655563,
                                    0.23432458365518544,
                                    0.04702624903444373,
                                    0.015675416344814577,
                                ],
                                [
                                    0.7029737509655563,
                                    0.04702624903444373,
                                    0.23432458365518544,
                                    0.015675416344814577,
                                ],
                                [
                                    0.37023687548277817,
                                    0.12341229182759272,
                                    0.37976312451722183,
                                    0.12658770817240728,
                                ],
                                [
                                    0.23432458365518544,
                                    0.015675416344814577,
                                    0.7029737509655563,
                                    0.04702624903444373,
                                ],
                                [
                                    0.23432458365518544,
                                    0.7029737509655563,
                                    0.015675416344814577,
                                    0.04702624903444373,
                                ],
                                [
                                    0.37023687548277817,
                                    0.37976312451722183,
                                    0.12341229182759272,
                                    0.12658770817240728,
                                ],
                                [
                                    0.12341229182759272,
                                    0.37023687548277817,
                                    0.12658770817240728,
                                    0.37976312451722183,
                                ],
                                [
                                    0.12341229182759272,
                                    0.12658770817240728,
                                    0.37023687548277817,
                                    0.37976312451722183,
                                ],
                                [
                                    0.9210281680828158,
                                    0.05499999999999999,
                                    0.02262099922755498,
                                    0.0013508326896291552,
                                ],
                                [
                                    0.9210281680828158,
                                    0.02262099922755498,
                                    0.05499999999999999,
                                    0.0013508326896291552,
                                ],
                                [
                                    0.17809475019311125,
                                    0.010635083268962914,
                                    0.7655544171172596,
                                    0.04571574942066624,
                                ],
                                [
                                    0.05499999999999999,
                                    0.0013508326896291552,
                                    0.9210281680828158,
                                    0.02262099922755498,
                                ],
                                [
                                    0.05499999999999999,
                                    0.9210281680828158,
                                    0.0013508326896291552,
                                    0.02262099922755498,
                                ],
                                [
                                    0.17809475019311125,
                                    0.7655544171172596,
                                    0.010635083268962914,
                                    0.04571574942066624,
                                ],
                                [
                                    0.010635083268962914,
                                    0.17809475019311125,
                                    0.04571574942066624,
                                    0.7655544171172596,
                                ],
                                [
                                    0.010635083268962914,
                                    0.04571574942066624,
                                    0.17809475019311125,
                                    0.7655544171172596,
                                ],
                                [
                                    0.19112701665379253,
                                    0.707441484504875,
                                    0.021574648725465724,
                                    0.07985685011586675,
                                ],
                                [
                                    0.19112701665379253,
                                    0.021574648725465724,
                                    0.707441484504875,
                                    0.07985685011586675,
                                ],
                                [
                                    0.1698568501158667,
                                    0.6287116510428008,
                                    0.042844815263391546,
                                    0.15858668357794092,
                                ],
                                [
                                    0.08985685011586673,
                                    0.010143149884133245,
                                    0.8087116510428007,
                                    0.09128834895719923,
                                ],
                                [
                                    0.08985685011586673,
                                    0.8087116510428007,
                                    0.010143149884133245,
                                    0.09128834895719923,
                                ],
                                [
                                    0.1698568501158667,
                                    0.042844815263391546,
                                    0.6287116510428008,
                                    0.15858668357794092,
                                ],
                                [
                                    0.07985685011586674,
                                    0.7187116510428008,
                                    0.02014314988413324,
                                    0.18128834895719922,
                                ],
                                [
                                    0.07985685011586674,
                                    0.02014314988413324,
                                    0.7187116510428008,
                                    0.18128834895719922,
                                ],
                                [
                                    0.5214667089448524,
                                    0.41583162567588944,
                                    0.034884123744776854,
                                    0.027817541634481458,
                                ],
                                [
                                    0.5214667089448524,
                                    0.034884123744776854,
                                    0.41583162567588944,
                                    0.027817541634481458,
                                ],
                                [
                                    0.2746421252896669,
                                    0.21900704202070398,
                                    0.28170870739996223,
                                    0.22464212528966687,
                                ],
                                [
                                    0.052817541634481456,
                                    0.003533291055147697,
                                    0.8844807929862603,
                                    0.05916837432411061,
                                ],
                                [
                                    0.052817541634481456,
                                    0.8844807929862603,
                                    0.003533291055147697,
                                    0.05916837432411061,
                                ],
                                [
                                    0.2746421252896669,
                                    0.28170870739996223,
                                    0.21900704202070398,
                                    0.22464212528966687,
                                ],
                                [
                                    0.027817541634481458,
                                    0.4658316256758894,
                                    0.02853329105514769,
                                    0.4778175416344814,
                                ],
                                [
                                    0.027817541634481458,
                                    0.02853329105514769,
                                    0.4658316256758894,
                                    0.4778175416344814,
                                ],
                                [
                                    0.8784253512745344,
                                    0.09760281680828158,
                                    0.021574648725465724,
                                    0.0023971831917184135,
                                ],
                                [
                                    0.8784253512745344,
                                    0.021574648725465724,
                                    0.09760281680828158,
                                    0.0023971831917184135,
                                ],
                                [
                                    0.16985685011586676,
                                    0.018872983346207416,
                                    0.7301431498841333,
                                    0.08112701665379257,
                                ],
                                [
                                    0.012397183191718423,
                                    0.00030448218753989737,
                                    0.9636309848910974,
                                    0.023667349729644238,
                                ],
                                [
                                    0.012397183191718423,
                                    0.9636309848910974,
                                    0.00030448218753989737,
                                    0.023667349729644238,
                                ],
                                [
                                    0.16985685011586676,
                                    0.7301431498841333,
                                    0.018872983346207416,
                                    0.08112701665379257,
                                ],
                                [
                                    0.002397183191718416,
                                    0.18633265027035575,
                                    0.010304482187539904,
                                    0.800965684350386,
                                ],
                                [
                                    0.002397183191718416,
                                    0.010304482187539904,
                                    0.18633265027035575,
                                    0.800965684350386,
                                ],
                                [0.49500000000000005, 0.055, 0.405, 0.045],
                                [0.49500000000000005, 0.405, 0.055, 0.045],
                                [
                                    0.40499999999999997,
                                    0.04499999999999999,
                                    0.49500000000000005,
                                    0.055,
                                ],
                                [
                                    0.433014084041408,
                                    0.35428425057933377,
                                    0.11698591595859206,
                                    0.09571574942066623,
                                ],
                                [
                                    0.433014084041408,
                                    0.11698591595859206,
                                    0.35428425057933377,
                                    0.09571574942066623,
                                ],
                                [
                                    0.40499999999999997,
                                    0.49500000000000005,
                                    0.04499999999999999,
                                    0.055,
                                ],
                                [
                                    0.3542842505793337,
                                    0.09571574942066621,
                                    0.433014084041408,
                                    0.11698591595859206,
                                ],
                                [
                                    0.3542842505793337,
                                    0.433014084041408,
                                    0.09571574942066621,
                                    0.11698591595859206,
                                ],
                                [
                                    0.6811491673103709,
                                    0.04067541634481457,
                                    0.2625,
                                    0.015675416344814577,
                                ],
                                [
                                    0.6811491673103709,
                                    0.2625,
                                    0.04067541634481457,
                                    0.015675416344814577,
                                ],
                                [
                                    0.2625,
                                    0.015675416344814577,
                                    0.6811491673103709,
                                    0.04067541634481457,
                                ],
                                [
                                    0.3202368754827781,
                                    0.12341229182759271,
                                    0.4015877081724073,
                                    0.15476312451722185,
                                ],
                                [
                                    0.3202368754827781,
                                    0.4015877081724073,
                                    0.12341229182759271,
                                    0.15476312451722185,
                                ],
                                [
                                    0.2625,
                                    0.6811491673103709,
                                    0.015675416344814577,
                                    0.04067541634481457,
                                ],
                                [
                                    0.12341229182759271,
                                    0.15476312451722185,
                                    0.3202368754827781,
                                    0.4015877081724073,
                                ],
                                [
                                    0.12341229182759271,
                                    0.3202368754827781,
                                    0.15476312451722185,
                                    0.4015877081724073,
                                ],
                                [
                                    0.8822983346207417,
                                    0.011350832689629152,
                                    0.10499999999999998,
                                    0.0013508326896291552,
                                ],
                                [
                                    0.8822983346207417,
                                    0.10499999999999998,
                                    0.011350832689629152,
                                    0.0013508326896291552,
                                ],
                                [
                                    0.10500000000000004,
                                    0.0013508326896291558,
                                    0.8822983346207417,
                                    0.011350832689629152,
                                ],
                                [
                                    0.08936491673103707,
                                    0.010635083268962911,
                                    0.8042842505793337,
                                    0.09571574942066623,
                                ],
                                [
                                    0.08936491673103707,
                                    0.8042842505793337,
                                    0.010635083268962911,
                                    0.09571574942066623,
                                ],
                                [
                                    0.10500000000000004,
                                    0.8822983346207417,
                                    0.0013508326896291558,
                                    0.011350832689629152,
                                ],
                                [
                                    0.010635083268962916,
                                    0.09571574942066628,
                                    0.08936491673103707,
                                    0.8042842505793337,
                                ],
                                [
                                    0.010635083268962916,
                                    0.08936491673103707,
                                    0.09571574942066628,
                                    0.8042842505793337,
                                ],
                                [
                                    0.30599295797929604,
                                    0.244007042020704,
                                    0.2503578747103331,
                                    0.19964212528966688,
                                ],
                                [
                                    0.30599295797929604,
                                    0.2503578747103331,
                                    0.244007042020704,
                                    0.19964212528966688,
                                ],
                                [
                                    0.2503578747103331,
                                    0.19964212528966685,
                                    0.30599295797929604,
                                    0.244007042020704,
                                ],
                                [
                                    0.244007042020704,
                                    0.19964212528966688,
                                    0.30599295797929604,
                                    0.2503578747103331,
                                ],
                                [
                                    0.244007042020704,
                                    0.30599295797929604,
                                    0.19964212528966688,
                                    0.2503578747103331,
                                ],
                                [
                                    0.2503578747103331,
                                    0.30599295797929604,
                                    0.19964212528966685,
                                    0.244007042020704,
                                ],
                                [
                                    0.19964212528966685,
                                    0.2503578747103331,
                                    0.244007042020704,
                                    0.30599295797929604,
                                ],
                                [
                                    0.19964212528966685,
                                    0.244007042020704,
                                    0.2503578747103331,
                                    0.30599295797929604,
                                ],
                                [
                                    0.5413684377413891,
                                    0.18045614591379636,
                                    0.20863156225861093,
                                    0.06954385408620364,
                                ],
                                [
                                    0.5413684377413891,
                                    0.20863156225861093,
                                    0.18045614591379636,
                                    0.06954385408620364,
                                ],
                                [
                                    0.20863156225861093,
                                    0.06954385408620364,
                                    0.5413684377413891,
                                    0.18045614591379636,
                                ],
                                [
                                    0.18045614591379636,
                                    0.06954385408620364,
                                    0.5413684377413891,
                                    0.20863156225861093,
                                ],
                                [
                                    0.18045614591379636,
                                    0.5413684377413891,
                                    0.06954385408620364,
                                    0.20863156225861093,
                                ],
                                [
                                    0.20863156225861093,
                                    0.5413684377413891,
                                    0.06954385408620364,
                                    0.18045614591379636,
                                ],
                                [
                                    0.06954385408620364,
                                    0.20863156225861093,
                                    0.18045614591379636,
                                    0.5413684377413891,
                                ],
                                [
                                    0.06954385408620364,
                                    0.18045614591379636,
                                    0.20863156225861093,
                                    0.5413684377413891,
                                ],
                                [
                                    0.8432912926000377,
                                    0.05035787471033311,
                                    0.1003578747103331,
                                    0.005992957979296034,
                                ],
                                [
                                    0.8432912926000377,
                                    0.1003578747103331,
                                    0.05035787471033311,
                                    0.005992957979296034,
                                ],
                                [
                                    0.10035787471033315,
                                    0.005992957979296037,
                                    0.8432912926000377,
                                    0.05035787471033311,
                                ],
                                [
                                    0.05035787471033311,
                                    0.005992957979296034,
                                    0.8432912926000377,
                                    0.1003578747103331,
                                ],
                                [
                                    0.05035787471033311,
                                    0.8432912926000377,
                                    0.005992957979296034,
                                    0.1003578747103331,
                                ],
                                [
                                    0.10035787471033315,
                                    0.8432912926000377,
                                    0.005992957979296037,
                                    0.05035787471033311,
                                ],
                                [
                                    0.005992957979296037,
                                    0.10035787471033315,
                                    0.05035787471033311,
                                    0.8432912926000377,
                                ],
                                [
                                    0.005992957979296037,
                                    0.05035787471033311,
                                    0.10035787471033315,
                                    0.8432912926000377,
                                ],
                                [
                                    0.11698591595859206,
                                    0.433014084041408,
                                    0.09571574942066623,
                                    0.35428425057933377,
                                ],
                                [
                                    0.11698591595859206,
                                    0.09571574942066623,
                                    0.433014084041408,
                                    0.35428425057933377,
                                ],
                                [
                                    0.09571574942066621,
                                    0.3542842505793337,
                                    0.11698591595859206,
                                    0.433014084041408,
                                ],
                                [
                                    0.05499999999999999,
                                    0.04499999999999999,
                                    0.49500000000000005,
                                    0.405,
                                ],
                                [
                                    0.05499999999999999,
                                    0.49500000000000005,
                                    0.04499999999999999,
                                    0.405,
                                ],
                                [
                                    0.09571574942066621,
                                    0.11698591595859206,
                                    0.3542842505793337,
                                    0.433014084041408,
                                ],
                                [
                                    0.044999999999999984,
                                    0.40499999999999997,
                                    0.05499999999999999,
                                    0.49500000000000005,
                                ],
                                [
                                    0.044999999999999984,
                                    0.05499999999999999,
                                    0.40499999999999997,
                                    0.49500000000000005,
                                ],
                                [
                                    0.4015877081724073,
                                    0.3202368754827781,
                                    0.15476312451722185,
                                    0.12341229182759271,
                                ],
                                [
                                    0.4015877081724073,
                                    0.15476312451722185,
                                    0.3202368754827781,
                                    0.12341229182759271,
                                ],
                                [
                                    0.15476312451722185,
                                    0.12341229182759271,
                                    0.4015877081724073,
                                    0.3202368754827781,
                                ],
                                [
                                    0.04067541634481457,
                                    0.015675416344814577,
                                    0.6811491673103709,
                                    0.2625,
                                ],
                                [
                                    0.04067541634481457,
                                    0.6811491673103709,
                                    0.015675416344814577,
                                    0.2625,
                                ],
                                [
                                    0.15476312451722185,
                                    0.4015877081724073,
                                    0.12341229182759271,
                                    0.3202368754827781,
                                ],
                                [
                                    0.015675416344814577,
                                    0.2625,
                                    0.04067541634481457,
                                    0.6811491673103709,
                                ],
                                [
                                    0.015675416344814577,
                                    0.04067541634481457,
                                    0.2625,
                                    0.6811491673103709,
                                ],
                                [
                                    0.8042842505793337,
                                    0.08936491673103707,
                                    0.09571574942066623,
                                    0.010635083268962913,
                                ],
                                [
                                    0.8042842505793337,
                                    0.09571574942066623,
                                    0.08936491673103707,
                                    0.010635083268962913,
                                ],
                                [
                                    0.09571574942066628,
                                    0.010635083268962918,
                                    0.8042842505793337,
                                    0.08936491673103707,
                                ],
                                [
                                    0.011350832689629163,
                                    0.0013508326896291565,
                                    0.8822983346207417,
                                    0.10499999999999998,
                                ],
                                [
                                    0.011350832689629163,
                                    0.8822983346207417,
                                    0.0013508326896291565,
                                    0.10499999999999998,
                                ],
                                [
                                    0.09571574942066628,
                                    0.8042842505793337,
                                    0.010635083268962918,
                                    0.08936491673103707,
                                ],
                                [
                                    0.0013508326896291571,
                                    0.10500000000000004,
                                    0.011350832689629163,
                                    0.8822983346207417,
                                ],
                                [
                                    0.0013508326896291571,
                                    0.011350832689629163,
                                    0.10500000000000004,
                                    0.8822983346207417,
                                ],
                                [
                                    0.18128834895719925,
                                    0.02014314988413325,
                                    0.7187116510428008,
                                    0.07985685011586674,
                                ],
                                [
                                    0.18128834895719925,
                                    0.7187116510428008,
                                    0.02014314988413325,
                                    0.07985685011586674,
                                ],
                                [
                                    0.09128834895719927,
                                    0.01014314988413325,
                                    0.8087116510428007,
                                    0.08985685011586673,
                                ],
                                [
                                    0.15858668357794092,
                                    0.6287116510428008,
                                    0.04284481526339155,
                                    0.1698568501158667,
                                ],
                                [
                                    0.15858668357794092,
                                    0.04284481526339155,
                                    0.6287116510428008,
                                    0.1698568501158667,
                                ],
                                [
                                    0.09128834895719927,
                                    0.8087116510428007,
                                    0.01014314988413325,
                                    0.08985685011586673,
                                ],
                                [
                                    0.07985685011586678,
                                    0.02157464872546573,
                                    0.707441484504875,
                                    0.19112701665379253,
                                ],
                                [
                                    0.07985685011586678,
                                    0.707441484504875,
                                    0.02157464872546573,
                                    0.19112701665379253,
                                ],
                                [
                                    0.4778175416344814,
                                    0.02853329105514769,
                                    0.46583162567588937,
                                    0.027817541634481455,
                                ],
                                [
                                    0.4778175416344814,
                                    0.46583162567588937,
                                    0.02853329105514769,
                                    0.027817541634481455,
                                ],
                                [
                                    0.05916837432411056,
                                    0.003533291055147694,
                                    0.8844807929862603,
                                    0.052817541634481456,
                                ],
                                [
                                    0.22464212528966687,
                                    0.21900704202070398,
                                    0.28170870739996223,
                                    0.27464212528966686,
                                ],
                                [
                                    0.22464212528966687,
                                    0.28170870739996223,
                                    0.21900704202070398,
                                    0.27464212528966686,
                                ],
                                [
                                    0.05916837432411056,
                                    0.8844807929862603,
                                    0.003533291055147694,
                                    0.052817541634481456,
                                ],
                                [
                                    0.027817541634481434,
                                    0.03488412374477682,
                                    0.41583162567588944,
                                    0.5214667089448524,
                                ],
                                [
                                    0.027817541634481434,
                                    0.41583162567588944,
                                    0.03488412374477682,
                                    0.5214667089448524,
                                ],
                                [
                                    0.800965684350386,
                                    0.010304482187539894,
                                    0.18633265027035573,
                                    0.002397183191718413,
                                ],
                                [
                                    0.800965684350386,
                                    0.18633265027035573,
                                    0.010304482187539894,
                                    0.002397183191718413,
                                ],
                                [
                                    0.023667349729644207,
                                    0.00030448218753989666,
                                    0.9636309848910974,
                                    0.012397183191718411,
                                ],
                                [
                                    0.08112701665379257,
                                    0.01887298334620741,
                                    0.7301431498841333,
                                    0.16985685011586674,
                                ],
                                [
                                    0.08112701665379257,
                                    0.7301431498841333,
                                    0.01887298334620741,
                                    0.16985685011586674,
                                ],
                                [
                                    0.023667349729644207,
                                    0.9636309848910974,
                                    0.00030448218753989666,
                                    0.012397183191718411,
                                ],
                                [
                                    0.00239718319171841,
                                    0.021574648725465696,
                                    0.09760281680828156,
                                    0.8784253512745344,
                                ],
                                [
                                    0.00239718319171841,
                                    0.09760281680828156,
                                    0.021574648725465696,
                                    0.8784253512745344,
                                ],
                                [
                                    0.1120665821102954,
                                    0.0893649167310371,
                                    0.44428425057933374,
                                    0.35428425057933377,
                                ],
                                [
                                    0.1120665821102954,
                                    0.44428425057933374,
                                    0.0893649167310371,
                                    0.35428425057933377,
                                ],
                                [
                                    0.0564314988413325,
                                    0.04500000000000001,
                                    0.4999193338482967,
                                    0.3986491673103708,
                                ],
                                [
                                    0.0893649167310371,
                                    0.35428425057933377,
                                    0.1120665821102954,
                                    0.44428425057933374,
                                ],
                                [
                                    0.0893649167310371,
                                    0.1120665821102954,
                                    0.35428425057933377,
                                    0.44428425057933374,
                                ],
                                [
                                    0.0564314988413325,
                                    0.4999193338482967,
                                    0.04500000000000001,
                                    0.3986491673103708,
                                ],
                                [
                                    0.04500000000000001,
                                    0.0564314988413325,
                                    0.3986491673103708,
                                    0.4999193338482967,
                                ],
                                [
                                    0.04500000000000001,
                                    0.3986491673103708,
                                    0.0564314988413325,
                                    0.4999193338482967,
                                ],
                                [
                                    0.37976312451722183,
                                    0.12658770817240728,
                                    0.3702368754827781,
                                    0.12341229182759271,
                                ],
                                [
                                    0.37976312451722183,
                                    0.3702368754827781,
                                    0.12658770817240728,
                                    0.12341229182759271,
                                ],
                                [
                                    0.04702624903444369,
                                    0.015675416344814563,
                                    0.7029737509655563,
                                    0.23432458365518544,
                                ],
                                [
                                    0.12658770817240728,
                                    0.12341229182759271,
                                    0.37976312451722183,
                                    0.3702368754827781,
                                ],
                                [
                                    0.12658770817240728,
                                    0.37976312451722183,
                                    0.12341229182759271,
                                    0.3702368754827781,
                                ],
                                [
                                    0.04702624903444369,
                                    0.7029737509655563,
                                    0.015675416344814563,
                                    0.23432458365518544,
                                ],
                                [
                                    0.015675416344814563,
                                    0.04702624903444369,
                                    0.23432458365518544,
                                    0.7029737509655563,
                                ],
                                [
                                    0.015675416344814563,
                                    0.23432458365518544,
                                    0.04702624903444369,
                                    0.7029737509655563,
                                ],
                                [
                                    0.7655544171172596,
                                    0.04571574942066624,
                                    0.17809475019311122,
                                    0.010635083268962913,
                                ],
                                [
                                    0.7655544171172596,
                                    0.17809475019311122,
                                    0.04571574942066624,
                                    0.010635083268962913,
                                ],
                                [
                                    0.022620999227554953,
                                    0.0013508326896291534,
                                    0.9210281680828158,
                                    0.05499999999999999,
                                ],
                                [
                                    0.04571574942066624,
                                    0.010635083268962913,
                                    0.7655544171172596,
                                    0.17809475019311122,
                                ],
                                [
                                    0.04571574942066624,
                                    0.7655544171172596,
                                    0.010635083268962913,
                                    0.17809475019311122,
                                ],
                                [
                                    0.022620999227554953,
                                    0.9210281680828158,
                                    0.0013508326896291534,
                                    0.05499999999999999,
                                ],
                                [
                                    0.0013508326896291534,
                                    0.022620999227554953,
                                    0.05499999999999999,
                                    0.9210281680828158,
                                ],
                                [
                                    0.0013508326896291534,
                                    0.05499999999999999,
                                    0.022620999227554953,
                                    0.9210281680828158,
                                ],
                                [
                                    0.04284481526339155,
                                    0.15858668357794092,
                                    0.1698568501158667,
                                    0.6287116510428008,
                                ],
                                [
                                    0.04284481526339155,
                                    0.1698568501158667,
                                    0.15858668357794092,
                                    0.6287116510428008,
                                ],
                                [
                                    0.02157464872546573,
                                    0.07985685011586678,
                                    0.19112701665379253,
                                    0.707441484504875,
                                ],
                                [
                                    0.020143149884133245,
                                    0.07985685011586674,
                                    0.18128834895719925,
                                    0.7187116510428008,
                                ],
                                [
                                    0.020143149884133245,
                                    0.18128834895719925,
                                    0.07985685011586674,
                                    0.7187116510428008,
                                ],
                                [
                                    0.02157464872546573,
                                    0.19112701665379253,
                                    0.07985685011586678,
                                    0.707441484504875,
                                ],
                                [
                                    0.01014314988413325,
                                    0.09128834895719927,
                                    0.08985685011586673,
                                    0.8087116510428007,
                                ],
                                [
                                    0.01014314988413325,
                                    0.08985685011586673,
                                    0.09128834895719927,
                                    0.8087116510428007,
                                ],
                                [
                                    0.28170870739996223,
                                    0.22464212528966687,
                                    0.27464212528966686,
                                    0.21900704202070398,
                                ],
                                [
                                    0.28170870739996223,
                                    0.27464212528966686,
                                    0.22464212528966687,
                                    0.21900704202070398,
                                ],
                                [
                                    0.03488412374477682,
                                    0.027817541634481434,
                                    0.5214667089448524,
                                    0.41583162567588944,
                                ],
                                [
                                    0.02853329105514769,
                                    0.027817541634481455,
                                    0.4778175416344814,
                                    0.46583162567588937,
                                ],
                                [
                                    0.02853329105514769,
                                    0.4778175416344814,
                                    0.027817541634481455,
                                    0.46583162567588937,
                                ],
                                [
                                    0.03488412374477682,
                                    0.5214667089448524,
                                    0.027817541634481434,
                                    0.41583162567588944,
                                ],
                                [
                                    0.003533291055147694,
                                    0.05916837432411056,
                                    0.052817541634481456,
                                    0.8844807929862603,
                                ],
                                [
                                    0.003533291055147694,
                                    0.052817541634481456,
                                    0.05916837432411056,
                                    0.8844807929862603,
                                ],
                                [
                                    0.7301431498841333,
                                    0.08112701665379257,
                                    0.16985685011586674,
                                    0.018872983346207413,
                                ],
                                [
                                    0.7301431498841333,
                                    0.16985685011586674,
                                    0.08112701665379257,
                                    0.018872983346207413,
                                ],
                                [
                                    0.021574648725465696,
                                    0.0023971831917184105,
                                    0.8784253512745344,
                                    0.09760281680828158,
                                ],
                                [
                                    0.010304482187539904,
                                    0.0023971831917184157,
                                    0.800965684350386,
                                    0.18633265027035573,
                                ],
                                [
                                    0.010304482187539904,
                                    0.800965684350386,
                                    0.0023971831917184157,
                                    0.18633265027035573,
                                ],
                                [
                                    0.021574648725465696,
                                    0.8784253512745344,
                                    0.0023971831917184105,
                                    0.09760281680828158,
                                ],
                                [
                                    0.00030448218753989693,
                                    0.023667349729644207,
                                    0.012397183191718423,
                                    0.9636309848910974,
                                ],
                                [
                                    0.00030448218753989693,
                                    0.012397183191718423,
                                    0.023667349729644207,
                                    0.9636309848910974,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.6896955178124602,
                                    0.18633265027035573,
                                    0.09760281680828158,
                                    0.02636901510890255,
                                ],
                                [
                                    0.6896955178124602,
                                    0.09760281680828158,
                                    0.18633265027035573,
                                    0.02636901510890255,
                                ],
                                [
                                    0.6996955178124601,
                                    0.18903431564961404,
                                    0.08760281680828158,
                                    0.023667349729644238,
                                ],
                                [
                                    0.7884253512745344,
                                    0.11157464872546571,
                                    0.08760281680828158,
                                    0.012397183191718411,
                                ],
                                [
                                    0.7884253512745344,
                                    0.08760281680828158,
                                    0.11157464872546571,
                                    0.012397183191718411,
                                ],
                                [
                                    0.6996955178124601,
                                    0.08760281680828158,
                                    0.18903431564961404,
                                    0.023667349729644238,
                                ],
                                [
                                    0.7998568501158667,
                                    0.0888729833462074,
                                    0.10014314988413324,
                                    0.01112701665379258,
                                ],
                                [
                                    0.7998568501158667,
                                    0.10014314988413324,
                                    0.0888729833462074,
                                    0.01112701665379258,
                                ],
                                [
                                    0.3714667089448523,
                                    0.46583162567588937,
                                    0.07218245836551854,
                                    0.09051920701373975,
                                ],
                                [
                                    0.3714667089448523,
                                    0.07218245836551854,
                                    0.46583162567588937,
                                    0.09051920701373975,
                                ],
                                [
                                    0.3964667089448523,
                                    0.4971824583655185,
                                    0.047182458365518536,
                                    0.0591683743241106,
                                ],
                                [
                                    0.7901158762552232,
                                    0.15353329105514768,
                                    0.047182458365518536,
                                    0.009168374324110612,
                                ],
                                [
                                    0.7901158762552232,
                                    0.047182458365518536,
                                    0.15353329105514768,
                                    0.009168374324110612,
                                ],
                                [
                                    0.3964667089448523,
                                    0.047182458365518536,
                                    0.4971824583655185,
                                    0.0591683743241106,
                                ],
                                [
                                    0.8432912926000377,
                                    0.05035787471033311,
                                    0.1003578747103331,
                                    0.005992957979296034,
                                ],
                                [
                                    0.8432912926000377,
                                    0.1003578747103331,
                                    0.05035787471033311,
                                    0.005992957979296034,
                                ],
                                [
                                    0.07985685011586674,
                                    0.7187116510428008,
                                    0.02014314988413324,
                                    0.18128834895719922,
                                ],
                                [
                                    0.07985685011586674,
                                    0.02014314988413324,
                                    0.7187116510428008,
                                    0.18128834895719922,
                                ],
                                [
                                    0.08985685011586673,
                                    0.8087116510428007,
                                    0.010143149884133245,
                                    0.09128834895719923,
                                ],
                                [
                                    0.7884253512745343,
                                    0.1988729833462074,
                                    0.010143149884133245,
                                    0.0025585154951250624,
                                ],
                                [
                                    0.7884253512745343,
                                    0.010143149884133245,
                                    0.1988729833462074,
                                    0.0025585154951250624,
                                ],
                                [
                                    0.08985685011586673,
                                    0.010143149884133245,
                                    0.8087116510428007,
                                    0.09128834895719923,
                                ],
                                [
                                    0.8871551847366084,
                                    0.011413316422059075,
                                    0.10014314988413324,
                                    0.001288348957199232,
                                ],
                                [
                                    0.8871551847366084,
                                    0.10014314988413324,
                                    0.011413316422059075,
                                    0.001288348957199232,
                                ],
                                [
                                    0.38864916731037086,
                                    0.48737900077244506,
                                    0.05499999999999999,
                                    0.06897183191718413,
                                ],
                                [
                                    0.38864916731037086,
                                    0.05499999999999999,
                                    0.48737900077244506,
                                    0.06897183191718413,
                                ],
                                [
                                    0.39428425057933375,
                                    0.4944455828827404,
                                    0.04936491673103708,
                                    0.06190524980688874,
                                ],
                                [
                                    0.48737900077244506,
                                    0.06897183191718413,
                                    0.38864916731037086,
                                    0.05499999999999999,
                                ],
                                [
                                    0.48737900077244506,
                                    0.38864916731037086,
                                    0.06897183191718413,
                                    0.05499999999999999,
                                ],
                                [
                                    0.39428425057933375,
                                    0.04936491673103708,
                                    0.4944455828827404,
                                    0.06190524980688874,
                                ],
                                [
                                    0.4944455828827404,
                                    0.39428425057933375,
                                    0.06190524980688874,
                                    0.04936491673103708,
                                ],
                                [
                                    0.4944455828827404,
                                    0.06190524980688874,
                                    0.39428425057933375,
                                    0.04936491673103708,
                                ],
                                [
                                    0.20932458365518541,
                                    0.6279737509655563,
                                    0.04067541634481457,
                                    0.12202624903444372,
                                ],
                                [
                                    0.20932458365518541,
                                    0.04067541634481457,
                                    0.6279737509655563,
                                    0.12202624903444372,
                                ],
                                [
                                    0.2234122918275927,
                                    0.6702368754827781,
                                    0.026587708172407284,
                                    0.07976312451722185,
                                ],
                                [
                                    0.6279737509655563,
                                    0.12202624903444372,
                                    0.20932458365518541,
                                    0.04067541634481457,
                                ],
                                [
                                    0.6279737509655563,
                                    0.20932458365518541,
                                    0.12202624903444372,
                                    0.04067541634481457,
                                ],
                                [
                                    0.2234122918275927,
                                    0.026587708172407284,
                                    0.6702368754827781,
                                    0.07976312451722185,
                                ],
                                [
                                    0.6702368754827781,
                                    0.2234122918275927,
                                    0.07976312451722185,
                                    0.026587708172407284,
                                ],
                                [
                                    0.6702368754827781,
                                    0.07976312451722185,
                                    0.2234122918275927,
                                    0.026587708172407284,
                                ],
                                [
                                    0.04499999999999999,
                                    0.7535685011586675,
                                    0.011350832689629154,
                                    0.1900806661517033,
                                ],
                                [
                                    0.04499999999999999,
                                    0.011350832689629154,
                                    0.7535685011586675,
                                    0.1900806661517033,
                                ],
                                [
                                    0.050635083268962905,
                                    0.8479334178897046,
                                    0.005715749420666239,
                                    0.09571574942066623,
                                ],
                                [
                                    0.7535685011586675,
                                    0.1900806661517033,
                                    0.04499999999999999,
                                    0.011350832689629154,
                                ],
                                [
                                    0.7535685011586675,
                                    0.04499999999999999,
                                    0.1900806661517033,
                                    0.011350832689629154,
                                ],
                                [
                                    0.050635083268962905,
                                    0.005715749420666239,
                                    0.8479334178897046,
                                    0.09571574942066623,
                                ],
                                [
                                    0.8479334178897046,
                                    0.050635083268962905,
                                    0.09571574942066623,
                                    0.005715749420666239,
                                ],
                                [
                                    0.8479334178897046,
                                    0.09571574942066623,
                                    0.050635083268962905,
                                    0.005715749420666239,
                                ],
                                [
                                    0.08760281680828157,
                                    0.7884253512745344,
                                    0.01239718319171841,
                                    0.11157464872546571,
                                ],
                                [
                                    0.08760281680828157,
                                    0.01239718319171841,
                                    0.7884253512745344,
                                    0.11157464872546571,
                                ],
                                [
                                    0.0888729833462074,
                                    0.7998568501158667,
                                    0.011127016653792579,
                                    0.10014314988413324,
                                ],
                                [
                                    0.18633265027035573,
                                    0.02636901510890255,
                                    0.6896955178124602,
                                    0.09760281680828158,
                                ],
                                [
                                    0.18633265027035573,
                                    0.6896955178124602,
                                    0.02636901510890255,
                                    0.09760281680828158,
                                ],
                                [
                                    0.0888729833462074,
                                    0.011127016653792579,
                                    0.7998568501158667,
                                    0.10014314988413324,
                                ],
                                [
                                    0.18903431564961404,
                                    0.6996955178124601,
                                    0.023667349729644238,
                                    0.08760281680828158,
                                ],
                                [
                                    0.18903431564961404,
                                    0.023667349729644238,
                                    0.6996955178124601,
                                    0.08760281680828158,
                                ],
                                [
                                    0.047182458365518536,
                                    0.7901158762552232,
                                    0.009168374324110612,
                                    0.15353329105514768,
                                ],
                                [
                                    0.047182458365518536,
                                    0.009168374324110612,
                                    0.7901158762552232,
                                    0.15353329105514768,
                                ],
                                [
                                    0.05035787471033311,
                                    0.8432912926000377,
                                    0.005992957979296034,
                                    0.1003578747103331,
                                ],
                                [
                                    0.46583162567588937,
                                    0.09051920701373975,
                                    0.3714667089448523,
                                    0.07218245836551854,
                                ],
                                [
                                    0.46583162567588937,
                                    0.3714667089448523,
                                    0.09051920701373975,
                                    0.07218245836551854,
                                ],
                                [
                                    0.05035787471033311,
                                    0.005992957979296034,
                                    0.8432912926000377,
                                    0.1003578747103331,
                                ],
                                [
                                    0.4971824583655185,
                                    0.3964667089448523,
                                    0.0591683743241106,
                                    0.047182458365518536,
                                ],
                                [
                                    0.4971824583655185,
                                    0.0591683743241106,
                                    0.3964667089448523,
                                    0.047182458365518536,
                                ],
                                [
                                    0.010143149884133255,
                                    0.7884253512745343,
                                    0.002558515495125065,
                                    0.1988729833462074,
                                ],
                                [
                                    0.010143149884133255,
                                    0.002558515495125065,
                                    0.7884253512745343,
                                    0.1988729833462074,
                                ],
                                [
                                    0.011413316422059087,
                                    0.8871551847366084,
                                    0.001288348957199233,
                                    0.10014314988413324,
                                ],
                                [
                                    0.7187116510428008,
                                    0.18128834895719922,
                                    0.07985685011586674,
                                    0.020143149884133245,
                                ],
                                [
                                    0.7187116510428008,
                                    0.07985685011586674,
                                    0.18128834895719922,
                                    0.020143149884133245,
                                ],
                                [
                                    0.011413316422059087,
                                    0.001288348957199233,
                                    0.8871551847366084,
                                    0.10014314988413324,
                                ],
                                [
                                    0.8087116510428007,
                                    0.08985685011586673,
                                    0.09128834895719923,
                                    0.010143149884133246,
                                ],
                                [
                                    0.8087116510428007,
                                    0.09128834895719923,
                                    0.08985685011586673,
                                    0.010143149884133246,
                                ],
                                [
                                    0.3886491673103709,
                                    0.105,
                                    0.3986491673103708,
                                    0.10770166537925828,
                                ],
                                [
                                    0.3886491673103709,
                                    0.3986491673103708,
                                    0.105,
                                    0.10770166537925828,
                                ],
                                [
                                    0.3986491673103708,
                                    0.10770166537925828,
                                    0.38864916731037086,
                                    0.10499999999999998,
                                ],
                                [
                                    0.4442842505793338,
                                    0.4557157494206662,
                                    0.04936491673103709,
                                    0.050635083268962905,
                                ],
                                [
                                    0.4442842505793338,
                                    0.04936491673103709,
                                    0.4557157494206662,
                                    0.050635083268962905,
                                ],
                                [
                                    0.3986491673103708,
                                    0.38864916731037086,
                                    0.10770166537925828,
                                    0.10499999999999998,
                                ],
                                [
                                    0.4557157494206662,
                                    0.050635083268962905,
                                    0.44428425057933374,
                                    0.04936491673103708,
                                ],
                                [
                                    0.4557157494206662,
                                    0.44428425057933374,
                                    0.050635083268962905,
                                    0.04936491673103708,
                                ],
                                [
                                    0.20932458365518541,
                                    0.2625,
                                    0.23432458365518544,
                                    0.29385083268962914,
                                ],
                                [
                                    0.20932458365518541,
                                    0.23432458365518544,
                                    0.2625,
                                    0.29385083268962914,
                                ],
                                [
                                    0.23432458365518544,
                                    0.29385083268962914,
                                    0.20932458365518541,
                                    0.2625,
                                ],
                                [
                                    0.4452368754827781,
                                    0.4984122918275927,
                                    0.026587708172407284,
                                    0.029763124517221864,
                                ],
                                [
                                    0.4452368754827781,
                                    0.026587708172407284,
                                    0.4984122918275927,
                                    0.029763124517221864,
                                ],
                                [
                                    0.23432458365518544,
                                    0.20932458365518541,
                                    0.29385083268962914,
                                    0.2625,
                                ],
                                [
                                    0.4984122918275927,
                                    0.029763124517221864,
                                    0.4452368754827781,
                                    0.026587708172407284,
                                ],
                                [
                                    0.4984122918275927,
                                    0.4452368754827781,
                                    0.029763124517221864,
                                    0.026587708172407284,
                                ],
                                [
                                    0.044999999999999984,
                                    0.40499999999999997,
                                    0.05499999999999999,
                                    0.49500000000000005,
                                ],
                                [
                                    0.044999999999999984,
                                    0.05499999999999999,
                                    0.40499999999999997,
                                    0.49500000000000005,
                                ],
                                [
                                    0.05499999999999999,
                                    0.49500000000000005,
                                    0.04499999999999999,
                                    0.405,
                                ],
                                [
                                    0.44428425057933374,
                                    0.5430140840414079,
                                    0.005715749420666238,
                                    0.00698591595859207,
                                ],
                                [
                                    0.44428425057933374,
                                    0.005715749420666238,
                                    0.5430140840414079,
                                    0.00698591595859207,
                                ],
                                [
                                    0.05499999999999999,
                                    0.04499999999999999,
                                    0.49500000000000005,
                                    0.405,
                                ],
                                [
                                    0.5430140840414079,
                                    0.00698591595859207,
                                    0.44428425057933374,
                                    0.005715749420666239,
                                ],
                                [
                                    0.5430140840414079,
                                    0.44428425057933374,
                                    0.00698591595859207,
                                    0.005715749420666239,
                                ],
                                [
                                    0.21900704202070398,
                                    0.2746421252896669,
                                    0.22464212528966687,
                                    0.28170870739996223,
                                ],
                                [
                                    0.21900704202070398,
                                    0.22464212528966687,
                                    0.2746421252896669,
                                    0.28170870739996223,
                                ],
                                [
                                    0.22464212528966687,
                                    0.28170870739996223,
                                    0.21900704202070398,
                                    0.27464212528966686,
                                ],
                                [
                                    0.2746421252896669,
                                    0.28170870739996223,
                                    0.21900704202070398,
                                    0.22464212528966687,
                                ],
                                [
                                    0.2746421252896669,
                                    0.21900704202070398,
                                    0.28170870739996223,
                                    0.22464212528966687,
                                ],
                                [
                                    0.22464212528966687,
                                    0.21900704202070398,
                                    0.28170870739996223,
                                    0.27464212528966686,
                                ],
                                [
                                    0.28170870739996223,
                                    0.22464212528966687,
                                    0.27464212528966686,
                                    0.21900704202070398,
                                ],
                                [
                                    0.28170870739996223,
                                    0.27464212528966686,
                                    0.22464212528966687,
                                    0.21900704202070398,
                                ],
                                [
                                    0.11795614591379636,
                                    0.3538684377413891,
                                    0.13204385408620364,
                                    0.3961315622586109,
                                ],
                                [
                                    0.11795614591379636,
                                    0.13204385408620364,
                                    0.3538684377413891,
                                    0.3961315622586109,
                                ],
                                [
                                    0.13204385408620364,
                                    0.3961315622586109,
                                    0.11795614591379636,
                                    0.3538684377413891,
                                ],
                                [
                                    0.3538684377413891,
                                    0.3961315622586109,
                                    0.11795614591379636,
                                    0.13204385408620364,
                                ],
                                [
                                    0.3538684377413891,
                                    0.11795614591379636,
                                    0.3961315622586109,
                                    0.13204385408620364,
                                ],
                                [
                                    0.13204385408620364,
                                    0.11795614591379636,
                                    0.3961315622586109,
                                    0.3538684377413891,
                                ],
                                [
                                    0.3961315622586109,
                                    0.13204385408620364,
                                    0.3538684377413891,
                                    0.11795614591379636,
                                ],
                                [
                                    0.3961315622586109,
                                    0.3538684377413891,
                                    0.13204385408620364,
                                    0.11795614591379636,
                                ],
                                [
                                    0.025357874710333114,
                                    0.4246421252896668,
                                    0.030992957979296035,
                                    0.519007042020704,
                                ],
                                [
                                    0.025357874710333114,
                                    0.030992957979296035,
                                    0.4246421252896668,
                                    0.519007042020704,
                                ],
                                [
                                    0.030992957979296035,
                                    0.519007042020704,
                                    0.025357874710333118,
                                    0.4246421252896669,
                                ],
                                [
                                    0.4246421252896668,
                                    0.519007042020704,
                                    0.025357874710333114,
                                    0.030992957979296035,
                                ],
                                [
                                    0.4246421252896668,
                                    0.025357874710333114,
                                    0.519007042020704,
                                    0.030992957979296035,
                                ],
                                [
                                    0.030992957979296035,
                                    0.025357874710333118,
                                    0.519007042020704,
                                    0.4246421252896669,
                                ],
                                [
                                    0.519007042020704,
                                    0.030992957979296035,
                                    0.4246421252896669,
                                    0.025357874710333118,
                                ],
                                [
                                    0.519007042020704,
                                    0.4246421252896669,
                                    0.030992957979296035,
                                    0.025357874710333118,
                                ],
                                [
                                    0.04936491673103708,
                                    0.4442842505793338,
                                    0.0506350832689629,
                                    0.4557157494206662,
                                ],
                                [
                                    0.04936491673103708,
                                    0.0506350832689629,
                                    0.4442842505793338,
                                    0.4557157494206662,
                                ],
                                [
                                    0.0506350832689629,
                                    0.4557157494206662,
                                    0.04936491673103707,
                                    0.44428425057933374,
                                ],
                                [
                                    0.105,
                                    0.10770166537925828,
                                    0.3886491673103709,
                                    0.3986491673103708,
                                ],
                                [
                                    0.105,
                                    0.3886491673103709,
                                    0.10770166537925828,
                                    0.3986491673103708,
                                ],
                                [
                                    0.0506350832689629,
                                    0.04936491673103707,
                                    0.4557157494206662,
                                    0.44428425057933374,
                                ],
                                [
                                    0.10770166537925828,
                                    0.3986491673103708,
                                    0.10499999999999998,
                                    0.38864916731037086,
                                ],
                                [
                                    0.10770166537925828,
                                    0.10499999999999998,
                                    0.3986491673103708,
                                    0.38864916731037086,
                                ],
                                [
                                    0.026587708172407284,
                                    0.4452368754827781,
                                    0.029763124517221864,
                                    0.4984122918275927,
                                ],
                                [
                                    0.026587708172407284,
                                    0.029763124517221864,
                                    0.4452368754827781,
                                    0.4984122918275927,
                                ],
                                [
                                    0.029763124517221864,
                                    0.4984122918275927,
                                    0.026587708172407284,
                                    0.4452368754827781,
                                ],
                                [
                                    0.2625,
                                    0.29385083268962914,
                                    0.20932458365518541,
                                    0.23432458365518544,
                                ],
                                [
                                    0.2625,
                                    0.20932458365518541,
                                    0.29385083268962914,
                                    0.23432458365518544,
                                ],
                                [
                                    0.029763124517221864,
                                    0.026587708172407284,
                                    0.4984122918275927,
                                    0.4452368754827781,
                                ],
                                [
                                    0.29385083268962914,
                                    0.23432458365518544,
                                    0.2625,
                                    0.20932458365518541,
                                ],
                                [
                                    0.29385083268962914,
                                    0.2625,
                                    0.23432458365518544,
                                    0.20932458365518541,
                                ],
                                [
                                    0.005715749420666243,
                                    0.44428425057933374,
                                    0.006985915958592077,
                                    0.5430140840414079,
                                ],
                                [
                                    0.005715749420666243,
                                    0.006985915958592077,
                                    0.44428425057933374,
                                    0.5430140840414079,
                                ],
                                [
                                    0.006985915958592077,
                                    0.5430140840414079,
                                    0.005715749420666244,
                                    0.44428425057933374,
                                ],
                                [
                                    0.40499999999999997,
                                    0.49500000000000005,
                                    0.04499999999999999,
                                    0.055,
                                ],
                                [
                                    0.40499999999999997,
                                    0.04499999999999999,
                                    0.49500000000000005,
                                    0.055,
                                ],
                                [
                                    0.006985915958592077,
                                    0.005715749420666244,
                                    0.5430140840414079,
                                    0.44428425057933374,
                                ],
                                [0.49500000000000005, 0.055, 0.405, 0.045],
                                [0.49500000000000005, 0.405, 0.055, 0.045],
                                [
                                    0.08760281680828154,
                                    0.023667349729644228,
                                    0.6996955178124602,
                                    0.18903431564961404,
                                ],
                                [
                                    0.08760281680828154,
                                    0.6996955178124602,
                                    0.023667349729644228,
                                    0.18903431564961404,
                                ],
                                [
                                    0.09760281680828155,
                                    0.02636901510890254,
                                    0.6896955178124602,
                                    0.18633265027035573,
                                ],
                                [
                                    0.10014314988413318,
                                    0.7998568501158668,
                                    0.011127016653792576,
                                    0.08887298334620741,
                                ],
                                [
                                    0.10014314988413318,
                                    0.011127016653792576,
                                    0.7998568501158668,
                                    0.08887298334620741,
                                ],
                                [
                                    0.09760281680828155,
                                    0.6896955178124602,
                                    0.02636901510890254,
                                    0.18633265027035573,
                                ],
                                [
                                    0.11157464872546567,
                                    0.012397183191718408,
                                    0.7884253512745344,
                                    0.08760281680828158,
                                ],
                                [
                                    0.11157464872546567,
                                    0.7884253512745344,
                                    0.012397183191718408,
                                    0.08760281680828158,
                                ],
                                [
                                    0.047182458365518556,
                                    0.05916837432411064,
                                    0.3964667089448523,
                                    0.4971824583655185,
                                ],
                                [
                                    0.047182458365518556,
                                    0.3964667089448523,
                                    0.05916837432411064,
                                    0.4971824583655185,
                                ],
                                [
                                    0.07218245836551855,
                                    0.09051920701373979,
                                    0.3714667089448523,
                                    0.46583162567588937,
                                ],
                                [
                                    0.10035787471033315,
                                    0.8432912926000377,
                                    0.005992957979296037,
                                    0.05035787471033311,
                                ],
                                [
                                    0.10035787471033315,
                                    0.005992957979296037,
                                    0.8432912926000377,
                                    0.05035787471033311,
                                ],
                                [
                                    0.07218245836551855,
                                    0.3714667089448523,
                                    0.09051920701373979,
                                    0.46583162567588937,
                                ],
                                [
                                    0.15353329105514774,
                                    0.009168374324110613,
                                    0.7901158762552232,
                                    0.047182458365518536,
                                ],
                                [
                                    0.15353329105514774,
                                    0.7901158762552232,
                                    0.009168374324110613,
                                    0.047182458365518536,
                                ],
                                [
                                    0.01014314988413325,
                                    0.09128834895719927,
                                    0.08985685011586673,
                                    0.8087116510428007,
                                ],
                                [
                                    0.01014314988413325,
                                    0.08985685011586673,
                                    0.09128834895719927,
                                    0.8087116510428007,
                                ],
                                [
                                    0.020143149884133245,
                                    0.18128834895719925,
                                    0.07985685011586674,
                                    0.7187116510428008,
                                ],
                                [
                                    0.10014314988413328,
                                    0.8871551847366084,
                                    0.0012883489571992323,
                                    0.011413316422059075,
                                ],
                                [
                                    0.10014314988413328,
                                    0.0012883489571992323,
                                    0.8871551847366084,
                                    0.011413316422059075,
                                ],
                                [
                                    0.020143149884133245,
                                    0.07985685011586674,
                                    0.18128834895719925,
                                    0.7187116510428008,
                                ],
                                [
                                    0.19887298334620743,
                                    0.002558515495125063,
                                    0.7884253512745343,
                                    0.010143149884133245,
                                ],
                                [
                                    0.19887298334620743,
                                    0.7884253512745343,
                                    0.002558515495125063,
                                    0.010143149884133245,
                                ],
                                [
                                    0.04936491673103705,
                                    0.06190524980688871,
                                    0.3942842505793338,
                                    0.49444558288274043,
                                ],
                                [
                                    0.04936491673103705,
                                    0.3942842505793338,
                                    0.06190524980688871,
                                    0.49444558288274043,
                                ],
                                [
                                    0.05499999999999997,
                                    0.0689718319171841,
                                    0.38864916731037086,
                                    0.48737900077244506,
                                ],
                                [
                                    0.06190524980688871,
                                    0.49444558288274043,
                                    0.04936491673103705,
                                    0.3942842505793338,
                                ],
                                [
                                    0.06190524980688871,
                                    0.04936491673103705,
                                    0.49444558288274043,
                                    0.3942842505793338,
                                ],
                                [
                                    0.05499999999999997,
                                    0.38864916731037086,
                                    0.0689718319171841,
                                    0.48737900077244506,
                                ],
                                [
                                    0.0689718319171841,
                                    0.05499999999999997,
                                    0.48737900077244506,
                                    0.38864916731037086,
                                ],
                                [
                                    0.0689718319171841,
                                    0.48737900077244506,
                                    0.05499999999999997,
                                    0.38864916731037086,
                                ],
                                [
                                    0.0265877081724073,
                                    0.0797631245172219,
                                    0.2234122918275927,
                                    0.6702368754827781,
                                ],
                                [
                                    0.0265877081724073,
                                    0.2234122918275927,
                                    0.0797631245172219,
                                    0.6702368754827781,
                                ],
                                [
                                    0.040675416344814586,
                                    0.12202624903444376,
                                    0.20932458365518541,
                                    0.6279737509655563,
                                ],
                                [
                                    0.0797631245172219,
                                    0.6702368754827781,
                                    0.0265877081724073,
                                    0.2234122918275927,
                                ],
                                [
                                    0.0797631245172219,
                                    0.0265877081724073,
                                    0.6702368754827781,
                                    0.2234122918275927,
                                ],
                                [
                                    0.040675416344814586,
                                    0.20932458365518541,
                                    0.12202624903444376,
                                    0.6279737509655563,
                                ],
                                [
                                    0.12202624903444376,
                                    0.040675416344814586,
                                    0.6279737509655563,
                                    0.20932458365518541,
                                ],
                                [
                                    0.12202624903444376,
                                    0.6279737509655563,
                                    0.040675416344814586,
                                    0.20932458365518541,
                                ],
                                [
                                    0.005715749420666241,
                                    0.09571574942066627,
                                    0.050635083268962905,
                                    0.8479334178897046,
                                ],
                                [
                                    0.005715749420666241,
                                    0.050635083268962905,
                                    0.09571574942066627,
                                    0.8479334178897046,
                                ],
                                [
                                    0.011350832689629154,
                                    0.19008066615170333,
                                    0.04499999999999999,
                                    0.7535685011586675,
                                ],
                                [
                                    0.09571574942066627,
                                    0.8479334178897046,
                                    0.005715749420666241,
                                    0.050635083268962905,
                                ],
                                [
                                    0.09571574942066627,
                                    0.005715749420666241,
                                    0.8479334178897046,
                                    0.050635083268962905,
                                ],
                                [
                                    0.011350832689629154,
                                    0.04499999999999999,
                                    0.19008066615170333,
                                    0.7535685011586675,
                                ],
                                [
                                    0.19008066615170333,
                                    0.011350832689629154,
                                    0.7535685011586675,
                                    0.04499999999999999,
                                ],
                                [
                                    0.19008066615170333,
                                    0.7535685011586675,
                                    0.011350832689629154,
                                    0.04499999999999999,
                                ],
                                [
                                    0.011127016653792574,
                                    0.10014314988413318,
                                    0.0888729833462074,
                                    0.7998568501158668,
                                ],
                                [
                                    0.011127016653792574,
                                    0.0888729833462074,
                                    0.10014314988413318,
                                    0.7998568501158668,
                                ],
                                [
                                    0.012397183191718406,
                                    0.11157464872546567,
                                    0.08760281680828157,
                                    0.7884253512745344,
                                ],
                                [
                                    0.023667349729644228,
                                    0.18903431564961404,
                                    0.08760281680828154,
                                    0.6996955178124602,
                                ],
                                [
                                    0.023667349729644228,
                                    0.08760281680828154,
                                    0.18903431564961404,
                                    0.6996955178124602,
                                ],
                                [
                                    0.012397183191718406,
                                    0.08760281680828157,
                                    0.11157464872546567,
                                    0.7884253512745344,
                                ],
                                [
                                    0.02636901510890254,
                                    0.09760281680828155,
                                    0.18633265027035573,
                                    0.6896955178124602,
                                ],
                                [
                                    0.02636901510890254,
                                    0.18633265027035573,
                                    0.09760281680828155,
                                    0.6896955178124602,
                                ],
                                [
                                    0.005992957979296037,
                                    0.10035787471033315,
                                    0.05035787471033311,
                                    0.8432912926000377,
                                ],
                                [
                                    0.005992957979296037,
                                    0.05035787471033311,
                                    0.10035787471033315,
                                    0.8432912926000377,
                                ],
                                [
                                    0.009168374324110613,
                                    0.15353329105514774,
                                    0.047182458365518536,
                                    0.7901158762552232,
                                ],
                                [
                                    0.05916837432411064,
                                    0.4971824583655185,
                                    0.047182458365518556,
                                    0.3964667089448523,
                                ],
                                [
                                    0.05916837432411064,
                                    0.047182458365518556,
                                    0.4971824583655185,
                                    0.3964667089448523,
                                ],
                                [
                                    0.009168374324110613,
                                    0.047182458365518536,
                                    0.15353329105514774,
                                    0.7901158762552232,
                                ],
                                [
                                    0.09051920701373979,
                                    0.07218245836551855,
                                    0.46583162567588937,
                                    0.3714667089448523,
                                ],
                                [
                                    0.09051920701373979,
                                    0.46583162567588937,
                                    0.07218245836551855,
                                    0.3714667089448523,
                                ],
                                [
                                    0.0012883489571992336,
                                    0.10014314988413328,
                                    0.011413316422059087,
                                    0.8871551847366084,
                                ],
                                [
                                    0.0012883489571992336,
                                    0.011413316422059087,
                                    0.10014314988413328,
                                    0.8871551847366084,
                                ],
                                [
                                    0.0025585154951250654,
                                    0.19887298334620743,
                                    0.010143149884133255,
                                    0.7884253512745343,
                                ],
                                [
                                    0.09128834895719927,
                                    0.8087116510428007,
                                    0.01014314988413325,
                                    0.08985685011586673,
                                ],
                                [
                                    0.09128834895719927,
                                    0.01014314988413325,
                                    0.8087116510428007,
                                    0.08985685011586673,
                                ],
                                [
                                    0.0025585154951250654,
                                    0.010143149884133255,
                                    0.19887298334620743,
                                    0.7884253512745343,
                                ],
                                [
                                    0.18128834895719925,
                                    0.02014314988413325,
                                    0.7187116510428008,
                                    0.07985685011586674,
                                ],
                                [
                                    0.18128834895719925,
                                    0.7187116510428008,
                                    0.02014314988413325,
                                    0.07985685011586674,
                                ],
                                [
                                    0.6592035844276305,
                                    0.17809475019311122,
                                    0.12809475019311123,
                                    0.034606915186147044,
                                ],
                                [
                                    0.6592035844276305,
                                    0.12809475019311123,
                                    0.17809475019311122,
                                    0.034606915186147044,
                                ],
                                [
                                    0.7035685011586675,
                                    0.1900806661517033,
                                    0.08372983346207416,
                                    0.022620999227554978,
                                ],
                                [
                                    0.7535685011586675,
                                    0.14643149884133247,
                                    0.08372983346207416,
                                    0.016270166537925828,
                                ],
                                [
                                    0.7535685011586675,
                                    0.08372983346207416,
                                    0.14643149884133247,
                                    0.016270166537925828,
                                ],
                                [
                                    0.7035685011586675,
                                    0.08372983346207416,
                                    0.1900806661517033,
                                    0.022620999227554978,
                                ],
                                [
                                    0.8042842505793337,
                                    0.08936491673103707,
                                    0.09571574942066623,
                                    0.010635083268962913,
                                ],
                                [
                                    0.8042842505793337,
                                    0.09571574942066623,
                                    0.08936491673103707,
                                    0.010635083268962913,
                                ],
                                [
                                    0.29523687548277816,
                                    0.3702368754827781,
                                    0.14841229182759272,
                                    0.186113957206851,
                                ],
                                [
                                    0.29523687548277816,
                                    0.14841229182759272,
                                    0.3702368754827781,
                                    0.186113957206851,
                                ],
                                [
                                    0.4061491673103709,
                                    0.5093245836551854,
                                    0.0375,
                                    0.047026249034443725,
                                ],
                                [
                                    0.6279737509655563,
                                    0.31567541634481455,
                                    0.0375,
                                    0.018850832689629154,
                                ],
                                [
                                    0.6279737509655563,
                                    0.0375,
                                    0.31567541634481455,
                                    0.018850832689629154,
                                ],
                                [
                                    0.4061491673103709,
                                    0.0375,
                                    0.5093245836551854,
                                    0.047026249034443725,
                                ],
                                [
                                    0.863886042793149,
                                    0.051587708172407286,
                                    0.07976312451722185,
                                    0.004763124517221866,
                                ],
                                [
                                    0.863886042793149,
                                    0.07976312451722185,
                                    0.051587708172407286,
                                    0.004763124517221866,
                                ],
                                [
                                    0.04936491673103708,
                                    0.4442842505793338,
                                    0.0506350832689629,
                                    0.4557157494206662,
                                ],
                                [
                                    0.04936491673103708,
                                    0.0506350832689629,
                                    0.4442842505793338,
                                    0.4557157494206662,
                                ],
                                [
                                    0.09372983346207416,
                                    0.8435685011586675,
                                    0.0062701665379258295,
                                    0.05643149884133248,
                                ],
                                [
                                    0.48737900077244506,
                                    0.4999193338482966,
                                    0.00627016653792583,
                                    0.0064314988413324775,
                                ],
                                [
                                    0.48737900077244506,
                                    0.00627016653792583,
                                    0.4999193338482966,
                                    0.0064314988413324775,
                                ],
                                [
                                    0.09372983346207416,
                                    0.0062701665379258295,
                                    0.8435685011586675,
                                    0.05643149884133248,
                                ],
                                [
                                    0.925393084813853,
                                    0.011905249806888745,
                                    0.061905249806888746,
                                    0.0007964155723695645,
                                ],
                                [
                                    0.925393084813853,
                                    0.061905249806888746,
                                    0.011905249806888745,
                                    0.0007964155723695645,
                                ],
                                [
                                    0.3714667089448523,
                                    0.46583162567588937,
                                    0.07218245836551854,
                                    0.09051920701373975,
                                ],
                                [
                                    0.3714667089448523,
                                    0.07218245836551854,
                                    0.46583162567588937,
                                    0.09051920701373975,
                                ],
                                [
                                    0.3964667089448523,
                                    0.4971824583655185,
                                    0.047182458365518536,
                                    0.0591683743241106,
                                ],
                                [
                                    0.46583162567588937,
                                    0.09051920701373975,
                                    0.3714667089448523,
                                    0.07218245836551854,
                                ],
                                [
                                    0.46583162567588937,
                                    0.3714667089448523,
                                    0.09051920701373975,
                                    0.07218245836551854,
                                ],
                                [
                                    0.3964667089448523,
                                    0.047182458365518536,
                                    0.4971824583655185,
                                    0.0591683743241106,
                                ],
                                [
                                    0.4971824583655185,
                                    0.3964667089448523,
                                    0.0591683743241106,
                                    0.047182458365518536,
                                ],
                                [
                                    0.4971824583655185,
                                    0.0591683743241106,
                                    0.3964667089448523,
                                    0.047182458365518536,
                                ],
                                [
                                    0.16636843774138907,
                                    0.4991053132241672,
                                    0.08363156225861093,
                                    0.2508946867758328,
                                ],
                                [
                                    0.16636843774138907,
                                    0.08363156225861093,
                                    0.4991053132241672,
                                    0.2508946867758328,
                                ],
                                [
                                    0.22886843774138907,
                                    0.6866053132241672,
                                    0.02113156225861093,
                                    0.06339468677583279,
                                ],
                                [
                                    0.4991053132241672,
                                    0.2508946867758328,
                                    0.16636843774138907,
                                    0.08363156225861093,
                                ],
                                [
                                    0.4991053132241672,
                                    0.16636843774138907,
                                    0.2508946867758328,
                                    0.08363156225861093,
                                ],
                                [
                                    0.22886843774138907,
                                    0.02113156225861093,
                                    0.6866053132241672,
                                    0.06339468677583279,
                                ],
                                [
                                    0.6866053132241672,
                                    0.22886843774138907,
                                    0.06339468677583279,
                                    0.02113156225861093,
                                ],
                                [
                                    0.6866053132241672,
                                    0.06339468677583279,
                                    0.22886843774138907,
                                    0.02113156225861093,
                                ],
                                [
                                    0.027817541634481458,
                                    0.4658316256758894,
                                    0.02853329105514769,
                                    0.4778175416344814,
                                ],
                                [
                                    0.027817541634481458,
                                    0.02853329105514769,
                                    0.4658316256758894,
                                    0.4778175416344814,
                                ],
                                [
                                    0.052817541634481456,
                                    0.8844807929862603,
                                    0.003533291055147697,
                                    0.05916837432411061,
                                ],
                                [
                                    0.4658316256758894,
                                    0.4778175416344814,
                                    0.027817541634481458,
                                    0.02853329105514769,
                                ],
                                [
                                    0.4658316256758894,
                                    0.027817541634481458,
                                    0.4778175416344814,
                                    0.02853329105514769,
                                ],
                                [
                                    0.052817541634481456,
                                    0.003533291055147697,
                                    0.8844807929862603,
                                    0.05916837432411061,
                                ],
                                [
                                    0.8844807929862603,
                                    0.052817541634481456,
                                    0.05916837432411061,
                                    0.003533291055147697,
                                ],
                                [
                                    0.8844807929862603,
                                    0.05916837432411061,
                                    0.052817541634481456,
                                    0.003533291055147697,
                                ],
                                [
                                    0.08372983346207415,
                                    0.7535685011586675,
                                    0.016270166537925825,
                                    0.14643149884133247,
                                ],
                                [
                                    0.08372983346207415,
                                    0.016270166537925825,
                                    0.7535685011586675,
                                    0.14643149884133247,
                                ],
                                [
                                    0.08936491673103707,
                                    0.8042842505793337,
                                    0.010635083268962911,
                                    0.09571574942066623,
                                ],
                                [
                                    0.17809475019311122,
                                    0.034606915186147044,
                                    0.6592035844276305,
                                    0.12809475019311123,
                                ],
                                [
                                    0.17809475019311122,
                                    0.6592035844276305,
                                    0.034606915186147044,
                                    0.12809475019311123,
                                ],
                                [
                                    0.08936491673103707,
                                    0.010635083268962911,
                                    0.8042842505793337,
                                    0.09571574942066623,
                                ],
                                [
                                    0.1900806661517033,
                                    0.7035685011586675,
                                    0.022620999227554978,
                                    0.08372983346207416,
                                ],
                                [
                                    0.1900806661517033,
                                    0.022620999227554978,
                                    0.7035685011586675,
                                    0.08372983346207416,
                                ],
                                [
                                    0.0375,
                                    0.6279737509655563,
                                    0.018850832689629154,
                                    0.31567541634481455,
                                ],
                                [
                                    0.0375,
                                    0.018850832689629154,
                                    0.6279737509655563,
                                    0.31567541634481455,
                                ],
                                [
                                    0.051587708172407286,
                                    0.863886042793149,
                                    0.004763124517221866,
                                    0.07976312451722185,
                                ],
                                [
                                    0.3702368754827781,
                                    0.186113957206851,
                                    0.29523687548277816,
                                    0.14841229182759272,
                                ],
                                [
                                    0.3702368754827781,
                                    0.29523687548277816,
                                    0.186113957206851,
                                    0.14841229182759272,
                                ],
                                [
                                    0.051587708172407286,
                                    0.004763124517221866,
                                    0.863886042793149,
                                    0.07976312451722185,
                                ],
                                [
                                    0.5093245836551854,
                                    0.4061491673103709,
                                    0.047026249034443725,
                                    0.0375,
                                ],
                                [
                                    0.5093245836551854,
                                    0.047026249034443725,
                                    0.4061491673103709,
                                    0.0375,
                                ],
                                [
                                    0.0062701665379258364,
                                    0.48737900077244506,
                                    0.006431498841332484,
                                    0.4999193338482966,
                                ],
                                [
                                    0.0062701665379258364,
                                    0.006431498841332484,
                                    0.48737900077244506,
                                    0.4999193338482966,
                                ],
                                [
                                    0.011905249806888755,
                                    0.925393084813853,
                                    0.0007964155723695652,
                                    0.061905249806888746,
                                ],
                                [
                                    0.4442842505793338,
                                    0.4557157494206662,
                                    0.04936491673103709,
                                    0.050635083268962905,
                                ],
                                [
                                    0.4442842505793338,
                                    0.04936491673103709,
                                    0.4557157494206662,
                                    0.050635083268962905,
                                ],
                                [
                                    0.011905249806888755,
                                    0.0007964155723695652,
                                    0.925393084813853,
                                    0.061905249806888746,
                                ],
                                [
                                    0.8435685011586675,
                                    0.09372983346207417,
                                    0.05643149884133248,
                                    0.00627016653792583,
                                ],
                                [
                                    0.8435685011586675,
                                    0.05643149884133248,
                                    0.09372983346207417,
                                    0.00627016653792583,
                                ],
                                [
                                    0.37146670894485234,
                                    0.1003578747103331,
                                    0.4158316256758894,
                                    0.11234379066892518,
                                ],
                                [
                                    0.37146670894485234,
                                    0.4158316256758894,
                                    0.1003578747103331,
                                    0.11234379066892518,
                                ],
                                [
                                    0.4158316256758894,
                                    0.11234379066892518,
                                    0.37146670894485234,
                                    0.1003578747103331,
                                ],
                                [
                                    0.4246421252896669,
                                    0.47535787471033314,
                                    0.047182458365518536,
                                    0.052817541634481456,
                                ],
                                [
                                    0.4246421252896669,
                                    0.047182458365518536,
                                    0.47535787471033314,
                                    0.052817541634481456,
                                ],
                                [
                                    0.4158316256758894,
                                    0.37146670894485234,
                                    0.11234379066892518,
                                    0.1003578747103331,
                                ],
                                [
                                    0.47535787471033314,
                                    0.052817541634481456,
                                    0.4246421252896669,
                                    0.047182458365518536,
                                ],
                                [
                                    0.47535787471033314,
                                    0.4246421252896669,
                                    0.052817541634481456,
                                    0.047182458365518536,
                                ],
                                [
                                    0.16636843774138907,
                                    0.20863156225861093,
                                    0.27728072956898175,
                                    0.34771927043101825,
                                ],
                                [
                                    0.16636843774138907,
                                    0.27728072956898175,
                                    0.20863156225861093,
                                    0.34771927043101825,
                                ],
                                [
                                    0.27728072956898175,
                                    0.34771927043101825,
                                    0.16636843774138907,
                                    0.20863156225861093,
                                ],
                                [
                                    0.3538684377413891,
                                    0.5897807295689818,
                                    0.02113156225861093,
                                    0.03521927043101822,
                                ],
                                [
                                    0.3538684377413891,
                                    0.02113156225861093,
                                    0.5897807295689818,
                                    0.03521927043101822,
                                ],
                                [
                                    0.27728072956898175,
                                    0.16636843774138907,
                                    0.34771927043101825,
                                    0.20863156225861093,
                                ],
                                [
                                    0.5897807295689818,
                                    0.03521927043101822,
                                    0.3538684377413891,
                                    0.02113156225861093,
                                ],
                                [
                                    0.5897807295689818,
                                    0.3538684377413891,
                                    0.03521927043101822,
                                    0.02113156225861093,
                                ],
                                [
                                    0.02781754163448145,
                                    0.2503578747103331,
                                    0.07218245836551852,
                                    0.6496421252896669,
                                ],
                                [
                                    0.02781754163448145,
                                    0.07218245836551852,
                                    0.2503578747103331,
                                    0.6496421252896669,
                                ],
                                [
                                    0.07218245836551852,
                                    0.6496421252896669,
                                    0.02781754163448145,
                                    0.2503578747103331,
                                ],
                                [
                                    0.27464212528966686,
                                    0.7126562093310748,
                                    0.0035332910551476968,
                                    0.009168374324110612,
                                ],
                                [
                                    0.27464212528966686,
                                    0.0035332910551476968,
                                    0.7126562093310748,
                                    0.009168374324110612,
                                ],
                                [
                                    0.07218245836551852,
                                    0.02781754163448145,
                                    0.6496421252896669,
                                    0.2503578747103331,
                                ],
                                [
                                    0.7126562093310748,
                                    0.009168374324110612,
                                    0.27464212528966686,
                                    0.0035332910551476968,
                                ],
                                [
                                    0.7126562093310748,
                                    0.27464212528966686,
                                    0.009168374324110612,
                                    0.0035332910551476968,
                                ],
                                [
                                    0.20932458365518541,
                                    0.2625,
                                    0.23432458365518544,
                                    0.29385083268962914,
                                ],
                                [
                                    0.20932458365518541,
                                    0.23432458365518544,
                                    0.2625,
                                    0.29385083268962914,
                                ],
                                [
                                    0.23432458365518544,
                                    0.29385083268962914,
                                    0.20932458365518541,
                                    0.2625,
                                ],
                                [
                                    0.2625,
                                    0.29385083268962914,
                                    0.20932458365518541,
                                    0.23432458365518544,
                                ],
                                [
                                    0.2625,
                                    0.20932458365518541,
                                    0.29385083268962914,
                                    0.23432458365518544,
                                ],
                                [
                                    0.23432458365518544,
                                    0.20932458365518541,
                                    0.29385083268962914,
                                    0.2625,
                                ],
                                [
                                    0.29385083268962914,
                                    0.23432458365518544,
                                    0.2625,
                                    0.20932458365518541,
                                ],
                                [
                                    0.29385083268962914,
                                    0.2625,
                                    0.23432458365518544,
                                    0.20932458365518541,
                                ],
                                [0.09375, 0.28125, 0.15625, 0.46875],
                                [0.09375, 0.15625, 0.28125, 0.46875],
                                [0.15625, 0.46875, 0.09375, 0.28125],
                                [0.28125, 0.46875, 0.09375, 0.15625],
                                [0.28125, 0.09375, 0.46875, 0.15625],
                                [0.15625, 0.09375, 0.46875, 0.28125],
                                [0.46875, 0.15625, 0.28125, 0.09375],
                                [0.46875, 0.28125, 0.15625, 0.09375],
                                [
                                    0.015675416344814577,
                                    0.2625,
                                    0.04067541634481457,
                                    0.6811491673103709,
                                ],
                                [
                                    0.015675416344814577,
                                    0.04067541634481457,
                                    0.2625,
                                    0.6811491673103709,
                                ],
                                [
                                    0.04067541634481457,
                                    0.6811491673103709,
                                    0.015675416344814577,
                                    0.2625,
                                ],
                                [
                                    0.2625,
                                    0.6811491673103709,
                                    0.015675416344814577,
                                    0.04067541634481457,
                                ],
                                [
                                    0.2625,
                                    0.015675416344814577,
                                    0.6811491673103709,
                                    0.04067541634481457,
                                ],
                                [
                                    0.04067541634481457,
                                    0.015675416344814577,
                                    0.6811491673103709,
                                    0.2625,
                                ],
                                [
                                    0.6811491673103709,
                                    0.04067541634481457,
                                    0.2625,
                                    0.015675416344814577,
                                ],
                                [
                                    0.6811491673103709,
                                    0.2625,
                                    0.04067541634481457,
                                    0.015675416344814577,
                                ],
                                [
                                    0.04718245836551853,
                                    0.4246421252896669,
                                    0.05281754163448145,
                                    0.47535787471033314,
                                ],
                                [
                                    0.04718245836551853,
                                    0.05281754163448145,
                                    0.4246421252896669,
                                    0.47535787471033314,
                                ],
                                [
                                    0.05281754163448145,
                                    0.47535787471033314,
                                    0.04718245836551853,
                                    0.4246421252896669,
                                ],
                                [
                                    0.1003578747103331,
                                    0.11234379066892518,
                                    0.37146670894485234,
                                    0.4158316256758894,
                                ],
                                [
                                    0.1003578747103331,
                                    0.37146670894485234,
                                    0.11234379066892518,
                                    0.4158316256758894,
                                ],
                                [
                                    0.05281754163448145,
                                    0.04718245836551853,
                                    0.47535787471033314,
                                    0.4246421252896669,
                                ],
                                [
                                    0.11234379066892518,
                                    0.4158316256758894,
                                    0.1003578747103331,
                                    0.37146670894485234,
                                ],
                                [
                                    0.11234379066892518,
                                    0.1003578747103331,
                                    0.4158316256758894,
                                    0.37146670894485234,
                                ],
                                [
                                    0.02113156225861093,
                                    0.3538684377413891,
                                    0.03521927043101822,
                                    0.5897807295689818,
                                ],
                                [
                                    0.02113156225861093,
                                    0.03521927043101822,
                                    0.3538684377413891,
                                    0.5897807295689818,
                                ],
                                [
                                    0.03521927043101822,
                                    0.5897807295689818,
                                    0.02113156225861093,
                                    0.3538684377413891,
                                ],
                                [
                                    0.20863156225861093,
                                    0.34771927043101825,
                                    0.16636843774138907,
                                    0.27728072956898175,
                                ],
                                [
                                    0.20863156225861093,
                                    0.16636843774138907,
                                    0.34771927043101825,
                                    0.27728072956898175,
                                ],
                                [
                                    0.03521927043101822,
                                    0.02113156225861093,
                                    0.5897807295689818,
                                    0.3538684377413891,
                                ],
                                [
                                    0.34771927043101825,
                                    0.27728072956898175,
                                    0.20863156225861093,
                                    0.16636843774138907,
                                ],
                                [
                                    0.34771927043101825,
                                    0.20863156225861093,
                                    0.27728072956898175,
                                    0.16636843774138907,
                                ],
                                [
                                    0.0035332910551477002,
                                    0.27464212528966686,
                                    0.00916837432411062,
                                    0.7126562093310748,
                                ],
                                [
                                    0.0035332910551477002,
                                    0.00916837432411062,
                                    0.27464212528966686,
                                    0.7126562093310748,
                                ],
                                [
                                    0.00916837432411062,
                                    0.7126562093310748,
                                    0.0035332910551477002,
                                    0.27464212528966686,
                                ],
                                [
                                    0.2503578747103331,
                                    0.6496421252896669,
                                    0.027817541634481455,
                                    0.07218245836551854,
                                ],
                                [
                                    0.2503578747103331,
                                    0.027817541634481455,
                                    0.6496421252896669,
                                    0.07218245836551854,
                                ],
                                [
                                    0.00916837432411062,
                                    0.0035332910551477002,
                                    0.7126562093310748,
                                    0.27464212528966686,
                                ],
                                [
                                    0.6496421252896669,
                                    0.07218245836551854,
                                    0.2503578747103331,
                                    0.027817541634481455,
                                ],
                                [
                                    0.6496421252896669,
                                    0.2503578747103331,
                                    0.07218245836551854,
                                    0.027817541634481455,
                                ],
                                [
                                    0.0837298334620742,
                                    0.02262099922755499,
                                    0.7035685011586675,
                                    0.1900806661517033,
                                ],
                                [
                                    0.0837298334620742,
                                    0.7035685011586675,
                                    0.02262099922755499,
                                    0.1900806661517033,
                                ],
                                [
                                    0.12809475019311128,
                                    0.03460691518614706,
                                    0.6592035844276305,
                                    0.17809475019311122,
                                ],
                                [
                                    0.09571574942066628,
                                    0.8042842505793337,
                                    0.010635083268962918,
                                    0.08936491673103707,
                                ],
                                [
                                    0.09571574942066628,
                                    0.010635083268962918,
                                    0.8042842505793337,
                                    0.08936491673103707,
                                ],
                                [
                                    0.12809475019311128,
                                    0.6592035844276305,
                                    0.03460691518614706,
                                    0.17809475019311122,
                                ],
                                [
                                    0.14643149884133252,
                                    0.01627016653792583,
                                    0.7535685011586675,
                                    0.08372983346207416,
                                ],
                                [
                                    0.14643149884133252,
                                    0.7535685011586675,
                                    0.01627016653792583,
                                    0.08372983346207416,
                                ],
                                [
                                    0.0375,
                                    0.047026249034443725,
                                    0.4061491673103709,
                                    0.5093245836551854,
                                ],
                                [
                                    0.0375,
                                    0.4061491673103709,
                                    0.047026249034443725,
                                    0.5093245836551854,
                                ],
                                [
                                    0.14841229182759272,
                                    0.186113957206851,
                                    0.29523687548277816,
                                    0.3702368754827781,
                                ],
                                [
                                    0.07976312451722185,
                                    0.863886042793149,
                                    0.004763124517221866,
                                    0.051587708172407286,
                                ],
                                [
                                    0.07976312451722185,
                                    0.004763124517221866,
                                    0.863886042793149,
                                    0.051587708172407286,
                                ],
                                [
                                    0.14841229182759272,
                                    0.29523687548277816,
                                    0.186113957206851,
                                    0.3702368754827781,
                                ],
                                [
                                    0.31567541634481455,
                                    0.018850832689629154,
                                    0.6279737509655563,
                                    0.0375,
                                ],
                                [
                                    0.31567541634481455,
                                    0.6279737509655563,
                                    0.018850832689629154,
                                    0.0375,
                                ],
                                [
                                    0.006270166537925824,
                                    0.05643149884133243,
                                    0.09372983346207416,
                                    0.8435685011586675,
                                ],
                                [
                                    0.006270166537925824,
                                    0.09372983346207416,
                                    0.05643149884133243,
                                    0.8435685011586675,
                                ],
                                [
                                    0.0506350832689629,
                                    0.4557157494206662,
                                    0.04936491673103707,
                                    0.44428425057933374,
                                ],
                                [
                                    0.06190524980688869,
                                    0.925393084813853,
                                    0.0007964155723695638,
                                    0.011905249806888745,
                                ],
                                [
                                    0.06190524980688869,
                                    0.0007964155723695638,
                                    0.925393084813853,
                                    0.011905249806888745,
                                ],
                                [
                                    0.0506350832689629,
                                    0.04936491673103707,
                                    0.4557157494206662,
                                    0.44428425057933374,
                                ],
                                [
                                    0.4999193338482966,
                                    0.0064314988413324775,
                                    0.487379000772445,
                                    0.0062701665379258295,
                                ],
                                [
                                    0.4999193338482966,
                                    0.487379000772445,
                                    0.0064314988413324775,
                                    0.0062701665379258295,
                                ],
                                [
                                    0.047182458365518556,
                                    0.05916837432411064,
                                    0.3964667089448523,
                                    0.4971824583655185,
                                ],
                                [
                                    0.047182458365518556,
                                    0.3964667089448523,
                                    0.05916837432411064,
                                    0.4971824583655185,
                                ],
                                [
                                    0.07218245836551855,
                                    0.09051920701373979,
                                    0.3714667089448523,
                                    0.46583162567588937,
                                ],
                                [
                                    0.05916837432411064,
                                    0.4971824583655185,
                                    0.047182458365518556,
                                    0.3964667089448523,
                                ],
                                [
                                    0.05916837432411064,
                                    0.047182458365518556,
                                    0.4971824583655185,
                                    0.3964667089448523,
                                ],
                                [
                                    0.07218245836551855,
                                    0.3714667089448523,
                                    0.09051920701373979,
                                    0.46583162567588937,
                                ],
                                [
                                    0.09051920701373979,
                                    0.07218245836551855,
                                    0.46583162567588937,
                                    0.3714667089448523,
                                ],
                                [
                                    0.09051920701373979,
                                    0.46583162567588937,
                                    0.07218245836551855,
                                    0.3714667089448523,
                                ],
                                [
                                    0.02113156225861093,
                                    0.06339468677583279,
                                    0.22886843774138907,
                                    0.6866053132241672,
                                ],
                                [
                                    0.02113156225861093,
                                    0.22886843774138907,
                                    0.06339468677583279,
                                    0.6866053132241672,
                                ],
                                [
                                    0.08363156225861093,
                                    0.2508946867758328,
                                    0.16636843774138907,
                                    0.4991053132241672,
                                ],
                                [
                                    0.06339468677583279,
                                    0.6866053132241672,
                                    0.02113156225861093,
                                    0.22886843774138907,
                                ],
                                [
                                    0.06339468677583279,
                                    0.02113156225861093,
                                    0.6866053132241672,
                                    0.22886843774138907,
                                ],
                                [
                                    0.08363156225861093,
                                    0.16636843774138907,
                                    0.2508946867758328,
                                    0.4991053132241672,
                                ],
                                [
                                    0.2508946867758328,
                                    0.08363156225861093,
                                    0.4991053132241672,
                                    0.16636843774138907,
                                ],
                                [
                                    0.2508946867758328,
                                    0.4991053132241672,
                                    0.08363156225861093,
                                    0.16636843774138907,
                                ],
                                [
                                    0.003533291055147694,
                                    0.05916837432411056,
                                    0.052817541634481456,
                                    0.8844807929862603,
                                ],
                                [
                                    0.003533291055147694,
                                    0.052817541634481456,
                                    0.05916837432411056,
                                    0.8844807929862603,
                                ],
                                [
                                    0.02853329105514769,
                                    0.4778175416344814,
                                    0.027817541634481455,
                                    0.46583162567588937,
                                ],
                                [
                                    0.05916837432411056,
                                    0.8844807929862603,
                                    0.003533291055147694,
                                    0.052817541634481456,
                                ],
                                [
                                    0.05916837432411056,
                                    0.003533291055147694,
                                    0.8844807929862603,
                                    0.052817541634481456,
                                ],
                                [
                                    0.02853329105514769,
                                    0.027817541634481455,
                                    0.4778175416344814,
                                    0.46583162567588937,
                                ],
                                [
                                    0.4778175416344814,
                                    0.02853329105514769,
                                    0.46583162567588937,
                                    0.027817541634481455,
                                ],
                                [
                                    0.4778175416344814,
                                    0.46583162567588937,
                                    0.02853329105514769,
                                    0.027817541634481455,
                                ],
                                [
                                    0.010635083268962916,
                                    0.09571574942066628,
                                    0.08936491673103707,
                                    0.8042842505793337,
                                ],
                                [
                                    0.010635083268962916,
                                    0.08936491673103707,
                                    0.09571574942066628,
                                    0.8042842505793337,
                                ],
                                [
                                    0.01627016653792583,
                                    0.14643149884133252,
                                    0.08372983346207415,
                                    0.7535685011586675,
                                ],
                                [
                                    0.02262099922755499,
                                    0.1900806661517033,
                                    0.0837298334620742,
                                    0.7035685011586675,
                                ],
                                [
                                    0.02262099922755499,
                                    0.0837298334620742,
                                    0.1900806661517033,
                                    0.7035685011586675,
                                ],
                                [
                                    0.01627016653792583,
                                    0.08372983346207415,
                                    0.14643149884133252,
                                    0.7535685011586675,
                                ],
                                [
                                    0.03460691518614706,
                                    0.12809475019311128,
                                    0.17809475019311122,
                                    0.6592035844276305,
                                ],
                                [
                                    0.03460691518614706,
                                    0.17809475019311122,
                                    0.12809475019311128,
                                    0.6592035844276305,
                                ],
                                [
                                    0.004763124517221866,
                                    0.07976312451722185,
                                    0.051587708172407286,
                                    0.863886042793149,
                                ],
                                [
                                    0.004763124517221866,
                                    0.051587708172407286,
                                    0.07976312451722185,
                                    0.863886042793149,
                                ],
                                [
                                    0.018850832689629154,
                                    0.31567541634481455,
                                    0.0375,
                                    0.6279737509655563,
                                ],
                                [
                                    0.047026249034443725,
                                    0.5093245836551854,
                                    0.0375,
                                    0.4061491673103709,
                                ],
                                [
                                    0.047026249034443725,
                                    0.0375,
                                    0.5093245836551854,
                                    0.4061491673103709,
                                ],
                                [
                                    0.018850832689629154,
                                    0.0375,
                                    0.31567541634481455,
                                    0.6279737509655563,
                                ],
                                [
                                    0.186113957206851,
                                    0.14841229182759272,
                                    0.3702368754827781,
                                    0.29523687548277816,
                                ],
                                [
                                    0.186113957206851,
                                    0.3702368754827781,
                                    0.14841229182759272,
                                    0.29523687548277816,
                                ],
                                [
                                    0.0007964155723695646,
                                    0.06190524980688869,
                                    0.011905249806888755,
                                    0.925393084813853,
                                ],
                                [
                                    0.0007964155723695646,
                                    0.011905249806888755,
                                    0.06190524980688869,
                                    0.925393084813853,
                                ],
                                [
                                    0.006431498841332484,
                                    0.4999193338482966,
                                    0.006270166537925836,
                                    0.487379000772445,
                                ],
                                [
                                    0.05643149884133243,
                                    0.8435685011586675,
                                    0.006270166537925825,
                                    0.09372983346207417,
                                ],
                                [
                                    0.05643149884133243,
                                    0.006270166537925825,
                                    0.8435685011586675,
                                    0.09372983346207417,
                                ],
                                [
                                    0.006431498841332484,
                                    0.006270166537925836,
                                    0.4999193338482966,
                                    0.487379000772445,
                                ],
                                [
                                    0.4557157494206662,
                                    0.050635083268962905,
                                    0.44428425057933374,
                                    0.04936491673103708,
                                ],
                                [
                                    0.4557157494206662,
                                    0.44428425057933374,
                                    0.050635083268962905,
                                    0.04936491673103708,
                                ],
                                [
                                    0.6287116510428008,
                                    0.1698568501158667,
                                    0.15858668357794092,
                                    0.042844815263391546,
                                ],
                                [
                                    0.6287116510428008,
                                    0.15858668357794092,
                                    0.1698568501158667,
                                    0.042844815263391546,
                                ],
                                [
                                    0.707441484504875,
                                    0.19112701665379253,
                                    0.07985685011586675,
                                    0.021574648725465724,
                                ],
                                [
                                    0.7187116510428008,
                                    0.18128834895719922,
                                    0.07985685011586674,
                                    0.020143149884133245,
                                ],
                                [
                                    0.7187116510428008,
                                    0.07985685011586674,
                                    0.18128834895719922,
                                    0.020143149884133245,
                                ],
                                [
                                    0.707441484504875,
                                    0.07985685011586675,
                                    0.19112701665379253,
                                    0.021574648725465724,
                                ],
                                [
                                    0.8087116510428007,
                                    0.08985685011586673,
                                    0.09128834895719923,
                                    0.010143149884133246,
                                ],
                                [
                                    0.8087116510428007,
                                    0.09128834895719923,
                                    0.08985685011586673,
                                    0.010143149884133246,
                                ],
                                [
                                    0.21900704202070398,
                                    0.2746421252896669,
                                    0.22464212528966687,
                                    0.28170870739996223,
                                ],
                                [
                                    0.21900704202070398,
                                    0.22464212528966687,
                                    0.2746421252896669,
                                    0.28170870739996223,
                                ],
                                [
                                    0.41583162567588944,
                                    0.5214667089448524,
                                    0.027817541634481458,
                                    0.034884123744776854,
                                ],
                                [
                                    0.4658316256758894,
                                    0.4778175416344814,
                                    0.027817541634481458,
                                    0.02853329105514769,
                                ],
                                [
                                    0.4658316256758894,
                                    0.027817541634481458,
                                    0.4778175416344814,
                                    0.02853329105514769,
                                ],
                                [
                                    0.41583162567588944,
                                    0.027817541634481458,
                                    0.5214667089448524,
                                    0.034884123744776854,
                                ],
                                [
                                    0.8844807929862603,
                                    0.052817541634481456,
                                    0.05916837432411061,
                                    0.003533291055147697,
                                ],
                                [
                                    0.8844807929862603,
                                    0.05916837432411061,
                                    0.052817541634481456,
                                    0.003533291055147697,
                                ],
                                [
                                    0.018872983346207413,
                                    0.16985685011586676,
                                    0.08112701665379257,
                                    0.7301431498841333,
                                ],
                                [
                                    0.018872983346207413,
                                    0.08112701665379257,
                                    0.16985685011586676,
                                    0.7301431498841333,
                                ],
                                [
                                    0.09760281680828156,
                                    0.8784253512745344,
                                    0.002397183191718413,
                                    0.021574648725465724,
                                ],
                                [
                                    0.18633265027035575,
                                    0.800965684350386,
                                    0.0023971831917184135,
                                    0.010304482187539894,
                                ],
                                [
                                    0.18633265027035575,
                                    0.0023971831917184135,
                                    0.800965684350386,
                                    0.010304482187539894,
                                ],
                                [
                                    0.09760281680828156,
                                    0.002397183191718413,
                                    0.8784253512745344,
                                    0.021574648725465724,
                                ],
                                [
                                    0.9636309848910974,
                                    0.012397183191718411,
                                    0.023667349729644238,
                                    0.00030448218753989704,
                                ],
                                [
                                    0.9636309848910974,
                                    0.023667349729644238,
                                    0.012397183191718411,
                                    0.00030448218753989704,
                                ],
                                [
                                    0.35428425057933377,
                                    0.44428425057933374,
                                    0.08936491673103708,
                                    0.11206658211029538,
                                ],
                                [
                                    0.35428425057933377,
                                    0.08936491673103708,
                                    0.44428425057933374,
                                    0.11206658211029538,
                                ],
                                [
                                    0.3986491673103708,
                                    0.4999193338482967,
                                    0.045,
                                    0.05643149884133247,
                                ],
                                [
                                    0.44428425057933374,
                                    0.11206658211029538,
                                    0.35428425057933377,
                                    0.08936491673103708,
                                ],
                                [
                                    0.44428425057933374,
                                    0.35428425057933377,
                                    0.11206658211029538,
                                    0.08936491673103708,
                                ],
                                [
                                    0.3986491673103708,
                                    0.045,
                                    0.4999193338482967,
                                    0.05643149884133247,
                                ],
                                [
                                    0.4999193338482967,
                                    0.3986491673103708,
                                    0.05643149884133247,
                                    0.045,
                                ],
                                [
                                    0.4999193338482967,
                                    0.05643149884133247,
                                    0.3986491673103708,
                                    0.045,
                                ],
                                [
                                    0.12341229182759272,
                                    0.37023687548277817,
                                    0.12658770817240728,
                                    0.37976312451722183,
                                ],
                                [
                                    0.12341229182759272,
                                    0.12658770817240728,
                                    0.37023687548277817,
                                    0.37976312451722183,
                                ],
                                [
                                    0.23432458365518544,
                                    0.7029737509655563,
                                    0.015675416344814577,
                                    0.04702624903444373,
                                ],
                                [
                                    0.37023687548277817,
                                    0.37976312451722183,
                                    0.12341229182759272,
                                    0.12658770817240728,
                                ],
                                [
                                    0.37023687548277817,
                                    0.12341229182759272,
                                    0.37976312451722183,
                                    0.12658770817240728,
                                ],
                                [
                                    0.23432458365518544,
                                    0.015675416344814577,
                                    0.7029737509655563,
                                    0.04702624903444373,
                                ],
                                [
                                    0.7029737509655563,
                                    0.23432458365518544,
                                    0.04702624903444373,
                                    0.015675416344814577,
                                ],
                                [
                                    0.7029737509655563,
                                    0.04702624903444373,
                                    0.23432458365518544,
                                    0.015675416344814577,
                                ],
                                [
                                    0.010635083268962914,
                                    0.17809475019311125,
                                    0.04571574942066624,
                                    0.7655544171172596,
                                ],
                                [
                                    0.010635083268962914,
                                    0.04571574942066624,
                                    0.17809475019311125,
                                    0.7655544171172596,
                                ],
                                [
                                    0.05499999999999999,
                                    0.9210281680828158,
                                    0.0013508326896291552,
                                    0.02262099922755498,
                                ],
                                [
                                    0.17809475019311125,
                                    0.7655544171172596,
                                    0.010635083268962914,
                                    0.04571574942066624,
                                ],
                                [
                                    0.17809475019311125,
                                    0.010635083268962914,
                                    0.7655544171172596,
                                    0.04571574942066624,
                                ],
                                [
                                    0.05499999999999999,
                                    0.0013508326896291552,
                                    0.9210281680828158,
                                    0.02262099922755498,
                                ],
                                [
                                    0.9210281680828158,
                                    0.05499999999999999,
                                    0.02262099922755498,
                                    0.0013508326896291552,
                                ],
                                [
                                    0.9210281680828158,
                                    0.02262099922755498,
                                    0.05499999999999999,
                                    0.0013508326896291552,
                                ],
                                [
                                    0.07985685011586674,
                                    0.7187116510428008,
                                    0.02014314988413324,
                                    0.18128834895719922,
                                ],
                                [
                                    0.07985685011586674,
                                    0.02014314988413324,
                                    0.7187116510428008,
                                    0.18128834895719922,
                                ],
                                [
                                    0.08985685011586673,
                                    0.8087116510428007,
                                    0.010143149884133245,
                                    0.09128834895719923,
                                ],
                                [
                                    0.1698568501158667,
                                    0.042844815263391546,
                                    0.6287116510428008,
                                    0.15858668357794092,
                                ],
                                [
                                    0.1698568501158667,
                                    0.6287116510428008,
                                    0.042844815263391546,
                                    0.15858668357794092,
                                ],
                                [
                                    0.08985685011586673,
                                    0.010143149884133245,
                                    0.8087116510428007,
                                    0.09128834895719923,
                                ],
                                [
                                    0.19112701665379253,
                                    0.707441484504875,
                                    0.021574648725465724,
                                    0.07985685011586675,
                                ],
                                [
                                    0.19112701665379253,
                                    0.021574648725465724,
                                    0.707441484504875,
                                    0.07985685011586675,
                                ],
                                [
                                    0.027817541634481458,
                                    0.4658316256758894,
                                    0.02853329105514769,
                                    0.4778175416344814,
                                ],
                                [
                                    0.027817541634481458,
                                    0.02853329105514769,
                                    0.4658316256758894,
                                    0.4778175416344814,
                                ],
                                [
                                    0.052817541634481456,
                                    0.8844807929862603,
                                    0.003533291055147697,
                                    0.05916837432411061,
                                ],
                                [
                                    0.2746421252896669,
                                    0.28170870739996223,
                                    0.21900704202070398,
                                    0.22464212528966687,
                                ],
                                [
                                    0.2746421252896669,
                                    0.21900704202070398,
                                    0.28170870739996223,
                                    0.22464212528966687,
                                ],
                                [
                                    0.052817541634481456,
                                    0.003533291055147697,
                                    0.8844807929862603,
                                    0.05916837432411061,
                                ],
                                [
                                    0.5214667089448524,
                                    0.41583162567588944,
                                    0.034884123744776854,
                                    0.027817541634481458,
                                ],
                                [
                                    0.5214667089448524,
                                    0.034884123744776854,
                                    0.41583162567588944,
                                    0.027817541634481458,
                                ],
                                [
                                    0.002397183191718416,
                                    0.18633265027035575,
                                    0.010304482187539904,
                                    0.800965684350386,
                                ],
                                [
                                    0.002397183191718416,
                                    0.010304482187539904,
                                    0.18633265027035575,
                                    0.800965684350386,
                                ],
                                [
                                    0.012397183191718423,
                                    0.9636309848910974,
                                    0.00030448218753989737,
                                    0.023667349729644238,
                                ],
                                [
                                    0.16985685011586676,
                                    0.7301431498841333,
                                    0.018872983346207416,
                                    0.08112701665379257,
                                ],
                                [
                                    0.16985685011586676,
                                    0.018872983346207416,
                                    0.7301431498841333,
                                    0.08112701665379257,
                                ],
                                [
                                    0.012397183191718423,
                                    0.00030448218753989737,
                                    0.9636309848910974,
                                    0.023667349729644238,
                                ],
                                [
                                    0.8784253512745344,
                                    0.09760281680828158,
                                    0.021574648725465724,
                                    0.0023971831917184135,
                                ],
                                [
                                    0.8784253512745344,
                                    0.021574648725465724,
                                    0.09760281680828158,
                                    0.0023971831917184135,
                                ],
                                [
                                    0.3542842505793337,
                                    0.09571574942066621,
                                    0.433014084041408,
                                    0.11698591595859206,
                                ],
                                [
                                    0.3542842505793337,
                                    0.433014084041408,
                                    0.09571574942066621,
                                    0.11698591595859206,
                                ],
                                [
                                    0.433014084041408,
                                    0.11698591595859206,
                                    0.35428425057933377,
                                    0.09571574942066623,
                                ],
                                [
                                    0.40499999999999997,
                                    0.49500000000000005,
                                    0.04499999999999999,
                                    0.055,
                                ],
                                [
                                    0.40499999999999997,
                                    0.04499999999999999,
                                    0.49500000000000005,
                                    0.055,
                                ],
                                [
                                    0.433014084041408,
                                    0.35428425057933377,
                                    0.11698591595859206,
                                    0.09571574942066623,
                                ],
                                [0.49500000000000005, 0.055, 0.405, 0.045],
                                [0.49500000000000005, 0.405, 0.055, 0.045],
                                [
                                    0.12341229182759271,
                                    0.15476312451722185,
                                    0.3202368754827781,
                                    0.4015877081724073,
                                ],
                                [
                                    0.12341229182759271,
                                    0.3202368754827781,
                                    0.15476312451722185,
                                    0.4015877081724073,
                                ],
                                [
                                    0.3202368754827781,
                                    0.4015877081724073,
                                    0.12341229182759271,
                                    0.15476312451722185,
                                ],
                                [
                                    0.2625,
                                    0.6811491673103709,
                                    0.015675416344814577,
                                    0.04067541634481457,
                                ],
                                [
                                    0.2625,
                                    0.015675416344814577,
                                    0.6811491673103709,
                                    0.04067541634481457,
                                ],
                                [
                                    0.3202368754827781,
                                    0.12341229182759271,
                                    0.4015877081724073,
                                    0.15476312451722185,
                                ],
                                [
                                    0.6811491673103709,
                                    0.04067541634481457,
                                    0.2625,
                                    0.015675416344814577,
                                ],
                                [
                                    0.6811491673103709,
                                    0.2625,
                                    0.04067541634481457,
                                    0.015675416344814577,
                                ],
                                [
                                    0.010635083268962916,
                                    0.09571574942066628,
                                    0.08936491673103707,
                                    0.8042842505793337,
                                ],
                                [
                                    0.010635083268962916,
                                    0.08936491673103707,
                                    0.09571574942066628,
                                    0.8042842505793337,
                                ],
                                [
                                    0.08936491673103707,
                                    0.8042842505793337,
                                    0.010635083268962911,
                                    0.09571574942066623,
                                ],
                                [
                                    0.10500000000000004,
                                    0.8822983346207417,
                                    0.0013508326896291558,
                                    0.011350832689629152,
                                ],
                                [
                                    0.10500000000000004,
                                    0.0013508326896291558,
                                    0.8822983346207417,
                                    0.011350832689629152,
                                ],
                                [
                                    0.08936491673103707,
                                    0.010635083268962911,
                                    0.8042842505793337,
                                    0.09571574942066623,
                                ],
                                [
                                    0.8822983346207417,
                                    0.011350832689629152,
                                    0.10499999999999998,
                                    0.0013508326896291552,
                                ],
                                [
                                    0.8822983346207417,
                                    0.10499999999999998,
                                    0.011350832689629152,
                                    0.0013508326896291552,
                                ],
                                [
                                    0.19964212528966685,
                                    0.2503578747103331,
                                    0.244007042020704,
                                    0.30599295797929604,
                                ],
                                [
                                    0.19964212528966685,
                                    0.244007042020704,
                                    0.2503578747103331,
                                    0.30599295797929604,
                                ],
                                [
                                    0.244007042020704,
                                    0.30599295797929604,
                                    0.19964212528966688,
                                    0.2503578747103331,
                                ],
                                [
                                    0.2503578747103331,
                                    0.30599295797929604,
                                    0.19964212528966685,
                                    0.244007042020704,
                                ],
                                [
                                    0.2503578747103331,
                                    0.19964212528966685,
                                    0.30599295797929604,
                                    0.244007042020704,
                                ],
                                [
                                    0.244007042020704,
                                    0.19964212528966688,
                                    0.30599295797929604,
                                    0.2503578747103331,
                                ],
                                [
                                    0.30599295797929604,
                                    0.244007042020704,
                                    0.2503578747103331,
                                    0.19964212528966688,
                                ],
                                [
                                    0.30599295797929604,
                                    0.2503578747103331,
                                    0.244007042020704,
                                    0.19964212528966688,
                                ],
                                [
                                    0.06954385408620364,
                                    0.20863156225861093,
                                    0.18045614591379636,
                                    0.5413684377413891,
                                ],
                                [
                                    0.06954385408620364,
                                    0.18045614591379636,
                                    0.20863156225861093,
                                    0.5413684377413891,
                                ],
                                [
                                    0.18045614591379636,
                                    0.5413684377413891,
                                    0.06954385408620364,
                                    0.20863156225861093,
                                ],
                                [
                                    0.20863156225861093,
                                    0.5413684377413891,
                                    0.06954385408620364,
                                    0.18045614591379636,
                                ],
                                [
                                    0.20863156225861093,
                                    0.06954385408620364,
                                    0.5413684377413891,
                                    0.18045614591379636,
                                ],
                                [
                                    0.18045614591379636,
                                    0.06954385408620364,
                                    0.5413684377413891,
                                    0.20863156225861093,
                                ],
                                [
                                    0.5413684377413891,
                                    0.18045614591379636,
                                    0.20863156225861093,
                                    0.06954385408620364,
                                ],
                                [
                                    0.5413684377413891,
                                    0.20863156225861093,
                                    0.18045614591379636,
                                    0.06954385408620364,
                                ],
                                [
                                    0.005992957979296037,
                                    0.10035787471033315,
                                    0.05035787471033311,
                                    0.8432912926000377,
                                ],
                                [
                                    0.005992957979296037,
                                    0.05035787471033311,
                                    0.10035787471033315,
                                    0.8432912926000377,
                                ],
                                [
                                    0.05035787471033311,
                                    0.8432912926000377,
                                    0.005992957979296034,
                                    0.1003578747103331,
                                ],
                                [
                                    0.10035787471033315,
                                    0.8432912926000377,
                                    0.005992957979296037,
                                    0.05035787471033311,
                                ],
                                [
                                    0.10035787471033315,
                                    0.005992957979296037,
                                    0.8432912926000377,
                                    0.05035787471033311,
                                ],
                                [
                                    0.05035787471033311,
                                    0.005992957979296034,
                                    0.8432912926000377,
                                    0.1003578747103331,
                                ],
                                [
                                    0.8432912926000377,
                                    0.05035787471033311,
                                    0.1003578747103331,
                                    0.005992957979296034,
                                ],
                                [
                                    0.8432912926000377,
                                    0.1003578747103331,
                                    0.05035787471033311,
                                    0.005992957979296034,
                                ],
                                [
                                    0.044999999999999984,
                                    0.40499999999999997,
                                    0.05499999999999999,
                                    0.49500000000000005,
                                ],
                                [
                                    0.044999999999999984,
                                    0.05499999999999999,
                                    0.40499999999999997,
                                    0.49500000000000005,
                                ],
                                [
                                    0.05499999999999999,
                                    0.49500000000000005,
                                    0.04499999999999999,
                                    0.405,
                                ],
                                [
                                    0.09571574942066621,
                                    0.11698591595859206,
                                    0.3542842505793337,
                                    0.433014084041408,
                                ],
                                [
                                    0.09571574942066621,
                                    0.3542842505793337,
                                    0.11698591595859206,
                                    0.433014084041408,
                                ],
                                [
                                    0.05499999999999999,
                                    0.04499999999999999,
                                    0.49500000000000005,
                                    0.405,
                                ],
                                [
                                    0.11698591595859206,
                                    0.433014084041408,
                                    0.09571574942066623,
                                    0.35428425057933377,
                                ],
                                [
                                    0.11698591595859206,
                                    0.09571574942066623,
                                    0.433014084041408,
                                    0.35428425057933377,
                                ],
                                [
                                    0.015675416344814577,
                                    0.2625,
                                    0.04067541634481457,
                                    0.6811491673103709,
                                ],
                                [
                                    0.015675416344814577,
                                    0.04067541634481457,
                                    0.2625,
                                    0.6811491673103709,
                                ],
                                [
                                    0.04067541634481457,
                                    0.6811491673103709,
                                    0.015675416344814577,
                                    0.2625,
                                ],
                                [
                                    0.15476312451722185,
                                    0.4015877081724073,
                                    0.12341229182759271,
                                    0.3202368754827781,
                                ],
                                [
                                    0.15476312451722185,
                                    0.12341229182759271,
                                    0.4015877081724073,
                                    0.3202368754827781,
                                ],
                                [
                                    0.04067541634481457,
                                    0.015675416344814577,
                                    0.6811491673103709,
                                    0.2625,
                                ],
                                [
                                    0.4015877081724073,
                                    0.3202368754827781,
                                    0.15476312451722185,
                                    0.12341229182759271,
                                ],
                                [
                                    0.4015877081724073,
                                    0.15476312451722185,
                                    0.3202368754827781,
                                    0.12341229182759271,
                                ],
                                [
                                    0.0013508326896291571,
                                    0.10500000000000004,
                                    0.011350832689629163,
                                    0.8822983346207417,
                                ],
                                [
                                    0.0013508326896291571,
                                    0.011350832689629163,
                                    0.10500000000000004,
                                    0.8822983346207417,
                                ],
                                [
                                    0.011350832689629163,
                                    0.8822983346207417,
                                    0.0013508326896291565,
                                    0.10499999999999998,
                                ],
                                [
                                    0.09571574942066628,
                                    0.8042842505793337,
                                    0.010635083268962918,
                                    0.08936491673103707,
                                ],
                                [
                                    0.09571574942066628,
                                    0.010635083268962918,
                                    0.8042842505793337,
                                    0.08936491673103707,
                                ],
                                [
                                    0.011350832689629163,
                                    0.0013508326896291565,
                                    0.8822983346207417,
                                    0.10499999999999998,
                                ],
                                [
                                    0.8042842505793337,
                                    0.08936491673103707,
                                    0.09571574942066623,
                                    0.010635083268962913,
                                ],
                                [
                                    0.8042842505793337,
                                    0.09571574942066623,
                                    0.08936491673103707,
                                    0.010635083268962913,
                                ],
                                [
                                    0.07985685011586678,
                                    0.02157464872546573,
                                    0.707441484504875,
                                    0.19112701665379253,
                                ],
                                [
                                    0.07985685011586678,
                                    0.707441484504875,
                                    0.02157464872546573,
                                    0.19112701665379253,
                                ],
                                [
                                    0.15858668357794092,
                                    0.04284481526339155,
                                    0.6287116510428008,
                                    0.1698568501158667,
                                ],
                                [
                                    0.09128834895719927,
                                    0.8087116510428007,
                                    0.01014314988413325,
                                    0.08985685011586673,
                                ],
                                [
                                    0.09128834895719927,
                                    0.01014314988413325,
                                    0.8087116510428007,
                                    0.08985685011586673,
                                ],
                                [
                                    0.15858668357794092,
                                    0.6287116510428008,
                                    0.04284481526339155,
                                    0.1698568501158667,
                                ],
                                [
                                    0.18128834895719925,
                                    0.02014314988413325,
                                    0.7187116510428008,
                                    0.07985685011586674,
                                ],
                                [
                                    0.18128834895719925,
                                    0.7187116510428008,
                                    0.02014314988413325,
                                    0.07985685011586674,
                                ],
                                [
                                    0.027817541634481434,
                                    0.03488412374477682,
                                    0.41583162567588944,
                                    0.5214667089448524,
                                ],
                                [
                                    0.027817541634481434,
                                    0.41583162567588944,
                                    0.03488412374477682,
                                    0.5214667089448524,
                                ],
                                [
                                    0.22464212528966687,
                                    0.28170870739996223,
                                    0.21900704202070398,
                                    0.27464212528966686,
                                ],
                                [
                                    0.05916837432411056,
                                    0.8844807929862603,
                                    0.003533291055147694,
                                    0.052817541634481456,
                                ],
                                [
                                    0.05916837432411056,
                                    0.003533291055147694,
                                    0.8844807929862603,
                                    0.052817541634481456,
                                ],
                                [
                                    0.22464212528966687,
                                    0.21900704202070398,
                                    0.28170870739996223,
                                    0.27464212528966686,
                                ],
                                [
                                    0.4778175416344814,
                                    0.02853329105514769,
                                    0.46583162567588937,
                                    0.027817541634481455,
                                ],
                                [
                                    0.4778175416344814,
                                    0.46583162567588937,
                                    0.02853329105514769,
                                    0.027817541634481455,
                                ],
                                [
                                    0.00239718319171841,
                                    0.021574648725465696,
                                    0.09760281680828156,
                                    0.8784253512745344,
                                ],
                                [
                                    0.00239718319171841,
                                    0.09760281680828156,
                                    0.021574648725465696,
                                    0.8784253512745344,
                                ],
                                [
                                    0.08112701665379257,
                                    0.7301431498841333,
                                    0.01887298334620741,
                                    0.16985685011586674,
                                ],
                                [
                                    0.023667349729644207,
                                    0.9636309848910974,
                                    0.00030448218753989666,
                                    0.012397183191718411,
                                ],
                                [
                                    0.023667349729644207,
                                    0.00030448218753989666,
                                    0.9636309848910974,
                                    0.012397183191718411,
                                ],
                                [
                                    0.08112701665379257,
                                    0.01887298334620741,
                                    0.7301431498841333,
                                    0.16985685011586674,
                                ],
                                [
                                    0.800965684350386,
                                    0.010304482187539894,
                                    0.18633265027035573,
                                    0.002397183191718413,
                                ],
                                [
                                    0.800965684350386,
                                    0.18633265027035573,
                                    0.010304482187539894,
                                    0.002397183191718413,
                                ],
                                [
                                    0.04500000000000001,
                                    0.0564314988413325,
                                    0.3986491673103708,
                                    0.4999193338482967,
                                ],
                                [
                                    0.04500000000000001,
                                    0.3986491673103708,
                                    0.0564314988413325,
                                    0.4999193338482967,
                                ],
                                [
                                    0.0893649167310371,
                                    0.1120665821102954,
                                    0.35428425057933377,
                                    0.44428425057933374,
                                ],
                                [
                                    0.0564314988413325,
                                    0.4999193338482967,
                                    0.04500000000000001,
                                    0.3986491673103708,
                                ],
                                [
                                    0.0564314988413325,
                                    0.04500000000000001,
                                    0.4999193338482967,
                                    0.3986491673103708,
                                ],
                                [
                                    0.0893649167310371,
                                    0.35428425057933377,
                                    0.1120665821102954,
                                    0.44428425057933374,
                                ],
                                [
                                    0.1120665821102954,
                                    0.0893649167310371,
                                    0.44428425057933374,
                                    0.35428425057933377,
                                ],
                                [
                                    0.1120665821102954,
                                    0.44428425057933374,
                                    0.0893649167310371,
                                    0.35428425057933377,
                                ],
                                [
                                    0.015675416344814563,
                                    0.04702624903444369,
                                    0.23432458365518544,
                                    0.7029737509655563,
                                ],
                                [
                                    0.015675416344814563,
                                    0.23432458365518544,
                                    0.04702624903444369,
                                    0.7029737509655563,
                                ],
                                [
                                    0.12658770817240728,
                                    0.37976312451722183,
                                    0.12341229182759271,
                                    0.3702368754827781,
                                ],
                                [
                                    0.04702624903444369,
                                    0.7029737509655563,
                                    0.015675416344814563,
                                    0.23432458365518544,
                                ],
                                [
                                    0.04702624903444369,
                                    0.015675416344814563,
                                    0.7029737509655563,
                                    0.23432458365518544,
                                ],
                                [
                                    0.12658770817240728,
                                    0.12341229182759271,
                                    0.37976312451722183,
                                    0.3702368754827781,
                                ],
                                [
                                    0.37976312451722183,
                                    0.12658770817240728,
                                    0.3702368754827781,
                                    0.12341229182759271,
                                ],
                                [
                                    0.37976312451722183,
                                    0.3702368754827781,
                                    0.12658770817240728,
                                    0.12341229182759271,
                                ],
                                [
                                    0.0013508326896291534,
                                    0.022620999227554953,
                                    0.05499999999999999,
                                    0.9210281680828158,
                                ],
                                [
                                    0.0013508326896291534,
                                    0.05499999999999999,
                                    0.022620999227554953,
                                    0.9210281680828158,
                                ],
                                [
                                    0.04571574942066624,
                                    0.7655544171172596,
                                    0.010635083268962913,
                                    0.17809475019311122,
                                ],
                                [
                                    0.022620999227554953,
                                    0.9210281680828158,
                                    0.0013508326896291534,
                                    0.05499999999999999,
                                ],
                                [
                                    0.022620999227554953,
                                    0.0013508326896291534,
                                    0.9210281680828158,
                                    0.05499999999999999,
                                ],
                                [
                                    0.04571574942066624,
                                    0.010635083268962913,
                                    0.7655544171172596,
                                    0.17809475019311122,
                                ],
                                [
                                    0.7655544171172596,
                                    0.04571574942066624,
                                    0.17809475019311122,
                                    0.010635083268962913,
                                ],
                                [
                                    0.7655544171172596,
                                    0.17809475019311122,
                                    0.04571574942066624,
                                    0.010635083268962913,
                                ],
                                [
                                    0.01014314988413325,
                                    0.09128834895719927,
                                    0.08985685011586673,
                                    0.8087116510428007,
                                ],
                                [
                                    0.01014314988413325,
                                    0.08985685011586673,
                                    0.09128834895719927,
                                    0.8087116510428007,
                                ],
                                [
                                    0.020143149884133245,
                                    0.18128834895719925,
                                    0.07985685011586674,
                                    0.7187116510428008,
                                ],
                                [
                                    0.02157464872546573,
                                    0.19112701665379253,
                                    0.07985685011586678,
                                    0.707441484504875,
                                ],
                                [
                                    0.02157464872546573,
                                    0.07985685011586678,
                                    0.19112701665379253,
                                    0.707441484504875,
                                ],
                                [
                                    0.020143149884133245,
                                    0.07985685011586674,
                                    0.18128834895719925,
                                    0.7187116510428008,
                                ],
                                [
                                    0.04284481526339155,
                                    0.15858668357794092,
                                    0.1698568501158667,
                                    0.6287116510428008,
                                ],
                                [
                                    0.04284481526339155,
                                    0.1698568501158667,
                                    0.15858668357794092,
                                    0.6287116510428008,
                                ],
                                [
                                    0.003533291055147694,
                                    0.05916837432411056,
                                    0.052817541634481456,
                                    0.8844807929862603,
                                ],
                                [
                                    0.003533291055147694,
                                    0.052817541634481456,
                                    0.05916837432411056,
                                    0.8844807929862603,
                                ],
                                [
                                    0.02853329105514769,
                                    0.4778175416344814,
                                    0.027817541634481455,
                                    0.46583162567588937,
                                ],
                                [
                                    0.03488412374477682,
                                    0.5214667089448524,
                                    0.027817541634481434,
                                    0.41583162567588944,
                                ],
                                [
                                    0.03488412374477682,
                                    0.027817541634481434,
                                    0.5214667089448524,
                                    0.41583162567588944,
                                ],
                                [
                                    0.02853329105514769,
                                    0.027817541634481455,
                                    0.4778175416344814,
                                    0.46583162567588937,
                                ],
                                [
                                    0.28170870739996223,
                                    0.22464212528966687,
                                    0.27464212528966686,
                                    0.21900704202070398,
                                ],
                                [
                                    0.28170870739996223,
                                    0.27464212528966686,
                                    0.22464212528966687,
                                    0.21900704202070398,
                                ],
                                [
                                    0.00030448218753989693,
                                    0.023667349729644207,
                                    0.012397183191718423,
                                    0.9636309848910974,
                                ],
                                [
                                    0.00030448218753989693,
                                    0.012397183191718423,
                                    0.023667349729644207,
                                    0.9636309848910974,
                                ],
                                [
                                    0.010304482187539904,
                                    0.800965684350386,
                                    0.0023971831917184157,
                                    0.18633265027035573,
                                ],
                                [
                                    0.021574648725465696,
                                    0.8784253512745344,
                                    0.0023971831917184105,
                                    0.09760281680828158,
                                ],
                                [
                                    0.021574648725465696,
                                    0.0023971831917184105,
                                    0.8784253512745344,
                                    0.09760281680828158,
                                ],
                                [
                                    0.010304482187539904,
                                    0.0023971831917184157,
                                    0.800965684350386,
                                    0.18633265027035573,
                                ],
                                [
                                    0.7301431498841333,
                                    0.08112701665379257,
                                    0.16985685011586674,
                                    0.018872983346207413,
                                ],
                                [
                                    0.7301431498841333,
                                    0.16985685011586674,
                                    0.08112701665379257,
                                    0.018872983346207413,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0015047985590927325,
                                0.0015047985590927325,
                                0.0015047985590927325,
                                0.0015047985590927325,
                                0.0015047985590927325,
                                0.0015047985590927325,
                                0.0015047985590927325,
                                0.0015047985590927325,
                                0.005753081343151171,
                                0.005753081343151171,
                                0.005753081343151171,
                                0.005753081343151171,
                                0.005753081343151171,
                                0.005753081343151171,
                                0.005753081343151171,
                                0.005753081343151171,
                                0.0013717421124828536,
                                0.0013717421124828536,
                                0.0013717421124828536,
                                0.0013717421124828536,
                                0.0013717421124828536,
                                0.0013717421124828536,
                                0.0013717421124828536,
                                0.0013717421124828536,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0009404990994329582,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.0008573388203017838,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.000587811937145599,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0023012325372604686,
                                0.0023012325372604686,
                                0.0023012325372604686,
                                0.0023012325372604686,
                                0.0023012325372604686,
                                0.0023012325372604686,
                                0.0023012325372604686,
                                0.0023012325372604686,
                                0.007315957933241883,
                                0.007315957933241883,
                                0.007315957933241883,
                                0.007315957933241883,
                                0.007315957933241883,
                                0.007315957933241883,
                                0.007315957933241883,
                                0.007315957933241883,
                                0.0013567464293604734,
                                0.0013567464293604734,
                                0.0013567464293604734,
                                0.0013567464293604734,
                                0.0013567464293604734,
                                0.0013567464293604734,
                                0.0013567464293604734,
                                0.0013567464293604734,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.0014382703357877934,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.0008479665183502963,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.001438270335787793,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.0008479665183502962,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.000898918959867371,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.0005299790739689352,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.0013717421124828533,
                                0.0013717421124828533,
                                0.0013717421124828533,
                                0.0013717421124828533,
                                0.0013717421124828533,
                                0.0013717421124828533,
                                0.0013717421124828533,
                                0.0013717421124828533,
                                0.0033918660734011835,
                                0.0033918660734011835,
                                0.0033918660734011835,
                                0.0033918660734011835,
                                0.0033918660734011835,
                                0.0033918660734011835,
                                0.0033918660734011835,
                                0.0033918660734011835,
                                0.00032419092421773866,
                                0.00032419092421773866,
                                0.00032419092421773866,
                                0.00032419092421773866,
                                0.00032419092421773866,
                                0.00032419092421773866,
                                0.00032419092421773866,
                                0.00032419092421773866,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0008573388203017837,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.00020261932763608674,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.000535836762688615,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                                0.00012663707977255423,
                            ]
                        ),
                    )
                case 4:
                    return (
                        np.array(
                            [
                                [
                                    0.8707562472347103,
                                    0.06014662427691039,
                                    0.06463268955174192,
                                    0.004464438936637297,
                                ],
                                [
                                    0.8707562472347103,
                                    0.06463268955174192,
                                    0.06014662427691039,
                                    0.004464438936637297,
                                ],
                                [
                                    0.8662469420305309,
                                    0.05983514849166392,
                                    0.06914199475592146,
                                    0.00477591472188377,
                                ],
                                [
                                    0.8061219440918146,
                                    0.059835148491663916,
                                    0.12478092741980612,
                                    0.0092619799967153,
                                ],
                                [
                                    0.8061219440918146,
                                    0.12478092741980612,
                                    0.059835148491663916,
                                    0.0092619799967153,
                                ],
                                [
                                    0.8662469420305309,
                                    0.06914199475592146,
                                    0.05983514849166392,
                                    0.00477591472188377,
                                ],
                                [
                                    0.8019473546022295,
                                    0.12413473591996517,
                                    0.06400973798124897,
                                    0.009908171496556258,
                                ],
                                [
                                    0.8019473546022295,
                                    0.06400973798124897,
                                    0.12413473591996517,
                                    0.009908171496556258,
                                ],
                                [
                                    0.8887962525367729,
                                    0.043362806679126856,
                                    0.06468506993666619,
                                    0.003155870847434076,
                                ],
                                [
                                    0.8887962525367729,
                                    0.06468506993666619,
                                    0.043362806679126856,
                                    0.003155870847434076,
                                ],
                                [
                                    0.8669489760720925,
                                    0.042296916467394474,
                                    0.08653234640134658,
                                    0.004221761059166464,
                                ],
                                [
                                    0.5811749277984727,
                                    0.042296916467394474,
                                    0.350984131417427,
                                    0.02554402431670578,
                                ],
                                [
                                    0.5811749277984727,
                                    0.350984131417427,
                                    0.042296916467394474,
                                    0.02554402431670578,
                                ],
                                [
                                    0.8669489760720925,
                                    0.08653234640134658,
                                    0.042296916467394474,
                                    0.004221761059166464,
                                ],
                                [
                                    0.5668892135127584,
                                    0.3423566790267285,
                                    0.056582630753108765,
                                    0.03417147670740428,
                                ],
                                [
                                    0.5668892135127584,
                                    0.056582630753108765,
                                    0.3423566790267285,
                                    0.03417147670740428,
                                ],
                                [
                                    0.912401763386921,
                                    0.021396269980657794,
                                    0.06468506993666617,
                                    0.0015168966957549831,
                                ],
                                [
                                    0.912401763386921,
                                    0.06468506993666617,
                                    0.021396269980657794,
                                    0.0015168966957549831,
                                ],
                                [
                                    0.8669489760720925,
                                    0.02033037976892541,
                                    0.11013785725149472,
                                    0.002582786907487371,
                                ],
                                [
                                    0.2867659317622337,
                                    0.02033037976892541,
                                    0.6470321016053451,
                                    0.045871586863495746,
                                ],
                                [
                                    0.2867659317622337,
                                    0.6470321016053451,
                                    0.02033037976892541,
                                    0.045871586863495746,
                                ],
                                [
                                    0.8669489760720925,
                                    0.11013785725149472,
                                    0.02033037976892541,
                                    0.002582786907487371,
                                ],
                                [
                                    0.27248021747651946,
                                    0.6147991383644985,
                                    0.034616094054639696,
                                    0.07810455010434239,
                                ],
                                [
                                    0.27248021747651946,
                                    0.034616094054639696,
                                    0.6147991383644985,
                                    0.07810455010434239,
                                ],
                                [
                                    0.930546529458832,
                                    0.004507691613025766,
                                    0.06463268955174192,
                                    0.0003130893764002528,
                                ],
                                [
                                    0.930546529458832,
                                    0.06463268955174192,
                                    0.004507691613025766,
                                    0.0003130893764002528,
                                ],
                                [
                                    0.8662469420305308,
                                    0.004196215827779292,
                                    0.12893227698004314,
                                    0.0006245651616467263,
                                ],
                                [
                                    0.06041484738576841,
                                    0.004196215827779289,
                                    0.8746393736860893,
                                    0.0607495631003629,
                                ],
                                [
                                    0.06041484738576841,
                                    0.8746393736860893,
                                    0.004196215827779289,
                                    0.0607495631003629,
                                ],
                                [
                                    0.8662469420305308,
                                    0.12893227698004314,
                                    0.004196215827779292,
                                    0.0006245651616467263,
                                ],
                                [
                                    0.05624025789618335,
                                    0.8142028999621267,
                                    0.008370805317364347,
                                    0.12118603682432554,
                                ],
                                [
                                    0.05624025789618335,
                                    0.008370805317364347,
                                    0.8142028999621267,
                                    0.12118603682432554,
                                ],
                                [
                                    0.6450260332766374,
                                    0.2858768382349832,
                                    0.04787765519220338,
                                    0.021219473296175833,
                                ],
                                [
                                    0.6450260332766374,
                                    0.04787765519220338,
                                    0.2858768382349832,
                                    0.021219473296175833,
                                ],
                                [
                                    0.6416856963477637,
                                    0.28439639417443097,
                                    0.05121799212107714,
                                    0.02269991735672809,
                                ],
                                [
                                    0.5803917301337418,
                                    0.04308011413212538,
                                    0.3505111413778789,
                                    0.026017014356253833,
                                ],
                                [
                                    0.5803917301337418,
                                    0.3505111413778789,
                                    0.04308011413212538,
                                    0.026017014356253833,
                                ],
                                [
                                    0.6416856963477637,
                                    0.05121799212107714,
                                    0.28439639417443097,
                                    0.02269991735672809,
                                ],
                                [
                                    0.5773861089194626,
                                    0.34869598160273224,
                                    0.04608573534640465,
                                    0.02783217413140058,
                                ],
                                [
                                    0.5773861089194626,
                                    0.04608573534640465,
                                    0.34869598160273224,
                                    0.02783217413140058,
                                ],
                                [
                                    0.726055687340008,
                                    0.2061033718758917,
                                    0.05284109015925395,
                                    0.014999850624846312,
                                ],
                                [
                                    0.726055687340008,
                                    0.05284109015925395,
                                    0.2061033718758917,
                                    0.014999850624846312,
                                ],
                                [
                                    0.7082086956534467,
                                    0.20103719688604033,
                                    0.07068808184581535,
                                    0.020066025614697704,
                                ],
                                [
                                    0.41843436260170785,
                                    0.03045293668998224,
                                    0.5137246966141918,
                                    0.03738800409411802,
                                ],
                                [
                                    0.41843436260170785,
                                    0.5137246966141918,
                                    0.03045293668998224,
                                    0.03738800409411802,
                                ],
                                [
                                    0.7082086956534467,
                                    0.07068808184581535,
                                    0.20103719688604033,
                                    0.020066025614697704,
                                ],
                                [
                                    0.4081489330941126,
                                    0.5010969594453744,
                                    0.04073836619757753,
                                    0.050015741262935516,
                                ],
                                [
                                    0.4081489330941126,
                                    0.04073836619757753,
                                    0.5010969594453744,
                                    0.050015741262935516,
                                ],
                                [
                                    0.8321015859671107,
                                    0.10169644740046811,
                                    0.058992158326055415,
                                    0.007209808306365741,
                                ],
                                [
                                    0.8321015859671107,
                                    0.058992158326055415,
                                    0.10169644740046811,
                                    0.007209808306365741,
                                ],
                                [
                                    0.7906490834304012,
                                    0.09663027241061672,
                                    0.10044466086276495,
                                    0.01227598329621713,
                                ],
                                [
                                    0.20646575434242334,
                                    0.014637468158314649,
                                    0.7273322790251555,
                                    0.05156449847410651,
                                ],
                                [
                                    0.20646575434242334,
                                    0.7273322790251555,
                                    0.014637468158314649,
                                    0.05156449847410651,
                                ],
                                [
                                    0.7906490834304012,
                                    0.10044466086276495,
                                    0.09663027241061672,
                                    0.01227598329621713,
                                ],
                                [
                                    0.19618032483482806,
                                    0.6910990310061899,
                                    0.024922897665909927,
                                    0.08779774649307216,
                                ],
                                [
                                    0.19618032483482806,
                                    0.024922897665909927,
                                    0.6910990310061899,
                                    0.08779774649307216,
                                ],
                                [
                                    0.913629167852955,
                                    0.021425053218902815,
                                    0.06345766547063221,
                                    0.0014881134575099799,
                                ],
                                [
                                    0.913629167852955,
                                    0.06345766547063221,
                                    0.021425053218902815,
                                    0.0014881134575099799,
                                ],
                                [
                                    0.8504985486999596,
                                    0.019944609158350553,
                                    0.12658828462362764,
                                    0.0029685575180622417,
                                ],
                                [
                                    0.04349748577989145,
                                    0.0030211917466695685,
                                    0.8915567352919663,
                                    0.06192458718147262,
                                ],
                                [
                                    0.04349748577989145,
                                    0.8915567352919663,
                                    0.0030211917466695685,
                                    0.06192458718147262,
                                ],
                                [
                                    0.8504985486999596,
                                    0.12658828462362764,
                                    0.019944609158350553,
                                    0.0029685575180622417,
                                ],
                                [
                                    0.04049186456561218,
                                    0.8299512932926979,
                                    0.006026812960948843,
                                    0.12353002918074105,
                                ],
                                [
                                    0.04049186456561218,
                                    0.006026812960948843,
                                    0.8299512932926979,
                                    0.12353002918074105,
                                ],
                                [
                                    0.35051114137787903,
                                    0.5803917301337417,
                                    0.02601701435625384,
                                    0.043080114132125376,
                                ],
                                [
                                    0.35051114137787903,
                                    0.02601701435625384,
                                    0.5803917301337417,
                                    0.043080114132125376,
                                ],
                                [
                                    0.34869598160273235,
                                    0.5773861089194625,
                                    0.027832174131400586,
                                    0.046085735346404644,
                                ],
                                [
                                    0.2858768382349833,
                                    0.021219473296175836,
                                    0.6450260332766374,
                                    0.04787765519220338,
                                ],
                                [
                                    0.2858768382349833,
                                    0.6450260332766374,
                                    0.021219473296175836,
                                    0.04787765519220338,
                                ],
                                [
                                    0.34869598160273235,
                                    0.027832174131400586,
                                    0.5773861089194625,
                                    0.046085735346404644,
                                ],
                                [
                                    0.284396394174431,
                                    0.6416856963477637,
                                    0.022699917356728095,
                                    0.05121799212107714,
                                ],
                                [
                                    0.284396394174431,
                                    0.022699917356728095,
                                    0.6416856963477637,
                                    0.05121799212107714,
                                ],
                                [
                                    0.5137246966141918,
                                    0.41843436260170785,
                                    0.03738800409411802,
                                    0.03045293668998224,
                                ],
                                [
                                    0.5137246966141918,
                                    0.03738800409411802,
                                    0.41843436260170785,
                                    0.03045293668998224,
                                ],
                                [
                                    0.5010969594453744,
                                    0.4081489330941126,
                                    0.050015741262935516,
                                    0.04073836619757753,
                                ],
                                [
                                    0.20610337187589167,
                                    0.01499985062484631,
                                    0.726055687340008,
                                    0.05284109015925395,
                                ],
                                [
                                    0.20610337187589167,
                                    0.726055687340008,
                                    0.01499985062484631,
                                    0.05284109015925395,
                                ],
                                [
                                    0.5010969594453744,
                                    0.050015741262935516,
                                    0.4081489330941126,
                                    0.04073836619757753,
                                ],
                                [
                                    0.2010371968860403,
                                    0.7082086956534467,
                                    0.0200660256146977,
                                    0.07068808184581535,
                                ],
                                [
                                    0.2010371968860403,
                                    0.0200660256146977,
                                    0.7082086956534467,
                                    0.07068808184581535,
                                ],
                                [
                                    0.7273322790251555,
                                    0.20646575434242337,
                                    0.05156449847410651,
                                    0.01463746815831465,
                                ],
                                [
                                    0.7273322790251555,
                                    0.05156449847410651,
                                    0.20646575434242337,
                                    0.01463746815831465,
                                ],
                                [
                                    0.6910990310061899,
                                    0.19618032483482808,
                                    0.08779774649307216,
                                    0.02492289766590993,
                                ],
                                [
                                    0.10169644740046813,
                                    0.0072098083063657425,
                                    0.8321015859671107,
                                    0.058992158326055415,
                                ],
                                [
                                    0.10169644740046813,
                                    0.8321015859671107,
                                    0.0072098083063657425,
                                    0.058992158326055415,
                                ],
                                [
                                    0.6910990310061899,
                                    0.08779774649307216,
                                    0.19618032483482808,
                                    0.02492289766590993,
                                ],
                                [
                                    0.09663027241061674,
                                    0.7906490834304012,
                                    0.012275983296217133,
                                    0.10044466086276495,
                                ],
                                [
                                    0.09663027241061674,
                                    0.012275983296217133,
                                    0.7906490834304012,
                                    0.10044466086276495,
                                ],
                                [
                                    0.8915567352919664,
                                    0.043497485779891404,
                                    0.061924587181472625,
                                    0.0030211917466695646,
                                ],
                                [
                                    0.8915567352919664,
                                    0.061924587181472625,
                                    0.043497485779891404,
                                    0.0030211917466695646,
                                ],
                                [
                                    0.829951293292698,
                                    0.04049186456561213,
                                    0.12353002918074106,
                                    0.0060268129609488364,
                                ],
                                [
                                    0.02142505321890287,
                                    0.0014881134575099836,
                                    0.9136291678529549,
                                    0.0634576654706322,
                                ],
                                [
                                    0.02142505321890287,
                                    0.9136291678529549,
                                    0.0014881134575099836,
                                    0.0634576654706322,
                                ],
                                [
                                    0.829951293292698,
                                    0.12353002918074106,
                                    0.04049186456561213,
                                    0.0060268129609488364,
                                ],
                                [
                                    0.019944609158350605,
                                    0.8504985486999594,
                                    0.0029685575180622495,
                                    0.12658828462362764,
                                ],
                                [
                                    0.019944609158350605,
                                    0.0029685575180622495,
                                    0.8504985486999594,
                                    0.12658828462362764,
                                ],
                                [
                                    0.12478092741980616,
                                    0.8061219440918146,
                                    0.009261979996715304,
                                    0.059835148491663916,
                                ],
                                [
                                    0.12478092741980616,
                                    0.009261979996715304,
                                    0.8061219440918146,
                                    0.059835148491663916,
                                ],
                                [
                                    0.12413473591996521,
                                    0.8019473546022295,
                                    0.009908171496556262,
                                    0.06400973798124897,
                                ],
                                [
                                    0.06014662427691041,
                                    0.0044644389366372975,
                                    0.8707562472347103,
                                    0.06463268955174192,
                                ],
                                [
                                    0.06014662427691041,
                                    0.8707562472347103,
                                    0.0044644389366372975,
                                    0.06463268955174192,
                                ],
                                [
                                    0.12413473591996521,
                                    0.009908171496556262,
                                    0.8019473546022295,
                                    0.06400973798124897,
                                ],
                                [
                                    0.059835148491663936,
                                    0.8662469420305309,
                                    0.004775914721883771,
                                    0.06914199475592146,
                                ],
                                [
                                    0.059835148491663936,
                                    0.004775914721883771,
                                    0.8662469420305309,
                                    0.06914199475592146,
                                ],
                                [
                                    0.35098413141742707,
                                    0.5811749277984726,
                                    0.025544024316705792,
                                    0.04229691646739447,
                                ],
                                [
                                    0.35098413141742707,
                                    0.025544024316705792,
                                    0.5811749277984726,
                                    0.04229691646739447,
                                ],
                                [
                                    0.3423566790267286,
                                    0.5668892135127583,
                                    0.03417147670740429,
                                    0.05658263075310876,
                                ],
                                [
                                    0.04336280667912694,
                                    0.003155870847434082,
                                    0.8887962525367727,
                                    0.06468506993666617,
                                ],
                                [
                                    0.04336280667912694,
                                    0.8887962525367727,
                                    0.003155870847434082,
                                    0.06468506993666617,
                                ],
                                [
                                    0.3423566790267286,
                                    0.03417147670740429,
                                    0.5668892135127583,
                                    0.05658263075310876,
                                ],
                                [
                                    0.04229691646739455,
                                    0.8669489760720924,
                                    0.004221761059166472,
                                    0.08653234640134658,
                                ],
                                [
                                    0.04229691646739455,
                                    0.004221761059166472,
                                    0.8669489760720924,
                                    0.08653234640134658,
                                ],
                                [
                                    0.6470321016053451,
                                    0.28676593176223364,
                                    0.045871586863495746,
                                    0.020330379768925405,
                                ],
                                [
                                    0.6470321016053451,
                                    0.045871586863495746,
                                    0.28676593176223364,
                                    0.020330379768925405,
                                ],
                                [
                                    0.6147991383644985,
                                    0.2724802174765194,
                                    0.07810455010434239,
                                    0.03461609405463969,
                                ],
                                [
                                    0.021396269980657866,
                                    0.0015168966957549881,
                                    0.9124017633869209,
                                    0.06468506993666617,
                                ],
                                [
                                    0.021396269980657866,
                                    0.9124017633869209,
                                    0.0015168966957549881,
                                    0.06468506993666617,
                                ],
                                [
                                    0.6147991383644985,
                                    0.07810455010434239,
                                    0.2724802174765194,
                                    0.03461609405463969,
                                ],
                                [
                                    0.020330379768925474,
                                    0.8669489760720924,
                                    0.0025827869074873796,
                                    0.1101378572514947,
                                ],
                                [
                                    0.020330379768925474,
                                    0.0025827869074873796,
                                    0.8669489760720924,
                                    0.1101378572514947,
                                ],
                                [
                                    0.8746393736860893,
                                    0.06041484738576845,
                                    0.0607495631003629,
                                    0.004196215827779292,
                                ],
                                [
                                    0.8746393736860893,
                                    0.0607495631003629,
                                    0.06041484738576845,
                                    0.004196215827779292,
                                ],
                                [
                                    0.8142028999621267,
                                    0.05624025789618339,
                                    0.12118603682432554,
                                    0.008370805317364352,
                                ],
                                [
                                    0.004507691613025809,
                                    0.0003130893764002558,
                                    0.930546529458832,
                                    0.06463268955174192,
                                ],
                                [
                                    0.004507691613025809,
                                    0.930546529458832,
                                    0.0003130893764002558,
                                    0.06463268955174192,
                                ],
                                [
                                    0.8142028999621267,
                                    0.12118603682432554,
                                    0.05624025789618339,
                                    0.008370805317364352,
                                ],
                                [
                                    0.004196215827779333,
                                    0.8662469420305308,
                                    0.0006245651616467323,
                                    0.12893227698004314,
                                ],
                                [
                                    0.004196215827779333,
                                    0.0006245651616467323,
                                    0.8662469420305308,
                                    0.12893227698004314,
                                ],
                                [
                                    0.6281898352939297,
                                    0.04339158991737186,
                                    0.30719910149252255,
                                    0.021219473296175833,
                                ],
                                [
                                    0.6281898352939297,
                                    0.30719910149252255,
                                    0.04339158991737186,
                                    0.021219473296175833,
                                ],
                                [
                                    0.6236805300897502,
                                    0.04308011413212539,
                                    0.3117084066967021,
                                    0.021530949081422304,
                                ],
                                [
                                    0.5815606984090476,
                                    0.28439639417443097,
                                    0.09002072680225401,
                                    0.044022180614267416,
                                ],
                                [
                                    0.5815606984090476,
                                    0.09002072680225401,
                                    0.28439639417443097,
                                    0.044022180614267416,
                                ],
                                [
                                    0.6236805300897502,
                                    0.3117084066967021,
                                    0.04308011413212539,
                                    0.021530949081422304,
                                ],
                                [
                                    0.5773861089194625,
                                    0.08937453530241306,
                                    0.288570983664016,
                                    0.04466837211410837,
                                ],
                                [
                                    0.5773861089194625,
                                    0.288570983664016,
                                    0.08937453530241306,
                                    0.04466837211410837,
                                ],
                                [
                                    0.6460332570696796,
                                    0.031518826901714626,
                                    0.30744806540375946,
                                    0.014999850624846312,
                                ],
                                [
                                    0.6460332570696796,
                                    0.30744806540375946,
                                    0.031518826901714626,
                                    0.014999850624846312,
                                ],
                                [
                                    0.6241859806049992,
                                    0.03045293668998223,
                                    0.3292953418684399,
                                    0.0160657408365787,
                                ],
                                [
                                    0.4224346473798269,
                                    0.20103719688604033,
                                    0.2551174365915673,
                                    0.12141071914256545,
                                ],
                                [
                                    0.4224346473798269,
                                    0.2551174365915673,
                                    0.20103719688604033,
                                    0.12141071914256545,
                                ],
                                [
                                    0.6241859806049992,
                                    0.3292953418684399,
                                    0.03045293668998223,
                                    0.0160657408365787,
                                ],
                                [
                                    0.40814893309411254,
                                    0.24648998420086882,
                                    0.21532291117175464,
                                    0.13003817153326394,
                                ],
                                [
                                    0.40814893309411254,
                                    0.21532291117175464,
                                    0.24648998420086882,
                                    0.13003817153326394,
                                ],
                                [
                                    0.6696387679198278,
                                    0.01570335837004704,
                                    0.30744806540375946,
                                    0.007209808306365742,
                                ],
                                [
                                    0.6696387679198278,
                                    0.30744806540375946,
                                    0.01570335837004704,
                                    0.007209808306365742,
                                ],
                                [
                                    0.6241859806049992,
                                    0.01463746815831465,
                                    0.352900852718588,
                                    0.008275698518098128,
                                ],
                                [
                                    0.2104660391205424,
                                    0.09663027241061674,
                                    0.4748760871693324,
                                    0.2180276012995085,
                                ],
                                [
                                    0.2104660391205424,
                                    0.4748760871693324,
                                    0.09663027241061674,
                                    0.2180276012995085,
                                ],
                                [
                                    0.6241859806049992,
                                    0.352900852718588,
                                    0.01463746815831465,
                                    0.008275698518098128,
                                ],
                                [
                                    0.1961803248348281,
                                    0.44264312392848576,
                                    0.11091598669633101,
                                    0.2502605645403551,
                                ],
                                [
                                    0.1961803248348281,
                                    0.11091598669633101,
                                    0.44264312392848576,
                                    0.2502605645403551,
                                ],
                                [
                                    0.6879801175180513,
                                    0.0033326675319160387,
                                    0.30719910149252255,
                                    0.00148811345750998,
                                ],
                                [
                                    0.6879801175180513,
                                    0.30719910149252255,
                                    0.0033326675319160387,
                                    0.00148811345750998,
                                ],
                                [
                                    0.6236805300897501,
                                    0.003021191746669565,
                                    0.37149868892082377,
                                    0.0017995892427564535,
                                ],
                                [
                                    0.04466645405519716,
                                    0.01994460915835054,
                                    0.6466463309947702,
                                    0.288742605791682,
                                ],
                                [
                                    0.04466645405519716,
                                    0.6466463309947702,
                                    0.01994460915835054,
                                    0.288742605791682,
                                ],
                                [
                                    0.6236805300897501,
                                    0.37149868892082377,
                                    0.003021191746669565,
                                    0.0017995892427564535,
                                ],
                                [
                                    0.0404918645656121,
                                    0.5862098572708075,
                                    0.0241191986479356,
                                    0.34917907951564464,
                                ],
                                [
                                    0.0404918645656121,
                                    0.0241191986479356,
                                    0.5862098572708075,
                                    0.34917907951564464,
                                ],
                                [
                                    0.4653412466360719,
                                    0.2062401785752297,
                                    0.227562441832769,
                                    0.10085613295592939,
                                ],
                                [
                                    0.4653412466360719,
                                    0.227562441832769,
                                    0.2062401785752297,
                                    0.10085613295592939,
                                ],
                                [
                                    0.46200090970719815,
                                    0.20475973451467744,
                                    0.23090277876164275,
                                    0.10233657701648165,
                                ],
                                [
                                    0.4187121097511898,
                                    0.20475973451467744,
                                    0.2528693154601118,
                                    0.12365884027402096,
                                ],
                                [
                                    0.4187121097511898,
                                    0.2528693154601118,
                                    0.20475973451467744,
                                    0.12365884027402096,
                                ],
                                [
                                    0.46200090970719815,
                                    0.23090277876164275,
                                    0.20475973451467744,
                                    0.10233657701648165,
                                ],
                                [
                                    0.41570648853691056,
                                    0.2510541556849651,
                                    0.2077653557289567,
                                    0.1254740000491677,
                                ],
                                [
                                    0.41570648853691056,
                                    0.2077653557289567,
                                    0.2510541556849651,
                                    0.1254740000491677,
                                ],
                                [
                                    0.5277431347932283,
                                    0.1498089491781659,
                                    0.2511536427060337,
                                    0.07129427332257211,
                                ],
                                [
                                    0.5277431347932283,
                                    0.2511536427060337,
                                    0.1498089491781659,
                                    0.07129427332257211,
                                ],
                                [
                                    0.5098961431066669,
                                    0.1447427741883145,
                                    0.2690006343925951,
                                    0.07636044831242352,
                                ],
                                [
                                    0.3041445251033756,
                                    0.14474277418831452,
                                    0.37340755886801863,
                                    0.17770514184029126,
                                ],
                                [
                                    0.3041445251033756,
                                    0.37340755886801863,
                                    0.14474277418831452,
                                    0.17770514184029126,
                                ],
                                [
                                    0.5098961431066669,
                                    0.2690006343925951,
                                    0.1447427741883145,
                                    0.07636044831242352,
                                ],
                                [
                                    0.2938590955957803,
                                    0.3607798216992011,
                                    0.15502820369590983,
                                    0.19033287900910875,
                                ],
                                [
                                    0.2938590955957803,
                                    0.15502820369590983,
                                    0.3607798216992011,
                                    0.19033287900910875,
                                ],
                                [
                                    0.6107040814374844,
                                    0.07463804485239033,
                                    0.2803896628556817,
                                    0.03426821085444353,
                                ],
                                [
                                    0.6107040814374844,
                                    0.2803896628556817,
                                    0.07463804485239033,
                                    0.03426821085444353,
                                ],
                                [
                                    0.5692515789007749,
                                    0.06957186986253894,
                                    0.3218421653923912,
                                    0.03933438584429492,
                                ],
                                [
                                    0.15153135263819906,
                                    0.06957186986253894,
                                    0.5338107736516757,
                                    0.24508600384758628,
                                ],
                                [
                                    0.15153135263819906,
                                    0.5338107736516757,
                                    0.06957186986253894,
                                    0.24508600384758628,
                                ],
                                [
                                    0.5692515789007749,
                                    0.3218421653923912,
                                    0.06957186986253894,
                                    0.03933438584429492,
                                ],
                                [
                                    0.14124592313060377,
                                    0.49757752563271007,
                                    0.07985729937013421,
                                    0.28131925186655193,
                                ],
                                [
                                    0.14124592313060377,
                                    0.07985729937013421,
                                    0.49757752563271007,
                                    0.28131925186655193,
                                ],
                                [
                                    0.6754726199805824,
                                    0.015840165069385036,
                                    0.3016142133430048,
                                    0.007073001607027759,
                                ],
                                [
                                    0.6754726199805824,
                                    0.3016142133430048,
                                    0.015840165069385036,
                                    0.007073001607027759,
                                ],
                                [
                                    0.6123420008275869,
                                    0.014359721008832774,
                                    0.36474483249600026,
                                    0.00855344566758002,
                                ],
                                [
                                    0.03215895651772823,
                                    0.014359721008832791,
                                    0.6591538285322391,
                                    0.2943274939411997,
                                ],
                                [
                                    0.03215895651772823,
                                    0.6591538285322391,
                                    0.014359721008832791,
                                    0.2943274939411997,
                                ],
                                [
                                    0.6123420008275869,
                                    0.36474483249600026,
                                    0.014359721008832774,
                                    0.00855344566758002,
                                ],
                                [
                                    0.029153335303448956,
                                    0.5975483865329707,
                                    0.017365342223112066,
                                    0.35593293594046815,
                                ],
                                [
                                    0.029153335303448956,
                                    0.017365342223112066,
                                    0.5975483865329707,
                                    0.35593293594046815,
                                ],
                                [
                                    0.2528693154601119,
                                    0.4187121097511897,
                                    0.123658840274021,
                                    0.2047597345146774,
                                ],
                                [
                                    0.2528693154601119,
                                    0.123658840274021,
                                    0.4187121097511897,
                                    0.2047597345146774,
                                ],
                                [
                                    0.2510541556849652,
                                    0.41570648853691045,
                                    0.12547400004916776,
                                    0.20776535572895666,
                                ],
                                [
                                    0.20624017857522972,
                                    0.1008561329559294,
                                    0.4653412466360719,
                                    0.227562441832769,
                                ],
                                [
                                    0.20624017857522972,
                                    0.4653412466360719,
                                    0.1008561329559294,
                                    0.227562441832769,
                                ],
                                [
                                    0.2510541556849652,
                                    0.12547400004916776,
                                    0.41570648853691045,
                                    0.20776535572895666,
                                ],
                                [
                                    0.20475973451467747,
                                    0.46200090970719815,
                                    0.10233657701648166,
                                    0.23090277876164275,
                                ],
                                [
                                    0.20475973451467747,
                                    0.10233657701648166,
                                    0.46200090970719815,
                                    0.23090277876164275,
                                ],
                                [
                                    0.37340755886801863,
                                    0.3041445251033756,
                                    0.17770514184029126,
                                    0.14474277418831452,
                                ],
                                [
                                    0.37340755886801863,
                                    0.17770514184029126,
                                    0.3041445251033756,
                                    0.14474277418831452,
                                ],
                                [
                                    0.3607798216992011,
                                    0.2938590955957803,
                                    0.19033287900910875,
                                    0.15502820369590983,
                                ],
                                [
                                    0.1498089491781659,
                                    0.07129427332257211,
                                    0.5277431347932283,
                                    0.2511536427060337,
                                ],
                                [
                                    0.1498089491781659,
                                    0.5277431347932283,
                                    0.07129427332257211,
                                    0.2511536427060337,
                                ],
                                [
                                    0.3607798216992011,
                                    0.19033287900910875,
                                    0.2938590955957803,
                                    0.15502820369590983,
                                ],
                                [
                                    0.1447427741883145,
                                    0.5098961431066669,
                                    0.0763604483124235,
                                    0.2690006343925951,
                                ],
                                [
                                    0.1447427741883145,
                                    0.0763604483124235,
                                    0.5098961431066669,
                                    0.2690006343925951,
                                ],
                                [
                                    0.5338107736516757,
                                    0.15153135263819908,
                                    0.24508600384758628,
                                    0.06957186986253894,
                                ],
                                [
                                    0.5338107736516757,
                                    0.24508600384758628,
                                    0.15153135263819908,
                                    0.06957186986253894,
                                ],
                                [
                                    0.49757752563271007,
                                    0.1412459231306038,
                                    0.28131925186655193,
                                    0.07985729937013422,
                                ],
                                [
                                    0.07463804485239034,
                                    0.03426821085444354,
                                    0.6107040814374844,
                                    0.2803896628556817,
                                ],
                                [
                                    0.07463804485239034,
                                    0.6107040814374844,
                                    0.03426821085444354,
                                    0.2803896628556817,
                                ],
                                [
                                    0.49757752563271007,
                                    0.28131925186655193,
                                    0.1412459231306038,
                                    0.07985729937013422,
                                ],
                                [
                                    0.06957186986253895,
                                    0.5692515789007749,
                                    0.039334385844294925,
                                    0.3218421653923912,
                                ],
                                [
                                    0.06957186986253895,
                                    0.039334385844294925,
                                    0.5692515789007749,
                                    0.3218421653923912,
                                ],
                                [
                                    0.6591538285322392,
                                    0.032158956517728196,
                                    0.2943274939411998,
                                    0.014359721008832774,
                                ],
                                [
                                    0.6591538285322392,
                                    0.2943274939411998,
                                    0.032158956517728196,
                                    0.014359721008832774,
                                ],
                                [
                                    0.5975483865329708,
                                    0.02915333530344892,
                                    0.3559329359404682,
                                    0.017365342223112045,
                                ],
                                [
                                    0.015840165069385077,
                                    0.007073001607027778,
                                    0.6754726199805823,
                                    0.30161421334300476,
                                ],
                                [
                                    0.015840165069385077,
                                    0.6754726199805823,
                                    0.007073001607027778,
                                    0.30161421334300476,
                                ],
                                [
                                    0.5975483865329708,
                                    0.3559329359404682,
                                    0.02915333530344892,
                                    0.017365342223112045,
                                ],
                                [
                                    0.01435972100883281,
                                    0.6123420008275869,
                                    0.008553445667580043,
                                    0.3647448324960002,
                                ],
                                [
                                    0.01435972100883281,
                                    0.008553445667580043,
                                    0.6123420008275869,
                                    0.3647448324960002,
                                ],
                                [
                                    0.09002072680225404,
                                    0.5815606984090476,
                                    0.04402218061426744,
                                    0.28439639417443097,
                                ],
                                [
                                    0.09002072680225404,
                                    0.04402218061426744,
                                    0.5815606984090476,
                                    0.28439639417443097,
                                ],
                                [
                                    0.08937453530241309,
                                    0.5773861089194625,
                                    0.04466837211410839,
                                    0.288570983664016,
                                ],
                                [
                                    0.04339158991737187,
                                    0.021219473296175836,
                                    0.6281898352939297,
                                    0.30719910149252255,
                                ],
                                [
                                    0.04339158991737187,
                                    0.6281898352939297,
                                    0.021219473296175836,
                                    0.30719910149252255,
                                ],
                                [
                                    0.08937453530241309,
                                    0.04466837211410839,
                                    0.5773861089194625,
                                    0.288570983664016,
                                ],
                                [
                                    0.0430801141321254,
                                    0.6236805300897502,
                                    0.02153094908142231,
                                    0.3117084066967021,
                                ],
                                [
                                    0.0430801141321254,
                                    0.02153094908142231,
                                    0.6236805300897502,
                                    0.3117084066967021,
                                ],
                                [
                                    0.25511743659156744,
                                    0.4224346473798268,
                                    0.12141071914256549,
                                    0.2010371968860403,
                                ],
                                [
                                    0.25511743659156744,
                                    0.12141071914256549,
                                    0.4224346473798268,
                                    0.2010371968860403,
                                ],
                                [
                                    0.2464899842008689,
                                    0.4081489330941125,
                                    0.130038171533264,
                                    0.2153229111717546,
                                ],
                                [
                                    0.03151882690171468,
                                    0.01499985062484634,
                                    0.6460332570696795,
                                    0.30744806540375946,
                                ],
                                [
                                    0.03151882690171468,
                                    0.6460332570696795,
                                    0.01499985062484634,
                                    0.30744806540375946,
                                ],
                                [
                                    0.2464899842008689,
                                    0.130038171533264,
                                    0.4081489330941125,
                                    0.2153229111717546,
                                ],
                                [
                                    0.03045293668998229,
                                    0.6241859806049991,
                                    0.016065740836578732,
                                    0.32929534186843984,
                                ],
                                [
                                    0.03045293668998229,
                                    0.016065740836578732,
                                    0.6241859806049991,
                                    0.32929534186843984,
                                ],
                                [
                                    0.4748760871693324,
                                    0.21046603912054235,
                                    0.2180276012995085,
                                    0.09663027241061672,
                                ],
                                [
                                    0.4748760871693324,
                                    0.2180276012995085,
                                    0.21046603912054235,
                                    0.09663027241061672,
                                ],
                                [
                                    0.44264312392848576,
                                    0.19618032483482808,
                                    0.2502605645403551,
                                    0.110915986696331,
                                ],
                                [
                                    0.01570335837004709,
                                    0.007209808306365766,
                                    0.6696387679198277,
                                    0.30744806540375946,
                                ],
                                [
                                    0.01570335837004709,
                                    0.6696387679198277,
                                    0.007209808306365766,
                                    0.30744806540375946,
                                ],
                                [
                                    0.44264312392848576,
                                    0.2502605645403551,
                                    0.19618032483482808,
                                    0.110915986696331,
                                ],
                                [
                                    0.014637468158314699,
                                    0.6241859806049992,
                                    0.008275698518098156,
                                    0.35290085271858795,
                                ],
                                [
                                    0.014637468158314699,
                                    0.008275698518098156,
                                    0.6241859806049992,
                                    0.35290085271858795,
                                ],
                                [
                                    0.6466463309947702,
                                    0.04466645405519719,
                                    0.288742605791682,
                                    0.019944609158350553,
                                ],
                                [
                                    0.6466463309947702,
                                    0.288742605791682,
                                    0.04466645405519719,
                                    0.019944609158350553,
                                ],
                                [
                                    0.5862098572708075,
                                    0.04049186456561213,
                                    0.34917907951564464,
                                    0.024119198647935613,
                                ],
                                [
                                    0.0033326675319160707,
                                    0.0014881134575099944,
                                    0.6879801175180513,
                                    0.30719910149252255,
                                ],
                                [
                                    0.0033326675319160707,
                                    0.6879801175180513,
                                    0.0014881134575099944,
                                    0.30719910149252255,
                                ],
                                [
                                    0.5862098572708075,
                                    0.34917907951564464,
                                    0.04049186456561213,
                                    0.024119198647935613,
                                ],
                                [
                                    0.003021191746669594,
                                    0.6236805300897501,
                                    0.001799589242756471,
                                    0.37149868892082377,
                                ],
                                [
                                    0.003021191746669594,
                                    0.001799589242756471,
                                    0.6236805300897501,
                                    0.37149868892082377,
                                ],
                                [
                                    0.31170840669670213,
                                    0.021530949081422307,
                                    0.6236805300897501,
                                    0.04308011413212538,
                                ],
                                [
                                    0.31170840669670213,
                                    0.6236805300897501,
                                    0.021530949081422307,
                                    0.04308011413212538,
                                ],
                                [
                                    0.30719910149252255,
                                    0.021219473296175833,
                                    0.6281898352939297,
                                    0.04339158991737186,
                                ],
                                [
                                    0.28857098366401607,
                                    0.5773861089194624,
                                    0.04466837211410838,
                                    0.08937453530241304,
                                ],
                                [
                                    0.28857098366401607,
                                    0.04466837211410838,
                                    0.5773861089194624,
                                    0.08937453530241304,
                                ],
                                [
                                    0.30719910149252255,
                                    0.6281898352939297,
                                    0.021219473296175833,
                                    0.04339158991737186,
                                ],
                                [
                                    0.28439639417443097,
                                    0.044022180614267416,
                                    0.5815606984090476,
                                    0.09002072680225401,
                                ],
                                [
                                    0.28439639417443097,
                                    0.5815606984090476,
                                    0.044022180614267416,
                                    0.09002072680225401,
                                ],
                                [
                                    0.32929534186843984,
                                    0.016065740836578697,
                                    0.6241859806049993,
                                    0.030452936689982238,
                                ],
                                [
                                    0.32929534186843984,
                                    0.6241859806049993,
                                    0.016065740836578697,
                                    0.030452936689982238,
                                ],
                                [
                                    0.30744806540375946,
                                    0.014999850624846312,
                                    0.6460332570696796,
                                    0.031518826901714626,
                                ],
                                [
                                    0.2153229111717546,
                                    0.4081489330941126,
                                    0.13003817153326394,
                                    0.24648998420086884,
                                ],
                                [
                                    0.2153229111717546,
                                    0.13003817153326394,
                                    0.4081489330941126,
                                    0.24648998420086884,
                                ],
                                [
                                    0.30744806540375946,
                                    0.6460332570696796,
                                    0.014999850624846312,
                                    0.031518826901714626,
                                ],
                                [
                                    0.20103719688604033,
                                    0.12141071914256545,
                                    0.4224346473798269,
                                    0.2551174365915673,
                                ],
                                [
                                    0.20103719688604033,
                                    0.4224346473798269,
                                    0.12141071914256545,
                                    0.2551174365915673,
                                ],
                                [
                                    0.352900852718588,
                                    0.008275698518098128,
                                    0.6241859806049992,
                                    0.01463746815831465,
                                ],
                                [
                                    0.352900852718588,
                                    0.6241859806049992,
                                    0.008275698518098128,
                                    0.01463746815831465,
                                ],
                                [
                                    0.30744806540375946,
                                    0.007209808306365742,
                                    0.6696387679198278,
                                    0.01570335837004704,
                                ],
                                [
                                    0.11091598669633101,
                                    0.1961803248348281,
                                    0.2502605645403551,
                                    0.44264312392848576,
                                ],
                                [
                                    0.11091598669633101,
                                    0.2502605645403551,
                                    0.1961803248348281,
                                    0.44264312392848576,
                                ],
                                [
                                    0.30744806540375946,
                                    0.6696387679198278,
                                    0.007209808306365742,
                                    0.01570335837004704,
                                ],
                                [
                                    0.09663027241061674,
                                    0.2180276012995085,
                                    0.2104660391205424,
                                    0.4748760871693324,
                                ],
                                [
                                    0.09663027241061674,
                                    0.2104660391205424,
                                    0.2180276012995085,
                                    0.4748760871693324,
                                ],
                                [
                                    0.3714986889208238,
                                    0.0017995892427564537,
                                    0.6236805300897501,
                                    0.003021191746669565,
                                ],
                                [
                                    0.3714986889208238,
                                    0.6236805300897501,
                                    0.0017995892427564537,
                                    0.003021191746669565,
                                ],
                                [
                                    0.3071991014925226,
                                    0.0014881134575099803,
                                    0.6879801175180513,
                                    0.0033326675319160387,
                                ],
                                [
                                    0.024119198647935602,
                                    0.0404918645656121,
                                    0.3491790795156447,
                                    0.5862098572708075,
                                ],
                                [
                                    0.024119198647935602,
                                    0.3491790795156447,
                                    0.0404918645656121,
                                    0.5862098572708075,
                                ],
                                [
                                    0.3071991014925226,
                                    0.6879801175180513,
                                    0.0014881134575099803,
                                    0.0033326675319160387,
                                ],
                                [
                                    0.019944609158350543,
                                    0.28874260579168204,
                                    0.04466645405519716,
                                    0.6466463309947702,
                                ],
                                [
                                    0.019944609158350543,
                                    0.04466645405519716,
                                    0.28874260579168204,
                                    0.6466463309947702,
                                ],
                                [
                                    0.23090277876164278,
                                    0.10233657701648166,
                                    0.4620009097071981,
                                    0.2047597345146774,
                                ],
                                [
                                    0.23090277876164278,
                                    0.4620009097071981,
                                    0.10233657701648166,
                                    0.2047597345146774,
                                ],
                                [
                                    0.227562441832769,
                                    0.10085613295592939,
                                    0.4653412466360719,
                                    0.2062401785752297,
                                ],
                                [
                                    0.20776535572895674,
                                    0.4157064885369105,
                                    0.12547400004916773,
                                    0.25105415568496503,
                                ],
                                [
                                    0.20776535572895674,
                                    0.12547400004916773,
                                    0.4157064885369105,
                                    0.25105415568496503,
                                ],
                                [
                                    0.227562441832769,
                                    0.4653412466360719,
                                    0.10085613295592939,
                                    0.2062401785752297,
                                ],
                                [
                                    0.20475973451467744,
                                    0.12365884027402096,
                                    0.4187121097511898,
                                    0.2528693154601118,
                                ],
                                [
                                    0.20475973451467744,
                                    0.4187121097511898,
                                    0.12365884027402096,
                                    0.2528693154601118,
                                ],
                                [
                                    0.26900063439259503,
                                    0.0763604483124235,
                                    0.509896143106667,
                                    0.14474277418831452,
                                ],
                                [
                                    0.26900063439259503,
                                    0.509896143106667,
                                    0.0763604483124235,
                                    0.14474277418831452,
                                ],
                                [
                                    0.2511536427060337,
                                    0.07129427332257211,
                                    0.5277431347932283,
                                    0.1498089491781659,
                                ],
                                [
                                    0.1550282036959098,
                                    0.29385909559578033,
                                    0.19033287900910872,
                                    0.36077982169920114,
                                ],
                                [
                                    0.1550282036959098,
                                    0.19033287900910872,
                                    0.29385909559578033,
                                    0.36077982169920114,
                                ],
                                [
                                    0.2511536427060337,
                                    0.5277431347932283,
                                    0.07129427332257211,
                                    0.1498089491781659,
                                ],
                                [
                                    0.14474277418831452,
                                    0.17770514184029126,
                                    0.3041445251033756,
                                    0.37340755886801863,
                                ],
                                [
                                    0.14474277418831452,
                                    0.3041445251033756,
                                    0.17770514184029126,
                                    0.37340755886801863,
                                ],
                                [
                                    0.3218421653923912,
                                    0.03933438584429492,
                                    0.5692515789007749,
                                    0.06957186986253894,
                                ],
                                [
                                    0.3218421653923912,
                                    0.5692515789007749,
                                    0.03933438584429492,
                                    0.06957186986253894,
                                ],
                                [
                                    0.2803896628556817,
                                    0.03426821085444353,
                                    0.6107040814374844,
                                    0.07463804485239033,
                                ],
                                [
                                    0.07985729937013421,
                                    0.14124592313060377,
                                    0.28131925186655193,
                                    0.49757752563271007,
                                ],
                                [
                                    0.07985729937013421,
                                    0.28131925186655193,
                                    0.14124592313060377,
                                    0.49757752563271007,
                                ],
                                [
                                    0.2803896628556817,
                                    0.6107040814374844,
                                    0.03426821085444353,
                                    0.07463804485239033,
                                ],
                                [
                                    0.06957186986253894,
                                    0.24508600384758628,
                                    0.15153135263819906,
                                    0.5338107736516757,
                                ],
                                [
                                    0.06957186986253894,
                                    0.15153135263819906,
                                    0.24508600384758628,
                                    0.5338107736516757,
                                ],
                                [
                                    0.3647448324960003,
                                    0.008553445667580022,
                                    0.6123420008275869,
                                    0.014359721008832774,
                                ],
                                [
                                    0.3647448324960003,
                                    0.6123420008275869,
                                    0.008553445667580022,
                                    0.014359721008832774,
                                ],
                                [
                                    0.30161421334300487,
                                    0.007073001607027761,
                                    0.6754726199805824,
                                    0.015840165069385036,
                                ],
                                [
                                    0.01736534222311207,
                                    0.029153335303448956,
                                    0.3559329359404682,
                                    0.5975483865329707,
                                ],
                                [
                                    0.01736534222311207,
                                    0.3559329359404682,
                                    0.029153335303448956,
                                    0.5975483865329707,
                                ],
                                [
                                    0.30161421334300487,
                                    0.6754726199805824,
                                    0.007073001607027761,
                                    0.015840165069385036,
                                ],
                                [
                                    0.014359721008832795,
                                    0.2943274939411998,
                                    0.03215895651772823,
                                    0.6591538285322391,
                                ],
                                [
                                    0.014359721008832795,
                                    0.03215895651772823,
                                    0.2943274939411998,
                                    0.6591538285322391,
                                ],
                                [
                                    0.12547400004916776,
                                    0.2077653557289567,
                                    0.25105415568496514,
                                    0.4157064885369104,
                                ],
                                [
                                    0.12547400004916776,
                                    0.25105415568496514,
                                    0.2077653557289567,
                                    0.4157064885369104,
                                ],
                                [
                                    0.123658840274021,
                                    0.2047597345146774,
                                    0.2528693154601119,
                                    0.4187121097511897,
                                ],
                                [
                                    0.10233657701648169,
                                    0.20475973451467744,
                                    0.23090277876164278,
                                    0.4620009097071981,
                                ],
                                [
                                    0.10233657701648169,
                                    0.23090277876164278,
                                    0.20475973451467744,
                                    0.4620009097071981,
                                ],
                                [
                                    0.123658840274021,
                                    0.2528693154601119,
                                    0.2047597345146774,
                                    0.4187121097511897,
                                ],
                                [
                                    0.1008561329559294,
                                    0.227562441832769,
                                    0.20624017857522972,
                                    0.4653412466360719,
                                ],
                                [
                                    0.1008561329559294,
                                    0.20624017857522972,
                                    0.227562441832769,
                                    0.4653412466360719,
                                ],
                                [
                                    0.19033287900910872,
                                    0.1550282036959098,
                                    0.36077982169920114,
                                    0.29385909559578033,
                                ],
                                [
                                    0.19033287900910872,
                                    0.36077982169920114,
                                    0.1550282036959098,
                                    0.29385909559578033,
                                ],
                                [
                                    0.17770514184029126,
                                    0.14474277418831452,
                                    0.37340755886801863,
                                    0.3041445251033756,
                                ],
                                [
                                    0.07636044831242349,
                                    0.1447427741883145,
                                    0.26900063439259503,
                                    0.509896143106667,
                                ],
                                [
                                    0.07636044831242349,
                                    0.26900063439259503,
                                    0.1447427741883145,
                                    0.509896143106667,
                                ],
                                [
                                    0.17770514184029126,
                                    0.37340755886801863,
                                    0.14474277418831452,
                                    0.3041445251033756,
                                ],
                                [
                                    0.07129427332257211,
                                    0.2511536427060337,
                                    0.1498089491781659,
                                    0.5277431347932283,
                                ],
                                [
                                    0.07129427332257211,
                                    0.1498089491781659,
                                    0.2511536427060337,
                                    0.5277431347932283,
                                ],
                                [
                                    0.28131925186655193,
                                    0.07985729937013422,
                                    0.49757752563271007,
                                    0.1412459231306038,
                                ],
                                [
                                    0.28131925186655193,
                                    0.49757752563271007,
                                    0.07985729937013422,
                                    0.1412459231306038,
                                ],
                                [
                                    0.24508600384758628,
                                    0.06957186986253894,
                                    0.5338107736516757,
                                    0.15153135263819908,
                                ],
                                [
                                    0.039334385844294925,
                                    0.06957186986253895,
                                    0.3218421653923912,
                                    0.5692515789007749,
                                ],
                                [
                                    0.039334385844294925,
                                    0.3218421653923912,
                                    0.06957186986253895,
                                    0.5692515789007749,
                                ],
                                [
                                    0.24508600384758628,
                                    0.5338107736516757,
                                    0.06957186986253894,
                                    0.15153135263819908,
                                ],
                                [
                                    0.03426821085444354,
                                    0.2803896628556817,
                                    0.07463804485239034,
                                    0.6107040814374844,
                                ],
                                [
                                    0.03426821085444354,
                                    0.07463804485239034,
                                    0.2803896628556817,
                                    0.6107040814374844,
                                ],
                                [
                                    0.35593293594046826,
                                    0.01736534222311205,
                                    0.5975483865329708,
                                    0.02915333530344892,
                                ],
                                [
                                    0.35593293594046826,
                                    0.5975483865329708,
                                    0.01736534222311205,
                                    0.02915333530344892,
                                ],
                                [
                                    0.29432749394119984,
                                    0.014359721008832777,
                                    0.6591538285322392,
                                    0.032158956517728196,
                                ],
                                [
                                    0.008553445667580045,
                                    0.01435972100883281,
                                    0.36474483249600026,
                                    0.6123420008275869,
                                ],
                                [
                                    0.008553445667580045,
                                    0.36474483249600026,
                                    0.01435972100883281,
                                    0.6123420008275869,
                                ],
                                [
                                    0.29432749394119984,
                                    0.6591538285322392,
                                    0.014359721008832777,
                                    0.032158956517728196,
                                ],
                                [
                                    0.0070730016070277785,
                                    0.3016142133430048,
                                    0.015840165069385077,
                                    0.6754726199805823,
                                ],
                                [
                                    0.0070730016070277785,
                                    0.015840165069385077,
                                    0.3016142133430048,
                                    0.6754726199805823,
                                ],
                                [
                                    0.0446683721141084,
                                    0.28857098366401607,
                                    0.08937453530241307,
                                    0.5773861089194624,
                                ],
                                [
                                    0.0446683721141084,
                                    0.08937453530241307,
                                    0.28857098366401607,
                                    0.5773861089194624,
                                ],
                                [
                                    0.04402218061426744,
                                    0.28439639417443097,
                                    0.09002072680225404,
                                    0.5815606984090476,
                                ],
                                [
                                    0.021530949081422314,
                                    0.04308011413212539,
                                    0.31170840669670213,
                                    0.6236805300897501,
                                ],
                                [
                                    0.021530949081422314,
                                    0.31170840669670213,
                                    0.04308011413212539,
                                    0.6236805300897501,
                                ],
                                [
                                    0.04402218061426744,
                                    0.09002072680225404,
                                    0.28439639417443097,
                                    0.5815606984090476,
                                ],
                                [
                                    0.021219473296175836,
                                    0.30719910149252255,
                                    0.04339158991737187,
                                    0.6281898352939297,
                                ],
                                [
                                    0.021219473296175836,
                                    0.04339158991737187,
                                    0.30719910149252255,
                                    0.6281898352939297,
                                ],
                                [
                                    0.13003817153326397,
                                    0.21532291117175456,
                                    0.24648998420086893,
                                    0.40814893309411254,
                                ],
                                [
                                    0.13003817153326397,
                                    0.24648998420086893,
                                    0.21532291117175456,
                                    0.40814893309411254,
                                ],
                                [
                                    0.12141071914256549,
                                    0.2010371968860403,
                                    0.25511743659156744,
                                    0.4224346473798268,
                                ],
                                [
                                    0.01606574083657873,
                                    0.030452936689982297,
                                    0.3292953418684398,
                                    0.6241859806049992,
                                ],
                                [
                                    0.01606574083657873,
                                    0.3292953418684398,
                                    0.030452936689982297,
                                    0.6241859806049992,
                                ],
                                [
                                    0.12141071914256549,
                                    0.25511743659156744,
                                    0.2010371968860403,
                                    0.4224346473798268,
                                ],
                                [
                                    0.01499985062484634,
                                    0.30744806540375946,
                                    0.03151882690171468,
                                    0.6460332570696795,
                                ],
                                [
                                    0.01499985062484634,
                                    0.03151882690171468,
                                    0.30744806540375946,
                                    0.6460332570696795,
                                ],
                                [
                                    0.2502605645403551,
                                    0.110915986696331,
                                    0.44264312392848576,
                                    0.19618032483482808,
                                ],
                                [
                                    0.2502605645403551,
                                    0.44264312392848576,
                                    0.110915986696331,
                                    0.19618032483482808,
                                ],
                                [
                                    0.2180276012995085,
                                    0.09663027241061672,
                                    0.4748760871693324,
                                    0.21046603912054235,
                                ],
                                [
                                    0.008275698518098156,
                                    0.014637468158314699,
                                    0.35290085271858795,
                                    0.6241859806049992,
                                ],
                                [
                                    0.008275698518098156,
                                    0.35290085271858795,
                                    0.014637468158314699,
                                    0.6241859806049992,
                                ],
                                [
                                    0.2180276012995085,
                                    0.4748760871693324,
                                    0.09663027241061672,
                                    0.21046603912054235,
                                ],
                                [
                                    0.007209808306365766,
                                    0.30744806540375946,
                                    0.01570335837004709,
                                    0.6696387679198277,
                                ],
                                [
                                    0.007209808306365766,
                                    0.01570335837004709,
                                    0.30744806540375946,
                                    0.6696387679198277,
                                ],
                                [
                                    0.3491790795156447,
                                    0.024119198647935616,
                                    0.5862098572708075,
                                    0.04049186456561213,
                                ],
                                [
                                    0.3491790795156447,
                                    0.5862098572708075,
                                    0.024119198647935616,
                                    0.04049186456561213,
                                ],
                                [
                                    0.28874260579168204,
                                    0.019944609158350557,
                                    0.6466463309947702,
                                    0.04466645405519719,
                                ],
                                [
                                    0.0017995892427564713,
                                    0.003021191746669594,
                                    0.3714986889208238,
                                    0.6236805300897501,
                                ],
                                [
                                    0.0017995892427564713,
                                    0.3714986889208238,
                                    0.003021191746669594,
                                    0.6236805300897501,
                                ],
                                [
                                    0.28874260579168204,
                                    0.6466463309947702,
                                    0.019944609158350557,
                                    0.04466645405519719,
                                ],
                                [
                                    0.0014881134575099946,
                                    0.3071991014925226,
                                    0.0033326675319160707,
                                    0.6879801175180513,
                                ],
                                [
                                    0.0014881134575099946,
                                    0.0033326675319160707,
                                    0.3071991014925226,
                                    0.6879801175180513,
                                ],
                                [
                                    0.06914199475592152,
                                    0.004775914721883774,
                                    0.8662469420305308,
                                    0.059835148491663916,
                                ],
                                [
                                    0.06914199475592152,
                                    0.8662469420305308,
                                    0.004775914721883774,
                                    0.059835148491663916,
                                ],
                                [
                                    0.06463268955174194,
                                    0.0044644389366372975,
                                    0.8707562472347103,
                                    0.06014662427691039,
                                ],
                                [
                                    0.06400973798124902,
                                    0.8019473546022295,
                                    0.009908171496556267,
                                    0.12413473591996516,
                                ],
                                [
                                    0.06400973798124902,
                                    0.009908171496556267,
                                    0.8019473546022295,
                                    0.12413473591996516,
                                ],
                                [
                                    0.06463268955174194,
                                    0.8707562472347103,
                                    0.0044644389366372975,
                                    0.06014662427691039,
                                ],
                                [
                                    0.05983514849166393,
                                    0.009261979996715302,
                                    0.8061219440918146,
                                    0.12478092741980612,
                                ],
                                [
                                    0.05983514849166393,
                                    0.8061219440918146,
                                    0.009261979996715302,
                                    0.12478092741980612,
                                ],
                                [
                                    0.08653234640134658,
                                    0.004221761059166464,
                                    0.8669489760720925,
                                    0.042296916467394474,
                                ],
                                [
                                    0.08653234640134658,
                                    0.8669489760720925,
                                    0.004221761059166464,
                                    0.042296916467394474,
                                ],
                                [
                                    0.06468506993666623,
                                    0.003155870847434078,
                                    0.8887962525367729,
                                    0.043362806679126856,
                                ],
                                [
                                    0.056582630753108765,
                                    0.5668892135127584,
                                    0.03417147670740428,
                                    0.3423566790267285,
                                ],
                                [
                                    0.056582630753108765,
                                    0.03417147670740428,
                                    0.5668892135127584,
                                    0.3423566790267285,
                                ],
                                [
                                    0.06468506993666623,
                                    0.8887962525367729,
                                    0.003155870847434078,
                                    0.043362806679126856,
                                ],
                                [
                                    0.0422969164673945,
                                    0.0255440243167058,
                                    0.5811749277984727,
                                    0.350984131417427,
                                ],
                                [
                                    0.0422969164673945,
                                    0.5811749277984727,
                                    0.0255440243167058,
                                    0.350984131417427,
                                ],
                                [
                                    0.11013785725149472,
                                    0.002582786907487371,
                                    0.8669489760720925,
                                    0.02033037976892541,
                                ],
                                [
                                    0.11013785725149472,
                                    0.8669489760720925,
                                    0.002582786907487371,
                                    0.02033037976892541,
                                ],
                                [
                                    0.06468506993666619,
                                    0.0015168966957549836,
                                    0.912401763386921,
                                    0.021396269980657794,
                                ],
                                [
                                    0.034616094054639696,
                                    0.27248021747651946,
                                    0.07810455010434239,
                                    0.6147991383644985,
                                ],
                                [
                                    0.034616094054639696,
                                    0.07810455010434239,
                                    0.27248021747651946,
                                    0.6147991383644985,
                                ],
                                [
                                    0.06468506993666619,
                                    0.912401763386921,
                                    0.0015168966957549836,
                                    0.021396269980657794,
                                ],
                                [
                                    0.020330379768925412,
                                    0.04587158686349576,
                                    0.2867659317622337,
                                    0.6470321016053451,
                                ],
                                [
                                    0.020330379768925412,
                                    0.2867659317622337,
                                    0.04587158686349576,
                                    0.6470321016053451,
                                ],
                                [
                                    0.1289322769800432,
                                    0.0006245651616467266,
                                    0.8662469420305308,
                                    0.004196215827779292,
                                ],
                                [
                                    0.1289322769800432,
                                    0.8662469420305308,
                                    0.0006245651616467266,
                                    0.004196215827779292,
                                ],
                                [
                                    0.06463268955174198,
                                    0.00031308937640025304,
                                    0.930546529458832,
                                    0.004507691613025766,
                                ],
                                [
                                    0.00837080531736435,
                                    0.05624025789618335,
                                    0.12118603682432559,
                                    0.8142028999621267,
                                ],
                                [
                                    0.00837080531736435,
                                    0.12118603682432559,
                                    0.05624025789618335,
                                    0.8142028999621267,
                                ],
                                [
                                    0.06463268955174198,
                                    0.930546529458832,
                                    0.00031308937640025304,
                                    0.004507691613025766,
                                ],
                                [
                                    0.004196215827779293,
                                    0.06074956310036295,
                                    0.06041484738576841,
                                    0.8746393736860893,
                                ],
                                [
                                    0.004196215827779293,
                                    0.06041484738576841,
                                    0.06074956310036295,
                                    0.8746393736860893,
                                ],
                                [
                                    0.05121799212107718,
                                    0.022699917356728112,
                                    0.6416856963477637,
                                    0.28439639417443097,
                                ],
                                [
                                    0.05121799212107718,
                                    0.6416856963477637,
                                    0.022699917356728112,
                                    0.28439639417443097,
                                ],
                                [
                                    0.0478776551922034,
                                    0.021219473296175836,
                                    0.6450260332766374,
                                    0.2858768382349832,
                                ],
                                [
                                    0.04608573534640469,
                                    0.5773861089194625,
                                    0.027832174131400603,
                                    0.3486959816027322,
                                ],
                                [
                                    0.04608573534640469,
                                    0.027832174131400603,
                                    0.5773861089194625,
                                    0.3486959816027322,
                                ],
                                [
                                    0.0478776551922034,
                                    0.6450260332766374,
                                    0.021219473296175836,
                                    0.2858768382349832,
                                ],
                                [
                                    0.0430801141321254,
                                    0.02601701435625384,
                                    0.5803917301337418,
                                    0.3505111413778789,
                                ],
                                [
                                    0.0430801141321254,
                                    0.5803917301337418,
                                    0.02601701435625384,
                                    0.3505111413778789,
                                ],
                                [
                                    0.07068808184581535,
                                    0.020066025614697704,
                                    0.7082086956534467,
                                    0.20103719688604033,
                                ],
                                [
                                    0.07068808184581535,
                                    0.7082086956534467,
                                    0.020066025614697704,
                                    0.20103719688604033,
                                ],
                                [
                                    0.05284109015925398,
                                    0.01499985062484632,
                                    0.726055687340008,
                                    0.2061033718758917,
                                ],
                                [
                                    0.04073836619757753,
                                    0.4081489330941126,
                                    0.050015741262935516,
                                    0.5010969594453744,
                                ],
                                [
                                    0.04073836619757753,
                                    0.050015741262935516,
                                    0.4081489330941126,
                                    0.5010969594453744,
                                ],
                                [
                                    0.05284109015925398,
                                    0.726055687340008,
                                    0.01499985062484632,
                                    0.2061033718758917,
                                ],
                                [
                                    0.03045293668998226,
                                    0.03738800409411804,
                                    0.41843436260170785,
                                    0.5137246966141918,
                                ],
                                [
                                    0.03045293668998226,
                                    0.41843436260170785,
                                    0.03738800409411804,
                                    0.5137246966141918,
                                ],
                                [
                                    0.10044466086276495,
                                    0.01227598329621713,
                                    0.7906490834304012,
                                    0.09663027241061672,
                                ],
                                [
                                    0.10044466086276495,
                                    0.7906490834304012,
                                    0.01227598329621713,
                                    0.09663027241061672,
                                ],
                                [
                                    0.05899215832605543,
                                    0.0072098083063657425,
                                    0.8321015859671107,
                                    0.10169644740046811,
                                ],
                                [
                                    0.024922897665909927,
                                    0.19618032483482806,
                                    0.08779774649307216,
                                    0.6910990310061899,
                                ],
                                [
                                    0.024922897665909927,
                                    0.08779774649307216,
                                    0.19618032483482806,
                                    0.6910990310061899,
                                ],
                                [
                                    0.05899215832605543,
                                    0.8321015859671107,
                                    0.0072098083063657425,
                                    0.10169644740046811,
                                ],
                                [
                                    0.01463746815831465,
                                    0.05156449847410652,
                                    0.20646575434242334,
                                    0.7273322790251555,
                                ],
                                [
                                    0.01463746815831465,
                                    0.20646575434242334,
                                    0.05156449847410652,
                                    0.7273322790251555,
                                ],
                                [
                                    0.1265882846236277,
                                    0.002968557518062243,
                                    0.8504985486999596,
                                    0.019944609158350553,
                                ],
                                [
                                    0.1265882846236277,
                                    0.8504985486999596,
                                    0.002968557518062243,
                                    0.019944609158350553,
                                ],
                                [
                                    0.06345766547063227,
                                    0.0014881134575099812,
                                    0.913629167852955,
                                    0.021425053218902815,
                                ],
                                [
                                    0.006026812960948846,
                                    0.04049186456561218,
                                    0.1235300291807411,
                                    0.8299512932926979,
                                ],
                                [
                                    0.006026812960948846,
                                    0.1235300291807411,
                                    0.04049186456561218,
                                    0.8299512932926979,
                                ],
                                [
                                    0.06345766547063227,
                                    0.913629167852955,
                                    0.0014881134575099812,
                                    0.021425053218902815,
                                ],
                                [
                                    0.003021191746669571,
                                    0.061924587181472666,
                                    0.04349748577989145,
                                    0.8915567352919663,
                                ],
                                [
                                    0.003021191746669571,
                                    0.04349748577989145,
                                    0.061924587181472666,
                                    0.8915567352919663,
                                ],
                                [
                                    0.02783217413140061,
                                    0.046085735346404685,
                                    0.3486959816027323,
                                    0.5773861089194624,
                                ],
                                [
                                    0.02783217413140061,
                                    0.3486959816027323,
                                    0.046085735346404685,
                                    0.5773861089194624,
                                ],
                                [
                                    0.026017014356253847,
                                    0.04308011413212539,
                                    0.35051114137787903,
                                    0.5803917301337417,
                                ],
                                [
                                    0.022699917356728116,
                                    0.284396394174431,
                                    0.05121799212107718,
                                    0.6416856963477637,
                                ],
                                [
                                    0.022699917356728116,
                                    0.05121799212107718,
                                    0.284396394174431,
                                    0.6416856963477637,
                                ],
                                [
                                    0.026017014356253847,
                                    0.35051114137787903,
                                    0.04308011413212539,
                                    0.5803917301337417,
                                ],
                                [
                                    0.02121947329617584,
                                    0.0478776551922034,
                                    0.2858768382349833,
                                    0.6450260332766374,
                                ],
                                [
                                    0.02121947329617584,
                                    0.2858768382349833,
                                    0.0478776551922034,
                                    0.6450260332766374,
                                ],
                                [
                                    0.050015741262935516,
                                    0.04073836619757753,
                                    0.5010969594453744,
                                    0.4081489330941126,
                                ],
                                [
                                    0.050015741262935516,
                                    0.5010969594453744,
                                    0.04073836619757753,
                                    0.4081489330941126,
                                ],
                                [
                                    0.03738800409411804,
                                    0.03045293668998226,
                                    0.5137246966141918,
                                    0.41843436260170785,
                                ],
                                [
                                    0.0200660256146977,
                                    0.2010371968860403,
                                    0.07068808184581535,
                                    0.7082086956534467,
                                ],
                                [
                                    0.0200660256146977,
                                    0.07068808184581535,
                                    0.2010371968860403,
                                    0.7082086956534467,
                                ],
                                [
                                    0.03738800409411804,
                                    0.5137246966141918,
                                    0.03045293668998226,
                                    0.41843436260170785,
                                ],
                                [
                                    0.014999850624846319,
                                    0.05284109015925398,
                                    0.20610337187589167,
                                    0.726055687340008,
                                ],
                                [
                                    0.014999850624846319,
                                    0.20610337187589167,
                                    0.05284109015925398,
                                    0.726055687340008,
                                ],
                                [
                                    0.08779774649307216,
                                    0.02492289766590993,
                                    0.6910990310061899,
                                    0.19618032483482808,
                                ],
                                [
                                    0.08779774649307216,
                                    0.6910990310061899,
                                    0.02492289766590993,
                                    0.19618032483482808,
                                ],
                                [
                                    0.05156449847410652,
                                    0.014637468158314652,
                                    0.7273322790251555,
                                    0.20646575434242337,
                                ],
                                [
                                    0.012275983296217133,
                                    0.09663027241061674,
                                    0.10044466086276495,
                                    0.7906490834304012,
                                ],
                                [
                                    0.012275983296217133,
                                    0.10044466086276495,
                                    0.09663027241061674,
                                    0.7906490834304012,
                                ],
                                [
                                    0.05156449847410652,
                                    0.7273322790251555,
                                    0.014637468158314652,
                                    0.20646575434242337,
                                ],
                                [
                                    0.007209808306365744,
                                    0.05899215832605543,
                                    0.10169644740046813,
                                    0.8321015859671107,
                                ],
                                [
                                    0.007209808306365744,
                                    0.10169644740046813,
                                    0.05899215832605543,
                                    0.8321015859671107,
                                ],
                                [
                                    0.12353002918074112,
                                    0.006026812960948839,
                                    0.829951293292698,
                                    0.04049186456561213,
                                ],
                                [
                                    0.12353002918074112,
                                    0.829951293292698,
                                    0.006026812960948839,
                                    0.04049186456561213,
                                ],
                                [
                                    0.06192458718147267,
                                    0.003021191746669567,
                                    0.8915567352919664,
                                    0.043497485779891404,
                                ],
                                [
                                    0.002968557518062251,
                                    0.019944609158350605,
                                    0.1265882846236277,
                                    0.8504985486999594,
                                ],
                                [
                                    0.002968557518062251,
                                    0.1265882846236277,
                                    0.019944609158350605,
                                    0.8504985486999594,
                                ],
                                [
                                    0.06192458718147267,
                                    0.8915567352919664,
                                    0.003021191746669567,
                                    0.043497485779891404,
                                ],
                                [
                                    0.0014881134575099849,
                                    0.06345766547063225,
                                    0.02142505321890287,
                                    0.9136291678529549,
                                ],
                                [
                                    0.0014881134575099849,
                                    0.02142505321890287,
                                    0.06345766547063225,
                                    0.9136291678529549,
                                ],
                                [
                                    0.00990817149655627,
                                    0.06400973798124902,
                                    0.1241347359199652,
                                    0.8019473546022295,
                                ],
                                [
                                    0.00990817149655627,
                                    0.1241347359199652,
                                    0.06400973798124902,
                                    0.8019473546022295,
                                ],
                                [
                                    0.009261979996715306,
                                    0.05983514849166393,
                                    0.12478092741980616,
                                    0.8061219440918146,
                                ],
                                [
                                    0.004775914721883775,
                                    0.05983514849166393,
                                    0.06914199475592152,
                                    0.8662469420305308,
                                ],
                                [
                                    0.004775914721883775,
                                    0.06914199475592152,
                                    0.05983514849166393,
                                    0.8662469420305308,
                                ],
                                [
                                    0.009261979996715306,
                                    0.12478092741980616,
                                    0.05983514849166393,
                                    0.8061219440918146,
                                ],
                                [
                                    0.004464438936637298,
                                    0.06463268955174194,
                                    0.06014662427691041,
                                    0.8707562472347103,
                                ],
                                [
                                    0.004464438936637298,
                                    0.06014662427691041,
                                    0.06463268955174194,
                                    0.8707562472347103,
                                ],
                                [
                                    0.03417147670740429,
                                    0.05658263075310876,
                                    0.3423566790267286,
                                    0.5668892135127583,
                                ],
                                [
                                    0.03417147670740429,
                                    0.3423566790267286,
                                    0.05658263075310876,
                                    0.5668892135127583,
                                ],
                                [
                                    0.025544024316705806,
                                    0.042296916467394495,
                                    0.35098413141742707,
                                    0.5811749277984726,
                                ],
                                [
                                    0.004221761059166472,
                                    0.04229691646739455,
                                    0.08653234640134658,
                                    0.8669489760720924,
                                ],
                                [
                                    0.004221761059166472,
                                    0.08653234640134658,
                                    0.04229691646739455,
                                    0.8669489760720924,
                                ],
                                [
                                    0.025544024316705806,
                                    0.35098413141742707,
                                    0.042296916467394495,
                                    0.5811749277984726,
                                ],
                                [
                                    0.003155870847434084,
                                    0.06468506993666621,
                                    0.04336280667912694,
                                    0.8887962525367727,
                                ],
                                [
                                    0.003155870847434084,
                                    0.04336280667912694,
                                    0.06468506993666621,
                                    0.8887962525367727,
                                ],
                                [
                                    0.07810455010434239,
                                    0.03461609405463969,
                                    0.6147991383644985,
                                    0.2724802174765194,
                                ],
                                [
                                    0.07810455010434239,
                                    0.6147991383644985,
                                    0.03461609405463969,
                                    0.2724802174765194,
                                ],
                                [
                                    0.04587158686349576,
                                    0.02033037976892541,
                                    0.6470321016053451,
                                    0.28676593176223364,
                                ],
                                [
                                    0.0025827869074873796,
                                    0.020330379768925474,
                                    0.1101378572514947,
                                    0.8669489760720924,
                                ],
                                [
                                    0.0025827869074873796,
                                    0.1101378572514947,
                                    0.020330379768925474,
                                    0.8669489760720924,
                                ],
                                [
                                    0.04587158686349576,
                                    0.6470321016053451,
                                    0.02033037976892541,
                                    0.28676593176223364,
                                ],
                                [
                                    0.0015168966957549886,
                                    0.06468506993666619,
                                    0.021396269980657866,
                                    0.9124017633869209,
                                ],
                                [
                                    0.0015168966957549886,
                                    0.021396269980657866,
                                    0.06468506993666619,
                                    0.9124017633869209,
                                ],
                                [
                                    0.12118603682432559,
                                    0.008370805317364356,
                                    0.8142028999621267,
                                    0.05624025789618339,
                                ],
                                [
                                    0.12118603682432559,
                                    0.8142028999621267,
                                    0.008370805317364356,
                                    0.05624025789618339,
                                ],
                                [
                                    0.06074956310036295,
                                    0.004196215827779295,
                                    0.8746393736860893,
                                    0.06041484738576845,
                                ],
                                [
                                    0.0006245651616467327,
                                    0.004196215827779333,
                                    0.1289322769800432,
                                    0.8662469420305308,
                                ],
                                [
                                    0.0006245651616467327,
                                    0.1289322769800432,
                                    0.004196215827779333,
                                    0.8662469420305308,
                                ],
                                [
                                    0.06074956310036295,
                                    0.8746393736860893,
                                    0.004196215827779295,
                                    0.06041484738576845,
                                ],
                                [
                                    0.0003130893764002561,
                                    0.06463268955174198,
                                    0.004507691613025809,
                                    0.930546529458832,
                                ],
                                [
                                    0.0003130893764002561,
                                    0.004507691613025809,
                                    0.06463268955174198,
                                    0.930546529458832,
                                ],
                                [
                                    0.87193127131582,
                                    0.06022778790007964,
                                    0.06345766547063221,
                                    0.004383275313468047,
                                ],
                                [
                                    0.87193127131582,
                                    0.06345766547063221,
                                    0.06022778790007964,
                                    0.004383275313468047,
                                ],
                                [
                                    0.8504985486999596,
                                    0.05874734383952738,
                                    0.08489038808649274,
                                    0.0058637193740203085,
                                ],
                                [
                                    0.8072097487439511,
                                    0.05874734383952739,
                                    0.12494931047194854,
                                    0.009093596944572863,
                                ],
                                [
                                    0.8072097487439511,
                                    0.12494931047194854,
                                    0.05874734383952739,
                                    0.009093596944572863,
                                ],
                                [
                                    0.8504985486999596,
                                    0.08489038808649274,
                                    0.05874734383952738,
                                    0.0058637193740203085,
                                ],
                                [
                                    0.7873679295469641,
                                    0.12187796299252283,
                                    0.07858916303651445,
                                    0.012164944423998585,
                                ],
                                [
                                    0.7873679295469641,
                                    0.07858916303651445,
                                    0.12187796299252283,
                                    0.012164944423998585,
                                ],
                                [
                                    0.8944891641473837,
                                    0.04364055382860875,
                                    0.05899215832605542,
                                    0.0028781236979521898,
                                ],
                                [
                                    0.8944891641473837,
                                    0.05899215832605542,
                                    0.04364055382860875,
                                    0.0028781236979521898,
                                ],
                                [
                                    0.7906490834304012,
                                    0.038574378838757355,
                                    0.16283223904303787,
                                    0.00794429868780358,
                                ],
                                [
                                    0.5848974654271099,
                                    0.038574378838757355,
                                    0.3532322525488825,
                                    0.023295903185250252,
                                ],
                                [
                                    0.5848974654271099,
                                    0.3532322525488825,
                                    0.038574378838757355,
                                    0.023295903185250252,
                                ],
                                [
                                    0.7906490834304012,
                                    0.16283223904303787,
                                    0.038574378838757355,
                                    0.00794429868780358,
                                ],
                                [
                                    0.5169974813294801,
                                    0.3122259809396785,
                                    0.10647436293638718,
                                    0.06430217479445427,
                                ],
                                [
                                    0.5169974813294801,
                                    0.10647436293638718,
                                    0.3122259809396785,
                                    0.06430217479445427,
                                ],
                                [
                                    0.9242457431643334,
                                    0.02167401713013968,
                                    0.052841090159253944,
                                    0.0012391495462730974,
                                ],
                                [
                                    0.9242457431643334,
                                    0.052841090159253944,
                                    0.02167401713013968,
                                    0.0012391495462730974,
                                ],
                                [
                                    0.7082086956534467,
                                    0.016607842140288293,
                                    0.26887813767014057,
                                    0.006305324536124488,
                                ],
                                [
                                    0.29048846939087086,
                                    0.016607842140288293,
                                    0.6554312909036022,
                                    0.03747239756523875,
                                ],
                                [
                                    0.29048846939087086,
                                    0.6554312909036022,
                                    0.016607842140288293,
                                    0.03747239756523875,
                                ],
                                [
                                    0.7082086956534467,
                                    0.26887813767014057,
                                    0.016607842140288293,
                                    0.006305324536124488,
                                ],
                                [
                                    0.22258848529324102,
                                    0.502228052500494,
                                    0.08450782623791812,
                                    0.1906756359683469,
                                ],
                                [
                                    0.22258848529324102,
                                    0.08450782623791812,
                                    0.502228052500494,
                                    0.1906756359683469,
                                ],
                                [
                                    0.9473015638183706,
                                    0.004588855236195017,
                                    0.04787765519220339,
                                    0.00023192575323100238,
                                ],
                                [
                                    0.9473015638183706,
                                    0.04787765519220339,
                                    0.004588855236195017,
                                    0.00023192575323100238,
                                ],
                                [
                                    0.6416856963477637,
                                    0.0031084111756427544,
                                    0.3534935226628102,
                                    0.0017123698137832641,
                                ],
                                [
                                    0.061502652037904955,
                                    0.003108411175642752,
                                    0.8903877670166607,
                                    0.04500116976979165,
                                ],
                                [
                                    0.061502652037904955,
                                    0.8903877670166607,
                                    0.003108411175642752,
                                    0.04500116976979165,
                                ],
                                [
                                    0.6416856963477637,
                                    0.3534935226628102,
                                    0.0031084111756427544,
                                    0.0017123698137832641,
                                ],
                                [
                                    0.04166083284091789,
                                    0.6031332746824886,
                                    0.022950230372629808,
                                    0.3322556621039636,
                                ],
                                [
                                    0.04166083284091789,
                                    0.022950230372629808,
                                    0.6031332746824886,
                                    0.3322556621039636,
                                ],
                                [
                                    0.6458964503703416,
                                    0.2862626088455581,
                                    0.047007238098499285,
                                    0.020833702685600967,
                                ],
                                [
                                    0.6458964503703416,
                                    0.047007238098499285,
                                    0.2862626088455581,
                                    0.020833702685600967,
                                ],
                                [
                                    0.6300198326657538,
                                    0.27922605987373306,
                                    0.06288385580308704,
                                    0.027870251657426,
                                ],
                                [
                                    0.5811749277984727,
                                    0.042296916467394474,
                                    0.350984131417427,
                                    0.02554402431670578,
                                ],
                                [
                                    0.5811749277984727,
                                    0.350984131417427,
                                    0.042296916467394474,
                                    0.02554402431670578,
                                ],
                                [
                                    0.6300198326657538,
                                    0.06288385580308704,
                                    0.27922605987373306,
                                    0.027870251657426,
                                ],
                                [
                                    0.5668892135127584,
                                    0.3423566790267285,
                                    0.056582630753108765,
                                    0.03417147670740428,
                                ],
                                [
                                    0.5668892135127584,
                                    0.056582630753108765,
                                    0.3423566790267285,
                                    0.03417147670740428,
                                ],
                                [
                                    0.730706214207792,
                                    0.20742350376820046,
                                    0.04819056329147004,
                                    0.013679718732537566,
                                ],
                                [
                                    0.730706214207792,
                                    0.04819056329147004,
                                    0.20742350376820046,
                                    0.013679718732537566,
                                ],
                                [
                                    0.6458794825882285,
                                    0.1833439796809301,
                                    0.13301729491103353,
                                    0.03775924281980792,
                                ],
                                [
                                    0.42111451548751816,
                                    0.027772783804171978,
                                    0.5170152024884742,
                                    0.034097498219835626,
                                ],
                                [
                                    0.42111451548751816,
                                    0.5170152024884742,
                                    0.027772783804171978,
                                    0.034097498219835626,
                                ],
                                [
                                    0.6458794825882285,
                                    0.13301729491103353,
                                    0.1833439796809301,
                                    0.03775924281980792,
                                ],
                                [
                                    0.3722278804873073,
                                    0.45699558178185123,
                                    0.07665941880438285,
                                    0.0941171189264586,
                                ],
                                [
                                    0.3722278804873073,
                                    0.07665941880438285,
                                    0.45699558178185123,
                                    0.0941171189264586,
                                ],
                                [
                                    0.8429031810016961,
                                    0.10301657929277686,
                                    0.04819056329147004,
                                    0.005889676414056997,
                                ],
                                [
                                    0.8429031810016961,
                                    0.04819056329147004,
                                    0.10301657929277686,
                                    0.005889676414056997,
                                ],
                                [
                                    0.6458794825882285,
                                    0.0789370552055065,
                                    0.24521426170493768,
                                    0.02996920050132735,
                                ],
                                [
                                    0.20914590722823362,
                                    0.01195731527250439,
                                    0.7367738530662394,
                                    0.04212292443302265,
                                ],
                                [
                                    0.20914590722823362,
                                    0.7367738530662394,
                                    0.01195731527250439,
                                    0.04212292443302265,
                                ],
                                [
                                    0.6458794825882285,
                                    0.24521426170493768,
                                    0.0789370552055065,
                                    0.02996920050132735,
                                ],
                                [
                                    0.16025927222802275,
                                    0.5645572655657123,
                                    0.06084395027271525,
                                    0.2143395119335498,
                                ],
                                [
                                    0.16025927222802275,
                                    0.06084395027271525,
                                    0.5645572655657123,
                                    0.2143395119335498,
                                ],
                                [
                                    0.930079595225088,
                                    0.021810823829477684,
                                    0.047007238098499285,
                                    0.0011023428469351115,
                                ],
                                [
                                    0.930079595225088,
                                    0.047007238098499285,
                                    0.021810823829477684,
                                    0.0011023428469351115,
                                ],
                                [
                                    0.6300198326657539,
                                    0.014774274857652647,
                                    0.3470670006578333,
                                    0.008138891818760147,
                                ],
                                [
                                    0.044280683444622375,
                                    0.0022379940819386474,
                                    0.9076097356099433,
                                    0.045871586863495746,
                                ],
                                [
                                    0.044280683444622375,
                                    0.9076097356099433,
                                    0.0022379940819386474,
                                    0.045871586863495746,
                                ],
                                [
                                    0.6300198326657539,
                                    0.3470670006578333,
                                    0.014774274857652647,
                                    0.008138891818760147,
                                ],
                                [
                                    0.029994969158908064,
                                    0.6147991383644984,
                                    0.016523708367652958,
                                    0.3386821841089405,
                                ],
                                [
                                    0.029994969158908064,
                                    0.016523708367652958,
                                    0.6147991383644984,
                                    0.3386821841089405,
                                ],
                                [
                                    0.35098413141742707,
                                    0.5811749277984726,
                                    0.025544024316705792,
                                    0.04229691646739447,
                                ],
                                [
                                    0.35098413141742707,
                                    0.025544024316705792,
                                    0.5811749277984726,
                                    0.04229691646739447,
                                ],
                                [
                                    0.3423566790267286,
                                    0.5668892135127583,
                                    0.03417147670740429,
                                    0.05658263075310876,
                                ],
                                [
                                    0.28626260884555815,
                                    0.02083370268560097,
                                    0.6458964503703416,
                                    0.047007238098499285,
                                ],
                                [
                                    0.28626260884555815,
                                    0.6458964503703416,
                                    0.02083370268560097,
                                    0.047007238098499285,
                                ],
                                [
                                    0.3423566790267286,
                                    0.03417147670740429,
                                    0.5668892135127583,
                                    0.05658263075310876,
                                ],
                                [
                                    0.2792260598737331,
                                    0.6300198326657538,
                                    0.027870251657426008,
                                    0.06288385580308704,
                                ],
                                [
                                    0.2792260598737331,
                                    0.027870251657426008,
                                    0.6300198326657538,
                                    0.06288385580308704,
                                ],
                                [
                                    0.5170152024884742,
                                    0.42111451548751816,
                                    0.034097498219835626,
                                    0.027772783804171978,
                                ],
                                [
                                    0.5170152024884742,
                                    0.034097498219835626,
                                    0.42111451548751816,
                                    0.027772783804171978,
                                ],
                                [
                                    0.45699558178185123,
                                    0.3722278804873073,
                                    0.0941171189264586,
                                    0.07665941880438285,
                                ],
                                [
                                    0.20742350376820043,
                                    0.013679718732537564,
                                    0.730706214207792,
                                    0.04819056329147004,
                                ],
                                [
                                    0.20742350376820043,
                                    0.730706214207792,
                                    0.013679718732537564,
                                    0.04819056329147004,
                                ],
                                [
                                    0.45699558178185123,
                                    0.0941171189264586,
                                    0.3722278804873073,
                                    0.07665941880438285,
                                ],
                                [
                                    0.18334397968093008,
                                    0.6458794825882285,
                                    0.037759242819807914,
                                    0.13301729491103353,
                                ],
                                [
                                    0.18334397968093008,
                                    0.037759242819807914,
                                    0.6458794825882285,
                                    0.13301729491103353,
                                ],
                                [
                                    0.7367738530662394,
                                    0.20914590722823365,
                                    0.04212292443302265,
                                    0.011957315272504392,
                                ],
                                [
                                    0.7367738530662394,
                                    0.04212292443302265,
                                    0.20914590722823365,
                                    0.011957315272504392,
                                ],
                                [
                                    0.5645572655657123,
                                    0.16025927222802278,
                                    0.2143395119335498,
                                    0.060843950272715254,
                                ],
                                [
                                    0.10301657929277688,
                                    0.005889676414056999,
                                    0.8429031810016961,
                                    0.04819056329147004,
                                ],
                                [
                                    0.10301657929277688,
                                    0.8429031810016961,
                                    0.005889676414056999,
                                    0.04819056329147004,
                                ],
                                [
                                    0.5645572655657123,
                                    0.2143395119335498,
                                    0.16025927222802278,
                                    0.060843950272715254,
                                ],
                                [
                                    0.07893705520550652,
                                    0.6458794825882285,
                                    0.029969200501327356,
                                    0.24521426170493768,
                                ],
                                [
                                    0.07893705520550652,
                                    0.029969200501327356,
                                    0.6458794825882285,
                                    0.24521426170493768,
                                ],
                                [
                                    0.9076097356099433,
                                    0.044280683444622326,
                                    0.04587158686349575,
                                    0.0022379940819386448,
                                ],
                                [
                                    0.9076097356099433,
                                    0.04587158686349575,
                                    0.044280683444622326,
                                    0.0022379940819386448,
                                ],
                                [
                                    0.6147991383644985,
                                    0.029994969158908025,
                                    0.3386821841089405,
                                    0.01652370836765294,
                                ],
                                [
                                    0.02181082382947774,
                                    0.0011023428469351144,
                                    0.9300795952250879,
                                    0.047007238098499285,
                                ],
                                [
                                    0.02181082382947774,
                                    0.9300795952250879,
                                    0.0011023428469351144,
                                    0.047007238098499285,
                                ],
                                [
                                    0.6147991383644985,
                                    0.3386821841089405,
                                    0.029994969158908025,
                                    0.01652370836765294,
                                ],
                                [
                                    0.014774274857652685,
                                    0.6300198326657538,
                                    0.00813889181876017,
                                    0.3470670006578333,
                                ],
                                [
                                    0.014774274857652685,
                                    0.00813889181876017,
                                    0.6300198326657538,
                                    0.3470670006578333,
                                ],
                                [
                                    0.1249493104719486,
                                    0.8072097487439511,
                                    0.009093596944572867,
                                    0.05874734383952739,
                                ],
                                [
                                    0.1249493104719486,
                                    0.009093596944572867,
                                    0.8072097487439511,
                                    0.05874734383952739,
                                ],
                                [
                                    0.12187796299252288,
                                    0.7873679295469641,
                                    0.01216494442399859,
                                    0.07858916303651445,
                                ],
                                [
                                    0.060227787900079655,
                                    0.004383275313468048,
                                    0.87193127131582,
                                    0.06345766547063221,
                                ],
                                [
                                    0.060227787900079655,
                                    0.87193127131582,
                                    0.004383275313468048,
                                    0.06345766547063221,
                                ],
                                [
                                    0.12187796299252288,
                                    0.01216494442399859,
                                    0.7873679295469641,
                                    0.07858916303651445,
                                ],
                                [
                                    0.05874734383952739,
                                    0.8504985486999596,
                                    0.005863719374020309,
                                    0.08489038808649274,
                                ],
                                [
                                    0.05874734383952739,
                                    0.005863719374020309,
                                    0.8504985486999596,
                                    0.08489038808649274,
                                ],
                                [
                                    0.35323225254888263,
                                    0.5848974654271097,
                                    0.02329590318525026,
                                    0.03857437883875735,
                                ],
                                [
                                    0.35323225254888263,
                                    0.02329590318525026,
                                    0.5848974654271097,
                                    0.03857437883875735,
                                ],
                                [
                                    0.3122259809396786,
                                    0.51699748132948,
                                    0.0643021747944543,
                                    0.10647436293638715,
                                ],
                                [
                                    0.04364055382860883,
                                    0.0028781236979521954,
                                    0.8944891641473836,
                                    0.058992158326055415,
                                ],
                                [
                                    0.04364055382860883,
                                    0.8944891641473836,
                                    0.0028781236979521954,
                                    0.058992158326055415,
                                ],
                                [
                                    0.3122259809396786,
                                    0.0643021747944543,
                                    0.51699748132948,
                                    0.10647436293638715,
                                ],
                                [
                                    0.03857437883875743,
                                    0.7906490834304011,
                                    0.007944298687803594,
                                    0.16283223904303784,
                                ],
                                [
                                    0.03857437883875743,
                                    0.007944298687803594,
                                    0.7906490834304011,
                                    0.16283223904303784,
                                ],
                                [
                                    0.6554312909036022,
                                    0.2904884693908708,
                                    0.03747239756523875,
                                    0.01660784214028829,
                                ],
                                [
                                    0.6554312909036022,
                                    0.03747239756523875,
                                    0.2904884693908708,
                                    0.01660784214028829,
                                ],
                                [
                                    0.502228052500494,
                                    0.222588485293241,
                                    0.1906756359683469,
                                    0.08450782623791811,
                                ],
                                [
                                    0.021674017130139753,
                                    0.0012391495462731016,
                                    0.9242457431643333,
                                    0.05284109015925394,
                                ],
                                [
                                    0.021674017130139753,
                                    0.9242457431643333,
                                    0.0012391495462731016,
                                    0.05284109015925394,
                                ],
                                [
                                    0.502228052500494,
                                    0.1906756359683469,
                                    0.222588485293241,
                                    0.08450782623791811,
                                ],
                                [
                                    0.016607842140288348,
                                    0.7082086956534467,
                                    0.006305324536124509,
                                    0.2688781376701405,
                                ],
                                [
                                    0.016607842140288348,
                                    0.006305324536124509,
                                    0.7082086956534467,
                                    0.2688781376701405,
                                ],
                                [
                                    0.8903877670166607,
                                    0.06150265203790499,
                                    0.04500116976979165,
                                    0.003108411175642754,
                                ],
                                [
                                    0.8903877670166607,
                                    0.04500116976979165,
                                    0.06150265203790499,
                                    0.003108411175642754,
                                ],
                                [
                                    0.6031332746824886,
                                    0.04166083284091792,
                                    0.3322556621039636,
                                    0.022950230372629825,
                                ],
                                [
                                    0.004588855236195061,
                                    0.00023192575323100463,
                                    0.9473015638183706,
                                    0.04787765519220339,
                                ],
                                [
                                    0.004588855236195061,
                                    0.9473015638183706,
                                    0.00023192575323100463,
                                    0.04787765519220339,
                                ],
                                [
                                    0.6031332746824886,
                                    0.3322556621039636,
                                    0.04166083284091792,
                                    0.022950230372629825,
                                ],
                                [
                                    0.0031084111756427843,
                                    0.6416856963477637,
                                    0.0017123698137832808,
                                    0.3534935226628102,
                                ],
                                [
                                    0.0031084111756427843,
                                    0.0017123698137832808,
                                    0.6416856963477637,
                                    0.3534935226628102,
                                ],
                                [
                                    0.6337747234434474,
                                    0.04377736052794672,
                                    0.3016142133430048,
                                    0.020833702685600967,
                                ],
                                [
                                    0.6337747234434474,
                                    0.3016142133430048,
                                    0.04377736052794672,
                                    0.020833702685600967,
                                ],
                                [
                                    0.6123420008275869,
                                    0.04229691646739446,
                                    0.32304693595886536,
                                    0.022314146746153226,
                                ],
                                [
                                    0.5867310327097455,
                                    0.2792260598737331,
                                    0.09082105126164874,
                                    0.04322185615487268,
                                ],
                                [
                                    0.5867310327097455,
                                    0.09082105126164874,
                                    0.2792260598737331,
                                    0.04322185615487268,
                                ],
                                [
                                    0.6123420008275869,
                                    0.32304693595886536,
                                    0.04229691646739446,
                                    0.022314146746153226,
                                ],
                                [
                                    0.5668892135127583,
                                    0.087749703782223,
                                    0.2990678790707202,
                                    0.046293203634298404,
                                ],
                                [
                                    0.5668892135127583,
                                    0.2990678790707202,
                                    0.087749703782223,
                                    0.046293203634298404,
                                ],
                                [
                                    0.6730916596177575,
                                    0.03283895879402337,
                                    0.2803896628556817,
                                    0.013679718732537566,
                                ],
                                [
                                    0.6730916596177575,
                                    0.2803896628556817,
                                    0.03283895879402337,
                                    0.013679718732537566,
                                ],
                                [
                                    0.569251578900775,
                                    0.02777278380417198,
                                    0.3842297435726641,
                                    0.018745893722388954,
                                ],
                                [
                                    0.44012786458493713,
                                    0.18334397968093008,
                                    0.2658027538268437,
                                    0.11072540190728912,
                                ],
                                [
                                    0.44012786458493713,
                                    0.2658027538268437,
                                    0.18334397968093008,
                                    0.11072540190728912,
                                ],
                                [
                                    0.569251578900775,
                                    0.3842297435726641,
                                    0.02777278380417198,
                                    0.018745893722388954,
                                ],
                                [
                                    0.3722278804873073,
                                    0.22479648221763965,
                                    0.2512439637785599,
                                    0.15173167351649314,
                                ],
                                [
                                    0.3722278804873073,
                                    0.2512439637785599,
                                    0.22479648221763965,
                                    0.15173167351649314,
                                ],
                                [
                                    0.7259331906175536,
                                    0.01702349026235578,
                                    0.2511536427060337,
                                    0.005889676414056997,
                                ],
                                [
                                    0.7259331906175536,
                                    0.2511536427060337,
                                    0.01702349026235578,
                                    0.005889676414056997,
                                ],
                                [
                                    0.509896143106667,
                                    0.01195731527250439,
                                    0.46719069021692033,
                                    0.010955851403908388,
                                ],
                                [
                                    0.2281592563256526,
                                    0.0789370552055065,
                                    0.5147974245542567,
                                    0.17810626391458415,
                                ],
                                [
                                    0.2281592563256526,
                                    0.5147974245542567,
                                    0.0789370552055065,
                                    0.17810626391458415,
                                ],
                                [
                                    0.509896143106667,
                                    0.46719069021692033,
                                    0.01195731527250439,
                                    0.010955851403908388,
                                ],
                                [
                                    0.16025927222802278,
                                    0.3615941861511485,
                                    0.14683703930313635,
                                    0.33130950231769235,
                                ],
                                [
                                    0.16025927222802278,
                                    0.14683703930313635,
                                    0.3615941861511485,
                                    0.33130950231769235,
                                ],
                                [
                                    0.767616777177805,
                                    0.0037184381424909072,
                                    0.227562441832769,
                                    0.0011023428469351115,
                                ],
                                [
                                    0.767616777177805,
                                    0.227562441832769,
                                    0.0037184381424909072,
                                    0.0011023428469351115,
                                ],
                                [
                                    0.46200090970719815,
                                    0.002237994081938645,
                                    0.5331783093033758,
                                    0.0025827869074873736,
                                ],
                                [
                                    0.04983678835589507,
                                    0.014774274857652637,
                                    0.7214984269644008,
                                    0.21389050982205146,
                                ],
                                [
                                    0.04983678835589507,
                                    0.7214984269644008,
                                    0.014774274857652637,
                                    0.21389050982205146,
                                ],
                                [
                                    0.46200090970719815,
                                    0.5331783093033758,
                                    0.002237994081938645,
                                    0.0025827869074873736,
                                ],
                                [
                                    0.029994969158908008,
                                    0.4342439346302288,
                                    0.034616094054639696,
                                    0.5011450021562235,
                                ],
                                [
                                    0.029994969158908008,
                                    0.034616094054639696,
                                    0.4342439346302288,
                                    0.5011450021562235,
                                ],
                                [
                                    0.46947833811352885,
                                    0.20807374585786534,
                                    0.22342535035531202,
                                    0.09902256567329375,
                                ],
                                [
                                    0.46947833811352885,
                                    0.22342535035531202,
                                    0.20807374585786534,
                                    0.09902256567329375,
                                ],
                                [
                                    0.45360172040894103,
                                    0.20103719688604027,
                                    0.23930196805989978,
                                    0.10605911464511877,
                                ],
                                [
                                    0.4224346473798269,
                                    0.20103719688604033,
                                    0.2551174365915673,
                                    0.12141071914256545,
                                ],
                                [
                                    0.4224346473798269,
                                    0.2551174365915673,
                                    0.20103719688604033,
                                    0.12141071914256545,
                                ],
                                [
                                    0.45360172040894103,
                                    0.23930196805989978,
                                    0.20103719688604027,
                                    0.10605911464511877,
                                ],
                                [
                                    0.40814893309411254,
                                    0.24648998420086882,
                                    0.21532291117175464,
                                    0.13003817153326394,
                                ],
                                [
                                    0.40814893309411254,
                                    0.21532291117175464,
                                    0.24648998420086882,
                                    0.13003817153326394,
                                ],
                                [
                                    0.5498470838189973,
                                    0.15608353459278357,
                                    0.22904969368026476,
                                    0.06501968790795447,
                                ],
                                [
                                    0.5498470838189973,
                                    0.22904969368026476,
                                    0.15608353459278357,
                                    0.06501968790795447,
                                ],
                                [
                                    0.4650203521994338,
                                    0.13200401050551322,
                                    0.31387642529982823,
                                    0.08909921199522482,
                                ],
                                [
                                    0.31688328878617694,
                                    0.1320040105055132,
                                    0.3890473296256039,
                                    0.16206537108270602,
                                ],
                                [
                                    0.31688328878617694,
                                    0.3890473296256039,
                                    0.1320040105055132,
                                    0.16206537108270602,
                                ],
                                [
                                    0.4650203521994338,
                                    0.31387642529982823,
                                    0.13200401050551322,
                                    0.08909921199522482,
                                ],
                                [
                                    0.2679966537859661,
                                    0.32902770891898087,
                                    0.18089064550572403,
                                    0.222084991789329,
                                ],
                                [
                                    0.2679966537859661,
                                    0.18089064550572403,
                                    0.32902770891898087,
                                    0.222084991789329,
                                ],
                                [
                                    0.6620440506129013,
                                    0.08091263026700796,
                                    0.22904969368026476,
                                    0.027993625439825885,
                                ],
                                [
                                    0.6620440506129013,
                                    0.22904969368026476,
                                    0.08091263026700796,
                                    0.027993625439825885,
                                ],
                                [
                                    0.46502035219943366,
                                    0.0568331061797376,
                                    0.42607339209373246,
                                    0.05207314952709625,
                                ],
                                [
                                    0.1642701163210004,
                                    0.0568331061797376,
                                    0.5786865645589089,
                                    0.20021021294035304,
                                ],
                                [
                                    0.1642701163210004,
                                    0.5786865645589089,
                                    0.0568331061797376,
                                    0.20021021294035304,
                                ],
                                [
                                    0.46502035219943366,
                                    0.42607339209373246,
                                    0.0568331061797376,
                                    0.05207314952709625,
                                ],
                                [
                                    0.11538348132078953,
                                    0.4064699770583818,
                                    0.10571974117994846,
                                    0.3724268004408802,
                                ],
                                [
                                    0.11538348132078953,
                                    0.10571974117994846,
                                    0.4064699770583818,
                                    0.3724268004408802,
                                ],
                                [
                                    0.7536614829682753,
                                    0.017673732352020695,
                                    0.22342535035531202,
                                    0.005239434324392104,
                                ],
                                [
                                    0.7536614829682753,
                                    0.22342535035531202,
                                    0.017673732352020695,
                                    0.005239434324392104,
                                ],
                                [
                                    0.45360172040894114,
                                    0.010637183380195656,
                                    0.5234851129146461,
                                    0.01227598329621714,
                                ],
                                [
                                    0.03588149414636536,
                                    0.010637183380195668,
                                    0.7354537211739306,
                                    0.21802760129950843,
                                ],
                                [
                                    0.03588149414636536,
                                    0.7354537211739306,
                                    0.010637183380195668,
                                    0.21802760129950843,
                                ],
                                [
                                    0.45360172040894114,
                                    0.5234851129146461,
                                    0.010637183380195656,
                                    0.01227598329621714,
                                ],
                                [
                                    0.021595779860651042,
                                    0.44264312392848576,
                                    0.024922897665909983,
                                    0.5108381985449533,
                                ],
                                [
                                    0.021595779860651042,
                                    0.024922897665909983,
                                    0.44264312392848576,
                                    0.5108381985449533,
                                ],
                                [
                                    0.25511743659156744,
                                    0.4224346473798268,
                                    0.12141071914256549,
                                    0.2010371968860403,
                                ],
                                [
                                    0.25511743659156744,
                                    0.12141071914256549,
                                    0.4224346473798268,
                                    0.2010371968860403,
                                ],
                                [
                                    0.2464899842008689,
                                    0.4081489330941125,
                                    0.130038171533264,
                                    0.2153229111717546,
                                ],
                                [
                                    0.20807374585786537,
                                    0.09902256567329376,
                                    0.46947833811352885,
                                    0.22342535035531202,
                                ],
                                [
                                    0.20807374585786537,
                                    0.46947833811352885,
                                    0.09902256567329376,
                                    0.22342535035531202,
                                ],
                                [
                                    0.2464899842008689,
                                    0.130038171533264,
                                    0.4081489330941125,
                                    0.2153229111717546,
                                ],
                                [
                                    0.2010371968860403,
                                    0.45360172040894103,
                                    0.1060591146451188,
                                    0.23930196805989978,
                                ],
                                [
                                    0.2010371968860403,
                                    0.1060591146451188,
                                    0.45360172040894103,
                                    0.23930196805989978,
                                ],
                                [
                                    0.3890473296256039,
                                    0.31688328878617694,
                                    0.16206537108270602,
                                    0.1320040105055132,
                                ],
                                [
                                    0.3890473296256039,
                                    0.16206537108270602,
                                    0.31688328878617694,
                                    0.1320040105055132,
                                ],
                                [
                                    0.32902770891898087,
                                    0.2679966537859661,
                                    0.222084991789329,
                                    0.18089064550572403,
                                ],
                                [
                                    0.15608353459278354,
                                    0.06501968790795445,
                                    0.5498470838189973,
                                    0.22904969368026476,
                                ],
                                [
                                    0.15608353459278354,
                                    0.5498470838189973,
                                    0.06501968790795445,
                                    0.22904969368026476,
                                ],
                                [
                                    0.32902770891898087,
                                    0.222084991789329,
                                    0.2679966537859661,
                                    0.18089064550572403,
                                ],
                                [
                                    0.1320040105055132,
                                    0.4650203521994338,
                                    0.0890992119952248,
                                    0.31387642529982823,
                                ],
                                [
                                    0.1320040105055132,
                                    0.0890992119952248,
                                    0.4650203521994338,
                                    0.31387642529982823,
                                ],
                                [
                                    0.5786865645589089,
                                    0.1642701163210004,
                                    0.20021021294035304,
                                    0.05683310617973761,
                                ],
                                [
                                    0.5786865645589089,
                                    0.20021021294035304,
                                    0.1642701163210004,
                                    0.05683310617973761,
                                ],
                                [
                                    0.4064699770583818,
                                    0.11538348132078954,
                                    0.3724268004408802,
                                    0.10571974117994848,
                                ],
                                [
                                    0.08091263026700797,
                                    0.027993625439825896,
                                    0.6620440506129013,
                                    0.22904969368026476,
                                ],
                                [
                                    0.08091263026700797,
                                    0.6620440506129013,
                                    0.027993625439825896,
                                    0.22904969368026476,
                                ],
                                [
                                    0.4064699770583818,
                                    0.3724268004408802,
                                    0.11538348132078954,
                                    0.10571974117994848,
                                ],
                                [
                                    0.05683310617973762,
                                    0.46502035219943366,
                                    0.052073149527096255,
                                    0.42607339209373246,
                                ],
                                [
                                    0.05683310617973762,
                                    0.052073149527096255,
                                    0.46502035219943366,
                                    0.42607339209373246,
                                ],
                                [
                                    0.7354537211739306,
                                    0.035881494146365316,
                                    0.21802760129950846,
                                    0.010637183380195654,
                                ],
                                [
                                    0.7354537211739306,
                                    0.21802760129950846,
                                    0.035881494146365316,
                                    0.010637183380195654,
                                ],
                                [
                                    0.4426431239284858,
                                    0.021595779860651018,
                                    0.5108381985449533,
                                    0.02492289766590995,
                                ],
                                [
                                    0.01767373235202074,
                                    0.005239434324392117,
                                    0.7536614829682752,
                                    0.223425350355312,
                                ],
                                [
                                    0.01767373235202074,
                                    0.7536614829682752,
                                    0.005239434324392117,
                                    0.223425350355312,
                                ],
                                [
                                    0.4426431239284858,
                                    0.5108381985449533,
                                    0.021595779860651018,
                                    0.02492289766590995,
                                ],
                                [
                                    0.010637183380195682,
                                    0.4536017204089411,
                                    0.012275983296217173,
                                    0.5234851129146461,
                                ],
                                [
                                    0.010637183380195682,
                                    0.012275983296217173,
                                    0.4536017204089411,
                                    0.5234851129146461,
                                ],
                                [
                                    0.09082105126164877,
                                    0.5867310327097455,
                                    0.043221856154872694,
                                    0.2792260598737331,
                                ],
                                [
                                    0.09082105126164877,
                                    0.043221856154872694,
                                    0.5867310327097455,
                                    0.2792260598737331,
                                ],
                                [
                                    0.08774970378222305,
                                    0.5668892135127583,
                                    0.046293203634298424,
                                    0.2990678790707202,
                                ],
                                [
                                    0.043777360527946736,
                                    0.02083370268560097,
                                    0.6337747234434474,
                                    0.3016142133430048,
                                ],
                                [
                                    0.043777360527946736,
                                    0.6337747234434474,
                                    0.02083370268560097,
                                    0.3016142133430048,
                                ],
                                [
                                    0.08774970378222305,
                                    0.046293203634298424,
                                    0.5668892135127583,
                                    0.2990678790707202,
                                ],
                                [
                                    0.04229691646739447,
                                    0.6123420008275869,
                                    0.022314146746153233,
                                    0.32304693595886536,
                                ],
                                [
                                    0.04229691646739447,
                                    0.022314146746153233,
                                    0.6123420008275869,
                                    0.32304693595886536,
                                ],
                                [
                                    0.26580275382684376,
                                    0.4401278645849371,
                                    0.11072540190728916,
                                    0.18334397968093005,
                                ],
                                [
                                    0.26580275382684376,
                                    0.11072540190728916,
                                    0.4401278645849371,
                                    0.18334397968093005,
                                ],
                                [
                                    0.2247964822176397,
                                    0.37222788048730726,
                                    0.1517316735164932,
                                    0.25124396377855984,
                                ],
                                [
                                    0.03283895879402344,
                                    0.013679718732537592,
                                    0.6730916596177574,
                                    0.2803896628556816,
                                ],
                                [
                                    0.03283895879402344,
                                    0.6730916596177574,
                                    0.013679718732537592,
                                    0.2803896628556816,
                                ],
                                [
                                    0.2247964822176397,
                                    0.1517316735164932,
                                    0.37222788048730726,
                                    0.25124396377855984,
                                ],
                                [
                                    0.027772783804172033,
                                    0.5692515789007749,
                                    0.018745893722388992,
                                    0.38422974357266404,
                                ],
                                [
                                    0.027772783804172033,
                                    0.018745893722388992,
                                    0.5692515789007749,
                                    0.38422974357266404,
                                ],
                                [
                                    0.5147974245542567,
                                    0.22815925632565257,
                                    0.17810626391458415,
                                    0.07893705520550649,
                                ],
                                [
                                    0.5147974245542567,
                                    0.17810626391458415,
                                    0.22815925632565257,
                                    0.07893705520550649,
                                ],
                                [
                                    0.3615941861511485,
                                    0.16025927222802275,
                                    0.33130950231769235,
                                    0.14683703930313632,
                                ],
                                [
                                    0.017023490262355837,
                                    0.005889676414057016,
                                    0.7259331906175535,
                                    0.25115364270603363,
                                ],
                                [
                                    0.017023490262355837,
                                    0.7259331906175535,
                                    0.005889676414057016,
                                    0.25115364270603363,
                                ],
                                [
                                    0.3615941861511485,
                                    0.33130950231769235,
                                    0.16025927222802275,
                                    0.14683703930313632,
                                ],
                                [
                                    0.01195731527250443,
                                    0.5098961431066669,
                                    0.010955851403908425,
                                    0.4671906902169203,
                                ],
                                [
                                    0.01195731527250443,
                                    0.010955851403908425,
                                    0.5098961431066669,
                                    0.4671906902169203,
                                ],
                                [
                                    0.7214984269644008,
                                    0.0498367883558951,
                                    0.21389050982205146,
                                    0.014774274857652646,
                                ],
                                [
                                    0.7214984269644008,
                                    0.21389050982205146,
                                    0.0498367883558951,
                                    0.014774274857652646,
                                ],
                                [
                                    0.4342439346302288,
                                    0.02999496915890803,
                                    0.5011450021562235,
                                    0.034616094054639716,
                                ],
                                [
                                    0.0037184381424909436,
                                    0.0011023428469351222,
                                    0.767616777177805,
                                    0.227562441832769,
                                ],
                                [
                                    0.0037184381424909436,
                                    0.767616777177805,
                                    0.0011023428469351222,
                                    0.227562441832769,
                                ],
                                [
                                    0.4342439346302288,
                                    0.5011450021562235,
                                    0.02999496915890803,
                                    0.034616094054639716,
                                ],
                                [
                                    0.002237994081938667,
                                    0.46200090970719815,
                                    0.0025827869074873987,
                                    0.5331783093033758,
                                ],
                                [
                                    0.002237994081938667,
                                    0.0025827869074873987,
                                    0.46200090970719815,
                                    0.5331783093033758,
                                ],
                                [
                                    0.3230469359588653,
                                    0.022314146746153223,
                                    0.6123420008275869,
                                    0.04229691646739447,
                                ],
                                [
                                    0.3230469359588653,
                                    0.6123420008275869,
                                    0.022314146746153223,
                                    0.04229691646739447,
                                ],
                                [
                                    0.3016142133430048,
                                    0.020833702685600967,
                                    0.6337747234434474,
                                    0.04377736052794672,
                                ],
                                [
                                    0.29906787907072013,
                                    0.5668892135127584,
                                    0.0462932036342984,
                                    0.08774970378222302,
                                ],
                                [
                                    0.29906787907072013,
                                    0.0462932036342984,
                                    0.5668892135127584,
                                    0.08774970378222302,
                                ],
                                [
                                    0.3016142133430048,
                                    0.6337747234434474,
                                    0.020833702685600967,
                                    0.04377736052794672,
                                ],
                                [
                                    0.2792260598737331,
                                    0.04322185615487268,
                                    0.5867310327097455,
                                    0.09082105126164874,
                                ],
                                [
                                    0.2792260598737331,
                                    0.5867310327097455,
                                    0.04322185615487268,
                                    0.09082105126164874,
                                ],
                                [
                                    0.3842297435726642,
                                    0.01874589372238896,
                                    0.5692515789007749,
                                    0.027772783804171974,
                                ],
                                [
                                    0.3842297435726642,
                                    0.5692515789007749,
                                    0.01874589372238896,
                                    0.027772783804171974,
                                ],
                                [
                                    0.28038966285568173,
                                    0.013679718732537567,
                                    0.6730916596177574,
                                    0.03283895879402337,
                                ],
                                [
                                    0.25124396377855995,
                                    0.37222788048730726,
                                    0.15173167351649317,
                                    0.22479648221763962,
                                ],
                                [
                                    0.25124396377855995,
                                    0.15173167351649317,
                                    0.37222788048730726,
                                    0.22479648221763962,
                                ],
                                [
                                    0.28038966285568173,
                                    0.6730916596177574,
                                    0.013679718732537567,
                                    0.03283895879402337,
                                ],
                                [
                                    0.18334397968093014,
                                    0.11072540190728915,
                                    0.4401278645849371,
                                    0.26580275382684365,
                                ],
                                [
                                    0.18334397968093014,
                                    0.4401278645849371,
                                    0.11072540190728915,
                                    0.26580275382684365,
                                ],
                                [
                                    0.46719069021692033,
                                    0.010955851403908388,
                                    0.509896143106667,
                                    0.01195731527250439,
                                ],
                                [
                                    0.46719069021692033,
                                    0.509896143106667,
                                    0.010955851403908388,
                                    0.01195731527250439,
                                ],
                                [
                                    0.25115364270603374,
                                    0.005889676414056998,
                                    0.7259331906175536,
                                    0.01702349026235578,
                                ],
                                [
                                    0.14683703930313635,
                                    0.16025927222802278,
                                    0.33130950231769235,
                                    0.3615941861511485,
                                ],
                                [
                                    0.14683703930313635,
                                    0.33130950231769235,
                                    0.16025927222802278,
                                    0.3615941861511485,
                                ],
                                [
                                    0.25115364270603374,
                                    0.7259331906175536,
                                    0.005889676414056998,
                                    0.01702349026235578,
                                ],
                                [
                                    0.07893705520550652,
                                    0.17810626391458417,
                                    0.2281592563256526,
                                    0.5147974245542567,
                                ],
                                [
                                    0.07893705520550652,
                                    0.2281592563256526,
                                    0.17810626391458417,
                                    0.5147974245542567,
                                ],
                                [
                                    0.5331783093033758,
                                    0.0025827869074873736,
                                    0.4620009097071981,
                                    0.0022379940819386448,
                                ],
                                [
                                    0.5331783093033758,
                                    0.4620009097071981,
                                    0.0025827869074873736,
                                    0.0022379940819386448,
                                ],
                                [
                                    0.22756244183276908,
                                    0.001102342846935112,
                                    0.7676167771778049,
                                    0.003718438142490907,
                                ],
                                [
                                    0.034616094054639696,
                                    0.029994969158908005,
                                    0.5011450021562235,
                                    0.43424393463022876,
                                ],
                                [
                                    0.034616094054639696,
                                    0.5011450021562235,
                                    0.029994969158908005,
                                    0.43424393463022876,
                                ],
                                [
                                    0.22756244183276908,
                                    0.7676167771778049,
                                    0.001102342846935112,
                                    0.003718438142490907,
                                ],
                                [
                                    0.014774274857652642,
                                    0.21389050982205154,
                                    0.04983678835589506,
                                    0.7214984269644007,
                                ],
                                [
                                    0.014774274857652642,
                                    0.04983678835589506,
                                    0.21389050982205154,
                                    0.7214984269644007,
                                ],
                                [
                                    0.23930196805989976,
                                    0.10605911464511876,
                                    0.45360172040894114,
                                    0.2010371968860403,
                                ],
                                [
                                    0.23930196805989976,
                                    0.45360172040894114,
                                    0.10605911464511876,
                                    0.2010371968860403,
                                ],
                                [
                                    0.22342535035531202,
                                    0.09902256567329375,
                                    0.46947833811352885,
                                    0.20807374585786534,
                                ],
                                [
                                    0.2153229111717546,
                                    0.4081489330941126,
                                    0.13003817153326394,
                                    0.24648998420086884,
                                ],
                                [
                                    0.2153229111717546,
                                    0.13003817153326394,
                                    0.4081489330941126,
                                    0.24648998420086884,
                                ],
                                [
                                    0.22342535035531202,
                                    0.46947833811352885,
                                    0.09902256567329375,
                                    0.20807374585786534,
                                ],
                                [
                                    0.20103719688604033,
                                    0.12141071914256545,
                                    0.4224346473798269,
                                    0.2551174365915673,
                                ],
                                [
                                    0.20103719688604033,
                                    0.4224346473798269,
                                    0.12141071914256545,
                                    0.2551174365915673,
                                ],
                                [
                                    0.31387642529982834,
                                    0.08909921199522484,
                                    0.46502035219943366,
                                    0.1320040105055132,
                                ],
                                [
                                    0.31387642529982834,
                                    0.46502035219943366,
                                    0.08909921199522484,
                                    0.1320040105055132,
                                ],
                                [
                                    0.2290496936802648,
                                    0.06501968790795448,
                                    0.5498470838189972,
                                    0.15608353459278354,
                                ],
                                [
                                    0.1808906455057241,
                                    0.26799665378596604,
                                    0.22208499178932906,
                                    0.3290277089189808,
                                ],
                                [
                                    0.1808906455057241,
                                    0.22208499178932906,
                                    0.26799665378596604,
                                    0.3290277089189808,
                                ],
                                [
                                    0.2290496936802648,
                                    0.5498470838189972,
                                    0.06501968790795448,
                                    0.15608353459278354,
                                ],
                                [
                                    0.13200401050551322,
                                    0.16206537108270605,
                                    0.31688328878617694,
                                    0.3890473296256038,
                                ],
                                [
                                    0.13200401050551322,
                                    0.31688328878617694,
                                    0.16206537108270605,
                                    0.3890473296256038,
                                ],
                                [
                                    0.42607339209373246,
                                    0.05207314952709625,
                                    0.46502035219943366,
                                    0.0568331061797376,
                                ],
                                [
                                    0.42607339209373246,
                                    0.46502035219943366,
                                    0.05207314952709625,
                                    0.0568331061797376,
                                ],
                                [
                                    0.22904969368026482,
                                    0.027993625439825892,
                                    0.6620440506129013,
                                    0.08091263026700796,
                                ],
                                [
                                    0.10571974117994846,
                                    0.11538348132078953,
                                    0.3724268004408802,
                                    0.4064699770583818,
                                ],
                                [
                                    0.10571974117994846,
                                    0.3724268004408802,
                                    0.11538348132078953,
                                    0.4064699770583818,
                                ],
                                [
                                    0.22904969368026482,
                                    0.6620440506129013,
                                    0.027993625439825892,
                                    0.08091263026700796,
                                ],
                                [
                                    0.056833106179737615,
                                    0.2002102129403531,
                                    0.1642701163210004,
                                    0.5786865645589089,
                                ],
                                [
                                    0.056833106179737615,
                                    0.1642701163210004,
                                    0.2002102129403531,
                                    0.5786865645589089,
                                ],
                                [
                                    0.5234851129146461,
                                    0.01227598329621714,
                                    0.4536017204089411,
                                    0.010637183380195654,
                                ],
                                [
                                    0.5234851129146461,
                                    0.4536017204089411,
                                    0.01227598329621714,
                                    0.010637183380195654,
                                ],
                                [
                                    0.2234253503553121,
                                    0.0052394343243921055,
                                    0.7536614829682752,
                                    0.01767373235202069,
                                ],
                                [
                                    0.024922897665909983,
                                    0.021595779860651042,
                                    0.5108381985449533,
                                    0.4426431239284857,
                                ],
                                [
                                    0.024922897665909983,
                                    0.5108381985449533,
                                    0.021595779860651042,
                                    0.4426431239284857,
                                ],
                                [
                                    0.2234253503553121,
                                    0.7536614829682752,
                                    0.0052394343243921055,
                                    0.01767373235202069,
                                ],
                                [
                                    0.010637183380195672,
                                    0.21802760129950852,
                                    0.03588149414636536,
                                    0.7354537211739305,
                                ],
                                [
                                    0.010637183380195672,
                                    0.03588149414636536,
                                    0.21802760129950852,
                                    0.7354537211739305,
                                ],
                                [
                                    0.13003817153326397,
                                    0.21532291117175456,
                                    0.24648998420086893,
                                    0.40814893309411254,
                                ],
                                [
                                    0.13003817153326397,
                                    0.24648998420086893,
                                    0.21532291117175456,
                                    0.40814893309411254,
                                ],
                                [
                                    0.12141071914256549,
                                    0.2010371968860403,
                                    0.25511743659156744,
                                    0.4224346473798268,
                                ],
                                [
                                    0.10605911464511879,
                                    0.20103719688604035,
                                    0.23930196805989976,
                                    0.45360172040894114,
                                ],
                                [
                                    0.10605911464511879,
                                    0.23930196805989976,
                                    0.20103719688604035,
                                    0.45360172040894114,
                                ],
                                [
                                    0.12141071914256549,
                                    0.25511743659156744,
                                    0.2010371968860403,
                                    0.4224346473798268,
                                ],
                                [
                                    0.09902256567329376,
                                    0.22342535035531202,
                                    0.20807374585786537,
                                    0.46947833811352885,
                                ],
                                [
                                    0.09902256567329376,
                                    0.20807374585786537,
                                    0.22342535035531202,
                                    0.46947833811352885,
                                ],
                                [
                                    0.22208499178932906,
                                    0.1808906455057241,
                                    0.3290277089189808,
                                    0.26799665378596604,
                                ],
                                [
                                    0.22208499178932906,
                                    0.3290277089189808,
                                    0.1808906455057241,
                                    0.26799665378596604,
                                ],
                                [
                                    0.16206537108270605,
                                    0.13200401050551322,
                                    0.3890473296256038,
                                    0.31688328878617694,
                                ],
                                [
                                    0.08909921199522483,
                                    0.13200401050551316,
                                    0.31387642529982834,
                                    0.46502035219943366,
                                ],
                                [
                                    0.08909921199522483,
                                    0.31387642529982834,
                                    0.13200401050551316,
                                    0.46502035219943366,
                                ],
                                [
                                    0.16206537108270605,
                                    0.3890473296256038,
                                    0.13200401050551322,
                                    0.31688328878617694,
                                ],
                                [
                                    0.06501968790795447,
                                    0.2290496936802648,
                                    0.1560835345927835,
                                    0.5498470838189972,
                                ],
                                [
                                    0.06501968790795447,
                                    0.1560835345927835,
                                    0.2290496936802648,
                                    0.5498470838189972,
                                ],
                                [
                                    0.3724268004408802,
                                    0.10571974117994848,
                                    0.4064699770583818,
                                    0.11538348132078954,
                                ],
                                [
                                    0.3724268004408802,
                                    0.4064699770583818,
                                    0.10571974117994848,
                                    0.11538348132078954,
                                ],
                                [
                                    0.2002102129403531,
                                    0.05683310617973762,
                                    0.5786865645589089,
                                    0.1642701163210004,
                                ],
                                [
                                    0.052073149527096255,
                                    0.05683310617973762,
                                    0.42607339209373246,
                                    0.46502035219943366,
                                ],
                                [
                                    0.052073149527096255,
                                    0.42607339209373246,
                                    0.05683310617973762,
                                    0.46502035219943366,
                                ],
                                [
                                    0.2002102129403531,
                                    0.5786865645589089,
                                    0.05683310617973762,
                                    0.1642701163210004,
                                ],
                                [
                                    0.0279936254398259,
                                    0.22904969368026482,
                                    0.08091263026700797,
                                    0.6620440506129013,
                                ],
                                [
                                    0.0279936254398259,
                                    0.08091263026700797,
                                    0.22904969368026482,
                                    0.6620440506129013,
                                ],
                                [
                                    0.5108381985449533,
                                    0.02492289766590995,
                                    0.44264312392848576,
                                    0.021595779860651015,
                                ],
                                [
                                    0.5108381985449533,
                                    0.44264312392848576,
                                    0.02492289766590995,
                                    0.021595779860651015,
                                ],
                                [
                                    0.21802760129950854,
                                    0.01063718338019566,
                                    0.7354537211739305,
                                    0.03588149414636531,
                                ],
                                [
                                    0.012275983296217173,
                                    0.010637183380195682,
                                    0.5234851129146461,
                                    0.45360172040894103,
                                ],
                                [
                                    0.012275983296217173,
                                    0.5234851129146461,
                                    0.010637183380195682,
                                    0.45360172040894103,
                                ],
                                [
                                    0.21802760129950854,
                                    0.7354537211739305,
                                    0.01063718338019566,
                                    0.03588149414636531,
                                ],
                                [
                                    0.0052394343243921185,
                                    0.22342535035531208,
                                    0.017673732352020737,
                                    0.7536614829682751,
                                ],
                                [
                                    0.0052394343243921185,
                                    0.017673732352020737,
                                    0.22342535035531208,
                                    0.7536614829682751,
                                ],
                                [
                                    0.04629320363429842,
                                    0.29906787907072013,
                                    0.08774970378222306,
                                    0.5668892135127584,
                                ],
                                [
                                    0.04629320363429842,
                                    0.08774970378222306,
                                    0.29906787907072013,
                                    0.5668892135127584,
                                ],
                                [
                                    0.043221856154872694,
                                    0.2792260598737331,
                                    0.09082105126164877,
                                    0.5867310327097455,
                                ],
                                [
                                    0.02231414674615323,
                                    0.042296916467394474,
                                    0.3230469359588653,
                                    0.6123420008275869,
                                ],
                                [
                                    0.02231414674615323,
                                    0.3230469359588653,
                                    0.042296916467394474,
                                    0.6123420008275869,
                                ],
                                [
                                    0.043221856154872694,
                                    0.09082105126164877,
                                    0.2792260598737331,
                                    0.5867310327097455,
                                ],
                                [
                                    0.02083370268560097,
                                    0.3016142133430048,
                                    0.043777360527946736,
                                    0.6337747234434474,
                                ],
                                [
                                    0.02083370268560097,
                                    0.043777360527946736,
                                    0.3016142133430048,
                                    0.6337747234434474,
                                ],
                                [
                                    0.15173167351649322,
                                    0.2512439637785599,
                                    0.22479648221763968,
                                    0.3722278804873072,
                                ],
                                [
                                    0.15173167351649322,
                                    0.22479648221763968,
                                    0.2512439637785599,
                                    0.3722278804873072,
                                ],
                                [
                                    0.11072540190728918,
                                    0.18334397968093008,
                                    0.2658027538268437,
                                    0.440127864584937,
                                ],
                                [
                                    0.018745893722388995,
                                    0.02777278380417203,
                                    0.38422974357266415,
                                    0.5692515789007748,
                                ],
                                [
                                    0.018745893722388995,
                                    0.38422974357266415,
                                    0.02777278380417203,
                                    0.5692515789007748,
                                ],
                                [
                                    0.11072540190728918,
                                    0.2658027538268437,
                                    0.18334397968093008,
                                    0.440127864584937,
                                ],
                                [
                                    0.013679718732537594,
                                    0.2803896628556817,
                                    0.03283895879402343,
                                    0.6730916596177573,
                                ],
                                [
                                    0.013679718732537594,
                                    0.03283895879402343,
                                    0.2803896628556817,
                                    0.6730916596177573,
                                ],
                                [
                                    0.33130950231769235,
                                    0.14683703930313632,
                                    0.3615941861511485,
                                    0.16025927222802275,
                                ],
                                [
                                    0.33130950231769235,
                                    0.3615941861511485,
                                    0.14683703930313632,
                                    0.16025927222802275,
                                ],
                                [
                                    0.17810626391458417,
                                    0.0789370552055065,
                                    0.5147974245542567,
                                    0.22815925632565257,
                                ],
                                [
                                    0.010955851403908425,
                                    0.01195731527250443,
                                    0.4671906902169203,
                                    0.5098961431066669,
                                ],
                                [
                                    0.010955851403908425,
                                    0.4671906902169203,
                                    0.01195731527250443,
                                    0.5098961431066669,
                                ],
                                [
                                    0.17810626391458417,
                                    0.5147974245542567,
                                    0.0789370552055065,
                                    0.22815925632565257,
                                ],
                                [
                                    0.005889676414057018,
                                    0.2511536427060337,
                                    0.017023490262355837,
                                    0.7259331906175535,
                                ],
                                [
                                    0.005889676414057018,
                                    0.017023490262355837,
                                    0.2511536427060337,
                                    0.7259331906175535,
                                ],
                                [
                                    0.5011450021562235,
                                    0.034616094054639716,
                                    0.43424393463022876,
                                    0.029994969158908022,
                                ],
                                [
                                    0.5011450021562235,
                                    0.43424393463022876,
                                    0.034616094054639716,
                                    0.029994969158908022,
                                ],
                                [
                                    0.21389050982205154,
                                    0.01477427485765265,
                                    0.7214984269644007,
                                    0.04983678835589509,
                                ],
                                [
                                    0.0025827869074873987,
                                    0.0022379940819386664,
                                    0.5331783093033758,
                                    0.4620009097071981,
                                ],
                                [
                                    0.0025827869074873987,
                                    0.5331783093033758,
                                    0.0022379940819386664,
                                    0.4620009097071981,
                                ],
                                [
                                    0.21389050982205154,
                                    0.7214984269644007,
                                    0.01477427485765265,
                                    0.04983678835589509,
                                ],
                                [
                                    0.0011023428469351226,
                                    0.22756244183276908,
                                    0.0037184381424909428,
                                    0.7676167771778049,
                                ],
                                [
                                    0.0011023428469351226,
                                    0.0037184381424909428,
                                    0.22756244183276908,
                                    0.7676167771778049,
                                ],
                                [
                                    0.08489038808649274,
                                    0.0058637193740203085,
                                    0.8504985486999596,
                                    0.05874734383952738,
                                ],
                                [
                                    0.08489038808649274,
                                    0.8504985486999596,
                                    0.0058637193740203085,
                                    0.05874734383952738,
                                ],
                                [
                                    0.06345766547063225,
                                    0.00438327531346805,
                                    0.87193127131582,
                                    0.06022778790007964,
                                ],
                                [
                                    0.07858916303651445,
                                    0.7873679295469641,
                                    0.012164944423998585,
                                    0.12187796299252283,
                                ],
                                [
                                    0.07858916303651445,
                                    0.012164944423998585,
                                    0.7873679295469641,
                                    0.12187796299252283,
                                ],
                                [
                                    0.06345766547063225,
                                    0.87193127131582,
                                    0.00438327531346805,
                                    0.06022778790007964,
                                ],
                                [
                                    0.05874734383952743,
                                    0.009093596944572869,
                                    0.8072097487439511,
                                    0.12494931047194854,
                                ],
                                [
                                    0.05874734383952743,
                                    0.8072097487439511,
                                    0.009093596944572869,
                                    0.12494931047194854,
                                ],
                                [
                                    0.16283223904303798,
                                    0.007944298687803586,
                                    0.7906490834304011,
                                    0.03857437883875735,
                                ],
                                [
                                    0.16283223904303798,
                                    0.7906490834304011,
                                    0.007944298687803586,
                                    0.03857437883875735,
                                ],
                                [
                                    0.05899215832605549,
                                    0.0028781236979521932,
                                    0.8944891641473836,
                                    0.04364055382860874,
                                ],
                                [
                                    0.10647436293638725,
                                    0.51699748132948,
                                    0.06430217479445431,
                                    0.31222598093967846,
                                ],
                                [
                                    0.10647436293638725,
                                    0.06430217479445431,
                                    0.51699748132948,
                                    0.31222598093967846,
                                ],
                                [
                                    0.05899215832605549,
                                    0.8944891641473836,
                                    0.0028781236979521932,
                                    0.04364055382860874,
                                ],
                                [
                                    0.0385743788387574,
                                    0.02329590318525028,
                                    0.5848974654271099,
                                    0.3532322525488825,
                                ],
                                [
                                    0.0385743788387574,
                                    0.5848974654271099,
                                    0.02329590318525028,
                                    0.3532322525488825,
                                ],
                                [
                                    0.2688781376701406,
                                    0.006305324536124489,
                                    0.7082086956534467,
                                    0.01660784214028829,
                                ],
                                [
                                    0.2688781376701406,
                                    0.7082086956534467,
                                    0.006305324536124489,
                                    0.01660784214028829,
                                ],
                                [
                                    0.05284109015925401,
                                    0.001239149546273099,
                                    0.9242457431643333,
                                    0.02167401713013968,
                                ],
                                [
                                    0.08450782623791814,
                                    0.222588485293241,
                                    0.19067563596834697,
                                    0.502228052500494,
                                ],
                                [
                                    0.08450782623791814,
                                    0.19067563596834697,
                                    0.222588485293241,
                                    0.502228052500494,
                                ],
                                [
                                    0.05284109015925401,
                                    0.9242457431643333,
                                    0.001239149546273099,
                                    0.02167401713013968,
                                ],
                                [
                                    0.016607842140288313,
                                    0.0374723975652388,
                                    0.2904884693908708,
                                    0.6554312909036021,
                                ],
                                [
                                    0.016607842140288313,
                                    0.2904884693908708,
                                    0.0374723975652388,
                                    0.6554312909036021,
                                ],
                                [
                                    0.35349352266281026,
                                    0.0017123698137832646,
                                    0.6416856963477637,
                                    0.0031084111756427544,
                                ],
                                [
                                    0.35349352266281026,
                                    0.6416856963477637,
                                    0.0017123698137832646,
                                    0.0031084111756427544,
                                ],
                                [
                                    0.047877655192203376,
                                    0.0002319257532310023,
                                    0.9473015638183706,
                                    0.004588855236195017,
                                ],
                                [
                                    0.02295023037262981,
                                    0.04166083284091789,
                                    0.3322556621039637,
                                    0.6031332746824886,
                                ],
                                [
                                    0.02295023037262981,
                                    0.3322556621039637,
                                    0.04166083284091789,
                                    0.6031332746824886,
                                ],
                                [
                                    0.047877655192203376,
                                    0.9473015638183706,
                                    0.0002319257532310023,
                                    0.004588855236195017,
                                ],
                                [
                                    0.003108411175642751,
                                    0.045001169769791634,
                                    0.061502652037904955,
                                    0.8903877670166607,
                                ],
                                [
                                    0.003108411175642751,
                                    0.061502652037904955,
                                    0.045001169769791634,
                                    0.8903877670166607,
                                ],
                                [
                                    0.06288385580308704,
                                    0.027870251657426,
                                    0.6300198326657538,
                                    0.27922605987373306,
                                ],
                                [
                                    0.06288385580308704,
                                    0.6300198326657538,
                                    0.027870251657426,
                                    0.27922605987373306,
                                ],
                                [
                                    0.04700723809849932,
                                    0.02083370268560098,
                                    0.6458964503703416,
                                    0.2862626088455581,
                                ],
                                [
                                    0.056582630753108765,
                                    0.5668892135127584,
                                    0.03417147670740428,
                                    0.3423566790267285,
                                ],
                                [
                                    0.056582630753108765,
                                    0.03417147670740428,
                                    0.5668892135127584,
                                    0.3423566790267285,
                                ],
                                [
                                    0.04700723809849932,
                                    0.6458964503703416,
                                    0.02083370268560098,
                                    0.2862626088455581,
                                ],
                                [
                                    0.0422969164673945,
                                    0.0255440243167058,
                                    0.5811749277984727,
                                    0.350984131417427,
                                ],
                                [
                                    0.0422969164673945,
                                    0.5811749277984727,
                                    0.0255440243167058,
                                    0.350984131417427,
                                ],
                                [
                                    0.13301729491103362,
                                    0.03775924281980794,
                                    0.6458794825882284,
                                    0.18334397968093008,
                                ],
                                [
                                    0.13301729491103362,
                                    0.6458794825882284,
                                    0.03775924281980794,
                                    0.18334397968093008,
                                ],
                                [
                                    0.048190563291470104,
                                    0.013679718732537583,
                                    0.7307062142077919,
                                    0.20742350376820043,
                                ],
                                [
                                    0.07665941880438289,
                                    0.37222788048730726,
                                    0.09411711892645867,
                                    0.4569955817818512,
                                ],
                                [
                                    0.07665941880438289,
                                    0.09411711892645867,
                                    0.37222788048730726,
                                    0.4569955817818512,
                                ],
                                [
                                    0.048190563291470104,
                                    0.7307062142077919,
                                    0.013679718732537583,
                                    0.20742350376820043,
                                ],
                                [
                                    0.027772783804172013,
                                    0.03409749821983567,
                                    0.4211145154875181,
                                    0.5170152024884742,
                                ],
                                [
                                    0.027772783804172013,
                                    0.4211145154875181,
                                    0.03409749821983567,
                                    0.5170152024884742,
                                ],
                                [
                                    0.24521426170493774,
                                    0.029969200501327356,
                                    0.6458794825882284,
                                    0.07893705520550649,
                                ],
                                [
                                    0.24521426170493774,
                                    0.6458794825882284,
                                    0.029969200501327356,
                                    0.07893705520550649,
                                ],
                                [
                                    0.048190563291470104,
                                    0.005889676414057005,
                                    0.842903181001696,
                                    0.10301657929277684,
                                ],
                                [
                                    0.06084395027271526,
                                    0.16025927222802275,
                                    0.21433951193354986,
                                    0.5645572655657122,
                                ],
                                [
                                    0.06084395027271526,
                                    0.21433951193354986,
                                    0.16025927222802275,
                                    0.5645572655657122,
                                ],
                                [
                                    0.048190563291470104,
                                    0.842903181001696,
                                    0.005889676414057005,
                                    0.10301657929277684,
                                ],
                                [
                                    0.011957315272504406,
                                    0.04212292443302271,
                                    0.2091459072282336,
                                    0.7367738530662393,
                                ],
                                [
                                    0.011957315272504406,
                                    0.2091459072282336,
                                    0.04212292443302271,
                                    0.7367738530662393,
                                ],
                                [
                                    0.34706700065783336,
                                    0.008138891818760149,
                                    0.6300198326657539,
                                    0.014774274857652647,
                                ],
                                [
                                    0.34706700065783336,
                                    0.6300198326657539,
                                    0.008138891818760149,
                                    0.014774274857652647,
                                ],
                                [
                                    0.04700723809849927,
                                    0.001102342846935111,
                                    0.930079595225088,
                                    0.021810823829477684,
                                ],
                                [
                                    0.01652370836765296,
                                    0.029994969158908064,
                                    0.3386821841089405,
                                    0.6147991383644984,
                                ],
                                [
                                    0.01652370836765296,
                                    0.3386821841089405,
                                    0.029994969158908064,
                                    0.6147991383644984,
                                ],
                                [
                                    0.04700723809849927,
                                    0.930079595225088,
                                    0.001102342846935111,
                                    0.021810823829477684,
                                ],
                                [
                                    0.002237994081938647,
                                    0.04587158686349573,
                                    0.044280683444622375,
                                    0.9076097356099433,
                                ],
                                [
                                    0.002237994081938647,
                                    0.044280683444622375,
                                    0.04587158686349573,
                                    0.9076097356099433,
                                ],
                                [
                                    0.03417147670740429,
                                    0.05658263075310876,
                                    0.3423566790267286,
                                    0.5668892135127583,
                                ],
                                [
                                    0.03417147670740429,
                                    0.3423566790267286,
                                    0.05658263075310876,
                                    0.5668892135127583,
                                ],
                                [
                                    0.025544024316705806,
                                    0.042296916467394495,
                                    0.35098413141742707,
                                    0.5811749277984726,
                                ],
                                [
                                    0.027870251657426008,
                                    0.2792260598737331,
                                    0.06288385580308704,
                                    0.6300198326657538,
                                ],
                                [
                                    0.027870251657426008,
                                    0.06288385580308704,
                                    0.2792260598737331,
                                    0.6300198326657538,
                                ],
                                [
                                    0.025544024316705806,
                                    0.35098413141742707,
                                    0.042296916467394495,
                                    0.5811749277984726,
                                ],
                                [
                                    0.020833702685600985,
                                    0.04700723809849932,
                                    0.28626260884555815,
                                    0.6458964503703416,
                                ],
                                [
                                    0.020833702685600985,
                                    0.28626260884555815,
                                    0.04700723809849932,
                                    0.6458964503703416,
                                ],
                                [
                                    0.09411711892645867,
                                    0.07665941880438289,
                                    0.4569955817818512,
                                    0.37222788048730726,
                                ],
                                [
                                    0.09411711892645867,
                                    0.4569955817818512,
                                    0.07665941880438289,
                                    0.37222788048730726,
                                ],
                                [
                                    0.03409749821983567,
                                    0.027772783804172013,
                                    0.5170152024884742,
                                    0.4211145154875181,
                                ],
                                [
                                    0.03775924281980794,
                                    0.18334397968093005,
                                    0.13301729491103362,
                                    0.6458794825882284,
                                ],
                                [
                                    0.03775924281980794,
                                    0.13301729491103362,
                                    0.18334397968093005,
                                    0.6458794825882284,
                                ],
                                [
                                    0.03409749821983567,
                                    0.5170152024884742,
                                    0.027772783804172013,
                                    0.4211145154875181,
                                ],
                                [
                                    0.013679718732537581,
                                    0.048190563291470104,
                                    0.2074235037682004,
                                    0.7307062142077919,
                                ],
                                [
                                    0.013679718732537581,
                                    0.2074235037682004,
                                    0.048190563291470104,
                                    0.7307062142077919,
                                ],
                                [
                                    0.21433951193354986,
                                    0.06084395027271527,
                                    0.5645572655657122,
                                    0.16025927222802275,
                                ],
                                [
                                    0.21433951193354986,
                                    0.5645572655657122,
                                    0.06084395027271527,
                                    0.16025927222802275,
                                ],
                                [
                                    0.04212292443302271,
                                    0.011957315272504408,
                                    0.7367738530662393,
                                    0.20914590722823362,
                                ],
                                [
                                    0.029969200501327363,
                                    0.0789370552055065,
                                    0.24521426170493774,
                                    0.6458794825882284,
                                ],
                                [
                                    0.029969200501327363,
                                    0.24521426170493774,
                                    0.0789370552055065,
                                    0.6458794825882284,
                                ],
                                [
                                    0.04212292443302271,
                                    0.7367738530662393,
                                    0.011957315272504408,
                                    0.20914590722823362,
                                ],
                                [
                                    0.005889676414057006,
                                    0.048190563291470104,
                                    0.10301657929277687,
                                    0.842903181001696,
                                ],
                                [
                                    0.005889676414057006,
                                    0.10301657929277687,
                                    0.048190563291470104,
                                    0.842903181001696,
                                ],
                                [
                                    0.3386821841089406,
                                    0.016523708367652944,
                                    0.6147991383644985,
                                    0.029994969158908025,
                                ],
                                [
                                    0.3386821841089406,
                                    0.6147991383644985,
                                    0.016523708367652944,
                                    0.029994969158908025,
                                ],
                                [
                                    0.04587158686349574,
                                    0.0022379940819386443,
                                    0.9076097356099433,
                                    0.044280683444622326,
                                ],
                                [
                                    0.00813889181876017,
                                    0.014774274857652685,
                                    0.34706700065783336,
                                    0.6300198326657538,
                                ],
                                [
                                    0.00813889181876017,
                                    0.34706700065783336,
                                    0.014774274857652685,
                                    0.6300198326657538,
                                ],
                                [
                                    0.04587158686349574,
                                    0.9076097356099433,
                                    0.0022379940819386443,
                                    0.044280683444622326,
                                ],
                                [
                                    0.001102342846935114,
                                    0.04700723809849927,
                                    0.02181082382947774,
                                    0.9300795952250879,
                                ],
                                [
                                    0.001102342846935114,
                                    0.02181082382947774,
                                    0.04700723809849927,
                                    0.9300795952250879,
                                ],
                                [
                                    0.01216494442399859,
                                    0.07858916303651445,
                                    0.12187796299252288,
                                    0.7873679295469641,
                                ],
                                [
                                    0.01216494442399859,
                                    0.12187796299252288,
                                    0.07858916303651445,
                                    0.7873679295469641,
                                ],
                                [
                                    0.009093596944572872,
                                    0.05874734383952743,
                                    0.1249493104719486,
                                    0.8072097487439511,
                                ],
                                [
                                    0.005863719374020309,
                                    0.05874734383952739,
                                    0.08489038808649274,
                                    0.8504985486999596,
                                ],
                                [
                                    0.005863719374020309,
                                    0.08489038808649274,
                                    0.05874734383952739,
                                    0.8504985486999596,
                                ],
                                [
                                    0.009093596944572872,
                                    0.1249493104719486,
                                    0.05874734383952743,
                                    0.8072097487439511,
                                ],
                                [
                                    0.004383275313468051,
                                    0.06345766547063225,
                                    0.060227787900079655,
                                    0.87193127131582,
                                ],
                                [
                                    0.004383275313468051,
                                    0.060227787900079655,
                                    0.06345766547063225,
                                    0.87193127131582,
                                ],
                                [
                                    0.06430217479445434,
                                    0.10647436293638722,
                                    0.31222598093967857,
                                    0.5169974813294799,
                                ],
                                [
                                    0.06430217479445434,
                                    0.31222598093967857,
                                    0.10647436293638722,
                                    0.5169974813294799,
                                ],
                                [
                                    0.023295903185250287,
                                    0.038574378838757396,
                                    0.35323225254888263,
                                    0.5848974654271097,
                                ],
                                [
                                    0.0079442986878036,
                                    0.038574378838757424,
                                    0.16283223904303795,
                                    0.790649083430401,
                                ],
                                [
                                    0.0079442986878036,
                                    0.16283223904303795,
                                    0.038574378838757424,
                                    0.790649083430401,
                                ],
                                [
                                    0.023295903185250287,
                                    0.35323225254888263,
                                    0.038574378838757396,
                                    0.5848974654271097,
                                ],
                                [
                                    0.002878123697952199,
                                    0.058992158326055484,
                                    0.043640553828608826,
                                    0.8944891641473834,
                                ],
                                [
                                    0.002878123697952199,
                                    0.043640553828608826,
                                    0.058992158326055484,
                                    0.8944891641473834,
                                ],
                                [
                                    0.19067563596834697,
                                    0.08450782623791812,
                                    0.502228052500494,
                                    0.22258848529324093,
                                ],
                                [
                                    0.19067563596834697,
                                    0.502228052500494,
                                    0.08450782623791812,
                                    0.22258848529324093,
                                ],
                                [
                                    0.0374723975652388,
                                    0.016607842140288313,
                                    0.6554312909036021,
                                    0.29048846939087075,
                                ],
                                [
                                    0.0063053245361245095,
                                    0.016607842140288345,
                                    0.26887813767014057,
                                    0.7082086956534466,
                                ],
                                [
                                    0.0063053245361245095,
                                    0.26887813767014057,
                                    0.016607842140288345,
                                    0.7082086956534466,
                                ],
                                [
                                    0.0374723975652388,
                                    0.6554312909036021,
                                    0.016607842140288313,
                                    0.29048846939087075,
                                ],
                                [
                                    0.001239149546273103,
                                    0.052841090159254006,
                                    0.021674017130139753,
                                    0.9242457431643332,
                                ],
                                [
                                    0.001239149546273103,
                                    0.021674017130139753,
                                    0.052841090159254006,
                                    0.9242457431643332,
                                ],
                                [
                                    0.3322556621039637,
                                    0.02295023037262983,
                                    0.6031332746824886,
                                    0.04166083284091792,
                                ],
                                [
                                    0.3322556621039637,
                                    0.6031332746824886,
                                    0.02295023037262983,
                                    0.04166083284091792,
                                ],
                                [
                                    0.045001169769791634,
                                    0.003108411175642753,
                                    0.8903877670166607,
                                    0.06150265203790499,
                                ],
                                [
                                    0.001712369813783281,
                                    0.0031084111756427843,
                                    0.35349352266281026,
                                    0.6416856963477637,
                                ],
                                [
                                    0.001712369813783281,
                                    0.35349352266281026,
                                    0.0031084111756427843,
                                    0.6416856963477637,
                                ],
                                [
                                    0.045001169769791634,
                                    0.8903877670166607,
                                    0.003108411175642753,
                                    0.06150265203790499,
                                ],
                                [
                                    0.00023192575323100455,
                                    0.047877655192203376,
                                    0.004588855236195061,
                                    0.9473015638183706,
                                ],
                                [
                                    0.00023192575323100455,
                                    0.004588855236195061,
                                    0.047877655192203376,
                                    0.9473015638183706,
                                ],
                                [
                                    0.8734643496049797,
                                    0.06033368376259915,
                                    0.06192458718147262,
                                    0.0042773794509485385,
                                ],
                                [
                                    0.8734643496049797,
                                    0.06192458718147262,
                                    0.06033368376259915,
                                    0.0042773794509485385,
                                ],
                                [
                                    0.829951293292698,
                                    0.05732806254831988,
                                    0.10543764349375427,
                                    0.007283000665227806,
                                ],
                                [
                                    0.8086290300351586,
                                    0.05732806254831988,
                                    0.12516900333242015,
                                    0.00887390408410127,
                                ],
                                [
                                    0.8086290300351586,
                                    0.12516900333242015,
                                    0.05732806254831988,
                                    0.00887390408410127,
                                ],
                                [
                                    0.829951293292698,
                                    0.10543764349375427,
                                    0.05732806254831988,
                                    0.007283000665227806,
                                ],
                                [
                                    0.7683458512934296,
                                    0.11893350454758833,
                                    0.09761124129004899,
                                    0.015109402868933091,
                                ],
                                [
                                    0.7683458512934296,
                                    0.09761124129004899,
                                    0.11893350454758833,
                                    0.015109402868933091,
                                ],
                                [
                                    0.9019168239993326,
                                    0.044002936295140405,
                                    0.05156449847410651,
                                    0.002515741231420529,
                                ],
                                [
                                    0.9019168239993326,
                                    0.05156449847410651,
                                    0.044002936295140405,
                                    0.002515741231420529,
                                ],
                                [
                                    0.6910990310061899,
                                    0.03371750678754513,
                                    0.26238229146724923,
                                    0.012801170739015813,
                                ],
                                [
                                    0.5897543374783221,
                                    0.03371750678754513,
                                    0.3561654228161509,
                                    0.020362732917981918,
                                ],
                                [
                                    0.5897543374783221,
                                    0.3561654228161509,
                                    0.03371750678754513,
                                    0.020362732917981918,
                                ],
                                [
                                    0.6910990310061899,
                                    0.26238229146724923,
                                    0.03371750678754513,
                                    0.012801170739015813,
                                ],
                                [
                                    0.4519027035726606,
                                    0.2729138342210744,
                                    0.17156914069320664,
                                    0.10361432151305841,
                                ],
                                [
                                    0.4519027035726606,
                                    0.17156914069320664,
                                    0.2729138342210744,
                                    0.10361432151305841,
                                ],
                                [
                                    0.9396988292294692,
                                    0.022036399596671342,
                                    0.037388004094118014,
                                    0.0008767670797414366,
                                ],
                                [
                                    0.9396988292294692,
                                    0.037388004094118014,
                                    0.022036399596671342,
                                    0.0008767670797414366,
                                ],
                                [
                                    0.5010969594453744,
                                    0.011750970089076057,
                                    0.4759898738782129,
                                    0.01116219658733672,
                                ],
                                [
                                    0.2953453414420831,
                                    0.01175097008907606,
                                    0.6663898873840575,
                                    0.026513801084783392,
                                ],
                                [
                                    0.2953453414420831,
                                    0.6663898873840575,
                                    0.01175097008907606,
                                    0.026513801084783392,
                                ],
                                [
                                    0.5010969594453744,
                                    0.4759898738782129,
                                    0.011750970089076057,
                                    0.01116219658733672,
                                ],
                                [
                                    0.1574937075364215,
                                    0.35535422199802885,
                                    0.1496026039947376,
                                    0.33754946647081197,
                                ],
                                [
                                    0.1574937075364215,
                                    0.1496026039947376,
                                    0.35535422199802885,
                                    0.33754946647081197,
                                ],
                                [
                                    0.9691622046543201,
                                    0.004694751098714525,
                                    0.026017014356253844,
                                    0.00012602989071149376,
                                ],
                                [
                                    0.9691622046543201,
                                    0.026017014356253844,
                                    0.004694751098714525,
                                    0.00012602989071149376,
                                ],
                                [
                                    0.3486959816027323,
                                    0.0016891298844352535,
                                    0.6464832374078416,
                                    0.0031316511049907653,
                                ],
                                [
                                    0.06292193332911244,
                                    0.001689129884435252,
                                    0.9109350224239222,
                                    0.024453914362530086,
                                ],
                                [
                                    0.06292193332911244,
                                    0.9109350224239222,
                                    0.001689129884435252,
                                    0.024453914362530086,
                                ],
                                [
                                    0.3486959816027323,
                                    0.6464832374078416,
                                    0.0016891298844352535,
                                    0.0031316511049907653,
                                ],
                                [
                                    0.022638754587383344,
                                    0.3277463568997842,
                                    0.04197230862616436,
                                    0.607642579886668,
                                ],
                                [
                                    0.022638754587383344,
                                    0.04197230862616436,
                                    0.3277463568997842,
                                    0.607642579886668,
                                ],
                                [
                                    0.6470321016053451,
                                    0.28676593176223364,
                                    0.045871586863495746,
                                    0.020330379768925405,
                                ],
                                [
                                    0.6470321016053451,
                                    0.045871586863495746,
                                    0.28676593176223364,
                                    0.020330379768925405,
                                ],
                                [
                                    0.6147991383644985,
                                    0.2724802174765194,
                                    0.07810455010434239,
                                    0.03461609405463969,
                                ],
                                [
                                    0.5821967820355242,
                                    0.041275062230343024,
                                    0.35160125133205467,
                                    0.024926904402078134,
                                ],
                                [
                                    0.5821967820355242,
                                    0.35160125133205467,
                                    0.041275062230343024,
                                    0.024926904402078134,
                                ],
                                [
                                    0.6147991383644985,
                                    0.07810455010434239,
                                    0.2724802174765194,
                                    0.03461609405463969,
                                ],
                                [
                                    0.5531936963652301,
                                    0.33408565947578783,
                                    0.07027814790063712,
                                    0.042442496258344974,
                                ],
                                [
                                    0.5531936963652301,
                                    0.07027814790063712,
                                    0.33408565947578783,
                                    0.042442496258344974,
                                ],
                                [
                                    0.7367738530662394,
                                    0.20914590722823365,
                                    0.04212292443302265,
                                    0.011957315272504392,
                                ],
                                [
                                    0.7367738530662394,
                                    0.04212292443302265,
                                    0.20914590722823365,
                                    0.011957315272504392,
                                ],
                                [
                                    0.5645572655657123,
                                    0.16025927222802278,
                                    0.2143395119335498,
                                    0.060843950272715254,
                                ],
                                [
                                    0.4246113665452289,
                                    0.02427593274646126,
                                    0.5213083937492441,
                                    0.02980430695906578,
                                ],
                                [
                                    0.4246113665452289,
                                    0.5213083937492441,
                                    0.02427593274646126,
                                    0.02980430695906578,
                                ],
                                [
                                    0.5645572655657123,
                                    0.2143395119335498,
                                    0.16025927222802278,
                                    0.060843950272715254,
                                ],
                                [
                                    0.325360938132183,
                                    0.39945559966155203,
                                    0.1235263611595072,
                                    0.15165710104675786,
                                ],
                                [
                                    0.325360938132183,
                                    0.1235263611595072,
                                    0.39945559966155203,
                                    0.15165710104675786,
                                ],
                                [
                                    0.8569962460733306,
                                    0.10473898275281003,
                                    0.034097498219835626,
                                    0.004167272954023822,
                                ],
                                [
                                    0.8569962460733306,
                                    0.034097498219835626,
                                    0.10473898275281003,
                                    0.004167272954023822,
                                ],
                                [
                                    0.4569955817818512,
                                    0.05585234775259916,
                                    0.4340981625113149,
                                    0.05305390795423469,
                                ],
                                [
                                    0.21264275828594434,
                                    0.008460464214793672,
                                    0.7490924705401962,
                                    0.02980430695906578,
                                ],
                                [
                                    0.21264275828594434,
                                    0.7490924705401962,
                                    0.008460464214793672,
                                    0.02980430695906578,
                                ],
                                [
                                    0.4569955817818512,
                                    0.4340981625113149,
                                    0.05585234775259916,
                                    0.05305390795423469,
                                ],
                                [
                                    0.11339232987289838,
                                    0.399455599661552,
                                    0.1077108926278396,
                                    0.37944117783771,
                                ],
                                [
                                    0.11339232987289838,
                                    0.1077108926278396,
                                    0.399455599661552,
                                    0.37944117783771,
                                ],
                                [
                                    0.9515428090068815,
                                    0.022314146746153243,
                                    0.02554402431670579,
                                    0.0005990199302595515,
                                ],
                                [
                                    0.9515428090068815,
                                    0.02554402431670579,
                                    0.022314146746153243,
                                    0.0005990199302595515,
                                ],
                                [
                                    0.3423566790267286,
                                    0.00802843246043895,
                                    0.6347301542968586,
                                    0.014884734215973847,
                                ],
                                [
                                    0.045302537681673825,
                                    0.0012161398448871969,
                                    0.9285544180713609,
                                    0.02492690440207814,
                                ],
                                [
                                    0.045302537681673825,
                                    0.9285544180713609,
                                    0.0012161398448871969,
                                    0.02492690440207814,
                                ],
                                [
                                    0.3423566790267286,
                                    0.6347301542968586,
                                    0.00802843246043895,
                                    0.014884734215973847,
                                ],
                                [
                                    0.01629945201137968,
                                    0.3340856594757879,
                                    0.030219225515181344,
                                    0.6193956629976511,
                                ],
                                [
                                    0.01629945201137968,
                                    0.030219225515181344,
                                    0.3340856594757879,
                                    0.6193956629976511,
                                ],
                                [
                                    0.3516012513320547,
                                    0.582196782035524,
                                    0.024926904402078145,
                                    0.04127506223034302,
                                ],
                                [
                                    0.3516012513320547,
                                    0.024926904402078145,
                                    0.582196782035524,
                                    0.04127506223034302,
                                ],
                                [
                                    0.3340856594757879,
                                    0.55319369636523,
                                    0.04244249625834499,
                                    0.0702781479006371,
                                ],
                                [
                                    0.2867659317622337,
                                    0.02033037976892541,
                                    0.6470321016053451,
                                    0.045871586863495746,
                                ],
                                [
                                    0.2867659317622337,
                                    0.6470321016053451,
                                    0.02033037976892541,
                                    0.045871586863495746,
                                ],
                                [
                                    0.3340856594757879,
                                    0.04244249625834499,
                                    0.55319369636523,
                                    0.0702781479006371,
                                ],
                                [
                                    0.27248021747651946,
                                    0.6147991383644985,
                                    0.034616094054639696,
                                    0.07810455010434239,
                                ],
                                [
                                    0.27248021747651946,
                                    0.034616094054639696,
                                    0.6147991383644985,
                                    0.07810455010434239,
                                ],
                                [
                                    0.5213083937492441,
                                    0.4246113665452289,
                                    0.02980430695906578,
                                    0.02427593274646126,
                                ],
                                [
                                    0.5213083937492441,
                                    0.02980430695906578,
                                    0.4246113665452289,
                                    0.02427593274646126,
                                ],
                                [
                                    0.39945559966155203,
                                    0.325360938132183,
                                    0.15165710104675786,
                                    0.1235263611595072,
                                ],
                                [
                                    0.20914590722823362,
                                    0.01195731527250439,
                                    0.7367738530662394,
                                    0.04212292443302265,
                                ],
                                [
                                    0.20914590722823362,
                                    0.7367738530662394,
                                    0.01195731527250439,
                                    0.04212292443302265,
                                ],
                                [
                                    0.39945559966155203,
                                    0.15165710104675786,
                                    0.325360938132183,
                                    0.1235263611595072,
                                ],
                                [
                                    0.16025927222802275,
                                    0.5645572655657123,
                                    0.06084395027271525,
                                    0.2143395119335498,
                                ],
                                [
                                    0.16025927222802275,
                                    0.06084395027271525,
                                    0.5645572655657123,
                                    0.2143395119335498,
                                ],
                                [
                                    0.7490924705401962,
                                    0.21264275828594437,
                                    0.02980430695906578,
                                    0.008460464214793673,
                                ],
                                [
                                    0.7490924705401962,
                                    0.02980430695906578,
                                    0.21264275828594437,
                                    0.008460464214793673,
                                ],
                                [
                                    0.399455599661552,
                                    0.11339232987289839,
                                    0.37944117783771,
                                    0.10771089262783962,
                                ],
                                [
                                    0.10473898275281006,
                                    0.004167272954023823,
                                    0.8569962460733306,
                                    0.034097498219835626,
                                ],
                                [
                                    0.10473898275281006,
                                    0.8569962460733306,
                                    0.004167272954023823,
                                    0.034097498219835626,
                                ],
                                [
                                    0.399455599661552,
                                    0.37944117783771,
                                    0.11339232987289839,
                                    0.10771089262783962,
                                ],
                                [
                                    0.055852347752599174,
                                    0.4569955817818512,
                                    0.053053907954234696,
                                    0.4340981625113149,
                                ],
                                [
                                    0.055852347752599174,
                                    0.053053907954234696,
                                    0.4569955817818512,
                                    0.4340981625113149,
                                ],
                                [
                                    0.928554418071361,
                                    0.04530253768167378,
                                    0.024926904402078145,
                                    0.0012161398448871956,
                                ],
                                [
                                    0.928554418071361,
                                    0.024926904402078145,
                                    0.04530253768167378,
                                    0.0012161398448871956,
                                ],
                                [
                                    0.3340856594757879,
                                    0.01629945201137966,
                                    0.6193956629976511,
                                    0.03021922551518131,
                                ],
                                [
                                    0.022314146746153302,
                                    0.000599019930259553,
                                    0.9515428090068814,
                                    0.025544024316705785,
                                ],
                                [
                                    0.022314146746153302,
                                    0.9515428090068814,
                                    0.000599019930259553,
                                    0.025544024316705785,
                                ],
                                [
                                    0.3340856594757879,
                                    0.6193956629976511,
                                    0.01629945201137966,
                                    0.03021922551518131,
                                ],
                                [
                                    0.00802843246043897,
                                    0.34235667902672856,
                                    0.014884734215973885,
                                    0.6347301542968585,
                                ],
                                [
                                    0.00802843246043897,
                                    0.014884734215973885,
                                    0.34235667902672856,
                                    0.6347301542968585,
                                ],
                                [
                                    0.1251690033324202,
                                    0.8086290300351586,
                                    0.008873904084101273,
                                    0.05732806254831988,
                                ],
                                [
                                    0.1251690033324202,
                                    0.008873904084101273,
                                    0.8086290300351586,
                                    0.05732806254831988,
                                ],
                                [
                                    0.11893350454758837,
                                    0.7683458512934296,
                                    0.015109402868933098,
                                    0.09761124129004899,
                                ],
                                [
                                    0.06033368376259916,
                                    0.004277379450948539,
                                    0.8734643496049797,
                                    0.06192458718147262,
                                ],
                                [
                                    0.06033368376259916,
                                    0.8734643496049797,
                                    0.004277379450948539,
                                    0.06192458718147262,
                                ],
                                [
                                    0.11893350454758837,
                                    0.015109402868933098,
                                    0.7683458512934296,
                                    0.09761124129004899,
                                ],
                                [
                                    0.057328062548319896,
                                    0.829951293292698,
                                    0.007283000665227808,
                                    0.10543764349375427,
                                ],
                                [
                                    0.057328062548319896,
                                    0.007283000665227808,
                                    0.829951293292698,
                                    0.10543764349375427,
                                ],
                                [
                                    0.356165422816151,
                                    0.5897543374783221,
                                    0.020362732917981925,
                                    0.03371750678754512,
                                ],
                                [
                                    0.356165422816151,
                                    0.020362732917981925,
                                    0.5897543374783221,
                                    0.03371750678754512,
                                ],
                                [
                                    0.27291383422107446,
                                    0.45190270357266055,
                                    0.10361432151305844,
                                    0.1715691406932066,
                                ],
                                [
                                    0.044002936295140495,
                                    0.002515741231420534,
                                    0.9019168239993325,
                                    0.051564498474106504,
                                ],
                                [
                                    0.044002936295140495,
                                    0.9019168239993325,
                                    0.002515741231420534,
                                    0.051564498474106504,
                                ],
                                [
                                    0.27291383422107446,
                                    0.10361432151305844,
                                    0.45190270357266055,
                                    0.1715691406932066,
                                ],
                                [
                                    0.03371750678754519,
                                    0.6910990310061899,
                                    0.012801170739015837,
                                    0.26238229146724923,
                                ],
                                [
                                    0.03371750678754519,
                                    0.012801170739015837,
                                    0.6910990310061899,
                                    0.26238229146724923,
                                ],
                                [
                                    0.6663898873840575,
                                    0.295345341442083,
                                    0.026513801084783392,
                                    0.011750970089076057,
                                ],
                                [
                                    0.6663898873840575,
                                    0.026513801084783392,
                                    0.295345341442083,
                                    0.011750970089076057,
                                ],
                                [
                                    0.35535422199802885,
                                    0.15749370753642147,
                                    0.33754946647081197,
                                    0.14960260399473757,
                                ],
                                [
                                    0.022036399596671415,
                                    0.0008767670797414396,
                                    0.9396988292294692,
                                    0.037388004094118014,
                                ],
                                [
                                    0.022036399596671415,
                                    0.9396988292294692,
                                    0.0008767670797414396,
                                    0.037388004094118014,
                                ],
                                [
                                    0.35535422199802885,
                                    0.33754946647081197,
                                    0.15749370753642147,
                                    0.14960260399473757,
                                ],
                                [
                                    0.011750970089076097,
                                    0.5010969594453742,
                                    0.011162196587336758,
                                    0.47598987387821284,
                                ],
                                [
                                    0.011750970089076097,
                                    0.011162196587336758,
                                    0.5010969594453742,
                                    0.47598987387821284,
                                ],
                                [
                                    0.9109350224239222,
                                    0.06292193332911249,
                                    0.024453914362530086,
                                    0.001689129884435253,
                                ],
                                [
                                    0.9109350224239222,
                                    0.024453914362530086,
                                    0.06292193332911249,
                                    0.001689129884435253,
                                ],
                                [
                                    0.3277463568997842,
                                    0.022638754587383358,
                                    0.607642579886668,
                                    0.04197230862616439,
                                ],
                                [
                                    0.004694751098714571,
                                    0.00012602989071149498,
                                    0.9691622046543201,
                                    0.026017014356253844,
                                ],
                                [
                                    0.004694751098714571,
                                    0.9691622046543201,
                                    0.00012602989071149498,
                                    0.026017014356253844,
                                ],
                                [
                                    0.3277463568997842,
                                    0.607642579886668,
                                    0.022638754587383358,
                                    0.04197230862616439,
                                ],
                                [
                                    0.00168912988443527,
                                    0.3486959816027323,
                                    0.0031316511049907956,
                                    0.6464832374078416,
                                ],
                                [
                                    0.00168912988443527,
                                    0.0031316511049907956,
                                    0.3486959816027323,
                                    0.6464832374078416,
                                ],
                                [
                                    0.6410614428452525,
                                    0.044280683444622285,
                                    0.2943274939411998,
                                    0.020330379768925405,
                                ],
                                [
                                    0.6410614428452525,
                                    0.2943274939411998,
                                    0.044280683444622285,
                                    0.020330379768925405,
                                ],
                                [
                                    0.5975483865329708,
                                    0.04127506223034302,
                                    0.3378405502534815,
                                    0.023336000983204673,
                                ],
                                [
                                    0.5934768751069591,
                                    0.2724802174765194,
                                    0.09186525118291561,
                                    0.0421776562336058,
                                ],
                                [
                                    0.5934768751069591,
                                    0.09186525118291561,
                                    0.2724802174765194,
                                    0.0421776562336058,
                                ],
                                [
                                    0.5975483865329708,
                                    0.3378405502534815,
                                    0.04127506223034302,
                                    0.023336000983204673,
                                ],
                                [
                                    0.5531936963652301,
                                    0.08562975239808379,
                                    0.3127633962182485,
                                    0.048413155018437626,
                                ],
                                [
                                    0.5531936963652301,
                                    0.3127633962182485,
                                    0.08562975239808379,
                                    0.048413155018437626,
                                ],
                                [
                                    0.7083953186258528,
                                    0.03456136225405654,
                                    0.24508600384758628,
                                    0.011957315272504392,
                                ],
                                [
                                    0.7083953186258528,
                                    0.24508600384758628,
                                    0.03456136225405654,
                                    0.011957315272504392,
                                ],
                                [
                                    0.49757752563271007,
                                    0.024275932746461257,
                                    0.455903796840729,
                                    0.022242744780099678,
                                ],
                                [
                                    0.46321257203784444,
                                    0.16025927222802278,
                                    0.27974410884206485,
                                    0.09678404689206789,
                                ],
                                [
                                    0.46321257203784444,
                                    0.27974410884206485,
                                    0.16025927222802278,
                                    0.09678404689206789,
                                ],
                                [
                                    0.49757752563271007,
                                    0.455903796840729,
                                    0.024275932746461257,
                                    0.022242744780099678,
                                ],
                                [
                                    0.3253609381321829,
                                    0.1964925202469884,
                                    0.2981109061336843,
                                    0.18003563548714438,
                                ],
                                [
                                    0.3253609381321829,
                                    0.2981109061336843,
                                    0.1964925202469884,
                                    0.18003563548714438,
                                ],
                                [
                                    0.7993816914832961,
                                    0.018745893722388957,
                                    0.17770514184029126,
                                    0.004167272954023822,
                                ],
                                [
                                    0.7993816914832961,
                                    0.17770514184029126,
                                    0.018745893722388957,
                                    0.004167272954023822,
                                ],
                                [
                                    0.36077982169920114,
                                    0.008460464214793673,
                                    0.6163070116243861,
                                    0.014452702461619105,
                                ],
                                [
                                    0.25124396377855995,
                                    0.055852347752599174,
                                    0.566883621427125,
                                    0.1260200670417159,
                                ],
                                [
                                    0.25124396377855995,
                                    0.566883621427125,
                                    0.055852347752599174,
                                    0.1260200670417159,
                                ],
                                [
                                    0.36077982169920114,
                                    0.6163070116243861,
                                    0.008460464214793673,
                                    0.014452702461619105,
                                ],
                                [
                                    0.11339232987289842,
                                    0.2558479560410964,
                                    0.1937039816582607,
                                    0.4370557324277445,
                                ],
                                [
                                    0.11339232987289842,
                                    0.1937039816582607,
                                    0.2558479560410964,
                                    0.4370557324277445,
                                ],
                                [
                                    0.871520378736553,
                                    0.004221761059166467,
                                    0.123658840274021,
                                    0.0005990199302595516,
                                ],
                                [
                                    0.871520378736553,
                                    0.123658840274021,
                                    0.004221761059166467,
                                    0.0005990199302595516,
                                ],
                                [
                                    0.25105415568496514,
                                    0.0012161398448871958,
                                    0.7441250633256088,
                                    0.0036046411445388228,
                                ],
                                [
                                    0.05658263075310876,
                                    0.008028432460438944,
                                    0.8191595090426107,
                                    0.11622942774384162,
                                ],
                                [
                                    0.05658263075310876,
                                    0.8191595090426107,
                                    0.008028432460438944,
                                    0.11622942774384162,
                                ],
                                [
                                    0.25105415568496514,
                                    0.7441250633256088,
                                    0.0012161398448871958,
                                    0.0036046411445388228,
                                ],
                                [
                                    0.016299452011379653,
                                    0.23597084351847272,
                                    0.04831161120216805,
                                    0.6994180932679795,
                                ],
                                [
                                    0.016299452011379653,
                                    0.04831161120216805,
                                    0.23597084351847272,
                                    0.6994180932679795,
                                ],
                                [
                                    0.4748760871693324,
                                    0.21046603912054235,
                                    0.2180276012995085,
                                    0.09663027241061672,
                                ],
                                [
                                    0.4748760871693324,
                                    0.2180276012995085,
                                    0.21046603912054235,
                                    0.09663027241061672,
                                ],
                                [
                                    0.44264312392848576,
                                    0.19618032483482808,
                                    0.2502605645403551,
                                    0.110915986696331,
                                ],
                                [
                                    0.4272915194310391,
                                    0.1961803248348281,
                                    0.2580506068588357,
                                    0.11847754887529711,
                                ],
                                [
                                    0.4272915194310391,
                                    0.2580506068588357,
                                    0.1961803248348281,
                                    0.11847754887529711,
                                ],
                                [
                                    0.44264312392848576,
                                    0.2502605645403551,
                                    0.19618032483482808,
                                    0.110915986696331,
                                ],
                                [
                                    0.398288433760745,
                                    0.24053501500256885,
                                    0.2251834105051222,
                                    0.13599314073156393,
                                ],
                                [
                                    0.398288433760745,
                                    0.2251834105051222,
                                    0.24053501500256885,
                                    0.13599314073156393,
                                ],
                                [
                                    0.5786865645589089,
                                    0.1642701163210004,
                                    0.20021021294035304,
                                    0.05683310617973761,
                                ],
                                [
                                    0.5786865645589089,
                                    0.20021021294035304,
                                    0.1642701163210004,
                                    0.05683310617973761,
                                ],
                                [
                                    0.4064699770583818,
                                    0.11538348132078954,
                                    0.3724268004408802,
                                    0.10571974117994848,
                                ],
                                [
                                    0.33350381797090056,
                                    0.11538348132078954,
                                    0.40945286290900873,
                                    0.1416598377993011,
                                ],
                                [
                                    0.33350381797090056,
                                    0.40945286290900873,
                                    0.11538348132078954,
                                    0.1416598377993011,
                                ],
                                [
                                    0.4064699770583818,
                                    0.3724268004408802,
                                    0.11538348132078954,
                                    0.10571974117994848,
                                ],
                                [
                                    0.23425338955785463,
                                    0.28760006882131667,
                                    0.2146339097338355,
                                    0.2635126318869932,
                                ],
                                [
                                    0.23425338955785463,
                                    0.2146339097338355,
                                    0.28760006882131667,
                                    0.2635126318869932,
                                ],
                                [
                                    0.7290283732104601,
                                    0.08909921199522482,
                                    0.16206537108270602,
                                    0.01980704371160903,
                                ],
                                [
                                    0.7290283732104601,
                                    0.16206537108270602,
                                    0.08909921199522482,
                                    0.01980704371160903,
                                ],
                                [
                                    0.32902770891898087,
                                    0.04021257699501396,
                                    0.5620660353741853,
                                    0.06869367871181989,
                                ],
                                [
                                    0.18089064550572403,
                                    0.04021257699501396,
                                    0.6372369396999609,
                                    0.1416598377993011,
                                ],
                                [
                                    0.18089064550572403,
                                    0.6372369396999609,
                                    0.04021257699501396,
                                    0.1416598377993011,
                                ],
                                [
                                    0.32902770891898087,
                                    0.5620660353741853,
                                    0.04021257699501396,
                                    0.06869367871181989,
                                ],
                                [
                                    0.08164021709267812,
                                    0.2876000688213167,
                                    0.1394630054080599,
                                    0.4912967086779453,
                                ],
                                [
                                    0.08164021709267812,
                                    0.1394630054080599,
                                    0.2876000688213167,
                                    0.4912967086779453,
                                ],
                                [
                                    0.8556761141810217,
                                    0.020066025614697714,
                                    0.12141071914256549,
                                    0.002847141061715081,
                                ],
                                [
                                    0.8556761141810217,
                                    0.12141071914256549,
                                    0.020066025614697714,
                                    0.002847141061715081,
                                ],
                                [
                                    0.24648998420086896,
                                    0.005780311328983421,
                                    0.7305968491227183,
                                    0.017132855347429376,
                                ],
                                [
                                    0.0407383661975776,
                                    0.005780311328983428,
                                    0.8350037735981418,
                                    0.11847754887529713,
                                ],
                                [
                                    0.0407383661975776,
                                    0.8350037735981418,
                                    0.005780311328983428,
                                    0.11847754887529713,
                                ],
                                [
                                    0.24648998420086896,
                                    0.7305968491227183,
                                    0.005780311328983421,
                                    0.017132855347429376,
                                ],
                                [
                                    0.011735280527283452,
                                    0.2405350150025689,
                                    0.03478339699927757,
                                    0.7129463074708701,
                                ],
                                [
                                    0.011735280527283452,
                                    0.03478339699927757,
                                    0.2405350150025689,
                                    0.7129463074708701,
                                ],
                                [
                                    0.25805060685883574,
                                    0.42729151943103905,
                                    0.11847754887529714,
                                    0.19618032483482806,
                                ],
                                [
                                    0.25805060685883574,
                                    0.11847754887529714,
                                    0.42729151943103905,
                                    0.19618032483482806,
                                ],
                                [
                                    0.2405350150025689,
                                    0.39828843376074496,
                                    0.135993140731564,
                                    0.22518341050512214,
                                ],
                                [
                                    0.2104660391205424,
                                    0.09663027241061674,
                                    0.4748760871693324,
                                    0.2180276012995085,
                                ],
                                [
                                    0.2104660391205424,
                                    0.4748760871693324,
                                    0.09663027241061674,
                                    0.2180276012995085,
                                ],
                                [
                                    0.2405350150025689,
                                    0.135993140731564,
                                    0.39828843376074496,
                                    0.22518341050512214,
                                ],
                                [
                                    0.1961803248348281,
                                    0.44264312392848576,
                                    0.11091598669633101,
                                    0.2502605645403551,
                                ],
                                [
                                    0.1961803248348281,
                                    0.11091598669633101,
                                    0.44264312392848576,
                                    0.2502605645403551,
                                ],
                                [
                                    0.40945286290900873,
                                    0.33350381797090056,
                                    0.1416598377993011,
                                    0.11538348132078954,
                                ],
                                [
                                    0.40945286290900873,
                                    0.1416598377993011,
                                    0.33350381797090056,
                                    0.11538348132078954,
                                ],
                                [
                                    0.28760006882131667,
                                    0.23425338955785463,
                                    0.2635126318869932,
                                    0.2146339097338355,
                                ],
                                [
                                    0.1642701163210004,
                                    0.0568331061797376,
                                    0.5786865645589089,
                                    0.20021021294035304,
                                ],
                                [
                                    0.1642701163210004,
                                    0.5786865645589089,
                                    0.0568331061797376,
                                    0.20021021294035304,
                                ],
                                [
                                    0.28760006882131667,
                                    0.2635126318869932,
                                    0.23425338955785463,
                                    0.2146339097338355,
                                ],
                                [
                                    0.11538348132078953,
                                    0.4064699770583818,
                                    0.10571974117994846,
                                    0.3724268004408802,
                                ],
                                [
                                    0.11538348132078953,
                                    0.10571974117994846,
                                    0.4064699770583818,
                                    0.3724268004408802,
                                ],
                                [
                                    0.6372369396999609,
                                    0.18089064550572406,
                                    0.1416598377993011,
                                    0.04021257699501396,
                                ],
                                [
                                    0.6372369396999609,
                                    0.1416598377993011,
                                    0.18089064550572406,
                                    0.04021257699501396,
                                ],
                                [
                                    0.2876000688213167,
                                    0.08164021709267812,
                                    0.4912967086779453,
                                    0.1394630054080599,
                                ],
                                [
                                    0.08909921199522484,
                                    0.019807043711609032,
                                    0.7290283732104601,
                                    0.16206537108270602,
                                ],
                                [
                                    0.08909921199522484,
                                    0.7290283732104601,
                                    0.019807043711609032,
                                    0.16206537108270602,
                                ],
                                [
                                    0.2876000688213167,
                                    0.4912967086779453,
                                    0.08164021709267812,
                                    0.1394630054080599,
                                ],
                                [
                                    0.040212576995013974,
                                    0.32902770891898087,
                                    0.0686936787118199,
                                    0.5620660353741853,
                                ],
                                [
                                    0.040212576995013974,
                                    0.0686936787118199,
                                    0.32902770891898087,
                                    0.5620660353741853,
                                ],
                                [
                                    0.8350037735981419,
                                    0.04073836619757755,
                                    0.11847754887529714,
                                    0.005780311328983421,
                                ],
                                [
                                    0.8350037735981419,
                                    0.11847754887529714,
                                    0.04073836619757755,
                                    0.005780311328983421,
                                ],
                                [
                                    0.24053501500256894,
                                    0.011735280527283438,
                                    0.7129463074708702,
                                    0.03478339699927753,
                                ],
                                [
                                    0.020066025614697766,
                                    0.0028471410617150884,
                                    0.8556761141810217,
                                    0.12141071914256547,
                                ],
                                [
                                    0.020066025614697766,
                                    0.8556761141810217,
                                    0.0028471410617150884,
                                    0.12141071914256547,
                                ],
                                [
                                    0.24053501500256894,
                                    0.7129463074708702,
                                    0.011735280527283438,
                                    0.03478339699927753,
                                ],
                                [
                                    0.005780311328983436,
                                    0.24648998420086893,
                                    0.017132855347429417,
                                    0.7305968491227183,
                                ],
                                [
                                    0.005780311328983436,
                                    0.017132855347429417,
                                    0.24648998420086893,
                                    0.7305968491227183,
                                ],
                                [
                                    0.09186525118291565,
                                    0.5934768751069591,
                                    0.04217765623360582,
                                    0.2724802174765194,
                                ],
                                [
                                    0.09186525118291565,
                                    0.04217765623360582,
                                    0.5934768751069591,
                                    0.2724802174765194,
                                ],
                                [
                                    0.08562975239808383,
                                    0.5531936963652301,
                                    0.04841315501843764,
                                    0.3127633962182485,
                                ],
                                [
                                    0.04428068344462229,
                                    0.02033037976892541,
                                    0.6410614428452525,
                                    0.2943274939411998,
                                ],
                                [
                                    0.04428068344462229,
                                    0.6410614428452525,
                                    0.02033037976892541,
                                    0.2943274939411998,
                                ],
                                [
                                    0.08562975239808383,
                                    0.04841315501843764,
                                    0.5531936963652301,
                                    0.3127633962182485,
                                ],
                                [
                                    0.041275062230343024,
                                    0.5975483865329708,
                                    0.02333600098320468,
                                    0.3378405502534815,
                                ],
                                [
                                    0.041275062230343024,
                                    0.02333600098320468,
                                    0.5975483865329708,
                                    0.3378405502534815,
                                ],
                                [
                                    0.27974410884206496,
                                    0.46321257203784433,
                                    0.09678404689206792,
                                    0.16025927222802275,
                                ],
                                [
                                    0.27974410884206496,
                                    0.09678404689206792,
                                    0.46321257203784433,
                                    0.16025927222802275,
                                ],
                                [
                                    0.19649252024698846,
                                    0.32536093813218286,
                                    0.18003563548714444,
                                    0.29811090613368424,
                                ],
                                [
                                    0.03456136225405661,
                                    0.011957315272504414,
                                    0.7083953186258527,
                                    0.24508600384758625,
                                ],
                                [
                                    0.03456136225405661,
                                    0.7083953186258527,
                                    0.011957315272504414,
                                    0.24508600384758625,
                                ],
                                [
                                    0.19649252024698846,
                                    0.18003563548714444,
                                    0.32536093813218286,
                                    0.29811090613368424,
                                ],
                                [
                                    0.024275932746461306,
                                    0.49757752563271,
                                    0.02224274478009972,
                                    0.45590379684072896,
                                ],
                                [
                                    0.024275932746461306,
                                    0.02224274478009972,
                                    0.49757752563271,
                                    0.45590379684072896,
                                ],
                                [
                                    0.566883621427125,
                                    0.2512439637785599,
                                    0.1260200670417159,
                                    0.05585234775259917,
                                ],
                                [
                                    0.566883621427125,
                                    0.1260200670417159,
                                    0.2512439637785599,
                                    0.05585234775259917,
                                ],
                                [
                                    0.2558479560410964,
                                    0.1133923298728984,
                                    0.4370557324277445,
                                    0.19370398165826067,
                                ],
                                [
                                    0.01874589372238902,
                                    0.004167272954023836,
                                    0.799381691483296,
                                    0.17770514184029124,
                                ],
                                [
                                    0.01874589372238902,
                                    0.799381691483296,
                                    0.004167272954023836,
                                    0.17770514184029124,
                                ],
                                [
                                    0.2558479560410964,
                                    0.4370557324277445,
                                    0.1133923298728984,
                                    0.19370398165826067,
                                ],
                                [
                                    0.008460464214793701,
                                    0.36077982169920114,
                                    0.014452702461619154,
                                    0.6163070116243861,
                                ],
                                [
                                    0.008460464214793701,
                                    0.014452702461619154,
                                    0.36077982169920114,
                                    0.6163070116243861,
                                ],
                                [
                                    0.8191595090426107,
                                    0.0565826307531088,
                                    0.11622942774384162,
                                    0.00802843246043895,
                                ],
                                [
                                    0.8191595090426107,
                                    0.11622942774384162,
                                    0.0565826307531088,
                                    0.00802843246043895,
                                ],
                                [
                                    0.23597084351847272,
                                    0.016299452011379664,
                                    0.6994180932679795,
                                    0.048311611202168085,
                                ],
                                [
                                    0.004221761059166509,
                                    0.0005990199302595574,
                                    0.871520378736553,
                                    0.123658840274021,
                                ],
                                [
                                    0.004221761059166509,
                                    0.871520378736553,
                                    0.0005990199302595574,
                                    0.123658840274021,
                                ],
                                [
                                    0.23597084351847272,
                                    0.6994180932679795,
                                    0.016299452011379664,
                                    0.048311611202168085,
                                ],
                                [
                                    0.0012161398448872077,
                                    0.25105415568496514,
                                    0.003604641144538858,
                                    0.7441250633256088,
                                ],
                                [
                                    0.0012161398448872077,
                                    0.003604641144538858,
                                    0.25105415568496514,
                                    0.7441250633256088,
                                ],
                                [
                                    0.3378405502534815,
                                    0.023336000983204673,
                                    0.5975483865329708,
                                    0.04127506223034302,
                                ],
                                [
                                    0.3378405502534815,
                                    0.5975483865329708,
                                    0.023336000983204673,
                                    0.04127506223034302,
                                ],
                                [
                                    0.2943274939411998,
                                    0.020330379768925405,
                                    0.6410614428452525,
                                    0.044280683444622285,
                                ],
                                [
                                    0.3127633962182485,
                                    0.5531936963652301,
                                    0.048413155018437626,
                                    0.08562975239808379,
                                ],
                                [
                                    0.3127633962182485,
                                    0.048413155018437626,
                                    0.5531936963652301,
                                    0.08562975239808379,
                                ],
                                [
                                    0.2943274939411998,
                                    0.6410614428452525,
                                    0.020330379768925405,
                                    0.044280683444622285,
                                ],
                                [
                                    0.2724802174765194,
                                    0.0421776562336058,
                                    0.5934768751069591,
                                    0.09186525118291561,
                                ],
                                [
                                    0.2724802174765194,
                                    0.5934768751069591,
                                    0.0421776562336058,
                                    0.09186525118291561,
                                ],
                                [
                                    0.455903796840729,
                                    0.022242744780099678,
                                    0.49757752563271007,
                                    0.024275932746461257,
                                ],
                                [
                                    0.455903796840729,
                                    0.49757752563271007,
                                    0.022242744780099678,
                                    0.024275932746461257,
                                ],
                                [
                                    0.24508600384758633,
                                    0.011957315272504394,
                                    0.7083953186258528,
                                    0.03456136225405654,
                                ],
                                [
                                    0.2981109061336843,
                                    0.3253609381321829,
                                    0.18003563548714438,
                                    0.1964925202469884,
                                ],
                                [
                                    0.2981109061336843,
                                    0.18003563548714438,
                                    0.3253609381321829,
                                    0.1964925202469884,
                                ],
                                [
                                    0.24508600384758633,
                                    0.7083953186258528,
                                    0.011957315272504394,
                                    0.03456136225405654,
                                ],
                                [
                                    0.1602592722280228,
                                    0.0967840468920679,
                                    0.46321257203784444,
                                    0.27974410884206485,
                                ],
                                [
                                    0.1602592722280228,
                                    0.46321257203784444,
                                    0.0967840468920679,
                                    0.27974410884206485,
                                ],
                                [
                                    0.6163070116243861,
                                    0.014452702461619105,
                                    0.36077982169920114,
                                    0.008460464214793673,
                                ],
                                [
                                    0.6163070116243861,
                                    0.36077982169920114,
                                    0.014452702461619105,
                                    0.008460464214793673,
                                ],
                                [
                                    0.17770514184029124,
                                    0.004167272954023822,
                                    0.7993816914832961,
                                    0.018745893722388957,
                                ],
                                [
                                    0.1937039816582607,
                                    0.11339232987289842,
                                    0.4370557324277445,
                                    0.2558479560410964,
                                ],
                                [
                                    0.1937039816582607,
                                    0.4370557324277445,
                                    0.11339232987289842,
                                    0.2558479560410964,
                                ],
                                [
                                    0.17770514184029124,
                                    0.7993816914832961,
                                    0.004167272954023822,
                                    0.018745893722388957,
                                ],
                                [
                                    0.05585234775259917,
                                    0.12602006704171587,
                                    0.25124396377855995,
                                    0.566883621427125,
                                ],
                                [
                                    0.05585234775259917,
                                    0.25124396377855995,
                                    0.12602006704171587,
                                    0.566883621427125,
                                ],
                                [
                                    0.7441250633256088,
                                    0.0036046411445388228,
                                    0.25105415568496514,
                                    0.0012161398448871958,
                                ],
                                [
                                    0.7441250633256088,
                                    0.25105415568496514,
                                    0.0036046411445388228,
                                    0.0012161398448871958,
                                ],
                                [
                                    0.12365884027402098,
                                    0.0005990199302595515,
                                    0.871520378736553,
                                    0.004221761059166467,
                                ],
                                [
                                    0.04831161120216805,
                                    0.016299452011379653,
                                    0.6994180932679795,
                                    0.23597084351847272,
                                ],
                                [
                                    0.04831161120216805,
                                    0.6994180932679795,
                                    0.016299452011379653,
                                    0.23597084351847272,
                                ],
                                [
                                    0.12365884027402098,
                                    0.871520378736553,
                                    0.0005990199302595515,
                                    0.004221761059166467,
                                ],
                                [
                                    0.008028432460438942,
                                    0.1162294277438416,
                                    0.05658263075310876,
                                    0.8191595090426107,
                                ],
                                [
                                    0.008028432460438942,
                                    0.05658263075310876,
                                    0.1162294277438416,
                                    0.8191595090426107,
                                ],
                                [
                                    0.2502605645403551,
                                    0.110915986696331,
                                    0.44264312392848576,
                                    0.19618032483482808,
                                ],
                                [
                                    0.2502605645403551,
                                    0.44264312392848576,
                                    0.110915986696331,
                                    0.19618032483482808,
                                ],
                                [
                                    0.2180276012995085,
                                    0.09663027241061672,
                                    0.4748760871693324,
                                    0.21046603912054235,
                                ],
                                [
                                    0.2251834105051222,
                                    0.398288433760745,
                                    0.13599314073156393,
                                    0.24053501500256885,
                                ],
                                [
                                    0.2251834105051222,
                                    0.13599314073156393,
                                    0.398288433760745,
                                    0.24053501500256885,
                                ],
                                [
                                    0.2180276012995085,
                                    0.4748760871693324,
                                    0.09663027241061672,
                                    0.21046603912054235,
                                ],
                                [
                                    0.1961803248348281,
                                    0.11847754887529711,
                                    0.4272915194310391,
                                    0.2580506068588357,
                                ],
                                [
                                    0.1961803248348281,
                                    0.4272915194310391,
                                    0.11847754887529711,
                                    0.2580506068588357,
                                ],
                                [
                                    0.3724268004408802,
                                    0.10571974117994848,
                                    0.4064699770583818,
                                    0.11538348132078954,
                                ],
                                [
                                    0.3724268004408802,
                                    0.4064699770583818,
                                    0.10571974117994848,
                                    0.11538348132078954,
                                ],
                                [
                                    0.2002102129403531,
                                    0.05683310617973762,
                                    0.5786865645589089,
                                    0.1642701163210004,
                                ],
                                [
                                    0.2146339097338355,
                                    0.23425338955785463,
                                    0.2635126318869932,
                                    0.28760006882131667,
                                ],
                                [
                                    0.2146339097338355,
                                    0.2635126318869932,
                                    0.23425338955785463,
                                    0.28760006882131667,
                                ],
                                [
                                    0.2002102129403531,
                                    0.5786865645589089,
                                    0.05683310617973762,
                                    0.1642701163210004,
                                ],
                                [
                                    0.11538348132078957,
                                    0.14165983779930114,
                                    0.33350381797090056,
                                    0.40945286290900873,
                                ],
                                [
                                    0.11538348132078957,
                                    0.33350381797090056,
                                    0.14165983779930114,
                                    0.40945286290900873,
                                ],
                                [
                                    0.5620660353741853,
                                    0.06869367871181989,
                                    0.32902770891898087,
                                    0.04021257699501396,
                                ],
                                [
                                    0.5620660353741853,
                                    0.32902770891898087,
                                    0.06869367871181989,
                                    0.04021257699501396,
                                ],
                                [
                                    0.16206537108270602,
                                    0.019807043711609025,
                                    0.7290283732104601,
                                    0.08909921199522482,
                                ],
                                [
                                    0.1394630054080599,
                                    0.08164021709267812,
                                    0.4912967086779453,
                                    0.2876000688213167,
                                ],
                                [
                                    0.1394630054080599,
                                    0.4912967086779453,
                                    0.08164021709267812,
                                    0.2876000688213167,
                                ],
                                [
                                    0.16206537108270602,
                                    0.7290283732104601,
                                    0.019807043711609025,
                                    0.08909921199522482,
                                ],
                                [
                                    0.04021257699501395,
                                    0.14165983779930108,
                                    0.18089064550572403,
                                    0.6372369396999609,
                                ],
                                [
                                    0.04021257699501395,
                                    0.18089064550572403,
                                    0.14165983779930108,
                                    0.6372369396999609,
                                ],
                                [
                                    0.7305968491227183,
                                    0.017132855347429376,
                                    0.24648998420086896,
                                    0.005780311328983421,
                                ],
                                [
                                    0.7305968491227183,
                                    0.24648998420086896,
                                    0.017132855347429376,
                                    0.005780311328983421,
                                ],
                                [
                                    0.12141071914256546,
                                    0.0028471410617150806,
                                    0.8556761141810217,
                                    0.020066025614697714,
                                ],
                                [
                                    0.03478339699927757,
                                    0.011735280527283452,
                                    0.7129463074708701,
                                    0.2405350150025689,
                                ],
                                [
                                    0.03478339699927757,
                                    0.7129463074708701,
                                    0.011735280527283452,
                                    0.2405350150025689,
                                ],
                                [
                                    0.12141071914256546,
                                    0.8556761141810217,
                                    0.0028471410617150806,
                                    0.020066025614697714,
                                ],
                                [
                                    0.005780311328983426,
                                    0.11847754887529711,
                                    0.0407383661975776,
                                    0.8350037735981418,
                                ],
                                [
                                    0.005780311328983426,
                                    0.0407383661975776,
                                    0.11847754887529711,
                                    0.8350037735981418,
                                ],
                                [
                                    0.135993140731564,
                                    0.22518341050512214,
                                    0.2405350150025689,
                                    0.39828843376074496,
                                ],
                                [
                                    0.135993140731564,
                                    0.2405350150025689,
                                    0.22518341050512214,
                                    0.39828843376074496,
                                ],
                                [
                                    0.11847754887529714,
                                    0.19618032483482806,
                                    0.25805060685883574,
                                    0.42729151943103905,
                                ],
                                [
                                    0.11091598669633101,
                                    0.1961803248348281,
                                    0.2502605645403551,
                                    0.44264312392848576,
                                ],
                                [
                                    0.11091598669633101,
                                    0.2502605645403551,
                                    0.1961803248348281,
                                    0.44264312392848576,
                                ],
                                [
                                    0.11847754887529714,
                                    0.25805060685883574,
                                    0.19618032483482806,
                                    0.42729151943103905,
                                ],
                                [
                                    0.09663027241061674,
                                    0.2180276012995085,
                                    0.2104660391205424,
                                    0.4748760871693324,
                                ],
                                [
                                    0.09663027241061674,
                                    0.2104660391205424,
                                    0.2180276012995085,
                                    0.4748760871693324,
                                ],
                                [
                                    0.2635126318869932,
                                    0.2146339097338355,
                                    0.28760006882131667,
                                    0.23425338955785463,
                                ],
                                [
                                    0.2635126318869932,
                                    0.28760006882131667,
                                    0.2146339097338355,
                                    0.23425338955785463,
                                ],
                                [
                                    0.14165983779930114,
                                    0.11538348132078957,
                                    0.40945286290900873,
                                    0.33350381797090056,
                                ],
                                [
                                    0.10571974117994846,
                                    0.11538348132078953,
                                    0.3724268004408802,
                                    0.4064699770583818,
                                ],
                                [
                                    0.10571974117994846,
                                    0.3724268004408802,
                                    0.11538348132078953,
                                    0.4064699770583818,
                                ],
                                [
                                    0.14165983779930114,
                                    0.40945286290900873,
                                    0.11538348132078957,
                                    0.33350381797090056,
                                ],
                                [
                                    0.056833106179737615,
                                    0.2002102129403531,
                                    0.1642701163210004,
                                    0.5786865645589089,
                                ],
                                [
                                    0.056833106179737615,
                                    0.1642701163210004,
                                    0.2002102129403531,
                                    0.5786865645589089,
                                ],
                                [
                                    0.4912967086779453,
                                    0.1394630054080599,
                                    0.2876000688213167,
                                    0.08164021709267812,
                                ],
                                [
                                    0.4912967086779453,
                                    0.2876000688213167,
                                    0.1394630054080599,
                                    0.08164021709267812,
                                ],
                                [
                                    0.14165983779930108,
                                    0.04021257699501395,
                                    0.6372369396999609,
                                    0.18089064550572406,
                                ],
                                [
                                    0.0686936787118199,
                                    0.040212576995013974,
                                    0.5620660353741853,
                                    0.32902770891898087,
                                ],
                                [
                                    0.0686936787118199,
                                    0.5620660353741853,
                                    0.040212576995013974,
                                    0.32902770891898087,
                                ],
                                [
                                    0.14165983779930108,
                                    0.6372369396999609,
                                    0.04021257699501395,
                                    0.18089064550572406,
                                ],
                                [
                                    0.019807043711609032,
                                    0.16206537108270602,
                                    0.08909921199522484,
                                    0.7290283732104601,
                                ],
                                [
                                    0.019807043711609032,
                                    0.08909921199522484,
                                    0.16206537108270602,
                                    0.7290283732104601,
                                ],
                                [
                                    0.7129463074708702,
                                    0.03478339699927753,
                                    0.24053501500256894,
                                    0.011735280527283438,
                                ],
                                [
                                    0.7129463074708702,
                                    0.24053501500256894,
                                    0.03478339699927753,
                                    0.011735280527283438,
                                ],
                                [
                                    0.11847754887529713,
                                    0.005780311328983419,
                                    0.8350037735981419,
                                    0.04073836619757755,
                                ],
                                [
                                    0.017132855347429417,
                                    0.005780311328983436,
                                    0.7305968491227183,
                                    0.24648998420086893,
                                ],
                                [
                                    0.017132855347429417,
                                    0.7305968491227183,
                                    0.005780311328983436,
                                    0.24648998420086893,
                                ],
                                [
                                    0.11847754887529713,
                                    0.8350037735981419,
                                    0.005780311328983419,
                                    0.04073836619757755,
                                ],
                                [
                                    0.002847141061715088,
                                    0.12141071914256545,
                                    0.020066025614697766,
                                    0.8556761141810217,
                                ],
                                [
                                    0.002847141061715088,
                                    0.020066025614697766,
                                    0.12141071914256545,
                                    0.8556761141810217,
                                ],
                                [
                                    0.04841315501843764,
                                    0.3127633962182485,
                                    0.08562975239808383,
                                    0.5531936963652301,
                                ],
                                [
                                    0.04841315501843764,
                                    0.08562975239808383,
                                    0.3127633962182485,
                                    0.5531936963652301,
                                ],
                                [
                                    0.04217765623360582,
                                    0.2724802174765194,
                                    0.09186525118291565,
                                    0.5934768751069591,
                                ],
                                [
                                    0.02333600098320468,
                                    0.041275062230343024,
                                    0.3378405502534815,
                                    0.5975483865329708,
                                ],
                                [
                                    0.02333600098320468,
                                    0.3378405502534815,
                                    0.041275062230343024,
                                    0.5975483865329708,
                                ],
                                [
                                    0.04217765623360582,
                                    0.09186525118291565,
                                    0.2724802174765194,
                                    0.5934768751069591,
                                ],
                                [
                                    0.02033037976892541,
                                    0.2943274939411998,
                                    0.04428068344462229,
                                    0.6410614428452525,
                                ],
                                [
                                    0.02033037976892541,
                                    0.04428068344462229,
                                    0.2943274939411998,
                                    0.6410614428452525,
                                ],
                                [
                                    0.18003563548714444,
                                    0.29811090613368424,
                                    0.19649252024698846,
                                    0.32536093813218286,
                                ],
                                [
                                    0.18003563548714444,
                                    0.19649252024698846,
                                    0.29811090613368424,
                                    0.32536093813218286,
                                ],
                                [
                                    0.09678404689206793,
                                    0.16025927222802278,
                                    0.27974410884206496,
                                    0.46321257203784433,
                                ],
                                [
                                    0.02224274478009972,
                                    0.024275932746461306,
                                    0.45590379684072896,
                                    0.49757752563271,
                                ],
                                [
                                    0.02224274478009972,
                                    0.45590379684072896,
                                    0.024275932746461306,
                                    0.49757752563271,
                                ],
                                [
                                    0.09678404689206793,
                                    0.27974410884206496,
                                    0.16025927222802278,
                                    0.46321257203784433,
                                ],
                                [
                                    0.011957315272504418,
                                    0.2450860038475863,
                                    0.03456136225405661,
                                    0.7083953186258527,
                                ],
                                [
                                    0.011957315272504418,
                                    0.03456136225405661,
                                    0.2450860038475863,
                                    0.7083953186258527,
                                ],
                                [
                                    0.4370557324277445,
                                    0.19370398165826067,
                                    0.2558479560410964,
                                    0.1133923298728984,
                                ],
                                [
                                    0.4370557324277445,
                                    0.2558479560410964,
                                    0.19370398165826067,
                                    0.1133923298728984,
                                ],
                                [
                                    0.12602006704171587,
                                    0.05585234775259915,
                                    0.566883621427125,
                                    0.2512439637785599,
                                ],
                                [
                                    0.014452702461619154,
                                    0.008460464214793701,
                                    0.6163070116243861,
                                    0.36077982169920114,
                                ],
                                [
                                    0.014452702461619154,
                                    0.6163070116243861,
                                    0.008460464214793701,
                                    0.36077982169920114,
                                ],
                                [
                                    0.12602006704171587,
                                    0.566883621427125,
                                    0.05585234775259915,
                                    0.2512439637785599,
                                ],
                                [
                                    0.004167272954023836,
                                    0.1777051418402912,
                                    0.01874589372238902,
                                    0.799381691483296,
                                ],
                                [
                                    0.004167272954023836,
                                    0.01874589372238902,
                                    0.1777051418402912,
                                    0.799381691483296,
                                ],
                                [
                                    0.6994180932679795,
                                    0.048311611202168085,
                                    0.23597084351847272,
                                    0.016299452011379664,
                                ],
                                [
                                    0.6994180932679795,
                                    0.23597084351847272,
                                    0.048311611202168085,
                                    0.016299452011379664,
                                ],
                                [
                                    0.1162294277438416,
                                    0.008028432460438948,
                                    0.8191595090426107,
                                    0.0565826307531088,
                                ],
                                [
                                    0.003604641144538858,
                                    0.0012161398448872077,
                                    0.7441250633256088,
                                    0.25105415568496514,
                                ],
                                [
                                    0.003604641144538858,
                                    0.7441250633256088,
                                    0.0012161398448872077,
                                    0.25105415568496514,
                                ],
                                [
                                    0.1162294277438416,
                                    0.8191595090426107,
                                    0.008028432460438948,
                                    0.0565826307531088,
                                ],
                                [
                                    0.0005990199302595572,
                                    0.12365884027402098,
                                    0.004221761059166509,
                                    0.871520378736553,
                                ],
                                [
                                    0.0005990199302595572,
                                    0.004221761059166509,
                                    0.12365884027402098,
                                    0.871520378736553,
                                ],
                                [
                                    0.10543764349375427,
                                    0.007283000665227806,
                                    0.829951293292698,
                                    0.05732806254831988,
                                ],
                                [
                                    0.10543764349375427,
                                    0.829951293292698,
                                    0.007283000665227806,
                                    0.05732806254831988,
                                ],
                                [
                                    0.06192458718147263,
                                    0.004277379450948539,
                                    0.8734643496049797,
                                    0.06033368376259915,
                                ],
                                [
                                    0.09761124129004899,
                                    0.7683458512934296,
                                    0.015109402868933091,
                                    0.11893350454758833,
                                ],
                                [
                                    0.09761124129004899,
                                    0.015109402868933091,
                                    0.7683458512934296,
                                    0.11893350454758833,
                                ],
                                [
                                    0.06192458718147263,
                                    0.8734643496049797,
                                    0.004277379450948539,
                                    0.06033368376259915,
                                ],
                                [
                                    0.057328062548319896,
                                    0.008873904084101271,
                                    0.8086290300351586,
                                    0.12516900333242015,
                                ],
                                [
                                    0.057328062548319896,
                                    0.8086290300351586,
                                    0.008873904084101271,
                                    0.12516900333242015,
                                ],
                                [
                                    0.2623822914672493,
                                    0.012801170739015814,
                                    0.6910990310061897,
                                    0.03371750678754512,
                                ],
                                [
                                    0.2623822914672493,
                                    0.6910990310061897,
                                    0.012801170739015814,
                                    0.03371750678754512,
                                ],
                                [
                                    0.05156449847410658,
                                    0.002515741231420532,
                                    0.9019168239993325,
                                    0.044002936295140405,
                                ],
                                [
                                    0.17156914069320667,
                                    0.45190270357266055,
                                    0.10361432151305844,
                                    0.27291383422107435,
                                ],
                                [
                                    0.17156914069320667,
                                    0.10361432151305844,
                                    0.45190270357266055,
                                    0.27291383422107435,
                                ],
                                [
                                    0.05156449847410658,
                                    0.9019168239993325,
                                    0.002515741231420532,
                                    0.044002936295140405,
                                ],
                                [
                                    0.03371750678754517,
                                    0.020362732917981942,
                                    0.5897543374783221,
                                    0.3561654228161508,
                                ],
                                [
                                    0.03371750678754517,
                                    0.5897543374783221,
                                    0.020362732917981942,
                                    0.3561654228161508,
                                ],
                                [
                                    0.47598987387821295,
                                    0.011162196587336722,
                                    0.5010969594453744,
                                    0.011750970089076057,
                                ],
                                [
                                    0.47598987387821295,
                                    0.5010969594453744,
                                    0.011162196587336722,
                                    0.011750970089076057,
                                ],
                                [
                                    0.03738800409411808,
                                    0.000876767079741438,
                                    0.9396988292294692,
                                    0.02203639959667134,
                                ],
                                [
                                    0.14960260399473763,
                                    0.1574937075364215,
                                    0.337549466470812,
                                    0.35535422199802885,
                                ],
                                [
                                    0.14960260399473763,
                                    0.337549466470812,
                                    0.1574937075364215,
                                    0.35535422199802885,
                                ],
                                [
                                    0.03738800409411808,
                                    0.9396988292294692,
                                    0.000876767079741438,
                                    0.02203639959667134,
                                ],
                                [
                                    0.01175097008907608,
                                    0.026513801084783434,
                                    0.2953453414420831,
                                    0.6663898873840575,
                                ],
                                [
                                    0.01175097008907608,
                                    0.2953453414420831,
                                    0.026513801084783434,
                                    0.6663898873840575,
                                ],
                                [
                                    0.6464832374078416,
                                    0.0031316511049907653,
                                    0.3486959816027323,
                                    0.0016891298844352535,
                                ],
                                [
                                    0.6464832374078416,
                                    0.3486959816027323,
                                    0.0031316511049907653,
                                    0.0016891298844352535,
                                ],
                                [
                                    0.026017014356253847,
                                    0.00012602989071149376,
                                    0.9691622046543201,
                                    0.004694751098714525,
                                ],
                                [
                                    0.04197230862616436,
                                    0.022638754587383344,
                                    0.607642579886668,
                                    0.3277463568997842,
                                ],
                                [
                                    0.04197230862616436,
                                    0.607642579886668,
                                    0.022638754587383344,
                                    0.3277463568997842,
                                ],
                                [
                                    0.026017014356253847,
                                    0.9691622046543201,
                                    0.00012602989071149376,
                                    0.004694751098714525,
                                ],
                                [
                                    0.0016891298844352522,
                                    0.02445391436253009,
                                    0.06292193332911244,
                                    0.9109350224239222,
                                ],
                                [
                                    0.0016891298844352522,
                                    0.06292193332911244,
                                    0.02445391436253009,
                                    0.9109350224239222,
                                ],
                                [
                                    0.07810455010434239,
                                    0.03461609405463969,
                                    0.6147991383644985,
                                    0.2724802174765194,
                                ],
                                [
                                    0.07810455010434239,
                                    0.6147991383644985,
                                    0.03461609405463969,
                                    0.2724802174765194,
                                ],
                                [
                                    0.04587158686349576,
                                    0.02033037976892541,
                                    0.6470321016053451,
                                    0.28676593176223364,
                                ],
                                [
                                    0.07027814790063712,
                                    0.5531936963652301,
                                    0.042442496258344974,
                                    0.33408565947578783,
                                ],
                                [
                                    0.07027814790063712,
                                    0.042442496258344974,
                                    0.5531936963652301,
                                    0.33408565947578783,
                                ],
                                [
                                    0.04587158686349576,
                                    0.6470321016053451,
                                    0.02033037976892541,
                                    0.28676593176223364,
                                ],
                                [
                                    0.04127506223034303,
                                    0.02492690440207814,
                                    0.5821967820355242,
                                    0.35160125133205467,
                                ],
                                [
                                    0.04127506223034303,
                                    0.5821967820355242,
                                    0.02492690440207814,
                                    0.35160125133205467,
                                ],
                                [
                                    0.21433951193354986,
                                    0.06084395027271527,
                                    0.5645572655657122,
                                    0.16025927222802275,
                                ],
                                [
                                    0.21433951193354986,
                                    0.5645572655657122,
                                    0.06084395027271527,
                                    0.16025927222802275,
                                ],
                                [
                                    0.04212292443302271,
                                    0.011957315272504408,
                                    0.7367738530662393,
                                    0.20914590722823362,
                                ],
                                [
                                    0.12352636115950723,
                                    0.3253609381321829,
                                    0.1516571010467579,
                                    0.399455599661552,
                                ],
                                [
                                    0.12352636115950723,
                                    0.1516571010467579,
                                    0.3253609381321829,
                                    0.399455599661552,
                                ],
                                [
                                    0.04212292443302271,
                                    0.7367738530662393,
                                    0.011957315272504408,
                                    0.20914590722823362,
                                ],
                                [
                                    0.024275932746461292,
                                    0.02980430695906582,
                                    0.42461136654522885,
                                    0.5213083937492441,
                                ],
                                [
                                    0.024275932746461292,
                                    0.42461136654522885,
                                    0.02980430695906582,
                                    0.5213083937492441,
                                ],
                                [
                                    0.43409816251131494,
                                    0.05305390795423469,
                                    0.4569955817818512,
                                    0.05585234775259916,
                                ],
                                [
                                    0.43409816251131494,
                                    0.4569955817818512,
                                    0.05305390795423469,
                                    0.05585234775259916,
                                ],
                                [
                                    0.03409749821983568,
                                    0.004167272954023829,
                                    0.8569962460733305,
                                    0.10473898275281002,
                                ],
                                [
                                    0.10771089262783962,
                                    0.11339232987289838,
                                    0.37944117783771003,
                                    0.399455599661552,
                                ],
                                [
                                    0.10771089262783962,
                                    0.37944117783771003,
                                    0.11339232987289838,
                                    0.399455599661552,
                                ],
                                [
                                    0.03409749821983568,
                                    0.8569962460733305,
                                    0.004167272954023829,
                                    0.10473898275281002,
                                ],
                                [
                                    0.008460464214793685,
                                    0.02980430695906583,
                                    0.2126427582859443,
                                    0.7490924705401962,
                                ],
                                [
                                    0.008460464214793685,
                                    0.2126427582859443,
                                    0.02980430695906583,
                                    0.7490924705401962,
                                ],
                                [
                                    0.6347301542968586,
                                    0.014884734215973847,
                                    0.3423566790267286,
                                    0.00802843246043895,
                                ],
                                [
                                    0.6347301542968586,
                                    0.3423566790267286,
                                    0.014884734215973847,
                                    0.00802843246043895,
                                ],
                                [
                                    0.025544024316705792,
                                    0.0005990199302595515,
                                    0.9515428090068815,
                                    0.022314146746153243,
                                ],
                                [
                                    0.030219225515181344,
                                    0.01629945201137968,
                                    0.6193956629976511,
                                    0.3340856594757879,
                                ],
                                [
                                    0.030219225515181344,
                                    0.6193956629976511,
                                    0.01629945201137968,
                                    0.3340856594757879,
                                ],
                                [
                                    0.025544024316705792,
                                    0.9515428090068815,
                                    0.0005990199302595515,
                                    0.022314146746153243,
                                ],
                                [
                                    0.001216139844887197,
                                    0.024926904402078145,
                                    0.045302537681673825,
                                    0.9285544180713609,
                                ],
                                [
                                    0.001216139844887197,
                                    0.045302537681673825,
                                    0.024926904402078145,
                                    0.9285544180713609,
                                ],
                                [
                                    0.04244249625834499,
                                    0.0702781479006371,
                                    0.3340856594757879,
                                    0.55319369636523,
                                ],
                                [
                                    0.04244249625834499,
                                    0.3340856594757879,
                                    0.0702781479006371,
                                    0.55319369636523,
                                ],
                                [
                                    0.02492690440207815,
                                    0.041275062230343024,
                                    0.3516012513320547,
                                    0.582196782035524,
                                ],
                                [
                                    0.034616094054639696,
                                    0.27248021747651946,
                                    0.07810455010434239,
                                    0.6147991383644985,
                                ],
                                [
                                    0.034616094054639696,
                                    0.07810455010434239,
                                    0.27248021747651946,
                                    0.6147991383644985,
                                ],
                                [
                                    0.02492690440207815,
                                    0.3516012513320547,
                                    0.041275062230343024,
                                    0.582196782035524,
                                ],
                                [
                                    0.020330379768925412,
                                    0.04587158686349576,
                                    0.2867659317622337,
                                    0.6470321016053451,
                                ],
                                [
                                    0.020330379768925412,
                                    0.2867659317622337,
                                    0.04587158686349576,
                                    0.6470321016053451,
                                ],
                                [
                                    0.1516571010467579,
                                    0.12352636115950723,
                                    0.399455599661552,
                                    0.3253609381321829,
                                ],
                                [
                                    0.1516571010467579,
                                    0.399455599661552,
                                    0.12352636115950723,
                                    0.3253609381321829,
                                ],
                                [
                                    0.02980430695906582,
                                    0.024275932746461292,
                                    0.5213083937492441,
                                    0.42461136654522885,
                                ],
                                [
                                    0.06084395027271526,
                                    0.16025927222802275,
                                    0.21433951193354986,
                                    0.5645572655657122,
                                ],
                                [
                                    0.06084395027271526,
                                    0.21433951193354986,
                                    0.16025927222802275,
                                    0.5645572655657122,
                                ],
                                [
                                    0.02980430695906582,
                                    0.5213083937492441,
                                    0.024275932746461292,
                                    0.42461136654522885,
                                ],
                                [
                                    0.011957315272504406,
                                    0.04212292443302271,
                                    0.2091459072282336,
                                    0.7367738530662393,
                                ],
                                [
                                    0.011957315272504406,
                                    0.2091459072282336,
                                    0.04212292443302271,
                                    0.7367738530662393,
                                ],
                                [
                                    0.37944117783771003,
                                    0.10771089262783963,
                                    0.399455599661552,
                                    0.11339232987289839,
                                ],
                                [
                                    0.37944117783771003,
                                    0.399455599661552,
                                    0.10771089262783963,
                                    0.11339232987289839,
                                ],
                                [
                                    0.02980430695906583,
                                    0.008460464214793687,
                                    0.7490924705401962,
                                    0.21264275828594434,
                                ],
                                [
                                    0.0530539079542347,
                                    0.055852347752599174,
                                    0.43409816251131494,
                                    0.4569955817818512,
                                ],
                                [
                                    0.0530539079542347,
                                    0.43409816251131494,
                                    0.055852347752599174,
                                    0.4569955817818512,
                                ],
                                [
                                    0.02980430695906583,
                                    0.7490924705401962,
                                    0.008460464214793687,
                                    0.21264275828594434,
                                ],
                                [
                                    0.00416727295402383,
                                    0.03409749821983568,
                                    0.10473898275281004,
                                    0.8569962460733305,
                                ],
                                [
                                    0.00416727295402383,
                                    0.10473898275281004,
                                    0.03409749821983568,
                                    0.8569962460733305,
                                ],
                                [
                                    0.6193956629976511,
                                    0.03021922551518131,
                                    0.3340856594757879,
                                    0.01629945201137966,
                                ],
                                [
                                    0.6193956629976511,
                                    0.3340856594757879,
                                    0.03021922551518131,
                                    0.01629945201137966,
                                ],
                                [
                                    0.02492690440207815,
                                    0.0012161398448871958,
                                    0.928554418071361,
                                    0.04530253768167378,
                                ],
                                [
                                    0.014884734215973885,
                                    0.00802843246043897,
                                    0.6347301542968585,
                                    0.34235667902672856,
                                ],
                                [
                                    0.014884734215973885,
                                    0.6347301542968585,
                                    0.00802843246043897,
                                    0.34235667902672856,
                                ],
                                [
                                    0.02492690440207815,
                                    0.928554418071361,
                                    0.0012161398448871958,
                                    0.04530253768167378,
                                ],
                                [
                                    0.0005990199302595531,
                                    0.02554402431670579,
                                    0.022314146746153302,
                                    0.9515428090068814,
                                ],
                                [
                                    0.0005990199302595531,
                                    0.022314146746153302,
                                    0.02554402431670579,
                                    0.9515428090068814,
                                ],
                                [
                                    0.015109402868933098,
                                    0.09761124129004899,
                                    0.11893350454758837,
                                    0.7683458512934296,
                                ],
                                [
                                    0.015109402868933098,
                                    0.11893350454758837,
                                    0.09761124129004899,
                                    0.7683458512934296,
                                ],
                                [
                                    0.008873904084101275,
                                    0.057328062548319896,
                                    0.1251690033324202,
                                    0.8086290300351586,
                                ],
                                [
                                    0.007283000665227808,
                                    0.057328062548319896,
                                    0.10543764349375427,
                                    0.829951293292698,
                                ],
                                [
                                    0.007283000665227808,
                                    0.10543764349375427,
                                    0.057328062548319896,
                                    0.829951293292698,
                                ],
                                [
                                    0.008873904084101275,
                                    0.1251690033324202,
                                    0.057328062548319896,
                                    0.8086290300351586,
                                ],
                                [
                                    0.00427737945094854,
                                    0.06192458718147263,
                                    0.06033368376259916,
                                    0.8734643496049797,
                                ],
                                [
                                    0.00427737945094854,
                                    0.06033368376259916,
                                    0.06192458718147263,
                                    0.8734643496049797,
                                ],
                                [
                                    0.10361432151305847,
                                    0.17156914069320664,
                                    0.27291383422107446,
                                    0.45190270357266044,
                                ],
                                [
                                    0.10361432151305847,
                                    0.27291383422107446,
                                    0.17156914069320664,
                                    0.45190270357266044,
                                ],
                                [
                                    0.02036273291798195,
                                    0.03371750678754516,
                                    0.35616542281615093,
                                    0.589754337478322,
                                ],
                                [
                                    0.01280117073901584,
                                    0.03371750678754518,
                                    0.2623822914672493,
                                    0.6910990310061897,
                                ],
                                [
                                    0.01280117073901584,
                                    0.2623822914672493,
                                    0.03371750678754518,
                                    0.6910990310061897,
                                ],
                                [
                                    0.02036273291798195,
                                    0.35616542281615093,
                                    0.03371750678754516,
                                    0.589754337478322,
                                ],
                                [
                                    0.0025157412314205374,
                                    0.051564498474106574,
                                    0.04400293629514049,
                                    0.9019168239993324,
                                ],
                                [
                                    0.0025157412314205374,
                                    0.04400293629514049,
                                    0.051564498474106574,
                                    0.9019168239993324,
                                ],
                                [
                                    0.337549466470812,
                                    0.1496026039947376,
                                    0.35535422199802885,
                                    0.15749370753642147,
                                ],
                                [
                                    0.337549466470812,
                                    0.35535422199802885,
                                    0.1496026039947376,
                                    0.15749370753642147,
                                ],
                                [
                                    0.026513801084783434,
                                    0.011750970089076076,
                                    0.6663898873840575,
                                    0.295345341442083,
                                ],
                                [
                                    0.011162196587336758,
                                    0.011750970089076097,
                                    0.4759898738782129,
                                    0.5010969594453742,
                                ],
                                [
                                    0.011162196587336758,
                                    0.4759898738782129,
                                    0.011750970089076097,
                                    0.5010969594453742,
                                ],
                                [
                                    0.026513801084783434,
                                    0.6663898873840575,
                                    0.011750970089076076,
                                    0.295345341442083,
                                ],
                                [
                                    0.000876767079741441,
                                    0.03738800409411807,
                                    0.022036399596671415,
                                    0.9396988292294691,
                                ],
                                [
                                    0.000876767079741441,
                                    0.022036399596671415,
                                    0.03738800409411807,
                                    0.9396988292294691,
                                ],
                                [
                                    0.607642579886668,
                                    0.04197230862616439,
                                    0.3277463568997842,
                                    0.022638754587383358,
                                ],
                                [
                                    0.607642579886668,
                                    0.3277463568997842,
                                    0.04197230862616439,
                                    0.022638754587383358,
                                ],
                                [
                                    0.02445391436253009,
                                    0.0016891298844352533,
                                    0.9109350224239222,
                                    0.06292193332911249,
                                ],
                                [
                                    0.0031316511049907956,
                                    0.00168912988443527,
                                    0.6464832374078416,
                                    0.3486959816027323,
                                ],
                                [
                                    0.0031316511049907956,
                                    0.6464832374078416,
                                    0.00168912988443527,
                                    0.3486959816027323,
                                ],
                                [
                                    0.02445391436253009,
                                    0.9109350224239222,
                                    0.0016891298844352533,
                                    0.06292193332911249,
                                ],
                                [
                                    0.00012602989071149498,
                                    0.026017014356253847,
                                    0.004694751098714571,
                                    0.9691622046543201,
                                ],
                                [
                                    0.00012602989071149498,
                                    0.004694751098714571,
                                    0.026017014356253847,
                                    0.9691622046543201,
                                ],
                                [
                                    0.8746393736860893,
                                    0.0604148473857684,
                                    0.0607495631003629,
                                    0.004196215827779288,
                                ],
                                [
                                    0.8746393736860893,
                                    0.0607495631003629,
                                    0.0604148473857684,
                                    0.004196215827779288,
                                ],
                                [
                                    0.8142028999621267,
                                    0.056240257896183345,
                                    0.12118603682432554,
                                    0.008370805317364345,
                                ],
                                [
                                    0.8097168346872952,
                                    0.05624025789618335,
                                    0.12533738638456257,
                                    0.00870552103195883,
                                ],
                                [
                                    0.8097168346872952,
                                    0.12533738638456257,
                                    0.05624025789618335,
                                    0.00870552103195883,
                                ],
                                [
                                    0.8142028999621267,
                                    0.12118603682432554,
                                    0.056240257896183345,
                                    0.008370805317364345,
                                ],
                                [
                                    0.753766426238164,
                                    0.116676731620146,
                                    0.11219066634531447,
                                    0.017366175796375418,
                                ],
                                [
                                    0.753766426238164,
                                    0.11219066634531447,
                                    0.116676731620146,
                                    0.017366175796375418,
                                ],
                                [
                                    0.9076097356099433,
                                    0.04428068344462229,
                                    0.04587158686349575,
                                    0.002237994081938643,
                                ],
                                [
                                    0.9076097356099433,
                                    0.04587158686349575,
                                    0.04428068344462229,
                                    0.002237994081938643,
                                ],
                                [
                                    0.6147991383644985,
                                    0.029994969158908005,
                                    0.3386821841089405,
                                    0.016523708367652927,
                                ],
                                [
                                    0.5934768751069592,
                                    0.029994969158908008,
                                    0.3584135439476064,
                                    0.01811461178652639,
                                ],
                                [
                                    0.5934768751069592,
                                    0.3584135439476064,
                                    0.029994969158908008,
                                    0.01811461178652639,
                                ],
                                [
                                    0.6147991383644985,
                                    0.3386821841089405,
                                    0.029994969158908005,
                                    0.016523708367652927,
                                ],
                                [
                                    0.40201097138938213,
                                    0.24278313613402436,
                                    0.22146087287648505,
                                    0.1337450196001084,
                                ],
                                [
                                    0.40201097138938213,
                                    0.22146087287648505,
                                    0.24278313613402436,
                                    0.1337450196001084,
                                ],
                                [
                                    0.9515428090068815,
                                    0.022314146746153226,
                                    0.02554402431670579,
                                    0.0005990199302595509,
                                ],
                                [
                                    0.9515428090068815,
                                    0.02554402431670579,
                                    0.022314146746153226,
                                    0.0005990199302595509,
                                ],
                                [
                                    0.3423566790267286,
                                    0.008028432460438944,
                                    0.6347301542968586,
                                    0.014884734215973834,
                                ],
                                [
                                    0.2990678790707202,
                                    0.008028432460438944,
                                    0.6747890766823145,
                                    0.018114611786526392,
                                ],
                                [
                                    0.2990678790707202,
                                    0.6747890766823145,
                                    0.008028432460438944,
                                    0.018114611786526392,
                                ],
                                [
                                    0.3423566790267286,
                                    0.6347301542968586,
                                    0.008028432460438944,
                                    0.014884734215973834,
                                ],
                                [
                                    0.10760197535314313,
                                    0.2427831361340244,
                                    0.19949433617801599,
                                    0.45012055233481646,
                                ],
                                [
                                    0.10760197535314313,
                                    0.19949433617801599,
                                    0.2427831361340244,
                                    0.45012055233481646,
                                ],
                                [
                                    0.9859172390138586,
                                    0.004775914721883775,
                                    0.009261979996715304,
                                    4.486626754224335e-05,
                                ],
                                [
                                    0.9859172390138586,
                                    0.009261979996715304,
                                    0.004775914721883775,
                                    4.486626754224335e-05,
                                ],
                                [
                                    0.12413473591996516,
                                    0.0006013252322987151,
                                    0.8710444830906088,
                                    0.004219455757127304,
                                ],
                                [
                                    0.06400973798124898,
                                    0.0006013252322987148,
                                    0.9266834157544934,
                                    0.008705521031958834,
                                ],
                                [
                                    0.06400973798124898,
                                    0.9266834157544934,
                                    0.0006013252322987148,
                                    0.008705521031958834,
                                ],
                                [
                                    0.12413473591996516,
                                    0.8710444830906088,
                                    0.0006013252322987151,
                                    0.004219455757127304,
                                ],
                                [
                                    0.008059329532117873,
                                    0.11667673162014601,
                                    0.05655173368142983,
                                    0.8187122051663063,
                                ],
                                [
                                    0.008059329532117873,
                                    0.05655173368142983,
                                    0.11667673162014601,
                                    0.8187122051663063,
                                ],
                                [
                                    0.6479025186990492,
                                    0.2871517023728085,
                                    0.04500116976979164,
                                    0.01994460915835054,
                                ],
                                [
                                    0.6479025186990492,
                                    0.04500116976979164,
                                    0.2871517023728085,
                                    0.01994460915835054,
                                ],
                                [
                                    0.6031332746824886,
                                    0.26730988317582144,
                                    0.08977041378635228,
                                    0.0397864283553376,
                                ],
                                [
                                    0.5829799797002551,
                                    0.0404918645656121,
                                    0.3520742413716027,
                                    0.02445391436253008,
                                ],
                                [
                                    0.5829799797002551,
                                    0.3520742413716027,
                                    0.0404918645656121,
                                    0.02445391436253008,
                                ],
                                [
                                    0.6031332746824886,
                                    0.08977041378635228,
                                    0.26730988317582144,
                                    0.0397864283553376,
                                ],
                                [
                                    0.5426968009585259,
                                    0.3277463568997841,
                                    0.08077504330734123,
                                    0.04878179883434867,
                                ],
                                [
                                    0.5426968009585259,
                                    0.08077504330734123,
                                    0.3277463568997841,
                                    0.04878179883434867,
                                ],
                                [
                                    0.7414243799340232,
                                    0.21046603912054238,
                                    0.03747239756523875,
                                    0.010637183380195647,
                                ],
                                [
                                    0.7414243799340232,
                                    0.03747239756523875,
                                    0.21046603912054238,
                                    0.010637183380195647,
                                ],
                                [
                                    0.502228052500494,
                                    0.14256605502291253,
                                    0.276668724998768,
                                    0.07853716747782546,
                                ],
                                [
                                    0.42729151943103916,
                                    0.021595779860651004,
                                    0.5245988996235265,
                                    0.026513801084783392,
                                ],
                                [
                                    0.42729151943103916,
                                    0.5245988996235265,
                                    0.021595779860651004,
                                    0.026513801084783392,
                                ],
                                [
                                    0.502228052500494,
                                    0.276668724998768,
                                    0.14256605502291253,
                                    0.07853716747782546,
                                ],
                                [
                                    0.2894398855253776,
                                    0.3553542219980289,
                                    0.15944741376631252,
                                    0.19575847871028093,
                                ],
                                [
                                    0.2894398855253776,
                                    0.15944741376631252,
                                    0.3553542219980289,
                                    0.19575847871028093,
                                ],
                                [
                                    0.8677978411079159,
                                    0.10605911464511877,
                                    0.02329590318525026,
                                    0.0028471410617150784,
                                ],
                                [
                                    0.8677978411079159,
                                    0.02329590318525026,
                                    0.10605911464511877,
                                    0.0028471410617150784,
                                ],
                                [
                                    0.31222598093967857,
                                    0.038159130547488956,
                                    0.5788677633534876,
                                    0.07074712515934489,
                                ],
                                [
                                    0.2153229111717546,
                                    0.005780311328983416,
                                    0.75853404458128,
                                    0.02036273291798192,
                                ],
                                [
                                    0.2153229111717546,
                                    0.75853404458128,
                                    0.005780311328983416,
                                    0.02036273291798192,
                                ],
                                [
                                    0.31222598093967857,
                                    0.5788677633534876,
                                    0.038159130547488956,
                                    0.07074712515934489,
                                ],
                                [
                                    0.0774712772660931,
                                    0.27291383422107446,
                                    0.1436319452346449,
                                    0.5059829432781875,
                                ],
                                [
                                    0.0774712772660931,
                                    0.1436319452346449,
                                    0.27291383422107446,
                                    0.5059829432781875,
                                ],
                                [
                                    0.9679932363790144,
                                    0.022699917356728112,
                                    0.009093596944572867,
                                    0.00021324931968468299,
                                ],
                                [
                                    0.9679932363790144,
                                    0.009093596944572867,
                                    0.022699917356728112,
                                    0.00021324931968468299,
                                ],
                                [
                                    0.12187796299252285,
                                    0.0028580981597410415,
                                    0.8552088703310644,
                                    0.020055068516671756,
                                ],
                                [
                                    0.04608573534640475,
                                    0.0004329421801562761,
                                    0.9446074183893377,
                                    0.008873904084101273,
                                ],
                                [
                                    0.04608573534640475,
                                    0.9446074183893377,
                                    0.0004329421801562761,
                                    0.008873904084101273,
                                ],
                                [
                                    0.12187796299252285,
                                    0.8552088703310644,
                                    0.0028580981597410415,
                                    0.020055068516671756,
                                ],
                                [
                                    0.005802556604675559,
                                    0.11893350454758832,
                                    0.040716120921885465,
                                    0.8345478179258506,
                                ],
                                [
                                    0.005802556604675559,
                                    0.040716120921885465,
                                    0.11893350454758832,
                                    0.8345478179258506,
                                ],
                                [
                                    0.3520742413716028,
                                    0.582979979700255,
                                    0.024453914362530086,
                                    0.040491864565612094,
                                ],
                                [
                                    0.3520742413716028,
                                    0.024453914362530086,
                                    0.582979979700255,
                                    0.040491864565612094,
                                ],
                                [
                                    0.3277463568997842,
                                    0.5426968009585259,
                                    0.04878179883434868,
                                    0.0807750433073412,
                                ],
                                [
                                    0.28715170237280857,
                                    0.019944609158350543,
                                    0.6479025186990492,
                                    0.04500116976979164,
                                ],
                                [
                                    0.28715170237280857,
                                    0.6479025186990492,
                                    0.019944609158350543,
                                    0.04500116976979164,
                                ],
                                [
                                    0.3277463568997842,
                                    0.04878179883434868,
                                    0.5426968009585259,
                                    0.0807750433073412,
                                ],
                                [
                                    0.2673098831758215,
                                    0.6031332746824886,
                                    0.039786428355337605,
                                    0.08977041378635228,
                                ],
                                [
                                    0.2673098831758215,
                                    0.039786428355337605,
                                    0.6031332746824886,
                                    0.08977041378635228,
                                ],
                                [
                                    0.5245988996235265,
                                    0.42729151943103916,
                                    0.026513801084783392,
                                    0.021595779860651004,
                                ],
                                [
                                    0.5245988996235265,
                                    0.026513801084783392,
                                    0.42729151943103916,
                                    0.021595779860651004,
                                ],
                                [
                                    0.3553542219980289,
                                    0.2894398855253776,
                                    0.19575847871028093,
                                    0.15944741376631252,
                                ],
                                [
                                    0.21046603912054235,
                                    0.010637183380195646,
                                    0.7414243799340232,
                                    0.03747239756523875,
                                ],
                                [
                                    0.21046603912054235,
                                    0.7414243799340232,
                                    0.010637183380195646,
                                    0.03747239756523875,
                                ],
                                [
                                    0.3553542219980289,
                                    0.19575847871028093,
                                    0.2894398855253776,
                                    0.15944741376631252,
                                ],
                                [
                                    0.14256605502291253,
                                    0.502228052500494,
                                    0.07853716747782546,
                                    0.276668724998768,
                                ],
                                [
                                    0.14256605502291253,
                                    0.07853716747782546,
                                    0.502228052500494,
                                    0.276668724998768,
                                ],
                                [
                                    0.75853404458128,
                                    0.21532291117175462,
                                    0.02036273291798192,
                                    0.005780311328983416,
                                ],
                                [
                                    0.75853404458128,
                                    0.02036273291798192,
                                    0.21532291117175462,
                                    0.005780311328983416,
                                ],
                                [
                                    0.27291383422107446,
                                    0.07747127726609311,
                                    0.5059829432781875,
                                    0.14363194523464493,
                                ],
                                [
                                    0.1060591146451188,
                                    0.0028471410617150793,
                                    0.8677978411079159,
                                    0.02329590318525026,
                                ],
                                [
                                    0.1060591146451188,
                                    0.8677978411079159,
                                    0.0028471410617150793,
                                    0.02329590318525026,
                                ],
                                [
                                    0.27291383422107446,
                                    0.5059829432781875,
                                    0.07747127726609311,
                                    0.14363194523464493,
                                ],
                                [
                                    0.03815913054748896,
                                    0.31222598093967857,
                                    0.0707471251593449,
                                    0.5788677633534876,
                                ],
                                [
                                    0.03815913054748896,
                                    0.0707471251593449,
                                    0.31222598093967857,
                                    0.5788677633534876,
                                ],
                                [
                                    0.9446074183893378,
                                    0.04608573534640469,
                                    0.008873904084101273,
                                    0.00043294218015627555,
                                ],
                                [
                                    0.9446074183893378,
                                    0.008873904084101273,
                                    0.04608573534640469,
                                    0.00043294218015627555,
                                ],
                                [
                                    0.11893350454758833,
                                    0.005802556604675552,
                                    0.8345478179258508,
                                    0.04071612092188542,
                                ],
                                [
                                    0.02269991735672817,
                                    0.00021324931968468353,
                                    0.9679932363790142,
                                    0.009093596944572865,
                                ],
                                [
                                    0.02269991735672817,
                                    0.9679932363790142,
                                    0.00021324931968468353,
                                    0.009093596944572865,
                                ],
                                [
                                    0.11893350454758833,
                                    0.8345478179258508,
                                    0.005802556604675552,
                                    0.04071612092188542,
                                ],
                                [
                                    0.002858098159741049,
                                    0.12187796299252283,
                                    0.020055068516671805,
                                    0.8552088703310643,
                                ],
                                [
                                    0.002858098159741049,
                                    0.020055068516671805,
                                    0.12187796299252283,
                                    0.8552088703310643,
                                ],
                                [
                                    0.12533738638456263,
                                    0.8097168346872952,
                                    0.008705521031958834,
                                    0.05624025789618335,
                                ],
                                [
                                    0.12533738638456263,
                                    0.008705521031958834,
                                    0.8097168346872952,
                                    0.05624025789618335,
                                ],
                                [
                                    0.11667673162014604,
                                    0.753766426238164,
                                    0.017366175796375425,
                                    0.11219066634531447,
                                ],
                                [
                                    0.06041484738576841,
                                    0.004196215827779289,
                                    0.8746393736860893,
                                    0.0607495631003629,
                                ],
                                [
                                    0.06041484738576841,
                                    0.8746393736860893,
                                    0.004196215827779289,
                                    0.0607495631003629,
                                ],
                                [
                                    0.11667673162014604,
                                    0.017366175796375425,
                                    0.753766426238164,
                                    0.11219066634531447,
                                ],
                                [
                                    0.05624025789618335,
                                    0.8142028999621267,
                                    0.008370805317364347,
                                    0.12118603682432554,
                                ],
                                [
                                    0.05624025789618335,
                                    0.008370805317364347,
                                    0.8142028999621267,
                                    0.12118603682432554,
                                ],
                                [
                                    0.3584135439476065,
                                    0.5934768751069591,
                                    0.018114611786526395,
                                    0.029994969158908,
                                ],
                                [
                                    0.3584135439476065,
                                    0.018114611786526395,
                                    0.5934768751069591,
                                    0.029994969158908,
                                ],
                                [
                                    0.24278313613402444,
                                    0.4020109713893821,
                                    0.13374501960010846,
                                    0.221460872876485,
                                ],
                                [
                                    0.044280683444622375,
                                    0.0022379940819386474,
                                    0.9076097356099433,
                                    0.045871586863495746,
                                ],
                                [
                                    0.044280683444622375,
                                    0.9076097356099433,
                                    0.0022379940819386474,
                                    0.045871586863495746,
                                ],
                                [
                                    0.24278313613402444,
                                    0.13374501960010846,
                                    0.4020109713893821,
                                    0.221460872876485,
                                ],
                                [
                                    0.029994969158908064,
                                    0.6147991383644984,
                                    0.016523708367652958,
                                    0.3386821841089405,
                                ],
                                [
                                    0.029994969158908064,
                                    0.016523708367652958,
                                    0.6147991383644984,
                                    0.3386821841089405,
                                ],
                                [
                                    0.6747890766823145,
                                    0.29906787907072013,
                                    0.018114611786526392,
                                    0.008028432460438942,
                                ],
                                [
                                    0.6747890766823145,
                                    0.018114611786526392,
                                    0.29906787907072013,
                                    0.008028432460438942,
                                ],
                                [
                                    0.2427831361340244,
                                    0.10760197535314311,
                                    0.45012055233481646,
                                    0.19949433617801596,
                                ],
                                [
                                    0.022314146746153302,
                                    0.000599019930259553,
                                    0.9515428090068814,
                                    0.025544024316705785,
                                ],
                                [
                                    0.022314146746153302,
                                    0.9515428090068814,
                                    0.000599019930259553,
                                    0.025544024316705785,
                                ],
                                [
                                    0.2427831361340244,
                                    0.45012055233481646,
                                    0.10760197535314311,
                                    0.19949433617801596,
                                ],
                                [
                                    0.00802843246043897,
                                    0.34235667902672856,
                                    0.014884734215973885,
                                    0.6347301542968585,
                                ],
                                [
                                    0.00802843246043897,
                                    0.014884734215973885,
                                    0.34235667902672856,
                                    0.6347301542968585,
                                ],
                                [
                                    0.9266834157544934,
                                    0.06400973798124902,
                                    0.008705521031958834,
                                    0.0006013252322987152,
                                ],
                                [
                                    0.9266834157544934,
                                    0.008705521031958834,
                                    0.06400973798124902,
                                    0.0006013252322987152,
                                ],
                                [
                                    0.11667673162014601,
                                    0.008059329532117878,
                                    0.8187122051663063,
                                    0.056551733681429864,
                                ],
                                [
                                    0.004775914721883822,
                                    4.4866267542243785e-05,
                                    0.9859172390138586,
                                    0.009261979996715304,
                                ],
                                [
                                    0.004775914721883822,
                                    0.9859172390138586,
                                    4.4866267542243785e-05,
                                    0.009261979996715304,
                                ],
                                [
                                    0.11667673162014601,
                                    0.8187122051663063,
                                    0.008059329532117878,
                                    0.056551733681429864,
                                ],
                                [
                                    0.0006013252322987208,
                                    0.12413473591996516,
                                    0.004219455757127345,
                                    0.8710444830906088,
                                ],
                                [
                                    0.0006013252322987208,
                                    0.004219455757127345,
                                    0.12413473591996516,
                                    0.8710444830906088,
                                ],
                                [
                                    0.6466463309947702,
                                    0.044666454055197154,
                                    0.288742605791682,
                                    0.019944609158350536,
                                ],
                                [
                                    0.6466463309947702,
                                    0.288742605791682,
                                    0.044666454055197154,
                                    0.019944609158350536,
                                ],
                                [
                                    0.5862098572708075,
                                    0.040491864565612094,
                                    0.34917907951564464,
                                    0.024119198647935592,
                                ],
                                [
                                    0.598647209407657,
                                    0.26730988317582144,
                                    0.09266557564231036,
                                    0.04137733177421106,
                                ],
                                [
                                    0.598647209407657,
                                    0.09266557564231036,
                                    0.26730988317582144,
                                    0.04137733177421106,
                                ],
                                [
                                    0.5862098572708075,
                                    0.34917907951564464,
                                    0.040491864565612094,
                                    0.024119198647935592,
                                ],
                                [
                                    0.5426968009585259,
                                    0.08400492087789377,
                                    0.32326029162495257,
                                    0.05003798653862764,
                                ],
                                [
                                    0.5426968009585259,
                                    0.32326029162495257,
                                    0.08400492087789377,
                                    0.05003798653862764,
                                ],
                                [
                                    0.7354537211739306,
                                    0.03588149414636529,
                                    0.21802760129950846,
                                    0.010637183380195647,
                                ],
                                [
                                    0.7354537211739306,
                                    0.21802760129950846,
                                    0.03588149414636529,
                                    0.010637183380195647,
                                ],
                                [
                                    0.4426431239284858,
                                    0.021595779860651,
                                    0.5108381985449533,
                                    0.024922897665909934,
                                ],
                                [
                                    0.4809057892429547,
                                    0.14256605502291253,
                                    0.29042942607734124,
                                    0.08609872965679156,
                                ],
                                [
                                    0.4809057892429547,
                                    0.29042942607734124,
                                    0.14256605502291253,
                                    0.08609872965679156,
                                ],
                                [
                                    0.4426431239284858,
                                    0.5108381985449533,
                                    0.021595779860651,
                                    0.024922897665909934,
                                ],
                                [
                                    0.2894398855253776,
                                    0.17479901826375918,
                                    0.33403195874048963,
                                    0.2017291374703736,
                                ],
                                [
                                    0.2894398855253776,
                                    0.33403195874048963,
                                    0.17479901826375918,
                                    0.2017291374703736,
                                ],
                                [
                                    0.8556761141810217,
                                    0.0200660256146977,
                                    0.12141071914256549,
                                    0.002847141061715079,
                                ],
                                [
                                    0.8556761141810217,
                                    0.12141071914256549,
                                    0.0200660256146977,
                                    0.002847141061715079,
                                ],
                                [
                                    0.24648998420086896,
                                    0.005780311328983417,
                                    0.7305968491227183,
                                    0.017132855347429362,
                                ],
                                [
                                    0.2689371809836702,
                                    0.03815913054748896,
                                    0.6068049588120493,
                                    0.08609872965679159,
                                ],
                                [
                                    0.2689371809836702,
                                    0.6068049588120493,
                                    0.03815913054748896,
                                    0.08609872965679159,
                                ],
                                [
                                    0.24648998420086896,
                                    0.7305968491227183,
                                    0.005780311328983417,
                                    0.017132855347429362,
                                ],
                                [
                                    0.07747127726609312,
                                    0.17479901826375924,
                                    0.229625034265066,
                                    0.5181046702050817,
                                ],
                                [
                                    0.07747127726609312,
                                    0.229625034265066,
                                    0.17479901826375924,
                                    0.5181046702050817,
                                ],
                                [
                                    0.9511570383963065,
                                    0.004607531669741336,
                                    0.04402218061426743,
                                    0.000213249319684683,
                                ],
                                [
                                    0.9511570383963065,
                                    0.04402218061426743,
                                    0.004607531669741336,
                                    0.000213249319684683,
                                ],
                                [
                                    0.08937453530241306,
                                    0.00043294218015627555,
                                    0.9058046837081609,
                                    0.004387838809269743,
                                ],
                                [
                                    0.06175296505380666,
                                    0.0028580981597410406,
                                    0.8940116050122412,
                                    0.041377331774211074,
                                ],
                                [
                                    0.06175296505380666,
                                    0.8940116050122412,
                                    0.0028580981597410406,
                                    0.041377331774211074,
                                ],
                                [
                                    0.08937453530241306,
                                    0.9058046837081609,
                                    0.00043294218015627555,
                                    0.004387838809269743,
                                ],
                                [
                                    0.00580255660467555,
                                    0.0840049208778938,
                                    0.05880850660887215,
                                    0.8513840159085585,
                                ],
                                [
                                    0.00580255660467555,
                                    0.05880850660887215,
                                    0.0840049208778938,
                                    0.8513840159085585,
                                ],
                                [
                                    0.4790131786467894,
                                    0.212299606403178,
                                    0.21389050982205146,
                                    0.09479670512798105,
                                ],
                                [
                                    0.4790131786467894,
                                    0.21389050982205146,
                                    0.212299606403178,
                                    0.09479670512798105,
                                ],
                                [
                                    0.4342439346302287,
                                    0.19245778720619094,
                                    0.2586597538386121,
                                    0.11463852432496811,
                                ],
                                [
                                    0.4310140570596762,
                                    0.19245778720619097,
                                    0.2602987279902912,
                                    0.11622942774384157,
                                ],
                                [
                                    0.4310140570596762,
                                    0.2602987279902912,
                                    0.19245778720619097,
                                    0.11622942774384157,
                                ],
                                [
                                    0.4342439346302287,
                                    0.2586597538386121,
                                    0.19245778720619094,
                                    0.11463852432496811,
                                ],
                                [
                                    0.3907308783179471,
                                    0.2359708435184726,
                                    0.23274096594792007,
                                    0.14055731221566017,
                                ],
                                [
                                    0.3907308783179471,
                                    0.23274096594792007,
                                    0.2359708435184726,
                                    0.14055731221566017,
                                ],
                                [
                                    0.6007905135846778,
                                    0.17054470173561806,
                                    0.17810626391458415,
                                    0.05055852076511997,
                                ],
                                [
                                    0.6007905135846778,
                                    0.17810626391458415,
                                    0.17054470173561806,
                                    0.05055852076511997,
                                ],
                                [
                                    0.3615941861511486,
                                    0.10264471763798823,
                                    0.4173025913481134,
                                    0.1184585048627498,
                                ],
                                [
                                    0.3462425816537019,
                                    0.10264471763798821,
                                    0.425092633666594,
                                    0.1260200670417159,
                                ],
                                [
                                    0.3462425816537019,
                                    0.425092633666594,
                                    0.10264471763798821,
                                    0.1260200670417159,
                                ],
                                [
                                    0.3615941861511486,
                                    0.4173025913481134,
                                    0.10264471763798823,
                                    0.1184585048627498,
                                ],
                                [
                                    0.2083909477480404,
                                    0.2558479560410964,
                                    0.24049635154364973,
                                    0.2952647446672135,
                                ],
                                [
                                    0.2083909477480404,
                                    0.24049635154364973,
                                    0.2558479560410964,
                                    0.2952647446672135,
                                ],
                                [
                                    0.7803683423858769,
                                    0.09537379740984246,
                                    0.11072540190728916,
                                    0.013532458296991392,
                                ],
                                [
                                    0.7803683423858769,
                                    0.11072540190728916,
                                    0.09537379740984246,
                                    0.013532458296991392,
                                ],
                                [
                                    0.2247964822176397,
                                    0.027473813312212644,
                                    0.6662972620755264,
                                    0.0814324423946212,
                                ],
                                [
                                    0.19362940918852536,
                                    0.02747381331221264,
                                    0.6821127306071941,
                                    0.09678404689206792,
                                ],
                                [
                                    0.19362940918852536,
                                    0.6821127306071941,
                                    0.02747381331221264,
                                    0.09678404689206792,
                                ],
                                [
                                    0.2247964822176397,
                                    0.6662972620755264,
                                    0.027473813312212644,
                                    0.0814324423946212,
                                ],
                                [
                                    0.05577777528286387,
                                    0.1964925202469885,
                                    0.16532544721787412,
                                    0.5824042572522735,
                                ],
                                [
                                    0.05577777528286387,
                                    0.16532544721787412,
                                    0.1964925202469885,
                                    0.5824042572522735,
                                ],
                                [
                                    0.9338649771687145,
                                    0.02189959289733337,
                                    0.043221856154872694,
                                    0.0010135737790794247,
                                ],
                                [
                                    0.9338649771687145,
                                    0.043221856154872694,
                                    0.02189959289733337,
                                    0.0010135737790794247,
                                ],
                                [
                                    0.08774970378222305,
                                    0.0020577737003463,
                                    0.8893371295413642,
                                    0.020855392976066495,
                                ],
                                [
                                    0.044460903826214725,
                                    0.0020577737003463032,
                                    0.9113036662398332,
                                    0.042177656233605816,
                                ],
                                [
                                    0.044460903826214725,
                                    0.9113036662398332,
                                    0.0020577737003463032,
                                    0.042177656233605816,
                                ],
                                [
                                    0.08774970378222305,
                                    0.8893371295413642,
                                    0.0020577737003463,
                                    0.020855392976066495,
                                ],
                                [
                                    0.004177725084485534,
                                    0.0856297523980838,
                                    0.04234095244207549,
                                    0.8678515700753552,
                                ],
                                [
                                    0.004177725084485534,
                                    0.04234095244207549,
                                    0.0856297523980838,
                                    0.8678515700753552,
                                ],
                                [
                                    0.26029872799029125,
                                    0.43101405705967616,
                                    0.11622942774384161,
                                    0.19245778720619094,
                                ],
                                [
                                    0.26029872799029125,
                                    0.11622942774384161,
                                    0.43101405705967616,
                                    0.19245778720619094,
                                ],
                                [
                                    0.23597084351847267,
                                    0.390730878317947,
                                    0.1405573122156602,
                                    0.23274096594792004,
                                ],
                                [
                                    0.21229960640317805,
                                    0.09479670512798108,
                                    0.4790131786467894,
                                    0.21389050982205146,
                                ],
                                [
                                    0.21229960640317805,
                                    0.4790131786467894,
                                    0.09479670512798108,
                                    0.21389050982205146,
                                ],
                                [
                                    0.23597084351847267,
                                    0.1405573122156602,
                                    0.390730878317947,
                                    0.23274096594792004,
                                ],
                                [
                                    0.19245778720619097,
                                    0.4342439346302287,
                                    0.11463852432496814,
                                    0.2586597538386121,
                                ],
                                [
                                    0.19245778720619097,
                                    0.11463852432496814,
                                    0.4342439346302287,
                                    0.2586597538386121,
                                ],
                                [
                                    0.425092633666594,
                                    0.3462425816537019,
                                    0.1260200670417159,
                                    0.10264471763798821,
                                ],
                                [
                                    0.425092633666594,
                                    0.1260200670417159,
                                    0.3462425816537019,
                                    0.10264471763798821,
                                ],
                                [
                                    0.2558479560410964,
                                    0.2083909477480404,
                                    0.2952647446672135,
                                    0.24049635154364973,
                                ],
                                [
                                    0.17054470173561803,
                                    0.05055852076511996,
                                    0.6007905135846778,
                                    0.17810626391458415,
                                ],
                                [
                                    0.17054470173561803,
                                    0.6007905135846778,
                                    0.05055852076511996,
                                    0.17810626391458415,
                                ],
                                [
                                    0.2558479560410964,
                                    0.2952647446672135,
                                    0.2083909477480404,
                                    0.24049635154364973,
                                ],
                                [
                                    0.10264471763798821,
                                    0.3615941861511486,
                                    0.11845850486274978,
                                    0.4173025913481134,
                                ],
                                [
                                    0.10264471763798821,
                                    0.11845850486274978,
                                    0.3615941861511486,
                                    0.4173025913481134,
                                ],
                                [
                                    0.6821127306071941,
                                    0.1936294091885254,
                                    0.09678404689206792,
                                    0.027473813312212644,
                                ],
                                [
                                    0.6821127306071941,
                                    0.09678404689206792,
                                    0.1936294091885254,
                                    0.027473813312212644,
                                ],
                                [
                                    0.1964925202469885,
                                    0.05577777528286389,
                                    0.5824042572522735,
                                    0.16532544721787415,
                                ],
                                [
                                    0.09537379740984249,
                                    0.013532458296991396,
                                    0.7803683423858769,
                                    0.11072540190728916,
                                ],
                                [
                                    0.09537379740984249,
                                    0.7803683423858769,
                                    0.013532458296991396,
                                    0.11072540190728916,
                                ],
                                [
                                    0.1964925202469885,
                                    0.5824042572522735,
                                    0.05577777528286389,
                                    0.16532544721787415,
                                ],
                                [
                                    0.02747381331221265,
                                    0.2247964822176397,
                                    0.08143244239462122,
                                    0.6662972620755264,
                                ],
                                [
                                    0.02747381331221265,
                                    0.08143244239462122,
                                    0.2247964822176397,
                                    0.6662972620755264,
                                ],
                                [
                                    0.9113036662398333,
                                    0.04446090382621467,
                                    0.042177656233605816,
                                    0.0020577737003463006,
                                ],
                                [
                                    0.9113036662398333,
                                    0.042177656233605816,
                                    0.04446090382621467,
                                    0.0020577737003463006,
                                ],
                                [
                                    0.08562975239808382,
                                    0.004177725084485529,
                                    0.8678515700753553,
                                    0.04234095244207544,
                                ],
                                [
                                    0.02189959289733343,
                                    0.0010135737790794273,
                                    0.9338649771687144,
                                    0.04322185615487269,
                                ],
                                [
                                    0.02189959289733343,
                                    0.9338649771687144,
                                    0.0010135737790794273,
                                    0.04322185615487269,
                                ],
                                [
                                    0.08562975239808382,
                                    0.8678515700753553,
                                    0.004177725084485529,
                                    0.04234095244207544,
                                ],
                                [
                                    0.002057773700346306,
                                    0.08774970378222303,
                                    0.02085539297606655,
                                    0.8893371295413641,
                                ],
                                [
                                    0.002057773700346306,
                                    0.02085539297606655,
                                    0.08774970378222303,
                                    0.8893371295413641,
                                ],
                                [
                                    0.09266557564231039,
                                    0.598647209407657,
                                    0.041377331774211074,
                                    0.26730988317582144,
                                ],
                                [
                                    0.09266557564231039,
                                    0.041377331774211074,
                                    0.598647209407657,
                                    0.26730988317582144,
                                ],
                                [
                                    0.0840049208778938,
                                    0.5426968009585259,
                                    0.05003798653862766,
                                    0.32326029162495257,
                                ],
                                [
                                    0.04466645405519716,
                                    0.01994460915835054,
                                    0.6466463309947702,
                                    0.288742605791682,
                                ],
                                [
                                    0.04466645405519716,
                                    0.6466463309947702,
                                    0.01994460915835054,
                                    0.288742605791682,
                                ],
                                [
                                    0.0840049208778938,
                                    0.05003798653862766,
                                    0.5426968009585259,
                                    0.32326029162495257,
                                ],
                                [
                                    0.0404918645656121,
                                    0.5862098572708075,
                                    0.0241191986479356,
                                    0.34917907951564464,
                                ],
                                [
                                    0.0404918645656121,
                                    0.0241191986479356,
                                    0.5862098572708075,
                                    0.34917907951564464,
                                ],
                                [
                                    0.2904294260773413,
                                    0.48090578924295463,
                                    0.08609872965679159,
                                    0.1425660550229125,
                                ],
                                [
                                    0.2904294260773413,
                                    0.08609872965679159,
                                    0.48090578924295463,
                                    0.1425660550229125,
                                ],
                                [
                                    0.17479901826375924,
                                    0.2894398855253776,
                                    0.20172913747037366,
                                    0.3340319587404895,
                                ],
                                [
                                    0.03588149414636536,
                                    0.010637183380195668,
                                    0.7354537211739306,
                                    0.21802760129950843,
                                ],
                                [
                                    0.03588149414636536,
                                    0.7354537211739306,
                                    0.010637183380195668,
                                    0.21802760129950843,
                                ],
                                [
                                    0.17479901826375924,
                                    0.20172913747037366,
                                    0.2894398855253776,
                                    0.3340319587404895,
                                ],
                                [
                                    0.021595779860651042,
                                    0.44264312392848576,
                                    0.024922897665909983,
                                    0.5108381985449533,
                                ],
                                [
                                    0.021595779860651042,
                                    0.024922897665909983,
                                    0.44264312392848576,
                                    0.5108381985449533,
                                ],
                                [
                                    0.6068049588120493,
                                    0.26893718098367014,
                                    0.08609872965679159,
                                    0.038159130547488956,
                                ],
                                [
                                    0.6068049588120493,
                                    0.08609872965679159,
                                    0.26893718098367014,
                                    0.038159130547488956,
                                ],
                                [
                                    0.17479901826375924,
                                    0.07747127726609311,
                                    0.5181046702050817,
                                    0.22962503426506597,
                                ],
                                [
                                    0.020066025614697766,
                                    0.0028471410617150884,
                                    0.8556761141810217,
                                    0.12141071914256547,
                                ],
                                [
                                    0.020066025614697766,
                                    0.8556761141810217,
                                    0.0028471410617150884,
                                    0.12141071914256547,
                                ],
                                [
                                    0.17479901826375924,
                                    0.5181046702050817,
                                    0.07747127726609311,
                                    0.22962503426506597,
                                ],
                                [
                                    0.005780311328983436,
                                    0.24648998420086893,
                                    0.017132855347429417,
                                    0.7305968491227183,
                                ],
                                [
                                    0.005780311328983436,
                                    0.017132855347429417,
                                    0.24648998420086893,
                                    0.7305968491227183,
                                ],
                                [
                                    0.8940116050122412,
                                    0.0617529650538067,
                                    0.041377331774211074,
                                    0.0028580981597410423,
                                ],
                                [
                                    0.8940116050122412,
                                    0.041377331774211074,
                                    0.0617529650538067,
                                    0.0028580981597410423,
                                ],
                                [
                                    0.0840049208778938,
                                    0.005802556604675554,
                                    0.8513840159085585,
                                    0.05880850660887219,
                                ],
                                [
                                    0.00460753166974138,
                                    0.00021324931968468507,
                                    0.9511570383963065,
                                    0.04402218061426743,
                                ],
                                [
                                    0.00460753166974138,
                                    0.9511570383963065,
                                    0.00021324931968468507,
                                    0.04402218061426743,
                                ],
                                [
                                    0.0840049208778938,
                                    0.8513840159085585,
                                    0.005802556604675554,
                                    0.05880850660887219,
                                ],
                                [
                                    0.0004329421801562797,
                                    0.08937453530241306,
                                    0.0043878388092697855,
                                    0.9058046837081609,
                                ],
                                [
                                    0.0004329421801562797,
                                    0.0043878388092697855,
                                    0.08937453530241306,
                                    0.9058046837081609,
                                ],
                                [
                                    0.3491790795156447,
                                    0.024119198647935595,
                                    0.5862098572708075,
                                    0.040491864565612094,
                                ],
                                [
                                    0.3491790795156447,
                                    0.5862098572708075,
                                    0.024119198647935595,
                                    0.040491864565612094,
                                ],
                                [
                                    0.28874260579168204,
                                    0.01994460915835054,
                                    0.6466463309947702,
                                    0.044666454055197154,
                                ],
                                [
                                    0.3232602916249526,
                                    0.5426968009585259,
                                    0.050037986538627656,
                                    0.08400492087789377,
                                ],
                                [
                                    0.3232602916249526,
                                    0.050037986538627656,
                                    0.5426968009585259,
                                    0.08400492087789377,
                                ],
                                [
                                    0.28874260579168204,
                                    0.6466463309947702,
                                    0.01994460915835054,
                                    0.044666454055197154,
                                ],
                                [
                                    0.2673098831758215,
                                    0.04137733177421107,
                                    0.598647209407657,
                                    0.09266557564231036,
                                ],
                                [
                                    0.2673098831758215,
                                    0.598647209407657,
                                    0.04137733177421107,
                                    0.09266557564231036,
                                ],
                                [
                                    0.5108381985449533,
                                    0.024922897665909934,
                                    0.44264312392848576,
                                    0.021595779860651,
                                ],
                                [
                                    0.5108381985449533,
                                    0.44264312392848576,
                                    0.024922897665909934,
                                    0.021595779860651,
                                ],
                                [
                                    0.21802760129950854,
                                    0.01063718338019565,
                                    0.7354537211739305,
                                    0.03588149414636529,
                                ],
                                [
                                    0.33403195874048963,
                                    0.2894398855253776,
                                    0.2017291374703736,
                                    0.17479901826375915,
                                ],
                                [
                                    0.33403195874048963,
                                    0.2017291374703736,
                                    0.2894398855253776,
                                    0.17479901826375915,
                                ],
                                [
                                    0.21802760129950854,
                                    0.7354537211739305,
                                    0.01063718338019565,
                                    0.03588149414636529,
                                ],
                                [
                                    0.14256605502291259,
                                    0.0860987296567916,
                                    0.48090578924295463,
                                    0.2904294260773412,
                                ],
                                [
                                    0.14256605502291259,
                                    0.48090578924295463,
                                    0.0860987296567916,
                                    0.2904294260773412,
                                ],
                                [
                                    0.7305968491227183,
                                    0.017132855347429362,
                                    0.24648998420086896,
                                    0.005780311328983417,
                                ],
                                [
                                    0.7305968491227183,
                                    0.24648998420086896,
                                    0.017132855347429362,
                                    0.005780311328983417,
                                ],
                                [
                                    0.12141071914256546,
                                    0.0028471410617150784,
                                    0.8556761141810217,
                                    0.0200660256146977,
                                ],
                                [
                                    0.229625034265066,
                                    0.07747127726609312,
                                    0.5181046702050817,
                                    0.17479901826375924,
                                ],
                                [
                                    0.229625034265066,
                                    0.5181046702050817,
                                    0.07747127726609312,
                                    0.17479901826375924,
                                ],
                                [
                                    0.12141071914256546,
                                    0.8556761141810217,
                                    0.0028471410617150784,
                                    0.0200660256146977,
                                ],
                                [
                                    0.038159130547488956,
                                    0.08609872965679158,
                                    0.2689371809836702,
                                    0.6068049588120493,
                                ],
                                [
                                    0.038159130547488956,
                                    0.2689371809836702,
                                    0.08609872965679158,
                                    0.6068049588120493,
                                ],
                                [
                                    0.9058046837081609,
                                    0.004387838809269743,
                                    0.08937453530241307,
                                    0.0004329421801562756,
                                ],
                                [
                                    0.9058046837081609,
                                    0.08937453530241307,
                                    0.004387838809269743,
                                    0.0004329421801562756,
                                ],
                                [
                                    0.044022180614267443,
                                    0.00021324931968468307,
                                    0.9511570383963065,
                                    0.004607531669741336,
                                ],
                                [
                                    0.05880850660887215,
                                    0.0058025566046755505,
                                    0.8513840159085585,
                                    0.08400492087789381,
                                ],
                                [
                                    0.05880850660887215,
                                    0.8513840159085585,
                                    0.0058025566046755505,
                                    0.08400492087789381,
                                ],
                                [
                                    0.044022180614267443,
                                    0.9511570383963065,
                                    0.00021324931968468307,
                                    0.004607531669741336,
                                ],
                                [
                                    0.0028580981597410415,
                                    0.04137733177421109,
                                    0.06175296505380666,
                                    0.8940116050122412,
                                ],
                                [
                                    0.0028580981597410415,
                                    0.06175296505380666,
                                    0.04137733177421109,
                                    0.8940116050122412,
                                ],
                                [
                                    0.25865975383861217,
                                    0.11463852432496813,
                                    0.4342439346302287,
                                    0.19245778720619094,
                                ],
                                [
                                    0.25865975383861217,
                                    0.4342439346302287,
                                    0.11463852432496813,
                                    0.19245778720619094,
                                ],
                                [
                                    0.21389050982205152,
                                    0.09479670512798108,
                                    0.4790131786467894,
                                    0.212299606403178,
                                ],
                                [
                                    0.23274096594792013,
                                    0.3907308783179471,
                                    0.14055731221566017,
                                    0.2359708435184726,
                                ],
                                [
                                    0.23274096594792013,
                                    0.14055731221566017,
                                    0.3907308783179471,
                                    0.2359708435184726,
                                ],
                                [
                                    0.21389050982205152,
                                    0.4790131786467894,
                                    0.09479670512798108,
                                    0.212299606403178,
                                ],
                                [
                                    0.192457787206191,
                                    0.1162294277438416,
                                    0.4310140570596762,
                                    0.2602987279902912,
                                ],
                                [
                                    0.192457787206191,
                                    0.4310140570596762,
                                    0.1162294277438416,
                                    0.2602987279902912,
                                ],
                                [
                                    0.4173025913481134,
                                    0.1184585048627498,
                                    0.3615941861511485,
                                    0.10264471763798821,
                                ],
                                [
                                    0.4173025913481134,
                                    0.3615941861511485,
                                    0.1184585048627498,
                                    0.10264471763798821,
                                ],
                                [
                                    0.1781062639145842,
                                    0.050558520765119984,
                                    0.6007905135846778,
                                    0.17054470173561803,
                                ],
                                [
                                    0.24049635154364973,
                                    0.20839094774804037,
                                    0.2952647446672135,
                                    0.2558479560410964,
                                ],
                                [
                                    0.24049635154364973,
                                    0.2952647446672135,
                                    0.20839094774804037,
                                    0.2558479560410964,
                                ],
                                [
                                    0.1781062639145842,
                                    0.6007905135846778,
                                    0.050558520765119984,
                                    0.17054470173561803,
                                ],
                                [
                                    0.10264471763798826,
                                    0.12602006704171592,
                                    0.34624258165370186,
                                    0.42509263366659394,
                                ],
                                [
                                    0.10264471763798826,
                                    0.34624258165370186,
                                    0.12602006704171592,
                                    0.42509263366659394,
                                ],
                                [
                                    0.6662972620755264,
                                    0.0814324423946212,
                                    0.2247964822176397,
                                    0.027473813312212644,
                                ],
                                [
                                    0.6662972620755264,
                                    0.2247964822176397,
                                    0.0814324423946212,
                                    0.027473813312212644,
                                ],
                                [
                                    0.11072540190728915,
                                    0.013532458296991389,
                                    0.7803683423858769,
                                    0.09537379740984246,
                                ],
                                [
                                    0.16532544721787412,
                                    0.05577777528286387,
                                    0.5824042572522735,
                                    0.1964925202469885,
                                ],
                                [
                                    0.16532544721787412,
                                    0.5824042572522735,
                                    0.05577777528286387,
                                    0.1964925202469885,
                                ],
                                [
                                    0.11072540190728915,
                                    0.7803683423858769,
                                    0.013532458296991389,
                                    0.09537379740984246,
                                ],
                                [
                                    0.027473813312212637,
                                    0.0967840468920679,
                                    0.19362940918852536,
                                    0.6821127306071941,
                                ],
                                [
                                    0.027473813312212637,
                                    0.19362940918852536,
                                    0.0967840468920679,
                                    0.6821127306071941,
                                ],
                                [
                                    0.8893371295413642,
                                    0.020855392976066495,
                                    0.08774970378222306,
                                    0.0020577737003463006,
                                ],
                                [
                                    0.8893371295413642,
                                    0.08774970378222306,
                                    0.020855392976066495,
                                    0.0020577737003463006,
                                ],
                                [
                                    0.04322185615487271,
                                    0.0010135737790794251,
                                    0.9338649771687145,
                                    0.02189959289733337,
                                ],
                                [
                                    0.04234095244207549,
                                    0.004177725084485534,
                                    0.8678515700753552,
                                    0.08562975239808382,
                                ],
                                [
                                    0.04234095244207549,
                                    0.8678515700753552,
                                    0.004177725084485534,
                                    0.08562975239808382,
                                ],
                                [
                                    0.04322185615487271,
                                    0.9338649771687145,
                                    0.0010135737790794251,
                                    0.02189959289733337,
                                ],
                                [
                                    0.0020577737003463037,
                                    0.04217765623360583,
                                    0.044460903826214725,
                                    0.9113036662398332,
                                ],
                                [
                                    0.0020577737003463037,
                                    0.044460903826214725,
                                    0.04217765623360583,
                                    0.9113036662398332,
                                ],
                                [
                                    0.14055731221566023,
                                    0.23274096594792007,
                                    0.23597084351847267,
                                    0.390730878317947,
                                ],
                                [
                                    0.14055731221566023,
                                    0.23597084351847267,
                                    0.23274096594792007,
                                    0.390730878317947,
                                ],
                                [
                                    0.11622942774384162,
                                    0.19245778720619097,
                                    0.26029872799029125,
                                    0.43101405705967616,
                                ],
                                [
                                    0.11463852432496816,
                                    0.19245778720619097,
                                    0.25865975383861217,
                                    0.4342439346302287,
                                ],
                                [
                                    0.11463852432496816,
                                    0.25865975383861217,
                                    0.19245778720619097,
                                    0.4342439346302287,
                                ],
                                [
                                    0.11622942774384162,
                                    0.26029872799029125,
                                    0.19245778720619097,
                                    0.43101405705967616,
                                ],
                                [
                                    0.09479670512798109,
                                    0.21389050982205152,
                                    0.21229960640317805,
                                    0.4790131786467894,
                                ],
                                [
                                    0.09479670512798109,
                                    0.21229960640317805,
                                    0.21389050982205152,
                                    0.4790131786467894,
                                ],
                                [
                                    0.2952647446672135,
                                    0.24049635154364973,
                                    0.2558479560410964,
                                    0.20839094774804037,
                                ],
                                [
                                    0.2952647446672135,
                                    0.2558479560410964,
                                    0.24049635154364973,
                                    0.20839094774804037,
                                ],
                                [
                                    0.12602006704171592,
                                    0.10264471763798826,
                                    0.42509263366659394,
                                    0.34624258165370186,
                                ],
                                [
                                    0.11845850486274978,
                                    0.1026447176379882,
                                    0.4173025913481134,
                                    0.3615941861511485,
                                ],
                                [
                                    0.11845850486274978,
                                    0.4173025913481134,
                                    0.1026447176379882,
                                    0.3615941861511485,
                                ],
                                [
                                    0.12602006704171592,
                                    0.42509263366659394,
                                    0.10264471763798826,
                                    0.34624258165370186,
                                ],
                                [
                                    0.050558520765119984,
                                    0.1781062639145842,
                                    0.170544701735618,
                                    0.6007905135846778,
                                ],
                                [
                                    0.050558520765119984,
                                    0.170544701735618,
                                    0.1781062639145842,
                                    0.6007905135846778,
                                ],
                                [
                                    0.5824042572522735,
                                    0.16532544721787415,
                                    0.1964925202469885,
                                    0.05577777528286389,
                                ],
                                [
                                    0.5824042572522735,
                                    0.1964925202469885,
                                    0.16532544721787415,
                                    0.05577777528286389,
                                ],
                                [
                                    0.0967840468920679,
                                    0.02747381331221264,
                                    0.6821127306071941,
                                    0.1936294091885254,
                                ],
                                [
                                    0.08143244239462122,
                                    0.02747381331221265,
                                    0.6662972620755264,
                                    0.2247964822176397,
                                ],
                                [
                                    0.08143244239462122,
                                    0.6662972620755264,
                                    0.02747381331221265,
                                    0.2247964822176397,
                                ],
                                [
                                    0.0967840468920679,
                                    0.6821127306071941,
                                    0.02747381331221264,
                                    0.1936294091885254,
                                ],
                                [
                                    0.013532458296991392,
                                    0.11072540190728915,
                                    0.09537379740984249,
                                    0.7803683423858769,
                                ],
                                [
                                    0.013532458296991392,
                                    0.09537379740984249,
                                    0.11072540190728915,
                                    0.7803683423858769,
                                ],
                                [
                                    0.8678515700753553,
                                    0.04234095244207544,
                                    0.08562975239808383,
                                    0.00417772508448553,
                                ],
                                [
                                    0.8678515700753553,
                                    0.08562975239808383,
                                    0.04234095244207544,
                                    0.00417772508448553,
                                ],
                                [
                                    0.04217765623360583,
                                    0.0020577737003463015,
                                    0.9113036662398333,
                                    0.04446090382621467,
                                ],
                                [
                                    0.02085539297606655,
                                    0.002057773700346306,
                                    0.8893371295413641,
                                    0.08774970378222305,
                                ],
                                [
                                    0.02085539297606655,
                                    0.8893371295413641,
                                    0.002057773700346306,
                                    0.08774970378222305,
                                ],
                                [
                                    0.04217765623360583,
                                    0.9113036662398333,
                                    0.0020577737003463015,
                                    0.04446090382621467,
                                ],
                                [
                                    0.0010135737790794277,
                                    0.0432218561548727,
                                    0.02189959289733343,
                                    0.9338649771687144,
                                ],
                                [
                                    0.0010135737790794277,
                                    0.02189959289733343,
                                    0.0432218561548727,
                                    0.9338649771687144,
                                ],
                                [
                                    0.05003798653862768,
                                    0.3232602916249526,
                                    0.0840049208778938,
                                    0.5426968009585259,
                                ],
                                [
                                    0.05003798653862768,
                                    0.0840049208778938,
                                    0.3232602916249526,
                                    0.5426968009585259,
                                ],
                                [
                                    0.04137733177421108,
                                    0.2673098831758215,
                                    0.09266557564231039,
                                    0.598647209407657,
                                ],
                                [
                                    0.024119198647935602,
                                    0.0404918645656121,
                                    0.3491790795156447,
                                    0.5862098572708075,
                                ],
                                [
                                    0.024119198647935602,
                                    0.3491790795156447,
                                    0.0404918645656121,
                                    0.5862098572708075,
                                ],
                                [
                                    0.04137733177421108,
                                    0.09266557564231039,
                                    0.2673098831758215,
                                    0.598647209407657,
                                ],
                                [
                                    0.019944609158350543,
                                    0.28874260579168204,
                                    0.04466645405519716,
                                    0.6466463309947702,
                                ],
                                [
                                    0.019944609158350543,
                                    0.04466645405519716,
                                    0.28874260579168204,
                                    0.6466463309947702,
                                ],
                                [
                                    0.20172913747037366,
                                    0.3340319587404895,
                                    0.1747990182637592,
                                    0.2894398855253775,
                                ],
                                [
                                    0.20172913747037366,
                                    0.1747990182637592,
                                    0.3340319587404895,
                                    0.2894398855253775,
                                ],
                                [
                                    0.08609872965679162,
                                    0.14256605502291256,
                                    0.2904294260773413,
                                    0.4809057892429545,
                                ],
                                [
                                    0.024922897665909983,
                                    0.021595779860651042,
                                    0.5108381985449533,
                                    0.4426431239284857,
                                ],
                                [
                                    0.024922897665909983,
                                    0.5108381985449533,
                                    0.021595779860651042,
                                    0.4426431239284857,
                                ],
                                [
                                    0.08609872965679162,
                                    0.2904294260773413,
                                    0.14256605502291256,
                                    0.4809057892429545,
                                ],
                                [
                                    0.010637183380195672,
                                    0.21802760129950852,
                                    0.03588149414636536,
                                    0.7354537211739305,
                                ],
                                [
                                    0.010637183380195672,
                                    0.03588149414636536,
                                    0.21802760129950852,
                                    0.7354537211739305,
                                ],
                                [
                                    0.5181046702050817,
                                    0.22962503426506597,
                                    0.17479901826375924,
                                    0.07747127726609311,
                                ],
                                [
                                    0.5181046702050817,
                                    0.17479901826375924,
                                    0.22962503426506597,
                                    0.07747127726609311,
                                ],
                                [
                                    0.08609872965679158,
                                    0.03815913054748895,
                                    0.6068049588120493,
                                    0.26893718098367014,
                                ],
                                [
                                    0.017132855347429417,
                                    0.005780311328983436,
                                    0.7305968491227183,
                                    0.24648998420086893,
                                ],
                                [
                                    0.017132855347429417,
                                    0.7305968491227183,
                                    0.005780311328983436,
                                    0.24648998420086893,
                                ],
                                [
                                    0.08609872965679158,
                                    0.6068049588120493,
                                    0.03815913054748895,
                                    0.26893718098367014,
                                ],
                                [
                                    0.002847141061715088,
                                    0.12141071914256545,
                                    0.020066025614697766,
                                    0.8556761141810217,
                                ],
                                [
                                    0.002847141061715088,
                                    0.020066025614697766,
                                    0.12141071914256545,
                                    0.8556761141810217,
                                ],
                                [
                                    0.8513840159085585,
                                    0.05880850660887219,
                                    0.08400492087789381,
                                    0.005802556604675555,
                                ],
                                [
                                    0.8513840159085585,
                                    0.08400492087789381,
                                    0.05880850660887219,
                                    0.005802556604675555,
                                ],
                                [
                                    0.04137733177421109,
                                    0.002858098159741043,
                                    0.8940116050122412,
                                    0.0617529650538067,
                                ],
                                [
                                    0.0043878388092697855,
                                    0.00043294218015627983,
                                    0.9058046837081609,
                                    0.08937453530241307,
                                ],
                                [
                                    0.0043878388092697855,
                                    0.9058046837081609,
                                    0.00043294218015627983,
                                    0.08937453530241307,
                                ],
                                [
                                    0.04137733177421109,
                                    0.8940116050122412,
                                    0.002858098159741043,
                                    0.0617529650538067,
                                ],
                                [
                                    0.00021324931968468515,
                                    0.044022180614267443,
                                    0.00460753166974138,
                                    0.9511570383963065,
                                ],
                                [
                                    0.00021324931968468515,
                                    0.00460753166974138,
                                    0.044022180614267443,
                                    0.9511570383963065,
                                ],
                                [
                                    0.12118603682432559,
                                    0.008370805317364349,
                                    0.8142028999621267,
                                    0.056240257896183345,
                                ],
                                [
                                    0.12118603682432559,
                                    0.8142028999621267,
                                    0.008370805317364349,
                                    0.056240257896183345,
                                ],
                                [
                                    0.06074956310036295,
                                    0.004196215827779292,
                                    0.8746393736860893,
                                    0.0604148473857684,
                                ],
                                [
                                    0.11219066634531451,
                                    0.753766426238164,
                                    0.017366175796375425,
                                    0.116676731620146,
                                ],
                                [
                                    0.11219066634531451,
                                    0.017366175796375425,
                                    0.753766426238164,
                                    0.116676731620146,
                                ],
                                [
                                    0.06074956310036295,
                                    0.8746393736860893,
                                    0.004196215827779292,
                                    0.0604148473857684,
                                ],
                                [
                                    0.0562402578961834,
                                    0.008705521031958837,
                                    0.8097168346872952,
                                    0.12533738638456257,
                                ],
                                [
                                    0.0562402578961834,
                                    0.8097168346872952,
                                    0.008705521031958837,
                                    0.12533738638456257,
                                ],
                                [
                                    0.3386821841089406,
                                    0.01652370836765293,
                                    0.6147991383644985,
                                    0.029994969158908005,
                                ],
                                [
                                    0.3386821841089406,
                                    0.6147991383644985,
                                    0.01652370836765293,
                                    0.029994969158908005,
                                ],
                                [
                                    0.04587158686349574,
                                    0.0022379940819386426,
                                    0.9076097356099433,
                                    0.04428068344462229,
                                ],
                                [
                                    0.22146087287648508,
                                    0.40201097138938213,
                                    0.13374501960010843,
                                    0.24278313613402436,
                                ],
                                [
                                    0.22146087287648508,
                                    0.13374501960010843,
                                    0.40201097138938213,
                                    0.24278313613402436,
                                ],
                                [
                                    0.04587158686349574,
                                    0.9076097356099433,
                                    0.0022379940819386426,
                                    0.04428068344462229,
                                ],
                                [
                                    0.029994969158907998,
                                    0.018114611786526385,
                                    0.5934768751069592,
                                    0.3584135439476064,
                                ],
                                [
                                    0.029994969158907998,
                                    0.5934768751069592,
                                    0.018114611786526385,
                                    0.3584135439476064,
                                ],
                                [
                                    0.6347301542968586,
                                    0.014884734215973834,
                                    0.3423566790267286,
                                    0.008028432460438944,
                                ],
                                [
                                    0.6347301542968586,
                                    0.3423566790267286,
                                    0.014884734215973834,
                                    0.008028432460438944,
                                ],
                                [
                                    0.025544024316705792,
                                    0.000599019930259551,
                                    0.9515428090068815,
                                    0.022314146746153226,
                                ],
                                [
                                    0.19949433617801599,
                                    0.10760197535314313,
                                    0.45012055233481646,
                                    0.2427831361340244,
                                ],
                                [
                                    0.19949433617801599,
                                    0.45012055233481646,
                                    0.10760197535314313,
                                    0.2427831361340244,
                                ],
                                [
                                    0.025544024316705792,
                                    0.9515428090068815,
                                    0.000599019930259551,
                                    0.022314146746153226,
                                ],
                                [
                                    0.008028432460438946,
                                    0.018114611786526395,
                                    0.2990678790707202,
                                    0.6747890766823145,
                                ],
                                [
                                    0.008028432460438946,
                                    0.2990678790707202,
                                    0.018114611786526395,
                                    0.6747890766823145,
                                ],
                                [
                                    0.8710444830906088,
                                    0.004219455757127304,
                                    0.1241347359199652,
                                    0.0006013252322987152,
                                ],
                                [
                                    0.8710444830906088,
                                    0.1241347359199652,
                                    0.004219455757127304,
                                    0.0006013252322987152,
                                ],
                                [
                                    0.009261979996715351,
                                    4.4866267542243575e-05,
                                    0.9859172390138586,
                                    0.004775914721883775,
                                ],
                                [
                                    0.05655173368142983,
                                    0.008059329532117876,
                                    0.8187122051663063,
                                    0.11667673162014604,
                                ],
                                [
                                    0.05655173368142983,
                                    0.8187122051663063,
                                    0.008059329532117876,
                                    0.11667673162014604,
                                ],
                                [
                                    0.009261979996715351,
                                    0.9859172390138586,
                                    4.4866267542243575e-05,
                                    0.004775914721883775,
                                ],
                                [
                                    0.0006013252322987178,
                                    0.008705521031958877,
                                    0.06400973798124898,
                                    0.9266834157544934,
                                ],
                                [
                                    0.0006013252322987178,
                                    0.06400973798124898,
                                    0.008705521031958877,
                                    0.9266834157544934,
                                ],
                                [
                                    0.08977041378635232,
                                    0.03978642835533761,
                                    0.6031332746824886,
                                    0.26730988317582144,
                                ],
                                [
                                    0.08977041378635232,
                                    0.6031332746824886,
                                    0.03978642835533761,
                                    0.26730988317582144,
                                ],
                                [
                                    0.04500116976979168,
                                    0.019944609158350557,
                                    0.6479025186990492,
                                    0.2871517023728085,
                                ],
                                [
                                    0.08077504330734125,
                                    0.5426968009585259,
                                    0.04878179883434869,
                                    0.3277463568997841,
                                ],
                                [
                                    0.08077504330734125,
                                    0.04878179883434869,
                                    0.5426968009585259,
                                    0.3277463568997841,
                                ],
                                [
                                    0.04500116976979168,
                                    0.6479025186990492,
                                    0.019944609158350557,
                                    0.2871517023728085,
                                ],
                                [
                                    0.040491864565612136,
                                    0.0244539143625301,
                                    0.5829799797002551,
                                    0.3520742413716027,
                                ],
                                [
                                    0.040491864565612136,
                                    0.5829799797002551,
                                    0.0244539143625301,
                                    0.3520742413716027,
                                ],
                                [
                                    0.27666872499876805,
                                    0.07853716747782548,
                                    0.502228052500494,
                                    0.14256605502291253,
                                ],
                                [
                                    0.27666872499876805,
                                    0.502228052500494,
                                    0.07853716747782548,
                                    0.14256605502291253,
                                ],
                                [
                                    0.03747239756523874,
                                    0.010637183380195644,
                                    0.7414243799340232,
                                    0.21046603912054238,
                                ],
                                [
                                    0.15944741376631252,
                                    0.2894398855253776,
                                    0.195758478710281,
                                    0.3553542219980289,
                                ],
                                [
                                    0.15944741376631252,
                                    0.195758478710281,
                                    0.2894398855253776,
                                    0.3553542219980289,
                                ],
                                [
                                    0.03747239756523874,
                                    0.7414243799340232,
                                    0.010637183380195644,
                                    0.21046603912054238,
                                ],
                                [
                                    0.021595779860650997,
                                    0.026513801084783385,
                                    0.42729151943103916,
                                    0.5245988996235265,
                                ],
                                [
                                    0.021595779860650997,
                                    0.42729151943103916,
                                    0.026513801084783385,
                                    0.5245988996235265,
                                ],
                                [
                                    0.5788677633534876,
                                    0.07074712515934489,
                                    0.31222598093967857,
                                    0.038159130547488956,
                                ],
                                [
                                    0.5788677633534876,
                                    0.31222598093967857,
                                    0.07074712515934489,
                                    0.038159130547488956,
                                ],
                                [
                                    0.023295903185250263,
                                    0.002847141061715079,
                                    0.8677978411079159,
                                    0.10605911464511877,
                                ],
                                [
                                    0.1436319452346449,
                                    0.0774712772660931,
                                    0.5059829432781875,
                                    0.27291383422107446,
                                ],
                                [
                                    0.1436319452346449,
                                    0.5059829432781875,
                                    0.0774712772660931,
                                    0.27291383422107446,
                                ],
                                [
                                    0.023295903185250263,
                                    0.8677978411079159,
                                    0.002847141061715079,
                                    0.10605911464511877,
                                ],
                                [
                                    0.005780311328983416,
                                    0.020362732917981925,
                                    0.2153229111717546,
                                    0.75853404458128,
                                ],
                                [
                                    0.005780311328983416,
                                    0.2153229111717546,
                                    0.020362732917981925,
                                    0.75853404458128,
                                ],
                                [
                                    0.8552088703310644,
                                    0.020055068516671756,
                                    0.12187796299252289,
                                    0.0028580981597410423,
                                ],
                                [
                                    0.8552088703310644,
                                    0.12187796299252289,
                                    0.020055068516671756,
                                    0.0028580981597410423,
                                ],
                                [
                                    0.009093596944572912,
                                    0.00021324931968468407,
                                    0.9679932363790144,
                                    0.022699917356728112,
                                ],
                                [
                                    0.040716120921885465,
                                    0.005802556604675562,
                                    0.8345478179258506,
                                    0.11893350454758836,
                                ],
                                [
                                    0.040716120921885465,
                                    0.8345478179258506,
                                    0.005802556604675562,
                                    0.11893350454758836,
                                ],
                                [
                                    0.009093596944572912,
                                    0.9679932363790144,
                                    0.00021324931968468407,
                                    0.022699917356728112,
                                ],
                                [
                                    0.00043294218015627826,
                                    0.008873904084101318,
                                    0.04608573534640475,
                                    0.9446074183893377,
                                ],
                                [
                                    0.00043294218015627826,
                                    0.04608573534640475,
                                    0.008873904084101318,
                                    0.9446074183893377,
                                ],
                                [
                                    0.0487817988343487,
                                    0.08077504330734124,
                                    0.3277463568997842,
                                    0.5426968009585259,
                                ],
                                [
                                    0.0487817988343487,
                                    0.3277463568997842,
                                    0.08077504330734124,
                                    0.5426968009585259,
                                ],
                                [
                                    0.024453914362530107,
                                    0.04049186456561213,
                                    0.3520742413716028,
                                    0.582979979700255,
                                ],
                                [
                                    0.03978642835533762,
                                    0.2673098831758215,
                                    0.08977041378635232,
                                    0.6031332746824886,
                                ],
                                [
                                    0.03978642835533762,
                                    0.08977041378635232,
                                    0.2673098831758215,
                                    0.6031332746824886,
                                ],
                                [
                                    0.024453914362530107,
                                    0.3520742413716028,
                                    0.04049186456561213,
                                    0.582979979700255,
                                ],
                                [
                                    0.01994460915835056,
                                    0.04500116976979168,
                                    0.28715170237280857,
                                    0.6479025186990492,
                                ],
                                [
                                    0.01994460915835056,
                                    0.28715170237280857,
                                    0.04500116976979168,
                                    0.6479025186990492,
                                ],
                                [
                                    0.195758478710281,
                                    0.15944741376631252,
                                    0.3553542219980289,
                                    0.2894398855253776,
                                ],
                                [
                                    0.195758478710281,
                                    0.3553542219980289,
                                    0.15944741376631252,
                                    0.2894398855253776,
                                ],
                                [
                                    0.026513801084783385,
                                    0.021595779860650997,
                                    0.5245988996235265,
                                    0.42729151943103916,
                                ],
                                [
                                    0.07853716747782546,
                                    0.14256605502291253,
                                    0.27666872499876805,
                                    0.502228052500494,
                                ],
                                [
                                    0.07853716747782546,
                                    0.27666872499876805,
                                    0.14256605502291253,
                                    0.502228052500494,
                                ],
                                [
                                    0.026513801084783385,
                                    0.5245988996235265,
                                    0.021595779860650997,
                                    0.42729151943103916,
                                ],
                                [
                                    0.010637183380195644,
                                    0.03747239756523874,
                                    0.21046603912054235,
                                    0.7414243799340232,
                                ],
                                [
                                    0.010637183380195644,
                                    0.21046603912054235,
                                    0.03747239756523874,
                                    0.7414243799340232,
                                ],
                                [
                                    0.5059829432781875,
                                    0.14363194523464493,
                                    0.27291383422107446,
                                    0.07747127726609311,
                                ],
                                [
                                    0.5059829432781875,
                                    0.27291383422107446,
                                    0.14363194523464493,
                                    0.07747127726609311,
                                ],
                                [
                                    0.020362732917981925,
                                    0.005780311328983417,
                                    0.75853404458128,
                                    0.21532291117175462,
                                ],
                                [
                                    0.0707471251593449,
                                    0.03815913054748896,
                                    0.5788677633534876,
                                    0.31222598093967857,
                                ],
                                [
                                    0.0707471251593449,
                                    0.5788677633534876,
                                    0.03815913054748896,
                                    0.31222598093967857,
                                ],
                                [
                                    0.020362732917981925,
                                    0.75853404458128,
                                    0.005780311328983417,
                                    0.21532291117175462,
                                ],
                                [
                                    0.0028471410617150797,
                                    0.023295903185250263,
                                    0.1060591146451188,
                                    0.8677978411079159,
                                ],
                                [
                                    0.0028471410617150797,
                                    0.1060591146451188,
                                    0.023295903185250263,
                                    0.8677978411079159,
                                ],
                                [
                                    0.8345478179258508,
                                    0.04071612092188542,
                                    0.11893350454758837,
                                    0.005802556604675555,
                                ],
                                [
                                    0.8345478179258508,
                                    0.11893350454758837,
                                    0.04071612092188542,
                                    0.005802556604675555,
                                ],
                                [
                                    0.008873904084101318,
                                    0.0004329421801562777,
                                    0.9446074183893378,
                                    0.04608573534640469,
                                ],
                                [
                                    0.020055068516671805,
                                    0.0028580981597410497,
                                    0.8552088703310643,
                                    0.12187796299252288,
                                ],
                                [
                                    0.020055068516671805,
                                    0.8552088703310643,
                                    0.0028580981597410497,
                                    0.12187796299252288,
                                ],
                                [
                                    0.008873904084101318,
                                    0.9446074183893378,
                                    0.0004329421801562777,
                                    0.04608573534640469,
                                ],
                                [
                                    0.0002132493196846846,
                                    0.00909359694457291,
                                    0.02269991735672817,
                                    0.9679932363790142,
                                ],
                                [
                                    0.0002132493196846846,
                                    0.02269991735672817,
                                    0.00909359694457291,
                                    0.9679932363790142,
                                ],
                                [
                                    0.017366175796375432,
                                    0.11219066634531451,
                                    0.11667673162014604,
                                    0.753766426238164,
                                ],
                                [
                                    0.017366175796375432,
                                    0.11667673162014604,
                                    0.11219066634531451,
                                    0.753766426238164,
                                ],
                                [
                                    0.008705521031958841,
                                    0.0562402578961834,
                                    0.12533738638456263,
                                    0.8097168346872952,
                                ],
                                [
                                    0.00837080531736435,
                                    0.05624025789618335,
                                    0.12118603682432559,
                                    0.8142028999621267,
                                ],
                                [
                                    0.00837080531736435,
                                    0.12118603682432559,
                                    0.05624025789618335,
                                    0.8142028999621267,
                                ],
                                [
                                    0.008705521031958841,
                                    0.12533738638456263,
                                    0.0562402578961834,
                                    0.8097168346872952,
                                ],
                                [
                                    0.004196215827779293,
                                    0.06074956310036295,
                                    0.06041484738576841,
                                    0.8746393736860893,
                                ],
                                [
                                    0.004196215827779293,
                                    0.06041484738576841,
                                    0.06074956310036295,
                                    0.8746393736860893,
                                ],
                                [
                                    0.13374501960010846,
                                    0.22146087287648505,
                                    0.24278313613402444,
                                    0.4020109713893821,
                                ],
                                [
                                    0.13374501960010846,
                                    0.24278313613402444,
                                    0.22146087287648505,
                                    0.4020109713893821,
                                ],
                                [
                                    0.01811461178652639,
                                    0.029994969158907994,
                                    0.3584135439476065,
                                    0.5934768751069591,
                                ],
                                [
                                    0.01652370836765296,
                                    0.029994969158908064,
                                    0.3386821841089405,
                                    0.6147991383644984,
                                ],
                                [
                                    0.01652370836765296,
                                    0.3386821841089405,
                                    0.029994969158908064,
                                    0.6147991383644984,
                                ],
                                [
                                    0.01811461178652639,
                                    0.3584135439476065,
                                    0.029994969158907994,
                                    0.5934768751069591,
                                ],
                                [
                                    0.002237994081938647,
                                    0.04587158686349573,
                                    0.044280683444622375,
                                    0.9076097356099433,
                                ],
                                [
                                    0.002237994081938647,
                                    0.044280683444622375,
                                    0.04587158686349573,
                                    0.9076097356099433,
                                ],
                                [
                                    0.45012055233481646,
                                    0.19949433617801596,
                                    0.2427831361340244,
                                    0.10760197535314311,
                                ],
                                [
                                    0.45012055233481646,
                                    0.2427831361340244,
                                    0.19949433617801596,
                                    0.10760197535314311,
                                ],
                                [
                                    0.018114611786526395,
                                    0.008028432460438944,
                                    0.6747890766823145,
                                    0.29906787907072013,
                                ],
                                [
                                    0.014884734215973885,
                                    0.00802843246043897,
                                    0.6347301542968585,
                                    0.34235667902672856,
                                ],
                                [
                                    0.014884734215973885,
                                    0.6347301542968585,
                                    0.00802843246043897,
                                    0.34235667902672856,
                                ],
                                [
                                    0.018114611786526395,
                                    0.6747890766823145,
                                    0.008028432460438944,
                                    0.29906787907072013,
                                ],
                                [
                                    0.0005990199302595531,
                                    0.02554402431670579,
                                    0.022314146746153302,
                                    0.9515428090068814,
                                ],
                                [
                                    0.0005990199302595531,
                                    0.022314146746153302,
                                    0.02554402431670579,
                                    0.9515428090068814,
                                ],
                                [
                                    0.8187122051663063,
                                    0.056551733681429864,
                                    0.11667673162014604,
                                    0.008059329532117882,
                                ],
                                [
                                    0.8187122051663063,
                                    0.11667673162014604,
                                    0.056551733681429864,
                                    0.008059329532117882,
                                ],
                                [
                                    0.008705521031958877,
                                    0.0006013252322987182,
                                    0.9266834157544934,
                                    0.06400973798124902,
                                ],
                                [
                                    0.004219455757127345,
                                    0.000601325232298721,
                                    0.8710444830906088,
                                    0.1241347359199652,
                                ],
                                [
                                    0.004219455757127345,
                                    0.8710444830906088,
                                    0.000601325232298721,
                                    0.1241347359199652,
                                ],
                                [
                                    0.008705521031958877,
                                    0.9266834157544934,
                                    0.0006013252322987182,
                                    0.06400973798124902,
                                ],
                                [
                                    4.4866267542244015e-05,
                                    0.009261979996715351,
                                    0.004775914721883822,
                                    0.9859172390138586,
                                ],
                                [
                                    4.4866267542244015e-05,
                                    0.004775914721883822,
                                    0.009261979996715351,
                                    0.9859172390138586,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.8019473546022295,
                                    0.12413473591996517,
                                    0.06400973798124897,
                                    0.009908171496556258,
                                ],
                                [
                                    0.8019473546022295,
                                    0.06400973798124897,
                                    0.12413473591996517,
                                    0.009908171496556258,
                                ],
                                [
                                    0.8061219440918146,
                                    0.12478092741980612,
                                    0.059835148491663916,
                                    0.0092619799967153,
                                ],
                                [
                                    0.8662469420305309,
                                    0.06914199475592146,
                                    0.05983514849166392,
                                    0.00477591472188377,
                                ],
                                [
                                    0.8662469420305309,
                                    0.05983514849166392,
                                    0.06914199475592146,
                                    0.00477591472188377,
                                ],
                                [
                                    0.8061219440918146,
                                    0.059835148491663916,
                                    0.12478092741980612,
                                    0.0092619799967153,
                                ],
                                [
                                    0.8707562472347103,
                                    0.06014662427691039,
                                    0.06463268955174192,
                                    0.004464438936637297,
                                ],
                                [
                                    0.8707562472347103,
                                    0.06463268955174192,
                                    0.06014662427691039,
                                    0.004464438936637297,
                                ],
                                [
                                    0.5668892135127584,
                                    0.3423566790267285,
                                    0.056582630753108765,
                                    0.03417147670740428,
                                ],
                                [
                                    0.5668892135127584,
                                    0.056582630753108765,
                                    0.3423566790267285,
                                    0.03417147670740428,
                                ],
                                [
                                    0.5811749277984727,
                                    0.350984131417427,
                                    0.042296916467394474,
                                    0.02554402431670578,
                                ],
                                [
                                    0.8669489760720925,
                                    0.08653234640134658,
                                    0.042296916467394474,
                                    0.004221761059166464,
                                ],
                                [
                                    0.8669489760720925,
                                    0.042296916467394474,
                                    0.08653234640134658,
                                    0.004221761059166464,
                                ],
                                [
                                    0.5811749277984727,
                                    0.042296916467394474,
                                    0.350984131417427,
                                    0.02554402431670578,
                                ],
                                [
                                    0.8887962525367729,
                                    0.043362806679126856,
                                    0.06468506993666619,
                                    0.003155870847434076,
                                ],
                                [
                                    0.8887962525367729,
                                    0.06468506993666619,
                                    0.043362806679126856,
                                    0.003155870847434076,
                                ],
                                [
                                    0.27248021747651946,
                                    0.6147991383644985,
                                    0.034616094054639696,
                                    0.07810455010434239,
                                ],
                                [
                                    0.27248021747651946,
                                    0.034616094054639696,
                                    0.6147991383644985,
                                    0.07810455010434239,
                                ],
                                [
                                    0.2867659317622337,
                                    0.6470321016053451,
                                    0.02033037976892541,
                                    0.045871586863495746,
                                ],
                                [
                                    0.8669489760720925,
                                    0.11013785725149472,
                                    0.02033037976892541,
                                    0.002582786907487371,
                                ],
                                [
                                    0.8669489760720925,
                                    0.02033037976892541,
                                    0.11013785725149472,
                                    0.002582786907487371,
                                ],
                                [
                                    0.2867659317622337,
                                    0.02033037976892541,
                                    0.6470321016053451,
                                    0.045871586863495746,
                                ],
                                [
                                    0.912401763386921,
                                    0.021396269980657794,
                                    0.06468506993666617,
                                    0.0015168966957549831,
                                ],
                                [
                                    0.912401763386921,
                                    0.06468506993666617,
                                    0.021396269980657794,
                                    0.0015168966957549831,
                                ],
                                [
                                    0.05624025789618335,
                                    0.8142028999621267,
                                    0.008370805317364347,
                                    0.12118603682432554,
                                ],
                                [
                                    0.05624025789618335,
                                    0.008370805317364347,
                                    0.8142028999621267,
                                    0.12118603682432554,
                                ],
                                [
                                    0.06041484738576841,
                                    0.8746393736860893,
                                    0.004196215827779289,
                                    0.0607495631003629,
                                ],
                                [
                                    0.8662469420305308,
                                    0.12893227698004314,
                                    0.004196215827779292,
                                    0.0006245651616467263,
                                ],
                                [
                                    0.8662469420305308,
                                    0.004196215827779292,
                                    0.12893227698004314,
                                    0.0006245651616467263,
                                ],
                                [
                                    0.06041484738576841,
                                    0.004196215827779289,
                                    0.8746393736860893,
                                    0.0607495631003629,
                                ],
                                [
                                    0.930546529458832,
                                    0.004507691613025766,
                                    0.06463268955174192,
                                    0.0003130893764002528,
                                ],
                                [
                                    0.930546529458832,
                                    0.06463268955174192,
                                    0.004507691613025766,
                                    0.0003130893764002528,
                                ],
                                [
                                    0.5773861089194626,
                                    0.34869598160273224,
                                    0.04608573534640465,
                                    0.02783217413140058,
                                ],
                                [
                                    0.5773861089194626,
                                    0.04608573534640465,
                                    0.34869598160273224,
                                    0.02783217413140058,
                                ],
                                [
                                    0.5803917301337418,
                                    0.3505111413778789,
                                    0.04308011413212538,
                                    0.026017014356253833,
                                ],
                                [
                                    0.6416856963477637,
                                    0.05121799212107714,
                                    0.28439639417443097,
                                    0.02269991735672809,
                                ],
                                [
                                    0.6416856963477637,
                                    0.28439639417443097,
                                    0.05121799212107714,
                                    0.02269991735672809,
                                ],
                                [
                                    0.5803917301337418,
                                    0.04308011413212538,
                                    0.3505111413778789,
                                    0.026017014356253833,
                                ],
                                [
                                    0.6450260332766374,
                                    0.2858768382349832,
                                    0.04787765519220338,
                                    0.021219473296175833,
                                ],
                                [
                                    0.6450260332766374,
                                    0.04787765519220338,
                                    0.2858768382349832,
                                    0.021219473296175833,
                                ],
                                [
                                    0.4081489330941126,
                                    0.5010969594453744,
                                    0.04073836619757753,
                                    0.050015741262935516,
                                ],
                                [
                                    0.4081489330941126,
                                    0.04073836619757753,
                                    0.5010969594453744,
                                    0.050015741262935516,
                                ],
                                [
                                    0.41843436260170785,
                                    0.5137246966141918,
                                    0.03045293668998224,
                                    0.03738800409411802,
                                ],
                                [
                                    0.7082086956534467,
                                    0.07068808184581535,
                                    0.20103719688604033,
                                    0.020066025614697704,
                                ],
                                [
                                    0.7082086956534467,
                                    0.20103719688604033,
                                    0.07068808184581535,
                                    0.020066025614697704,
                                ],
                                [
                                    0.41843436260170785,
                                    0.03045293668998224,
                                    0.5137246966141918,
                                    0.03738800409411802,
                                ],
                                [
                                    0.726055687340008,
                                    0.2061033718758917,
                                    0.05284109015925395,
                                    0.014999850624846312,
                                ],
                                [
                                    0.726055687340008,
                                    0.05284109015925395,
                                    0.2061033718758917,
                                    0.014999850624846312,
                                ],
                                [
                                    0.19618032483482806,
                                    0.6910990310061899,
                                    0.024922897665909927,
                                    0.08779774649307216,
                                ],
                                [
                                    0.19618032483482806,
                                    0.024922897665909927,
                                    0.6910990310061899,
                                    0.08779774649307216,
                                ],
                                [
                                    0.20646575434242334,
                                    0.7273322790251555,
                                    0.014637468158314649,
                                    0.05156449847410651,
                                ],
                                [
                                    0.7906490834304012,
                                    0.10044466086276495,
                                    0.09663027241061672,
                                    0.01227598329621713,
                                ],
                                [
                                    0.7906490834304012,
                                    0.09663027241061672,
                                    0.10044466086276495,
                                    0.01227598329621713,
                                ],
                                [
                                    0.20646575434242334,
                                    0.014637468158314649,
                                    0.7273322790251555,
                                    0.05156449847410651,
                                ],
                                [
                                    0.8321015859671107,
                                    0.10169644740046811,
                                    0.058992158326055415,
                                    0.007209808306365741,
                                ],
                                [
                                    0.8321015859671107,
                                    0.058992158326055415,
                                    0.10169644740046811,
                                    0.007209808306365741,
                                ],
                                [
                                    0.04049186456561218,
                                    0.8299512932926979,
                                    0.006026812960948843,
                                    0.12353002918074105,
                                ],
                                [
                                    0.04049186456561218,
                                    0.006026812960948843,
                                    0.8299512932926979,
                                    0.12353002918074105,
                                ],
                                [
                                    0.04349748577989145,
                                    0.8915567352919663,
                                    0.0030211917466695685,
                                    0.06192458718147262,
                                ],
                                [
                                    0.8504985486999596,
                                    0.12658828462362764,
                                    0.019944609158350553,
                                    0.0029685575180622417,
                                ],
                                [
                                    0.8504985486999596,
                                    0.019944609158350553,
                                    0.12658828462362764,
                                    0.0029685575180622417,
                                ],
                                [
                                    0.04349748577989145,
                                    0.0030211917466695685,
                                    0.8915567352919663,
                                    0.06192458718147262,
                                ],
                                [
                                    0.913629167852955,
                                    0.021425053218902815,
                                    0.06345766547063221,
                                    0.0014881134575099799,
                                ],
                                [
                                    0.913629167852955,
                                    0.06345766547063221,
                                    0.021425053218902815,
                                    0.0014881134575099799,
                                ],
                                [
                                    0.284396394174431,
                                    0.6416856963477637,
                                    0.022699917356728095,
                                    0.05121799212107714,
                                ],
                                [
                                    0.284396394174431,
                                    0.022699917356728095,
                                    0.6416856963477637,
                                    0.05121799212107714,
                                ],
                                [
                                    0.2858768382349833,
                                    0.6450260332766374,
                                    0.021219473296175836,
                                    0.04787765519220338,
                                ],
                                [
                                    0.34869598160273235,
                                    0.027832174131400586,
                                    0.5773861089194625,
                                    0.046085735346404644,
                                ],
                                [
                                    0.34869598160273235,
                                    0.5773861089194625,
                                    0.027832174131400586,
                                    0.046085735346404644,
                                ],
                                [
                                    0.2858768382349833,
                                    0.021219473296175836,
                                    0.6450260332766374,
                                    0.04787765519220338,
                                ],
                                [
                                    0.35051114137787903,
                                    0.5803917301337417,
                                    0.02601701435625384,
                                    0.043080114132125376,
                                ],
                                [
                                    0.35051114137787903,
                                    0.02601701435625384,
                                    0.5803917301337417,
                                    0.043080114132125376,
                                ],
                                [
                                    0.2010371968860403,
                                    0.7082086956534467,
                                    0.0200660256146977,
                                    0.07068808184581535,
                                ],
                                [
                                    0.2010371968860403,
                                    0.0200660256146977,
                                    0.7082086956534467,
                                    0.07068808184581535,
                                ],
                                [
                                    0.20610337187589167,
                                    0.726055687340008,
                                    0.01499985062484631,
                                    0.05284109015925395,
                                ],
                                [
                                    0.5010969594453744,
                                    0.050015741262935516,
                                    0.4081489330941126,
                                    0.04073836619757753,
                                ],
                                [
                                    0.5010969594453744,
                                    0.4081489330941126,
                                    0.050015741262935516,
                                    0.04073836619757753,
                                ],
                                [
                                    0.20610337187589167,
                                    0.01499985062484631,
                                    0.726055687340008,
                                    0.05284109015925395,
                                ],
                                [
                                    0.5137246966141918,
                                    0.41843436260170785,
                                    0.03738800409411802,
                                    0.03045293668998224,
                                ],
                                [
                                    0.5137246966141918,
                                    0.03738800409411802,
                                    0.41843436260170785,
                                    0.03045293668998224,
                                ],
                                [
                                    0.09663027241061674,
                                    0.7906490834304012,
                                    0.012275983296217133,
                                    0.10044466086276495,
                                ],
                                [
                                    0.09663027241061674,
                                    0.012275983296217133,
                                    0.7906490834304012,
                                    0.10044466086276495,
                                ],
                                [
                                    0.10169644740046813,
                                    0.8321015859671107,
                                    0.0072098083063657425,
                                    0.058992158326055415,
                                ],
                                [
                                    0.6910990310061899,
                                    0.08779774649307216,
                                    0.19618032483482808,
                                    0.02492289766590993,
                                ],
                                [
                                    0.6910990310061899,
                                    0.19618032483482808,
                                    0.08779774649307216,
                                    0.02492289766590993,
                                ],
                                [
                                    0.10169644740046813,
                                    0.0072098083063657425,
                                    0.8321015859671107,
                                    0.058992158326055415,
                                ],
                                [
                                    0.7273322790251555,
                                    0.20646575434242337,
                                    0.05156449847410651,
                                    0.01463746815831465,
                                ],
                                [
                                    0.7273322790251555,
                                    0.05156449847410651,
                                    0.20646575434242337,
                                    0.01463746815831465,
                                ],
                                [
                                    0.019944609158350605,
                                    0.8504985486999594,
                                    0.0029685575180622495,
                                    0.12658828462362764,
                                ],
                                [
                                    0.019944609158350605,
                                    0.0029685575180622495,
                                    0.8504985486999594,
                                    0.12658828462362764,
                                ],
                                [
                                    0.02142505321890287,
                                    0.9136291678529549,
                                    0.0014881134575099836,
                                    0.0634576654706322,
                                ],
                                [
                                    0.829951293292698,
                                    0.12353002918074106,
                                    0.04049186456561213,
                                    0.0060268129609488364,
                                ],
                                [
                                    0.829951293292698,
                                    0.04049186456561213,
                                    0.12353002918074106,
                                    0.0060268129609488364,
                                ],
                                [
                                    0.02142505321890287,
                                    0.0014881134575099836,
                                    0.9136291678529549,
                                    0.0634576654706322,
                                ],
                                [
                                    0.8915567352919664,
                                    0.043497485779891404,
                                    0.061924587181472625,
                                    0.0030211917466695646,
                                ],
                                [
                                    0.8915567352919664,
                                    0.061924587181472625,
                                    0.043497485779891404,
                                    0.0030211917466695646,
                                ],
                                [
                                    0.059835148491663936,
                                    0.8662469420305309,
                                    0.004775914721883771,
                                    0.06914199475592146,
                                ],
                                [
                                    0.059835148491663936,
                                    0.004775914721883771,
                                    0.8662469420305309,
                                    0.06914199475592146,
                                ],
                                [
                                    0.06014662427691041,
                                    0.8707562472347103,
                                    0.0044644389366372975,
                                    0.06463268955174192,
                                ],
                                [
                                    0.12413473591996521,
                                    0.009908171496556262,
                                    0.8019473546022295,
                                    0.06400973798124897,
                                ],
                                [
                                    0.12413473591996521,
                                    0.8019473546022295,
                                    0.009908171496556262,
                                    0.06400973798124897,
                                ],
                                [
                                    0.06014662427691041,
                                    0.0044644389366372975,
                                    0.8707562472347103,
                                    0.06463268955174192,
                                ],
                                [
                                    0.12478092741980616,
                                    0.8061219440918146,
                                    0.009261979996715304,
                                    0.059835148491663916,
                                ],
                                [
                                    0.12478092741980616,
                                    0.009261979996715304,
                                    0.8061219440918146,
                                    0.059835148491663916,
                                ],
                                [
                                    0.04229691646739455,
                                    0.8669489760720924,
                                    0.004221761059166472,
                                    0.08653234640134658,
                                ],
                                [
                                    0.04229691646739455,
                                    0.004221761059166472,
                                    0.8669489760720924,
                                    0.08653234640134658,
                                ],
                                [
                                    0.04336280667912694,
                                    0.8887962525367727,
                                    0.003155870847434082,
                                    0.06468506993666617,
                                ],
                                [
                                    0.3423566790267286,
                                    0.03417147670740429,
                                    0.5668892135127583,
                                    0.05658263075310876,
                                ],
                                [
                                    0.3423566790267286,
                                    0.5668892135127583,
                                    0.03417147670740429,
                                    0.05658263075310876,
                                ],
                                [
                                    0.04336280667912694,
                                    0.003155870847434082,
                                    0.8887962525367727,
                                    0.06468506993666617,
                                ],
                                [
                                    0.35098413141742707,
                                    0.5811749277984726,
                                    0.025544024316705792,
                                    0.04229691646739447,
                                ],
                                [
                                    0.35098413141742707,
                                    0.025544024316705792,
                                    0.5811749277984726,
                                    0.04229691646739447,
                                ],
                                [
                                    0.020330379768925474,
                                    0.8669489760720924,
                                    0.0025827869074873796,
                                    0.1101378572514947,
                                ],
                                [
                                    0.020330379768925474,
                                    0.0025827869074873796,
                                    0.8669489760720924,
                                    0.1101378572514947,
                                ],
                                [
                                    0.021396269980657866,
                                    0.9124017633869209,
                                    0.0015168966957549881,
                                    0.06468506993666617,
                                ],
                                [
                                    0.6147991383644985,
                                    0.07810455010434239,
                                    0.2724802174765194,
                                    0.03461609405463969,
                                ],
                                [
                                    0.6147991383644985,
                                    0.2724802174765194,
                                    0.07810455010434239,
                                    0.03461609405463969,
                                ],
                                [
                                    0.021396269980657866,
                                    0.0015168966957549881,
                                    0.9124017633869209,
                                    0.06468506993666617,
                                ],
                                [
                                    0.6470321016053451,
                                    0.28676593176223364,
                                    0.045871586863495746,
                                    0.020330379768925405,
                                ],
                                [
                                    0.6470321016053451,
                                    0.045871586863495746,
                                    0.28676593176223364,
                                    0.020330379768925405,
                                ],
                                [
                                    0.004196215827779333,
                                    0.8662469420305308,
                                    0.0006245651616467323,
                                    0.12893227698004314,
                                ],
                                [
                                    0.004196215827779333,
                                    0.0006245651616467323,
                                    0.8662469420305308,
                                    0.12893227698004314,
                                ],
                                [
                                    0.004507691613025809,
                                    0.930546529458832,
                                    0.0003130893764002558,
                                    0.06463268955174192,
                                ],
                                [
                                    0.8142028999621267,
                                    0.12118603682432554,
                                    0.05624025789618339,
                                    0.008370805317364352,
                                ],
                                [
                                    0.8142028999621267,
                                    0.05624025789618339,
                                    0.12118603682432554,
                                    0.008370805317364352,
                                ],
                                [
                                    0.004507691613025809,
                                    0.0003130893764002558,
                                    0.930546529458832,
                                    0.06463268955174192,
                                ],
                                [
                                    0.8746393736860893,
                                    0.06041484738576845,
                                    0.0607495631003629,
                                    0.004196215827779292,
                                ],
                                [
                                    0.8746393736860893,
                                    0.0607495631003629,
                                    0.06041484738576845,
                                    0.004196215827779292,
                                ],
                                [
                                    0.5773861089194625,
                                    0.08937453530241306,
                                    0.288570983664016,
                                    0.04466837211410837,
                                ],
                                [
                                    0.5773861089194625,
                                    0.288570983664016,
                                    0.08937453530241306,
                                    0.04466837211410837,
                                ],
                                [
                                    0.5815606984090476,
                                    0.09002072680225401,
                                    0.28439639417443097,
                                    0.044022180614267416,
                                ],
                                [
                                    0.6236805300897502,
                                    0.3117084066967021,
                                    0.04308011413212539,
                                    0.021530949081422304,
                                ],
                                [
                                    0.6236805300897502,
                                    0.04308011413212539,
                                    0.3117084066967021,
                                    0.021530949081422304,
                                ],
                                [
                                    0.5815606984090476,
                                    0.28439639417443097,
                                    0.09002072680225401,
                                    0.044022180614267416,
                                ],
                                [
                                    0.6281898352939297,
                                    0.04339158991737186,
                                    0.30719910149252255,
                                    0.021219473296175833,
                                ],
                                [
                                    0.6281898352939297,
                                    0.30719910149252255,
                                    0.04339158991737186,
                                    0.021219473296175833,
                                ],
                                [
                                    0.40814893309411254,
                                    0.24648998420086882,
                                    0.21532291117175464,
                                    0.13003817153326394,
                                ],
                                [
                                    0.40814893309411254,
                                    0.21532291117175464,
                                    0.24648998420086882,
                                    0.13003817153326394,
                                ],
                                [
                                    0.4224346473798269,
                                    0.2551174365915673,
                                    0.20103719688604033,
                                    0.12141071914256545,
                                ],
                                [
                                    0.6241859806049992,
                                    0.3292953418684399,
                                    0.03045293668998223,
                                    0.0160657408365787,
                                ],
                                [
                                    0.6241859806049992,
                                    0.03045293668998223,
                                    0.3292953418684399,
                                    0.0160657408365787,
                                ],
                                [
                                    0.4224346473798269,
                                    0.20103719688604033,
                                    0.2551174365915673,
                                    0.12141071914256545,
                                ],
                                [
                                    0.6460332570696796,
                                    0.031518826901714626,
                                    0.30744806540375946,
                                    0.014999850624846312,
                                ],
                                [
                                    0.6460332570696796,
                                    0.30744806540375946,
                                    0.031518826901714626,
                                    0.014999850624846312,
                                ],
                                [
                                    0.1961803248348281,
                                    0.44264312392848576,
                                    0.11091598669633101,
                                    0.2502605645403551,
                                ],
                                [
                                    0.1961803248348281,
                                    0.11091598669633101,
                                    0.44264312392848576,
                                    0.2502605645403551,
                                ],
                                [
                                    0.2104660391205424,
                                    0.4748760871693324,
                                    0.09663027241061674,
                                    0.2180276012995085,
                                ],
                                [
                                    0.6241859806049992,
                                    0.352900852718588,
                                    0.01463746815831465,
                                    0.008275698518098128,
                                ],
                                [
                                    0.6241859806049992,
                                    0.01463746815831465,
                                    0.352900852718588,
                                    0.008275698518098128,
                                ],
                                [
                                    0.2104660391205424,
                                    0.09663027241061674,
                                    0.4748760871693324,
                                    0.2180276012995085,
                                ],
                                [
                                    0.6696387679198278,
                                    0.01570335837004704,
                                    0.30744806540375946,
                                    0.007209808306365742,
                                ],
                                [
                                    0.6696387679198278,
                                    0.30744806540375946,
                                    0.01570335837004704,
                                    0.007209808306365742,
                                ],
                                [
                                    0.0404918645656121,
                                    0.5862098572708075,
                                    0.0241191986479356,
                                    0.34917907951564464,
                                ],
                                [
                                    0.0404918645656121,
                                    0.0241191986479356,
                                    0.5862098572708075,
                                    0.34917907951564464,
                                ],
                                [
                                    0.04466645405519716,
                                    0.6466463309947702,
                                    0.01994460915835054,
                                    0.288742605791682,
                                ],
                                [
                                    0.6236805300897501,
                                    0.37149868892082377,
                                    0.003021191746669565,
                                    0.0017995892427564535,
                                ],
                                [
                                    0.6236805300897501,
                                    0.003021191746669565,
                                    0.37149868892082377,
                                    0.0017995892427564535,
                                ],
                                [
                                    0.04466645405519716,
                                    0.01994460915835054,
                                    0.6466463309947702,
                                    0.288742605791682,
                                ],
                                [
                                    0.6879801175180513,
                                    0.0033326675319160387,
                                    0.30719910149252255,
                                    0.00148811345750998,
                                ],
                                [
                                    0.6879801175180513,
                                    0.30719910149252255,
                                    0.0033326675319160387,
                                    0.00148811345750998,
                                ],
                                [
                                    0.41570648853691056,
                                    0.2510541556849651,
                                    0.2077653557289567,
                                    0.1254740000491677,
                                ],
                                [
                                    0.41570648853691056,
                                    0.2077653557289567,
                                    0.2510541556849651,
                                    0.1254740000491677,
                                ],
                                [
                                    0.4187121097511898,
                                    0.2528693154601118,
                                    0.20475973451467744,
                                    0.12365884027402096,
                                ],
                                [
                                    0.46200090970719815,
                                    0.23090277876164275,
                                    0.20475973451467744,
                                    0.10233657701648165,
                                ],
                                [
                                    0.46200090970719815,
                                    0.20475973451467744,
                                    0.23090277876164275,
                                    0.10233657701648165,
                                ],
                                [
                                    0.4187121097511898,
                                    0.20475973451467744,
                                    0.2528693154601118,
                                    0.12365884027402096,
                                ],
                                [
                                    0.4653412466360719,
                                    0.2062401785752297,
                                    0.227562441832769,
                                    0.10085613295592939,
                                ],
                                [
                                    0.4653412466360719,
                                    0.227562441832769,
                                    0.2062401785752297,
                                    0.10085613295592939,
                                ],
                                [
                                    0.2938590955957803,
                                    0.3607798216992011,
                                    0.15502820369590983,
                                    0.19033287900910875,
                                ],
                                [
                                    0.2938590955957803,
                                    0.15502820369590983,
                                    0.3607798216992011,
                                    0.19033287900910875,
                                ],
                                [
                                    0.3041445251033756,
                                    0.37340755886801863,
                                    0.14474277418831452,
                                    0.17770514184029126,
                                ],
                                [
                                    0.5098961431066669,
                                    0.2690006343925951,
                                    0.1447427741883145,
                                    0.07636044831242352,
                                ],
                                [
                                    0.5098961431066669,
                                    0.1447427741883145,
                                    0.2690006343925951,
                                    0.07636044831242352,
                                ],
                                [
                                    0.3041445251033756,
                                    0.14474277418831452,
                                    0.37340755886801863,
                                    0.17770514184029126,
                                ],
                                [
                                    0.5277431347932283,
                                    0.1498089491781659,
                                    0.2511536427060337,
                                    0.07129427332257211,
                                ],
                                [
                                    0.5277431347932283,
                                    0.2511536427060337,
                                    0.1498089491781659,
                                    0.07129427332257211,
                                ],
                                [
                                    0.14124592313060377,
                                    0.49757752563271007,
                                    0.07985729937013421,
                                    0.28131925186655193,
                                ],
                                [
                                    0.14124592313060377,
                                    0.07985729937013421,
                                    0.49757752563271007,
                                    0.28131925186655193,
                                ],
                                [
                                    0.15153135263819906,
                                    0.5338107736516757,
                                    0.06957186986253894,
                                    0.24508600384758628,
                                ],
                                [
                                    0.5692515789007749,
                                    0.3218421653923912,
                                    0.06957186986253894,
                                    0.03933438584429492,
                                ],
                                [
                                    0.5692515789007749,
                                    0.06957186986253894,
                                    0.3218421653923912,
                                    0.03933438584429492,
                                ],
                                [
                                    0.15153135263819906,
                                    0.06957186986253894,
                                    0.5338107736516757,
                                    0.24508600384758628,
                                ],
                                [
                                    0.6107040814374844,
                                    0.07463804485239033,
                                    0.2803896628556817,
                                    0.03426821085444353,
                                ],
                                [
                                    0.6107040814374844,
                                    0.2803896628556817,
                                    0.07463804485239033,
                                    0.03426821085444353,
                                ],
                                [
                                    0.029153335303448956,
                                    0.5975483865329707,
                                    0.017365342223112066,
                                    0.35593293594046815,
                                ],
                                [
                                    0.029153335303448956,
                                    0.017365342223112066,
                                    0.5975483865329707,
                                    0.35593293594046815,
                                ],
                                [
                                    0.03215895651772823,
                                    0.6591538285322391,
                                    0.014359721008832791,
                                    0.2943274939411997,
                                ],
                                [
                                    0.6123420008275869,
                                    0.36474483249600026,
                                    0.014359721008832774,
                                    0.00855344566758002,
                                ],
                                [
                                    0.6123420008275869,
                                    0.014359721008832774,
                                    0.36474483249600026,
                                    0.00855344566758002,
                                ],
                                [
                                    0.03215895651772823,
                                    0.014359721008832791,
                                    0.6591538285322391,
                                    0.2943274939411997,
                                ],
                                [
                                    0.6754726199805824,
                                    0.015840165069385036,
                                    0.3016142133430048,
                                    0.007073001607027759,
                                ],
                                [
                                    0.6754726199805824,
                                    0.3016142133430048,
                                    0.015840165069385036,
                                    0.007073001607027759,
                                ],
                                [
                                    0.20475973451467747,
                                    0.46200090970719815,
                                    0.10233657701648166,
                                    0.23090277876164275,
                                ],
                                [
                                    0.20475973451467747,
                                    0.10233657701648166,
                                    0.46200090970719815,
                                    0.23090277876164275,
                                ],
                                [
                                    0.20624017857522972,
                                    0.4653412466360719,
                                    0.1008561329559294,
                                    0.227562441832769,
                                ],
                                [
                                    0.2510541556849652,
                                    0.12547400004916776,
                                    0.41570648853691045,
                                    0.20776535572895666,
                                ],
                                [
                                    0.2510541556849652,
                                    0.41570648853691045,
                                    0.12547400004916776,
                                    0.20776535572895666,
                                ],
                                [
                                    0.20624017857522972,
                                    0.1008561329559294,
                                    0.4653412466360719,
                                    0.227562441832769,
                                ],
                                [
                                    0.2528693154601119,
                                    0.4187121097511897,
                                    0.123658840274021,
                                    0.2047597345146774,
                                ],
                                [
                                    0.2528693154601119,
                                    0.123658840274021,
                                    0.4187121097511897,
                                    0.2047597345146774,
                                ],
                                [
                                    0.1447427741883145,
                                    0.5098961431066669,
                                    0.0763604483124235,
                                    0.2690006343925951,
                                ],
                                [
                                    0.1447427741883145,
                                    0.0763604483124235,
                                    0.5098961431066669,
                                    0.2690006343925951,
                                ],
                                [
                                    0.1498089491781659,
                                    0.5277431347932283,
                                    0.07129427332257211,
                                    0.2511536427060337,
                                ],
                                [
                                    0.3607798216992011,
                                    0.19033287900910875,
                                    0.2938590955957803,
                                    0.15502820369590983,
                                ],
                                [
                                    0.3607798216992011,
                                    0.2938590955957803,
                                    0.19033287900910875,
                                    0.15502820369590983,
                                ],
                                [
                                    0.1498089491781659,
                                    0.07129427332257211,
                                    0.5277431347932283,
                                    0.2511536427060337,
                                ],
                                [
                                    0.37340755886801863,
                                    0.3041445251033756,
                                    0.17770514184029126,
                                    0.14474277418831452,
                                ],
                                [
                                    0.37340755886801863,
                                    0.17770514184029126,
                                    0.3041445251033756,
                                    0.14474277418831452,
                                ],
                                [
                                    0.06957186986253895,
                                    0.5692515789007749,
                                    0.039334385844294925,
                                    0.3218421653923912,
                                ],
                                [
                                    0.06957186986253895,
                                    0.039334385844294925,
                                    0.5692515789007749,
                                    0.3218421653923912,
                                ],
                                [
                                    0.07463804485239034,
                                    0.6107040814374844,
                                    0.03426821085444354,
                                    0.2803896628556817,
                                ],
                                [
                                    0.49757752563271007,
                                    0.28131925186655193,
                                    0.1412459231306038,
                                    0.07985729937013422,
                                ],
                                [
                                    0.49757752563271007,
                                    0.1412459231306038,
                                    0.28131925186655193,
                                    0.07985729937013422,
                                ],
                                [
                                    0.07463804485239034,
                                    0.03426821085444354,
                                    0.6107040814374844,
                                    0.2803896628556817,
                                ],
                                [
                                    0.5338107736516757,
                                    0.15153135263819908,
                                    0.24508600384758628,
                                    0.06957186986253894,
                                ],
                                [
                                    0.5338107736516757,
                                    0.24508600384758628,
                                    0.15153135263819908,
                                    0.06957186986253894,
                                ],
                                [
                                    0.01435972100883281,
                                    0.6123420008275869,
                                    0.008553445667580043,
                                    0.3647448324960002,
                                ],
                                [
                                    0.01435972100883281,
                                    0.008553445667580043,
                                    0.6123420008275869,
                                    0.3647448324960002,
                                ],
                                [
                                    0.015840165069385077,
                                    0.6754726199805823,
                                    0.007073001607027778,
                                    0.30161421334300476,
                                ],
                                [
                                    0.5975483865329708,
                                    0.3559329359404682,
                                    0.02915333530344892,
                                    0.017365342223112045,
                                ],
                                [
                                    0.5975483865329708,
                                    0.02915333530344892,
                                    0.3559329359404682,
                                    0.017365342223112045,
                                ],
                                [
                                    0.015840165069385077,
                                    0.007073001607027778,
                                    0.6754726199805823,
                                    0.30161421334300476,
                                ],
                                [
                                    0.6591538285322392,
                                    0.032158956517728196,
                                    0.2943274939411998,
                                    0.014359721008832774,
                                ],
                                [
                                    0.6591538285322392,
                                    0.2943274939411998,
                                    0.032158956517728196,
                                    0.014359721008832774,
                                ],
                                [
                                    0.0430801141321254,
                                    0.6236805300897502,
                                    0.02153094908142231,
                                    0.3117084066967021,
                                ],
                                [
                                    0.0430801141321254,
                                    0.02153094908142231,
                                    0.6236805300897502,
                                    0.3117084066967021,
                                ],
                                [
                                    0.04339158991737187,
                                    0.6281898352939297,
                                    0.021219473296175836,
                                    0.30719910149252255,
                                ],
                                [
                                    0.08937453530241309,
                                    0.04466837211410839,
                                    0.5773861089194625,
                                    0.288570983664016,
                                ],
                                [
                                    0.08937453530241309,
                                    0.5773861089194625,
                                    0.04466837211410839,
                                    0.288570983664016,
                                ],
                                [
                                    0.04339158991737187,
                                    0.021219473296175836,
                                    0.6281898352939297,
                                    0.30719910149252255,
                                ],
                                [
                                    0.09002072680225404,
                                    0.5815606984090476,
                                    0.04402218061426744,
                                    0.28439639417443097,
                                ],
                                [
                                    0.09002072680225404,
                                    0.04402218061426744,
                                    0.5815606984090476,
                                    0.28439639417443097,
                                ],
                                [
                                    0.03045293668998229,
                                    0.6241859806049991,
                                    0.016065740836578732,
                                    0.32929534186843984,
                                ],
                                [
                                    0.03045293668998229,
                                    0.016065740836578732,
                                    0.6241859806049991,
                                    0.32929534186843984,
                                ],
                                [
                                    0.03151882690171468,
                                    0.6460332570696795,
                                    0.01499985062484634,
                                    0.30744806540375946,
                                ],
                                [
                                    0.2464899842008689,
                                    0.130038171533264,
                                    0.4081489330941125,
                                    0.2153229111717546,
                                ],
                                [
                                    0.2464899842008689,
                                    0.4081489330941125,
                                    0.130038171533264,
                                    0.2153229111717546,
                                ],
                                [
                                    0.03151882690171468,
                                    0.01499985062484634,
                                    0.6460332570696795,
                                    0.30744806540375946,
                                ],
                                [
                                    0.25511743659156744,
                                    0.4224346473798268,
                                    0.12141071914256549,
                                    0.2010371968860403,
                                ],
                                [
                                    0.25511743659156744,
                                    0.12141071914256549,
                                    0.4224346473798268,
                                    0.2010371968860403,
                                ],
                                [
                                    0.014637468158314699,
                                    0.6241859806049992,
                                    0.008275698518098156,
                                    0.35290085271858795,
                                ],
                                [
                                    0.014637468158314699,
                                    0.008275698518098156,
                                    0.6241859806049992,
                                    0.35290085271858795,
                                ],
                                [
                                    0.01570335837004709,
                                    0.6696387679198277,
                                    0.007209808306365766,
                                    0.30744806540375946,
                                ],
                                [
                                    0.44264312392848576,
                                    0.2502605645403551,
                                    0.19618032483482808,
                                    0.110915986696331,
                                ],
                                [
                                    0.44264312392848576,
                                    0.19618032483482808,
                                    0.2502605645403551,
                                    0.110915986696331,
                                ],
                                [
                                    0.01570335837004709,
                                    0.007209808306365766,
                                    0.6696387679198277,
                                    0.30744806540375946,
                                ],
                                [
                                    0.4748760871693324,
                                    0.21046603912054235,
                                    0.2180276012995085,
                                    0.09663027241061672,
                                ],
                                [
                                    0.4748760871693324,
                                    0.2180276012995085,
                                    0.21046603912054235,
                                    0.09663027241061672,
                                ],
                                [
                                    0.003021191746669594,
                                    0.6236805300897501,
                                    0.001799589242756471,
                                    0.37149868892082377,
                                ],
                                [
                                    0.003021191746669594,
                                    0.001799589242756471,
                                    0.6236805300897501,
                                    0.37149868892082377,
                                ],
                                [
                                    0.0033326675319160707,
                                    0.6879801175180513,
                                    0.0014881134575099944,
                                    0.30719910149252255,
                                ],
                                [
                                    0.5862098572708075,
                                    0.34917907951564464,
                                    0.04049186456561213,
                                    0.024119198647935613,
                                ],
                                [
                                    0.5862098572708075,
                                    0.04049186456561213,
                                    0.34917907951564464,
                                    0.024119198647935613,
                                ],
                                [
                                    0.0033326675319160707,
                                    0.0014881134575099944,
                                    0.6879801175180513,
                                    0.30719910149252255,
                                ],
                                [
                                    0.6466463309947702,
                                    0.04466645405519719,
                                    0.288742605791682,
                                    0.019944609158350553,
                                ],
                                [
                                    0.6466463309947702,
                                    0.288742605791682,
                                    0.04466645405519719,
                                    0.019944609158350553,
                                ],
                                [
                                    0.28439639417443097,
                                    0.044022180614267416,
                                    0.5815606984090476,
                                    0.09002072680225401,
                                ],
                                [
                                    0.28439639417443097,
                                    0.5815606984090476,
                                    0.044022180614267416,
                                    0.09002072680225401,
                                ],
                                [
                                    0.28857098366401607,
                                    0.04466837211410838,
                                    0.5773861089194624,
                                    0.08937453530241304,
                                ],
                                [
                                    0.30719910149252255,
                                    0.6281898352939297,
                                    0.021219473296175833,
                                    0.04339158991737186,
                                ],
                                [
                                    0.30719910149252255,
                                    0.021219473296175833,
                                    0.6281898352939297,
                                    0.04339158991737186,
                                ],
                                [
                                    0.28857098366401607,
                                    0.5773861089194624,
                                    0.04466837211410838,
                                    0.08937453530241304,
                                ],
                                [
                                    0.31170840669670213,
                                    0.021530949081422307,
                                    0.6236805300897501,
                                    0.04308011413212538,
                                ],
                                [
                                    0.31170840669670213,
                                    0.6236805300897501,
                                    0.021530949081422307,
                                    0.04308011413212538,
                                ],
                                [
                                    0.20103719688604033,
                                    0.12141071914256545,
                                    0.4224346473798269,
                                    0.2551174365915673,
                                ],
                                [
                                    0.20103719688604033,
                                    0.4224346473798269,
                                    0.12141071914256545,
                                    0.2551174365915673,
                                ],
                                [
                                    0.2153229111717546,
                                    0.13003817153326394,
                                    0.4081489330941126,
                                    0.24648998420086884,
                                ],
                                [
                                    0.30744806540375946,
                                    0.6460332570696796,
                                    0.014999850624846312,
                                    0.031518826901714626,
                                ],
                                [
                                    0.30744806540375946,
                                    0.014999850624846312,
                                    0.6460332570696796,
                                    0.031518826901714626,
                                ],
                                [
                                    0.2153229111717546,
                                    0.4081489330941126,
                                    0.13003817153326394,
                                    0.24648998420086884,
                                ],
                                [
                                    0.32929534186843984,
                                    0.016065740836578697,
                                    0.6241859806049993,
                                    0.030452936689982238,
                                ],
                                [
                                    0.32929534186843984,
                                    0.6241859806049993,
                                    0.016065740836578697,
                                    0.030452936689982238,
                                ],
                                [
                                    0.09663027241061674,
                                    0.2180276012995085,
                                    0.2104660391205424,
                                    0.4748760871693324,
                                ],
                                [
                                    0.09663027241061674,
                                    0.2104660391205424,
                                    0.2180276012995085,
                                    0.4748760871693324,
                                ],
                                [
                                    0.11091598669633101,
                                    0.2502605645403551,
                                    0.1961803248348281,
                                    0.44264312392848576,
                                ],
                                [
                                    0.30744806540375946,
                                    0.6696387679198278,
                                    0.007209808306365742,
                                    0.01570335837004704,
                                ],
                                [
                                    0.30744806540375946,
                                    0.007209808306365742,
                                    0.6696387679198278,
                                    0.01570335837004704,
                                ],
                                [
                                    0.11091598669633101,
                                    0.1961803248348281,
                                    0.2502605645403551,
                                    0.44264312392848576,
                                ],
                                [
                                    0.352900852718588,
                                    0.008275698518098128,
                                    0.6241859806049992,
                                    0.01463746815831465,
                                ],
                                [
                                    0.352900852718588,
                                    0.6241859806049992,
                                    0.008275698518098128,
                                    0.01463746815831465,
                                ],
                                [
                                    0.019944609158350543,
                                    0.28874260579168204,
                                    0.04466645405519716,
                                    0.6466463309947702,
                                ],
                                [
                                    0.019944609158350543,
                                    0.04466645405519716,
                                    0.28874260579168204,
                                    0.6466463309947702,
                                ],
                                [
                                    0.024119198647935602,
                                    0.3491790795156447,
                                    0.0404918645656121,
                                    0.5862098572708075,
                                ],
                                [
                                    0.3071991014925226,
                                    0.6879801175180513,
                                    0.0014881134575099803,
                                    0.0033326675319160387,
                                ],
                                [
                                    0.3071991014925226,
                                    0.0014881134575099803,
                                    0.6879801175180513,
                                    0.0033326675319160387,
                                ],
                                [
                                    0.024119198647935602,
                                    0.0404918645656121,
                                    0.3491790795156447,
                                    0.5862098572708075,
                                ],
                                [
                                    0.3714986889208238,
                                    0.0017995892427564537,
                                    0.6236805300897501,
                                    0.003021191746669565,
                                ],
                                [
                                    0.3714986889208238,
                                    0.6236805300897501,
                                    0.0017995892427564537,
                                    0.003021191746669565,
                                ],
                                [
                                    0.20475973451467744,
                                    0.12365884027402096,
                                    0.4187121097511898,
                                    0.2528693154601118,
                                ],
                                [
                                    0.20475973451467744,
                                    0.4187121097511898,
                                    0.12365884027402096,
                                    0.2528693154601118,
                                ],
                                [
                                    0.20776535572895674,
                                    0.12547400004916773,
                                    0.4157064885369105,
                                    0.25105415568496503,
                                ],
                                [
                                    0.227562441832769,
                                    0.4653412466360719,
                                    0.10085613295592939,
                                    0.2062401785752297,
                                ],
                                [
                                    0.227562441832769,
                                    0.10085613295592939,
                                    0.4653412466360719,
                                    0.2062401785752297,
                                ],
                                [
                                    0.20776535572895674,
                                    0.4157064885369105,
                                    0.12547400004916773,
                                    0.25105415568496503,
                                ],
                                [
                                    0.23090277876164278,
                                    0.10233657701648166,
                                    0.4620009097071981,
                                    0.2047597345146774,
                                ],
                                [
                                    0.23090277876164278,
                                    0.4620009097071981,
                                    0.10233657701648166,
                                    0.2047597345146774,
                                ],
                                [
                                    0.14474277418831452,
                                    0.17770514184029126,
                                    0.3041445251033756,
                                    0.37340755886801863,
                                ],
                                [
                                    0.14474277418831452,
                                    0.3041445251033756,
                                    0.17770514184029126,
                                    0.37340755886801863,
                                ],
                                [
                                    0.1550282036959098,
                                    0.19033287900910872,
                                    0.29385909559578033,
                                    0.36077982169920114,
                                ],
                                [
                                    0.2511536427060337,
                                    0.5277431347932283,
                                    0.07129427332257211,
                                    0.1498089491781659,
                                ],
                                [
                                    0.2511536427060337,
                                    0.07129427332257211,
                                    0.5277431347932283,
                                    0.1498089491781659,
                                ],
                                [
                                    0.1550282036959098,
                                    0.29385909559578033,
                                    0.19033287900910872,
                                    0.36077982169920114,
                                ],
                                [
                                    0.26900063439259503,
                                    0.0763604483124235,
                                    0.509896143106667,
                                    0.14474277418831452,
                                ],
                                [
                                    0.26900063439259503,
                                    0.509896143106667,
                                    0.0763604483124235,
                                    0.14474277418831452,
                                ],
                                [
                                    0.06957186986253894,
                                    0.24508600384758628,
                                    0.15153135263819906,
                                    0.5338107736516757,
                                ],
                                [
                                    0.06957186986253894,
                                    0.15153135263819906,
                                    0.24508600384758628,
                                    0.5338107736516757,
                                ],
                                [
                                    0.07985729937013421,
                                    0.28131925186655193,
                                    0.14124592313060377,
                                    0.49757752563271007,
                                ],
                                [
                                    0.2803896628556817,
                                    0.6107040814374844,
                                    0.03426821085444353,
                                    0.07463804485239033,
                                ],
                                [
                                    0.2803896628556817,
                                    0.03426821085444353,
                                    0.6107040814374844,
                                    0.07463804485239033,
                                ],
                                [
                                    0.07985729937013421,
                                    0.14124592313060377,
                                    0.28131925186655193,
                                    0.49757752563271007,
                                ],
                                [
                                    0.3218421653923912,
                                    0.03933438584429492,
                                    0.5692515789007749,
                                    0.06957186986253894,
                                ],
                                [
                                    0.3218421653923912,
                                    0.5692515789007749,
                                    0.03933438584429492,
                                    0.06957186986253894,
                                ],
                                [
                                    0.014359721008832795,
                                    0.2943274939411998,
                                    0.03215895651772823,
                                    0.6591538285322391,
                                ],
                                [
                                    0.014359721008832795,
                                    0.03215895651772823,
                                    0.2943274939411998,
                                    0.6591538285322391,
                                ],
                                [
                                    0.01736534222311207,
                                    0.3559329359404682,
                                    0.029153335303448956,
                                    0.5975483865329707,
                                ],
                                [
                                    0.30161421334300487,
                                    0.6754726199805824,
                                    0.007073001607027761,
                                    0.015840165069385036,
                                ],
                                [
                                    0.30161421334300487,
                                    0.007073001607027761,
                                    0.6754726199805824,
                                    0.015840165069385036,
                                ],
                                [
                                    0.01736534222311207,
                                    0.029153335303448956,
                                    0.3559329359404682,
                                    0.5975483865329707,
                                ],
                                [
                                    0.3647448324960003,
                                    0.008553445667580022,
                                    0.6123420008275869,
                                    0.014359721008832774,
                                ],
                                [
                                    0.3647448324960003,
                                    0.6123420008275869,
                                    0.008553445667580022,
                                    0.014359721008832774,
                                ],
                                [
                                    0.1008561329559294,
                                    0.227562441832769,
                                    0.20624017857522972,
                                    0.4653412466360719,
                                ],
                                [
                                    0.1008561329559294,
                                    0.20624017857522972,
                                    0.227562441832769,
                                    0.4653412466360719,
                                ],
                                [
                                    0.10233657701648169,
                                    0.23090277876164278,
                                    0.20475973451467744,
                                    0.4620009097071981,
                                ],
                                [
                                    0.123658840274021,
                                    0.2528693154601119,
                                    0.2047597345146774,
                                    0.4187121097511897,
                                ],
                                [
                                    0.123658840274021,
                                    0.2047597345146774,
                                    0.2528693154601119,
                                    0.4187121097511897,
                                ],
                                [
                                    0.10233657701648169,
                                    0.20475973451467744,
                                    0.23090277876164278,
                                    0.4620009097071981,
                                ],
                                [
                                    0.12547400004916776,
                                    0.2077653557289567,
                                    0.25105415568496514,
                                    0.4157064885369104,
                                ],
                                [
                                    0.12547400004916776,
                                    0.25105415568496514,
                                    0.2077653557289567,
                                    0.4157064885369104,
                                ],
                                [
                                    0.07129427332257211,
                                    0.2511536427060337,
                                    0.1498089491781659,
                                    0.5277431347932283,
                                ],
                                [
                                    0.07129427332257211,
                                    0.1498089491781659,
                                    0.2511536427060337,
                                    0.5277431347932283,
                                ],
                                [
                                    0.07636044831242349,
                                    0.26900063439259503,
                                    0.1447427741883145,
                                    0.509896143106667,
                                ],
                                [
                                    0.17770514184029126,
                                    0.37340755886801863,
                                    0.14474277418831452,
                                    0.3041445251033756,
                                ],
                                [
                                    0.17770514184029126,
                                    0.14474277418831452,
                                    0.37340755886801863,
                                    0.3041445251033756,
                                ],
                                [
                                    0.07636044831242349,
                                    0.1447427741883145,
                                    0.26900063439259503,
                                    0.509896143106667,
                                ],
                                [
                                    0.19033287900910872,
                                    0.1550282036959098,
                                    0.36077982169920114,
                                    0.29385909559578033,
                                ],
                                [
                                    0.19033287900910872,
                                    0.36077982169920114,
                                    0.1550282036959098,
                                    0.29385909559578033,
                                ],
                                [
                                    0.03426821085444354,
                                    0.2803896628556817,
                                    0.07463804485239034,
                                    0.6107040814374844,
                                ],
                                [
                                    0.03426821085444354,
                                    0.07463804485239034,
                                    0.2803896628556817,
                                    0.6107040814374844,
                                ],
                                [
                                    0.039334385844294925,
                                    0.3218421653923912,
                                    0.06957186986253895,
                                    0.5692515789007749,
                                ],
                                [
                                    0.24508600384758628,
                                    0.5338107736516757,
                                    0.06957186986253894,
                                    0.15153135263819908,
                                ],
                                [
                                    0.24508600384758628,
                                    0.06957186986253894,
                                    0.5338107736516757,
                                    0.15153135263819908,
                                ],
                                [
                                    0.039334385844294925,
                                    0.06957186986253895,
                                    0.3218421653923912,
                                    0.5692515789007749,
                                ],
                                [
                                    0.28131925186655193,
                                    0.07985729937013422,
                                    0.49757752563271007,
                                    0.1412459231306038,
                                ],
                                [
                                    0.28131925186655193,
                                    0.49757752563271007,
                                    0.07985729937013422,
                                    0.1412459231306038,
                                ],
                                [
                                    0.0070730016070277785,
                                    0.3016142133430048,
                                    0.015840165069385077,
                                    0.6754726199805823,
                                ],
                                [
                                    0.0070730016070277785,
                                    0.015840165069385077,
                                    0.3016142133430048,
                                    0.6754726199805823,
                                ],
                                [
                                    0.008553445667580045,
                                    0.36474483249600026,
                                    0.01435972100883281,
                                    0.6123420008275869,
                                ],
                                [
                                    0.29432749394119984,
                                    0.6591538285322392,
                                    0.014359721008832777,
                                    0.032158956517728196,
                                ],
                                [
                                    0.29432749394119984,
                                    0.014359721008832777,
                                    0.6591538285322392,
                                    0.032158956517728196,
                                ],
                                [
                                    0.008553445667580045,
                                    0.01435972100883281,
                                    0.36474483249600026,
                                    0.6123420008275869,
                                ],
                                [
                                    0.35593293594046826,
                                    0.01736534222311205,
                                    0.5975483865329708,
                                    0.02915333530344892,
                                ],
                                [
                                    0.35593293594046826,
                                    0.5975483865329708,
                                    0.01736534222311205,
                                    0.02915333530344892,
                                ],
                                [
                                    0.021219473296175836,
                                    0.30719910149252255,
                                    0.04339158991737187,
                                    0.6281898352939297,
                                ],
                                [
                                    0.021219473296175836,
                                    0.04339158991737187,
                                    0.30719910149252255,
                                    0.6281898352939297,
                                ],
                                [
                                    0.021530949081422314,
                                    0.31170840669670213,
                                    0.04308011413212539,
                                    0.6236805300897501,
                                ],
                                [
                                    0.04402218061426744,
                                    0.09002072680225404,
                                    0.28439639417443097,
                                    0.5815606984090476,
                                ],
                                [
                                    0.04402218061426744,
                                    0.28439639417443097,
                                    0.09002072680225404,
                                    0.5815606984090476,
                                ],
                                [
                                    0.021530949081422314,
                                    0.04308011413212539,
                                    0.31170840669670213,
                                    0.6236805300897501,
                                ],
                                [
                                    0.0446683721141084,
                                    0.28857098366401607,
                                    0.08937453530241307,
                                    0.5773861089194624,
                                ],
                                [
                                    0.0446683721141084,
                                    0.08937453530241307,
                                    0.28857098366401607,
                                    0.5773861089194624,
                                ],
                                [
                                    0.01499985062484634,
                                    0.30744806540375946,
                                    0.03151882690171468,
                                    0.6460332570696795,
                                ],
                                [
                                    0.01499985062484634,
                                    0.03151882690171468,
                                    0.30744806540375946,
                                    0.6460332570696795,
                                ],
                                [
                                    0.01606574083657873,
                                    0.3292953418684398,
                                    0.030452936689982297,
                                    0.6241859806049992,
                                ],
                                [
                                    0.12141071914256549,
                                    0.25511743659156744,
                                    0.2010371968860403,
                                    0.4224346473798268,
                                ],
                                [
                                    0.12141071914256549,
                                    0.2010371968860403,
                                    0.25511743659156744,
                                    0.4224346473798268,
                                ],
                                [
                                    0.01606574083657873,
                                    0.030452936689982297,
                                    0.3292953418684398,
                                    0.6241859806049992,
                                ],
                                [
                                    0.13003817153326397,
                                    0.21532291117175456,
                                    0.24648998420086893,
                                    0.40814893309411254,
                                ],
                                [
                                    0.13003817153326397,
                                    0.24648998420086893,
                                    0.21532291117175456,
                                    0.40814893309411254,
                                ],
                                [
                                    0.007209808306365766,
                                    0.30744806540375946,
                                    0.01570335837004709,
                                    0.6696387679198277,
                                ],
                                [
                                    0.007209808306365766,
                                    0.01570335837004709,
                                    0.30744806540375946,
                                    0.6696387679198277,
                                ],
                                [
                                    0.008275698518098156,
                                    0.35290085271858795,
                                    0.014637468158314699,
                                    0.6241859806049992,
                                ],
                                [
                                    0.2180276012995085,
                                    0.4748760871693324,
                                    0.09663027241061672,
                                    0.21046603912054235,
                                ],
                                [
                                    0.2180276012995085,
                                    0.09663027241061672,
                                    0.4748760871693324,
                                    0.21046603912054235,
                                ],
                                [
                                    0.008275698518098156,
                                    0.014637468158314699,
                                    0.35290085271858795,
                                    0.6241859806049992,
                                ],
                                [
                                    0.2502605645403551,
                                    0.110915986696331,
                                    0.44264312392848576,
                                    0.19618032483482808,
                                ],
                                [
                                    0.2502605645403551,
                                    0.44264312392848576,
                                    0.110915986696331,
                                    0.19618032483482808,
                                ],
                                [
                                    0.0014881134575099946,
                                    0.3071991014925226,
                                    0.0033326675319160707,
                                    0.6879801175180513,
                                ],
                                [
                                    0.0014881134575099946,
                                    0.0033326675319160707,
                                    0.3071991014925226,
                                    0.6879801175180513,
                                ],
                                [
                                    0.0017995892427564713,
                                    0.3714986889208238,
                                    0.003021191746669594,
                                    0.6236805300897501,
                                ],
                                [
                                    0.28874260579168204,
                                    0.6466463309947702,
                                    0.019944609158350557,
                                    0.04466645405519719,
                                ],
                                [
                                    0.28874260579168204,
                                    0.019944609158350557,
                                    0.6466463309947702,
                                    0.04466645405519719,
                                ],
                                [
                                    0.0017995892427564713,
                                    0.003021191746669594,
                                    0.3714986889208238,
                                    0.6236805300897501,
                                ],
                                [
                                    0.3491790795156447,
                                    0.024119198647935616,
                                    0.5862098572708075,
                                    0.04049186456561213,
                                ],
                                [
                                    0.3491790795156447,
                                    0.5862098572708075,
                                    0.024119198647935616,
                                    0.04049186456561213,
                                ],
                                [
                                    0.05983514849166393,
                                    0.009261979996715302,
                                    0.8061219440918146,
                                    0.12478092741980612,
                                ],
                                [
                                    0.05983514849166393,
                                    0.8061219440918146,
                                    0.009261979996715302,
                                    0.12478092741980612,
                                ],
                                [
                                    0.06400973798124902,
                                    0.009908171496556267,
                                    0.8019473546022295,
                                    0.12413473591996516,
                                ],
                                [
                                    0.06463268955174194,
                                    0.8707562472347103,
                                    0.0044644389366372975,
                                    0.06014662427691039,
                                ],
                                [
                                    0.06463268955174194,
                                    0.0044644389366372975,
                                    0.8707562472347103,
                                    0.06014662427691039,
                                ],
                                [
                                    0.06400973798124902,
                                    0.8019473546022295,
                                    0.009908171496556267,
                                    0.12413473591996516,
                                ],
                                [
                                    0.06914199475592152,
                                    0.004775914721883774,
                                    0.8662469420305308,
                                    0.059835148491663916,
                                ],
                                [
                                    0.06914199475592152,
                                    0.8662469420305308,
                                    0.004775914721883774,
                                    0.059835148491663916,
                                ],
                                [
                                    0.0422969164673945,
                                    0.0255440243167058,
                                    0.5811749277984727,
                                    0.350984131417427,
                                ],
                                [
                                    0.0422969164673945,
                                    0.5811749277984727,
                                    0.0255440243167058,
                                    0.350984131417427,
                                ],
                                [
                                    0.056582630753108765,
                                    0.03417147670740428,
                                    0.5668892135127584,
                                    0.3423566790267285,
                                ],
                                [
                                    0.06468506993666623,
                                    0.8887962525367729,
                                    0.003155870847434078,
                                    0.043362806679126856,
                                ],
                                [
                                    0.06468506993666623,
                                    0.003155870847434078,
                                    0.8887962525367729,
                                    0.043362806679126856,
                                ],
                                [
                                    0.056582630753108765,
                                    0.5668892135127584,
                                    0.03417147670740428,
                                    0.3423566790267285,
                                ],
                                [
                                    0.08653234640134658,
                                    0.004221761059166464,
                                    0.8669489760720925,
                                    0.042296916467394474,
                                ],
                                [
                                    0.08653234640134658,
                                    0.8669489760720925,
                                    0.004221761059166464,
                                    0.042296916467394474,
                                ],
                                [
                                    0.020330379768925412,
                                    0.04587158686349576,
                                    0.2867659317622337,
                                    0.6470321016053451,
                                ],
                                [
                                    0.020330379768925412,
                                    0.2867659317622337,
                                    0.04587158686349576,
                                    0.6470321016053451,
                                ],
                                [
                                    0.034616094054639696,
                                    0.07810455010434239,
                                    0.27248021747651946,
                                    0.6147991383644985,
                                ],
                                [
                                    0.06468506993666619,
                                    0.912401763386921,
                                    0.0015168966957549836,
                                    0.021396269980657794,
                                ],
                                [
                                    0.06468506993666619,
                                    0.0015168966957549836,
                                    0.912401763386921,
                                    0.021396269980657794,
                                ],
                                [
                                    0.034616094054639696,
                                    0.27248021747651946,
                                    0.07810455010434239,
                                    0.6147991383644985,
                                ],
                                [
                                    0.11013785725149472,
                                    0.002582786907487371,
                                    0.8669489760720925,
                                    0.02033037976892541,
                                ],
                                [
                                    0.11013785725149472,
                                    0.8669489760720925,
                                    0.002582786907487371,
                                    0.02033037976892541,
                                ],
                                [
                                    0.004196215827779293,
                                    0.06074956310036295,
                                    0.06041484738576841,
                                    0.8746393736860893,
                                ],
                                [
                                    0.004196215827779293,
                                    0.06041484738576841,
                                    0.06074956310036295,
                                    0.8746393736860893,
                                ],
                                [
                                    0.00837080531736435,
                                    0.12118603682432559,
                                    0.05624025789618335,
                                    0.8142028999621267,
                                ],
                                [
                                    0.06463268955174198,
                                    0.930546529458832,
                                    0.00031308937640025304,
                                    0.004507691613025766,
                                ],
                                [
                                    0.06463268955174198,
                                    0.00031308937640025304,
                                    0.930546529458832,
                                    0.004507691613025766,
                                ],
                                [
                                    0.00837080531736435,
                                    0.05624025789618335,
                                    0.12118603682432559,
                                    0.8142028999621267,
                                ],
                                [
                                    0.1289322769800432,
                                    0.0006245651616467266,
                                    0.8662469420305308,
                                    0.004196215827779292,
                                ],
                                [
                                    0.1289322769800432,
                                    0.8662469420305308,
                                    0.0006245651616467266,
                                    0.004196215827779292,
                                ],
                                [
                                    0.0430801141321254,
                                    0.02601701435625384,
                                    0.5803917301337418,
                                    0.3505111413778789,
                                ],
                                [
                                    0.0430801141321254,
                                    0.5803917301337418,
                                    0.02601701435625384,
                                    0.3505111413778789,
                                ],
                                [
                                    0.04608573534640469,
                                    0.027832174131400603,
                                    0.5773861089194625,
                                    0.3486959816027322,
                                ],
                                [
                                    0.0478776551922034,
                                    0.6450260332766374,
                                    0.021219473296175836,
                                    0.2858768382349832,
                                ],
                                [
                                    0.0478776551922034,
                                    0.021219473296175836,
                                    0.6450260332766374,
                                    0.2858768382349832,
                                ],
                                [
                                    0.04608573534640469,
                                    0.5773861089194625,
                                    0.027832174131400603,
                                    0.3486959816027322,
                                ],
                                [
                                    0.05121799212107718,
                                    0.022699917356728112,
                                    0.6416856963477637,
                                    0.28439639417443097,
                                ],
                                [
                                    0.05121799212107718,
                                    0.6416856963477637,
                                    0.022699917356728112,
                                    0.28439639417443097,
                                ],
                                [
                                    0.03045293668998226,
                                    0.03738800409411804,
                                    0.41843436260170785,
                                    0.5137246966141918,
                                ],
                                [
                                    0.03045293668998226,
                                    0.41843436260170785,
                                    0.03738800409411804,
                                    0.5137246966141918,
                                ],
                                [
                                    0.04073836619757753,
                                    0.050015741262935516,
                                    0.4081489330941126,
                                    0.5010969594453744,
                                ],
                                [
                                    0.05284109015925398,
                                    0.726055687340008,
                                    0.01499985062484632,
                                    0.2061033718758917,
                                ],
                                [
                                    0.05284109015925398,
                                    0.01499985062484632,
                                    0.726055687340008,
                                    0.2061033718758917,
                                ],
                                [
                                    0.04073836619757753,
                                    0.4081489330941126,
                                    0.050015741262935516,
                                    0.5010969594453744,
                                ],
                                [
                                    0.07068808184581535,
                                    0.020066025614697704,
                                    0.7082086956534467,
                                    0.20103719688604033,
                                ],
                                [
                                    0.07068808184581535,
                                    0.7082086956534467,
                                    0.020066025614697704,
                                    0.20103719688604033,
                                ],
                                [
                                    0.01463746815831465,
                                    0.05156449847410652,
                                    0.20646575434242334,
                                    0.7273322790251555,
                                ],
                                [
                                    0.01463746815831465,
                                    0.20646575434242334,
                                    0.05156449847410652,
                                    0.7273322790251555,
                                ],
                                [
                                    0.024922897665909927,
                                    0.08779774649307216,
                                    0.19618032483482806,
                                    0.6910990310061899,
                                ],
                                [
                                    0.05899215832605543,
                                    0.8321015859671107,
                                    0.0072098083063657425,
                                    0.10169644740046811,
                                ],
                                [
                                    0.05899215832605543,
                                    0.0072098083063657425,
                                    0.8321015859671107,
                                    0.10169644740046811,
                                ],
                                [
                                    0.024922897665909927,
                                    0.19618032483482806,
                                    0.08779774649307216,
                                    0.6910990310061899,
                                ],
                                [
                                    0.10044466086276495,
                                    0.01227598329621713,
                                    0.7906490834304012,
                                    0.09663027241061672,
                                ],
                                [
                                    0.10044466086276495,
                                    0.7906490834304012,
                                    0.01227598329621713,
                                    0.09663027241061672,
                                ],
                                [
                                    0.003021191746669571,
                                    0.061924587181472666,
                                    0.04349748577989145,
                                    0.8915567352919663,
                                ],
                                [
                                    0.003021191746669571,
                                    0.04349748577989145,
                                    0.061924587181472666,
                                    0.8915567352919663,
                                ],
                                [
                                    0.006026812960948846,
                                    0.1235300291807411,
                                    0.04049186456561218,
                                    0.8299512932926979,
                                ],
                                [
                                    0.06345766547063227,
                                    0.913629167852955,
                                    0.0014881134575099812,
                                    0.021425053218902815,
                                ],
                                [
                                    0.06345766547063227,
                                    0.0014881134575099812,
                                    0.913629167852955,
                                    0.021425053218902815,
                                ],
                                [
                                    0.006026812960948846,
                                    0.04049186456561218,
                                    0.1235300291807411,
                                    0.8299512932926979,
                                ],
                                [
                                    0.1265882846236277,
                                    0.002968557518062243,
                                    0.8504985486999596,
                                    0.019944609158350553,
                                ],
                                [
                                    0.1265882846236277,
                                    0.8504985486999596,
                                    0.002968557518062243,
                                    0.019944609158350553,
                                ],
                                [
                                    0.02121947329617584,
                                    0.0478776551922034,
                                    0.2858768382349833,
                                    0.6450260332766374,
                                ],
                                [
                                    0.02121947329617584,
                                    0.2858768382349833,
                                    0.0478776551922034,
                                    0.6450260332766374,
                                ],
                                [
                                    0.022699917356728116,
                                    0.05121799212107718,
                                    0.284396394174431,
                                    0.6416856963477637,
                                ],
                                [
                                    0.026017014356253847,
                                    0.35051114137787903,
                                    0.04308011413212539,
                                    0.5803917301337417,
                                ],
                                [
                                    0.026017014356253847,
                                    0.04308011413212539,
                                    0.35051114137787903,
                                    0.5803917301337417,
                                ],
                                [
                                    0.022699917356728116,
                                    0.284396394174431,
                                    0.05121799212107718,
                                    0.6416856963477637,
                                ],
                                [
                                    0.02783217413140061,
                                    0.046085735346404685,
                                    0.3486959816027323,
                                    0.5773861089194624,
                                ],
                                [
                                    0.02783217413140061,
                                    0.3486959816027323,
                                    0.046085735346404685,
                                    0.5773861089194624,
                                ],
                                [
                                    0.014999850624846319,
                                    0.05284109015925398,
                                    0.20610337187589167,
                                    0.726055687340008,
                                ],
                                [
                                    0.014999850624846319,
                                    0.20610337187589167,
                                    0.05284109015925398,
                                    0.726055687340008,
                                ],
                                [
                                    0.0200660256146977,
                                    0.07068808184581535,
                                    0.2010371968860403,
                                    0.7082086956534467,
                                ],
                                [
                                    0.03738800409411804,
                                    0.5137246966141918,
                                    0.03045293668998226,
                                    0.41843436260170785,
                                ],
                                [
                                    0.03738800409411804,
                                    0.03045293668998226,
                                    0.5137246966141918,
                                    0.41843436260170785,
                                ],
                                [
                                    0.0200660256146977,
                                    0.2010371968860403,
                                    0.07068808184581535,
                                    0.7082086956534467,
                                ],
                                [
                                    0.050015741262935516,
                                    0.04073836619757753,
                                    0.5010969594453744,
                                    0.4081489330941126,
                                ],
                                [
                                    0.050015741262935516,
                                    0.5010969594453744,
                                    0.04073836619757753,
                                    0.4081489330941126,
                                ],
                                [
                                    0.007209808306365744,
                                    0.05899215832605543,
                                    0.10169644740046813,
                                    0.8321015859671107,
                                ],
                                [
                                    0.007209808306365744,
                                    0.10169644740046813,
                                    0.05899215832605543,
                                    0.8321015859671107,
                                ],
                                [
                                    0.012275983296217133,
                                    0.10044466086276495,
                                    0.09663027241061674,
                                    0.7906490834304012,
                                ],
                                [
                                    0.05156449847410652,
                                    0.7273322790251555,
                                    0.014637468158314652,
                                    0.20646575434242337,
                                ],
                                [
                                    0.05156449847410652,
                                    0.014637468158314652,
                                    0.7273322790251555,
                                    0.20646575434242337,
                                ],
                                [
                                    0.012275983296217133,
                                    0.09663027241061674,
                                    0.10044466086276495,
                                    0.7906490834304012,
                                ],
                                [
                                    0.08779774649307216,
                                    0.02492289766590993,
                                    0.6910990310061899,
                                    0.19618032483482808,
                                ],
                                [
                                    0.08779774649307216,
                                    0.6910990310061899,
                                    0.02492289766590993,
                                    0.19618032483482808,
                                ],
                                [
                                    0.0014881134575099849,
                                    0.06345766547063225,
                                    0.02142505321890287,
                                    0.9136291678529549,
                                ],
                                [
                                    0.0014881134575099849,
                                    0.02142505321890287,
                                    0.06345766547063225,
                                    0.9136291678529549,
                                ],
                                [
                                    0.002968557518062251,
                                    0.1265882846236277,
                                    0.019944609158350605,
                                    0.8504985486999594,
                                ],
                                [
                                    0.06192458718147267,
                                    0.8915567352919664,
                                    0.003021191746669567,
                                    0.043497485779891404,
                                ],
                                [
                                    0.06192458718147267,
                                    0.003021191746669567,
                                    0.8915567352919664,
                                    0.043497485779891404,
                                ],
                                [
                                    0.002968557518062251,
                                    0.019944609158350605,
                                    0.1265882846236277,
                                    0.8504985486999594,
                                ],
                                [
                                    0.12353002918074112,
                                    0.006026812960948839,
                                    0.829951293292698,
                                    0.04049186456561213,
                                ],
                                [
                                    0.12353002918074112,
                                    0.829951293292698,
                                    0.006026812960948839,
                                    0.04049186456561213,
                                ],
                                [
                                    0.004464438936637298,
                                    0.06463268955174194,
                                    0.06014662427691041,
                                    0.8707562472347103,
                                ],
                                [
                                    0.004464438936637298,
                                    0.06014662427691041,
                                    0.06463268955174194,
                                    0.8707562472347103,
                                ],
                                [
                                    0.004775914721883775,
                                    0.06914199475592152,
                                    0.05983514849166393,
                                    0.8662469420305308,
                                ],
                                [
                                    0.009261979996715306,
                                    0.12478092741980616,
                                    0.05983514849166393,
                                    0.8061219440918146,
                                ],
                                [
                                    0.009261979996715306,
                                    0.05983514849166393,
                                    0.12478092741980616,
                                    0.8061219440918146,
                                ],
                                [
                                    0.004775914721883775,
                                    0.05983514849166393,
                                    0.06914199475592152,
                                    0.8662469420305308,
                                ],
                                [
                                    0.00990817149655627,
                                    0.06400973798124902,
                                    0.1241347359199652,
                                    0.8019473546022295,
                                ],
                                [
                                    0.00990817149655627,
                                    0.1241347359199652,
                                    0.06400973798124902,
                                    0.8019473546022295,
                                ],
                                [
                                    0.003155870847434084,
                                    0.06468506993666621,
                                    0.04336280667912694,
                                    0.8887962525367727,
                                ],
                                [
                                    0.003155870847434084,
                                    0.04336280667912694,
                                    0.06468506993666621,
                                    0.8887962525367727,
                                ],
                                [
                                    0.004221761059166472,
                                    0.08653234640134658,
                                    0.04229691646739455,
                                    0.8669489760720924,
                                ],
                                [
                                    0.025544024316705806,
                                    0.35098413141742707,
                                    0.042296916467394495,
                                    0.5811749277984726,
                                ],
                                [
                                    0.025544024316705806,
                                    0.042296916467394495,
                                    0.35098413141742707,
                                    0.5811749277984726,
                                ],
                                [
                                    0.004221761059166472,
                                    0.04229691646739455,
                                    0.08653234640134658,
                                    0.8669489760720924,
                                ],
                                [
                                    0.03417147670740429,
                                    0.05658263075310876,
                                    0.3423566790267286,
                                    0.5668892135127583,
                                ],
                                [
                                    0.03417147670740429,
                                    0.3423566790267286,
                                    0.05658263075310876,
                                    0.5668892135127583,
                                ],
                                [
                                    0.0015168966957549886,
                                    0.06468506993666619,
                                    0.021396269980657866,
                                    0.9124017633869209,
                                ],
                                [
                                    0.0015168966957549886,
                                    0.021396269980657866,
                                    0.06468506993666619,
                                    0.9124017633869209,
                                ],
                                [
                                    0.0025827869074873796,
                                    0.1101378572514947,
                                    0.020330379768925474,
                                    0.8669489760720924,
                                ],
                                [
                                    0.04587158686349576,
                                    0.6470321016053451,
                                    0.02033037976892541,
                                    0.28676593176223364,
                                ],
                                [
                                    0.04587158686349576,
                                    0.02033037976892541,
                                    0.6470321016053451,
                                    0.28676593176223364,
                                ],
                                [
                                    0.0025827869074873796,
                                    0.020330379768925474,
                                    0.1101378572514947,
                                    0.8669489760720924,
                                ],
                                [
                                    0.07810455010434239,
                                    0.03461609405463969,
                                    0.6147991383644985,
                                    0.2724802174765194,
                                ],
                                [
                                    0.07810455010434239,
                                    0.6147991383644985,
                                    0.03461609405463969,
                                    0.2724802174765194,
                                ],
                                [
                                    0.0003130893764002561,
                                    0.06463268955174198,
                                    0.004507691613025809,
                                    0.930546529458832,
                                ],
                                [
                                    0.0003130893764002561,
                                    0.004507691613025809,
                                    0.06463268955174198,
                                    0.930546529458832,
                                ],
                                [
                                    0.0006245651616467327,
                                    0.1289322769800432,
                                    0.004196215827779333,
                                    0.8662469420305308,
                                ],
                                [
                                    0.06074956310036295,
                                    0.8746393736860893,
                                    0.004196215827779295,
                                    0.06041484738576845,
                                ],
                                [
                                    0.06074956310036295,
                                    0.004196215827779295,
                                    0.8746393736860893,
                                    0.06041484738576845,
                                ],
                                [
                                    0.0006245651616467327,
                                    0.004196215827779333,
                                    0.1289322769800432,
                                    0.8662469420305308,
                                ],
                                [
                                    0.12118603682432559,
                                    0.008370805317364356,
                                    0.8142028999621267,
                                    0.05624025789618339,
                                ],
                                [
                                    0.12118603682432559,
                                    0.8142028999621267,
                                    0.008370805317364356,
                                    0.05624025789618339,
                                ],
                                [
                                    0.7873679295469641,
                                    0.12187796299252283,
                                    0.07858916303651445,
                                    0.012164944423998585,
                                ],
                                [
                                    0.7873679295469641,
                                    0.07858916303651445,
                                    0.12187796299252283,
                                    0.012164944423998585,
                                ],
                                [
                                    0.8072097487439511,
                                    0.12494931047194854,
                                    0.05874734383952739,
                                    0.009093596944572863,
                                ],
                                [
                                    0.8504985486999596,
                                    0.08489038808649274,
                                    0.05874734383952738,
                                    0.0058637193740203085,
                                ],
                                [
                                    0.8504985486999596,
                                    0.05874734383952738,
                                    0.08489038808649274,
                                    0.0058637193740203085,
                                ],
                                [
                                    0.8072097487439511,
                                    0.05874734383952739,
                                    0.12494931047194854,
                                    0.009093596944572863,
                                ],
                                [
                                    0.87193127131582,
                                    0.06022778790007964,
                                    0.06345766547063221,
                                    0.004383275313468047,
                                ],
                                [
                                    0.87193127131582,
                                    0.06345766547063221,
                                    0.06022778790007964,
                                    0.004383275313468047,
                                ],
                                [
                                    0.5169974813294801,
                                    0.3122259809396785,
                                    0.10647436293638718,
                                    0.06430217479445427,
                                ],
                                [
                                    0.5169974813294801,
                                    0.10647436293638718,
                                    0.3122259809396785,
                                    0.06430217479445427,
                                ],
                                [
                                    0.5848974654271099,
                                    0.3532322525488825,
                                    0.038574378838757355,
                                    0.023295903185250252,
                                ],
                                [
                                    0.7906490834304012,
                                    0.16283223904303787,
                                    0.038574378838757355,
                                    0.00794429868780358,
                                ],
                                [
                                    0.7906490834304012,
                                    0.038574378838757355,
                                    0.16283223904303787,
                                    0.00794429868780358,
                                ],
                                [
                                    0.5848974654271099,
                                    0.038574378838757355,
                                    0.3532322525488825,
                                    0.023295903185250252,
                                ],
                                [
                                    0.8944891641473837,
                                    0.04364055382860875,
                                    0.05899215832605542,
                                    0.0028781236979521898,
                                ],
                                [
                                    0.8944891641473837,
                                    0.05899215832605542,
                                    0.04364055382860875,
                                    0.0028781236979521898,
                                ],
                                [
                                    0.22258848529324102,
                                    0.502228052500494,
                                    0.08450782623791812,
                                    0.1906756359683469,
                                ],
                                [
                                    0.22258848529324102,
                                    0.08450782623791812,
                                    0.502228052500494,
                                    0.1906756359683469,
                                ],
                                [
                                    0.29048846939087086,
                                    0.6554312909036022,
                                    0.016607842140288293,
                                    0.03747239756523875,
                                ],
                                [
                                    0.7082086956534467,
                                    0.26887813767014057,
                                    0.016607842140288293,
                                    0.006305324536124488,
                                ],
                                [
                                    0.7082086956534467,
                                    0.016607842140288293,
                                    0.26887813767014057,
                                    0.006305324536124488,
                                ],
                                [
                                    0.29048846939087086,
                                    0.016607842140288293,
                                    0.6554312909036022,
                                    0.03747239756523875,
                                ],
                                [
                                    0.9242457431643334,
                                    0.02167401713013968,
                                    0.052841090159253944,
                                    0.0012391495462730974,
                                ],
                                [
                                    0.9242457431643334,
                                    0.052841090159253944,
                                    0.02167401713013968,
                                    0.0012391495462730974,
                                ],
                                [
                                    0.04166083284091789,
                                    0.6031332746824886,
                                    0.022950230372629808,
                                    0.3322556621039636,
                                ],
                                [
                                    0.04166083284091789,
                                    0.022950230372629808,
                                    0.6031332746824886,
                                    0.3322556621039636,
                                ],
                                [
                                    0.061502652037904955,
                                    0.8903877670166607,
                                    0.003108411175642752,
                                    0.04500116976979165,
                                ],
                                [
                                    0.6416856963477637,
                                    0.3534935226628102,
                                    0.0031084111756427544,
                                    0.0017123698137832641,
                                ],
                                [
                                    0.6416856963477637,
                                    0.0031084111756427544,
                                    0.3534935226628102,
                                    0.0017123698137832641,
                                ],
                                [
                                    0.061502652037904955,
                                    0.003108411175642752,
                                    0.8903877670166607,
                                    0.04500116976979165,
                                ],
                                [
                                    0.9473015638183706,
                                    0.004588855236195017,
                                    0.04787765519220339,
                                    0.00023192575323100238,
                                ],
                                [
                                    0.9473015638183706,
                                    0.04787765519220339,
                                    0.004588855236195017,
                                    0.00023192575323100238,
                                ],
                                [
                                    0.5668892135127584,
                                    0.3423566790267285,
                                    0.056582630753108765,
                                    0.03417147670740428,
                                ],
                                [
                                    0.5668892135127584,
                                    0.056582630753108765,
                                    0.3423566790267285,
                                    0.03417147670740428,
                                ],
                                [
                                    0.5811749277984727,
                                    0.350984131417427,
                                    0.042296916467394474,
                                    0.02554402431670578,
                                ],
                                [
                                    0.6300198326657538,
                                    0.06288385580308704,
                                    0.27922605987373306,
                                    0.027870251657426,
                                ],
                                [
                                    0.6300198326657538,
                                    0.27922605987373306,
                                    0.06288385580308704,
                                    0.027870251657426,
                                ],
                                [
                                    0.5811749277984727,
                                    0.042296916467394474,
                                    0.350984131417427,
                                    0.02554402431670578,
                                ],
                                [
                                    0.6458964503703416,
                                    0.2862626088455581,
                                    0.047007238098499285,
                                    0.020833702685600967,
                                ],
                                [
                                    0.6458964503703416,
                                    0.047007238098499285,
                                    0.2862626088455581,
                                    0.020833702685600967,
                                ],
                                [
                                    0.3722278804873073,
                                    0.45699558178185123,
                                    0.07665941880438285,
                                    0.0941171189264586,
                                ],
                                [
                                    0.3722278804873073,
                                    0.07665941880438285,
                                    0.45699558178185123,
                                    0.0941171189264586,
                                ],
                                [
                                    0.42111451548751816,
                                    0.5170152024884742,
                                    0.027772783804171978,
                                    0.034097498219835626,
                                ],
                                [
                                    0.6458794825882285,
                                    0.13301729491103353,
                                    0.1833439796809301,
                                    0.03775924281980792,
                                ],
                                [
                                    0.6458794825882285,
                                    0.1833439796809301,
                                    0.13301729491103353,
                                    0.03775924281980792,
                                ],
                                [
                                    0.42111451548751816,
                                    0.027772783804171978,
                                    0.5170152024884742,
                                    0.034097498219835626,
                                ],
                                [
                                    0.730706214207792,
                                    0.20742350376820046,
                                    0.04819056329147004,
                                    0.013679718732537566,
                                ],
                                [
                                    0.730706214207792,
                                    0.04819056329147004,
                                    0.20742350376820046,
                                    0.013679718732537566,
                                ],
                                [
                                    0.16025927222802275,
                                    0.5645572655657123,
                                    0.06084395027271525,
                                    0.2143395119335498,
                                ],
                                [
                                    0.16025927222802275,
                                    0.06084395027271525,
                                    0.5645572655657123,
                                    0.2143395119335498,
                                ],
                                [
                                    0.20914590722823362,
                                    0.7367738530662394,
                                    0.01195731527250439,
                                    0.04212292443302265,
                                ],
                                [
                                    0.6458794825882285,
                                    0.24521426170493768,
                                    0.0789370552055065,
                                    0.02996920050132735,
                                ],
                                [
                                    0.6458794825882285,
                                    0.0789370552055065,
                                    0.24521426170493768,
                                    0.02996920050132735,
                                ],
                                [
                                    0.20914590722823362,
                                    0.01195731527250439,
                                    0.7367738530662394,
                                    0.04212292443302265,
                                ],
                                [
                                    0.8429031810016961,
                                    0.10301657929277686,
                                    0.04819056329147004,
                                    0.005889676414056997,
                                ],
                                [
                                    0.8429031810016961,
                                    0.04819056329147004,
                                    0.10301657929277686,
                                    0.005889676414056997,
                                ],
                                [
                                    0.029994969158908064,
                                    0.6147991383644984,
                                    0.016523708367652958,
                                    0.3386821841089405,
                                ],
                                [
                                    0.029994969158908064,
                                    0.016523708367652958,
                                    0.6147991383644984,
                                    0.3386821841089405,
                                ],
                                [
                                    0.044280683444622375,
                                    0.9076097356099433,
                                    0.0022379940819386474,
                                    0.045871586863495746,
                                ],
                                [
                                    0.6300198326657539,
                                    0.3470670006578333,
                                    0.014774274857652647,
                                    0.008138891818760147,
                                ],
                                [
                                    0.6300198326657539,
                                    0.014774274857652647,
                                    0.3470670006578333,
                                    0.008138891818760147,
                                ],
                                [
                                    0.044280683444622375,
                                    0.0022379940819386474,
                                    0.9076097356099433,
                                    0.045871586863495746,
                                ],
                                [
                                    0.930079595225088,
                                    0.021810823829477684,
                                    0.047007238098499285,
                                    0.0011023428469351115,
                                ],
                                [
                                    0.930079595225088,
                                    0.047007238098499285,
                                    0.021810823829477684,
                                    0.0011023428469351115,
                                ],
                                [
                                    0.2792260598737331,
                                    0.6300198326657538,
                                    0.027870251657426008,
                                    0.06288385580308704,
                                ],
                                [
                                    0.2792260598737331,
                                    0.027870251657426008,
                                    0.6300198326657538,
                                    0.06288385580308704,
                                ],
                                [
                                    0.28626260884555815,
                                    0.6458964503703416,
                                    0.02083370268560097,
                                    0.047007238098499285,
                                ],
                                [
                                    0.3423566790267286,
                                    0.03417147670740429,
                                    0.5668892135127583,
                                    0.05658263075310876,
                                ],
                                [
                                    0.3423566790267286,
                                    0.5668892135127583,
                                    0.03417147670740429,
                                    0.05658263075310876,
                                ],
                                [
                                    0.28626260884555815,
                                    0.02083370268560097,
                                    0.6458964503703416,
                                    0.047007238098499285,
                                ],
                                [
                                    0.35098413141742707,
                                    0.5811749277984726,
                                    0.025544024316705792,
                                    0.04229691646739447,
                                ],
                                [
                                    0.35098413141742707,
                                    0.025544024316705792,
                                    0.5811749277984726,
                                    0.04229691646739447,
                                ],
                                [
                                    0.18334397968093008,
                                    0.6458794825882285,
                                    0.037759242819807914,
                                    0.13301729491103353,
                                ],
                                [
                                    0.18334397968093008,
                                    0.037759242819807914,
                                    0.6458794825882285,
                                    0.13301729491103353,
                                ],
                                [
                                    0.20742350376820043,
                                    0.730706214207792,
                                    0.013679718732537564,
                                    0.04819056329147004,
                                ],
                                [
                                    0.45699558178185123,
                                    0.0941171189264586,
                                    0.3722278804873073,
                                    0.07665941880438285,
                                ],
                                [
                                    0.45699558178185123,
                                    0.3722278804873073,
                                    0.0941171189264586,
                                    0.07665941880438285,
                                ],
                                [
                                    0.20742350376820043,
                                    0.013679718732537564,
                                    0.730706214207792,
                                    0.04819056329147004,
                                ],
                                [
                                    0.5170152024884742,
                                    0.42111451548751816,
                                    0.034097498219835626,
                                    0.027772783804171978,
                                ],
                                [
                                    0.5170152024884742,
                                    0.034097498219835626,
                                    0.42111451548751816,
                                    0.027772783804171978,
                                ],
                                [
                                    0.07893705520550652,
                                    0.6458794825882285,
                                    0.029969200501327356,
                                    0.24521426170493768,
                                ],
                                [
                                    0.07893705520550652,
                                    0.029969200501327356,
                                    0.6458794825882285,
                                    0.24521426170493768,
                                ],
                                [
                                    0.10301657929277688,
                                    0.8429031810016961,
                                    0.005889676414056999,
                                    0.04819056329147004,
                                ],
                                [
                                    0.5645572655657123,
                                    0.2143395119335498,
                                    0.16025927222802278,
                                    0.060843950272715254,
                                ],
                                [
                                    0.5645572655657123,
                                    0.16025927222802278,
                                    0.2143395119335498,
                                    0.060843950272715254,
                                ],
                                [
                                    0.10301657929277688,
                                    0.005889676414056999,
                                    0.8429031810016961,
                                    0.04819056329147004,
                                ],
                                [
                                    0.7367738530662394,
                                    0.20914590722823365,
                                    0.04212292443302265,
                                    0.011957315272504392,
                                ],
                                [
                                    0.7367738530662394,
                                    0.04212292443302265,
                                    0.20914590722823365,
                                    0.011957315272504392,
                                ],
                                [
                                    0.014774274857652685,
                                    0.6300198326657538,
                                    0.00813889181876017,
                                    0.3470670006578333,
                                ],
                                [
                                    0.014774274857652685,
                                    0.00813889181876017,
                                    0.6300198326657538,
                                    0.3470670006578333,
                                ],
                                [
                                    0.02181082382947774,
                                    0.9300795952250879,
                                    0.0011023428469351144,
                                    0.047007238098499285,
                                ],
                                [
                                    0.6147991383644985,
                                    0.3386821841089405,
                                    0.029994969158908025,
                                    0.01652370836765294,
                                ],
                                [
                                    0.6147991383644985,
                                    0.029994969158908025,
                                    0.3386821841089405,
                                    0.01652370836765294,
                                ],
                                [
                                    0.02181082382947774,
                                    0.0011023428469351144,
                                    0.9300795952250879,
                                    0.047007238098499285,
                                ],
                                [
                                    0.9076097356099433,
                                    0.044280683444622326,
                                    0.04587158686349575,
                                    0.0022379940819386448,
                                ],
                                [
                                    0.9076097356099433,
                                    0.04587158686349575,
                                    0.044280683444622326,
                                    0.0022379940819386448,
                                ],
                                [
                                    0.05874734383952739,
                                    0.8504985486999596,
                                    0.005863719374020309,
                                    0.08489038808649274,
                                ],
                                [
                                    0.05874734383952739,
                                    0.005863719374020309,
                                    0.8504985486999596,
                                    0.08489038808649274,
                                ],
                                [
                                    0.060227787900079655,
                                    0.87193127131582,
                                    0.004383275313468048,
                                    0.06345766547063221,
                                ],
                                [
                                    0.12187796299252288,
                                    0.01216494442399859,
                                    0.7873679295469641,
                                    0.07858916303651445,
                                ],
                                [
                                    0.12187796299252288,
                                    0.7873679295469641,
                                    0.01216494442399859,
                                    0.07858916303651445,
                                ],
                                [
                                    0.060227787900079655,
                                    0.004383275313468048,
                                    0.87193127131582,
                                    0.06345766547063221,
                                ],
                                [
                                    0.1249493104719486,
                                    0.8072097487439511,
                                    0.009093596944572867,
                                    0.05874734383952739,
                                ],
                                [
                                    0.1249493104719486,
                                    0.009093596944572867,
                                    0.8072097487439511,
                                    0.05874734383952739,
                                ],
                                [
                                    0.03857437883875743,
                                    0.7906490834304011,
                                    0.007944298687803594,
                                    0.16283223904303784,
                                ],
                                [
                                    0.03857437883875743,
                                    0.007944298687803594,
                                    0.7906490834304011,
                                    0.16283223904303784,
                                ],
                                [
                                    0.04364055382860883,
                                    0.8944891641473836,
                                    0.0028781236979521954,
                                    0.058992158326055415,
                                ],
                                [
                                    0.3122259809396786,
                                    0.0643021747944543,
                                    0.51699748132948,
                                    0.10647436293638715,
                                ],
                                [
                                    0.3122259809396786,
                                    0.51699748132948,
                                    0.0643021747944543,
                                    0.10647436293638715,
                                ],
                                [
                                    0.04364055382860883,
                                    0.0028781236979521954,
                                    0.8944891641473836,
                                    0.058992158326055415,
                                ],
                                [
                                    0.35323225254888263,
                                    0.5848974654271097,
                                    0.02329590318525026,
                                    0.03857437883875735,
                                ],
                                [
                                    0.35323225254888263,
                                    0.02329590318525026,
                                    0.5848974654271097,
                                    0.03857437883875735,
                                ],
                                [
                                    0.016607842140288348,
                                    0.7082086956534467,
                                    0.006305324536124509,
                                    0.2688781376701405,
                                ],
                                [
                                    0.016607842140288348,
                                    0.006305324536124509,
                                    0.7082086956534467,
                                    0.2688781376701405,
                                ],
                                [
                                    0.021674017130139753,
                                    0.9242457431643333,
                                    0.0012391495462731016,
                                    0.05284109015925394,
                                ],
                                [
                                    0.502228052500494,
                                    0.1906756359683469,
                                    0.222588485293241,
                                    0.08450782623791811,
                                ],
                                [
                                    0.502228052500494,
                                    0.222588485293241,
                                    0.1906756359683469,
                                    0.08450782623791811,
                                ],
                                [
                                    0.021674017130139753,
                                    0.0012391495462731016,
                                    0.9242457431643333,
                                    0.05284109015925394,
                                ],
                                [
                                    0.6554312909036022,
                                    0.2904884693908708,
                                    0.03747239756523875,
                                    0.01660784214028829,
                                ],
                                [
                                    0.6554312909036022,
                                    0.03747239756523875,
                                    0.2904884693908708,
                                    0.01660784214028829,
                                ],
                                [
                                    0.0031084111756427843,
                                    0.6416856963477637,
                                    0.0017123698137832808,
                                    0.3534935226628102,
                                ],
                                [
                                    0.0031084111756427843,
                                    0.0017123698137832808,
                                    0.6416856963477637,
                                    0.3534935226628102,
                                ],
                                [
                                    0.004588855236195061,
                                    0.9473015638183706,
                                    0.00023192575323100463,
                                    0.04787765519220339,
                                ],
                                [
                                    0.6031332746824886,
                                    0.3322556621039636,
                                    0.04166083284091792,
                                    0.022950230372629825,
                                ],
                                [
                                    0.6031332746824886,
                                    0.04166083284091792,
                                    0.3322556621039636,
                                    0.022950230372629825,
                                ],
                                [
                                    0.004588855236195061,
                                    0.00023192575323100463,
                                    0.9473015638183706,
                                    0.04787765519220339,
                                ],
                                [
                                    0.8903877670166607,
                                    0.06150265203790499,
                                    0.04500116976979165,
                                    0.003108411175642754,
                                ],
                                [
                                    0.8903877670166607,
                                    0.04500116976979165,
                                    0.06150265203790499,
                                    0.003108411175642754,
                                ],
                                [
                                    0.5668892135127583,
                                    0.087749703782223,
                                    0.2990678790707202,
                                    0.046293203634298404,
                                ],
                                [
                                    0.5668892135127583,
                                    0.2990678790707202,
                                    0.087749703782223,
                                    0.046293203634298404,
                                ],
                                [
                                    0.5867310327097455,
                                    0.09082105126164874,
                                    0.2792260598737331,
                                    0.04322185615487268,
                                ],
                                [
                                    0.6123420008275869,
                                    0.32304693595886536,
                                    0.04229691646739446,
                                    0.022314146746153226,
                                ],
                                [
                                    0.6123420008275869,
                                    0.04229691646739446,
                                    0.32304693595886536,
                                    0.022314146746153226,
                                ],
                                [
                                    0.5867310327097455,
                                    0.2792260598737331,
                                    0.09082105126164874,
                                    0.04322185615487268,
                                ],
                                [
                                    0.6337747234434474,
                                    0.04377736052794672,
                                    0.3016142133430048,
                                    0.020833702685600967,
                                ],
                                [
                                    0.6337747234434474,
                                    0.3016142133430048,
                                    0.04377736052794672,
                                    0.020833702685600967,
                                ],
                                [
                                    0.3722278804873073,
                                    0.22479648221763965,
                                    0.2512439637785599,
                                    0.15173167351649314,
                                ],
                                [
                                    0.3722278804873073,
                                    0.2512439637785599,
                                    0.22479648221763965,
                                    0.15173167351649314,
                                ],
                                [
                                    0.44012786458493713,
                                    0.2658027538268437,
                                    0.18334397968093008,
                                    0.11072540190728912,
                                ],
                                [
                                    0.569251578900775,
                                    0.3842297435726641,
                                    0.02777278380417198,
                                    0.018745893722388954,
                                ],
                                [
                                    0.569251578900775,
                                    0.02777278380417198,
                                    0.3842297435726641,
                                    0.018745893722388954,
                                ],
                                [
                                    0.44012786458493713,
                                    0.18334397968093008,
                                    0.2658027538268437,
                                    0.11072540190728912,
                                ],
                                [
                                    0.6730916596177575,
                                    0.03283895879402337,
                                    0.2803896628556817,
                                    0.013679718732537566,
                                ],
                                [
                                    0.6730916596177575,
                                    0.2803896628556817,
                                    0.03283895879402337,
                                    0.013679718732537566,
                                ],
                                [
                                    0.16025927222802278,
                                    0.3615941861511485,
                                    0.14683703930313635,
                                    0.33130950231769235,
                                ],
                                [
                                    0.16025927222802278,
                                    0.14683703930313635,
                                    0.3615941861511485,
                                    0.33130950231769235,
                                ],
                                [
                                    0.2281592563256526,
                                    0.5147974245542567,
                                    0.0789370552055065,
                                    0.17810626391458415,
                                ],
                                [
                                    0.509896143106667,
                                    0.46719069021692033,
                                    0.01195731527250439,
                                    0.010955851403908388,
                                ],
                                [
                                    0.509896143106667,
                                    0.01195731527250439,
                                    0.46719069021692033,
                                    0.010955851403908388,
                                ],
                                [
                                    0.2281592563256526,
                                    0.0789370552055065,
                                    0.5147974245542567,
                                    0.17810626391458415,
                                ],
                                [
                                    0.7259331906175536,
                                    0.01702349026235578,
                                    0.2511536427060337,
                                    0.005889676414056997,
                                ],
                                [
                                    0.7259331906175536,
                                    0.2511536427060337,
                                    0.01702349026235578,
                                    0.005889676414056997,
                                ],
                                [
                                    0.029994969158908008,
                                    0.4342439346302288,
                                    0.034616094054639696,
                                    0.5011450021562235,
                                ],
                                [
                                    0.029994969158908008,
                                    0.034616094054639696,
                                    0.4342439346302288,
                                    0.5011450021562235,
                                ],
                                [
                                    0.04983678835589507,
                                    0.7214984269644008,
                                    0.014774274857652637,
                                    0.21389050982205146,
                                ],
                                [
                                    0.46200090970719815,
                                    0.5331783093033758,
                                    0.002237994081938645,
                                    0.0025827869074873736,
                                ],
                                [
                                    0.46200090970719815,
                                    0.002237994081938645,
                                    0.5331783093033758,
                                    0.0025827869074873736,
                                ],
                                [
                                    0.04983678835589507,
                                    0.014774274857652637,
                                    0.7214984269644008,
                                    0.21389050982205146,
                                ],
                                [
                                    0.767616777177805,
                                    0.0037184381424909072,
                                    0.227562441832769,
                                    0.0011023428469351115,
                                ],
                                [
                                    0.767616777177805,
                                    0.227562441832769,
                                    0.0037184381424909072,
                                    0.0011023428469351115,
                                ],
                                [
                                    0.40814893309411254,
                                    0.24648998420086882,
                                    0.21532291117175464,
                                    0.13003817153326394,
                                ],
                                [
                                    0.40814893309411254,
                                    0.21532291117175464,
                                    0.24648998420086882,
                                    0.13003817153326394,
                                ],
                                [
                                    0.4224346473798269,
                                    0.2551174365915673,
                                    0.20103719688604033,
                                    0.12141071914256545,
                                ],
                                [
                                    0.45360172040894103,
                                    0.23930196805989978,
                                    0.20103719688604027,
                                    0.10605911464511877,
                                ],
                                [
                                    0.45360172040894103,
                                    0.20103719688604027,
                                    0.23930196805989978,
                                    0.10605911464511877,
                                ],
                                [
                                    0.4224346473798269,
                                    0.20103719688604033,
                                    0.2551174365915673,
                                    0.12141071914256545,
                                ],
                                [
                                    0.46947833811352885,
                                    0.20807374585786534,
                                    0.22342535035531202,
                                    0.09902256567329375,
                                ],
                                [
                                    0.46947833811352885,
                                    0.22342535035531202,
                                    0.20807374585786534,
                                    0.09902256567329375,
                                ],
                                [
                                    0.2679966537859661,
                                    0.32902770891898087,
                                    0.18089064550572403,
                                    0.222084991789329,
                                ],
                                [
                                    0.2679966537859661,
                                    0.18089064550572403,
                                    0.32902770891898087,
                                    0.222084991789329,
                                ],
                                [
                                    0.31688328878617694,
                                    0.3890473296256039,
                                    0.1320040105055132,
                                    0.16206537108270602,
                                ],
                                [
                                    0.4650203521994338,
                                    0.31387642529982823,
                                    0.13200401050551322,
                                    0.08909921199522482,
                                ],
                                [
                                    0.4650203521994338,
                                    0.13200401050551322,
                                    0.31387642529982823,
                                    0.08909921199522482,
                                ],
                                [
                                    0.31688328878617694,
                                    0.1320040105055132,
                                    0.3890473296256039,
                                    0.16206537108270602,
                                ],
                                [
                                    0.5498470838189973,
                                    0.15608353459278357,
                                    0.22904969368026476,
                                    0.06501968790795447,
                                ],
                                [
                                    0.5498470838189973,
                                    0.22904969368026476,
                                    0.15608353459278357,
                                    0.06501968790795447,
                                ],
                                [
                                    0.11538348132078953,
                                    0.4064699770583818,
                                    0.10571974117994846,
                                    0.3724268004408802,
                                ],
                                [
                                    0.11538348132078953,
                                    0.10571974117994846,
                                    0.4064699770583818,
                                    0.3724268004408802,
                                ],
                                [
                                    0.1642701163210004,
                                    0.5786865645589089,
                                    0.0568331061797376,
                                    0.20021021294035304,
                                ],
                                [
                                    0.46502035219943366,
                                    0.42607339209373246,
                                    0.0568331061797376,
                                    0.05207314952709625,
                                ],
                                [
                                    0.46502035219943366,
                                    0.0568331061797376,
                                    0.42607339209373246,
                                    0.05207314952709625,
                                ],
                                [
                                    0.1642701163210004,
                                    0.0568331061797376,
                                    0.5786865645589089,
                                    0.20021021294035304,
                                ],
                                [
                                    0.6620440506129013,
                                    0.08091263026700796,
                                    0.22904969368026476,
                                    0.027993625439825885,
                                ],
                                [
                                    0.6620440506129013,
                                    0.22904969368026476,
                                    0.08091263026700796,
                                    0.027993625439825885,
                                ],
                                [
                                    0.021595779860651042,
                                    0.44264312392848576,
                                    0.024922897665909983,
                                    0.5108381985449533,
                                ],
                                [
                                    0.021595779860651042,
                                    0.024922897665909983,
                                    0.44264312392848576,
                                    0.5108381985449533,
                                ],
                                [
                                    0.03588149414636536,
                                    0.7354537211739306,
                                    0.010637183380195668,
                                    0.21802760129950843,
                                ],
                                [
                                    0.45360172040894114,
                                    0.5234851129146461,
                                    0.010637183380195656,
                                    0.01227598329621714,
                                ],
                                [
                                    0.45360172040894114,
                                    0.010637183380195656,
                                    0.5234851129146461,
                                    0.01227598329621714,
                                ],
                                [
                                    0.03588149414636536,
                                    0.010637183380195668,
                                    0.7354537211739306,
                                    0.21802760129950843,
                                ],
                                [
                                    0.7536614829682753,
                                    0.017673732352020695,
                                    0.22342535035531202,
                                    0.005239434324392104,
                                ],
                                [
                                    0.7536614829682753,
                                    0.22342535035531202,
                                    0.017673732352020695,
                                    0.005239434324392104,
                                ],
                                [
                                    0.2010371968860403,
                                    0.45360172040894103,
                                    0.1060591146451188,
                                    0.23930196805989978,
                                ],
                                [
                                    0.2010371968860403,
                                    0.1060591146451188,
                                    0.45360172040894103,
                                    0.23930196805989978,
                                ],
                                [
                                    0.20807374585786537,
                                    0.46947833811352885,
                                    0.09902256567329376,
                                    0.22342535035531202,
                                ],
                                [
                                    0.2464899842008689,
                                    0.130038171533264,
                                    0.4081489330941125,
                                    0.2153229111717546,
                                ],
                                [
                                    0.2464899842008689,
                                    0.4081489330941125,
                                    0.130038171533264,
                                    0.2153229111717546,
                                ],
                                [
                                    0.20807374585786537,
                                    0.09902256567329376,
                                    0.46947833811352885,
                                    0.22342535035531202,
                                ],
                                [
                                    0.25511743659156744,
                                    0.4224346473798268,
                                    0.12141071914256549,
                                    0.2010371968860403,
                                ],
                                [
                                    0.25511743659156744,
                                    0.12141071914256549,
                                    0.4224346473798268,
                                    0.2010371968860403,
                                ],
                                [
                                    0.1320040105055132,
                                    0.4650203521994338,
                                    0.0890992119952248,
                                    0.31387642529982823,
                                ],
                                [
                                    0.1320040105055132,
                                    0.0890992119952248,
                                    0.4650203521994338,
                                    0.31387642529982823,
                                ],
                                [
                                    0.15608353459278354,
                                    0.5498470838189973,
                                    0.06501968790795445,
                                    0.22904969368026476,
                                ],
                                [
                                    0.32902770891898087,
                                    0.222084991789329,
                                    0.2679966537859661,
                                    0.18089064550572403,
                                ],
                                [
                                    0.32902770891898087,
                                    0.2679966537859661,
                                    0.222084991789329,
                                    0.18089064550572403,
                                ],
                                [
                                    0.15608353459278354,
                                    0.06501968790795445,
                                    0.5498470838189973,
                                    0.22904969368026476,
                                ],
                                [
                                    0.3890473296256039,
                                    0.31688328878617694,
                                    0.16206537108270602,
                                    0.1320040105055132,
                                ],
                                [
                                    0.3890473296256039,
                                    0.16206537108270602,
                                    0.31688328878617694,
                                    0.1320040105055132,
                                ],
                                [
                                    0.05683310617973762,
                                    0.46502035219943366,
                                    0.052073149527096255,
                                    0.42607339209373246,
                                ],
                                [
                                    0.05683310617973762,
                                    0.052073149527096255,
                                    0.46502035219943366,
                                    0.42607339209373246,
                                ],
                                [
                                    0.08091263026700797,
                                    0.6620440506129013,
                                    0.027993625439825896,
                                    0.22904969368026476,
                                ],
                                [
                                    0.4064699770583818,
                                    0.3724268004408802,
                                    0.11538348132078954,
                                    0.10571974117994848,
                                ],
                                [
                                    0.4064699770583818,
                                    0.11538348132078954,
                                    0.3724268004408802,
                                    0.10571974117994848,
                                ],
                                [
                                    0.08091263026700797,
                                    0.027993625439825896,
                                    0.6620440506129013,
                                    0.22904969368026476,
                                ],
                                [
                                    0.5786865645589089,
                                    0.1642701163210004,
                                    0.20021021294035304,
                                    0.05683310617973761,
                                ],
                                [
                                    0.5786865645589089,
                                    0.20021021294035304,
                                    0.1642701163210004,
                                    0.05683310617973761,
                                ],
                                [
                                    0.010637183380195682,
                                    0.4536017204089411,
                                    0.012275983296217173,
                                    0.5234851129146461,
                                ],
                                [
                                    0.010637183380195682,
                                    0.012275983296217173,
                                    0.4536017204089411,
                                    0.5234851129146461,
                                ],
                                [
                                    0.01767373235202074,
                                    0.7536614829682752,
                                    0.005239434324392117,
                                    0.223425350355312,
                                ],
                                [
                                    0.4426431239284858,
                                    0.5108381985449533,
                                    0.021595779860651018,
                                    0.02492289766590995,
                                ],
                                [
                                    0.4426431239284858,
                                    0.021595779860651018,
                                    0.5108381985449533,
                                    0.02492289766590995,
                                ],
                                [
                                    0.01767373235202074,
                                    0.005239434324392117,
                                    0.7536614829682752,
                                    0.223425350355312,
                                ],
                                [
                                    0.7354537211739306,
                                    0.035881494146365316,
                                    0.21802760129950846,
                                    0.010637183380195654,
                                ],
                                [
                                    0.7354537211739306,
                                    0.21802760129950846,
                                    0.035881494146365316,
                                    0.010637183380195654,
                                ],
                                [
                                    0.04229691646739447,
                                    0.6123420008275869,
                                    0.022314146746153233,
                                    0.32304693595886536,
                                ],
                                [
                                    0.04229691646739447,
                                    0.022314146746153233,
                                    0.6123420008275869,
                                    0.32304693595886536,
                                ],
                                [
                                    0.043777360527946736,
                                    0.6337747234434474,
                                    0.02083370268560097,
                                    0.3016142133430048,
                                ],
                                [
                                    0.08774970378222305,
                                    0.046293203634298424,
                                    0.5668892135127583,
                                    0.2990678790707202,
                                ],
                                [
                                    0.08774970378222305,
                                    0.5668892135127583,
                                    0.046293203634298424,
                                    0.2990678790707202,
                                ],
                                [
                                    0.043777360527946736,
                                    0.02083370268560097,
                                    0.6337747234434474,
                                    0.3016142133430048,
                                ],
                                [
                                    0.09082105126164877,
                                    0.5867310327097455,
                                    0.043221856154872694,
                                    0.2792260598737331,
                                ],
                                [
                                    0.09082105126164877,
                                    0.043221856154872694,
                                    0.5867310327097455,
                                    0.2792260598737331,
                                ],
                                [
                                    0.027772783804172033,
                                    0.5692515789007749,
                                    0.018745893722388992,
                                    0.38422974357266404,
                                ],
                                [
                                    0.027772783804172033,
                                    0.018745893722388992,
                                    0.5692515789007749,
                                    0.38422974357266404,
                                ],
                                [
                                    0.03283895879402344,
                                    0.6730916596177574,
                                    0.013679718732537592,
                                    0.2803896628556816,
                                ],
                                [
                                    0.2247964822176397,
                                    0.1517316735164932,
                                    0.37222788048730726,
                                    0.25124396377855984,
                                ],
                                [
                                    0.2247964822176397,
                                    0.37222788048730726,
                                    0.1517316735164932,
                                    0.25124396377855984,
                                ],
                                [
                                    0.03283895879402344,
                                    0.013679718732537592,
                                    0.6730916596177574,
                                    0.2803896628556816,
                                ],
                                [
                                    0.26580275382684376,
                                    0.4401278645849371,
                                    0.11072540190728916,
                                    0.18334397968093005,
                                ],
                                [
                                    0.26580275382684376,
                                    0.11072540190728916,
                                    0.4401278645849371,
                                    0.18334397968093005,
                                ],
                                [
                                    0.01195731527250443,
                                    0.5098961431066669,
                                    0.010955851403908425,
                                    0.4671906902169203,
                                ],
                                [
                                    0.01195731527250443,
                                    0.010955851403908425,
                                    0.5098961431066669,
                                    0.4671906902169203,
                                ],
                                [
                                    0.017023490262355837,
                                    0.7259331906175535,
                                    0.005889676414057016,
                                    0.25115364270603363,
                                ],
                                [
                                    0.3615941861511485,
                                    0.33130950231769235,
                                    0.16025927222802275,
                                    0.14683703930313632,
                                ],
                                [
                                    0.3615941861511485,
                                    0.16025927222802275,
                                    0.33130950231769235,
                                    0.14683703930313632,
                                ],
                                [
                                    0.017023490262355837,
                                    0.005889676414057016,
                                    0.7259331906175535,
                                    0.25115364270603363,
                                ],
                                [
                                    0.5147974245542567,
                                    0.22815925632565257,
                                    0.17810626391458415,
                                    0.07893705520550649,
                                ],
                                [
                                    0.5147974245542567,
                                    0.17810626391458415,
                                    0.22815925632565257,
                                    0.07893705520550649,
                                ],
                                [
                                    0.002237994081938667,
                                    0.46200090970719815,
                                    0.0025827869074873987,
                                    0.5331783093033758,
                                ],
                                [
                                    0.002237994081938667,
                                    0.0025827869074873987,
                                    0.46200090970719815,
                                    0.5331783093033758,
                                ],
                                [
                                    0.0037184381424909436,
                                    0.767616777177805,
                                    0.0011023428469351222,
                                    0.227562441832769,
                                ],
                                [
                                    0.4342439346302288,
                                    0.5011450021562235,
                                    0.02999496915890803,
                                    0.034616094054639716,
                                ],
                                [
                                    0.4342439346302288,
                                    0.02999496915890803,
                                    0.5011450021562235,
                                    0.034616094054639716,
                                ],
                                [
                                    0.0037184381424909436,
                                    0.0011023428469351222,
                                    0.767616777177805,
                                    0.227562441832769,
                                ],
                                [
                                    0.7214984269644008,
                                    0.0498367883558951,
                                    0.21389050982205146,
                                    0.014774274857652646,
                                ],
                                [
                                    0.7214984269644008,
                                    0.21389050982205146,
                                    0.0498367883558951,
                                    0.014774274857652646,
                                ],
                                [
                                    0.2792260598737331,
                                    0.04322185615487268,
                                    0.5867310327097455,
                                    0.09082105126164874,
                                ],
                                [
                                    0.2792260598737331,
                                    0.5867310327097455,
                                    0.04322185615487268,
                                    0.09082105126164874,
                                ],
                                [
                                    0.29906787907072013,
                                    0.0462932036342984,
                                    0.5668892135127584,
                                    0.08774970378222302,
                                ],
                                [
                                    0.3016142133430048,
                                    0.6337747234434474,
                                    0.020833702685600967,
                                    0.04377736052794672,
                                ],
                                [
                                    0.3016142133430048,
                                    0.020833702685600967,
                                    0.6337747234434474,
                                    0.04377736052794672,
                                ],
                                [
                                    0.29906787907072013,
                                    0.5668892135127584,
                                    0.0462932036342984,
                                    0.08774970378222302,
                                ],
                                [
                                    0.3230469359588653,
                                    0.022314146746153223,
                                    0.6123420008275869,
                                    0.04229691646739447,
                                ],
                                [
                                    0.3230469359588653,
                                    0.6123420008275869,
                                    0.022314146746153223,
                                    0.04229691646739447,
                                ],
                                [
                                    0.18334397968093014,
                                    0.11072540190728915,
                                    0.4401278645849371,
                                    0.26580275382684365,
                                ],
                                [
                                    0.18334397968093014,
                                    0.4401278645849371,
                                    0.11072540190728915,
                                    0.26580275382684365,
                                ],
                                [
                                    0.25124396377855995,
                                    0.15173167351649317,
                                    0.37222788048730726,
                                    0.22479648221763962,
                                ],
                                [
                                    0.28038966285568173,
                                    0.6730916596177574,
                                    0.013679718732537567,
                                    0.03283895879402337,
                                ],
                                [
                                    0.28038966285568173,
                                    0.013679718732537567,
                                    0.6730916596177574,
                                    0.03283895879402337,
                                ],
                                [
                                    0.25124396377855995,
                                    0.37222788048730726,
                                    0.15173167351649317,
                                    0.22479648221763962,
                                ],
                                [
                                    0.3842297435726642,
                                    0.01874589372238896,
                                    0.5692515789007749,
                                    0.027772783804171974,
                                ],
                                [
                                    0.3842297435726642,
                                    0.5692515789007749,
                                    0.01874589372238896,
                                    0.027772783804171974,
                                ],
                                [
                                    0.07893705520550652,
                                    0.17810626391458417,
                                    0.2281592563256526,
                                    0.5147974245542567,
                                ],
                                [
                                    0.07893705520550652,
                                    0.2281592563256526,
                                    0.17810626391458417,
                                    0.5147974245542567,
                                ],
                                [
                                    0.14683703930313635,
                                    0.33130950231769235,
                                    0.16025927222802278,
                                    0.3615941861511485,
                                ],
                                [
                                    0.25115364270603374,
                                    0.7259331906175536,
                                    0.005889676414056998,
                                    0.01702349026235578,
                                ],
                                [
                                    0.25115364270603374,
                                    0.005889676414056998,
                                    0.7259331906175536,
                                    0.01702349026235578,
                                ],
                                [
                                    0.14683703930313635,
                                    0.16025927222802278,
                                    0.33130950231769235,
                                    0.3615941861511485,
                                ],
                                [
                                    0.46719069021692033,
                                    0.010955851403908388,
                                    0.509896143106667,
                                    0.01195731527250439,
                                ],
                                [
                                    0.46719069021692033,
                                    0.509896143106667,
                                    0.010955851403908388,
                                    0.01195731527250439,
                                ],
                                [
                                    0.014774274857652642,
                                    0.21389050982205154,
                                    0.04983678835589506,
                                    0.7214984269644007,
                                ],
                                [
                                    0.014774274857652642,
                                    0.04983678835589506,
                                    0.21389050982205154,
                                    0.7214984269644007,
                                ],
                                [
                                    0.034616094054639696,
                                    0.5011450021562235,
                                    0.029994969158908005,
                                    0.43424393463022876,
                                ],
                                [
                                    0.22756244183276908,
                                    0.7676167771778049,
                                    0.001102342846935112,
                                    0.003718438142490907,
                                ],
                                [
                                    0.22756244183276908,
                                    0.001102342846935112,
                                    0.7676167771778049,
                                    0.003718438142490907,
                                ],
                                [
                                    0.034616094054639696,
                                    0.029994969158908005,
                                    0.5011450021562235,
                                    0.43424393463022876,
                                ],
                                [
                                    0.5331783093033758,
                                    0.0025827869074873736,
                                    0.4620009097071981,
                                    0.0022379940819386448,
                                ],
                                [
                                    0.5331783093033758,
                                    0.4620009097071981,
                                    0.0025827869074873736,
                                    0.0022379940819386448,
                                ],
                                [
                                    0.20103719688604033,
                                    0.12141071914256545,
                                    0.4224346473798269,
                                    0.2551174365915673,
                                ],
                                [
                                    0.20103719688604033,
                                    0.4224346473798269,
                                    0.12141071914256545,
                                    0.2551174365915673,
                                ],
                                [
                                    0.2153229111717546,
                                    0.13003817153326394,
                                    0.4081489330941126,
                                    0.24648998420086884,
                                ],
                                [
                                    0.22342535035531202,
                                    0.46947833811352885,
                                    0.09902256567329375,
                                    0.20807374585786534,
                                ],
                                [
                                    0.22342535035531202,
                                    0.09902256567329375,
                                    0.46947833811352885,
                                    0.20807374585786534,
                                ],
                                [
                                    0.2153229111717546,
                                    0.4081489330941126,
                                    0.13003817153326394,
                                    0.24648998420086884,
                                ],
                                [
                                    0.23930196805989976,
                                    0.10605911464511876,
                                    0.45360172040894114,
                                    0.2010371968860403,
                                ],
                                [
                                    0.23930196805989976,
                                    0.45360172040894114,
                                    0.10605911464511876,
                                    0.2010371968860403,
                                ],
                                [
                                    0.13200401050551322,
                                    0.16206537108270605,
                                    0.31688328878617694,
                                    0.3890473296256038,
                                ],
                                [
                                    0.13200401050551322,
                                    0.31688328878617694,
                                    0.16206537108270605,
                                    0.3890473296256038,
                                ],
                                [
                                    0.1808906455057241,
                                    0.22208499178932906,
                                    0.26799665378596604,
                                    0.3290277089189808,
                                ],
                                [
                                    0.2290496936802648,
                                    0.5498470838189972,
                                    0.06501968790795448,
                                    0.15608353459278354,
                                ],
                                [
                                    0.2290496936802648,
                                    0.06501968790795448,
                                    0.5498470838189972,
                                    0.15608353459278354,
                                ],
                                [
                                    0.1808906455057241,
                                    0.26799665378596604,
                                    0.22208499178932906,
                                    0.3290277089189808,
                                ],
                                [
                                    0.31387642529982834,
                                    0.08909921199522484,
                                    0.46502035219943366,
                                    0.1320040105055132,
                                ],
                                [
                                    0.31387642529982834,
                                    0.46502035219943366,
                                    0.08909921199522484,
                                    0.1320040105055132,
                                ],
                                [
                                    0.056833106179737615,
                                    0.2002102129403531,
                                    0.1642701163210004,
                                    0.5786865645589089,
                                ],
                                [
                                    0.056833106179737615,
                                    0.1642701163210004,
                                    0.2002102129403531,
                                    0.5786865645589089,
                                ],
                                [
                                    0.10571974117994846,
                                    0.3724268004408802,
                                    0.11538348132078953,
                                    0.4064699770583818,
                                ],
                                [
                                    0.22904969368026482,
                                    0.6620440506129013,
                                    0.027993625439825892,
                                    0.08091263026700796,
                                ],
                                [
                                    0.22904969368026482,
                                    0.027993625439825892,
                                    0.6620440506129013,
                                    0.08091263026700796,
                                ],
                                [
                                    0.10571974117994846,
                                    0.11538348132078953,
                                    0.3724268004408802,
                                    0.4064699770583818,
                                ],
                                [
                                    0.42607339209373246,
                                    0.05207314952709625,
                                    0.46502035219943366,
                                    0.0568331061797376,
                                ],
                                [
                                    0.42607339209373246,
                                    0.46502035219943366,
                                    0.05207314952709625,
                                    0.0568331061797376,
                                ],
                                [
                                    0.010637183380195672,
                                    0.21802760129950852,
                                    0.03588149414636536,
                                    0.7354537211739305,
                                ],
                                [
                                    0.010637183380195672,
                                    0.03588149414636536,
                                    0.21802760129950852,
                                    0.7354537211739305,
                                ],
                                [
                                    0.024922897665909983,
                                    0.5108381985449533,
                                    0.021595779860651042,
                                    0.4426431239284857,
                                ],
                                [
                                    0.2234253503553121,
                                    0.7536614829682752,
                                    0.0052394343243921055,
                                    0.01767373235202069,
                                ],
                                [
                                    0.2234253503553121,
                                    0.0052394343243921055,
                                    0.7536614829682752,
                                    0.01767373235202069,
                                ],
                                [
                                    0.024922897665909983,
                                    0.021595779860651042,
                                    0.5108381985449533,
                                    0.4426431239284857,
                                ],
                                [
                                    0.5234851129146461,
                                    0.01227598329621714,
                                    0.4536017204089411,
                                    0.010637183380195654,
                                ],
                                [
                                    0.5234851129146461,
                                    0.4536017204089411,
                                    0.01227598329621714,
                                    0.010637183380195654,
                                ],
                                [
                                    0.09902256567329376,
                                    0.22342535035531202,
                                    0.20807374585786537,
                                    0.46947833811352885,
                                ],
                                [
                                    0.09902256567329376,
                                    0.20807374585786537,
                                    0.22342535035531202,
                                    0.46947833811352885,
                                ],
                                [
                                    0.10605911464511879,
                                    0.23930196805989976,
                                    0.20103719688604035,
                                    0.45360172040894114,
                                ],
                                [
                                    0.12141071914256549,
                                    0.25511743659156744,
                                    0.2010371968860403,
                                    0.4224346473798268,
                                ],
                                [
                                    0.12141071914256549,
                                    0.2010371968860403,
                                    0.25511743659156744,
                                    0.4224346473798268,
                                ],
                                [
                                    0.10605911464511879,
                                    0.20103719688604035,
                                    0.23930196805989976,
                                    0.45360172040894114,
                                ],
                                [
                                    0.13003817153326397,
                                    0.21532291117175456,
                                    0.24648998420086893,
                                    0.40814893309411254,
                                ],
                                [
                                    0.13003817153326397,
                                    0.24648998420086893,
                                    0.21532291117175456,
                                    0.40814893309411254,
                                ],
                                [
                                    0.06501968790795447,
                                    0.2290496936802648,
                                    0.1560835345927835,
                                    0.5498470838189972,
                                ],
                                [
                                    0.06501968790795447,
                                    0.1560835345927835,
                                    0.2290496936802648,
                                    0.5498470838189972,
                                ],
                                [
                                    0.08909921199522483,
                                    0.31387642529982834,
                                    0.13200401050551316,
                                    0.46502035219943366,
                                ],
                                [
                                    0.16206537108270605,
                                    0.3890473296256038,
                                    0.13200401050551322,
                                    0.31688328878617694,
                                ],
                                [
                                    0.16206537108270605,
                                    0.13200401050551322,
                                    0.3890473296256038,
                                    0.31688328878617694,
                                ],
                                [
                                    0.08909921199522483,
                                    0.13200401050551316,
                                    0.31387642529982834,
                                    0.46502035219943366,
                                ],
                                [
                                    0.22208499178932906,
                                    0.1808906455057241,
                                    0.3290277089189808,
                                    0.26799665378596604,
                                ],
                                [
                                    0.22208499178932906,
                                    0.3290277089189808,
                                    0.1808906455057241,
                                    0.26799665378596604,
                                ],
                                [
                                    0.0279936254398259,
                                    0.22904969368026482,
                                    0.08091263026700797,
                                    0.6620440506129013,
                                ],
                                [
                                    0.0279936254398259,
                                    0.08091263026700797,
                                    0.22904969368026482,
                                    0.6620440506129013,
                                ],
                                [
                                    0.052073149527096255,
                                    0.42607339209373246,
                                    0.05683310617973762,
                                    0.46502035219943366,
                                ],
                                [
                                    0.2002102129403531,
                                    0.5786865645589089,
                                    0.05683310617973762,
                                    0.1642701163210004,
                                ],
                                [
                                    0.2002102129403531,
                                    0.05683310617973762,
                                    0.5786865645589089,
                                    0.1642701163210004,
                                ],
                                [
                                    0.052073149527096255,
                                    0.05683310617973762,
                                    0.42607339209373246,
                                    0.46502035219943366,
                                ],
                                [
                                    0.3724268004408802,
                                    0.10571974117994848,
                                    0.4064699770583818,
                                    0.11538348132078954,
                                ],
                                [
                                    0.3724268004408802,
                                    0.4064699770583818,
                                    0.10571974117994848,
                                    0.11538348132078954,
                                ],
                                [
                                    0.0052394343243921185,
                                    0.22342535035531208,
                                    0.017673732352020737,
                                    0.7536614829682751,
                                ],
                                [
                                    0.0052394343243921185,
                                    0.017673732352020737,
                                    0.22342535035531208,
                                    0.7536614829682751,
                                ],
                                [
                                    0.012275983296217173,
                                    0.5234851129146461,
                                    0.010637183380195682,
                                    0.45360172040894103,
                                ],
                                [
                                    0.21802760129950854,
                                    0.7354537211739305,
                                    0.01063718338019566,
                                    0.03588149414636531,
                                ],
                                [
                                    0.21802760129950854,
                                    0.01063718338019566,
                                    0.7354537211739305,
                                    0.03588149414636531,
                                ],
                                [
                                    0.012275983296217173,
                                    0.010637183380195682,
                                    0.5234851129146461,
                                    0.45360172040894103,
                                ],
                                [
                                    0.5108381985449533,
                                    0.02492289766590995,
                                    0.44264312392848576,
                                    0.021595779860651015,
                                ],
                                [
                                    0.5108381985449533,
                                    0.44264312392848576,
                                    0.02492289766590995,
                                    0.021595779860651015,
                                ],
                                [
                                    0.02083370268560097,
                                    0.3016142133430048,
                                    0.043777360527946736,
                                    0.6337747234434474,
                                ],
                                [
                                    0.02083370268560097,
                                    0.043777360527946736,
                                    0.3016142133430048,
                                    0.6337747234434474,
                                ],
                                [
                                    0.02231414674615323,
                                    0.3230469359588653,
                                    0.042296916467394474,
                                    0.6123420008275869,
                                ],
                                [
                                    0.043221856154872694,
                                    0.09082105126164877,
                                    0.2792260598737331,
                                    0.5867310327097455,
                                ],
                                [
                                    0.043221856154872694,
                                    0.2792260598737331,
                                    0.09082105126164877,
                                    0.5867310327097455,
                                ],
                                [
                                    0.02231414674615323,
                                    0.042296916467394474,
                                    0.3230469359588653,
                                    0.6123420008275869,
                                ],
                                [
                                    0.04629320363429842,
                                    0.29906787907072013,
                                    0.08774970378222306,
                                    0.5668892135127584,
                                ],
                                [
                                    0.04629320363429842,
                                    0.08774970378222306,
                                    0.29906787907072013,
                                    0.5668892135127584,
                                ],
                                [
                                    0.013679718732537594,
                                    0.2803896628556817,
                                    0.03283895879402343,
                                    0.6730916596177573,
                                ],
                                [
                                    0.013679718732537594,
                                    0.03283895879402343,
                                    0.2803896628556817,
                                    0.6730916596177573,
                                ],
                                [
                                    0.018745893722388995,
                                    0.38422974357266415,
                                    0.02777278380417203,
                                    0.5692515789007748,
                                ],
                                [
                                    0.11072540190728918,
                                    0.2658027538268437,
                                    0.18334397968093008,
                                    0.440127864584937,
                                ],
                                [
                                    0.11072540190728918,
                                    0.18334397968093008,
                                    0.2658027538268437,
                                    0.440127864584937,
                                ],
                                [
                                    0.018745893722388995,
                                    0.02777278380417203,
                                    0.38422974357266415,
                                    0.5692515789007748,
                                ],
                                [
                                    0.15173167351649322,
                                    0.2512439637785599,
                                    0.22479648221763968,
                                    0.3722278804873072,
                                ],
                                [
                                    0.15173167351649322,
                                    0.22479648221763968,
                                    0.2512439637785599,
                                    0.3722278804873072,
                                ],
                                [
                                    0.005889676414057018,
                                    0.2511536427060337,
                                    0.017023490262355837,
                                    0.7259331906175535,
                                ],
                                [
                                    0.005889676414057018,
                                    0.017023490262355837,
                                    0.2511536427060337,
                                    0.7259331906175535,
                                ],
                                [
                                    0.010955851403908425,
                                    0.4671906902169203,
                                    0.01195731527250443,
                                    0.5098961431066669,
                                ],
                                [
                                    0.17810626391458417,
                                    0.5147974245542567,
                                    0.0789370552055065,
                                    0.22815925632565257,
                                ],
                                [
                                    0.17810626391458417,
                                    0.0789370552055065,
                                    0.5147974245542567,
                                    0.22815925632565257,
                                ],
                                [
                                    0.010955851403908425,
                                    0.01195731527250443,
                                    0.4671906902169203,
                                    0.5098961431066669,
                                ],
                                [
                                    0.33130950231769235,
                                    0.14683703930313632,
                                    0.3615941861511485,
                                    0.16025927222802275,
                                ],
                                [
                                    0.33130950231769235,
                                    0.3615941861511485,
                                    0.14683703930313632,
                                    0.16025927222802275,
                                ],
                                [
                                    0.0011023428469351226,
                                    0.22756244183276908,
                                    0.0037184381424909428,
                                    0.7676167771778049,
                                ],
                                [
                                    0.0011023428469351226,
                                    0.0037184381424909428,
                                    0.22756244183276908,
                                    0.7676167771778049,
                                ],
                                [
                                    0.0025827869074873987,
                                    0.5331783093033758,
                                    0.0022379940819386664,
                                    0.4620009097071981,
                                ],
                                [
                                    0.21389050982205154,
                                    0.7214984269644007,
                                    0.01477427485765265,
                                    0.04983678835589509,
                                ],
                                [
                                    0.21389050982205154,
                                    0.01477427485765265,
                                    0.7214984269644007,
                                    0.04983678835589509,
                                ],
                                [
                                    0.0025827869074873987,
                                    0.0022379940819386664,
                                    0.5331783093033758,
                                    0.4620009097071981,
                                ],
                                [
                                    0.5011450021562235,
                                    0.034616094054639716,
                                    0.43424393463022876,
                                    0.029994969158908022,
                                ],
                                [
                                    0.5011450021562235,
                                    0.43424393463022876,
                                    0.034616094054639716,
                                    0.029994969158908022,
                                ],
                                [
                                    0.05874734383952743,
                                    0.009093596944572869,
                                    0.8072097487439511,
                                    0.12494931047194854,
                                ],
                                [
                                    0.05874734383952743,
                                    0.8072097487439511,
                                    0.009093596944572869,
                                    0.12494931047194854,
                                ],
                                [
                                    0.07858916303651445,
                                    0.012164944423998585,
                                    0.7873679295469641,
                                    0.12187796299252283,
                                ],
                                [
                                    0.06345766547063225,
                                    0.87193127131582,
                                    0.00438327531346805,
                                    0.06022778790007964,
                                ],
                                [
                                    0.06345766547063225,
                                    0.00438327531346805,
                                    0.87193127131582,
                                    0.06022778790007964,
                                ],
                                [
                                    0.07858916303651445,
                                    0.7873679295469641,
                                    0.012164944423998585,
                                    0.12187796299252283,
                                ],
                                [
                                    0.08489038808649274,
                                    0.0058637193740203085,
                                    0.8504985486999596,
                                    0.05874734383952738,
                                ],
                                [
                                    0.08489038808649274,
                                    0.8504985486999596,
                                    0.0058637193740203085,
                                    0.05874734383952738,
                                ],
                                [
                                    0.0385743788387574,
                                    0.02329590318525028,
                                    0.5848974654271099,
                                    0.3532322525488825,
                                ],
                                [
                                    0.0385743788387574,
                                    0.5848974654271099,
                                    0.02329590318525028,
                                    0.3532322525488825,
                                ],
                                [
                                    0.10647436293638725,
                                    0.06430217479445431,
                                    0.51699748132948,
                                    0.31222598093967846,
                                ],
                                [
                                    0.05899215832605549,
                                    0.8944891641473836,
                                    0.0028781236979521932,
                                    0.04364055382860874,
                                ],
                                [
                                    0.05899215832605549,
                                    0.0028781236979521932,
                                    0.8944891641473836,
                                    0.04364055382860874,
                                ],
                                [
                                    0.10647436293638725,
                                    0.51699748132948,
                                    0.06430217479445431,
                                    0.31222598093967846,
                                ],
                                [
                                    0.16283223904303798,
                                    0.007944298687803586,
                                    0.7906490834304011,
                                    0.03857437883875735,
                                ],
                                [
                                    0.16283223904303798,
                                    0.7906490834304011,
                                    0.007944298687803586,
                                    0.03857437883875735,
                                ],
                                [
                                    0.016607842140288313,
                                    0.0374723975652388,
                                    0.2904884693908708,
                                    0.6554312909036021,
                                ],
                                [
                                    0.016607842140288313,
                                    0.2904884693908708,
                                    0.0374723975652388,
                                    0.6554312909036021,
                                ],
                                [
                                    0.08450782623791814,
                                    0.19067563596834697,
                                    0.222588485293241,
                                    0.502228052500494,
                                ],
                                [
                                    0.05284109015925401,
                                    0.9242457431643333,
                                    0.001239149546273099,
                                    0.02167401713013968,
                                ],
                                [
                                    0.05284109015925401,
                                    0.001239149546273099,
                                    0.9242457431643333,
                                    0.02167401713013968,
                                ],
                                [
                                    0.08450782623791814,
                                    0.222588485293241,
                                    0.19067563596834697,
                                    0.502228052500494,
                                ],
                                [
                                    0.2688781376701406,
                                    0.006305324536124489,
                                    0.7082086956534467,
                                    0.01660784214028829,
                                ],
                                [
                                    0.2688781376701406,
                                    0.7082086956534467,
                                    0.006305324536124489,
                                    0.01660784214028829,
                                ],
                                [
                                    0.003108411175642751,
                                    0.045001169769791634,
                                    0.061502652037904955,
                                    0.8903877670166607,
                                ],
                                [
                                    0.003108411175642751,
                                    0.061502652037904955,
                                    0.045001169769791634,
                                    0.8903877670166607,
                                ],
                                [
                                    0.02295023037262981,
                                    0.3322556621039637,
                                    0.04166083284091789,
                                    0.6031332746824886,
                                ],
                                [
                                    0.047877655192203376,
                                    0.9473015638183706,
                                    0.0002319257532310023,
                                    0.004588855236195017,
                                ],
                                [
                                    0.047877655192203376,
                                    0.0002319257532310023,
                                    0.9473015638183706,
                                    0.004588855236195017,
                                ],
                                [
                                    0.02295023037262981,
                                    0.04166083284091789,
                                    0.3322556621039637,
                                    0.6031332746824886,
                                ],
                                [
                                    0.35349352266281026,
                                    0.0017123698137832646,
                                    0.6416856963477637,
                                    0.0031084111756427544,
                                ],
                                [
                                    0.35349352266281026,
                                    0.6416856963477637,
                                    0.0017123698137832646,
                                    0.0031084111756427544,
                                ],
                                [
                                    0.0422969164673945,
                                    0.0255440243167058,
                                    0.5811749277984727,
                                    0.350984131417427,
                                ],
                                [
                                    0.0422969164673945,
                                    0.5811749277984727,
                                    0.0255440243167058,
                                    0.350984131417427,
                                ],
                                [
                                    0.056582630753108765,
                                    0.03417147670740428,
                                    0.5668892135127584,
                                    0.3423566790267285,
                                ],
                                [
                                    0.04700723809849932,
                                    0.6458964503703416,
                                    0.02083370268560098,
                                    0.2862626088455581,
                                ],
                                [
                                    0.04700723809849932,
                                    0.02083370268560098,
                                    0.6458964503703416,
                                    0.2862626088455581,
                                ],
                                [
                                    0.056582630753108765,
                                    0.5668892135127584,
                                    0.03417147670740428,
                                    0.3423566790267285,
                                ],
                                [
                                    0.06288385580308704,
                                    0.027870251657426,
                                    0.6300198326657538,
                                    0.27922605987373306,
                                ],
                                [
                                    0.06288385580308704,
                                    0.6300198326657538,
                                    0.027870251657426,
                                    0.27922605987373306,
                                ],
                                [
                                    0.027772783804172013,
                                    0.03409749821983567,
                                    0.4211145154875181,
                                    0.5170152024884742,
                                ],
                                [
                                    0.027772783804172013,
                                    0.4211145154875181,
                                    0.03409749821983567,
                                    0.5170152024884742,
                                ],
                                [
                                    0.07665941880438289,
                                    0.09411711892645867,
                                    0.37222788048730726,
                                    0.4569955817818512,
                                ],
                                [
                                    0.048190563291470104,
                                    0.7307062142077919,
                                    0.013679718732537583,
                                    0.20742350376820043,
                                ],
                                [
                                    0.048190563291470104,
                                    0.013679718732537583,
                                    0.7307062142077919,
                                    0.20742350376820043,
                                ],
                                [
                                    0.07665941880438289,
                                    0.37222788048730726,
                                    0.09411711892645867,
                                    0.4569955817818512,
                                ],
                                [
                                    0.13301729491103362,
                                    0.03775924281980794,
                                    0.6458794825882284,
                                    0.18334397968093008,
                                ],
                                [
                                    0.13301729491103362,
                                    0.6458794825882284,
                                    0.03775924281980794,
                                    0.18334397968093008,
                                ],
                                [
                                    0.011957315272504406,
                                    0.04212292443302271,
                                    0.2091459072282336,
                                    0.7367738530662393,
                                ],
                                [
                                    0.011957315272504406,
                                    0.2091459072282336,
                                    0.04212292443302271,
                                    0.7367738530662393,
                                ],
                                [
                                    0.06084395027271526,
                                    0.21433951193354986,
                                    0.16025927222802275,
                                    0.5645572655657122,
                                ],
                                [
                                    0.048190563291470104,
                                    0.842903181001696,
                                    0.005889676414057005,
                                    0.10301657929277684,
                                ],
                                [
                                    0.048190563291470104,
                                    0.005889676414057005,
                                    0.842903181001696,
                                    0.10301657929277684,
                                ],
                                [
                                    0.06084395027271526,
                                    0.16025927222802275,
                                    0.21433951193354986,
                                    0.5645572655657122,
                                ],
                                [
                                    0.24521426170493774,
                                    0.029969200501327356,
                                    0.6458794825882284,
                                    0.07893705520550649,
                                ],
                                [
                                    0.24521426170493774,
                                    0.6458794825882284,
                                    0.029969200501327356,
                                    0.07893705520550649,
                                ],
                                [
                                    0.002237994081938647,
                                    0.04587158686349573,
                                    0.044280683444622375,
                                    0.9076097356099433,
                                ],
                                [
                                    0.002237994081938647,
                                    0.044280683444622375,
                                    0.04587158686349573,
                                    0.9076097356099433,
                                ],
                                [
                                    0.01652370836765296,
                                    0.3386821841089405,
                                    0.029994969158908064,
                                    0.6147991383644984,
                                ],
                                [
                                    0.04700723809849927,
                                    0.930079595225088,
                                    0.001102342846935111,
                                    0.021810823829477684,
                                ],
                                [
                                    0.04700723809849927,
                                    0.001102342846935111,
                                    0.930079595225088,
                                    0.021810823829477684,
                                ],
                                [
                                    0.01652370836765296,
                                    0.029994969158908064,
                                    0.3386821841089405,
                                    0.6147991383644984,
                                ],
                                [
                                    0.34706700065783336,
                                    0.008138891818760149,
                                    0.6300198326657539,
                                    0.014774274857652647,
                                ],
                                [
                                    0.34706700065783336,
                                    0.6300198326657539,
                                    0.008138891818760149,
                                    0.014774274857652647,
                                ],
                                [
                                    0.020833702685600985,
                                    0.04700723809849932,
                                    0.28626260884555815,
                                    0.6458964503703416,
                                ],
                                [
                                    0.020833702685600985,
                                    0.28626260884555815,
                                    0.04700723809849932,
                                    0.6458964503703416,
                                ],
                                [
                                    0.027870251657426008,
                                    0.06288385580308704,
                                    0.2792260598737331,
                                    0.6300198326657538,
                                ],
                                [
                                    0.025544024316705806,
                                    0.35098413141742707,
                                    0.042296916467394495,
                                    0.5811749277984726,
                                ],
                                [
                                    0.025544024316705806,
                                    0.042296916467394495,
                                    0.35098413141742707,
                                    0.5811749277984726,
                                ],
                                [
                                    0.027870251657426008,
                                    0.2792260598737331,
                                    0.06288385580308704,
                                    0.6300198326657538,
                                ],
                                [
                                    0.03417147670740429,
                                    0.05658263075310876,
                                    0.3423566790267286,
                                    0.5668892135127583,
                                ],
                                [
                                    0.03417147670740429,
                                    0.3423566790267286,
                                    0.05658263075310876,
                                    0.5668892135127583,
                                ],
                                [
                                    0.013679718732537581,
                                    0.048190563291470104,
                                    0.2074235037682004,
                                    0.7307062142077919,
                                ],
                                [
                                    0.013679718732537581,
                                    0.2074235037682004,
                                    0.048190563291470104,
                                    0.7307062142077919,
                                ],
                                [
                                    0.03775924281980794,
                                    0.13301729491103362,
                                    0.18334397968093005,
                                    0.6458794825882284,
                                ],
                                [
                                    0.03409749821983567,
                                    0.5170152024884742,
                                    0.027772783804172013,
                                    0.4211145154875181,
                                ],
                                [
                                    0.03409749821983567,
                                    0.027772783804172013,
                                    0.5170152024884742,
                                    0.4211145154875181,
                                ],
                                [
                                    0.03775924281980794,
                                    0.18334397968093005,
                                    0.13301729491103362,
                                    0.6458794825882284,
                                ],
                                [
                                    0.09411711892645867,
                                    0.07665941880438289,
                                    0.4569955817818512,
                                    0.37222788048730726,
                                ],
                                [
                                    0.09411711892645867,
                                    0.4569955817818512,
                                    0.07665941880438289,
                                    0.37222788048730726,
                                ],
                                [
                                    0.005889676414057006,
                                    0.048190563291470104,
                                    0.10301657929277687,
                                    0.842903181001696,
                                ],
                                [
                                    0.005889676414057006,
                                    0.10301657929277687,
                                    0.048190563291470104,
                                    0.842903181001696,
                                ],
                                [
                                    0.029969200501327363,
                                    0.24521426170493774,
                                    0.0789370552055065,
                                    0.6458794825882284,
                                ],
                                [
                                    0.04212292443302271,
                                    0.7367738530662393,
                                    0.011957315272504408,
                                    0.20914590722823362,
                                ],
                                [
                                    0.04212292443302271,
                                    0.011957315272504408,
                                    0.7367738530662393,
                                    0.20914590722823362,
                                ],
                                [
                                    0.029969200501327363,
                                    0.0789370552055065,
                                    0.24521426170493774,
                                    0.6458794825882284,
                                ],
                                [
                                    0.21433951193354986,
                                    0.06084395027271527,
                                    0.5645572655657122,
                                    0.16025927222802275,
                                ],
                                [
                                    0.21433951193354986,
                                    0.5645572655657122,
                                    0.06084395027271527,
                                    0.16025927222802275,
                                ],
                                [
                                    0.001102342846935114,
                                    0.04700723809849927,
                                    0.02181082382947774,
                                    0.9300795952250879,
                                ],
                                [
                                    0.001102342846935114,
                                    0.02181082382947774,
                                    0.04700723809849927,
                                    0.9300795952250879,
                                ],
                                [
                                    0.00813889181876017,
                                    0.34706700065783336,
                                    0.014774274857652685,
                                    0.6300198326657538,
                                ],
                                [
                                    0.04587158686349574,
                                    0.9076097356099433,
                                    0.0022379940819386443,
                                    0.044280683444622326,
                                ],
                                [
                                    0.04587158686349574,
                                    0.0022379940819386443,
                                    0.9076097356099433,
                                    0.044280683444622326,
                                ],
                                [
                                    0.00813889181876017,
                                    0.014774274857652685,
                                    0.34706700065783336,
                                    0.6300198326657538,
                                ],
                                [
                                    0.3386821841089406,
                                    0.016523708367652944,
                                    0.6147991383644985,
                                    0.029994969158908025,
                                ],
                                [
                                    0.3386821841089406,
                                    0.6147991383644985,
                                    0.016523708367652944,
                                    0.029994969158908025,
                                ],
                                [
                                    0.004383275313468051,
                                    0.06345766547063225,
                                    0.060227787900079655,
                                    0.87193127131582,
                                ],
                                [
                                    0.004383275313468051,
                                    0.060227787900079655,
                                    0.06345766547063225,
                                    0.87193127131582,
                                ],
                                [
                                    0.005863719374020309,
                                    0.08489038808649274,
                                    0.05874734383952739,
                                    0.8504985486999596,
                                ],
                                [
                                    0.009093596944572872,
                                    0.1249493104719486,
                                    0.05874734383952743,
                                    0.8072097487439511,
                                ],
                                [
                                    0.009093596944572872,
                                    0.05874734383952743,
                                    0.1249493104719486,
                                    0.8072097487439511,
                                ],
                                [
                                    0.005863719374020309,
                                    0.05874734383952739,
                                    0.08489038808649274,
                                    0.8504985486999596,
                                ],
                                [
                                    0.01216494442399859,
                                    0.07858916303651445,
                                    0.12187796299252288,
                                    0.7873679295469641,
                                ],
                                [
                                    0.01216494442399859,
                                    0.12187796299252288,
                                    0.07858916303651445,
                                    0.7873679295469641,
                                ],
                                [
                                    0.002878123697952199,
                                    0.058992158326055484,
                                    0.043640553828608826,
                                    0.8944891641473834,
                                ],
                                [
                                    0.002878123697952199,
                                    0.043640553828608826,
                                    0.058992158326055484,
                                    0.8944891641473834,
                                ],
                                [
                                    0.0079442986878036,
                                    0.16283223904303795,
                                    0.038574378838757424,
                                    0.790649083430401,
                                ],
                                [
                                    0.023295903185250287,
                                    0.35323225254888263,
                                    0.038574378838757396,
                                    0.5848974654271097,
                                ],
                                [
                                    0.023295903185250287,
                                    0.038574378838757396,
                                    0.35323225254888263,
                                    0.5848974654271097,
                                ],
                                [
                                    0.0079442986878036,
                                    0.038574378838757424,
                                    0.16283223904303795,
                                    0.790649083430401,
                                ],
                                [
                                    0.06430217479445434,
                                    0.10647436293638722,
                                    0.31222598093967857,
                                    0.5169974813294799,
                                ],
                                [
                                    0.06430217479445434,
                                    0.31222598093967857,
                                    0.10647436293638722,
                                    0.5169974813294799,
                                ],
                                [
                                    0.001239149546273103,
                                    0.052841090159254006,
                                    0.021674017130139753,
                                    0.9242457431643332,
                                ],
                                [
                                    0.001239149546273103,
                                    0.021674017130139753,
                                    0.052841090159254006,
                                    0.9242457431643332,
                                ],
                                [
                                    0.0063053245361245095,
                                    0.26887813767014057,
                                    0.016607842140288345,
                                    0.7082086956534466,
                                ],
                                [
                                    0.0374723975652388,
                                    0.6554312909036021,
                                    0.016607842140288313,
                                    0.29048846939087075,
                                ],
                                [
                                    0.0374723975652388,
                                    0.016607842140288313,
                                    0.6554312909036021,
                                    0.29048846939087075,
                                ],
                                [
                                    0.0063053245361245095,
                                    0.016607842140288345,
                                    0.26887813767014057,
                                    0.7082086956534466,
                                ],
                                [
                                    0.19067563596834697,
                                    0.08450782623791812,
                                    0.502228052500494,
                                    0.22258848529324093,
                                ],
                                [
                                    0.19067563596834697,
                                    0.502228052500494,
                                    0.08450782623791812,
                                    0.22258848529324093,
                                ],
                                [
                                    0.00023192575323100455,
                                    0.047877655192203376,
                                    0.004588855236195061,
                                    0.9473015638183706,
                                ],
                                [
                                    0.00023192575323100455,
                                    0.004588855236195061,
                                    0.047877655192203376,
                                    0.9473015638183706,
                                ],
                                [
                                    0.001712369813783281,
                                    0.35349352266281026,
                                    0.0031084111756427843,
                                    0.6416856963477637,
                                ],
                                [
                                    0.045001169769791634,
                                    0.8903877670166607,
                                    0.003108411175642753,
                                    0.06150265203790499,
                                ],
                                [
                                    0.045001169769791634,
                                    0.003108411175642753,
                                    0.8903877670166607,
                                    0.06150265203790499,
                                ],
                                [
                                    0.001712369813783281,
                                    0.0031084111756427843,
                                    0.35349352266281026,
                                    0.6416856963477637,
                                ],
                                [
                                    0.3322556621039637,
                                    0.02295023037262983,
                                    0.6031332746824886,
                                    0.04166083284091792,
                                ],
                                [
                                    0.3322556621039637,
                                    0.6031332746824886,
                                    0.02295023037262983,
                                    0.04166083284091792,
                                ],
                                [
                                    0.7683458512934296,
                                    0.11893350454758833,
                                    0.09761124129004899,
                                    0.015109402868933091,
                                ],
                                [
                                    0.7683458512934296,
                                    0.09761124129004899,
                                    0.11893350454758833,
                                    0.015109402868933091,
                                ],
                                [
                                    0.8086290300351586,
                                    0.12516900333242015,
                                    0.05732806254831988,
                                    0.00887390408410127,
                                ],
                                [
                                    0.829951293292698,
                                    0.10543764349375427,
                                    0.05732806254831988,
                                    0.007283000665227806,
                                ],
                                [
                                    0.829951293292698,
                                    0.05732806254831988,
                                    0.10543764349375427,
                                    0.007283000665227806,
                                ],
                                [
                                    0.8086290300351586,
                                    0.05732806254831988,
                                    0.12516900333242015,
                                    0.00887390408410127,
                                ],
                                [
                                    0.8734643496049797,
                                    0.06033368376259915,
                                    0.06192458718147262,
                                    0.0042773794509485385,
                                ],
                                [
                                    0.8734643496049797,
                                    0.06192458718147262,
                                    0.06033368376259915,
                                    0.0042773794509485385,
                                ],
                                [
                                    0.4519027035726606,
                                    0.2729138342210744,
                                    0.17156914069320664,
                                    0.10361432151305841,
                                ],
                                [
                                    0.4519027035726606,
                                    0.17156914069320664,
                                    0.2729138342210744,
                                    0.10361432151305841,
                                ],
                                [
                                    0.5897543374783221,
                                    0.3561654228161509,
                                    0.03371750678754513,
                                    0.020362732917981918,
                                ],
                                [
                                    0.6910990310061899,
                                    0.26238229146724923,
                                    0.03371750678754513,
                                    0.012801170739015813,
                                ],
                                [
                                    0.6910990310061899,
                                    0.03371750678754513,
                                    0.26238229146724923,
                                    0.012801170739015813,
                                ],
                                [
                                    0.5897543374783221,
                                    0.03371750678754513,
                                    0.3561654228161509,
                                    0.020362732917981918,
                                ],
                                [
                                    0.9019168239993326,
                                    0.044002936295140405,
                                    0.05156449847410651,
                                    0.002515741231420529,
                                ],
                                [
                                    0.9019168239993326,
                                    0.05156449847410651,
                                    0.044002936295140405,
                                    0.002515741231420529,
                                ],
                                [
                                    0.1574937075364215,
                                    0.35535422199802885,
                                    0.1496026039947376,
                                    0.33754946647081197,
                                ],
                                [
                                    0.1574937075364215,
                                    0.1496026039947376,
                                    0.35535422199802885,
                                    0.33754946647081197,
                                ],
                                [
                                    0.2953453414420831,
                                    0.6663898873840575,
                                    0.01175097008907606,
                                    0.026513801084783392,
                                ],
                                [
                                    0.5010969594453744,
                                    0.4759898738782129,
                                    0.011750970089076057,
                                    0.01116219658733672,
                                ],
                                [
                                    0.5010969594453744,
                                    0.011750970089076057,
                                    0.4759898738782129,
                                    0.01116219658733672,
                                ],
                                [
                                    0.2953453414420831,
                                    0.01175097008907606,
                                    0.6663898873840575,
                                    0.026513801084783392,
                                ],
                                [
                                    0.9396988292294692,
                                    0.022036399596671342,
                                    0.037388004094118014,
                                    0.0008767670797414366,
                                ],
                                [
                                    0.9396988292294692,
                                    0.037388004094118014,
                                    0.022036399596671342,
                                    0.0008767670797414366,
                                ],
                                [
                                    0.022638754587383344,
                                    0.3277463568997842,
                                    0.04197230862616436,
                                    0.607642579886668,
                                ],
                                [
                                    0.022638754587383344,
                                    0.04197230862616436,
                                    0.3277463568997842,
                                    0.607642579886668,
                                ],
                                [
                                    0.06292193332911244,
                                    0.9109350224239222,
                                    0.001689129884435252,
                                    0.024453914362530086,
                                ],
                                [
                                    0.3486959816027323,
                                    0.6464832374078416,
                                    0.0016891298844352535,
                                    0.0031316511049907653,
                                ],
                                [
                                    0.3486959816027323,
                                    0.0016891298844352535,
                                    0.6464832374078416,
                                    0.0031316511049907653,
                                ],
                                [
                                    0.06292193332911244,
                                    0.001689129884435252,
                                    0.9109350224239222,
                                    0.024453914362530086,
                                ],
                                [
                                    0.9691622046543201,
                                    0.004694751098714525,
                                    0.026017014356253844,
                                    0.00012602989071149376,
                                ],
                                [
                                    0.9691622046543201,
                                    0.026017014356253844,
                                    0.004694751098714525,
                                    0.00012602989071149376,
                                ],
                                [
                                    0.5531936963652301,
                                    0.33408565947578783,
                                    0.07027814790063712,
                                    0.042442496258344974,
                                ],
                                [
                                    0.5531936963652301,
                                    0.07027814790063712,
                                    0.33408565947578783,
                                    0.042442496258344974,
                                ],
                                [
                                    0.5821967820355242,
                                    0.35160125133205467,
                                    0.041275062230343024,
                                    0.024926904402078134,
                                ],
                                [
                                    0.6147991383644985,
                                    0.07810455010434239,
                                    0.2724802174765194,
                                    0.03461609405463969,
                                ],
                                [
                                    0.6147991383644985,
                                    0.2724802174765194,
                                    0.07810455010434239,
                                    0.03461609405463969,
                                ],
                                [
                                    0.5821967820355242,
                                    0.041275062230343024,
                                    0.35160125133205467,
                                    0.024926904402078134,
                                ],
                                [
                                    0.6470321016053451,
                                    0.28676593176223364,
                                    0.045871586863495746,
                                    0.020330379768925405,
                                ],
                                [
                                    0.6470321016053451,
                                    0.045871586863495746,
                                    0.28676593176223364,
                                    0.020330379768925405,
                                ],
                                [
                                    0.325360938132183,
                                    0.39945559966155203,
                                    0.1235263611595072,
                                    0.15165710104675786,
                                ],
                                [
                                    0.325360938132183,
                                    0.1235263611595072,
                                    0.39945559966155203,
                                    0.15165710104675786,
                                ],
                                [
                                    0.4246113665452289,
                                    0.5213083937492441,
                                    0.02427593274646126,
                                    0.02980430695906578,
                                ],
                                [
                                    0.5645572655657123,
                                    0.2143395119335498,
                                    0.16025927222802278,
                                    0.060843950272715254,
                                ],
                                [
                                    0.5645572655657123,
                                    0.16025927222802278,
                                    0.2143395119335498,
                                    0.060843950272715254,
                                ],
                                [
                                    0.4246113665452289,
                                    0.02427593274646126,
                                    0.5213083937492441,
                                    0.02980430695906578,
                                ],
                                [
                                    0.7367738530662394,
                                    0.20914590722823365,
                                    0.04212292443302265,
                                    0.011957315272504392,
                                ],
                                [
                                    0.7367738530662394,
                                    0.04212292443302265,
                                    0.20914590722823365,
                                    0.011957315272504392,
                                ],
                                [
                                    0.11339232987289838,
                                    0.399455599661552,
                                    0.1077108926278396,
                                    0.37944117783771,
                                ],
                                [
                                    0.11339232987289838,
                                    0.1077108926278396,
                                    0.399455599661552,
                                    0.37944117783771,
                                ],
                                [
                                    0.21264275828594434,
                                    0.7490924705401962,
                                    0.008460464214793672,
                                    0.02980430695906578,
                                ],
                                [
                                    0.4569955817818512,
                                    0.4340981625113149,
                                    0.05585234775259916,
                                    0.05305390795423469,
                                ],
                                [
                                    0.4569955817818512,
                                    0.05585234775259916,
                                    0.4340981625113149,
                                    0.05305390795423469,
                                ],
                                [
                                    0.21264275828594434,
                                    0.008460464214793672,
                                    0.7490924705401962,
                                    0.02980430695906578,
                                ],
                                [
                                    0.8569962460733306,
                                    0.10473898275281003,
                                    0.034097498219835626,
                                    0.004167272954023822,
                                ],
                                [
                                    0.8569962460733306,
                                    0.034097498219835626,
                                    0.10473898275281003,
                                    0.004167272954023822,
                                ],
                                [
                                    0.01629945201137968,
                                    0.3340856594757879,
                                    0.030219225515181344,
                                    0.6193956629976511,
                                ],
                                [
                                    0.01629945201137968,
                                    0.030219225515181344,
                                    0.3340856594757879,
                                    0.6193956629976511,
                                ],
                                [
                                    0.045302537681673825,
                                    0.9285544180713609,
                                    0.0012161398448871969,
                                    0.02492690440207814,
                                ],
                                [
                                    0.3423566790267286,
                                    0.6347301542968586,
                                    0.00802843246043895,
                                    0.014884734215973847,
                                ],
                                [
                                    0.3423566790267286,
                                    0.00802843246043895,
                                    0.6347301542968586,
                                    0.014884734215973847,
                                ],
                                [
                                    0.045302537681673825,
                                    0.0012161398448871969,
                                    0.9285544180713609,
                                    0.02492690440207814,
                                ],
                                [
                                    0.9515428090068815,
                                    0.022314146746153243,
                                    0.02554402431670579,
                                    0.0005990199302595515,
                                ],
                                [
                                    0.9515428090068815,
                                    0.02554402431670579,
                                    0.022314146746153243,
                                    0.0005990199302595515,
                                ],
                                [
                                    0.27248021747651946,
                                    0.6147991383644985,
                                    0.034616094054639696,
                                    0.07810455010434239,
                                ],
                                [
                                    0.27248021747651946,
                                    0.034616094054639696,
                                    0.6147991383644985,
                                    0.07810455010434239,
                                ],
                                [
                                    0.2867659317622337,
                                    0.6470321016053451,
                                    0.02033037976892541,
                                    0.045871586863495746,
                                ],
                                [
                                    0.3340856594757879,
                                    0.04244249625834499,
                                    0.55319369636523,
                                    0.0702781479006371,
                                ],
                                [
                                    0.3340856594757879,
                                    0.55319369636523,
                                    0.04244249625834499,
                                    0.0702781479006371,
                                ],
                                [
                                    0.2867659317622337,
                                    0.02033037976892541,
                                    0.6470321016053451,
                                    0.045871586863495746,
                                ],
                                [
                                    0.3516012513320547,
                                    0.582196782035524,
                                    0.024926904402078145,
                                    0.04127506223034302,
                                ],
                                [
                                    0.3516012513320547,
                                    0.024926904402078145,
                                    0.582196782035524,
                                    0.04127506223034302,
                                ],
                                [
                                    0.16025927222802275,
                                    0.5645572655657123,
                                    0.06084395027271525,
                                    0.2143395119335498,
                                ],
                                [
                                    0.16025927222802275,
                                    0.06084395027271525,
                                    0.5645572655657123,
                                    0.2143395119335498,
                                ],
                                [
                                    0.20914590722823362,
                                    0.7367738530662394,
                                    0.01195731527250439,
                                    0.04212292443302265,
                                ],
                                [
                                    0.39945559966155203,
                                    0.15165710104675786,
                                    0.325360938132183,
                                    0.1235263611595072,
                                ],
                                [
                                    0.39945559966155203,
                                    0.325360938132183,
                                    0.15165710104675786,
                                    0.1235263611595072,
                                ],
                                [
                                    0.20914590722823362,
                                    0.01195731527250439,
                                    0.7367738530662394,
                                    0.04212292443302265,
                                ],
                                [
                                    0.5213083937492441,
                                    0.4246113665452289,
                                    0.02980430695906578,
                                    0.02427593274646126,
                                ],
                                [
                                    0.5213083937492441,
                                    0.02980430695906578,
                                    0.4246113665452289,
                                    0.02427593274646126,
                                ],
                                [
                                    0.055852347752599174,
                                    0.4569955817818512,
                                    0.053053907954234696,
                                    0.4340981625113149,
                                ],
                                [
                                    0.055852347752599174,
                                    0.053053907954234696,
                                    0.4569955817818512,
                                    0.4340981625113149,
                                ],
                                [
                                    0.10473898275281006,
                                    0.8569962460733306,
                                    0.004167272954023823,
                                    0.034097498219835626,
                                ],
                                [
                                    0.399455599661552,
                                    0.37944117783771,
                                    0.11339232987289839,
                                    0.10771089262783962,
                                ],
                                [
                                    0.399455599661552,
                                    0.11339232987289839,
                                    0.37944117783771,
                                    0.10771089262783962,
                                ],
                                [
                                    0.10473898275281006,
                                    0.004167272954023823,
                                    0.8569962460733306,
                                    0.034097498219835626,
                                ],
                                [
                                    0.7490924705401962,
                                    0.21264275828594437,
                                    0.02980430695906578,
                                    0.008460464214793673,
                                ],
                                [
                                    0.7490924705401962,
                                    0.02980430695906578,
                                    0.21264275828594437,
                                    0.008460464214793673,
                                ],
                                [
                                    0.00802843246043897,
                                    0.34235667902672856,
                                    0.014884734215973885,
                                    0.6347301542968585,
                                ],
                                [
                                    0.00802843246043897,
                                    0.014884734215973885,
                                    0.34235667902672856,
                                    0.6347301542968585,
                                ],
                                [
                                    0.022314146746153302,
                                    0.9515428090068814,
                                    0.000599019930259553,
                                    0.025544024316705785,
                                ],
                                [
                                    0.3340856594757879,
                                    0.6193956629976511,
                                    0.01629945201137966,
                                    0.03021922551518131,
                                ],
                                [
                                    0.3340856594757879,
                                    0.01629945201137966,
                                    0.6193956629976511,
                                    0.03021922551518131,
                                ],
                                [
                                    0.022314146746153302,
                                    0.000599019930259553,
                                    0.9515428090068814,
                                    0.025544024316705785,
                                ],
                                [
                                    0.928554418071361,
                                    0.04530253768167378,
                                    0.024926904402078145,
                                    0.0012161398448871956,
                                ],
                                [
                                    0.928554418071361,
                                    0.024926904402078145,
                                    0.04530253768167378,
                                    0.0012161398448871956,
                                ],
                                [
                                    0.057328062548319896,
                                    0.829951293292698,
                                    0.007283000665227808,
                                    0.10543764349375427,
                                ],
                                [
                                    0.057328062548319896,
                                    0.007283000665227808,
                                    0.829951293292698,
                                    0.10543764349375427,
                                ],
                                [
                                    0.06033368376259916,
                                    0.8734643496049797,
                                    0.004277379450948539,
                                    0.06192458718147262,
                                ],
                                [
                                    0.11893350454758837,
                                    0.015109402868933098,
                                    0.7683458512934296,
                                    0.09761124129004899,
                                ],
                                [
                                    0.11893350454758837,
                                    0.7683458512934296,
                                    0.015109402868933098,
                                    0.09761124129004899,
                                ],
                                [
                                    0.06033368376259916,
                                    0.004277379450948539,
                                    0.8734643496049797,
                                    0.06192458718147262,
                                ],
                                [
                                    0.1251690033324202,
                                    0.8086290300351586,
                                    0.008873904084101273,
                                    0.05732806254831988,
                                ],
                                [
                                    0.1251690033324202,
                                    0.008873904084101273,
                                    0.8086290300351586,
                                    0.05732806254831988,
                                ],
                                [
                                    0.03371750678754519,
                                    0.6910990310061899,
                                    0.012801170739015837,
                                    0.26238229146724923,
                                ],
                                [
                                    0.03371750678754519,
                                    0.012801170739015837,
                                    0.6910990310061899,
                                    0.26238229146724923,
                                ],
                                [
                                    0.044002936295140495,
                                    0.9019168239993325,
                                    0.002515741231420534,
                                    0.051564498474106504,
                                ],
                                [
                                    0.27291383422107446,
                                    0.10361432151305844,
                                    0.45190270357266055,
                                    0.1715691406932066,
                                ],
                                [
                                    0.27291383422107446,
                                    0.45190270357266055,
                                    0.10361432151305844,
                                    0.1715691406932066,
                                ],
                                [
                                    0.044002936295140495,
                                    0.002515741231420534,
                                    0.9019168239993325,
                                    0.051564498474106504,
                                ],
                                [
                                    0.356165422816151,
                                    0.5897543374783221,
                                    0.020362732917981925,
                                    0.03371750678754512,
                                ],
                                [
                                    0.356165422816151,
                                    0.020362732917981925,
                                    0.5897543374783221,
                                    0.03371750678754512,
                                ],
                                [
                                    0.011750970089076097,
                                    0.5010969594453742,
                                    0.011162196587336758,
                                    0.47598987387821284,
                                ],
                                [
                                    0.011750970089076097,
                                    0.011162196587336758,
                                    0.5010969594453742,
                                    0.47598987387821284,
                                ],
                                [
                                    0.022036399596671415,
                                    0.9396988292294692,
                                    0.0008767670797414396,
                                    0.037388004094118014,
                                ],
                                [
                                    0.35535422199802885,
                                    0.33754946647081197,
                                    0.15749370753642147,
                                    0.14960260399473757,
                                ],
                                [
                                    0.35535422199802885,
                                    0.15749370753642147,
                                    0.33754946647081197,
                                    0.14960260399473757,
                                ],
                                [
                                    0.022036399596671415,
                                    0.0008767670797414396,
                                    0.9396988292294692,
                                    0.037388004094118014,
                                ],
                                [
                                    0.6663898873840575,
                                    0.295345341442083,
                                    0.026513801084783392,
                                    0.011750970089076057,
                                ],
                                [
                                    0.6663898873840575,
                                    0.026513801084783392,
                                    0.295345341442083,
                                    0.011750970089076057,
                                ],
                                [
                                    0.00168912988443527,
                                    0.3486959816027323,
                                    0.0031316511049907956,
                                    0.6464832374078416,
                                ],
                                [
                                    0.00168912988443527,
                                    0.0031316511049907956,
                                    0.3486959816027323,
                                    0.6464832374078416,
                                ],
                                [
                                    0.004694751098714571,
                                    0.9691622046543201,
                                    0.00012602989071149498,
                                    0.026017014356253844,
                                ],
                                [
                                    0.3277463568997842,
                                    0.607642579886668,
                                    0.022638754587383358,
                                    0.04197230862616439,
                                ],
                                [
                                    0.3277463568997842,
                                    0.022638754587383358,
                                    0.607642579886668,
                                    0.04197230862616439,
                                ],
                                [
                                    0.004694751098714571,
                                    0.00012602989071149498,
                                    0.9691622046543201,
                                    0.026017014356253844,
                                ],
                                [
                                    0.9109350224239222,
                                    0.06292193332911249,
                                    0.024453914362530086,
                                    0.001689129884435253,
                                ],
                                [
                                    0.9109350224239222,
                                    0.024453914362530086,
                                    0.06292193332911249,
                                    0.001689129884435253,
                                ],
                                [
                                    0.5531936963652301,
                                    0.08562975239808379,
                                    0.3127633962182485,
                                    0.048413155018437626,
                                ],
                                [
                                    0.5531936963652301,
                                    0.3127633962182485,
                                    0.08562975239808379,
                                    0.048413155018437626,
                                ],
                                [
                                    0.5934768751069591,
                                    0.09186525118291561,
                                    0.2724802174765194,
                                    0.0421776562336058,
                                ],
                                [
                                    0.5975483865329708,
                                    0.3378405502534815,
                                    0.04127506223034302,
                                    0.023336000983204673,
                                ],
                                [
                                    0.5975483865329708,
                                    0.04127506223034302,
                                    0.3378405502534815,
                                    0.023336000983204673,
                                ],
                                [
                                    0.5934768751069591,
                                    0.2724802174765194,
                                    0.09186525118291561,
                                    0.0421776562336058,
                                ],
                                [
                                    0.6410614428452525,
                                    0.044280683444622285,
                                    0.2943274939411998,
                                    0.020330379768925405,
                                ],
                                [
                                    0.6410614428452525,
                                    0.2943274939411998,
                                    0.044280683444622285,
                                    0.020330379768925405,
                                ],
                                [
                                    0.3253609381321829,
                                    0.1964925202469884,
                                    0.2981109061336843,
                                    0.18003563548714438,
                                ],
                                [
                                    0.3253609381321829,
                                    0.2981109061336843,
                                    0.1964925202469884,
                                    0.18003563548714438,
                                ],
                                [
                                    0.46321257203784444,
                                    0.27974410884206485,
                                    0.16025927222802278,
                                    0.09678404689206789,
                                ],
                                [
                                    0.49757752563271007,
                                    0.455903796840729,
                                    0.024275932746461257,
                                    0.022242744780099678,
                                ],
                                [
                                    0.49757752563271007,
                                    0.024275932746461257,
                                    0.455903796840729,
                                    0.022242744780099678,
                                ],
                                [
                                    0.46321257203784444,
                                    0.16025927222802278,
                                    0.27974410884206485,
                                    0.09678404689206789,
                                ],
                                [
                                    0.7083953186258528,
                                    0.03456136225405654,
                                    0.24508600384758628,
                                    0.011957315272504392,
                                ],
                                [
                                    0.7083953186258528,
                                    0.24508600384758628,
                                    0.03456136225405654,
                                    0.011957315272504392,
                                ],
                                [
                                    0.11339232987289842,
                                    0.2558479560410964,
                                    0.1937039816582607,
                                    0.4370557324277445,
                                ],
                                [
                                    0.11339232987289842,
                                    0.1937039816582607,
                                    0.2558479560410964,
                                    0.4370557324277445,
                                ],
                                [
                                    0.25124396377855995,
                                    0.566883621427125,
                                    0.055852347752599174,
                                    0.1260200670417159,
                                ],
                                [
                                    0.36077982169920114,
                                    0.6163070116243861,
                                    0.008460464214793673,
                                    0.014452702461619105,
                                ],
                                [
                                    0.36077982169920114,
                                    0.008460464214793673,
                                    0.6163070116243861,
                                    0.014452702461619105,
                                ],
                                [
                                    0.25124396377855995,
                                    0.055852347752599174,
                                    0.566883621427125,
                                    0.1260200670417159,
                                ],
                                [
                                    0.7993816914832961,
                                    0.018745893722388957,
                                    0.17770514184029126,
                                    0.004167272954023822,
                                ],
                                [
                                    0.7993816914832961,
                                    0.17770514184029126,
                                    0.018745893722388957,
                                    0.004167272954023822,
                                ],
                                [
                                    0.016299452011379653,
                                    0.23597084351847272,
                                    0.04831161120216805,
                                    0.6994180932679795,
                                ],
                                [
                                    0.016299452011379653,
                                    0.04831161120216805,
                                    0.23597084351847272,
                                    0.6994180932679795,
                                ],
                                [
                                    0.05658263075310876,
                                    0.8191595090426107,
                                    0.008028432460438944,
                                    0.11622942774384162,
                                ],
                                [
                                    0.25105415568496514,
                                    0.7441250633256088,
                                    0.0012161398448871958,
                                    0.0036046411445388228,
                                ],
                                [
                                    0.25105415568496514,
                                    0.0012161398448871958,
                                    0.7441250633256088,
                                    0.0036046411445388228,
                                ],
                                [
                                    0.05658263075310876,
                                    0.008028432460438944,
                                    0.8191595090426107,
                                    0.11622942774384162,
                                ],
                                [
                                    0.871520378736553,
                                    0.004221761059166467,
                                    0.123658840274021,
                                    0.0005990199302595516,
                                ],
                                [
                                    0.871520378736553,
                                    0.123658840274021,
                                    0.004221761059166467,
                                    0.0005990199302595516,
                                ],
                                [
                                    0.398288433760745,
                                    0.24053501500256885,
                                    0.2251834105051222,
                                    0.13599314073156393,
                                ],
                                [
                                    0.398288433760745,
                                    0.2251834105051222,
                                    0.24053501500256885,
                                    0.13599314073156393,
                                ],
                                [
                                    0.4272915194310391,
                                    0.2580506068588357,
                                    0.1961803248348281,
                                    0.11847754887529711,
                                ],
                                [
                                    0.44264312392848576,
                                    0.2502605645403551,
                                    0.19618032483482808,
                                    0.110915986696331,
                                ],
                                [
                                    0.44264312392848576,
                                    0.19618032483482808,
                                    0.2502605645403551,
                                    0.110915986696331,
                                ],
                                [
                                    0.4272915194310391,
                                    0.1961803248348281,
                                    0.2580506068588357,
                                    0.11847754887529711,
                                ],
                                [
                                    0.4748760871693324,
                                    0.21046603912054235,
                                    0.2180276012995085,
                                    0.09663027241061672,
                                ],
                                [
                                    0.4748760871693324,
                                    0.2180276012995085,
                                    0.21046603912054235,
                                    0.09663027241061672,
                                ],
                                [
                                    0.23425338955785463,
                                    0.28760006882131667,
                                    0.2146339097338355,
                                    0.2635126318869932,
                                ],
                                [
                                    0.23425338955785463,
                                    0.2146339097338355,
                                    0.28760006882131667,
                                    0.2635126318869932,
                                ],
                                [
                                    0.33350381797090056,
                                    0.40945286290900873,
                                    0.11538348132078954,
                                    0.1416598377993011,
                                ],
                                [
                                    0.4064699770583818,
                                    0.3724268004408802,
                                    0.11538348132078954,
                                    0.10571974117994848,
                                ],
                                [
                                    0.4064699770583818,
                                    0.11538348132078954,
                                    0.3724268004408802,
                                    0.10571974117994848,
                                ],
                                [
                                    0.33350381797090056,
                                    0.11538348132078954,
                                    0.40945286290900873,
                                    0.1416598377993011,
                                ],
                                [
                                    0.5786865645589089,
                                    0.1642701163210004,
                                    0.20021021294035304,
                                    0.05683310617973761,
                                ],
                                [
                                    0.5786865645589089,
                                    0.20021021294035304,
                                    0.1642701163210004,
                                    0.05683310617973761,
                                ],
                                [
                                    0.08164021709267812,
                                    0.2876000688213167,
                                    0.1394630054080599,
                                    0.4912967086779453,
                                ],
                                [
                                    0.08164021709267812,
                                    0.1394630054080599,
                                    0.2876000688213167,
                                    0.4912967086779453,
                                ],
                                [
                                    0.18089064550572403,
                                    0.6372369396999609,
                                    0.04021257699501396,
                                    0.1416598377993011,
                                ],
                                [
                                    0.32902770891898087,
                                    0.5620660353741853,
                                    0.04021257699501396,
                                    0.06869367871181989,
                                ],
                                [
                                    0.32902770891898087,
                                    0.04021257699501396,
                                    0.5620660353741853,
                                    0.06869367871181989,
                                ],
                                [
                                    0.18089064550572403,
                                    0.04021257699501396,
                                    0.6372369396999609,
                                    0.1416598377993011,
                                ],
                                [
                                    0.7290283732104601,
                                    0.08909921199522482,
                                    0.16206537108270602,
                                    0.01980704371160903,
                                ],
                                [
                                    0.7290283732104601,
                                    0.16206537108270602,
                                    0.08909921199522482,
                                    0.01980704371160903,
                                ],
                                [
                                    0.011735280527283452,
                                    0.2405350150025689,
                                    0.03478339699927757,
                                    0.7129463074708701,
                                ],
                                [
                                    0.011735280527283452,
                                    0.03478339699927757,
                                    0.2405350150025689,
                                    0.7129463074708701,
                                ],
                                [
                                    0.0407383661975776,
                                    0.8350037735981418,
                                    0.005780311328983428,
                                    0.11847754887529713,
                                ],
                                [
                                    0.24648998420086896,
                                    0.7305968491227183,
                                    0.005780311328983421,
                                    0.017132855347429376,
                                ],
                                [
                                    0.24648998420086896,
                                    0.005780311328983421,
                                    0.7305968491227183,
                                    0.017132855347429376,
                                ],
                                [
                                    0.0407383661975776,
                                    0.005780311328983428,
                                    0.8350037735981418,
                                    0.11847754887529713,
                                ],
                                [
                                    0.8556761141810217,
                                    0.020066025614697714,
                                    0.12141071914256549,
                                    0.002847141061715081,
                                ],
                                [
                                    0.8556761141810217,
                                    0.12141071914256549,
                                    0.020066025614697714,
                                    0.002847141061715081,
                                ],
                                [
                                    0.1961803248348281,
                                    0.44264312392848576,
                                    0.11091598669633101,
                                    0.2502605645403551,
                                ],
                                [
                                    0.1961803248348281,
                                    0.11091598669633101,
                                    0.44264312392848576,
                                    0.2502605645403551,
                                ],
                                [
                                    0.2104660391205424,
                                    0.4748760871693324,
                                    0.09663027241061674,
                                    0.2180276012995085,
                                ],
                                [
                                    0.2405350150025689,
                                    0.135993140731564,
                                    0.39828843376074496,
                                    0.22518341050512214,
                                ],
                                [
                                    0.2405350150025689,
                                    0.39828843376074496,
                                    0.135993140731564,
                                    0.22518341050512214,
                                ],
                                [
                                    0.2104660391205424,
                                    0.09663027241061674,
                                    0.4748760871693324,
                                    0.2180276012995085,
                                ],
                                [
                                    0.25805060685883574,
                                    0.42729151943103905,
                                    0.11847754887529714,
                                    0.19618032483482806,
                                ],
                                [
                                    0.25805060685883574,
                                    0.11847754887529714,
                                    0.42729151943103905,
                                    0.19618032483482806,
                                ],
                                [
                                    0.11538348132078953,
                                    0.4064699770583818,
                                    0.10571974117994846,
                                    0.3724268004408802,
                                ],
                                [
                                    0.11538348132078953,
                                    0.10571974117994846,
                                    0.4064699770583818,
                                    0.3724268004408802,
                                ],
                                [
                                    0.1642701163210004,
                                    0.5786865645589089,
                                    0.0568331061797376,
                                    0.20021021294035304,
                                ],
                                [
                                    0.28760006882131667,
                                    0.2635126318869932,
                                    0.23425338955785463,
                                    0.2146339097338355,
                                ],
                                [
                                    0.28760006882131667,
                                    0.23425338955785463,
                                    0.2635126318869932,
                                    0.2146339097338355,
                                ],
                                [
                                    0.1642701163210004,
                                    0.0568331061797376,
                                    0.5786865645589089,
                                    0.20021021294035304,
                                ],
                                [
                                    0.40945286290900873,
                                    0.33350381797090056,
                                    0.1416598377993011,
                                    0.11538348132078954,
                                ],
                                [
                                    0.40945286290900873,
                                    0.1416598377993011,
                                    0.33350381797090056,
                                    0.11538348132078954,
                                ],
                                [
                                    0.040212576995013974,
                                    0.32902770891898087,
                                    0.0686936787118199,
                                    0.5620660353741853,
                                ],
                                [
                                    0.040212576995013974,
                                    0.0686936787118199,
                                    0.32902770891898087,
                                    0.5620660353741853,
                                ],
                                [
                                    0.08909921199522484,
                                    0.7290283732104601,
                                    0.019807043711609032,
                                    0.16206537108270602,
                                ],
                                [
                                    0.2876000688213167,
                                    0.4912967086779453,
                                    0.08164021709267812,
                                    0.1394630054080599,
                                ],
                                [
                                    0.2876000688213167,
                                    0.08164021709267812,
                                    0.4912967086779453,
                                    0.1394630054080599,
                                ],
                                [
                                    0.08909921199522484,
                                    0.019807043711609032,
                                    0.7290283732104601,
                                    0.16206537108270602,
                                ],
                                [
                                    0.6372369396999609,
                                    0.18089064550572406,
                                    0.1416598377993011,
                                    0.04021257699501396,
                                ],
                                [
                                    0.6372369396999609,
                                    0.1416598377993011,
                                    0.18089064550572406,
                                    0.04021257699501396,
                                ],
                                [
                                    0.005780311328983436,
                                    0.24648998420086893,
                                    0.017132855347429417,
                                    0.7305968491227183,
                                ],
                                [
                                    0.005780311328983436,
                                    0.017132855347429417,
                                    0.24648998420086893,
                                    0.7305968491227183,
                                ],
                                [
                                    0.020066025614697766,
                                    0.8556761141810217,
                                    0.0028471410617150884,
                                    0.12141071914256547,
                                ],
                                [
                                    0.24053501500256894,
                                    0.7129463074708702,
                                    0.011735280527283438,
                                    0.03478339699927753,
                                ],
                                [
                                    0.24053501500256894,
                                    0.011735280527283438,
                                    0.7129463074708702,
                                    0.03478339699927753,
                                ],
                                [
                                    0.020066025614697766,
                                    0.0028471410617150884,
                                    0.8556761141810217,
                                    0.12141071914256547,
                                ],
                                [
                                    0.8350037735981419,
                                    0.04073836619757755,
                                    0.11847754887529714,
                                    0.005780311328983421,
                                ],
                                [
                                    0.8350037735981419,
                                    0.11847754887529714,
                                    0.04073836619757755,
                                    0.005780311328983421,
                                ],
                                [
                                    0.041275062230343024,
                                    0.5975483865329708,
                                    0.02333600098320468,
                                    0.3378405502534815,
                                ],
                                [
                                    0.041275062230343024,
                                    0.02333600098320468,
                                    0.5975483865329708,
                                    0.3378405502534815,
                                ],
                                [
                                    0.04428068344462229,
                                    0.6410614428452525,
                                    0.02033037976892541,
                                    0.2943274939411998,
                                ],
                                [
                                    0.08562975239808383,
                                    0.04841315501843764,
                                    0.5531936963652301,
                                    0.3127633962182485,
                                ],
                                [
                                    0.08562975239808383,
                                    0.5531936963652301,
                                    0.04841315501843764,
                                    0.3127633962182485,
                                ],
                                [
                                    0.04428068344462229,
                                    0.02033037976892541,
                                    0.6410614428452525,
                                    0.2943274939411998,
                                ],
                                [
                                    0.09186525118291565,
                                    0.5934768751069591,
                                    0.04217765623360582,
                                    0.2724802174765194,
                                ],
                                [
                                    0.09186525118291565,
                                    0.04217765623360582,
                                    0.5934768751069591,
                                    0.2724802174765194,
                                ],
                                [
                                    0.024275932746461306,
                                    0.49757752563271,
                                    0.02224274478009972,
                                    0.45590379684072896,
                                ],
                                [
                                    0.024275932746461306,
                                    0.02224274478009972,
                                    0.49757752563271,
                                    0.45590379684072896,
                                ],
                                [
                                    0.03456136225405661,
                                    0.7083953186258527,
                                    0.011957315272504414,
                                    0.24508600384758625,
                                ],
                                [
                                    0.19649252024698846,
                                    0.18003563548714444,
                                    0.32536093813218286,
                                    0.29811090613368424,
                                ],
                                [
                                    0.19649252024698846,
                                    0.32536093813218286,
                                    0.18003563548714444,
                                    0.29811090613368424,
                                ],
                                [
                                    0.03456136225405661,
                                    0.011957315272504414,
                                    0.7083953186258527,
                                    0.24508600384758625,
                                ],
                                [
                                    0.27974410884206496,
                                    0.46321257203784433,
                                    0.09678404689206792,
                                    0.16025927222802275,
                                ],
                                [
                                    0.27974410884206496,
                                    0.09678404689206792,
                                    0.46321257203784433,
                                    0.16025927222802275,
                                ],
                                [
                                    0.008460464214793701,
                                    0.36077982169920114,
                                    0.014452702461619154,
                                    0.6163070116243861,
                                ],
                                [
                                    0.008460464214793701,
                                    0.014452702461619154,
                                    0.36077982169920114,
                                    0.6163070116243861,
                                ],
                                [
                                    0.01874589372238902,
                                    0.799381691483296,
                                    0.004167272954023836,
                                    0.17770514184029124,
                                ],
                                [
                                    0.2558479560410964,
                                    0.4370557324277445,
                                    0.1133923298728984,
                                    0.19370398165826067,
                                ],
                                [
                                    0.2558479560410964,
                                    0.1133923298728984,
                                    0.4370557324277445,
                                    0.19370398165826067,
                                ],
                                [
                                    0.01874589372238902,
                                    0.004167272954023836,
                                    0.799381691483296,
                                    0.17770514184029124,
                                ],
                                [
                                    0.566883621427125,
                                    0.2512439637785599,
                                    0.1260200670417159,
                                    0.05585234775259917,
                                ],
                                [
                                    0.566883621427125,
                                    0.1260200670417159,
                                    0.2512439637785599,
                                    0.05585234775259917,
                                ],
                                [
                                    0.0012161398448872077,
                                    0.25105415568496514,
                                    0.003604641144538858,
                                    0.7441250633256088,
                                ],
                                [
                                    0.0012161398448872077,
                                    0.003604641144538858,
                                    0.25105415568496514,
                                    0.7441250633256088,
                                ],
                                [
                                    0.004221761059166509,
                                    0.871520378736553,
                                    0.0005990199302595574,
                                    0.123658840274021,
                                ],
                                [
                                    0.23597084351847272,
                                    0.6994180932679795,
                                    0.016299452011379664,
                                    0.048311611202168085,
                                ],
                                [
                                    0.23597084351847272,
                                    0.016299452011379664,
                                    0.6994180932679795,
                                    0.048311611202168085,
                                ],
                                [
                                    0.004221761059166509,
                                    0.0005990199302595574,
                                    0.871520378736553,
                                    0.123658840274021,
                                ],
                                [
                                    0.8191595090426107,
                                    0.0565826307531088,
                                    0.11622942774384162,
                                    0.00802843246043895,
                                ],
                                [
                                    0.8191595090426107,
                                    0.11622942774384162,
                                    0.0565826307531088,
                                    0.00802843246043895,
                                ],
                                [
                                    0.2724802174765194,
                                    0.0421776562336058,
                                    0.5934768751069591,
                                    0.09186525118291561,
                                ],
                                [
                                    0.2724802174765194,
                                    0.5934768751069591,
                                    0.0421776562336058,
                                    0.09186525118291561,
                                ],
                                [
                                    0.3127633962182485,
                                    0.048413155018437626,
                                    0.5531936963652301,
                                    0.08562975239808379,
                                ],
                                [
                                    0.2943274939411998,
                                    0.6410614428452525,
                                    0.020330379768925405,
                                    0.044280683444622285,
                                ],
                                [
                                    0.2943274939411998,
                                    0.020330379768925405,
                                    0.6410614428452525,
                                    0.044280683444622285,
                                ],
                                [
                                    0.3127633962182485,
                                    0.5531936963652301,
                                    0.048413155018437626,
                                    0.08562975239808379,
                                ],
                                [
                                    0.3378405502534815,
                                    0.023336000983204673,
                                    0.5975483865329708,
                                    0.04127506223034302,
                                ],
                                [
                                    0.3378405502534815,
                                    0.5975483865329708,
                                    0.023336000983204673,
                                    0.04127506223034302,
                                ],
                                [
                                    0.1602592722280228,
                                    0.0967840468920679,
                                    0.46321257203784444,
                                    0.27974410884206485,
                                ],
                                [
                                    0.1602592722280228,
                                    0.46321257203784444,
                                    0.0967840468920679,
                                    0.27974410884206485,
                                ],
                                [
                                    0.2981109061336843,
                                    0.18003563548714438,
                                    0.3253609381321829,
                                    0.1964925202469884,
                                ],
                                [
                                    0.24508600384758633,
                                    0.7083953186258528,
                                    0.011957315272504394,
                                    0.03456136225405654,
                                ],
                                [
                                    0.24508600384758633,
                                    0.011957315272504394,
                                    0.7083953186258528,
                                    0.03456136225405654,
                                ],
                                [
                                    0.2981109061336843,
                                    0.3253609381321829,
                                    0.18003563548714438,
                                    0.1964925202469884,
                                ],
                                [
                                    0.455903796840729,
                                    0.022242744780099678,
                                    0.49757752563271007,
                                    0.024275932746461257,
                                ],
                                [
                                    0.455903796840729,
                                    0.49757752563271007,
                                    0.022242744780099678,
                                    0.024275932746461257,
                                ],
                                [
                                    0.05585234775259917,
                                    0.12602006704171587,
                                    0.25124396377855995,
                                    0.566883621427125,
                                ],
                                [
                                    0.05585234775259917,
                                    0.25124396377855995,
                                    0.12602006704171587,
                                    0.566883621427125,
                                ],
                                [
                                    0.1937039816582607,
                                    0.4370557324277445,
                                    0.11339232987289842,
                                    0.2558479560410964,
                                ],
                                [
                                    0.17770514184029124,
                                    0.7993816914832961,
                                    0.004167272954023822,
                                    0.018745893722388957,
                                ],
                                [
                                    0.17770514184029124,
                                    0.004167272954023822,
                                    0.7993816914832961,
                                    0.018745893722388957,
                                ],
                                [
                                    0.1937039816582607,
                                    0.11339232987289842,
                                    0.4370557324277445,
                                    0.2558479560410964,
                                ],
                                [
                                    0.6163070116243861,
                                    0.014452702461619105,
                                    0.36077982169920114,
                                    0.008460464214793673,
                                ],
                                [
                                    0.6163070116243861,
                                    0.36077982169920114,
                                    0.014452702461619105,
                                    0.008460464214793673,
                                ],
                                [
                                    0.008028432460438942,
                                    0.1162294277438416,
                                    0.05658263075310876,
                                    0.8191595090426107,
                                ],
                                [
                                    0.008028432460438942,
                                    0.05658263075310876,
                                    0.1162294277438416,
                                    0.8191595090426107,
                                ],
                                [
                                    0.04831161120216805,
                                    0.6994180932679795,
                                    0.016299452011379653,
                                    0.23597084351847272,
                                ],
                                [
                                    0.12365884027402098,
                                    0.871520378736553,
                                    0.0005990199302595515,
                                    0.004221761059166467,
                                ],
                                [
                                    0.12365884027402098,
                                    0.0005990199302595515,
                                    0.871520378736553,
                                    0.004221761059166467,
                                ],
                                [
                                    0.04831161120216805,
                                    0.016299452011379653,
                                    0.6994180932679795,
                                    0.23597084351847272,
                                ],
                                [
                                    0.7441250633256088,
                                    0.0036046411445388228,
                                    0.25105415568496514,
                                    0.0012161398448871958,
                                ],
                                [
                                    0.7441250633256088,
                                    0.25105415568496514,
                                    0.0036046411445388228,
                                    0.0012161398448871958,
                                ],
                                [
                                    0.1961803248348281,
                                    0.11847754887529711,
                                    0.4272915194310391,
                                    0.2580506068588357,
                                ],
                                [
                                    0.1961803248348281,
                                    0.4272915194310391,
                                    0.11847754887529711,
                                    0.2580506068588357,
                                ],
                                [
                                    0.2251834105051222,
                                    0.13599314073156393,
                                    0.398288433760745,
                                    0.24053501500256885,
                                ],
                                [
                                    0.2180276012995085,
                                    0.4748760871693324,
                                    0.09663027241061672,
                                    0.21046603912054235,
                                ],
                                [
                                    0.2180276012995085,
                                    0.09663027241061672,
                                    0.4748760871693324,
                                    0.21046603912054235,
                                ],
                                [
                                    0.2251834105051222,
                                    0.398288433760745,
                                    0.13599314073156393,
                                    0.24053501500256885,
                                ],
                                [
                                    0.2502605645403551,
                                    0.110915986696331,
                                    0.44264312392848576,
                                    0.19618032483482808,
                                ],
                                [
                                    0.2502605645403551,
                                    0.44264312392848576,
                                    0.110915986696331,
                                    0.19618032483482808,
                                ],
                                [
                                    0.11538348132078957,
                                    0.14165983779930114,
                                    0.33350381797090056,
                                    0.40945286290900873,
                                ],
                                [
                                    0.11538348132078957,
                                    0.33350381797090056,
                                    0.14165983779930114,
                                    0.40945286290900873,
                                ],
                                [
                                    0.2146339097338355,
                                    0.2635126318869932,
                                    0.23425338955785463,
                                    0.28760006882131667,
                                ],
                                [
                                    0.2002102129403531,
                                    0.5786865645589089,
                                    0.05683310617973762,
                                    0.1642701163210004,
                                ],
                                [
                                    0.2002102129403531,
                                    0.05683310617973762,
                                    0.5786865645589089,
                                    0.1642701163210004,
                                ],
                                [
                                    0.2146339097338355,
                                    0.23425338955785463,
                                    0.2635126318869932,
                                    0.28760006882131667,
                                ],
                                [
                                    0.3724268004408802,
                                    0.10571974117994848,
                                    0.4064699770583818,
                                    0.11538348132078954,
                                ],
                                [
                                    0.3724268004408802,
                                    0.4064699770583818,
                                    0.10571974117994848,
                                    0.11538348132078954,
                                ],
                                [
                                    0.04021257699501395,
                                    0.14165983779930108,
                                    0.18089064550572403,
                                    0.6372369396999609,
                                ],
                                [
                                    0.04021257699501395,
                                    0.18089064550572403,
                                    0.14165983779930108,
                                    0.6372369396999609,
                                ],
                                [
                                    0.1394630054080599,
                                    0.4912967086779453,
                                    0.08164021709267812,
                                    0.2876000688213167,
                                ],
                                [
                                    0.16206537108270602,
                                    0.7290283732104601,
                                    0.019807043711609025,
                                    0.08909921199522482,
                                ],
                                [
                                    0.16206537108270602,
                                    0.019807043711609025,
                                    0.7290283732104601,
                                    0.08909921199522482,
                                ],
                                [
                                    0.1394630054080599,
                                    0.08164021709267812,
                                    0.4912967086779453,
                                    0.2876000688213167,
                                ],
                                [
                                    0.5620660353741853,
                                    0.06869367871181989,
                                    0.32902770891898087,
                                    0.04021257699501396,
                                ],
                                [
                                    0.5620660353741853,
                                    0.32902770891898087,
                                    0.06869367871181989,
                                    0.04021257699501396,
                                ],
                                [
                                    0.005780311328983426,
                                    0.11847754887529711,
                                    0.0407383661975776,
                                    0.8350037735981418,
                                ],
                                [
                                    0.005780311328983426,
                                    0.0407383661975776,
                                    0.11847754887529711,
                                    0.8350037735981418,
                                ],
                                [
                                    0.03478339699927757,
                                    0.7129463074708701,
                                    0.011735280527283452,
                                    0.2405350150025689,
                                ],
                                [
                                    0.12141071914256546,
                                    0.8556761141810217,
                                    0.0028471410617150806,
                                    0.020066025614697714,
                                ],
                                [
                                    0.12141071914256546,
                                    0.0028471410617150806,
                                    0.8556761141810217,
                                    0.020066025614697714,
                                ],
                                [
                                    0.03478339699927757,
                                    0.011735280527283452,
                                    0.7129463074708701,
                                    0.2405350150025689,
                                ],
                                [
                                    0.7305968491227183,
                                    0.017132855347429376,
                                    0.24648998420086896,
                                    0.005780311328983421,
                                ],
                                [
                                    0.7305968491227183,
                                    0.24648998420086896,
                                    0.017132855347429376,
                                    0.005780311328983421,
                                ],
                                [
                                    0.09663027241061674,
                                    0.2180276012995085,
                                    0.2104660391205424,
                                    0.4748760871693324,
                                ],
                                [
                                    0.09663027241061674,
                                    0.2104660391205424,
                                    0.2180276012995085,
                                    0.4748760871693324,
                                ],
                                [
                                    0.11091598669633101,
                                    0.2502605645403551,
                                    0.1961803248348281,
                                    0.44264312392848576,
                                ],
                                [
                                    0.11847754887529714,
                                    0.25805060685883574,
                                    0.19618032483482806,
                                    0.42729151943103905,
                                ],
                                [
                                    0.11847754887529714,
                                    0.19618032483482806,
                                    0.25805060685883574,
                                    0.42729151943103905,
                                ],
                                [
                                    0.11091598669633101,
                                    0.1961803248348281,
                                    0.2502605645403551,
                                    0.44264312392848576,
                                ],
                                [
                                    0.135993140731564,
                                    0.22518341050512214,
                                    0.2405350150025689,
                                    0.39828843376074496,
                                ],
                                [
                                    0.135993140731564,
                                    0.2405350150025689,
                                    0.22518341050512214,
                                    0.39828843376074496,
                                ],
                                [
                                    0.056833106179737615,
                                    0.2002102129403531,
                                    0.1642701163210004,
                                    0.5786865645589089,
                                ],
                                [
                                    0.056833106179737615,
                                    0.1642701163210004,
                                    0.2002102129403531,
                                    0.5786865645589089,
                                ],
                                [
                                    0.10571974117994846,
                                    0.3724268004408802,
                                    0.11538348132078953,
                                    0.4064699770583818,
                                ],
                                [
                                    0.14165983779930114,
                                    0.40945286290900873,
                                    0.11538348132078957,
                                    0.33350381797090056,
                                ],
                                [
                                    0.14165983779930114,
                                    0.11538348132078957,
                                    0.40945286290900873,
                                    0.33350381797090056,
                                ],
                                [
                                    0.10571974117994846,
                                    0.11538348132078953,
                                    0.3724268004408802,
                                    0.4064699770583818,
                                ],
                                [
                                    0.2635126318869932,
                                    0.2146339097338355,
                                    0.28760006882131667,
                                    0.23425338955785463,
                                ],
                                [
                                    0.2635126318869932,
                                    0.28760006882131667,
                                    0.2146339097338355,
                                    0.23425338955785463,
                                ],
                                [
                                    0.019807043711609032,
                                    0.16206537108270602,
                                    0.08909921199522484,
                                    0.7290283732104601,
                                ],
                                [
                                    0.019807043711609032,
                                    0.08909921199522484,
                                    0.16206537108270602,
                                    0.7290283732104601,
                                ],
                                [
                                    0.0686936787118199,
                                    0.5620660353741853,
                                    0.040212576995013974,
                                    0.32902770891898087,
                                ],
                                [
                                    0.14165983779930108,
                                    0.6372369396999609,
                                    0.04021257699501395,
                                    0.18089064550572406,
                                ],
                                [
                                    0.14165983779930108,
                                    0.04021257699501395,
                                    0.6372369396999609,
                                    0.18089064550572406,
                                ],
                                [
                                    0.0686936787118199,
                                    0.040212576995013974,
                                    0.5620660353741853,
                                    0.32902770891898087,
                                ],
                                [
                                    0.4912967086779453,
                                    0.1394630054080599,
                                    0.2876000688213167,
                                    0.08164021709267812,
                                ],
                                [
                                    0.4912967086779453,
                                    0.2876000688213167,
                                    0.1394630054080599,
                                    0.08164021709267812,
                                ],
                                [
                                    0.002847141061715088,
                                    0.12141071914256545,
                                    0.020066025614697766,
                                    0.8556761141810217,
                                ],
                                [
                                    0.002847141061715088,
                                    0.020066025614697766,
                                    0.12141071914256545,
                                    0.8556761141810217,
                                ],
                                [
                                    0.017132855347429417,
                                    0.7305968491227183,
                                    0.005780311328983436,
                                    0.24648998420086893,
                                ],
                                [
                                    0.11847754887529713,
                                    0.8350037735981419,
                                    0.005780311328983419,
                                    0.04073836619757755,
                                ],
                                [
                                    0.11847754887529713,
                                    0.005780311328983419,
                                    0.8350037735981419,
                                    0.04073836619757755,
                                ],
                                [
                                    0.017132855347429417,
                                    0.005780311328983436,
                                    0.7305968491227183,
                                    0.24648998420086893,
                                ],
                                [
                                    0.7129463074708702,
                                    0.03478339699927753,
                                    0.24053501500256894,
                                    0.011735280527283438,
                                ],
                                [
                                    0.7129463074708702,
                                    0.24053501500256894,
                                    0.03478339699927753,
                                    0.011735280527283438,
                                ],
                                [
                                    0.02033037976892541,
                                    0.2943274939411998,
                                    0.04428068344462229,
                                    0.6410614428452525,
                                ],
                                [
                                    0.02033037976892541,
                                    0.04428068344462229,
                                    0.2943274939411998,
                                    0.6410614428452525,
                                ],
                                [
                                    0.02333600098320468,
                                    0.3378405502534815,
                                    0.041275062230343024,
                                    0.5975483865329708,
                                ],
                                [
                                    0.04217765623360582,
                                    0.09186525118291565,
                                    0.2724802174765194,
                                    0.5934768751069591,
                                ],
                                [
                                    0.04217765623360582,
                                    0.2724802174765194,
                                    0.09186525118291565,
                                    0.5934768751069591,
                                ],
                                [
                                    0.02333600098320468,
                                    0.041275062230343024,
                                    0.3378405502534815,
                                    0.5975483865329708,
                                ],
                                [
                                    0.04841315501843764,
                                    0.3127633962182485,
                                    0.08562975239808383,
                                    0.5531936963652301,
                                ],
                                [
                                    0.04841315501843764,
                                    0.08562975239808383,
                                    0.3127633962182485,
                                    0.5531936963652301,
                                ],
                                [
                                    0.011957315272504418,
                                    0.2450860038475863,
                                    0.03456136225405661,
                                    0.7083953186258527,
                                ],
                                [
                                    0.011957315272504418,
                                    0.03456136225405661,
                                    0.2450860038475863,
                                    0.7083953186258527,
                                ],
                                [
                                    0.02224274478009972,
                                    0.45590379684072896,
                                    0.024275932746461306,
                                    0.49757752563271,
                                ],
                                [
                                    0.09678404689206793,
                                    0.27974410884206496,
                                    0.16025927222802278,
                                    0.46321257203784433,
                                ],
                                [
                                    0.09678404689206793,
                                    0.16025927222802278,
                                    0.27974410884206496,
                                    0.46321257203784433,
                                ],
                                [
                                    0.02224274478009972,
                                    0.024275932746461306,
                                    0.45590379684072896,
                                    0.49757752563271,
                                ],
                                [
                                    0.18003563548714444,
                                    0.29811090613368424,
                                    0.19649252024698846,
                                    0.32536093813218286,
                                ],
                                [
                                    0.18003563548714444,
                                    0.19649252024698846,
                                    0.29811090613368424,
                                    0.32536093813218286,
                                ],
                                [
                                    0.004167272954023836,
                                    0.1777051418402912,
                                    0.01874589372238902,
                                    0.799381691483296,
                                ],
                                [
                                    0.004167272954023836,
                                    0.01874589372238902,
                                    0.1777051418402912,
                                    0.799381691483296,
                                ],
                                [
                                    0.014452702461619154,
                                    0.6163070116243861,
                                    0.008460464214793701,
                                    0.36077982169920114,
                                ],
                                [
                                    0.12602006704171587,
                                    0.566883621427125,
                                    0.05585234775259915,
                                    0.2512439637785599,
                                ],
                                [
                                    0.12602006704171587,
                                    0.05585234775259915,
                                    0.566883621427125,
                                    0.2512439637785599,
                                ],
                                [
                                    0.014452702461619154,
                                    0.008460464214793701,
                                    0.6163070116243861,
                                    0.36077982169920114,
                                ],
                                [
                                    0.4370557324277445,
                                    0.19370398165826067,
                                    0.2558479560410964,
                                    0.1133923298728984,
                                ],
                                [
                                    0.4370557324277445,
                                    0.2558479560410964,
                                    0.19370398165826067,
                                    0.1133923298728984,
                                ],
                                [
                                    0.0005990199302595572,
                                    0.12365884027402098,
                                    0.004221761059166509,
                                    0.871520378736553,
                                ],
                                [
                                    0.0005990199302595572,
                                    0.004221761059166509,
                                    0.12365884027402098,
                                    0.871520378736553,
                                ],
                                [
                                    0.003604641144538858,
                                    0.7441250633256088,
                                    0.0012161398448872077,
                                    0.25105415568496514,
                                ],
                                [
                                    0.1162294277438416,
                                    0.8191595090426107,
                                    0.008028432460438948,
                                    0.0565826307531088,
                                ],
                                [
                                    0.1162294277438416,
                                    0.008028432460438948,
                                    0.8191595090426107,
                                    0.0565826307531088,
                                ],
                                [
                                    0.003604641144538858,
                                    0.0012161398448872077,
                                    0.7441250633256088,
                                    0.25105415568496514,
                                ],
                                [
                                    0.6994180932679795,
                                    0.048311611202168085,
                                    0.23597084351847272,
                                    0.016299452011379664,
                                ],
                                [
                                    0.6994180932679795,
                                    0.23597084351847272,
                                    0.048311611202168085,
                                    0.016299452011379664,
                                ],
                                [
                                    0.057328062548319896,
                                    0.008873904084101271,
                                    0.8086290300351586,
                                    0.12516900333242015,
                                ],
                                [
                                    0.057328062548319896,
                                    0.8086290300351586,
                                    0.008873904084101271,
                                    0.12516900333242015,
                                ],
                                [
                                    0.09761124129004899,
                                    0.015109402868933091,
                                    0.7683458512934296,
                                    0.11893350454758833,
                                ],
                                [
                                    0.06192458718147263,
                                    0.8734643496049797,
                                    0.004277379450948539,
                                    0.06033368376259915,
                                ],
                                [
                                    0.06192458718147263,
                                    0.004277379450948539,
                                    0.8734643496049797,
                                    0.06033368376259915,
                                ],
                                [
                                    0.09761124129004899,
                                    0.7683458512934296,
                                    0.015109402868933091,
                                    0.11893350454758833,
                                ],
                                [
                                    0.10543764349375427,
                                    0.007283000665227806,
                                    0.829951293292698,
                                    0.05732806254831988,
                                ],
                                [
                                    0.10543764349375427,
                                    0.829951293292698,
                                    0.007283000665227806,
                                    0.05732806254831988,
                                ],
                                [
                                    0.03371750678754517,
                                    0.020362732917981942,
                                    0.5897543374783221,
                                    0.3561654228161508,
                                ],
                                [
                                    0.03371750678754517,
                                    0.5897543374783221,
                                    0.020362732917981942,
                                    0.3561654228161508,
                                ],
                                [
                                    0.17156914069320667,
                                    0.10361432151305844,
                                    0.45190270357266055,
                                    0.27291383422107435,
                                ],
                                [
                                    0.05156449847410658,
                                    0.9019168239993325,
                                    0.002515741231420532,
                                    0.044002936295140405,
                                ],
                                [
                                    0.05156449847410658,
                                    0.002515741231420532,
                                    0.9019168239993325,
                                    0.044002936295140405,
                                ],
                                [
                                    0.17156914069320667,
                                    0.45190270357266055,
                                    0.10361432151305844,
                                    0.27291383422107435,
                                ],
                                [
                                    0.2623822914672493,
                                    0.012801170739015814,
                                    0.6910990310061897,
                                    0.03371750678754512,
                                ],
                                [
                                    0.2623822914672493,
                                    0.6910990310061897,
                                    0.012801170739015814,
                                    0.03371750678754512,
                                ],
                                [
                                    0.01175097008907608,
                                    0.026513801084783434,
                                    0.2953453414420831,
                                    0.6663898873840575,
                                ],
                                [
                                    0.01175097008907608,
                                    0.2953453414420831,
                                    0.026513801084783434,
                                    0.6663898873840575,
                                ],
                                [
                                    0.14960260399473763,
                                    0.337549466470812,
                                    0.1574937075364215,
                                    0.35535422199802885,
                                ],
                                [
                                    0.03738800409411808,
                                    0.9396988292294692,
                                    0.000876767079741438,
                                    0.02203639959667134,
                                ],
                                [
                                    0.03738800409411808,
                                    0.000876767079741438,
                                    0.9396988292294692,
                                    0.02203639959667134,
                                ],
                                [
                                    0.14960260399473763,
                                    0.1574937075364215,
                                    0.337549466470812,
                                    0.35535422199802885,
                                ],
                                [
                                    0.47598987387821295,
                                    0.011162196587336722,
                                    0.5010969594453744,
                                    0.011750970089076057,
                                ],
                                [
                                    0.47598987387821295,
                                    0.5010969594453744,
                                    0.011162196587336722,
                                    0.011750970089076057,
                                ],
                                [
                                    0.0016891298844352522,
                                    0.02445391436253009,
                                    0.06292193332911244,
                                    0.9109350224239222,
                                ],
                                [
                                    0.0016891298844352522,
                                    0.06292193332911244,
                                    0.02445391436253009,
                                    0.9109350224239222,
                                ],
                                [
                                    0.04197230862616436,
                                    0.607642579886668,
                                    0.022638754587383344,
                                    0.3277463568997842,
                                ],
                                [
                                    0.026017014356253847,
                                    0.9691622046543201,
                                    0.00012602989071149376,
                                    0.004694751098714525,
                                ],
                                [
                                    0.026017014356253847,
                                    0.00012602989071149376,
                                    0.9691622046543201,
                                    0.004694751098714525,
                                ],
                                [
                                    0.04197230862616436,
                                    0.022638754587383344,
                                    0.607642579886668,
                                    0.3277463568997842,
                                ],
                                [
                                    0.6464832374078416,
                                    0.0031316511049907653,
                                    0.3486959816027323,
                                    0.0016891298844352535,
                                ],
                                [
                                    0.6464832374078416,
                                    0.3486959816027323,
                                    0.0031316511049907653,
                                    0.0016891298844352535,
                                ],
                                [
                                    0.04127506223034303,
                                    0.02492690440207814,
                                    0.5821967820355242,
                                    0.35160125133205467,
                                ],
                                [
                                    0.04127506223034303,
                                    0.5821967820355242,
                                    0.02492690440207814,
                                    0.35160125133205467,
                                ],
                                [
                                    0.07027814790063712,
                                    0.042442496258344974,
                                    0.5531936963652301,
                                    0.33408565947578783,
                                ],
                                [
                                    0.04587158686349576,
                                    0.6470321016053451,
                                    0.02033037976892541,
                                    0.28676593176223364,
                                ],
                                [
                                    0.04587158686349576,
                                    0.02033037976892541,
                                    0.6470321016053451,
                                    0.28676593176223364,
                                ],
                                [
                                    0.07027814790063712,
                                    0.5531936963652301,
                                    0.042442496258344974,
                                    0.33408565947578783,
                                ],
                                [
                                    0.07810455010434239,
                                    0.03461609405463969,
                                    0.6147991383644985,
                                    0.2724802174765194,
                                ],
                                [
                                    0.07810455010434239,
                                    0.6147991383644985,
                                    0.03461609405463969,
                                    0.2724802174765194,
                                ],
                                [
                                    0.024275932746461292,
                                    0.02980430695906582,
                                    0.42461136654522885,
                                    0.5213083937492441,
                                ],
                                [
                                    0.024275932746461292,
                                    0.42461136654522885,
                                    0.02980430695906582,
                                    0.5213083937492441,
                                ],
                                [
                                    0.12352636115950723,
                                    0.1516571010467579,
                                    0.3253609381321829,
                                    0.399455599661552,
                                ],
                                [
                                    0.04212292443302271,
                                    0.7367738530662393,
                                    0.011957315272504408,
                                    0.20914590722823362,
                                ],
                                [
                                    0.04212292443302271,
                                    0.011957315272504408,
                                    0.7367738530662393,
                                    0.20914590722823362,
                                ],
                                [
                                    0.12352636115950723,
                                    0.3253609381321829,
                                    0.1516571010467579,
                                    0.399455599661552,
                                ],
                                [
                                    0.21433951193354986,
                                    0.06084395027271527,
                                    0.5645572655657122,
                                    0.16025927222802275,
                                ],
                                [
                                    0.21433951193354986,
                                    0.5645572655657122,
                                    0.06084395027271527,
                                    0.16025927222802275,
                                ],
                                [
                                    0.008460464214793685,
                                    0.02980430695906583,
                                    0.2126427582859443,
                                    0.7490924705401962,
                                ],
                                [
                                    0.008460464214793685,
                                    0.2126427582859443,
                                    0.02980430695906583,
                                    0.7490924705401962,
                                ],
                                [
                                    0.10771089262783962,
                                    0.37944117783771003,
                                    0.11339232987289838,
                                    0.399455599661552,
                                ],
                                [
                                    0.03409749821983568,
                                    0.8569962460733305,
                                    0.004167272954023829,
                                    0.10473898275281002,
                                ],
                                [
                                    0.03409749821983568,
                                    0.004167272954023829,
                                    0.8569962460733305,
                                    0.10473898275281002,
                                ],
                                [
                                    0.10771089262783962,
                                    0.11339232987289838,
                                    0.37944117783771003,
                                    0.399455599661552,
                                ],
                                [
                                    0.43409816251131494,
                                    0.05305390795423469,
                                    0.4569955817818512,
                                    0.05585234775259916,
                                ],
                                [
                                    0.43409816251131494,
                                    0.4569955817818512,
                                    0.05305390795423469,
                                    0.05585234775259916,
                                ],
                                [
                                    0.001216139844887197,
                                    0.024926904402078145,
                                    0.045302537681673825,
                                    0.9285544180713609,
                                ],
                                [
                                    0.001216139844887197,
                                    0.045302537681673825,
                                    0.024926904402078145,
                                    0.9285544180713609,
                                ],
                                [
                                    0.030219225515181344,
                                    0.6193956629976511,
                                    0.01629945201137968,
                                    0.3340856594757879,
                                ],
                                [
                                    0.025544024316705792,
                                    0.9515428090068815,
                                    0.0005990199302595515,
                                    0.022314146746153243,
                                ],
                                [
                                    0.025544024316705792,
                                    0.0005990199302595515,
                                    0.9515428090068815,
                                    0.022314146746153243,
                                ],
                                [
                                    0.030219225515181344,
                                    0.01629945201137968,
                                    0.6193956629976511,
                                    0.3340856594757879,
                                ],
                                [
                                    0.6347301542968586,
                                    0.014884734215973847,
                                    0.3423566790267286,
                                    0.00802843246043895,
                                ],
                                [
                                    0.6347301542968586,
                                    0.3423566790267286,
                                    0.014884734215973847,
                                    0.00802843246043895,
                                ],
                                [
                                    0.020330379768925412,
                                    0.04587158686349576,
                                    0.2867659317622337,
                                    0.6470321016053451,
                                ],
                                [
                                    0.020330379768925412,
                                    0.2867659317622337,
                                    0.04587158686349576,
                                    0.6470321016053451,
                                ],
                                [
                                    0.034616094054639696,
                                    0.07810455010434239,
                                    0.27248021747651946,
                                    0.6147991383644985,
                                ],
                                [
                                    0.02492690440207815,
                                    0.3516012513320547,
                                    0.041275062230343024,
                                    0.582196782035524,
                                ],
                                [
                                    0.02492690440207815,
                                    0.041275062230343024,
                                    0.3516012513320547,
                                    0.582196782035524,
                                ],
                                [
                                    0.034616094054639696,
                                    0.27248021747651946,
                                    0.07810455010434239,
                                    0.6147991383644985,
                                ],
                                [
                                    0.04244249625834499,
                                    0.0702781479006371,
                                    0.3340856594757879,
                                    0.55319369636523,
                                ],
                                [
                                    0.04244249625834499,
                                    0.3340856594757879,
                                    0.0702781479006371,
                                    0.55319369636523,
                                ],
                                [
                                    0.011957315272504406,
                                    0.04212292443302271,
                                    0.2091459072282336,
                                    0.7367738530662393,
                                ],
                                [
                                    0.011957315272504406,
                                    0.2091459072282336,
                                    0.04212292443302271,
                                    0.7367738530662393,
                                ],
                                [
                                    0.06084395027271526,
                                    0.21433951193354986,
                                    0.16025927222802275,
                                    0.5645572655657122,
                                ],
                                [
                                    0.02980430695906582,
                                    0.5213083937492441,
                                    0.024275932746461292,
                                    0.42461136654522885,
                                ],
                                [
                                    0.02980430695906582,
                                    0.024275932746461292,
                                    0.5213083937492441,
                                    0.42461136654522885,
                                ],
                                [
                                    0.06084395027271526,
                                    0.16025927222802275,
                                    0.21433951193354986,
                                    0.5645572655657122,
                                ],
                                [
                                    0.1516571010467579,
                                    0.12352636115950723,
                                    0.399455599661552,
                                    0.3253609381321829,
                                ],
                                [
                                    0.1516571010467579,
                                    0.399455599661552,
                                    0.12352636115950723,
                                    0.3253609381321829,
                                ],
                                [
                                    0.00416727295402383,
                                    0.03409749821983568,
                                    0.10473898275281004,
                                    0.8569962460733305,
                                ],
                                [
                                    0.00416727295402383,
                                    0.10473898275281004,
                                    0.03409749821983568,
                                    0.8569962460733305,
                                ],
                                [
                                    0.0530539079542347,
                                    0.43409816251131494,
                                    0.055852347752599174,
                                    0.4569955817818512,
                                ],
                                [
                                    0.02980430695906583,
                                    0.7490924705401962,
                                    0.008460464214793687,
                                    0.21264275828594434,
                                ],
                                [
                                    0.02980430695906583,
                                    0.008460464214793687,
                                    0.7490924705401962,
                                    0.21264275828594434,
                                ],
                                [
                                    0.0530539079542347,
                                    0.055852347752599174,
                                    0.43409816251131494,
                                    0.4569955817818512,
                                ],
                                [
                                    0.37944117783771003,
                                    0.10771089262783963,
                                    0.399455599661552,
                                    0.11339232987289839,
                                ],
                                [
                                    0.37944117783771003,
                                    0.399455599661552,
                                    0.10771089262783963,
                                    0.11339232987289839,
                                ],
                                [
                                    0.0005990199302595531,
                                    0.02554402431670579,
                                    0.022314146746153302,
                                    0.9515428090068814,
                                ],
                                [
                                    0.0005990199302595531,
                                    0.022314146746153302,
                                    0.02554402431670579,
                                    0.9515428090068814,
                                ],
                                [
                                    0.014884734215973885,
                                    0.6347301542968585,
                                    0.00802843246043897,
                                    0.34235667902672856,
                                ],
                                [
                                    0.02492690440207815,
                                    0.928554418071361,
                                    0.0012161398448871958,
                                    0.04530253768167378,
                                ],
                                [
                                    0.02492690440207815,
                                    0.0012161398448871958,
                                    0.928554418071361,
                                    0.04530253768167378,
                                ],
                                [
                                    0.014884734215973885,
                                    0.00802843246043897,
                                    0.6347301542968585,
                                    0.34235667902672856,
                                ],
                                [
                                    0.6193956629976511,
                                    0.03021922551518131,
                                    0.3340856594757879,
                                    0.01629945201137966,
                                ],
                                [
                                    0.6193956629976511,
                                    0.3340856594757879,
                                    0.03021922551518131,
                                    0.01629945201137966,
                                ],
                                [
                                    0.00427737945094854,
                                    0.06192458718147263,
                                    0.06033368376259916,
                                    0.8734643496049797,
                                ],
                                [
                                    0.00427737945094854,
                                    0.06033368376259916,
                                    0.06192458718147263,
                                    0.8734643496049797,
                                ],
                                [
                                    0.007283000665227808,
                                    0.10543764349375427,
                                    0.057328062548319896,
                                    0.829951293292698,
                                ],
                                [
                                    0.008873904084101275,
                                    0.1251690033324202,
                                    0.057328062548319896,
                                    0.8086290300351586,
                                ],
                                [
                                    0.008873904084101275,
                                    0.057328062548319896,
                                    0.1251690033324202,
                                    0.8086290300351586,
                                ],
                                [
                                    0.007283000665227808,
                                    0.057328062548319896,
                                    0.10543764349375427,
                                    0.829951293292698,
                                ],
                                [
                                    0.015109402868933098,
                                    0.09761124129004899,
                                    0.11893350454758837,
                                    0.7683458512934296,
                                ],
                                [
                                    0.015109402868933098,
                                    0.11893350454758837,
                                    0.09761124129004899,
                                    0.7683458512934296,
                                ],
                                [
                                    0.0025157412314205374,
                                    0.051564498474106574,
                                    0.04400293629514049,
                                    0.9019168239993324,
                                ],
                                [
                                    0.0025157412314205374,
                                    0.04400293629514049,
                                    0.051564498474106574,
                                    0.9019168239993324,
                                ],
                                [
                                    0.01280117073901584,
                                    0.2623822914672493,
                                    0.03371750678754518,
                                    0.6910990310061897,
                                ],
                                [
                                    0.02036273291798195,
                                    0.35616542281615093,
                                    0.03371750678754516,
                                    0.589754337478322,
                                ],
                                [
                                    0.02036273291798195,
                                    0.03371750678754516,
                                    0.35616542281615093,
                                    0.589754337478322,
                                ],
                                [
                                    0.01280117073901584,
                                    0.03371750678754518,
                                    0.2623822914672493,
                                    0.6910990310061897,
                                ],
                                [
                                    0.10361432151305847,
                                    0.17156914069320664,
                                    0.27291383422107446,
                                    0.45190270357266044,
                                ],
                                [
                                    0.10361432151305847,
                                    0.27291383422107446,
                                    0.17156914069320664,
                                    0.45190270357266044,
                                ],
                                [
                                    0.000876767079741441,
                                    0.03738800409411807,
                                    0.022036399596671415,
                                    0.9396988292294691,
                                ],
                                [
                                    0.000876767079741441,
                                    0.022036399596671415,
                                    0.03738800409411807,
                                    0.9396988292294691,
                                ],
                                [
                                    0.011162196587336758,
                                    0.4759898738782129,
                                    0.011750970089076097,
                                    0.5010969594453742,
                                ],
                                [
                                    0.026513801084783434,
                                    0.6663898873840575,
                                    0.011750970089076076,
                                    0.295345341442083,
                                ],
                                [
                                    0.026513801084783434,
                                    0.011750970089076076,
                                    0.6663898873840575,
                                    0.295345341442083,
                                ],
                                [
                                    0.011162196587336758,
                                    0.011750970089076097,
                                    0.4759898738782129,
                                    0.5010969594453742,
                                ],
                                [
                                    0.337549466470812,
                                    0.1496026039947376,
                                    0.35535422199802885,
                                    0.15749370753642147,
                                ],
                                [
                                    0.337549466470812,
                                    0.35535422199802885,
                                    0.1496026039947376,
                                    0.15749370753642147,
                                ],
                                [
                                    0.00012602989071149498,
                                    0.026017014356253847,
                                    0.004694751098714571,
                                    0.9691622046543201,
                                ],
                                [
                                    0.00012602989071149498,
                                    0.004694751098714571,
                                    0.026017014356253847,
                                    0.9691622046543201,
                                ],
                                [
                                    0.0031316511049907956,
                                    0.6464832374078416,
                                    0.00168912988443527,
                                    0.3486959816027323,
                                ],
                                [
                                    0.02445391436253009,
                                    0.9109350224239222,
                                    0.0016891298844352533,
                                    0.06292193332911249,
                                ],
                                [
                                    0.02445391436253009,
                                    0.0016891298844352533,
                                    0.9109350224239222,
                                    0.06292193332911249,
                                ],
                                [
                                    0.0031316511049907956,
                                    0.00168912988443527,
                                    0.6464832374078416,
                                    0.3486959816027323,
                                ],
                                [
                                    0.607642579886668,
                                    0.04197230862616439,
                                    0.3277463568997842,
                                    0.022638754587383358,
                                ],
                                [
                                    0.607642579886668,
                                    0.3277463568997842,
                                    0.04197230862616439,
                                    0.022638754587383358,
                                ],
                                [
                                    0.753766426238164,
                                    0.116676731620146,
                                    0.11219066634531447,
                                    0.017366175796375418,
                                ],
                                [
                                    0.753766426238164,
                                    0.11219066634531447,
                                    0.116676731620146,
                                    0.017366175796375418,
                                ],
                                [
                                    0.8097168346872952,
                                    0.12533738638456257,
                                    0.05624025789618335,
                                    0.00870552103195883,
                                ],
                                [
                                    0.8142028999621267,
                                    0.12118603682432554,
                                    0.056240257896183345,
                                    0.008370805317364345,
                                ],
                                [
                                    0.8142028999621267,
                                    0.056240257896183345,
                                    0.12118603682432554,
                                    0.008370805317364345,
                                ],
                                [
                                    0.8097168346872952,
                                    0.05624025789618335,
                                    0.12533738638456257,
                                    0.00870552103195883,
                                ],
                                [
                                    0.8746393736860893,
                                    0.0604148473857684,
                                    0.0607495631003629,
                                    0.004196215827779288,
                                ],
                                [
                                    0.8746393736860893,
                                    0.0607495631003629,
                                    0.0604148473857684,
                                    0.004196215827779288,
                                ],
                                [
                                    0.40201097138938213,
                                    0.24278313613402436,
                                    0.22146087287648505,
                                    0.1337450196001084,
                                ],
                                [
                                    0.40201097138938213,
                                    0.22146087287648505,
                                    0.24278313613402436,
                                    0.1337450196001084,
                                ],
                                [
                                    0.5934768751069592,
                                    0.3584135439476064,
                                    0.029994969158908008,
                                    0.01811461178652639,
                                ],
                                [
                                    0.6147991383644985,
                                    0.3386821841089405,
                                    0.029994969158908005,
                                    0.016523708367652927,
                                ],
                                [
                                    0.6147991383644985,
                                    0.029994969158908005,
                                    0.3386821841089405,
                                    0.016523708367652927,
                                ],
                                [
                                    0.5934768751069592,
                                    0.029994969158908008,
                                    0.3584135439476064,
                                    0.01811461178652639,
                                ],
                                [
                                    0.9076097356099433,
                                    0.04428068344462229,
                                    0.04587158686349575,
                                    0.002237994081938643,
                                ],
                                [
                                    0.9076097356099433,
                                    0.04587158686349575,
                                    0.04428068344462229,
                                    0.002237994081938643,
                                ],
                                [
                                    0.10760197535314313,
                                    0.2427831361340244,
                                    0.19949433617801599,
                                    0.45012055233481646,
                                ],
                                [
                                    0.10760197535314313,
                                    0.19949433617801599,
                                    0.2427831361340244,
                                    0.45012055233481646,
                                ],
                                [
                                    0.2990678790707202,
                                    0.6747890766823145,
                                    0.008028432460438944,
                                    0.018114611786526392,
                                ],
                                [
                                    0.3423566790267286,
                                    0.6347301542968586,
                                    0.008028432460438944,
                                    0.014884734215973834,
                                ],
                                [
                                    0.3423566790267286,
                                    0.008028432460438944,
                                    0.6347301542968586,
                                    0.014884734215973834,
                                ],
                                [
                                    0.2990678790707202,
                                    0.008028432460438944,
                                    0.6747890766823145,
                                    0.018114611786526392,
                                ],
                                [
                                    0.9515428090068815,
                                    0.022314146746153226,
                                    0.02554402431670579,
                                    0.0005990199302595509,
                                ],
                                [
                                    0.9515428090068815,
                                    0.02554402431670579,
                                    0.022314146746153226,
                                    0.0005990199302595509,
                                ],
                                [
                                    0.008059329532117873,
                                    0.11667673162014601,
                                    0.05655173368142983,
                                    0.8187122051663063,
                                ],
                                [
                                    0.008059329532117873,
                                    0.05655173368142983,
                                    0.11667673162014601,
                                    0.8187122051663063,
                                ],
                                [
                                    0.06400973798124898,
                                    0.9266834157544934,
                                    0.0006013252322987148,
                                    0.008705521031958834,
                                ],
                                [
                                    0.12413473591996516,
                                    0.8710444830906088,
                                    0.0006013252322987151,
                                    0.004219455757127304,
                                ],
                                [
                                    0.12413473591996516,
                                    0.0006013252322987151,
                                    0.8710444830906088,
                                    0.004219455757127304,
                                ],
                                [
                                    0.06400973798124898,
                                    0.0006013252322987148,
                                    0.9266834157544934,
                                    0.008705521031958834,
                                ],
                                [
                                    0.9859172390138586,
                                    0.004775914721883775,
                                    0.009261979996715304,
                                    4.486626754224335e-05,
                                ],
                                [
                                    0.9859172390138586,
                                    0.009261979996715304,
                                    0.004775914721883775,
                                    4.486626754224335e-05,
                                ],
                                [
                                    0.5426968009585259,
                                    0.3277463568997841,
                                    0.08077504330734123,
                                    0.04878179883434867,
                                ],
                                [
                                    0.5426968009585259,
                                    0.08077504330734123,
                                    0.3277463568997841,
                                    0.04878179883434867,
                                ],
                                [
                                    0.5829799797002551,
                                    0.3520742413716027,
                                    0.0404918645656121,
                                    0.02445391436253008,
                                ],
                                [
                                    0.6031332746824886,
                                    0.08977041378635228,
                                    0.26730988317582144,
                                    0.0397864283553376,
                                ],
                                [
                                    0.6031332746824886,
                                    0.26730988317582144,
                                    0.08977041378635228,
                                    0.0397864283553376,
                                ],
                                [
                                    0.5829799797002551,
                                    0.0404918645656121,
                                    0.3520742413716027,
                                    0.02445391436253008,
                                ],
                                [
                                    0.6479025186990492,
                                    0.2871517023728085,
                                    0.04500116976979164,
                                    0.01994460915835054,
                                ],
                                [
                                    0.6479025186990492,
                                    0.04500116976979164,
                                    0.2871517023728085,
                                    0.01994460915835054,
                                ],
                                [
                                    0.2894398855253776,
                                    0.3553542219980289,
                                    0.15944741376631252,
                                    0.19575847871028093,
                                ],
                                [
                                    0.2894398855253776,
                                    0.15944741376631252,
                                    0.3553542219980289,
                                    0.19575847871028093,
                                ],
                                [
                                    0.42729151943103916,
                                    0.5245988996235265,
                                    0.021595779860651004,
                                    0.026513801084783392,
                                ],
                                [
                                    0.502228052500494,
                                    0.276668724998768,
                                    0.14256605502291253,
                                    0.07853716747782546,
                                ],
                                [
                                    0.502228052500494,
                                    0.14256605502291253,
                                    0.276668724998768,
                                    0.07853716747782546,
                                ],
                                [
                                    0.42729151943103916,
                                    0.021595779860651004,
                                    0.5245988996235265,
                                    0.026513801084783392,
                                ],
                                [
                                    0.7414243799340232,
                                    0.21046603912054238,
                                    0.03747239756523875,
                                    0.010637183380195647,
                                ],
                                [
                                    0.7414243799340232,
                                    0.03747239756523875,
                                    0.21046603912054238,
                                    0.010637183380195647,
                                ],
                                [
                                    0.0774712772660931,
                                    0.27291383422107446,
                                    0.1436319452346449,
                                    0.5059829432781875,
                                ],
                                [
                                    0.0774712772660931,
                                    0.1436319452346449,
                                    0.27291383422107446,
                                    0.5059829432781875,
                                ],
                                [
                                    0.2153229111717546,
                                    0.75853404458128,
                                    0.005780311328983416,
                                    0.02036273291798192,
                                ],
                                [
                                    0.31222598093967857,
                                    0.5788677633534876,
                                    0.038159130547488956,
                                    0.07074712515934489,
                                ],
                                [
                                    0.31222598093967857,
                                    0.038159130547488956,
                                    0.5788677633534876,
                                    0.07074712515934489,
                                ],
                                [
                                    0.2153229111717546,
                                    0.005780311328983416,
                                    0.75853404458128,
                                    0.02036273291798192,
                                ],
                                [
                                    0.8677978411079159,
                                    0.10605911464511877,
                                    0.02329590318525026,
                                    0.0028471410617150784,
                                ],
                                [
                                    0.8677978411079159,
                                    0.02329590318525026,
                                    0.10605911464511877,
                                    0.0028471410617150784,
                                ],
                                [
                                    0.005802556604675559,
                                    0.11893350454758832,
                                    0.040716120921885465,
                                    0.8345478179258506,
                                ],
                                [
                                    0.005802556604675559,
                                    0.040716120921885465,
                                    0.11893350454758832,
                                    0.8345478179258506,
                                ],
                                [
                                    0.04608573534640475,
                                    0.9446074183893377,
                                    0.0004329421801562761,
                                    0.008873904084101273,
                                ],
                                [
                                    0.12187796299252285,
                                    0.8552088703310644,
                                    0.0028580981597410415,
                                    0.020055068516671756,
                                ],
                                [
                                    0.12187796299252285,
                                    0.0028580981597410415,
                                    0.8552088703310644,
                                    0.020055068516671756,
                                ],
                                [
                                    0.04608573534640475,
                                    0.0004329421801562761,
                                    0.9446074183893377,
                                    0.008873904084101273,
                                ],
                                [
                                    0.9679932363790144,
                                    0.022699917356728112,
                                    0.009093596944572867,
                                    0.00021324931968468299,
                                ],
                                [
                                    0.9679932363790144,
                                    0.009093596944572867,
                                    0.022699917356728112,
                                    0.00021324931968468299,
                                ],
                                [
                                    0.2673098831758215,
                                    0.6031332746824886,
                                    0.039786428355337605,
                                    0.08977041378635228,
                                ],
                                [
                                    0.2673098831758215,
                                    0.039786428355337605,
                                    0.6031332746824886,
                                    0.08977041378635228,
                                ],
                                [
                                    0.28715170237280857,
                                    0.6479025186990492,
                                    0.019944609158350543,
                                    0.04500116976979164,
                                ],
                                [
                                    0.3277463568997842,
                                    0.04878179883434868,
                                    0.5426968009585259,
                                    0.0807750433073412,
                                ],
                                [
                                    0.3277463568997842,
                                    0.5426968009585259,
                                    0.04878179883434868,
                                    0.0807750433073412,
                                ],
                                [
                                    0.28715170237280857,
                                    0.019944609158350543,
                                    0.6479025186990492,
                                    0.04500116976979164,
                                ],
                                [
                                    0.3520742413716028,
                                    0.582979979700255,
                                    0.024453914362530086,
                                    0.040491864565612094,
                                ],
                                [
                                    0.3520742413716028,
                                    0.024453914362530086,
                                    0.582979979700255,
                                    0.040491864565612094,
                                ],
                                [
                                    0.14256605502291253,
                                    0.502228052500494,
                                    0.07853716747782546,
                                    0.276668724998768,
                                ],
                                [
                                    0.14256605502291253,
                                    0.07853716747782546,
                                    0.502228052500494,
                                    0.276668724998768,
                                ],
                                [
                                    0.21046603912054235,
                                    0.7414243799340232,
                                    0.010637183380195646,
                                    0.03747239756523875,
                                ],
                                [
                                    0.3553542219980289,
                                    0.19575847871028093,
                                    0.2894398855253776,
                                    0.15944741376631252,
                                ],
                                [
                                    0.3553542219980289,
                                    0.2894398855253776,
                                    0.19575847871028093,
                                    0.15944741376631252,
                                ],
                                [
                                    0.21046603912054235,
                                    0.010637183380195646,
                                    0.7414243799340232,
                                    0.03747239756523875,
                                ],
                                [
                                    0.5245988996235265,
                                    0.42729151943103916,
                                    0.026513801084783392,
                                    0.021595779860651004,
                                ],
                                [
                                    0.5245988996235265,
                                    0.026513801084783392,
                                    0.42729151943103916,
                                    0.021595779860651004,
                                ],
                                [
                                    0.03815913054748896,
                                    0.31222598093967857,
                                    0.0707471251593449,
                                    0.5788677633534876,
                                ],
                                [
                                    0.03815913054748896,
                                    0.0707471251593449,
                                    0.31222598093967857,
                                    0.5788677633534876,
                                ],
                                [
                                    0.1060591146451188,
                                    0.8677978411079159,
                                    0.0028471410617150793,
                                    0.02329590318525026,
                                ],
                                [
                                    0.27291383422107446,
                                    0.5059829432781875,
                                    0.07747127726609311,
                                    0.14363194523464493,
                                ],
                                [
                                    0.27291383422107446,
                                    0.07747127726609311,
                                    0.5059829432781875,
                                    0.14363194523464493,
                                ],
                                [
                                    0.1060591146451188,
                                    0.0028471410617150793,
                                    0.8677978411079159,
                                    0.02329590318525026,
                                ],
                                [
                                    0.75853404458128,
                                    0.21532291117175462,
                                    0.02036273291798192,
                                    0.005780311328983416,
                                ],
                                [
                                    0.75853404458128,
                                    0.02036273291798192,
                                    0.21532291117175462,
                                    0.005780311328983416,
                                ],
                                [
                                    0.002858098159741049,
                                    0.12187796299252283,
                                    0.020055068516671805,
                                    0.8552088703310643,
                                ],
                                [
                                    0.002858098159741049,
                                    0.020055068516671805,
                                    0.12187796299252283,
                                    0.8552088703310643,
                                ],
                                [
                                    0.02269991735672817,
                                    0.9679932363790142,
                                    0.00021324931968468353,
                                    0.009093596944572865,
                                ],
                                [
                                    0.11893350454758833,
                                    0.8345478179258508,
                                    0.005802556604675552,
                                    0.04071612092188542,
                                ],
                                [
                                    0.11893350454758833,
                                    0.005802556604675552,
                                    0.8345478179258508,
                                    0.04071612092188542,
                                ],
                                [
                                    0.02269991735672817,
                                    0.00021324931968468353,
                                    0.9679932363790142,
                                    0.009093596944572865,
                                ],
                                [
                                    0.9446074183893378,
                                    0.04608573534640469,
                                    0.008873904084101273,
                                    0.00043294218015627555,
                                ],
                                [
                                    0.9446074183893378,
                                    0.008873904084101273,
                                    0.04608573534640469,
                                    0.00043294218015627555,
                                ],
                                [
                                    0.05624025789618335,
                                    0.8142028999621267,
                                    0.008370805317364347,
                                    0.12118603682432554,
                                ],
                                [
                                    0.05624025789618335,
                                    0.008370805317364347,
                                    0.8142028999621267,
                                    0.12118603682432554,
                                ],
                                [
                                    0.06041484738576841,
                                    0.8746393736860893,
                                    0.004196215827779289,
                                    0.0607495631003629,
                                ],
                                [
                                    0.11667673162014604,
                                    0.017366175796375425,
                                    0.753766426238164,
                                    0.11219066634531447,
                                ],
                                [
                                    0.11667673162014604,
                                    0.753766426238164,
                                    0.017366175796375425,
                                    0.11219066634531447,
                                ],
                                [
                                    0.06041484738576841,
                                    0.004196215827779289,
                                    0.8746393736860893,
                                    0.0607495631003629,
                                ],
                                [
                                    0.12533738638456263,
                                    0.8097168346872952,
                                    0.008705521031958834,
                                    0.05624025789618335,
                                ],
                                [
                                    0.12533738638456263,
                                    0.008705521031958834,
                                    0.8097168346872952,
                                    0.05624025789618335,
                                ],
                                [
                                    0.029994969158908064,
                                    0.6147991383644984,
                                    0.016523708367652958,
                                    0.3386821841089405,
                                ],
                                [
                                    0.029994969158908064,
                                    0.016523708367652958,
                                    0.6147991383644984,
                                    0.3386821841089405,
                                ],
                                [
                                    0.044280683444622375,
                                    0.9076097356099433,
                                    0.0022379940819386474,
                                    0.045871586863495746,
                                ],
                                [
                                    0.24278313613402444,
                                    0.13374501960010846,
                                    0.4020109713893821,
                                    0.221460872876485,
                                ],
                                [
                                    0.24278313613402444,
                                    0.4020109713893821,
                                    0.13374501960010846,
                                    0.221460872876485,
                                ],
                                [
                                    0.044280683444622375,
                                    0.0022379940819386474,
                                    0.9076097356099433,
                                    0.045871586863495746,
                                ],
                                [
                                    0.3584135439476065,
                                    0.5934768751069591,
                                    0.018114611786526395,
                                    0.029994969158908,
                                ],
                                [
                                    0.3584135439476065,
                                    0.018114611786526395,
                                    0.5934768751069591,
                                    0.029994969158908,
                                ],
                                [
                                    0.00802843246043897,
                                    0.34235667902672856,
                                    0.014884734215973885,
                                    0.6347301542968585,
                                ],
                                [
                                    0.00802843246043897,
                                    0.014884734215973885,
                                    0.34235667902672856,
                                    0.6347301542968585,
                                ],
                                [
                                    0.022314146746153302,
                                    0.9515428090068814,
                                    0.000599019930259553,
                                    0.025544024316705785,
                                ],
                                [
                                    0.2427831361340244,
                                    0.45012055233481646,
                                    0.10760197535314311,
                                    0.19949433617801596,
                                ],
                                [
                                    0.2427831361340244,
                                    0.10760197535314311,
                                    0.45012055233481646,
                                    0.19949433617801596,
                                ],
                                [
                                    0.022314146746153302,
                                    0.000599019930259553,
                                    0.9515428090068814,
                                    0.025544024316705785,
                                ],
                                [
                                    0.6747890766823145,
                                    0.29906787907072013,
                                    0.018114611786526392,
                                    0.008028432460438942,
                                ],
                                [
                                    0.6747890766823145,
                                    0.018114611786526392,
                                    0.29906787907072013,
                                    0.008028432460438942,
                                ],
                                [
                                    0.0006013252322987208,
                                    0.12413473591996516,
                                    0.004219455757127345,
                                    0.8710444830906088,
                                ],
                                [
                                    0.0006013252322987208,
                                    0.004219455757127345,
                                    0.12413473591996516,
                                    0.8710444830906088,
                                ],
                                [
                                    0.004775914721883822,
                                    0.9859172390138586,
                                    4.4866267542243785e-05,
                                    0.009261979996715304,
                                ],
                                [
                                    0.11667673162014601,
                                    0.8187122051663063,
                                    0.008059329532117878,
                                    0.056551733681429864,
                                ],
                                [
                                    0.11667673162014601,
                                    0.008059329532117878,
                                    0.8187122051663063,
                                    0.056551733681429864,
                                ],
                                [
                                    0.004775914721883822,
                                    4.4866267542243785e-05,
                                    0.9859172390138586,
                                    0.009261979996715304,
                                ],
                                [
                                    0.9266834157544934,
                                    0.06400973798124902,
                                    0.008705521031958834,
                                    0.0006013252322987152,
                                ],
                                [
                                    0.9266834157544934,
                                    0.008705521031958834,
                                    0.06400973798124902,
                                    0.0006013252322987152,
                                ],
                                [
                                    0.5426968009585259,
                                    0.08400492087789377,
                                    0.32326029162495257,
                                    0.05003798653862764,
                                ],
                                [
                                    0.5426968009585259,
                                    0.32326029162495257,
                                    0.08400492087789377,
                                    0.05003798653862764,
                                ],
                                [
                                    0.598647209407657,
                                    0.09266557564231036,
                                    0.26730988317582144,
                                    0.04137733177421106,
                                ],
                                [
                                    0.5862098572708075,
                                    0.34917907951564464,
                                    0.040491864565612094,
                                    0.024119198647935592,
                                ],
                                [
                                    0.5862098572708075,
                                    0.040491864565612094,
                                    0.34917907951564464,
                                    0.024119198647935592,
                                ],
                                [
                                    0.598647209407657,
                                    0.26730988317582144,
                                    0.09266557564231036,
                                    0.04137733177421106,
                                ],
                                [
                                    0.6466463309947702,
                                    0.044666454055197154,
                                    0.288742605791682,
                                    0.019944609158350536,
                                ],
                                [
                                    0.6466463309947702,
                                    0.288742605791682,
                                    0.044666454055197154,
                                    0.019944609158350536,
                                ],
                                [
                                    0.2894398855253776,
                                    0.17479901826375918,
                                    0.33403195874048963,
                                    0.2017291374703736,
                                ],
                                [
                                    0.2894398855253776,
                                    0.33403195874048963,
                                    0.17479901826375918,
                                    0.2017291374703736,
                                ],
                                [
                                    0.4809057892429547,
                                    0.29042942607734124,
                                    0.14256605502291253,
                                    0.08609872965679156,
                                ],
                                [
                                    0.4426431239284858,
                                    0.5108381985449533,
                                    0.021595779860651,
                                    0.024922897665909934,
                                ],
                                [
                                    0.4426431239284858,
                                    0.021595779860651,
                                    0.5108381985449533,
                                    0.024922897665909934,
                                ],
                                [
                                    0.4809057892429547,
                                    0.14256605502291253,
                                    0.29042942607734124,
                                    0.08609872965679156,
                                ],
                                [
                                    0.7354537211739306,
                                    0.03588149414636529,
                                    0.21802760129950846,
                                    0.010637183380195647,
                                ],
                                [
                                    0.7354537211739306,
                                    0.21802760129950846,
                                    0.03588149414636529,
                                    0.010637183380195647,
                                ],
                                [
                                    0.07747127726609312,
                                    0.17479901826375924,
                                    0.229625034265066,
                                    0.5181046702050817,
                                ],
                                [
                                    0.07747127726609312,
                                    0.229625034265066,
                                    0.17479901826375924,
                                    0.5181046702050817,
                                ],
                                [
                                    0.2689371809836702,
                                    0.6068049588120493,
                                    0.03815913054748896,
                                    0.08609872965679159,
                                ],
                                [
                                    0.24648998420086896,
                                    0.7305968491227183,
                                    0.005780311328983417,
                                    0.017132855347429362,
                                ],
                                [
                                    0.24648998420086896,
                                    0.005780311328983417,
                                    0.7305968491227183,
                                    0.017132855347429362,
                                ],
                                [
                                    0.2689371809836702,
                                    0.03815913054748896,
                                    0.6068049588120493,
                                    0.08609872965679159,
                                ],
                                [
                                    0.8556761141810217,
                                    0.0200660256146977,
                                    0.12141071914256549,
                                    0.002847141061715079,
                                ],
                                [
                                    0.8556761141810217,
                                    0.12141071914256549,
                                    0.0200660256146977,
                                    0.002847141061715079,
                                ],
                                [
                                    0.00580255660467555,
                                    0.0840049208778938,
                                    0.05880850660887215,
                                    0.8513840159085585,
                                ],
                                [
                                    0.00580255660467555,
                                    0.05880850660887215,
                                    0.0840049208778938,
                                    0.8513840159085585,
                                ],
                                [
                                    0.06175296505380666,
                                    0.8940116050122412,
                                    0.0028580981597410406,
                                    0.041377331774211074,
                                ],
                                [
                                    0.08937453530241306,
                                    0.9058046837081609,
                                    0.00043294218015627555,
                                    0.004387838809269743,
                                ],
                                [
                                    0.08937453530241306,
                                    0.00043294218015627555,
                                    0.9058046837081609,
                                    0.004387838809269743,
                                ],
                                [
                                    0.06175296505380666,
                                    0.0028580981597410406,
                                    0.8940116050122412,
                                    0.041377331774211074,
                                ],
                                [
                                    0.9511570383963065,
                                    0.004607531669741336,
                                    0.04402218061426743,
                                    0.000213249319684683,
                                ],
                                [
                                    0.9511570383963065,
                                    0.04402218061426743,
                                    0.004607531669741336,
                                    0.000213249319684683,
                                ],
                                [
                                    0.3907308783179471,
                                    0.2359708435184726,
                                    0.23274096594792007,
                                    0.14055731221566017,
                                ],
                                [
                                    0.3907308783179471,
                                    0.23274096594792007,
                                    0.2359708435184726,
                                    0.14055731221566017,
                                ],
                                [
                                    0.4310140570596762,
                                    0.2602987279902912,
                                    0.19245778720619097,
                                    0.11622942774384157,
                                ],
                                [
                                    0.4342439346302287,
                                    0.2586597538386121,
                                    0.19245778720619094,
                                    0.11463852432496811,
                                ],
                                [
                                    0.4342439346302287,
                                    0.19245778720619094,
                                    0.2586597538386121,
                                    0.11463852432496811,
                                ],
                                [
                                    0.4310140570596762,
                                    0.19245778720619097,
                                    0.2602987279902912,
                                    0.11622942774384157,
                                ],
                                [
                                    0.4790131786467894,
                                    0.212299606403178,
                                    0.21389050982205146,
                                    0.09479670512798105,
                                ],
                                [
                                    0.4790131786467894,
                                    0.21389050982205146,
                                    0.212299606403178,
                                    0.09479670512798105,
                                ],
                                [
                                    0.2083909477480404,
                                    0.2558479560410964,
                                    0.24049635154364973,
                                    0.2952647446672135,
                                ],
                                [
                                    0.2083909477480404,
                                    0.24049635154364973,
                                    0.2558479560410964,
                                    0.2952647446672135,
                                ],
                                [
                                    0.3462425816537019,
                                    0.425092633666594,
                                    0.10264471763798821,
                                    0.1260200670417159,
                                ],
                                [
                                    0.3615941861511486,
                                    0.4173025913481134,
                                    0.10264471763798823,
                                    0.1184585048627498,
                                ],
                                [
                                    0.3615941861511486,
                                    0.10264471763798823,
                                    0.4173025913481134,
                                    0.1184585048627498,
                                ],
                                [
                                    0.3462425816537019,
                                    0.10264471763798821,
                                    0.425092633666594,
                                    0.1260200670417159,
                                ],
                                [
                                    0.6007905135846778,
                                    0.17054470173561806,
                                    0.17810626391458415,
                                    0.05055852076511997,
                                ],
                                [
                                    0.6007905135846778,
                                    0.17810626391458415,
                                    0.17054470173561806,
                                    0.05055852076511997,
                                ],
                                [
                                    0.05577777528286387,
                                    0.1964925202469885,
                                    0.16532544721787412,
                                    0.5824042572522735,
                                ],
                                [
                                    0.05577777528286387,
                                    0.16532544721787412,
                                    0.1964925202469885,
                                    0.5824042572522735,
                                ],
                                [
                                    0.19362940918852536,
                                    0.6821127306071941,
                                    0.02747381331221264,
                                    0.09678404689206792,
                                ],
                                [
                                    0.2247964822176397,
                                    0.6662972620755264,
                                    0.027473813312212644,
                                    0.0814324423946212,
                                ],
                                [
                                    0.2247964822176397,
                                    0.027473813312212644,
                                    0.6662972620755264,
                                    0.0814324423946212,
                                ],
                                [
                                    0.19362940918852536,
                                    0.02747381331221264,
                                    0.6821127306071941,
                                    0.09678404689206792,
                                ],
                                [
                                    0.7803683423858769,
                                    0.09537379740984246,
                                    0.11072540190728916,
                                    0.013532458296991392,
                                ],
                                [
                                    0.7803683423858769,
                                    0.11072540190728916,
                                    0.09537379740984246,
                                    0.013532458296991392,
                                ],
                                [
                                    0.004177725084485534,
                                    0.0856297523980838,
                                    0.04234095244207549,
                                    0.8678515700753552,
                                ],
                                [
                                    0.004177725084485534,
                                    0.04234095244207549,
                                    0.0856297523980838,
                                    0.8678515700753552,
                                ],
                                [
                                    0.044460903826214725,
                                    0.9113036662398332,
                                    0.0020577737003463032,
                                    0.042177656233605816,
                                ],
                                [
                                    0.08774970378222305,
                                    0.8893371295413642,
                                    0.0020577737003463,
                                    0.020855392976066495,
                                ],
                                [
                                    0.08774970378222305,
                                    0.0020577737003463,
                                    0.8893371295413642,
                                    0.020855392976066495,
                                ],
                                [
                                    0.044460903826214725,
                                    0.0020577737003463032,
                                    0.9113036662398332,
                                    0.042177656233605816,
                                ],
                                [
                                    0.9338649771687145,
                                    0.02189959289733337,
                                    0.043221856154872694,
                                    0.0010135737790794247,
                                ],
                                [
                                    0.9338649771687145,
                                    0.043221856154872694,
                                    0.02189959289733337,
                                    0.0010135737790794247,
                                ],
                                [
                                    0.19245778720619097,
                                    0.4342439346302287,
                                    0.11463852432496814,
                                    0.2586597538386121,
                                ],
                                [
                                    0.19245778720619097,
                                    0.11463852432496814,
                                    0.4342439346302287,
                                    0.2586597538386121,
                                ],
                                [
                                    0.21229960640317805,
                                    0.4790131786467894,
                                    0.09479670512798108,
                                    0.21389050982205146,
                                ],
                                [
                                    0.23597084351847267,
                                    0.1405573122156602,
                                    0.390730878317947,
                                    0.23274096594792004,
                                ],
                                [
                                    0.23597084351847267,
                                    0.390730878317947,
                                    0.1405573122156602,
                                    0.23274096594792004,
                                ],
                                [
                                    0.21229960640317805,
                                    0.09479670512798108,
                                    0.4790131786467894,
                                    0.21389050982205146,
                                ],
                                [
                                    0.26029872799029125,
                                    0.43101405705967616,
                                    0.11622942774384161,
                                    0.19245778720619094,
                                ],
                                [
                                    0.26029872799029125,
                                    0.11622942774384161,
                                    0.43101405705967616,
                                    0.19245778720619094,
                                ],
                                [
                                    0.10264471763798821,
                                    0.3615941861511486,
                                    0.11845850486274978,
                                    0.4173025913481134,
                                ],
                                [
                                    0.10264471763798821,
                                    0.11845850486274978,
                                    0.3615941861511486,
                                    0.4173025913481134,
                                ],
                                [
                                    0.17054470173561803,
                                    0.6007905135846778,
                                    0.05055852076511996,
                                    0.17810626391458415,
                                ],
                                [
                                    0.2558479560410964,
                                    0.2952647446672135,
                                    0.2083909477480404,
                                    0.24049635154364973,
                                ],
                                [
                                    0.2558479560410964,
                                    0.2083909477480404,
                                    0.2952647446672135,
                                    0.24049635154364973,
                                ],
                                [
                                    0.17054470173561803,
                                    0.05055852076511996,
                                    0.6007905135846778,
                                    0.17810626391458415,
                                ],
                                [
                                    0.425092633666594,
                                    0.3462425816537019,
                                    0.1260200670417159,
                                    0.10264471763798821,
                                ],
                                [
                                    0.425092633666594,
                                    0.1260200670417159,
                                    0.3462425816537019,
                                    0.10264471763798821,
                                ],
                                [
                                    0.02747381331221265,
                                    0.2247964822176397,
                                    0.08143244239462122,
                                    0.6662972620755264,
                                ],
                                [
                                    0.02747381331221265,
                                    0.08143244239462122,
                                    0.2247964822176397,
                                    0.6662972620755264,
                                ],
                                [
                                    0.09537379740984249,
                                    0.7803683423858769,
                                    0.013532458296991396,
                                    0.11072540190728916,
                                ],
                                [
                                    0.1964925202469885,
                                    0.5824042572522735,
                                    0.05577777528286389,
                                    0.16532544721787415,
                                ],
                                [
                                    0.1964925202469885,
                                    0.05577777528286389,
                                    0.5824042572522735,
                                    0.16532544721787415,
                                ],
                                [
                                    0.09537379740984249,
                                    0.013532458296991396,
                                    0.7803683423858769,
                                    0.11072540190728916,
                                ],
                                [
                                    0.6821127306071941,
                                    0.1936294091885254,
                                    0.09678404689206792,
                                    0.027473813312212644,
                                ],
                                [
                                    0.6821127306071941,
                                    0.09678404689206792,
                                    0.1936294091885254,
                                    0.027473813312212644,
                                ],
                                [
                                    0.002057773700346306,
                                    0.08774970378222303,
                                    0.02085539297606655,
                                    0.8893371295413641,
                                ],
                                [
                                    0.002057773700346306,
                                    0.02085539297606655,
                                    0.08774970378222303,
                                    0.8893371295413641,
                                ],
                                [
                                    0.02189959289733343,
                                    0.9338649771687144,
                                    0.0010135737790794273,
                                    0.04322185615487269,
                                ],
                                [
                                    0.08562975239808382,
                                    0.8678515700753553,
                                    0.004177725084485529,
                                    0.04234095244207544,
                                ],
                                [
                                    0.08562975239808382,
                                    0.004177725084485529,
                                    0.8678515700753553,
                                    0.04234095244207544,
                                ],
                                [
                                    0.02189959289733343,
                                    0.0010135737790794273,
                                    0.9338649771687144,
                                    0.04322185615487269,
                                ],
                                [
                                    0.9113036662398333,
                                    0.04446090382621467,
                                    0.042177656233605816,
                                    0.0020577737003463006,
                                ],
                                [
                                    0.9113036662398333,
                                    0.042177656233605816,
                                    0.04446090382621467,
                                    0.0020577737003463006,
                                ],
                                [
                                    0.0404918645656121,
                                    0.5862098572708075,
                                    0.0241191986479356,
                                    0.34917907951564464,
                                ],
                                [
                                    0.0404918645656121,
                                    0.0241191986479356,
                                    0.5862098572708075,
                                    0.34917907951564464,
                                ],
                                [
                                    0.04466645405519716,
                                    0.6466463309947702,
                                    0.01994460915835054,
                                    0.288742605791682,
                                ],
                                [
                                    0.0840049208778938,
                                    0.05003798653862766,
                                    0.5426968009585259,
                                    0.32326029162495257,
                                ],
                                [
                                    0.0840049208778938,
                                    0.5426968009585259,
                                    0.05003798653862766,
                                    0.32326029162495257,
                                ],
                                [
                                    0.04466645405519716,
                                    0.01994460915835054,
                                    0.6466463309947702,
                                    0.288742605791682,
                                ],
                                [
                                    0.09266557564231039,
                                    0.598647209407657,
                                    0.041377331774211074,
                                    0.26730988317582144,
                                ],
                                [
                                    0.09266557564231039,
                                    0.041377331774211074,
                                    0.598647209407657,
                                    0.26730988317582144,
                                ],
                                [
                                    0.021595779860651042,
                                    0.44264312392848576,
                                    0.024922897665909983,
                                    0.5108381985449533,
                                ],
                                [
                                    0.021595779860651042,
                                    0.024922897665909983,
                                    0.44264312392848576,
                                    0.5108381985449533,
                                ],
                                [
                                    0.03588149414636536,
                                    0.7354537211739306,
                                    0.010637183380195668,
                                    0.21802760129950843,
                                ],
                                [
                                    0.17479901826375924,
                                    0.20172913747037366,
                                    0.2894398855253776,
                                    0.3340319587404895,
                                ],
                                [
                                    0.17479901826375924,
                                    0.2894398855253776,
                                    0.20172913747037366,
                                    0.3340319587404895,
                                ],
                                [
                                    0.03588149414636536,
                                    0.010637183380195668,
                                    0.7354537211739306,
                                    0.21802760129950843,
                                ],
                                [
                                    0.2904294260773413,
                                    0.48090578924295463,
                                    0.08609872965679159,
                                    0.1425660550229125,
                                ],
                                [
                                    0.2904294260773413,
                                    0.08609872965679159,
                                    0.48090578924295463,
                                    0.1425660550229125,
                                ],
                                [
                                    0.005780311328983436,
                                    0.24648998420086893,
                                    0.017132855347429417,
                                    0.7305968491227183,
                                ],
                                [
                                    0.005780311328983436,
                                    0.017132855347429417,
                                    0.24648998420086893,
                                    0.7305968491227183,
                                ],
                                [
                                    0.020066025614697766,
                                    0.8556761141810217,
                                    0.0028471410617150884,
                                    0.12141071914256547,
                                ],
                                [
                                    0.17479901826375924,
                                    0.5181046702050817,
                                    0.07747127726609311,
                                    0.22962503426506597,
                                ],
                                [
                                    0.17479901826375924,
                                    0.07747127726609311,
                                    0.5181046702050817,
                                    0.22962503426506597,
                                ],
                                [
                                    0.020066025614697766,
                                    0.0028471410617150884,
                                    0.8556761141810217,
                                    0.12141071914256547,
                                ],
                                [
                                    0.6068049588120493,
                                    0.26893718098367014,
                                    0.08609872965679159,
                                    0.038159130547488956,
                                ],
                                [
                                    0.6068049588120493,
                                    0.08609872965679159,
                                    0.26893718098367014,
                                    0.038159130547488956,
                                ],
                                [
                                    0.0004329421801562797,
                                    0.08937453530241306,
                                    0.0043878388092697855,
                                    0.9058046837081609,
                                ],
                                [
                                    0.0004329421801562797,
                                    0.0043878388092697855,
                                    0.08937453530241306,
                                    0.9058046837081609,
                                ],
                                [
                                    0.00460753166974138,
                                    0.9511570383963065,
                                    0.00021324931968468507,
                                    0.04402218061426743,
                                ],
                                [
                                    0.0840049208778938,
                                    0.8513840159085585,
                                    0.005802556604675554,
                                    0.05880850660887219,
                                ],
                                [
                                    0.0840049208778938,
                                    0.005802556604675554,
                                    0.8513840159085585,
                                    0.05880850660887219,
                                ],
                                [
                                    0.00460753166974138,
                                    0.00021324931968468507,
                                    0.9511570383963065,
                                    0.04402218061426743,
                                ],
                                [
                                    0.8940116050122412,
                                    0.0617529650538067,
                                    0.041377331774211074,
                                    0.0028580981597410423,
                                ],
                                [
                                    0.8940116050122412,
                                    0.041377331774211074,
                                    0.0617529650538067,
                                    0.0028580981597410423,
                                ],
                                [
                                    0.2673098831758215,
                                    0.04137733177421107,
                                    0.598647209407657,
                                    0.09266557564231036,
                                ],
                                [
                                    0.2673098831758215,
                                    0.598647209407657,
                                    0.04137733177421107,
                                    0.09266557564231036,
                                ],
                                [
                                    0.3232602916249526,
                                    0.050037986538627656,
                                    0.5426968009585259,
                                    0.08400492087789377,
                                ],
                                [
                                    0.28874260579168204,
                                    0.6466463309947702,
                                    0.01994460915835054,
                                    0.044666454055197154,
                                ],
                                [
                                    0.28874260579168204,
                                    0.01994460915835054,
                                    0.6466463309947702,
                                    0.044666454055197154,
                                ],
                                [
                                    0.3232602916249526,
                                    0.5426968009585259,
                                    0.050037986538627656,
                                    0.08400492087789377,
                                ],
                                [
                                    0.3491790795156447,
                                    0.024119198647935595,
                                    0.5862098572708075,
                                    0.040491864565612094,
                                ],
                                [
                                    0.3491790795156447,
                                    0.5862098572708075,
                                    0.024119198647935595,
                                    0.040491864565612094,
                                ],
                                [
                                    0.14256605502291259,
                                    0.0860987296567916,
                                    0.48090578924295463,
                                    0.2904294260773412,
                                ],
                                [
                                    0.14256605502291259,
                                    0.48090578924295463,
                                    0.0860987296567916,
                                    0.2904294260773412,
                                ],
                                [
                                    0.33403195874048963,
                                    0.2017291374703736,
                                    0.2894398855253776,
                                    0.17479901826375915,
                                ],
                                [
                                    0.21802760129950854,
                                    0.7354537211739305,
                                    0.01063718338019565,
                                    0.03588149414636529,
                                ],
                                [
                                    0.21802760129950854,
                                    0.01063718338019565,
                                    0.7354537211739305,
                                    0.03588149414636529,
                                ],
                                [
                                    0.33403195874048963,
                                    0.2894398855253776,
                                    0.2017291374703736,
                                    0.17479901826375915,
                                ],
                                [
                                    0.5108381985449533,
                                    0.024922897665909934,
                                    0.44264312392848576,
                                    0.021595779860651,
                                ],
                                [
                                    0.5108381985449533,
                                    0.44264312392848576,
                                    0.024922897665909934,
                                    0.021595779860651,
                                ],
                                [
                                    0.038159130547488956,
                                    0.08609872965679158,
                                    0.2689371809836702,
                                    0.6068049588120493,
                                ],
                                [
                                    0.038159130547488956,
                                    0.2689371809836702,
                                    0.08609872965679158,
                                    0.6068049588120493,
                                ],
                                [
                                    0.229625034265066,
                                    0.5181046702050817,
                                    0.07747127726609312,
                                    0.17479901826375924,
                                ],
                                [
                                    0.12141071914256546,
                                    0.8556761141810217,
                                    0.0028471410617150784,
                                    0.0200660256146977,
                                ],
                                [
                                    0.12141071914256546,
                                    0.0028471410617150784,
                                    0.8556761141810217,
                                    0.0200660256146977,
                                ],
                                [
                                    0.229625034265066,
                                    0.07747127726609312,
                                    0.5181046702050817,
                                    0.17479901826375924,
                                ],
                                [
                                    0.7305968491227183,
                                    0.017132855347429362,
                                    0.24648998420086896,
                                    0.005780311328983417,
                                ],
                                [
                                    0.7305968491227183,
                                    0.24648998420086896,
                                    0.017132855347429362,
                                    0.005780311328983417,
                                ],
                                [
                                    0.0028580981597410415,
                                    0.04137733177421109,
                                    0.06175296505380666,
                                    0.8940116050122412,
                                ],
                                [
                                    0.0028580981597410415,
                                    0.06175296505380666,
                                    0.04137733177421109,
                                    0.8940116050122412,
                                ],
                                [
                                    0.05880850660887215,
                                    0.8513840159085585,
                                    0.0058025566046755505,
                                    0.08400492087789381,
                                ],
                                [
                                    0.044022180614267443,
                                    0.9511570383963065,
                                    0.00021324931968468307,
                                    0.004607531669741336,
                                ],
                                [
                                    0.044022180614267443,
                                    0.00021324931968468307,
                                    0.9511570383963065,
                                    0.004607531669741336,
                                ],
                                [
                                    0.05880850660887215,
                                    0.0058025566046755505,
                                    0.8513840159085585,
                                    0.08400492087789381,
                                ],
                                [
                                    0.9058046837081609,
                                    0.004387838809269743,
                                    0.08937453530241307,
                                    0.0004329421801562756,
                                ],
                                [
                                    0.9058046837081609,
                                    0.08937453530241307,
                                    0.004387838809269743,
                                    0.0004329421801562756,
                                ],
                                [
                                    0.192457787206191,
                                    0.1162294277438416,
                                    0.4310140570596762,
                                    0.2602987279902912,
                                ],
                                [
                                    0.192457787206191,
                                    0.4310140570596762,
                                    0.1162294277438416,
                                    0.2602987279902912,
                                ],
                                [
                                    0.23274096594792013,
                                    0.14055731221566017,
                                    0.3907308783179471,
                                    0.2359708435184726,
                                ],
                                [
                                    0.21389050982205152,
                                    0.4790131786467894,
                                    0.09479670512798108,
                                    0.212299606403178,
                                ],
                                [
                                    0.21389050982205152,
                                    0.09479670512798108,
                                    0.4790131786467894,
                                    0.212299606403178,
                                ],
                                [
                                    0.23274096594792013,
                                    0.3907308783179471,
                                    0.14055731221566017,
                                    0.2359708435184726,
                                ],
                                [
                                    0.25865975383861217,
                                    0.11463852432496813,
                                    0.4342439346302287,
                                    0.19245778720619094,
                                ],
                                [
                                    0.25865975383861217,
                                    0.4342439346302287,
                                    0.11463852432496813,
                                    0.19245778720619094,
                                ],
                                [
                                    0.10264471763798826,
                                    0.12602006704171592,
                                    0.34624258165370186,
                                    0.42509263366659394,
                                ],
                                [
                                    0.10264471763798826,
                                    0.34624258165370186,
                                    0.12602006704171592,
                                    0.42509263366659394,
                                ],
                                [
                                    0.24049635154364973,
                                    0.2952647446672135,
                                    0.20839094774804037,
                                    0.2558479560410964,
                                ],
                                [
                                    0.1781062639145842,
                                    0.6007905135846778,
                                    0.050558520765119984,
                                    0.17054470173561803,
                                ],
                                [
                                    0.1781062639145842,
                                    0.050558520765119984,
                                    0.6007905135846778,
                                    0.17054470173561803,
                                ],
                                [
                                    0.24049635154364973,
                                    0.20839094774804037,
                                    0.2952647446672135,
                                    0.2558479560410964,
                                ],
                                [
                                    0.4173025913481134,
                                    0.1184585048627498,
                                    0.3615941861511485,
                                    0.10264471763798821,
                                ],
                                [
                                    0.4173025913481134,
                                    0.3615941861511485,
                                    0.1184585048627498,
                                    0.10264471763798821,
                                ],
                                [
                                    0.027473813312212637,
                                    0.0967840468920679,
                                    0.19362940918852536,
                                    0.6821127306071941,
                                ],
                                [
                                    0.027473813312212637,
                                    0.19362940918852536,
                                    0.0967840468920679,
                                    0.6821127306071941,
                                ],
                                [
                                    0.16532544721787412,
                                    0.5824042572522735,
                                    0.05577777528286387,
                                    0.1964925202469885,
                                ],
                                [
                                    0.11072540190728915,
                                    0.7803683423858769,
                                    0.013532458296991389,
                                    0.09537379740984246,
                                ],
                                [
                                    0.11072540190728915,
                                    0.013532458296991389,
                                    0.7803683423858769,
                                    0.09537379740984246,
                                ],
                                [
                                    0.16532544721787412,
                                    0.05577777528286387,
                                    0.5824042572522735,
                                    0.1964925202469885,
                                ],
                                [
                                    0.6662972620755264,
                                    0.0814324423946212,
                                    0.2247964822176397,
                                    0.027473813312212644,
                                ],
                                [
                                    0.6662972620755264,
                                    0.2247964822176397,
                                    0.0814324423946212,
                                    0.027473813312212644,
                                ],
                                [
                                    0.0020577737003463037,
                                    0.04217765623360583,
                                    0.044460903826214725,
                                    0.9113036662398332,
                                ],
                                [
                                    0.0020577737003463037,
                                    0.044460903826214725,
                                    0.04217765623360583,
                                    0.9113036662398332,
                                ],
                                [
                                    0.04234095244207549,
                                    0.8678515700753552,
                                    0.004177725084485534,
                                    0.08562975239808382,
                                ],
                                [
                                    0.04322185615487271,
                                    0.9338649771687145,
                                    0.0010135737790794251,
                                    0.02189959289733337,
                                ],
                                [
                                    0.04322185615487271,
                                    0.0010135737790794251,
                                    0.9338649771687145,
                                    0.02189959289733337,
                                ],
                                [
                                    0.04234095244207549,
                                    0.004177725084485534,
                                    0.8678515700753552,
                                    0.08562975239808382,
                                ],
                                [
                                    0.8893371295413642,
                                    0.020855392976066495,
                                    0.08774970378222306,
                                    0.0020577737003463006,
                                ],
                                [
                                    0.8893371295413642,
                                    0.08774970378222306,
                                    0.020855392976066495,
                                    0.0020577737003463006,
                                ],
                                [
                                    0.09479670512798109,
                                    0.21389050982205152,
                                    0.21229960640317805,
                                    0.4790131786467894,
                                ],
                                [
                                    0.09479670512798109,
                                    0.21229960640317805,
                                    0.21389050982205152,
                                    0.4790131786467894,
                                ],
                                [
                                    0.11463852432496816,
                                    0.25865975383861217,
                                    0.19245778720619097,
                                    0.4342439346302287,
                                ],
                                [
                                    0.11622942774384162,
                                    0.26029872799029125,
                                    0.19245778720619097,
                                    0.43101405705967616,
                                ],
                                [
                                    0.11622942774384162,
                                    0.19245778720619097,
                                    0.26029872799029125,
                                    0.43101405705967616,
                                ],
                                [
                                    0.11463852432496816,
                                    0.19245778720619097,
                                    0.25865975383861217,
                                    0.4342439346302287,
                                ],
                                [
                                    0.14055731221566023,
                                    0.23274096594792007,
                                    0.23597084351847267,
                                    0.390730878317947,
                                ],
                                [
                                    0.14055731221566023,
                                    0.23597084351847267,
                                    0.23274096594792007,
                                    0.390730878317947,
                                ],
                                [
                                    0.050558520765119984,
                                    0.1781062639145842,
                                    0.170544701735618,
                                    0.6007905135846778,
                                ],
                                [
                                    0.050558520765119984,
                                    0.170544701735618,
                                    0.1781062639145842,
                                    0.6007905135846778,
                                ],
                                [
                                    0.11845850486274978,
                                    0.4173025913481134,
                                    0.1026447176379882,
                                    0.3615941861511485,
                                ],
                                [
                                    0.12602006704171592,
                                    0.42509263366659394,
                                    0.10264471763798826,
                                    0.34624258165370186,
                                ],
                                [
                                    0.12602006704171592,
                                    0.10264471763798826,
                                    0.42509263366659394,
                                    0.34624258165370186,
                                ],
                                [
                                    0.11845850486274978,
                                    0.1026447176379882,
                                    0.4173025913481134,
                                    0.3615941861511485,
                                ],
                                [
                                    0.2952647446672135,
                                    0.24049635154364973,
                                    0.2558479560410964,
                                    0.20839094774804037,
                                ],
                                [
                                    0.2952647446672135,
                                    0.2558479560410964,
                                    0.24049635154364973,
                                    0.20839094774804037,
                                ],
                                [
                                    0.013532458296991392,
                                    0.11072540190728915,
                                    0.09537379740984249,
                                    0.7803683423858769,
                                ],
                                [
                                    0.013532458296991392,
                                    0.09537379740984249,
                                    0.11072540190728915,
                                    0.7803683423858769,
                                ],
                                [
                                    0.08143244239462122,
                                    0.6662972620755264,
                                    0.02747381331221265,
                                    0.2247964822176397,
                                ],
                                [
                                    0.0967840468920679,
                                    0.6821127306071941,
                                    0.02747381331221264,
                                    0.1936294091885254,
                                ],
                                [
                                    0.0967840468920679,
                                    0.02747381331221264,
                                    0.6821127306071941,
                                    0.1936294091885254,
                                ],
                                [
                                    0.08143244239462122,
                                    0.02747381331221265,
                                    0.6662972620755264,
                                    0.2247964822176397,
                                ],
                                [
                                    0.5824042572522735,
                                    0.16532544721787415,
                                    0.1964925202469885,
                                    0.05577777528286389,
                                ],
                                [
                                    0.5824042572522735,
                                    0.1964925202469885,
                                    0.16532544721787415,
                                    0.05577777528286389,
                                ],
                                [
                                    0.0010135737790794277,
                                    0.0432218561548727,
                                    0.02189959289733343,
                                    0.9338649771687144,
                                ],
                                [
                                    0.0010135737790794277,
                                    0.02189959289733343,
                                    0.0432218561548727,
                                    0.9338649771687144,
                                ],
                                [
                                    0.02085539297606655,
                                    0.8893371295413641,
                                    0.002057773700346306,
                                    0.08774970378222305,
                                ],
                                [
                                    0.04217765623360583,
                                    0.9113036662398333,
                                    0.0020577737003463015,
                                    0.04446090382621467,
                                ],
                                [
                                    0.04217765623360583,
                                    0.0020577737003463015,
                                    0.9113036662398333,
                                    0.04446090382621467,
                                ],
                                [
                                    0.02085539297606655,
                                    0.002057773700346306,
                                    0.8893371295413641,
                                    0.08774970378222305,
                                ],
                                [
                                    0.8678515700753553,
                                    0.04234095244207544,
                                    0.08562975239808383,
                                    0.00417772508448553,
                                ],
                                [
                                    0.8678515700753553,
                                    0.08562975239808383,
                                    0.04234095244207544,
                                    0.00417772508448553,
                                ],
                                [
                                    0.019944609158350543,
                                    0.28874260579168204,
                                    0.04466645405519716,
                                    0.6466463309947702,
                                ],
                                [
                                    0.019944609158350543,
                                    0.04466645405519716,
                                    0.28874260579168204,
                                    0.6466463309947702,
                                ],
                                [
                                    0.024119198647935602,
                                    0.3491790795156447,
                                    0.0404918645656121,
                                    0.5862098572708075,
                                ],
                                [
                                    0.04137733177421108,
                                    0.09266557564231039,
                                    0.2673098831758215,
                                    0.598647209407657,
                                ],
                                [
                                    0.04137733177421108,
                                    0.2673098831758215,
                                    0.09266557564231039,
                                    0.598647209407657,
                                ],
                                [
                                    0.024119198647935602,
                                    0.0404918645656121,
                                    0.3491790795156447,
                                    0.5862098572708075,
                                ],
                                [
                                    0.05003798653862768,
                                    0.3232602916249526,
                                    0.0840049208778938,
                                    0.5426968009585259,
                                ],
                                [
                                    0.05003798653862768,
                                    0.0840049208778938,
                                    0.3232602916249526,
                                    0.5426968009585259,
                                ],
                                [
                                    0.010637183380195672,
                                    0.21802760129950852,
                                    0.03588149414636536,
                                    0.7354537211739305,
                                ],
                                [
                                    0.010637183380195672,
                                    0.03588149414636536,
                                    0.21802760129950852,
                                    0.7354537211739305,
                                ],
                                [
                                    0.024922897665909983,
                                    0.5108381985449533,
                                    0.021595779860651042,
                                    0.4426431239284857,
                                ],
                                [
                                    0.08609872965679162,
                                    0.2904294260773413,
                                    0.14256605502291256,
                                    0.4809057892429545,
                                ],
                                [
                                    0.08609872965679162,
                                    0.14256605502291256,
                                    0.2904294260773413,
                                    0.4809057892429545,
                                ],
                                [
                                    0.024922897665909983,
                                    0.021595779860651042,
                                    0.5108381985449533,
                                    0.4426431239284857,
                                ],
                                [
                                    0.20172913747037366,
                                    0.3340319587404895,
                                    0.1747990182637592,
                                    0.2894398855253775,
                                ],
                                [
                                    0.20172913747037366,
                                    0.1747990182637592,
                                    0.3340319587404895,
                                    0.2894398855253775,
                                ],
                                [
                                    0.002847141061715088,
                                    0.12141071914256545,
                                    0.020066025614697766,
                                    0.8556761141810217,
                                ],
                                [
                                    0.002847141061715088,
                                    0.020066025614697766,
                                    0.12141071914256545,
                                    0.8556761141810217,
                                ],
                                [
                                    0.017132855347429417,
                                    0.7305968491227183,
                                    0.005780311328983436,
                                    0.24648998420086893,
                                ],
                                [
                                    0.08609872965679158,
                                    0.6068049588120493,
                                    0.03815913054748895,
                                    0.26893718098367014,
                                ],
                                [
                                    0.08609872965679158,
                                    0.03815913054748895,
                                    0.6068049588120493,
                                    0.26893718098367014,
                                ],
                                [
                                    0.017132855347429417,
                                    0.005780311328983436,
                                    0.7305968491227183,
                                    0.24648998420086893,
                                ],
                                [
                                    0.5181046702050817,
                                    0.22962503426506597,
                                    0.17479901826375924,
                                    0.07747127726609311,
                                ],
                                [
                                    0.5181046702050817,
                                    0.17479901826375924,
                                    0.22962503426506597,
                                    0.07747127726609311,
                                ],
                                [
                                    0.00021324931968468515,
                                    0.044022180614267443,
                                    0.00460753166974138,
                                    0.9511570383963065,
                                ],
                                [
                                    0.00021324931968468515,
                                    0.00460753166974138,
                                    0.044022180614267443,
                                    0.9511570383963065,
                                ],
                                [
                                    0.0043878388092697855,
                                    0.9058046837081609,
                                    0.00043294218015627983,
                                    0.08937453530241307,
                                ],
                                [
                                    0.04137733177421109,
                                    0.8940116050122412,
                                    0.002858098159741043,
                                    0.0617529650538067,
                                ],
                                [
                                    0.04137733177421109,
                                    0.002858098159741043,
                                    0.8940116050122412,
                                    0.0617529650538067,
                                ],
                                [
                                    0.0043878388092697855,
                                    0.00043294218015627983,
                                    0.9058046837081609,
                                    0.08937453530241307,
                                ],
                                [
                                    0.8513840159085585,
                                    0.05880850660887219,
                                    0.08400492087789381,
                                    0.005802556604675555,
                                ],
                                [
                                    0.8513840159085585,
                                    0.08400492087789381,
                                    0.05880850660887219,
                                    0.005802556604675555,
                                ],
                                [
                                    0.0562402578961834,
                                    0.008705521031958837,
                                    0.8097168346872952,
                                    0.12533738638456257,
                                ],
                                [
                                    0.0562402578961834,
                                    0.8097168346872952,
                                    0.008705521031958837,
                                    0.12533738638456257,
                                ],
                                [
                                    0.11219066634531451,
                                    0.017366175796375425,
                                    0.753766426238164,
                                    0.116676731620146,
                                ],
                                [
                                    0.06074956310036295,
                                    0.8746393736860893,
                                    0.004196215827779292,
                                    0.0604148473857684,
                                ],
                                [
                                    0.06074956310036295,
                                    0.004196215827779292,
                                    0.8746393736860893,
                                    0.0604148473857684,
                                ],
                                [
                                    0.11219066634531451,
                                    0.753766426238164,
                                    0.017366175796375425,
                                    0.116676731620146,
                                ],
                                [
                                    0.12118603682432559,
                                    0.008370805317364349,
                                    0.8142028999621267,
                                    0.056240257896183345,
                                ],
                                [
                                    0.12118603682432559,
                                    0.8142028999621267,
                                    0.008370805317364349,
                                    0.056240257896183345,
                                ],
                                [
                                    0.029994969158907998,
                                    0.018114611786526385,
                                    0.5934768751069592,
                                    0.3584135439476064,
                                ],
                                [
                                    0.029994969158907998,
                                    0.5934768751069592,
                                    0.018114611786526385,
                                    0.3584135439476064,
                                ],
                                [
                                    0.22146087287648508,
                                    0.13374501960010843,
                                    0.40201097138938213,
                                    0.24278313613402436,
                                ],
                                [
                                    0.04587158686349574,
                                    0.9076097356099433,
                                    0.0022379940819386426,
                                    0.04428068344462229,
                                ],
                                [
                                    0.04587158686349574,
                                    0.0022379940819386426,
                                    0.9076097356099433,
                                    0.04428068344462229,
                                ],
                                [
                                    0.22146087287648508,
                                    0.40201097138938213,
                                    0.13374501960010843,
                                    0.24278313613402436,
                                ],
                                [
                                    0.3386821841089406,
                                    0.01652370836765293,
                                    0.6147991383644985,
                                    0.029994969158908005,
                                ],
                                [
                                    0.3386821841089406,
                                    0.6147991383644985,
                                    0.01652370836765293,
                                    0.029994969158908005,
                                ],
                                [
                                    0.008028432460438946,
                                    0.018114611786526395,
                                    0.2990678790707202,
                                    0.6747890766823145,
                                ],
                                [
                                    0.008028432460438946,
                                    0.2990678790707202,
                                    0.018114611786526395,
                                    0.6747890766823145,
                                ],
                                [
                                    0.19949433617801599,
                                    0.45012055233481646,
                                    0.10760197535314313,
                                    0.2427831361340244,
                                ],
                                [
                                    0.025544024316705792,
                                    0.9515428090068815,
                                    0.000599019930259551,
                                    0.022314146746153226,
                                ],
                                [
                                    0.025544024316705792,
                                    0.000599019930259551,
                                    0.9515428090068815,
                                    0.022314146746153226,
                                ],
                                [
                                    0.19949433617801599,
                                    0.10760197535314313,
                                    0.45012055233481646,
                                    0.2427831361340244,
                                ],
                                [
                                    0.6347301542968586,
                                    0.014884734215973834,
                                    0.3423566790267286,
                                    0.008028432460438944,
                                ],
                                [
                                    0.6347301542968586,
                                    0.3423566790267286,
                                    0.014884734215973834,
                                    0.008028432460438944,
                                ],
                                [
                                    0.0006013252322987178,
                                    0.008705521031958877,
                                    0.06400973798124898,
                                    0.9266834157544934,
                                ],
                                [
                                    0.0006013252322987178,
                                    0.06400973798124898,
                                    0.008705521031958877,
                                    0.9266834157544934,
                                ],
                                [
                                    0.05655173368142983,
                                    0.8187122051663063,
                                    0.008059329532117876,
                                    0.11667673162014604,
                                ],
                                [
                                    0.009261979996715351,
                                    0.9859172390138586,
                                    4.4866267542243575e-05,
                                    0.004775914721883775,
                                ],
                                [
                                    0.009261979996715351,
                                    4.4866267542243575e-05,
                                    0.9859172390138586,
                                    0.004775914721883775,
                                ],
                                [
                                    0.05655173368142983,
                                    0.008059329532117876,
                                    0.8187122051663063,
                                    0.11667673162014604,
                                ],
                                [
                                    0.8710444830906088,
                                    0.004219455757127304,
                                    0.1241347359199652,
                                    0.0006013252322987152,
                                ],
                                [
                                    0.8710444830906088,
                                    0.1241347359199652,
                                    0.004219455757127304,
                                    0.0006013252322987152,
                                ],
                                [
                                    0.040491864565612136,
                                    0.0244539143625301,
                                    0.5829799797002551,
                                    0.3520742413716027,
                                ],
                                [
                                    0.040491864565612136,
                                    0.5829799797002551,
                                    0.0244539143625301,
                                    0.3520742413716027,
                                ],
                                [
                                    0.08077504330734125,
                                    0.04878179883434869,
                                    0.5426968009585259,
                                    0.3277463568997841,
                                ],
                                [
                                    0.04500116976979168,
                                    0.6479025186990492,
                                    0.019944609158350557,
                                    0.2871517023728085,
                                ],
                                [
                                    0.04500116976979168,
                                    0.019944609158350557,
                                    0.6479025186990492,
                                    0.2871517023728085,
                                ],
                                [
                                    0.08077504330734125,
                                    0.5426968009585259,
                                    0.04878179883434869,
                                    0.3277463568997841,
                                ],
                                [
                                    0.08977041378635232,
                                    0.03978642835533761,
                                    0.6031332746824886,
                                    0.26730988317582144,
                                ],
                                [
                                    0.08977041378635232,
                                    0.6031332746824886,
                                    0.03978642835533761,
                                    0.26730988317582144,
                                ],
                                [
                                    0.021595779860650997,
                                    0.026513801084783385,
                                    0.42729151943103916,
                                    0.5245988996235265,
                                ],
                                [
                                    0.021595779860650997,
                                    0.42729151943103916,
                                    0.026513801084783385,
                                    0.5245988996235265,
                                ],
                                [
                                    0.15944741376631252,
                                    0.195758478710281,
                                    0.2894398855253776,
                                    0.3553542219980289,
                                ],
                                [
                                    0.03747239756523874,
                                    0.7414243799340232,
                                    0.010637183380195644,
                                    0.21046603912054238,
                                ],
                                [
                                    0.03747239756523874,
                                    0.010637183380195644,
                                    0.7414243799340232,
                                    0.21046603912054238,
                                ],
                                [
                                    0.15944741376631252,
                                    0.2894398855253776,
                                    0.195758478710281,
                                    0.3553542219980289,
                                ],
                                [
                                    0.27666872499876805,
                                    0.07853716747782548,
                                    0.502228052500494,
                                    0.14256605502291253,
                                ],
                                [
                                    0.27666872499876805,
                                    0.502228052500494,
                                    0.07853716747782548,
                                    0.14256605502291253,
                                ],
                                [
                                    0.005780311328983416,
                                    0.020362732917981925,
                                    0.2153229111717546,
                                    0.75853404458128,
                                ],
                                [
                                    0.005780311328983416,
                                    0.2153229111717546,
                                    0.020362732917981925,
                                    0.75853404458128,
                                ],
                                [
                                    0.1436319452346449,
                                    0.5059829432781875,
                                    0.0774712772660931,
                                    0.27291383422107446,
                                ],
                                [
                                    0.023295903185250263,
                                    0.8677978411079159,
                                    0.002847141061715079,
                                    0.10605911464511877,
                                ],
                                [
                                    0.023295903185250263,
                                    0.002847141061715079,
                                    0.8677978411079159,
                                    0.10605911464511877,
                                ],
                                [
                                    0.1436319452346449,
                                    0.0774712772660931,
                                    0.5059829432781875,
                                    0.27291383422107446,
                                ],
                                [
                                    0.5788677633534876,
                                    0.07074712515934489,
                                    0.31222598093967857,
                                    0.038159130547488956,
                                ],
                                [
                                    0.5788677633534876,
                                    0.31222598093967857,
                                    0.07074712515934489,
                                    0.038159130547488956,
                                ],
                                [
                                    0.00043294218015627826,
                                    0.008873904084101318,
                                    0.04608573534640475,
                                    0.9446074183893377,
                                ],
                                [
                                    0.00043294218015627826,
                                    0.04608573534640475,
                                    0.008873904084101318,
                                    0.9446074183893377,
                                ],
                                [
                                    0.040716120921885465,
                                    0.8345478179258506,
                                    0.005802556604675562,
                                    0.11893350454758836,
                                ],
                                [
                                    0.009093596944572912,
                                    0.9679932363790144,
                                    0.00021324931968468407,
                                    0.022699917356728112,
                                ],
                                [
                                    0.009093596944572912,
                                    0.00021324931968468407,
                                    0.9679932363790144,
                                    0.022699917356728112,
                                ],
                                [
                                    0.040716120921885465,
                                    0.005802556604675562,
                                    0.8345478179258506,
                                    0.11893350454758836,
                                ],
                                [
                                    0.8552088703310644,
                                    0.020055068516671756,
                                    0.12187796299252289,
                                    0.0028580981597410423,
                                ],
                                [
                                    0.8552088703310644,
                                    0.12187796299252289,
                                    0.020055068516671756,
                                    0.0028580981597410423,
                                ],
                                [
                                    0.01994460915835056,
                                    0.04500116976979168,
                                    0.28715170237280857,
                                    0.6479025186990492,
                                ],
                                [
                                    0.01994460915835056,
                                    0.28715170237280857,
                                    0.04500116976979168,
                                    0.6479025186990492,
                                ],
                                [
                                    0.03978642835533762,
                                    0.08977041378635232,
                                    0.2673098831758215,
                                    0.6031332746824886,
                                ],
                                [
                                    0.024453914362530107,
                                    0.3520742413716028,
                                    0.04049186456561213,
                                    0.582979979700255,
                                ],
                                [
                                    0.024453914362530107,
                                    0.04049186456561213,
                                    0.3520742413716028,
                                    0.582979979700255,
                                ],
                                [
                                    0.03978642835533762,
                                    0.2673098831758215,
                                    0.08977041378635232,
                                    0.6031332746824886,
                                ],
                                [
                                    0.0487817988343487,
                                    0.08077504330734124,
                                    0.3277463568997842,
                                    0.5426968009585259,
                                ],
                                [
                                    0.0487817988343487,
                                    0.3277463568997842,
                                    0.08077504330734124,
                                    0.5426968009585259,
                                ],
                                [
                                    0.010637183380195644,
                                    0.03747239756523874,
                                    0.21046603912054235,
                                    0.7414243799340232,
                                ],
                                [
                                    0.010637183380195644,
                                    0.21046603912054235,
                                    0.03747239756523874,
                                    0.7414243799340232,
                                ],
                                [
                                    0.07853716747782546,
                                    0.27666872499876805,
                                    0.14256605502291253,
                                    0.502228052500494,
                                ],
                                [
                                    0.026513801084783385,
                                    0.5245988996235265,
                                    0.021595779860650997,
                                    0.42729151943103916,
                                ],
                                [
                                    0.026513801084783385,
                                    0.021595779860650997,
                                    0.5245988996235265,
                                    0.42729151943103916,
                                ],
                                [
                                    0.07853716747782546,
                                    0.14256605502291253,
                                    0.27666872499876805,
                                    0.502228052500494,
                                ],
                                [
                                    0.195758478710281,
                                    0.15944741376631252,
                                    0.3553542219980289,
                                    0.2894398855253776,
                                ],
                                [
                                    0.195758478710281,
                                    0.3553542219980289,
                                    0.15944741376631252,
                                    0.2894398855253776,
                                ],
                                [
                                    0.0028471410617150797,
                                    0.023295903185250263,
                                    0.1060591146451188,
                                    0.8677978411079159,
                                ],
                                [
                                    0.0028471410617150797,
                                    0.1060591146451188,
                                    0.023295903185250263,
                                    0.8677978411079159,
                                ],
                                [
                                    0.0707471251593449,
                                    0.5788677633534876,
                                    0.03815913054748896,
                                    0.31222598093967857,
                                ],
                                [
                                    0.020362732917981925,
                                    0.75853404458128,
                                    0.005780311328983417,
                                    0.21532291117175462,
                                ],
                                [
                                    0.020362732917981925,
                                    0.005780311328983417,
                                    0.75853404458128,
                                    0.21532291117175462,
                                ],
                                [
                                    0.0707471251593449,
                                    0.03815913054748896,
                                    0.5788677633534876,
                                    0.31222598093967857,
                                ],
                                [
                                    0.5059829432781875,
                                    0.14363194523464493,
                                    0.27291383422107446,
                                    0.07747127726609311,
                                ],
                                [
                                    0.5059829432781875,
                                    0.27291383422107446,
                                    0.14363194523464493,
                                    0.07747127726609311,
                                ],
                                [
                                    0.0002132493196846846,
                                    0.00909359694457291,
                                    0.02269991735672817,
                                    0.9679932363790142,
                                ],
                                [
                                    0.0002132493196846846,
                                    0.02269991735672817,
                                    0.00909359694457291,
                                    0.9679932363790142,
                                ],
                                [
                                    0.020055068516671805,
                                    0.8552088703310643,
                                    0.0028580981597410497,
                                    0.12187796299252288,
                                ],
                                [
                                    0.008873904084101318,
                                    0.9446074183893378,
                                    0.0004329421801562777,
                                    0.04608573534640469,
                                ],
                                [
                                    0.008873904084101318,
                                    0.0004329421801562777,
                                    0.9446074183893378,
                                    0.04608573534640469,
                                ],
                                [
                                    0.020055068516671805,
                                    0.0028580981597410497,
                                    0.8552088703310643,
                                    0.12187796299252288,
                                ],
                                [
                                    0.8345478179258508,
                                    0.04071612092188542,
                                    0.11893350454758837,
                                    0.005802556604675555,
                                ],
                                [
                                    0.8345478179258508,
                                    0.11893350454758837,
                                    0.04071612092188542,
                                    0.005802556604675555,
                                ],
                                [
                                    0.004196215827779293,
                                    0.06074956310036295,
                                    0.06041484738576841,
                                    0.8746393736860893,
                                ],
                                [
                                    0.004196215827779293,
                                    0.06041484738576841,
                                    0.06074956310036295,
                                    0.8746393736860893,
                                ],
                                [
                                    0.00837080531736435,
                                    0.12118603682432559,
                                    0.05624025789618335,
                                    0.8142028999621267,
                                ],
                                [
                                    0.008705521031958841,
                                    0.12533738638456263,
                                    0.0562402578961834,
                                    0.8097168346872952,
                                ],
                                [
                                    0.008705521031958841,
                                    0.0562402578961834,
                                    0.12533738638456263,
                                    0.8097168346872952,
                                ],
                                [
                                    0.00837080531736435,
                                    0.05624025789618335,
                                    0.12118603682432559,
                                    0.8142028999621267,
                                ],
                                [
                                    0.017366175796375432,
                                    0.11219066634531451,
                                    0.11667673162014604,
                                    0.753766426238164,
                                ],
                                [
                                    0.017366175796375432,
                                    0.11667673162014604,
                                    0.11219066634531451,
                                    0.753766426238164,
                                ],
                                [
                                    0.002237994081938647,
                                    0.04587158686349573,
                                    0.044280683444622375,
                                    0.9076097356099433,
                                ],
                                [
                                    0.002237994081938647,
                                    0.044280683444622375,
                                    0.04587158686349573,
                                    0.9076097356099433,
                                ],
                                [
                                    0.01652370836765296,
                                    0.3386821841089405,
                                    0.029994969158908064,
                                    0.6147991383644984,
                                ],
                                [
                                    0.01811461178652639,
                                    0.3584135439476065,
                                    0.029994969158907994,
                                    0.5934768751069591,
                                ],
                                [
                                    0.01811461178652639,
                                    0.029994969158907994,
                                    0.3584135439476065,
                                    0.5934768751069591,
                                ],
                                [
                                    0.01652370836765296,
                                    0.029994969158908064,
                                    0.3386821841089405,
                                    0.6147991383644984,
                                ],
                                [
                                    0.13374501960010846,
                                    0.22146087287648505,
                                    0.24278313613402444,
                                    0.4020109713893821,
                                ],
                                [
                                    0.13374501960010846,
                                    0.24278313613402444,
                                    0.22146087287648505,
                                    0.4020109713893821,
                                ],
                                [
                                    0.0005990199302595531,
                                    0.02554402431670579,
                                    0.022314146746153302,
                                    0.9515428090068814,
                                ],
                                [
                                    0.0005990199302595531,
                                    0.022314146746153302,
                                    0.02554402431670579,
                                    0.9515428090068814,
                                ],
                                [
                                    0.014884734215973885,
                                    0.6347301542968585,
                                    0.00802843246043897,
                                    0.34235667902672856,
                                ],
                                [
                                    0.018114611786526395,
                                    0.6747890766823145,
                                    0.008028432460438944,
                                    0.29906787907072013,
                                ],
                                [
                                    0.018114611786526395,
                                    0.008028432460438944,
                                    0.6747890766823145,
                                    0.29906787907072013,
                                ],
                                [
                                    0.014884734215973885,
                                    0.00802843246043897,
                                    0.6347301542968585,
                                    0.34235667902672856,
                                ],
                                [
                                    0.45012055233481646,
                                    0.19949433617801596,
                                    0.2427831361340244,
                                    0.10760197535314311,
                                ],
                                [
                                    0.45012055233481646,
                                    0.2427831361340244,
                                    0.19949433617801596,
                                    0.10760197535314311,
                                ],
                                [
                                    4.4866267542244015e-05,
                                    0.009261979996715351,
                                    0.004775914721883822,
                                    0.9859172390138586,
                                ],
                                [
                                    4.4866267542244015e-05,
                                    0.004775914721883822,
                                    0.009261979996715351,
                                    0.9859172390138586,
                                ],
                                [
                                    0.004219455757127345,
                                    0.8710444830906088,
                                    0.000601325232298721,
                                    0.1241347359199652,
                                ],
                                [
                                    0.008705521031958877,
                                    0.9266834157544934,
                                    0.0006013252322987182,
                                    0.06400973798124902,
                                ],
                                [
                                    0.008705521031958877,
                                    0.0006013252322987182,
                                    0.9266834157544934,
                                    0.06400973798124902,
                                ],
                                [
                                    0.004219455757127345,
                                    0.000601325232298721,
                                    0.8710444830906088,
                                    0.1241347359199652,
                                ],
                                [
                                    0.8187122051663063,
                                    0.056551733681429864,
                                    0.11667673162014604,
                                    0.008059329532117882,
                                ],
                                [
                                    0.8187122051663063,
                                    0.11667673162014604,
                                    0.056551733681429864,
                                    0.008059329532117882,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.0002068106318256911,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.001302684133657575,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.0012712124942877443,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00019438546678245336,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.00011031298748461555,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006948529544346365,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.0006780659520969104,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                0.00010368539264672433,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                5.884105232093418e-05,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.00037063522600134597,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                0.0003616810230068569,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                5.5305886938229844e-05,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.00038067200448312885,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.002227283873284808,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.0002699545495930693,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.00020305080882729705,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.001188035333915706,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.0001439940132080575,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.00010830749432546408,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.000633699175736689,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                7.680654343857948e-05,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.0003714753222377974,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.001946848176847779,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.0013775031398337572,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.00014669497418166475,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0001981452897808473,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0010384506670240573,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                0.0007347614834065946,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                7.824723858779744e-05,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.00010569088580587573,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0005539105723121963,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                0.0003919224732678385,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                4.17371513971128e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0001943854667824532,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0009238018672821883,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                0.0005019996561429077,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                2.785578501340159e-05,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.00010368539264672425,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.000492756793614249,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                0.00026776709348312453,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                1.4858302188967948e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                5.53058869382298e-05,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.0002628369418296771,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                0.00014282722204094349,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                                7.925432502888587e-06,
                            ]
                        ),
                    )
                case 5:
                    return (
                        np.array(
                            [
                                [
                                    0.9105763413083723,
                                    0.0426168098808606,
                                    0.0447141369879829,
                                    0.0020927118227842133,
                                ],
                                [
                                    0.9105763413083723,
                                    0.0447141369879829,
                                    0.0426168098808606,
                                    0.0020927118227842133,
                                ],
                                [
                                    0.9084741717575027,
                                    0.04251842410470698,
                                    0.046816306538852485,
                                    0.002191097598937829,
                                ],
                                [
                                    0.8658619771609802,
                                    0.042518424104706985,
                                    0.0873311740282527,
                                    0.00428842470606013,
                                ],
                                [
                                    0.8658619771609802,
                                    0.0873311740282527,
                                    0.042518424104706985,
                                    0.00428842470606013,
                                ],
                                [
                                    0.9084741717575027,
                                    0.046816306538852485,
                                    0.04251842410470698,
                                    0.002191097598937829,
                                ],
                                [
                                    0.8638630358300114,
                                    0.08712956003219817,
                                    0.044517365435675665,
                                    0.004490038702114651,
                                ],
                                [
                                    0.8638630358300114,
                                    0.044517365435675665,
                                    0.08712956003219817,
                                    0.004490038702114651,
                                ],
                                [
                                    0.9191872970530827,
                                    0.034410437825365084,
                                    0.044727846023729145,
                                    0.0016744190978230545,
                                ],
                                [
                                    0.9191872970530827,
                                    0.044727846023729145,
                                    0.034410437825365084,
                                    0.0016744190978230545,
                                ],
                                [
                                    0.9087527034643432,
                                    0.03401981130662465,
                                    0.05516243961246859,
                                    0.002065045616563485,
                                ],
                                [
                                    0.6991299868230287,
                                    0.03401981130662465,
                                    0.25446774805541905,
                                    0.012382453814927547,
                                ],
                                [
                                    0.6991299868230287,
                                    0.25446774805541905,
                                    0.03401981130662465,
                                    0.012382453814927547,
                                ],
                                [
                                    0.9087527034643432,
                                    0.05516243961246859,
                                    0.03401981130662465,
                                    0.002065045616563485,
                                ],
                                [
                                    0.6911934788865208,
                                    0.2515790358844471,
                                    0.04195631924313259,
                                    0.015271165985899487,
                                ],
                                [
                                    0.6911934788865208,
                                    0.04195631924313259,
                                    0.2515790358844471,
                                    0.015271165985899487,
                                ],
                                [
                                    0.9318096327260459,
                                    0.02238056790679763,
                                    0.04473532875862004,
                                    0.0010744706085363772,
                                ],
                                [
                                    0.9318096327260459,
                                    0.04473532875862004,
                                    0.02238056790679763,
                                    0.0010744706085363772,
                                ],
                                [
                                    0.9089047330424678,
                                    0.021830429075041832,
                                    0.06764022844219825,
                                    0.001624609440292179,
                                ],
                                [
                                    0.4547145324096241,
                                    0.02183042907504183,
                                    0.4994756682232194,
                                    0.023979370292114586,
                                ],
                                [
                                    0.4547145324096241,
                                    0.4994756682232194,
                                    0.02183042907504183,
                                    0.023979370292114586,
                                ],
                                [
                                    0.9089047330424678,
                                    0.06764022844219825,
                                    0.021830429075041832,
                                    0.001624609440292179,
                                ],
                                [
                                    0.44353715198371296,
                                    0.48719801013379666,
                                    0.03300780950095303,
                                    0.036257028381537396,
                                ],
                                [
                                    0.44353715198371296,
                                    0.03300780950095303,
                                    0.48719801013379666,
                                    0.036257028381537396,
                                ],
                                [
                                    0.944446933868791,
                                    0.0103357325184484,
                                    0.044727846023729145,
                                    0.0004894875890314823,
                                ],
                                [
                                    0.944446933868791,
                                    0.044727846023729145,
                                    0.0103357325184484,
                                    0.0004894875890314823,
                                ],
                                [
                                    0.9087527034643432,
                                    0.009945105999707968,
                                    0.08042207642817684,
                                    0.000880114107771913,
                                ],
                                [
                                    0.20999501883997065,
                                    0.009945105999707968,
                                    0.7447876475472688,
                                    0.03527222761305266,
                                ],
                                [
                                    0.20999501883997065,
                                    0.7447876475472688,
                                    0.009945105999707968,
                                    0.03527222761305266,
                                ],
                                [
                                    0.9087527034643432,
                                    0.08042207642817684,
                                    0.009945105999707968,
                                    0.000880114107771913,
                                ],
                                [
                                    0.20205851090346272,
                                    0.7166392985605885,
                                    0.017881613936215908,
                                    0.06342057659973285,
                                ],
                                [
                                    0.20205851090346272,
                                    0.017881613936215908,
                                    0.7166392985605885,
                                    0.06342057659973285,
                                ],
                                [
                                    0.9530853076849939,
                                    0.002101942391460392,
                                    0.0447141369879829,
                                    9.861293556281745e-05,
                                ],
                                [
                                    0.9530853076849939,
                                    0.0447141369879829,
                                    0.002101942391460392,
                                    9.861293556281745e-05,
                                ],
                                [
                                    0.9084741717575027,
                                    0.002003556615306777,
                                    0.0893252729154741,
                                    0.00019699871171643287,
                                ],
                                [
                                    0.042705965088338065,
                                    0.0020035566153067757,
                                    0.9124812849881163,
                                    0.042809193308238944,
                                ],
                                [
                                    0.042705965088338065,
                                    0.9124812849881163,
                                    0.0020035566153067757,
                                    0.042809193308238944,
                                ],
                                [
                                    0.9084741717575027,
                                    0.0893252729154741,
                                    0.002003556615306777,
                                    0.00019699871171643287,
                                ],
                                [
                                    0.04070702375736938,
                                    0.8697707046154401,
                                    0.004002497946275464,
                                    0.08551977368091507,
                                ],
                                [
                                    0.04070702375736938,
                                    0.004002497946275464,
                                    0.8697707046154401,
                                    0.08551977368091507,
                                ],
                                [
                                    0.7435477305203463,
                                    0.20964542066888647,
                                    0.03651214463997503,
                                    0.010294704170792078,
                                ],
                                [
                                    0.7435477305203463,
                                    0.03651214463997503,
                                    0.20964542066888647,
                                    0.010294704170792078,
                                ],
                                [
                                    0.7418311656066652,
                                    0.20916143025554437,
                                    0.038228709553656134,
                                    0.010778694584134182,
                                ],
                                [
                                    0.6988333663729542,
                                    0.034316431756699114,
                                    0.2543597848162786,
                                    0.012490417054067995,
                                ],
                                [
                                    0.6988333663729542,
                                    0.2543597848162786,
                                    0.034316431756699114,
                                    0.012490417054067995,
                                ],
                                [
                                    0.7418311656066652,
                                    0.038228709553656134,
                                    0.20916143025554437,
                                    0.010778694584134182,
                                ],
                                [
                                    0.6972200296791741,
                                    0.25377256618303556,
                                    0.035929768450479314,
                                    0.013077635687311006,
                                ],
                                [
                                    0.6972200296791741,
                                    0.035929768450479314,
                                    0.25377256618303556,
                                    0.013077635687311006,
                                ],
                                [
                                    0.7843220257517761,
                                    0.16927570912667167,
                                    0.03816527372964648,
                                    0.008236991391905726,
                                ],
                                [
                                    0.7843220257517761,
                                    0.03816527372964648,
                                    0.16927570912667167,
                                    0.008236991391905726,
                                ],
                                [
                                    0.775418419699283,
                                    0.16735409507168492,
                                    0.0470688797821396,
                                    0.010158605446892482,
                                ],
                                [
                                    0.5642647155217222,
                                    0.027457239012541983,
                                    0.38933301935672565,
                                    0.01894502610901022,
                                ],
                                [
                                    0.5642647155217222,
                                    0.38933301935672565,
                                    0.027457239012541983,
                                    0.01894502610901022,
                                ],
                                [
                                    0.775418419699283,
                                    0.0470688797821396,
                                    0.16735409507168492,
                                    0.010158605446892482,
                                ],
                                [
                                    0.5578591951214605,
                                    0.38491331964950737,
                                    0.03386275941280359,
                                    0.023364725816228487,
                                ],
                                [
                                    0.5578591951214605,
                                    0.03386275941280359,
                                    0.38491331964950737,
                                    0.023364725816228487,
                                ],
                                [
                                    0.8440931852357253,
                                    0.11009701539711823,
                                    0.040524142290695425,
                                    0.005285657076460985,
                                ],
                                [
                                    0.8440931852357253,
                                    0.040524142290695425,
                                    0.11009701539711823,
                                    0.005285657076460985,
                                ],
                                [
                                    0.8233444517472613,
                                    0.10739071037024828,
                                    0.061272875779159464,
                                    0.007991962103330955,
                                ],
                                [
                                    0.3669980849193035,
                                    0.01761924260711722,
                                    0.58719211571354,
                                    0.028190556760039193,
                                ],
                                [
                                    0.3669980849193035,
                                    0.58719211571354,
                                    0.01761924260711722,
                                    0.028190556760039193,
                                ],
                                [
                                    0.8233444517472613,
                                    0.061272875779159464,
                                    0.10739071037024828,
                                    0.007991962103330955,
                                ],
                                [
                                    0.35797687068850653,
                                    0.5727582914290031,
                                    0.026640456837914255,
                                    0.04262438104457617,
                                ],
                                [
                                    0.35797687068850653,
                                    0.026640456837914255,
                                    0.5727582914290031,
                                    0.04262438104457617,
                                ],
                                [
                                    0.9039379645475473,
                                    0.050844701839692176,
                                    0.04280939102387176,
                                    0.0024079425888888675,
                                ],
                                [
                                    0.9039379645475473,
                                    0.04280939102387176,
                                    0.050844701839692176,
                                    0.0024079425888888675,
                                ],
                                [
                                    0.8697747216793458,
                                    0.048923087784705416,
                                    0.07697263389207314,
                                    0.004329556643875626,
                                ],
                                [
                                    0.1694860495187269,
                                    0.008026650999850584,
                                    0.7852966168685125,
                                    0.03719068261291004,
                                ],
                                [
                                    0.1694860495187269,
                                    0.7852966168685125,
                                    0.008026650999850584,
                                    0.03719068261291004,
                                ],
                                [
                                    0.8697747216793458,
                                    0.07697263389207314,
                                    0.048923087784705416,
                                    0.004329556643875626,
                                ],
                                [
                                    0.1630805291184653,
                                    0.755617280345586,
                                    0.014432171400112196,
                                    0.06687001913583655,
                                ],
                                [
                                    0.1630805291184653,
                                    0.014432171400112196,
                                    0.755617280345586,
                                    0.06687001913583655,
                                ],
                                [
                                    0.9448471378505183,
                                    0.010340112225936058,
                                    0.04432764204200188,
                                    0.00048510788154383514,
                                ],
                                [
                                    0.9448471378505183,
                                    0.04432764204200188,
                                    0.010340112225936058,
                                    0.00048510788154383514,
                                ],
                                [
                                    0.9006216065602155,
                                    0.009856121812593953,
                                    0.0885531733323046,
                                    0.0009690982948859397,
                                ],
                                [
                                    0.034467795253862434,
                                    0.0016170616693257597,
                                    0.9207194548225919,
                                    0.04319568825421996,
                                ],
                                [
                                    0.034467795253862434,
                                    0.9207194548225919,
                                    0.0016170616693257597,
                                    0.04319568825421996,
                                ],
                                [
                                    0.9006216065602155,
                                    0.0885531733323046,
                                    0.009856121812593953,
                                    0.0009690982948859397,
                                ],
                                [
                                    0.032854458560082234,
                                    0.8776232698127273,
                                    0.00323039836310596,
                                    0.08629187326408458,
                                ],
                                [
                                    0.032854458560082234,
                                    0.00323039836310596,
                                    0.8776232698127273,
                                    0.08629187326408458,
                                ],
                                [
                                    0.4989537576683125,
                                    0.45423939352092035,
                                    0.024501280847021516,
                                    0.022305567963745596,
                                ],
                                [
                                    0.4989537576683125,
                                    0.024501280847021516,
                                    0.45423939352092035,
                                    0.022305567963745596,
                                ],
                                [
                                    0.4978018658948504,
                                    0.4531907299673592,
                                    0.025653172620483573,
                                    0.023354231517306746,
                                ],
                                [
                                    0.45423939352092035,
                                    0.022305567963745596,
                                    0.4989537576683125,
                                    0.024501280847021516,
                                ],
                                [
                                    0.45423939352092035,
                                    0.4989537576683125,
                                    0.022305567963745596,
                                    0.024501280847021516,
                                ],
                                [
                                    0.4978018658948504,
                                    0.025653172620483573,
                                    0.4531907299673592,
                                    0.023354231517306746,
                                ],
                                [
                                    0.4531907299673592,
                                    0.4978018658948504,
                                    0.023354231517306746,
                                    0.025653172620483573,
                                ],
                                [
                                    0.4531907299673592,
                                    0.023354231517306746,
                                    0.4978018658948504,
                                    0.025653172620483573,
                                ],
                                [
                                    0.5868275225542509,
                                    0.3667702123241969,
                                    0.02855514991932835,
                                    0.017847115202223852,
                                ],
                                [
                                    0.5868275225542509,
                                    0.02855514991932835,
                                    0.3667702123241969,
                                    0.017847115202223852,
                                ],
                                [
                                    0.5801658696743952,
                                    0.3626066450965727,
                                    0.035216802799184044,
                                    0.022010682429848036,
                                ],
                                [
                                    0.366770212324197,
                                    0.01784711520222386,
                                    0.5868275225542507,
                                    0.028555149919328345,
                                ],
                                [
                                    0.366770212324197,
                                    0.5868275225542507,
                                    0.01784711520222386,
                                    0.028555149919328345,
                                ],
                                [
                                    0.5801658696743952,
                                    0.035216802799184044,
                                    0.3626066450965727,
                                    0.022010682429848036,
                                ],
                                [
                                    0.3626066450965728,
                                    0.5801658696743951,
                                    0.022010682429848043,
                                    0.03521680279918404,
                                ],
                                [
                                    0.3626066450965728,
                                    0.022010682429848043,
                                    0.5801658696743951,
                                    0.03521680279918404,
                                ],
                                [
                                    0.7156426504746327,
                                    0.23854755015821089,
                                    0.034357349525367314,
                                    0.011452449841789104,
                                ],
                                [
                                    0.7156426504746327,
                                    0.034357349525367314,
                                    0.23854755015821089,
                                    0.011452449841789104,
                                ],
                                [
                                    0.6980513715881322,
                                    0.2326837905293774,
                                    0.051948628411867814,
                                    0.017316209470622606,
                                ],
                                [
                                    0.23854755015821089,
                                    0.011452449841789104,
                                    0.7156426504746327,
                                    0.034357349525367314,
                                ],
                                [
                                    0.23854755015821089,
                                    0.7156426504746327,
                                    0.011452449841789104,
                                    0.034357349525367314,
                                ],
                                [
                                    0.6980513715881322,
                                    0.051948628411867814,
                                    0.2326837905293774,
                                    0.017316209470622606,
                                ],
                                [
                                    0.2326837905293774,
                                    0.6980513715881322,
                                    0.017316209470622606,
                                    0.051948628411867814,
                                ],
                                [
                                    0.2326837905293774,
                                    0.017316209470622606,
                                    0.6980513715881322,
                                    0.051948628411867814,
                                ],
                                [
                                    0.8446172907080299,
                                    0.11016537567920953,
                                    0.0400000368183909,
                                    0.005217296794369725,
                                ],
                                [
                                    0.8446172907080299,
                                    0.0400000368183909,
                                    0.11016537567920953,
                                    0.005217296794369725,
                                ],
                                [
                                    0.8126960010124659,
                                    0.10600180845158534,
                                    0.07192132651395484,
                                    0.00938086402199391,
                                ],
                                [
                                    0.11016537567920953,
                                    0.005217296794369725,
                                    0.8446172907080299,
                                    0.0400000368183909,
                                ],
                                [
                                    0.11016537567920953,
                                    0.8446172907080299,
                                    0.005217296794369725,
                                    0.0400000368183909,
                                ],
                                [
                                    0.8126960010124659,
                                    0.07192132651395484,
                                    0.10600180845158534,
                                    0.00938086402199391,
                                ],
                                [
                                    0.10600180845158534,
                                    0.8126960010124659,
                                    0.00938086402199391,
                                    0.07192132651395484,
                                ],
                                [
                                    0.10600180845158534,
                                    0.00938086402199391,
                                    0.8126960010124659,
                                    0.07192132651395484,
                                ],
                                [
                                    0.9327832963365551,
                                    0.02240395373989924,
                                    0.04376166514811092,
                                    0.0010510847754347972,
                                ],
                                [
                                    0.9327832963365551,
                                    0.04376166514811092,
                                    0.02240395373989924,
                                    0.0010510847754347972,
                                ],
                                [
                                    0.8891224381864714,
                                    0.021355290186338086,
                                    0.08742252329819458,
                                    0.0020997483289959496,
                                ],
                                [
                                    0.02240395373989924,
                                    0.0010510847754347972,
                                    0.9327832963365551,
                                    0.04376166514811092,
                                ],
                                [
                                    0.02240395373989924,
                                    0.9327832963365551,
                                    0.0010510847754347972,
                                    0.04376166514811092,
                                ],
                                [
                                    0.8891224381864714,
                                    0.08742252329819458,
                                    0.021355290186338086,
                                    0.0020997483289959496,
                                ],
                                [
                                    0.021355290186338086,
                                    0.8891224381864714,
                                    0.0020997483289959496,
                                    0.08742252329819458,
                                ],
                                [
                                    0.021355290186338086,
                                    0.0020997483289959496,
                                    0.8891224381864714,
                                    0.08742252329819458,
                                ],
                                [
                                    0.2543597848162787,
                                    0.6988333663729542,
                                    0.012490417054068,
                                    0.03431643175669911,
                                ],
                                [
                                    0.2543597848162787,
                                    0.012490417054068,
                                    0.6988333663729542,
                                    0.03431643175669911,
                                ],
                                [
                                    0.2537725661830357,
                                    0.697220029679174,
                                    0.01307763568731101,
                                    0.03592976845047931,
                                ],
                                [
                                    0.20964542066888653,
                                    0.010294704170792082,
                                    0.7435477305203463,
                                    0.03651214463997503,
                                ],
                                [
                                    0.20964542066888653,
                                    0.7435477305203463,
                                    0.010294704170792082,
                                    0.03651214463997503,
                                ],
                                [
                                    0.2537725661830357,
                                    0.01307763568731101,
                                    0.697220029679174,
                                    0.03592976845047931,
                                ],
                                [
                                    0.20916143025554443,
                                    0.7418311656066652,
                                    0.010778694584134186,
                                    0.038228709553656134,
                                ],
                                [
                                    0.20916143025554443,
                                    0.010778694584134186,
                                    0.7418311656066652,
                                    0.038228709553656134,
                                ],
                                [
                                    0.38933301935672576,
                                    0.5642647155217221,
                                    0.018945026109010225,
                                    0.02745723901254198,
                                ],
                                [
                                    0.38933301935672576,
                                    0.018945026109010225,
                                    0.5642647155217221,
                                    0.02745723901254198,
                                ],
                                [
                                    0.3849133196495075,
                                    0.5578591951214604,
                                    0.023364725816228494,
                                    0.03386275941280359,
                                ],
                                [
                                    0.16927570912667175,
                                    0.00823699139190573,
                                    0.784322025751776,
                                    0.038165273729646475,
                                ],
                                [
                                    0.16927570912667175,
                                    0.784322025751776,
                                    0.00823699139190573,
                                    0.038165273729646475,
                                ],
                                [
                                    0.3849133196495075,
                                    0.023364725816228494,
                                    0.5578591951214604,
                                    0.03386275941280359,
                                ],
                                [
                                    0.167354095071685,
                                    0.7754184196992829,
                                    0.010158605446892488,
                                    0.04706887978213959,
                                ],
                                [
                                    0.167354095071685,
                                    0.010158605446892488,
                                    0.7754184196992829,
                                    0.04706887978213959,
                                ],
                                [
                                    0.58719211571354,
                                    0.3669980849193035,
                                    0.028190556760039193,
                                    0.01761924260711722,
                                ],
                                [
                                    0.58719211571354,
                                    0.028190556760039193,
                                    0.3669980849193035,
                                    0.01761924260711722,
                                ],
                                [
                                    0.5727582914290031,
                                    0.35797687068850653,
                                    0.04262438104457617,
                                    0.026640456837914255,
                                ],
                                [
                                    0.11009701539711826,
                                    0.005285657076460987,
                                    0.8440931852357253,
                                    0.040524142290695425,
                                ],
                                [
                                    0.11009701539711826,
                                    0.8440931852357253,
                                    0.005285657076460987,
                                    0.040524142290695425,
                                ],
                                [
                                    0.5727582914290031,
                                    0.04262438104457617,
                                    0.35797687068850653,
                                    0.026640456837914255,
                                ],
                                [
                                    0.1073907103702483,
                                    0.8233444517472613,
                                    0.007991962103330957,
                                    0.061272875779159464,
                                ],
                                [
                                    0.1073907103702483,
                                    0.007991962103330957,
                                    0.8233444517472613,
                                    0.061272875779159464,
                                ],
                                [
                                    0.7852966168685125,
                                    0.16948604951872687,
                                    0.03719068261291004,
                                    0.008026650999850582,
                                ],
                                [
                                    0.7852966168685125,
                                    0.03719068261291004,
                                    0.16948604951872687,
                                    0.008026650999850582,
                                ],
                                [
                                    0.755617280345586,
                                    0.16308052911846527,
                                    0.06687001913583655,
                                    0.014432171400112194,
                                ],
                                [
                                    0.050844701839692155,
                                    0.002407942588888866,
                                    0.9039379645475473,
                                    0.04280939102387176,
                                ],
                                [
                                    0.050844701839692155,
                                    0.9039379645475473,
                                    0.002407942588888866,
                                    0.04280939102387176,
                                ],
                                [
                                    0.755617280345586,
                                    0.06687001913583655,
                                    0.16308052911846527,
                                    0.014432171400112194,
                                ],
                                [
                                    0.048923087784705395,
                                    0.8697747216793458,
                                    0.004329556643875624,
                                    0.07697263389207314,
                                ],
                                [
                                    0.048923087784705395,
                                    0.004329556643875624,
                                    0.8697747216793458,
                                    0.07697263389207314,
                                ],
                                [
                                    0.9207194548225919,
                                    0.03446779525386242,
                                    0.04319568825421996,
                                    0.0016170616693257592,
                                ],
                                [
                                    0.9207194548225919,
                                    0.04319568825421996,
                                    0.03446779525386242,
                                    0.0016170616693257592,
                                ],
                                [
                                    0.8776232698127273,
                                    0.03285445856008222,
                                    0.08629187326408458,
                                    0.003230398363105959,
                                ],
                                [
                                    0.010340112225936048,
                                    0.0004851078815438347,
                                    0.9448471378505183,
                                    0.04432764204200188,
                                ],
                                [
                                    0.010340112225936048,
                                    0.9448471378505183,
                                    0.0004851078815438347,
                                    0.04432764204200188,
                                ],
                                [
                                    0.8776232698127273,
                                    0.08629187326408458,
                                    0.03285445856008222,
                                    0.003230398363105959,
                                ],
                                [
                                    0.009856121812593944,
                                    0.9006216065602155,
                                    0.0009690982948859387,
                                    0.0885531733323046,
                                ],
                                [
                                    0.009856121812593944,
                                    0.0009690982948859387,
                                    0.9006216065602155,
                                    0.0885531733323046,
                                ],
                                [
                                    0.08733117402825277,
                                    0.8658619771609801,
                                    0.004288424706060135,
                                    0.04251842410470698,
                                ],
                                [
                                    0.08733117402825277,
                                    0.004288424706060135,
                                    0.8658619771609801,
                                    0.04251842410470698,
                                ],
                                [
                                    0.08712956003219825,
                                    0.8638630358300113,
                                    0.0044900387021146555,
                                    0.044517365435675665,
                                ],
                                [
                                    0.042616809880860626,
                                    0.0020927118227842146,
                                    0.9105763413083723,
                                    0.0447141369879829,
                                ],
                                [
                                    0.042616809880860626,
                                    0.9105763413083723,
                                    0.0020927118227842146,
                                    0.0447141369879829,
                                ],
                                [
                                    0.08712956003219825,
                                    0.0044900387021146555,
                                    0.8638630358300113,
                                    0.044517365435675665,
                                ],
                                [
                                    0.042518424104707006,
                                    0.9084741717575027,
                                    0.0021910975989378302,
                                    0.046816306538852485,
                                ],
                                [
                                    0.042518424104707006,
                                    0.0021910975989378302,
                                    0.9084741717575027,
                                    0.046816306538852485,
                                ],
                                [
                                    0.25446774805541916,
                                    0.6991299868230286,
                                    0.012382453814927552,
                                    0.03401981130662465,
                                ],
                                [
                                    0.25446774805541916,
                                    0.012382453814927552,
                                    0.6991299868230286,
                                    0.03401981130662465,
                                ],
                                [
                                    0.2515790358844472,
                                    0.6911934788865207,
                                    0.015271165985899494,
                                    0.04195631924313258,
                                ],
                                [
                                    0.03441043782536513,
                                    0.001674419097823057,
                                    0.9191872970530827,
                                    0.044727846023729145,
                                ],
                                [
                                    0.03441043782536513,
                                    0.9191872970530827,
                                    0.001674419097823057,
                                    0.044727846023729145,
                                ],
                                [
                                    0.2515790358844472,
                                    0.015271165985899494,
                                    0.6911934788865207,
                                    0.04195631924313258,
                                ],
                                [
                                    0.0340198113066247,
                                    0.9087527034643432,
                                    0.0020650456165634884,
                                    0.05516243961246859,
                                ],
                                [
                                    0.0340198113066247,
                                    0.0020650456165634884,
                                    0.9087527034643432,
                                    0.05516243961246859,
                                ],
                                [
                                    0.4994756682232194,
                                    0.4547145324096241,
                                    0.023979370292114586,
                                    0.02183042907504183,
                                ],
                                [
                                    0.4994756682232194,
                                    0.023979370292114586,
                                    0.4547145324096241,
                                    0.02183042907504183,
                                ],
                                [
                                    0.48719801013379666,
                                    0.44353715198371296,
                                    0.036257028381537396,
                                    0.03300780950095303,
                                ],
                                [
                                    0.02238056790679766,
                                    0.0010744706085363785,
                                    0.9318096327260459,
                                    0.04473532875862004,
                                ],
                                [
                                    0.02238056790679766,
                                    0.9318096327260459,
                                    0.0010744706085363785,
                                    0.04473532875862004,
                                ],
                                [
                                    0.48719801013379666,
                                    0.036257028381537396,
                                    0.44353715198371296,
                                    0.03300780950095303,
                                ],
                                [
                                    0.021830429075041857,
                                    0.9089047330424678,
                                    0.001624609440292181,
                                    0.06764022844219825,
                                ],
                                [
                                    0.021830429075041857,
                                    0.001624609440292181,
                                    0.9089047330424678,
                                    0.06764022844219825,
                                ],
                                [
                                    0.7447876475472688,
                                    0.20999501883997065,
                                    0.03527222761305266,
                                    0.009945105999707968,
                                ],
                                [
                                    0.7447876475472688,
                                    0.03527222761305266,
                                    0.20999501883997065,
                                    0.009945105999707968,
                                ],
                                [
                                    0.7166392985605885,
                                    0.20205851090346272,
                                    0.06342057659973285,
                                    0.017881613936215908,
                                ],
                                [
                                    0.0103357325184484,
                                    0.0004894875890314823,
                                    0.944446933868791,
                                    0.044727846023729145,
                                ],
                                [
                                    0.0103357325184484,
                                    0.944446933868791,
                                    0.0004894875890314823,
                                    0.044727846023729145,
                                ],
                                [
                                    0.7166392985605885,
                                    0.06342057659973285,
                                    0.20205851090346272,
                                    0.017881613936215908,
                                ],
                                [
                                    0.009945105999707968,
                                    0.9087527034643432,
                                    0.000880114107771913,
                                    0.08042207642817684,
                                ],
                                [
                                    0.009945105999707968,
                                    0.000880114107771913,
                                    0.9087527034643432,
                                    0.08042207642817684,
                                ],
                                [
                                    0.9124812849881163,
                                    0.042705965088338085,
                                    0.042809193308238944,
                                    0.002003556615306777,
                                ],
                                [
                                    0.9124812849881163,
                                    0.042809193308238944,
                                    0.042705965088338085,
                                    0.002003556615306777,
                                ],
                                [
                                    0.8697707046154401,
                                    0.0407070237573694,
                                    0.08551977368091507,
                                    0.004002497946275466,
                                ],
                                [
                                    0.0021019423914604165,
                                    9.861293556281859e-05,
                                    0.9530853076849939,
                                    0.0447141369879829,
                                ],
                                [
                                    0.0021019423914604165,
                                    0.9530853076849939,
                                    9.861293556281859e-05,
                                    0.0447141369879829,
                                ],
                                [
                                    0.8697707046154401,
                                    0.08551977368091507,
                                    0.0407070237573694,
                                    0.004002497946275466,
                                ],
                                [
                                    0.0020035566153067995,
                                    0.9084741717575027,
                                    0.00019699871171643512,
                                    0.0893252729154741,
                                ],
                                [
                                    0.0020035566153067995,
                                    0.00019699871171643512,
                                    0.9084741717575027,
                                    0.0893252729154741,
                                ],
                                [
                                    0.7353276494291046,
                                    0.034414817532852734,
                                    0.21996282886725052,
                                    0.010294704170792078,
                                ],
                                [
                                    0.7353276494291046,
                                    0.21996282886725052,
                                    0.034414817532852734,
                                    0.010294704170792078,
                                ],
                                [
                                    0.733225479878235,
                                    0.03431643175669912,
                                    0.2220649984181201,
                                    0.010393089946945693,
                                ],
                                [
                                    0.6992189710101429,
                                    0.20916143025554437,
                                    0.07052349595181458,
                                    0.021096102782498242,
                                ],
                                [
                                    0.6992189710101429,
                                    0.07052349595181458,
                                    0.20916143025554437,
                                    0.021096102782498242,
                                ],
                                [
                                    0.733225479878235,
                                    0.2220649984181201,
                                    0.03431643175669912,
                                    0.010393089946945693,
                                ],
                                [
                                    0.6972200296791742,
                                    0.07032188195576007,
                                    0.21116037158651307,
                                    0.021297716778552765,
                                ],
                                [
                                    0.6972200296791742,
                                    0.21116037158651307,
                                    0.07032188195576007,
                                    0.021297716778552765,
                                ],
                                [
                                    0.7438848751737905,
                                    0.02784786553128241,
                                    0.22003026790302121,
                                    0.008236991391905726,
                                ],
                                [
                                    0.7438848751737905,
                                    0.22003026790302121,
                                    0.02784786553128241,
                                    0.008236991391905726,
                                ],
                                [
                                    0.7334502815850511,
                                    0.02745723901254198,
                                    0.23046486149176065,
                                    0.008627617910646156,
                                ],
                                [
                                    0.5657957030579684,
                                    0.16735409507168494,
                                    0.20593703764710458,
                                    0.060913164223242,
                                ],
                                [
                                    0.5657957030579684,
                                    0.20593703764710458,
                                    0.16735409507168494,
                                    0.060913164223242,
                                ],
                                [
                                    0.7334502815850511,
                                    0.23046486149176065,
                                    0.02745723901254198,
                                    0.008627617910646156,
                                ],
                                [
                                    0.5578591951214605,
                                    0.20304832547613264,
                                    0.17529060300819288,
                                    0.06380187639421395,
                                ],
                                [
                                    0.5578591951214605,
                                    0.17529060300819288,
                                    0.20304832547613264,
                                    0.06380187639421395,
                                ],
                                [
                                    0.7564778836677084,
                                    0.018169381438873023,
                                    0.2200670778169575,
                                    0.005285657076460985,
                                ],
                                [
                                    0.7564778836677084,
                                    0.2200670778169575,
                                    0.018169381438873023,
                                    0.005285657076460985,
                                ],
                                [
                                    0.7335729839841303,
                                    0.01761924260711722,
                                    0.24297197750053573,
                                    0.005835795908216787,
                                ],
                                [
                                    0.3691542511144177,
                                    0.10739071037024826,
                                    0.40549301399216375,
                                    0.11796202452317024,
                                ],
                                [
                                    0.3691542511144177,
                                    0.40549301399216375,
                                    0.10739071037024826,
                                    0.11796202452317024,
                                ],
                                [
                                    0.7335729839841303,
                                    0.24297197750053573,
                                    0.01761924260711722,
                                    0.005835795908216787,
                                ],
                                [
                                    0.35797687068850653,
                                    0.393215355902741,
                                    0.11856809079615946,
                                    0.13023968261259306,
                                ],
                                [
                                    0.35797687068850653,
                                    0.11856809079615946,
                                    0.393215355902741,
                                    0.13023968261259306,
                                ],
                                [
                                    0.769144511989499,
                                    0.008417277518591015,
                                    0.2200302679030212,
                                    0.0024079425888888675,
                                ],
                                [
                                    0.769144511989499,
                                    0.2200302679030212,
                                    0.008417277518591015,
                                    0.0024079425888888675,
                                ],
                                [
                                    0.7334502815850512,
                                    0.008026650999850584,
                                    0.2557244983074689,
                                    0.0027985691076292986,
                                ],
                                [
                                    0.1710170370549732,
                                    0.04892308778470541,
                                    0.6065447524531168,
                                    0.17351512270720465,
                                ],
                                [
                                    0.1710170370549732,
                                    0.6065447524531168,
                                    0.04892308778470541,
                                    0.17351512270720465,
                                ],
                                [
                                    0.7334502815850512,
                                    0.2557244983074689,
                                    0.008026650999850584,
                                    0.0027985691076292986,
                                ],
                                [
                                    0.16308052911846527,
                                    0.5783964034664365,
                                    0.05685959572121336,
                                    0.20166347169388488,
                                ],
                                [
                                    0.16308052911846527,
                                    0.05685959572121336,
                                    0.5783964034664365,
                                    0.20166347169388488,
                                ],
                                [
                                    0.7778366158057263,
                                    0.0017154474454793747,
                                    0.21996282886725052,
                                    0.00048510788154383503,
                                ],
                                [
                                    0.7778366158057263,
                                    0.21996282886725052,
                                    0.0017154474454793747,
                                    0.00048510788154383503,
                                ],
                                [
                                    0.733225479878235,
                                    0.001617061669325759,
                                    0.26457396479474177,
                                    0.0005834936576974505,
                                ],
                                [
                                    0.03485339989105089,
                                    0.009856121812593946,
                                    0.7446986633601548,
                                    0.2105918149362004,
                                ],
                                [
                                    0.03485339989105089,
                                    0.7446986633601548,
                                    0.009856121812593946,
                                    0.2105918149362004,
                                ],
                                [
                                    0.733225479878235,
                                    0.26457396479474177,
                                    0.001617061669325759,
                                    0.0005834936576974505,
                                ],
                                [
                                    0.032854458560082206,
                                    0.7019880829874786,
                                    0.011855063143562635,
                                    0.25330239530887655,
                                ],
                                [
                                    0.032854458560082206,
                                    0.011855063143562635,
                                    0.7019880829874786,
                                    0.25330239530887655,
                                ],
                                [
                                    0.6004452126839422,
                                    0.16929725427801506,
                                    0.17961466247637908,
                                    0.0506428705616635,
                                ],
                                [
                                    0.6004452126839422,
                                    0.17961466247637908,
                                    0.16929725427801506,
                                    0.0506428705616635,
                                ],
                                [
                                    0.5987286477702612,
                                    0.16881326386467296,
                                    0.1813312273900602,
                                    0.05112686097500561,
                                ],
                                [
                                    0.5643365342649804,
                                    0.16881326386467294,
                                    0.2054059326969769,
                                    0.06144426917336967,
                                ],
                                [
                                    0.5643365342649804,
                                    0.2054059326969769,
                                    0.16881326386467294,
                                    0.06144426917336967,
                                ],
                                [
                                    0.5987286477702612,
                                    0.1813312273900602,
                                    0.16881326386467296,
                                    0.05112686097500561,
                                ],
                                [
                                    0.5627231975712004,
                                    0.20481871406373392,
                                    0.17042660055845313,
                                    0.062031487806612676,
                                ],
                                [
                                    0.5627231975712004,
                                    0.17042660055845313,
                                    0.20481871406373392,
                                    0.062031487806612676,
                                ],
                                [
                                    0.6347403778239125,
                                    0.13699236288116057,
                                    0.18774692165751014,
                                    0.04052033763741682,
                                ],
                                [
                                    0.6347403778239125,
                                    0.18774692165751014,
                                    0.13699236288116057,
                                    0.04052033763741682,
                                ],
                                [
                                    0.6258367717714194,
                                    0.13507074882617381,
                                    0.19665052771000324,
                                    0.04244195169240358,
                                ],
                                [
                                    0.45665120570809026,
                                    0.13507074882617384,
                                    0.31508153499698277,
                                    0.0931965104687531,
                                ],
                                [
                                    0.45665120570809026,
                                    0.31508153499698277,
                                    0.13507074882617384,
                                    0.0931965104687531,
                                ],
                                [
                                    0.6258367717714194,
                                    0.19665052771000324,
                                    0.13507074882617381,
                                    0.04244195169240358,
                                ],
                                [
                                    0.45024568530782866,
                                    0.3106618352897645,
                                    0.14147626922643544,
                                    0.09761621017597137,
                                ],
                                [
                                    0.45024568530782866,
                                    0.14147626922643544,
                                    0.3106618352897645,
                                    0.09761621017597137,
                                ],
                                [
                                    0.6852663934342348,
                                    0.08938087167234658,
                                    0.19935093409218585,
                                    0.026001800801232634,
                                ],
                                [
                                    0.6852663934342348,
                                    0.19935093409218585,
                                    0.08938087167234658,
                                    0.026001800801232634,
                                ],
                                [
                                    0.6645176599457708,
                                    0.08667456664547663,
                                    0.2200996675806499,
                                    0.028708105828102605,
                                ],
                                [
                                    0.2979427608809441,
                                    0.08667456664547661,
                                    0.4767045042256373,
                                    0.1386781682479419,
                                ],
                                [
                                    0.2979427608809441,
                                    0.4767045042256373,
                                    0.08667456664547661,
                                    0.1386781682479419,
                                ],
                                [
                                    0.6645176599457708,
                                    0.2200996675806499,
                                    0.08667456664547663,
                                    0.028708105828102605,
                                ],
                                [
                                    0.28892154665014713,
                                    0.4622706799411004,
                                    0.09569578087627365,
                                    0.15311199253247887,
                                ],
                                [
                                    0.28892154665014713,
                                    0.09569578087627365,
                                    0.4622706799411004,
                                    0.15311199253247887,
                                ],
                                [
                                    0.7361545680101644,
                                    0.041407221497925494,
                                    0.21059278756125452,
                                    0.01184542293065555,
                                ],
                                [
                                    0.7361545680101644,
                                    0.21059278756125452,
                                    0.041407221497925494,
                                    0.01184542293065555,
                                ],
                                [
                                    0.701991325141963,
                                    0.039485607442938726,
                                    0.24475603042945593,
                                    0.01376703698564231,
                                ],
                                [
                                    0.13802709307563876,
                                    0.03948560744293873,
                                    0.6395346964324512,
                                    0.18295260304897135,
                                ],
                                [
                                    0.13802709307563876,
                                    0.6395346964324512,
                                    0.03948560744293873,
                                    0.18295260304897135,
                                ],
                                [
                                    0.701991325141963,
                                    0.24475603042945593,
                                    0.039485607442938726,
                                    0.01376703698564231,
                                ],
                                [
                                    0.13162157267537714,
                                    0.6098553599095247,
                                    0.04589112784320035,
                                    0.21263193957189788,
                                ],
                                [
                                    0.13162157267537714,
                                    0.04589112784320035,
                                    0.6098553599095247,
                                    0.21263193957189788,
                                ],
                                [
                                    0.7711132405812713,
                                    0.008438822669934388,
                                    0.21806153931124886,
                                    0.0023863974375455043,
                                ],
                                [
                                    0.7711132405812713,
                                    0.21806153931124886,
                                    0.008438822669934388,
                                    0.0023863974375455043,
                                ],
                                [
                                    0.7268877092909685,
                                    0.007954832256592284,
                                    0.2622870706015516,
                                    0.0028703878508876094,
                                ],
                                [
                                    0.028130024666595907,
                                    0.007954832256592286,
                                    0.7514220385846098,
                                    0.21249310449220207,
                                ],
                                [
                                    0.028130024666595907,
                                    0.7514220385846098,
                                    0.007954832256592286,
                                    0.21249310449220207,
                                ],
                                [
                                    0.7268877092909685,
                                    0.2622870706015516,
                                    0.007954832256592284,
                                    0.0028703878508876094,
                                ],
                                [
                                    0.026516687972815704,
                                    0.7083258535747451,
                                    0.009568168950372486,
                                    0.2555892895020667,
                                ],
                                [
                                    0.026516687972815704,
                                    0.009568168950372486,
                                    0.7083258535747451,
                                    0.2555892895020667,
                                ],
                                [
                                    0.40292557269045964,
                                    0.3668168942714977,
                                    0.1205294658248744,
                                    0.10972806721316822,
                                ],
                                [
                                    0.40292557269045964,
                                    0.1205294658248744,
                                    0.3668168942714977,
                                    0.10972806721316822,
                                ],
                                [
                                    0.4017736809169976,
                                    0.3657682307179366,
                                    0.12168135759833645,
                                    0.11077673076672936,
                                ],
                                [
                                    0.3668168942714977,
                                    0.10972806721316822,
                                    0.40292557269045964,
                                    0.1205294658248744,
                                ],
                                [
                                    0.3668168942714977,
                                    0.40292557269045964,
                                    0.10972806721316822,
                                    0.1205294658248744,
                                ],
                                [
                                    0.4017736809169976,
                                    0.12168135759833645,
                                    0.3657682307179366,
                                    0.11077673076672936,
                                ],
                                [
                                    0.3657682307179366,
                                    0.4017736809169976,
                                    0.11077673076672936,
                                    0.12168135759833645,
                                ],
                                [
                                    0.3657682307179366,
                                    0.11077673076672936,
                                    0.4017736809169976,
                                    0.12168135759833645,
                                ],
                                [
                                    0.4749109564104476,
                                    0.2968217842946254,
                                    0.1404717160631316,
                                    0.08779554323179532,
                                ],
                                [
                                    0.4749109564104476,
                                    0.1404717160631316,
                                    0.2968217842946254,
                                    0.08779554323179532,
                                ],
                                [
                                    0.4682493035305919,
                                    0.29265821706700124,
                                    0.1471333689429873,
                                    0.09195911045941951,
                                ],
                                [
                                    0.2968217842946255,
                                    0.08779554323179535,
                                    0.4749109564104475,
                                    0.14047171606313158,
                                ],
                                [
                                    0.2968217842946255,
                                    0.4749109564104475,
                                    0.08779554323179535,
                                    0.14047171606313158,
                                ],
                                [
                                    0.4682493035305919,
                                    0.1471333689429873,
                                    0.29265821706700124,
                                    0.09195911045941951,
                                ],
                                [
                                    0.2926582170670013,
                                    0.46824930353059185,
                                    0.09195911045941954,
                                    0.14713336894298729,
                                ],
                                [
                                    0.2926582170670013,
                                    0.09195911045941954,
                                    0.46824930353059185,
                                    0.14713336894298729,
                                ],
                                [
                                    0.5809854488299361,
                                    0.19366181627664536,
                                    0.16901455117006386,
                                    0.056338183723354626,
                                ],
                                [
                                    0.5809854488299361,
                                    0.16901455117006386,
                                    0.19366181627664536,
                                    0.056338183723354626,
                                ],
                                [
                                    0.5633941699434356,
                                    0.18779805664781188,
                                    0.1866058300565644,
                                    0.06220194335218813,
                                ],
                                [
                                    0.19366181627664536,
                                    0.056338183723354626,
                                    0.5809854488299361,
                                    0.16901455117006386,
                                ],
                                [
                                    0.19366181627664536,
                                    0.5809854488299361,
                                    0.056338183723354626,
                                    0.16901455117006386,
                                ],
                                [
                                    0.5633941699434356,
                                    0.1866058300565644,
                                    0.18779805664781188,
                                    0.06220194335218813,
                                ],
                                [
                                    0.18779805664781188,
                                    0.5633941699434356,
                                    0.06220194335218813,
                                    0.1866058300565644,
                                ],
                                [
                                    0.18779805664781188,
                                    0.06220194335218813,
                                    0.5633941699434356,
                                    0.1866058300565644,
                                ],
                                [
                                    0.6878446322213079,
                                    0.08971715728678212,
                                    0.19677269530511293,
                                    0.02566551518679714,
                                ],
                                [
                                    0.6878446322213079,
                                    0.19677269530511293,
                                    0.08971715728678212,
                                    0.02566551518679714,
                                ],
                                [
                                    0.6559233425257438,
                                    0.08555359005915793,
                                    0.2286939850006769,
                                    0.029829082414421327,
                                ],
                                [
                                    0.08971715728678212,
                                    0.02566551518679714,
                                    0.6878446322213079,
                                    0.19677269530511293,
                                ],
                                [
                                    0.08971715728678212,
                                    0.6878446322213079,
                                    0.02566551518679714,
                                    0.19677269530511293,
                                ],
                                [
                                    0.6559233425257438,
                                    0.2286939850006769,
                                    0.08555359005915793,
                                    0.029829082414421327,
                                ],
                                [
                                    0.08555359005915793,
                                    0.6559233425257438,
                                    0.029829082414421327,
                                    0.2286939850006769,
                                ],
                                [
                                    0.08555359005915793,
                                    0.029829082414421327,
                                    0.6559233425257438,
                                    0.2286939850006769,
                                ],
                                [
                                    0.7612676395829405,
                                    0.018284423668265142,
                                    0.21527732190172547,
                                    0.005170614847068894,
                                ],
                                [
                                    0.7612676395829405,
                                    0.21527732190172547,
                                    0.018284423668265142,
                                    0.005170614847068894,
                                ],
                                [
                                    0.7176067814328568,
                                    0.017235760114703992,
                                    0.2589381800518092,
                                    0.0062192784006300465,
                                ],
                                [
                                    0.018284423668265142,
                                    0.005170614847068894,
                                    0.7612676395829405,
                                    0.21527732190172547,
                                ],
                                [
                                    0.018284423668265142,
                                    0.7612676395829405,
                                    0.005170614847068894,
                                    0.21527732190172547,
                                ],
                                [
                                    0.7176067814328568,
                                    0.2589381800518092,
                                    0.017235760114703992,
                                    0.0062192784006300465,
                                ],
                                [
                                    0.017235760114703992,
                                    0.7176067814328568,
                                    0.0062192784006300465,
                                    0.2589381800518092,
                                ],
                                [
                                    0.017235760114703992,
                                    0.0062192784006300465,
                                    0.7176067814328568,
                                    0.2589381800518092,
                                ],
                                [
                                    0.205405932696977,
                                    0.5643365342649803,
                                    0.061444269173369696,
                                    0.1688132638646729,
                                ],
                                [
                                    0.205405932696977,
                                    0.061444269173369696,
                                    0.5643365342649803,
                                    0.1688132638646729,
                                ],
                                [
                                    0.204818714063734,
                                    0.5627231975712003,
                                    0.0620314878066127,
                                    0.17042660055845313,
                                ],
                                [
                                    0.1692972542780151,
                                    0.050642870561663514,
                                    0.6004452126839422,
                                    0.17961466247637908,
                                ],
                                [
                                    0.1692972542780151,
                                    0.6004452126839422,
                                    0.050642870561663514,
                                    0.17961466247637908,
                                ],
                                [
                                    0.204818714063734,
                                    0.0620314878066127,
                                    0.5627231975712003,
                                    0.17042660055845313,
                                ],
                                [
                                    0.16881326386467302,
                                    0.5987286477702612,
                                    0.05112686097500562,
                                    0.1813312273900602,
                                ],
                                [
                                    0.16881326386467302,
                                    0.05112686097500562,
                                    0.5987286477702612,
                                    0.1813312273900602,
                                ],
                                [
                                    0.3150815349969828,
                                    0.4566512057080902,
                                    0.09319651046875313,
                                    0.13507074882617381,
                                ],
                                [
                                    0.3150815349969828,
                                    0.09319651046875313,
                                    0.4566512057080902,
                                    0.13507074882617381,
                                ],
                                [
                                    0.3106618352897646,
                                    0.45024568530782855,
                                    0.0976162101759714,
                                    0.14147626922643544,
                                ],
                                [
                                    0.13699236288116065,
                                    0.04052033763741684,
                                    0.6347403778239123,
                                    0.1877469216575101,
                                ],
                                [
                                    0.13699236288116065,
                                    0.6347403778239123,
                                    0.04052033763741684,
                                    0.1877469216575101,
                                ],
                                [
                                    0.3106618352897646,
                                    0.0976162101759714,
                                    0.45024568530782855,
                                    0.14147626922643544,
                                ],
                                [
                                    0.13507074882617387,
                                    0.6258367717714193,
                                    0.0424419516924036,
                                    0.19665052771000324,
                                ],
                                [
                                    0.13507074882617387,
                                    0.0424419516924036,
                                    0.6258367717714193,
                                    0.19665052771000324,
                                ],
                                [
                                    0.4767045042256373,
                                    0.2979427608809441,
                                    0.1386781682479419,
                                    0.08667456664547661,
                                ],
                                [
                                    0.4767045042256373,
                                    0.1386781682479419,
                                    0.2979427608809441,
                                    0.08667456664547661,
                                ],
                                [
                                    0.4622706799411004,
                                    0.28892154665014713,
                                    0.15311199253247887,
                                    0.09569578087627365,
                                ],
                                [
                                    0.08938087167234661,
                                    0.02600180080123264,
                                    0.6852663934342348,
                                    0.19935093409218585,
                                ],
                                [
                                    0.08938087167234661,
                                    0.6852663934342348,
                                    0.02600180080123264,
                                    0.19935093409218585,
                                ],
                                [
                                    0.4622706799411004,
                                    0.15311199253247887,
                                    0.28892154665014713,
                                    0.09569578087627365,
                                ],
                                [
                                    0.08667456664547664,
                                    0.6645176599457708,
                                    0.028708105828102612,
                                    0.2200996675806499,
                                ],
                                [
                                    0.08667456664547664,
                                    0.028708105828102612,
                                    0.6645176599457708,
                                    0.2200996675806499,
                                ],
                                [
                                    0.6395346964324512,
                                    0.13802709307563873,
                                    0.18295260304897135,
                                    0.039485607442938726,
                                ],
                                [
                                    0.6395346964324512,
                                    0.18295260304897135,
                                    0.13802709307563873,
                                    0.039485607442938726,
                                ],
                                [
                                    0.6098553599095247,
                                    0.1316215726753771,
                                    0.21263193957189788,
                                    0.04589112784320034,
                                ],
                                [
                                    0.04140722149792547,
                                    0.011845422930655547,
                                    0.7361545680101644,
                                    0.21059278756125452,
                                ],
                                [
                                    0.04140722149792547,
                                    0.7361545680101644,
                                    0.011845422930655547,
                                    0.21059278756125452,
                                ],
                                [
                                    0.6098553599095247,
                                    0.21263193957189788,
                                    0.1316215726753771,
                                    0.04589112784320034,
                                ],
                                [
                                    0.03948560744293871,
                                    0.701991325141963,
                                    0.013767036985642305,
                                    0.24475603042945593,
                                ],
                                [
                                    0.03948560744293871,
                                    0.013767036985642305,
                                    0.701991325141963,
                                    0.24475603042945593,
                                ],
                                [
                                    0.7514220385846098,
                                    0.028130024666595897,
                                    0.21249310449220207,
                                    0.007954832256592282,
                                ],
                                [
                                    0.7514220385846098,
                                    0.21249310449220207,
                                    0.028130024666595897,
                                    0.007954832256592282,
                                ],
                                [
                                    0.7083258535747451,
                                    0.026516687972815693,
                                    0.2555892895020667,
                                    0.009568168950372482,
                                ],
                                [
                                    0.008438822669934381,
                                    0.002386397437545502,
                                    0.7711132405812713,
                                    0.21806153931124886,
                                ],
                                [
                                    0.008438822669934381,
                                    0.7711132405812713,
                                    0.002386397437545502,
                                    0.21806153931124886,
                                ],
                                [
                                    0.7083258535747451,
                                    0.2555892895020667,
                                    0.026516687972815693,
                                    0.009568168950372482,
                                ],
                                [
                                    0.007954832256592275,
                                    0.7268877092909685,
                                    0.0028703878508876063,
                                    0.2622870706015516,
                                ],
                                [
                                    0.007954832256592275,
                                    0.0028703878508876063,
                                    0.7268877092909685,
                                    0.2622870706015516,
                                ],
                                [
                                    0.07052349595181465,
                                    0.6992189710101427,
                                    0.021096102782498263,
                                    0.20916143025554434,
                                ],
                                [
                                    0.07052349595181465,
                                    0.021096102782498263,
                                    0.6992189710101427,
                                    0.20916143025554434,
                                ],
                                [
                                    0.07032188195576014,
                                    0.6972200296791741,
                                    0.021297716778552783,
                                    0.21116037158651305,
                                ],
                                [
                                    0.034414817532852755,
                                    0.010294704170792085,
                                    0.7353276494291046,
                                    0.21996282886725052,
                                ],
                                [
                                    0.034414817532852755,
                                    0.7353276494291046,
                                    0.010294704170792085,
                                    0.21996282886725052,
                                ],
                                [
                                    0.07032188195576014,
                                    0.021297716778552783,
                                    0.6972200296791741,
                                    0.21116037158651305,
                                ],
                                [
                                    0.03431643175669914,
                                    0.733225479878235,
                                    0.0103930899469457,
                                    0.2220649984181201,
                                ],
                                [
                                    0.03431643175669914,
                                    0.0103930899469457,
                                    0.733225479878235,
                                    0.2220649984181201,
                                ],
                                [
                                    0.20593703764710466,
                                    0.5657957030579683,
                                    0.06091316422324203,
                                    0.16735409507168492,
                                ],
                                [
                                    0.20593703764710466,
                                    0.06091316422324203,
                                    0.5657957030579683,
                                    0.16735409507168492,
                                ],
                                [
                                    0.20304832547613272,
                                    0.5578591951214604,
                                    0.06380187639421397,
                                    0.17529060300819285,
                                ],
                                [
                                    0.02784786553128245,
                                    0.008236991391905738,
                                    0.7438848751737905,
                                    0.22003026790302121,
                                ],
                                [
                                    0.02784786553128245,
                                    0.7438848751737905,
                                    0.008236991391905738,
                                    0.22003026790302121,
                                ],
                                [
                                    0.20304832547613272,
                                    0.06380187639421397,
                                    0.5578591951214604,
                                    0.17529060300819285,
                                ],
                                [
                                    0.02745723901254202,
                                    0.7334502815850511,
                                    0.00862761791064617,
                                    0.23046486149176065,
                                ],
                                [
                                    0.02745723901254202,
                                    0.00862761791064617,
                                    0.7334502815850511,
                                    0.23046486149176065,
                                ],
                                [
                                    0.40549301399216375,
                                    0.3691542511144177,
                                    0.11796202452317024,
                                    0.10739071037024826,
                                ],
                                [
                                    0.40549301399216375,
                                    0.11796202452317024,
                                    0.3691542511144177,
                                    0.10739071037024826,
                                ],
                                [
                                    0.393215355902741,
                                    0.35797687068850653,
                                    0.13023968261259306,
                                    0.11856809079615946,
                                ],
                                [
                                    0.018169381438873044,
                                    0.005285657076460991,
                                    0.7564778836677084,
                                    0.2200670778169575,
                                ],
                                [
                                    0.018169381438873044,
                                    0.7564778836677084,
                                    0.005285657076460991,
                                    0.2200670778169575,
                                ],
                                [
                                    0.393215355902741,
                                    0.13023968261259306,
                                    0.35797687068850653,
                                    0.11856809079615946,
                                ],
                                [
                                    0.017619242607117242,
                                    0.7335729839841303,
                                    0.005835795908216794,
                                    0.24297197750053573,
                                ],
                                [
                                    0.017619242607117242,
                                    0.005835795908216794,
                                    0.7335729839841303,
                                    0.24297197750053573,
                                ],
                                [
                                    0.6065447524531168,
                                    0.1710170370549732,
                                    0.17351512270720465,
                                    0.04892308778470541,
                                ],
                                [
                                    0.6065447524531168,
                                    0.17351512270720465,
                                    0.1710170370549732,
                                    0.04892308778470541,
                                ],
                                [
                                    0.5783964034664365,
                                    0.16308052911846527,
                                    0.20166347169388488,
                                    0.05685959572121336,
                                ],
                                [
                                    0.008417277518591015,
                                    0.0024079425888888675,
                                    0.769144511989499,
                                    0.2200302679030212,
                                ],
                                [
                                    0.008417277518591015,
                                    0.769144511989499,
                                    0.0024079425888888675,
                                    0.2200302679030212,
                                ],
                                [
                                    0.5783964034664365,
                                    0.20166347169388488,
                                    0.16308052911846527,
                                    0.05685959572121336,
                                ],
                                [
                                    0.008026650999850584,
                                    0.7334502815850512,
                                    0.0027985691076292986,
                                    0.2557244983074689,
                                ],
                                [
                                    0.008026650999850584,
                                    0.0027985691076292986,
                                    0.7334502815850512,
                                    0.2557244983074689,
                                ],
                                [
                                    0.7446986633601548,
                                    0.03485339989105091,
                                    0.2105918149362004,
                                    0.009856121812593951,
                                ],
                                [
                                    0.7446986633601548,
                                    0.2105918149362004,
                                    0.03485339989105091,
                                    0.009856121812593951,
                                ],
                                [
                                    0.7019880829874786,
                                    0.03285445856008222,
                                    0.25330239530887655,
                                    0.011855063143562642,
                                ],
                                [
                                    0.0017154474454793942,
                                    0.00048510788154384056,
                                    0.7778366158057263,
                                    0.21996282886725052,
                                ],
                                [
                                    0.0017154474454793942,
                                    0.7778366158057263,
                                    0.00048510788154384056,
                                    0.21996282886725052,
                                ],
                                [
                                    0.7019880829874786,
                                    0.25330239530887655,
                                    0.03285445856008222,
                                    0.011855063143562642,
                                ],
                                [
                                    0.0016170616693257777,
                                    0.733225479878235,
                                    0.0005834936576974572,
                                    0.26457396479474177,
                                ],
                                [
                                    0.0016170616693257777,
                                    0.0005834936576974572,
                                    0.733225479878235,
                                    0.26457396479474177,
                                ],
                                [
                                    0.4786963239236124,
                                    0.022403953739899216,
                                    0.4765941543727428,
                                    0.022305567963745596,
                                ],
                                [
                                    0.4786963239236124,
                                    0.4765941543727428,
                                    0.022403953739899216,
                                    0.022305567963745596,
                                ],
                                [
                                    0.4765941543727428,
                                    0.022305567963745596,
                                    0.4786963239236124,
                                    0.022403953739899216,
                                ],
                                [
                                    0.45518967129832794,
                                    0.45319072996735926,
                                    0.045910606365183675,
                                    0.045708992369129155,
                                ],
                                [
                                    0.45518967129832794,
                                    0.045910606365183675,
                                    0.45319072996735926,
                                    0.045708992369129155,
                                ],
                                [
                                    0.4765941543727428,
                                    0.4786963239236124,
                                    0.022305567963745596,
                                    0.022403953739899216,
                                ],
                                [
                                    0.45319072996735926,
                                    0.045708992369129155,
                                    0.45518967129832794,
                                    0.045910606365183675,
                                ],
                                [
                                    0.45319072996735926,
                                    0.45518967129832794,
                                    0.045708992369129155,
                                    0.045910606365183675,
                                ],
                                [
                                    0.4871748683327756,
                                    0.018237741720964283,
                                    0.4767402747440362,
                                    0.017847115202223852,
                                ],
                                [
                                    0.4871748683327756,
                                    0.4767402747440362,
                                    0.018237741720964283,
                                    0.017847115202223852,
                                ],
                                [
                                    0.4767402747440362,
                                    0.017847115202223852,
                                    0.4871748683327756,
                                    0.018237741720964283,
                                ],
                                [
                                    0.37054315303308066,
                                    0.36260664509657276,
                                    0.13486945702065925,
                                    0.13198074484968733,
                                ],
                                [
                                    0.37054315303308066,
                                    0.13486945702065925,
                                    0.36260664509657276,
                                    0.13198074484968733,
                                ],
                                [
                                    0.4767402747440362,
                                    0.4871748683327756,
                                    0.017847115202223852,
                                    0.018237741720964283,
                                ],
                                [
                                    0.36260664509657276,
                                    0.13198074484968733,
                                    0.37054315303308066,
                                    0.13486945702065925,
                                ],
                                [
                                    0.36260664509657276,
                                    0.37054315303308066,
                                    0.13198074484968733,
                                    0.13486945702065925,
                                ],
                                [
                                    0.4997249305841221,
                                    0.012002588673544905,
                                    0.47682003090054387,
                                    0.011452449841789104,
                                ],
                                [
                                    0.4997249305841221,
                                    0.47682003090054387,
                                    0.012002588673544905,
                                    0.011452449841789104,
                                ],
                                [
                                    0.47682003090054387,
                                    0.011452449841789104,
                                    0.4997249305841221,
                                    0.012002588673544905,
                                ],
                                [
                                    0.2438611709552886,
                                    0.23268379052937738,
                                    0.26786634830237843,
                                    0.2555886902129556,
                                ],
                                [
                                    0.2438611709552886,
                                    0.26786634830237843,
                                    0.23268379052937738,
                                    0.2555886902129556,
                                ],
                                [
                                    0.47682003090054387,
                                    0.4997249305841221,
                                    0.011452449841789104,
                                    0.012002588673544905,
                                ],
                                [
                                    0.23268379052937738,
                                    0.2555886902129556,
                                    0.2438611709552886,
                                    0.26786634830237843,
                                ],
                                [
                                    0.23268379052937738,
                                    0.2438611709552886,
                                    0.2555886902129556,
                                    0.26786634830237843,
                                ],
                                [
                                    0.512434505148484,
                                    0.005607923313110157,
                                    0.4767402747440362,
                                    0.005217296794369726,
                                ],
                                [
                                    0.512434505148484,
                                    0.4767402747440362,
                                    0.005607923313110157,
                                    0.005217296794369726,
                                ],
                                [
                                    0.4767402747440362,
                                    0.005217296794369726,
                                    0.512434505148484,
                                    0.005607923313110157,
                                ],
                                [
                                    0.11393831638809329,
                                    0.10600180845158533,
                                    0.40410411207350083,
                                    0.37595576308682055,
                                ],
                                [
                                    0.11393831638809329,
                                    0.40410411207350083,
                                    0.10600180845158533,
                                    0.37595576308682055,
                                ],
                                [
                                    0.4767402747440362,
                                    0.512434505148484,
                                    0.005217296794369726,
                                    0.005607923313110157,
                                ],
                                [
                                    0.10600180845158533,
                                    0.37595576308682055,
                                    0.11393831638809329,
                                    0.40410411207350083,
                                ],
                                [
                                    0.10600180845158533,
                                    0.11393831638809329,
                                    0.37595576308682055,
                                    0.40410411207350083,
                                ],
                                [
                                    0.521205290300234,
                                    0.0011494705515884126,
                                    0.4765941543727428,
                                    0.001051084775434797,
                                ],
                                [
                                    0.521205290300234,
                                    0.4765941543727428,
                                    0.0011494705515884126,
                                    0.001051084775434797,
                                ],
                                [
                                    0.4765941543727428,
                                    0.001051084775434797,
                                    0.521205290300234,
                                    0.0011494705515884126,
                                ],
                                [
                                    0.023354231517306763,
                                    0.021355290186338076,
                                    0.49900052933451566,
                                    0.4562899489618395,
                                ],
                                [
                                    0.023354231517306763,
                                    0.49900052933451566,
                                    0.021355290186338076,
                                    0.4562899489618395,
                                ],
                                [
                                    0.4765941543727428,
                                    0.521205290300234,
                                    0.001051084775434797,
                                    0.0011494705515884126,
                                ],
                                [
                                    0.021355290186338076,
                                    0.4562899489618395,
                                    0.023354231517306763,
                                    0.49900052933451566,
                                ],
                                [
                                    0.021355290186338076,
                                    0.023354231517306763,
                                    0.4562899489618395,
                                    0.49900052933451566,
                                ],
                                [
                                    0.39088822003700124,
                                    0.11021205762651033,
                                    0.38917165512332014,
                                    0.10972806721316823,
                                ],
                                [
                                    0.39088822003700124,
                                    0.38917165512332014,
                                    0.11021205762651033,
                                    0.10972806721316823,
                                ],
                                [
                                    0.38917165512332014,
                                    0.10972806721316823,
                                    0.39088822003700124,
                                    0.11021205762651033,
                                ],
                                [
                                    0.3673815674117168,
                                    0.3657682307179366,
                                    0.1337187102517948,
                                    0.13313149161855178,
                                ],
                                [
                                    0.3673815674117168,
                                    0.1337187102517948,
                                    0.3657682307179366,
                                    0.13313149161855178,
                                ],
                                [
                                    0.38917165512332014,
                                    0.39088822003700124,
                                    0.10972806721316823,
                                    0.11021205762651033,
                                ],
                                [
                                    0.3657682307179366,
                                    0.13313149161855178,
                                    0.3673815674117168,
                                    0.1337187102517948,
                                ],
                                [
                                    0.3657682307179366,
                                    0.3673815674117168,
                                    0.13313149161855178,
                                    0.1337187102517948,
                                ],
                                [
                                    0.41569545276695785,
                                    0.08971715728678208,
                                    0.4067918467144648,
                                    0.08779554323179532,
                                ],
                                [
                                    0.41569545276695785,
                                    0.4067918467144648,
                                    0.08971715728678208,
                                    0.08779554323179532,
                                ],
                                [
                                    0.4067918467144648,
                                    0.08779554323179532,
                                    0.41569545276695785,
                                    0.08971715728678208,
                                ],
                                [
                                    0.2990637374672629,
                                    0.29265821706700124,
                                    0.20634887258647708,
                                    0.2019291728792588,
                                ],
                                [
                                    0.2990637374672629,
                                    0.20634887258647708,
                                    0.29265821706700124,
                                    0.2019291728792588,
                                ],
                                [
                                    0.4067918467144648,
                                    0.41569545276695785,
                                    0.08779554323179532,
                                    0.08971715728678208,
                                ],
                                [
                                    0.29265821706700124,
                                    0.2019291728792588,
                                    0.2990637374672629,
                                    0.20634887258647708,
                                ],
                                [
                                    0.29265821706700124,
                                    0.2990637374672629,
                                    0.2019291728792588,
                                    0.20634887258647708,
                                ],
                                [
                                    0.4526830305074424,
                                    0.0590444887502246,
                                    0.43193429701897834,
                                    0.056338183723354626,
                                ],
                                [
                                    0.4526830305074424,
                                    0.43193429701897834,
                                    0.0590444887502246,
                                    0.056338183723354626,
                                ],
                                [
                                    0.43193429701897834,
                                    0.056338183723354626,
                                    0.4526830305074424,
                                    0.0590444887502246,
                                ],
                                [
                                    0.1968192708786089,
                                    0.18779805664781185,
                                    0.3149082483790581,
                                    0.30047442409452113,
                                ],
                                [
                                    0.1968192708786089,
                                    0.3149082483790581,
                                    0.18779805664781185,
                                    0.30047442409452113,
                                ],
                                [
                                    0.43193429701897834,
                                    0.4526830305074424,
                                    0.056338183723354626,
                                    0.0590444887502246,
                                ],
                                [
                                    0.18779805664781185,
                                    0.30047442409452113,
                                    0.1968192708786089,
                                    0.3149082483790581,
                                ],
                                [
                                    0.18779805664781185,
                                    0.1968192708786089,
                                    0.30047442409452113,
                                    0.3149082483790581,
                                ],
                                [
                                    0.4904552992198102,
                                    0.0275871292417839,
                                    0.4562920563516088,
                                    0.02566551518679714,
                                ],
                                [
                                    0.4904552992198102,
                                    0.4562920563516088,
                                    0.0275871292417839,
                                    0.02566551518679714,
                                ],
                                [
                                    0.4562920563516088,
                                    0.02566551518679714,
                                    0.4904552992198102,
                                    0.0275871292417839,
                                ],
                                [
                                    0.09195911045941955,
                                    0.08555359005915793,
                                    0.4260833180021745,
                                    0.396403981479248,
                                ],
                                [
                                    0.09195911045941955,
                                    0.4260833180021745,
                                    0.08555359005915793,
                                    0.396403981479248,
                                ],
                                [
                                    0.4562920563516088,
                                    0.4904552992198102,
                                    0.02566551518679714,
                                    0.0275871292417839,
                                ],
                                [
                                    0.08555359005915793,
                                    0.396403981479248,
                                    0.09195911045941955,
                                    0.4260833180021745,
                                ],
                                [
                                    0.08555359005915793,
                                    0.09195911045941955,
                                    0.396403981479248,
                                    0.4260833180021745,
                                ],
                                [
                                    0.5167001555914115,
                                    0.005654605260410999,
                                    0.4724746243011087,
                                    0.005170614847068894,
                                ],
                                [
                                    0.5167001555914115,
                                    0.4724746243011087,
                                    0.005654605260410999,
                                    0.005170614847068894,
                                ],
                                [
                                    0.4724746243011087,
                                    0.005170614847068894,
                                    0.5167001555914115,
                                    0.005654605260410999,
                                ],
                                [
                                    0.018849096808484195,
                                    0.017235760114703996,
                                    0.5035056640433382,
                                    0.46040947903347357,
                                ],
                                [
                                    0.018849096808484195,
                                    0.5035056640433382,
                                    0.017235760114703996,
                                    0.46040947903347357,
                                ],
                                [
                                    0.4724746243011087,
                                    0.5167001555914115,
                                    0.005170614847068894,
                                    0.005654605260410999,
                                ],
                                [
                                    0.017235760114703996,
                                    0.46040947903347357,
                                    0.018849096808484195,
                                    0.5035056640433382,
                                ],
                                [
                                    0.017235760114703996,
                                    0.018849096808484195,
                                    0.46040947903347357,
                                    0.5035056640433382,
                                ],
                                [
                                    0.26230346514439806,
                                    0.23879681251911355,
                                    0.261151573370936,
                                    0.2377481489655524,
                                ],
                                [
                                    0.26230346514439806,
                                    0.261151573370936,
                                    0.23879681251911355,
                                    0.2377481489655524,
                                ],
                                [
                                    0.261151573370936,
                                    0.2377481489655524,
                                    0.26230346514439806,
                                    0.23879681251911355,
                                ],
                                [
                                    0.23879681251911355,
                                    0.2377481489655524,
                                    0.26230346514439806,
                                    0.261151573370936,
                                ],
                                [
                                    0.23879681251911355,
                                    0.26230346514439806,
                                    0.2377481489655524,
                                    0.261151573370936,
                                ],
                                [
                                    0.261151573370936,
                                    0.26230346514439806,
                                    0.2377481489655524,
                                    0.23879681251911355,
                                ],
                                [
                                    0.2377481489655524,
                                    0.261151573370936,
                                    0.23879681251911355,
                                    0.26230346514439806,
                                ],
                                [
                                    0.2377481489655524,
                                    0.23879681251911355,
                                    0.261151573370936,
                                    0.26230346514439806,
                                ],
                                [
                                    0.31102216267671745,
                                    0.19439044737702246,
                                    0.3043605097968618,
                                    0.1902268801493983,
                                ],
                                [
                                    0.31102216267671745,
                                    0.3043605097968618,
                                    0.19439044737702246,
                                    0.1902268801493983,
                                ],
                                [
                                    0.3043605097968618,
                                    0.1902268801493983,
                                    0.31102216267671745,
                                    0.19439044737702246,
                                ],
                                [
                                    0.19439044737702252,
                                    0.19022688014939834,
                                    0.3110221626767174,
                                    0.30436050979686174,
                                ],
                                [
                                    0.19439044737702252,
                                    0.3110221626767174,
                                    0.19022688014939834,
                                    0.30436050979686174,
                                ],
                                [
                                    0.3043605097968618,
                                    0.31102216267671745,
                                    0.1902268801493983,
                                    0.19439044737702246,
                                ],
                                [
                                    0.19022688014939834,
                                    0.30436050979686174,
                                    0.19439044737702252,
                                    0.3110221626767174,
                                ],
                                [
                                    0.19022688014939834,
                                    0.19439044737702252,
                                    0.30436050979686174,
                                    0.3110221626767174,
                                ],
                                [
                                    0.38379563944325024,
                                    0.12793187981441675,
                                    0.36620436055674976,
                                    0.12206812018558325,
                                ],
                                [
                                    0.38379563944325024,
                                    0.36620436055674976,
                                    0.12793187981441675,
                                    0.12206812018558325,
                                ],
                                [
                                    0.36620436055674976,
                                    0.12206812018558325,
                                    0.38379563944325024,
                                    0.12793187981441675,
                                ],
                                [
                                    0.12793187981441675,
                                    0.12206812018558325,
                                    0.38379563944325024,
                                    0.36620436055674976,
                                ],
                                [
                                    0.12793187981441675,
                                    0.38379563944325024,
                                    0.12206812018558325,
                                    0.36620436055674976,
                                ],
                                [
                                    0.36620436055674976,
                                    0.38379563944325024,
                                    0.12206812018558325,
                                    0.12793187981441675,
                                ],
                                [
                                    0.12206812018558325,
                                    0.36620436055674976,
                                    0.12793187981441675,
                                    0.38379563944325024,
                                ],
                                [
                                    0.12206812018558325,
                                    0.12793187981441675,
                                    0.36620436055674976,
                                    0.38379563944325024,
                                ],
                                [
                                    0.45826930861099235,
                                    0.05977311985060172,
                                    0.4263480189154284,
                                    0.05560955262297753,
                                ],
                                [
                                    0.45826930861099235,
                                    0.4263480189154284,
                                    0.05977311985060172,
                                    0.05560955262297753,
                                ],
                                [
                                    0.4263480189154284,
                                    0.05560955262297753,
                                    0.45826930861099235,
                                    0.05977311985060172,
                                ],
                                [
                                    0.05977311985060172,
                                    0.05560955262297753,
                                    0.45826930861099235,
                                    0.4263480189154284,
                                ],
                                [
                                    0.05977311985060172,
                                    0.45826930861099235,
                                    0.05560955262297753,
                                    0.4263480189154284,
                                ],
                                [
                                    0.4263480189154284,
                                    0.45826930861099235,
                                    0.05560955262297753,
                                    0.05977311985060172,
                                ],
                                [
                                    0.05560955262297753,
                                    0.4263480189154284,
                                    0.05977311985060172,
                                    0.45826930861099235,
                                ],
                                [
                                    0.05560955262297753,
                                    0.05977311985060172,
                                    0.4263480189154284,
                                    0.45826930861099235,
                                ],
                                [
                                    0.5101029098173748,
                                    0.012251851034447595,
                                    0.46644205166729114,
                                    0.011203187480886442,
                                ],
                                [
                                    0.5101029098173748,
                                    0.46644205166729114,
                                    0.012251851034447595,
                                    0.011203187480886442,
                                ],
                                [
                                    0.46644205166729114,
                                    0.011203187480886442,
                                    0.5101029098173748,
                                    0.012251851034447595,
                                ],
                                [
                                    0.012251851034447595,
                                    0.011203187480886442,
                                    0.5101029098173748,
                                    0.46644205166729114,
                                ],
                                [
                                    0.012251851034447595,
                                    0.5101029098173748,
                                    0.011203187480886442,
                                    0.46644205166729114,
                                ],
                                [
                                    0.46644205166729114,
                                    0.5101029098173748,
                                    0.011203187480886442,
                                    0.012251851034447595,
                                ],
                                [
                                    0.011203187480886442,
                                    0.46644205166729114,
                                    0.012251851034447595,
                                    0.5101029098173748,
                                ],
                                [
                                    0.011203187480886442,
                                    0.012251851034447595,
                                    0.46644205166729114,
                                    0.5101029098173748,
                                ],
                                [
                                    0.13371871025179485,
                                    0.36738156741171674,
                                    0.13313149161855184,
                                    0.36576823071793657,
                                ],
                                [
                                    0.13371871025179485,
                                    0.13313149161855184,
                                    0.36738156741171674,
                                    0.36576823071793657,
                                ],
                                [
                                    0.13313149161855184,
                                    0.36576823071793657,
                                    0.13371871025179485,
                                    0.36738156741171674,
                                ],
                                [
                                    0.11021205762651036,
                                    0.10972806721316826,
                                    0.39088822003700124,
                                    0.38917165512332014,
                                ],
                                [
                                    0.11021205762651036,
                                    0.39088822003700124,
                                    0.10972806721316826,
                                    0.38917165512332014,
                                ],
                                [
                                    0.13313149161855184,
                                    0.13371871025179485,
                                    0.36576823071793657,
                                    0.36738156741171674,
                                ],
                                [
                                    0.10972806721316826,
                                    0.38917165512332014,
                                    0.11021205762651036,
                                    0.39088822003700124,
                                ],
                                [
                                    0.10972806721316826,
                                    0.11021205762651036,
                                    0.38917165512332014,
                                    0.39088822003700124,
                                ],
                                [
                                    0.20634887258647713,
                                    0.29906373746726284,
                                    0.20192917287925885,
                                    0.2926582170670012,
                                ],
                                [
                                    0.20634887258647713,
                                    0.20192917287925885,
                                    0.29906373746726284,
                                    0.2926582170670012,
                                ],
                                [
                                    0.20192917287925885,
                                    0.2926582170670012,
                                    0.20634887258647713,
                                    0.29906373746726284,
                                ],
                                [
                                    0.08971715728678212,
                                    0.08779554323179536,
                                    0.4156954527669578,
                                    0.4067918467144647,
                                ],
                                [
                                    0.08971715728678212,
                                    0.4156954527669578,
                                    0.08779554323179536,
                                    0.4067918467144647,
                                ],
                                [
                                    0.20192917287925885,
                                    0.20634887258647713,
                                    0.2926582170670012,
                                    0.29906373746726284,
                                ],
                                [
                                    0.08779554323179536,
                                    0.4067918467144647,
                                    0.08971715728678212,
                                    0.4156954527669578,
                                ],
                                [
                                    0.08779554323179536,
                                    0.08971715728678212,
                                    0.4067918467144647,
                                    0.4156954527669578,
                                ],
                                [
                                    0.3149082483790581,
                                    0.1968192708786089,
                                    0.30047442409452113,
                                    0.18779805664781185,
                                ],
                                [
                                    0.3149082483790581,
                                    0.30047442409452113,
                                    0.1968192708786089,
                                    0.18779805664781185,
                                ],
                                [
                                    0.30047442409452113,
                                    0.18779805664781185,
                                    0.3149082483790581,
                                    0.1968192708786089,
                                ],
                                [
                                    0.05904448875022461,
                                    0.05633818372335464,
                                    0.4526830305074424,
                                    0.43193429701897834,
                                ],
                                [
                                    0.05904448875022461,
                                    0.4526830305074424,
                                    0.05633818372335464,
                                    0.43193429701897834,
                                ],
                                [
                                    0.30047442409452113,
                                    0.3149082483790581,
                                    0.18779805664781185,
                                    0.1968192708786089,
                                ],
                                [
                                    0.05633818372335464,
                                    0.43193429701897834,
                                    0.05904448875022461,
                                    0.4526830305074424,
                                ],
                                [
                                    0.05633818372335464,
                                    0.05904448875022461,
                                    0.43193429701897834,
                                    0.4526830305074424,
                                ],
                                [
                                    0.4260833180021745,
                                    0.09195911045941954,
                                    0.396403981479248,
                                    0.08555359005915791,
                                ],
                                [
                                    0.4260833180021745,
                                    0.396403981479248,
                                    0.09195911045941954,
                                    0.08555359005915791,
                                ],
                                [
                                    0.396403981479248,
                                    0.08555359005915791,
                                    0.4260833180021745,
                                    0.09195911045941954,
                                ],
                                [
                                    0.02758712924178389,
                                    0.02566551518679713,
                                    0.4904552992198102,
                                    0.4562920563516088,
                                ],
                                [
                                    0.02758712924178389,
                                    0.4904552992198102,
                                    0.02566551518679713,
                                    0.4562920563516088,
                                ],
                                [
                                    0.396403981479248,
                                    0.4260833180021745,
                                    0.08555359005915791,
                                    0.09195911045941954,
                                ],
                                [
                                    0.02566551518679713,
                                    0.4562920563516088,
                                    0.02758712924178389,
                                    0.4904552992198102,
                                ],
                                [
                                    0.02566551518679713,
                                    0.02758712924178389,
                                    0.4562920563516088,
                                    0.4904552992198102,
                                ],
                                [
                                    0.5035056640433382,
                                    0.01884909680848419,
                                    0.46040947903347357,
                                    0.01723576011470399,
                                ],
                                [
                                    0.5035056640433382,
                                    0.46040947903347357,
                                    0.01884909680848419,
                                    0.01723576011470399,
                                ],
                                [
                                    0.46040947903347357,
                                    0.01723576011470399,
                                    0.5035056640433382,
                                    0.01884909680848419,
                                ],
                                [
                                    0.005654605260410993,
                                    0.0051706148470688894,
                                    0.5167001555914115,
                                    0.4724746243011087,
                                ],
                                [
                                    0.005654605260410993,
                                    0.5167001555914115,
                                    0.0051706148470688894,
                                    0.4724746243011087,
                                ],
                                [
                                    0.46040947903347357,
                                    0.5035056640433382,
                                    0.01723576011470399,
                                    0.01884909680848419,
                                ],
                                [
                                    0.0051706148470688894,
                                    0.4724746243011087,
                                    0.005654605260410993,
                                    0.5167001555914115,
                                ],
                                [
                                    0.0051706148470688894,
                                    0.005654605260410993,
                                    0.4724746243011087,
                                    0.5167001555914115,
                                ],
                                [
                                    0.045910606365183716,
                                    0.4551896712983279,
                                    0.045708992369129196,
                                    0.4531907299673592,
                                ],
                                [
                                    0.045910606365183716,
                                    0.045708992369129196,
                                    0.4551896712983279,
                                    0.4531907299673592,
                                ],
                                [
                                    0.045708992369129196,
                                    0.4531907299673592,
                                    0.045910606365183716,
                                    0.4551896712983279,
                                ],
                                [
                                    0.02240395373989923,
                                    0.02230556796374561,
                                    0.4786963239236124,
                                    0.4765941543727428,
                                ],
                                [
                                    0.02240395373989923,
                                    0.4786963239236124,
                                    0.02230556796374561,
                                    0.4765941543727428,
                                ],
                                [
                                    0.045708992369129196,
                                    0.045910606365183716,
                                    0.4531907299673592,
                                    0.4551896712983279,
                                ],
                                [
                                    0.02230556796374561,
                                    0.4765941543727428,
                                    0.02240395373989923,
                                    0.4786963239236124,
                                ],
                                [
                                    0.02230556796374561,
                                    0.02240395373989923,
                                    0.4765941543727428,
                                    0.4786963239236124,
                                ],
                                [
                                    0.1348694570206593,
                                    0.3705431530330806,
                                    0.1319807448496874,
                                    0.3626066450965727,
                                ],
                                [
                                    0.1348694570206593,
                                    0.1319807448496874,
                                    0.3705431530330806,
                                    0.3626066450965727,
                                ],
                                [
                                    0.1319807448496874,
                                    0.3626066450965727,
                                    0.1348694570206593,
                                    0.3705431530330806,
                                ],
                                [
                                    0.01823774172096431,
                                    0.01784711520222388,
                                    0.4871748683327756,
                                    0.4767402747440362,
                                ],
                                [
                                    0.01823774172096431,
                                    0.4871748683327756,
                                    0.01784711520222388,
                                    0.4767402747440362,
                                ],
                                [
                                    0.1319807448496874,
                                    0.1348694570206593,
                                    0.3626066450965727,
                                    0.3705431530330806,
                                ],
                                [
                                    0.01784711520222388,
                                    0.4767402747440362,
                                    0.01823774172096431,
                                    0.4871748683327756,
                                ],
                                [
                                    0.01784711520222388,
                                    0.01823774172096431,
                                    0.4767402747440362,
                                    0.4871748683327756,
                                ],
                                [
                                    0.26786634830237843,
                                    0.2438611709552886,
                                    0.2555886902129556,
                                    0.23268379052937738,
                                ],
                                [
                                    0.26786634830237843,
                                    0.2555886902129556,
                                    0.2438611709552886,
                                    0.23268379052937738,
                                ],
                                [
                                    0.2555886902129556,
                                    0.23268379052937738,
                                    0.26786634830237843,
                                    0.2438611709552886,
                                ],
                                [
                                    0.01200258867354492,
                                    0.011452449841789118,
                                    0.4997249305841221,
                                    0.47682003090054387,
                                ],
                                [
                                    0.01200258867354492,
                                    0.4997249305841221,
                                    0.011452449841789118,
                                    0.47682003090054387,
                                ],
                                [
                                    0.2555886902129556,
                                    0.26786634830237843,
                                    0.23268379052937738,
                                    0.2438611709552886,
                                ],
                                [
                                    0.011452449841789118,
                                    0.47682003090054387,
                                    0.01200258867354492,
                                    0.4997249305841221,
                                ],
                                [
                                    0.011452449841789118,
                                    0.01200258867354492,
                                    0.47682003090054387,
                                    0.4997249305841221,
                                ],
                                [
                                    0.40410411207350083,
                                    0.11393831638809329,
                                    0.37595576308682055,
                                    0.10600180845158533,
                                ],
                                [
                                    0.40410411207350083,
                                    0.37595576308682055,
                                    0.11393831638809329,
                                    0.10600180845158533,
                                ],
                                [
                                    0.37595576308682055,
                                    0.10600180845158533,
                                    0.40410411207350083,
                                    0.11393831638809329,
                                ],
                                [
                                    0.005607923313110157,
                                    0.005217296794369726,
                                    0.512434505148484,
                                    0.4767402747440362,
                                ],
                                [
                                    0.005607923313110157,
                                    0.512434505148484,
                                    0.005217296794369726,
                                    0.4767402747440362,
                                ],
                                [
                                    0.37595576308682055,
                                    0.40410411207350083,
                                    0.10600180845158533,
                                    0.11393831638809329,
                                ],
                                [
                                    0.005217296794369726,
                                    0.4767402747440362,
                                    0.005607923313110157,
                                    0.512434505148484,
                                ],
                                [
                                    0.005217296794369726,
                                    0.005607923313110157,
                                    0.4767402747440362,
                                    0.512434505148484,
                                ],
                                [
                                    0.49900052933451566,
                                    0.023354231517306773,
                                    0.4562899489618395,
                                    0.021355290186338086,
                                ],
                                [
                                    0.49900052933451566,
                                    0.4562899489618395,
                                    0.023354231517306773,
                                    0.021355290186338086,
                                ],
                                [
                                    0.4562899489618395,
                                    0.021355290186338086,
                                    0.49900052933451566,
                                    0.023354231517306773,
                                ],
                                [
                                    0.0011494705515884256,
                                    0.0010510847754348091,
                                    0.521205290300234,
                                    0.4765941543727428,
                                ],
                                [
                                    0.0011494705515884256,
                                    0.521205290300234,
                                    0.0010510847754348091,
                                    0.4765941543727428,
                                ],
                                [
                                    0.4562899489618395,
                                    0.49900052933451566,
                                    0.021355290186338086,
                                    0.023354231517306773,
                                ],
                                [
                                    0.0010510847754348091,
                                    0.4765941543727428,
                                    0.0011494705515884256,
                                    0.521205290300234,
                                ],
                                [
                                    0.0010510847754348091,
                                    0.0011494705515884256,
                                    0.4765941543727428,
                                    0.521205290300234,
                                ],
                                [
                                    0.22206499841812016,
                                    0.010393089946945697,
                                    0.7332254798782349,
                                    0.034316431756699114,
                                ],
                                [
                                    0.22206499841812016,
                                    0.7332254798782349,
                                    0.010393089946945697,
                                    0.034316431756699114,
                                ],
                                [
                                    0.21996282886725055,
                                    0.01029470417079208,
                                    0.7353276494291046,
                                    0.034414817532852734,
                                ],
                                [
                                    0.2111603715865131,
                                    0.6972200296791741,
                                    0.02129771677855277,
                                    0.07032188195576006,
                                ],
                                [
                                    0.2111603715865131,
                                    0.02129771677855277,
                                    0.6972200296791741,
                                    0.07032188195576006,
                                ],
                                [
                                    0.21996282886725055,
                                    0.7353276494291046,
                                    0.01029470417079208,
                                    0.034414817532852734,
                                ],
                                [
                                    0.2091614302555444,
                                    0.021096102782498245,
                                    0.6992189710101429,
                                    0.07052349595181458,
                                ],
                                [
                                    0.2091614302555444,
                                    0.6992189710101429,
                                    0.021096102782498245,
                                    0.07052349595181458,
                                ],
                                [
                                    0.23046486149176068,
                                    0.008627617910646158,
                                    0.7334502815850511,
                                    0.02745723901254198,
                                ],
                                [
                                    0.23046486149176068,
                                    0.7334502815850511,
                                    0.008627617910646158,
                                    0.02745723901254198,
                                ],
                                [
                                    0.22003026790302124,
                                    0.008236991391905727,
                                    0.7438848751737905,
                                    0.02784786553128241,
                                ],
                                [
                                    0.1752906030081929,
                                    0.5578591951214605,
                                    0.06380187639421395,
                                    0.20304832547613264,
                                ],
                                [
                                    0.1752906030081929,
                                    0.06380187639421395,
                                    0.5578591951214605,
                                    0.20304832547613264,
                                ],
                                [
                                    0.22003026790302124,
                                    0.7438848751737905,
                                    0.008236991391905727,
                                    0.02784786553128241,
                                ],
                                [
                                    0.16735409507168497,
                                    0.06091316422324201,
                                    0.5657957030579684,
                                    0.20593703764710458,
                                ],
                                [
                                    0.16735409507168497,
                                    0.5657957030579684,
                                    0.06091316422324201,
                                    0.20593703764710458,
                                ],
                                [
                                    0.2429719775005358,
                                    0.005835795908216789,
                                    0.7335729839841302,
                                    0.01761924260711722,
                                ],
                                [
                                    0.2429719775005358,
                                    0.7335729839841302,
                                    0.005835795908216789,
                                    0.01761924260711722,
                                ],
                                [
                                    0.22006707781695756,
                                    0.005285657076460987,
                                    0.7564778836677084,
                                    0.018169381438873023,
                                ],
                                [
                                    0.1185680907961595,
                                    0.3579768706885065,
                                    0.13023968261259308,
                                    0.3932153559027409,
                                ],
                                [
                                    0.1185680907961595,
                                    0.13023968261259308,
                                    0.3579768706885065,
                                    0.3932153559027409,
                                ],
                                [
                                    0.22006707781695756,
                                    0.7564778836677084,
                                    0.005285657076460987,
                                    0.018169381438873023,
                                ],
                                [
                                    0.10739071037024829,
                                    0.11796202452317027,
                                    0.3691542511144177,
                                    0.40549301399216375,
                                ],
                                [
                                    0.10739071037024829,
                                    0.3691542511144177,
                                    0.11796202452317027,
                                    0.40549301399216375,
                                ],
                                [
                                    0.255724498307469,
                                    0.0027985691076293,
                                    0.7334502815850511,
                                    0.008026650999850582,
                                ],
                                [
                                    0.255724498307469,
                                    0.7334502815850511,
                                    0.0027985691076293,
                                    0.008026650999850582,
                                ],
                                [
                                    0.22003026790302138,
                                    0.0024079425888888697,
                                    0.7691445119894987,
                                    0.008417277518591013,
                                ],
                                [
                                    0.05685959572121338,
                                    0.16308052911846524,
                                    0.20166347169388496,
                                    0.5783964034664364,
                                ],
                                [
                                    0.05685959572121338,
                                    0.20166347169388496,
                                    0.16308052911846524,
                                    0.5783964034664364,
                                ],
                                [
                                    0.22003026790302138,
                                    0.7691445119894987,
                                    0.0024079425888888697,
                                    0.008417277518591013,
                                ],
                                [
                                    0.04892308778470545,
                                    0.17351512270720482,
                                    0.17101703705497318,
                                    0.6065447524531166,
                                ],
                                [
                                    0.04892308778470545,
                                    0.17101703705497318,
                                    0.17351512270720482,
                                    0.6065447524531166,
                                ],
                                [
                                    0.2645739647947419,
                                    0.0005834936576974507,
                                    0.7332254798782349,
                                    0.0016170616693257588,
                                ],
                                [
                                    0.2645739647947419,
                                    0.7332254798782349,
                                    0.0005834936576974507,
                                    0.0016170616693257588,
                                ],
                                [
                                    0.21996282886725063,
                                    0.00048510788154383525,
                                    0.7778366158057262,
                                    0.0017154474454793742,
                                ],
                                [
                                    0.01185506314356264,
                                    0.0328544585600822,
                                    0.25330239530887666,
                                    0.7019880829874785,
                                ],
                                [
                                    0.01185506314356264,
                                    0.25330239530887666,
                                    0.0328544585600822,
                                    0.7019880829874785,
                                ],
                                [
                                    0.21996282886725063,
                                    0.7778366158057262,
                                    0.00048510788154383525,
                                    0.0017154474454793742,
                                ],
                                [
                                    0.009856121812593951,
                                    0.21059181493620052,
                                    0.034853399891050886,
                                    0.7446986633601547,
                                ],
                                [
                                    0.009856121812593951,
                                    0.034853399891050886,
                                    0.21059181493620052,
                                    0.7446986633601547,
                                ],
                                [
                                    0.18133122739006025,
                                    0.05112686097500562,
                                    0.5987286477702611,
                                    0.16881326386467294,
                                ],
                                [
                                    0.18133122739006025,
                                    0.5987286477702611,
                                    0.05112686097500562,
                                    0.16881326386467294,
                                ],
                                [
                                    0.1796146624763791,
                                    0.05064287056166351,
                                    0.6004452126839422,
                                    0.16929725427801506,
                                ],
                                [
                                    0.17042660055845318,
                                    0.5627231975712003,
                                    0.06203148780661269,
                                    0.2048187140637339,
                                ],
                                [
                                    0.17042660055845318,
                                    0.06203148780661269,
                                    0.5627231975712003,
                                    0.2048187140637339,
                                ],
                                [
                                    0.1796146624763791,
                                    0.6004452126839422,
                                    0.05064287056166351,
                                    0.16929725427801506,
                                ],
                                [
                                    0.16881326386467296,
                                    0.061444269173369676,
                                    0.5643365342649804,
                                    0.2054059326969769,
                                ],
                                [
                                    0.16881326386467296,
                                    0.5643365342649804,
                                    0.061444269173369676,
                                    0.2054059326969769,
                                ],
                                [
                                    0.19665052771000327,
                                    0.042441951692403584,
                                    0.6258367717714194,
                                    0.13507074882617381,
                                ],
                                [
                                    0.19665052771000327,
                                    0.6258367717714194,
                                    0.042441951692403584,
                                    0.13507074882617381,
                                ],
                                [
                                    0.18774692165751014,
                                    0.040520337637416824,
                                    0.6347403778239125,
                                    0.13699236288116057,
                                ],
                                [
                                    0.14147626922643547,
                                    0.45024568530782866,
                                    0.09761621017597139,
                                    0.3106618352897645,
                                ],
                                [
                                    0.14147626922643547,
                                    0.09761621017597139,
                                    0.45024568530782866,
                                    0.3106618352897645,
                                ],
                                [
                                    0.18774692165751014,
                                    0.6347403778239125,
                                    0.040520337637416824,
                                    0.13699236288116057,
                                ],
                                [
                                    0.13507074882617387,
                                    0.09319651046875312,
                                    0.45665120570809026,
                                    0.31508153499698277,
                                ],
                                [
                                    0.13507074882617387,
                                    0.45665120570809026,
                                    0.09319651046875312,
                                    0.31508153499698277,
                                ],
                                [
                                    0.22009966758064997,
                                    0.028708105828102615,
                                    0.6645176599457707,
                                    0.08667456664547661,
                                ],
                                [
                                    0.22009966758064997,
                                    0.6645176599457707,
                                    0.028708105828102615,
                                    0.08667456664547661,
                                ],
                                [
                                    0.1993509340921859,
                                    0.02600180080123264,
                                    0.6852663934342348,
                                    0.08938087167234658,
                                ],
                                [
                                    0.09569578087627367,
                                    0.2889215466501471,
                                    0.15311199253247892,
                                    0.4622706799411003,
                                ],
                                [
                                    0.09569578087627367,
                                    0.15311199253247892,
                                    0.2889215466501471,
                                    0.4622706799411003,
                                ],
                                [
                                    0.1993509340921859,
                                    0.6852663934342348,
                                    0.02600180080123264,
                                    0.08938087167234658,
                                ],
                                [
                                    0.08667456664547664,
                                    0.13867816824794194,
                                    0.2979427608809441,
                                    0.4767045042256373,
                                ],
                                [
                                    0.08667456664547664,
                                    0.2979427608809441,
                                    0.13867816824794194,
                                    0.4767045042256373,
                                ],
                                [
                                    0.24475603042945604,
                                    0.013767036985642318,
                                    0.7019913251419629,
                                    0.039485607442938726,
                                ],
                                [
                                    0.24475603042945604,
                                    0.7019913251419629,
                                    0.013767036985642318,
                                    0.039485607442938726,
                                ],
                                [
                                    0.2105927875612547,
                                    0.01184542293065556,
                                    0.7361545680101643,
                                    0.04140722149792548,
                                ],
                                [
                                    0.04589112784320037,
                                    0.1316215726753771,
                                    0.21263193957189797,
                                    0.6098553599095246,
                                ],
                                [
                                    0.04589112784320037,
                                    0.21263193957189797,
                                    0.1316215726753771,
                                    0.6098553599095246,
                                ],
                                [
                                    0.2105927875612547,
                                    0.7361545680101643,
                                    0.01184542293065556,
                                    0.04140722149792548,
                                ],
                                [
                                    0.03948560744293877,
                                    0.18295260304897148,
                                    0.1380270930756387,
                                    0.639534696432451,
                                ],
                                [
                                    0.03948560744293877,
                                    0.1380270930756387,
                                    0.18295260304897148,
                                    0.639534696432451,
                                ],
                                [
                                    0.2622870706015517,
                                    0.0028703878508876107,
                                    0.7268877092909684,
                                    0.007954832256592282,
                                ],
                                [
                                    0.2622870706015517,
                                    0.7268877092909684,
                                    0.0028703878508876107,
                                    0.007954832256592282,
                                ],
                                [
                                    0.21806153931124897,
                                    0.0023863974375455056,
                                    0.7711132405812712,
                                    0.008438822669934388,
                                ],
                                [
                                    0.009568168950372491,
                                    0.0265166879728157,
                                    0.25558928950206683,
                                    0.708325853574745,
                                ],
                                [
                                    0.009568168950372491,
                                    0.25558928950206683,
                                    0.0265166879728157,
                                    0.708325853574745,
                                ],
                                [
                                    0.21806153931124897,
                                    0.7711132405812712,
                                    0.0023863974375455056,
                                    0.008438822669934388,
                                ],
                                [
                                    0.00795483225659229,
                                    0.21249310449220218,
                                    0.028130024666595903,
                                    0.7514220385846097,
                                ],
                                [
                                    0.00795483225659229,
                                    0.028130024666595903,
                                    0.21249310449220218,
                                    0.7514220385846097,
                                ],
                                [
                                    0.12168135759833648,
                                    0.11077673076672939,
                                    0.40177368091699756,
                                    0.36576823071793657,
                                ],
                                [
                                    0.12168135759833648,
                                    0.40177368091699756,
                                    0.11077673076672939,
                                    0.36576823071793657,
                                ],
                                [
                                    0.12052946582487441,
                                    0.10972806721316823,
                                    0.40292557269045964,
                                    0.3668168942714977,
                                ],
                                [
                                    0.11077673076672939,
                                    0.36576823071793657,
                                    0.12168135759833648,
                                    0.40177368091699756,
                                ],
                                [
                                    0.11077673076672939,
                                    0.12168135759833648,
                                    0.36576823071793657,
                                    0.40177368091699756,
                                ],
                                [
                                    0.12052946582487441,
                                    0.40292557269045964,
                                    0.10972806721316823,
                                    0.3668168942714977,
                                ],
                                [
                                    0.10972806721316823,
                                    0.12052946582487441,
                                    0.3668168942714977,
                                    0.40292557269045964,
                                ],
                                [
                                    0.10972806721316823,
                                    0.3668168942714977,
                                    0.12052946582487441,
                                    0.40292557269045964,
                                ],
                                [
                                    0.14713336894298734,
                                    0.09195911045941953,
                                    0.4682493035305919,
                                    0.29265821706700124,
                                ],
                                [
                                    0.14713336894298734,
                                    0.4682493035305919,
                                    0.09195911045941953,
                                    0.29265821706700124,
                                ],
                                [
                                    0.14047171606313164,
                                    0.08779554323179534,
                                    0.4749109564104476,
                                    0.2968217842946254,
                                ],
                                [
                                    0.09195911045941955,
                                    0.2926582170670013,
                                    0.1471333689429873,
                                    0.46824930353059185,
                                ],
                                [
                                    0.09195911045941955,
                                    0.1471333689429873,
                                    0.2926582170670013,
                                    0.46824930353059185,
                                ],
                                [
                                    0.14047171606313164,
                                    0.4749109564104476,
                                    0.08779554323179534,
                                    0.2968217842946254,
                                ],
                                [
                                    0.08779554323179536,
                                    0.1404717160631316,
                                    0.2968217842946255,
                                    0.4749109564104475,
                                ],
                                [
                                    0.08779554323179536,
                                    0.2968217842946255,
                                    0.1404717160631316,
                                    0.4749109564104475,
                                ],
                                [
                                    0.18660583005656445,
                                    0.06220194335218815,
                                    0.5633941699434355,
                                    0.18779805664781185,
                                ],
                                [
                                    0.18660583005656445,
                                    0.5633941699434355,
                                    0.06220194335218815,
                                    0.18779805664781185,
                                ],
                                [
                                    0.16901455117006392,
                                    0.05633818372335464,
                                    0.5809854488299361,
                                    0.19366181627664536,
                                ],
                                [
                                    0.06220194335218815,
                                    0.18779805664781185,
                                    0.18660583005656445,
                                    0.5633941699434355,
                                ],
                                [
                                    0.06220194335218815,
                                    0.18660583005656445,
                                    0.18779805664781185,
                                    0.5633941699434355,
                                ],
                                [
                                    0.16901455117006392,
                                    0.5809854488299361,
                                    0.05633818372335464,
                                    0.19366181627664536,
                                ],
                                [
                                    0.05633818372335464,
                                    0.16901455117006392,
                                    0.19366181627664536,
                                    0.5809854488299361,
                                ],
                                [
                                    0.05633818372335464,
                                    0.19366181627664536,
                                    0.16901455117006392,
                                    0.5809854488299361,
                                ],
                                [
                                    0.228693985000677,
                                    0.02982908241442134,
                                    0.6559233425257438,
                                    0.08555359005915791,
                                ],
                                [
                                    0.228693985000677,
                                    0.6559233425257438,
                                    0.02982908241442134,
                                    0.08555359005915791,
                                ],
                                [
                                    0.1967726953051131,
                                    0.02566551518679716,
                                    0.6878446322213077,
                                    0.08971715728678209,
                                ],
                                [
                                    0.02982908241442134,
                                    0.08555359005915791,
                                    0.228693985000677,
                                    0.6559233425257438,
                                ],
                                [
                                    0.02982908241442134,
                                    0.228693985000677,
                                    0.08555359005915791,
                                    0.6559233425257438,
                                ],
                                [
                                    0.1967726953051131,
                                    0.6878446322213077,
                                    0.02566551518679716,
                                    0.08971715728678209,
                                ],
                                [
                                    0.02566551518679716,
                                    0.1967726953051131,
                                    0.08971715728678209,
                                    0.6878446322213077,
                                ],
                                [
                                    0.02566551518679716,
                                    0.08971715728678209,
                                    0.1967726953051131,
                                    0.6878446322213077,
                                ],
                                [
                                    0.2589381800518093,
                                    0.006219278400630049,
                                    0.7176067814328567,
                                    0.01723576011470399,
                                ],
                                [
                                    0.2589381800518093,
                                    0.7176067814328567,
                                    0.006219278400630049,
                                    0.01723576011470399,
                                ],
                                [
                                    0.21527732190172558,
                                    0.005170614847068896,
                                    0.7612676395829404,
                                    0.018284423668265142,
                                ],
                                [
                                    0.006219278400630049,
                                    0.01723576011470399,
                                    0.2589381800518093,
                                    0.7176067814328567,
                                ],
                                [
                                    0.006219278400630049,
                                    0.2589381800518093,
                                    0.01723576011470399,
                                    0.7176067814328567,
                                ],
                                [
                                    0.21527732190172558,
                                    0.7612676395829404,
                                    0.005170614847068896,
                                    0.018284423668265142,
                                ],
                                [
                                    0.005170614847068896,
                                    0.21527732190172558,
                                    0.018284423668265142,
                                    0.7612676395829404,
                                ],
                                [
                                    0.005170614847068896,
                                    0.018284423668265142,
                                    0.21527732190172558,
                                    0.7612676395829404,
                                ],
                                [
                                    0.06203148780661272,
                                    0.17042660055845316,
                                    0.20481871406373398,
                                    0.5627231975712002,
                                ],
                                [
                                    0.06203148780661272,
                                    0.20481871406373398,
                                    0.17042660055845316,
                                    0.5627231975712002,
                                ],
                                [
                                    0.0614442691733697,
                                    0.16881326386467294,
                                    0.205405932696977,
                                    0.5643365342649803,
                                ],
                                [
                                    0.051126860975005635,
                                    0.168813263864673,
                                    0.18133122739006025,
                                    0.5987286477702611,
                                ],
                                [
                                    0.051126860975005635,
                                    0.18133122739006025,
                                    0.168813263864673,
                                    0.5987286477702611,
                                ],
                                [
                                    0.0614442691733697,
                                    0.205405932696977,
                                    0.16881326386467294,
                                    0.5643365342649803,
                                ],
                                [
                                    0.05064287056166352,
                                    0.1796146624763791,
                                    0.1692972542780151,
                                    0.6004452126839422,
                                ],
                                [
                                    0.05064287056166352,
                                    0.1692972542780151,
                                    0.1796146624763791,
                                    0.6004452126839422,
                                ],
                                [
                                    0.09761621017597141,
                                    0.14147626922643544,
                                    0.3106618352897646,
                                    0.45024568530782855,
                                ],
                                [
                                    0.09761621017597141,
                                    0.3106618352897646,
                                    0.14147626922643544,
                                    0.45024568530782855,
                                ],
                                [
                                    0.09319651046875314,
                                    0.13507074882617384,
                                    0.3150815349969828,
                                    0.4566512057080902,
                                ],
                                [
                                    0.042441951692403605,
                                    0.13507074882617387,
                                    0.19665052771000324,
                                    0.6258367717714193,
                                ],
                                [
                                    0.042441951692403605,
                                    0.19665052771000324,
                                    0.13507074882617387,
                                    0.6258367717714193,
                                ],
                                [
                                    0.09319651046875314,
                                    0.3150815349969828,
                                    0.13507074882617384,
                                    0.4566512057080902,
                                ],
                                [
                                    0.040520337637416845,
                                    0.18774692165751014,
                                    0.13699236288116065,
                                    0.6347403778239123,
                                ],
                                [
                                    0.040520337637416845,
                                    0.13699236288116065,
                                    0.18774692165751014,
                                    0.6347403778239123,
                                ],
                                [
                                    0.15311199253247892,
                                    0.09569578087627367,
                                    0.4622706799411003,
                                    0.2889215466501471,
                                ],
                                [
                                    0.15311199253247892,
                                    0.4622706799411003,
                                    0.09569578087627367,
                                    0.2889215466501471,
                                ],
                                [
                                    0.13867816824794194,
                                    0.08667456664547664,
                                    0.4767045042256373,
                                    0.2979427608809441,
                                ],
                                [
                                    0.028708105828102622,
                                    0.08667456664547663,
                                    0.22009966758064997,
                                    0.6645176599457707,
                                ],
                                [
                                    0.028708105828102622,
                                    0.22009966758064997,
                                    0.08667456664547663,
                                    0.6645176599457707,
                                ],
                                [
                                    0.13867816824794194,
                                    0.4767045042256373,
                                    0.08667456664547664,
                                    0.2979427608809441,
                                ],
                                [
                                    0.026001800801232648,
                                    0.1993509340921859,
                                    0.08938087167234661,
                                    0.6852663934342348,
                                ],
                                [
                                    0.026001800801232648,
                                    0.08938087167234661,
                                    0.1993509340921859,
                                    0.6852663934342348,
                                ],
                                [
                                    0.21263193957189797,
                                    0.04589112784320036,
                                    0.6098553599095246,
                                    0.13162157267537708,
                                ],
                                [
                                    0.21263193957189797,
                                    0.6098553599095246,
                                    0.04589112784320036,
                                    0.13162157267537708,
                                ],
                                [
                                    0.18295260304897148,
                                    0.03948560744293876,
                                    0.639534696432451,
                                    0.1380270930756387,
                                ],
                                [
                                    0.013767036985642312,
                                    0.039485607442938706,
                                    0.24475603042945604,
                                    0.7019913251419629,
                                ],
                                [
                                    0.013767036985642312,
                                    0.24475603042945604,
                                    0.039485607442938706,
                                    0.7019913251419629,
                                ],
                                [
                                    0.18295260304897148,
                                    0.639534696432451,
                                    0.03948560744293876,
                                    0.1380270930756387,
                                ],
                                [
                                    0.011845422930655557,
                                    0.2105927875612547,
                                    0.041407221497925466,
                                    0.7361545680101643,
                                ],
                                [
                                    0.011845422930655557,
                                    0.041407221497925466,
                                    0.2105927875612547,
                                    0.7361545680101643,
                                ],
                                [
                                    0.25558928950206683,
                                    0.009568168950372486,
                                    0.708325853574745,
                                    0.02651668797281569,
                                ],
                                [
                                    0.25558928950206683,
                                    0.708325853574745,
                                    0.009568168950372486,
                                    0.02651668797281569,
                                ],
                                [
                                    0.21249310449220218,
                                    0.007954832256592286,
                                    0.7514220385846097,
                                    0.02813002466659589,
                                ],
                                [
                                    0.0028703878508876076,
                                    0.007954832256592275,
                                    0.2622870706015517,
                                    0.7268877092909684,
                                ],
                                [
                                    0.0028703878508876076,
                                    0.2622870706015517,
                                    0.007954832256592275,
                                    0.7268877092909684,
                                ],
                                [
                                    0.21249310449220218,
                                    0.7514220385846097,
                                    0.007954832256592286,
                                    0.02813002466659589,
                                ],
                                [
                                    0.0023863974375455035,
                                    0.21806153931124897,
                                    0.00843882266993438,
                                    0.7711132405812712,
                                ],
                                [
                                    0.0023863974375455035,
                                    0.00843882266993438,
                                    0.21806153931124897,
                                    0.7711132405812712,
                                ],
                                [
                                    0.02129771677855279,
                                    0.21116037158651307,
                                    0.07032188195576013,
                                    0.697220029679174,
                                ],
                                [
                                    0.02129771677855279,
                                    0.07032188195576013,
                                    0.21116037158651307,
                                    0.697220029679174,
                                ],
                                [
                                    0.021096102782498266,
                                    0.20916143025554437,
                                    0.07052349595181465,
                                    0.6992189710101427,
                                ],
                                [
                                    0.010393089946945702,
                                    0.034316431756699135,
                                    0.22206499841812016,
                                    0.7332254798782349,
                                ],
                                [
                                    0.010393089946945702,
                                    0.22206499841812016,
                                    0.034316431756699135,
                                    0.7332254798782349,
                                ],
                                [
                                    0.021096102782498266,
                                    0.07052349595181465,
                                    0.20916143025554437,
                                    0.6992189710101427,
                                ],
                                [
                                    0.010294704170792085,
                                    0.21996282886725055,
                                    0.034414817532852755,
                                    0.7353276494291046,
                                ],
                                [
                                    0.010294704170792085,
                                    0.034414817532852755,
                                    0.21996282886725055,
                                    0.7353276494291046,
                                ],
                                [
                                    0.06380187639421397,
                                    0.17529060300819288,
                                    0.20304832547613272,
                                    0.5578591951214604,
                                ],
                                [
                                    0.06380187639421397,
                                    0.20304832547613272,
                                    0.17529060300819288,
                                    0.5578591951214604,
                                ],
                                [
                                    0.060913164223242035,
                                    0.16735409507168494,
                                    0.20593703764710466,
                                    0.5657957030579683,
                                ],
                                [
                                    0.00862761791064617,
                                    0.02745723901254202,
                                    0.23046486149176068,
                                    0.7334502815850511,
                                ],
                                [
                                    0.00862761791064617,
                                    0.23046486149176068,
                                    0.02745723901254202,
                                    0.7334502815850511,
                                ],
                                [
                                    0.060913164223242035,
                                    0.20593703764710466,
                                    0.16735409507168494,
                                    0.5657957030579683,
                                ],
                                [
                                    0.00823699139190574,
                                    0.22003026790302124,
                                    0.02784786553128245,
                                    0.7438848751737905,
                                ],
                                [
                                    0.00823699139190574,
                                    0.02784786553128245,
                                    0.22003026790302124,
                                    0.7438848751737905,
                                ],
                                [
                                    0.13023968261259308,
                                    0.1185680907961595,
                                    0.3932153559027409,
                                    0.3579768706885065,
                                ],
                                [
                                    0.13023968261259308,
                                    0.3932153559027409,
                                    0.1185680907961595,
                                    0.3579768706885065,
                                ],
                                [
                                    0.11796202452317027,
                                    0.10739071037024829,
                                    0.40549301399216375,
                                    0.3691542511144177,
                                ],
                                [
                                    0.0058357959082167956,
                                    0.017619242607117242,
                                    0.2429719775005358,
                                    0.7335729839841302,
                                ],
                                [
                                    0.0058357959082167956,
                                    0.2429719775005358,
                                    0.017619242607117242,
                                    0.7335729839841302,
                                ],
                                [
                                    0.11796202452317027,
                                    0.40549301399216375,
                                    0.10739071037024829,
                                    0.3691542511144177,
                                ],
                                [
                                    0.005285657076460993,
                                    0.22006707781695756,
                                    0.018169381438873044,
                                    0.7564778836677084,
                                ],
                                [
                                    0.005285657076460993,
                                    0.018169381438873044,
                                    0.22006707781695756,
                                    0.7564778836677084,
                                ],
                                [
                                    0.20166347169388496,
                                    0.05685959572121338,
                                    0.5783964034664364,
                                    0.16308052911846524,
                                ],
                                [
                                    0.20166347169388496,
                                    0.5783964034664364,
                                    0.05685959572121338,
                                    0.16308052911846524,
                                ],
                                [
                                    0.17351512270720482,
                                    0.04892308778470545,
                                    0.6065447524531166,
                                    0.17101703705497318,
                                ],
                                [
                                    0.0027985691076293,
                                    0.008026650999850582,
                                    0.255724498307469,
                                    0.7334502815850511,
                                ],
                                [
                                    0.0027985691076293,
                                    0.255724498307469,
                                    0.008026650999850582,
                                    0.7334502815850511,
                                ],
                                [
                                    0.17351512270720482,
                                    0.6065447524531166,
                                    0.04892308778470545,
                                    0.17101703705497318,
                                ],
                                [
                                    0.0024079425888888697,
                                    0.22003026790302138,
                                    0.008417277518591013,
                                    0.7691445119894987,
                                ],
                                [
                                    0.0024079425888888697,
                                    0.008417277518591013,
                                    0.22003026790302138,
                                    0.7691445119894987,
                                ],
                                [
                                    0.25330239530887666,
                                    0.011855063143562645,
                                    0.7019880829874785,
                                    0.03285445856008221,
                                ],
                                [
                                    0.25330239530887666,
                                    0.7019880829874785,
                                    0.011855063143562645,
                                    0.03285445856008221,
                                ],
                                [
                                    0.21059181493620052,
                                    0.009856121812593956,
                                    0.7446986633601547,
                                    0.03485339989105091,
                                ],
                                [
                                    0.0005834936576974574,
                                    0.0016170616693257775,
                                    0.2645739647947419,
                                    0.7332254798782349,
                                ],
                                [
                                    0.0005834936576974574,
                                    0.2645739647947419,
                                    0.0016170616693257775,
                                    0.7332254798782349,
                                ],
                                [
                                    0.21059181493620052,
                                    0.7446986633601547,
                                    0.009856121812593956,
                                    0.03485339989105091,
                                ],
                                [
                                    0.00048510788154384083,
                                    0.21996282886725063,
                                    0.001715447445479394,
                                    0.7778366158057262,
                                ],
                                [
                                    0.00048510788154384083,
                                    0.001715447445479394,
                                    0.21996282886725063,
                                    0.7778366158057262,
                                ],
                                [
                                    0.046816306538852534,
                                    0.002191097598937831,
                                    0.9084741717575027,
                                    0.04251842410470698,
                                ],
                                [
                                    0.046816306538852534,
                                    0.9084741717575027,
                                    0.002191097598937831,
                                    0.04251842410470698,
                                ],
                                [
                                    0.04471413698798292,
                                    0.0020927118227842146,
                                    0.9105763413083723,
                                    0.0426168098808606,
                                ],
                                [
                                    0.044517365435675714,
                                    0.8638630358300114,
                                    0.0044900387021146555,
                                    0.08712956003219817,
                                ],
                                [
                                    0.044517365435675714,
                                    0.0044900387021146555,
                                    0.8638630358300114,
                                    0.08712956003219817,
                                ],
                                [
                                    0.04471413698798292,
                                    0.9105763413083723,
                                    0.0020927118227842146,
                                    0.0426168098808606,
                                ],
                                [
                                    0.042518424104707,
                                    0.004288424706060132,
                                    0.8658619771609802,
                                    0.0873311740282527,
                                ],
                                [
                                    0.042518424104707,
                                    0.8658619771609802,
                                    0.004288424706060132,
                                    0.0873311740282527,
                                ],
                                [
                                    0.055162439612468604,
                                    0.0020650456165634853,
                                    0.9087527034643432,
                                    0.03401981130662465,
                                ],
                                [
                                    0.055162439612468604,
                                    0.9087527034643432,
                                    0.0020650456165634853,
                                    0.03401981130662465,
                                ],
                                [
                                    0.04472784602372915,
                                    0.0016744190978230547,
                                    0.9191872970530827,
                                    0.034410437825365084,
                                ],
                                [
                                    0.0419563192431326,
                                    0.6911934788865208,
                                    0.015271165985899492,
                                    0.2515790358844471,
                                ],
                                [
                                    0.0419563192431326,
                                    0.015271165985899492,
                                    0.6911934788865208,
                                    0.2515790358844471,
                                ],
                                [
                                    0.04472784602372915,
                                    0.9191872970530827,
                                    0.0016744190978230547,
                                    0.034410437825365084,
                                ],
                                [
                                    0.03401981130662466,
                                    0.012382453814927549,
                                    0.6991299868230287,
                                    0.25446774805541905,
                                ],
                                [
                                    0.03401981130662466,
                                    0.6991299868230287,
                                    0.012382453814927549,
                                    0.25446774805541905,
                                ],
                                [
                                    0.06764022844219832,
                                    0.0016246094402921807,
                                    0.9089047330424677,
                                    0.02183042907504183,
                                ],
                                [
                                    0.06764022844219832,
                                    0.9089047330424677,
                                    0.0016246094402921807,
                                    0.02183042907504183,
                                ],
                                [
                                    0.044735328758620074,
                                    0.0010744706085363783,
                                    0.9318096327260459,
                                    0.02238056790679763,
                                ],
                                [
                                    0.03300780950095306,
                                    0.4435371519837129,
                                    0.03625702838153743,
                                    0.4871980101337966,
                                ],
                                [
                                    0.03300780950095306,
                                    0.03625702838153743,
                                    0.4435371519837129,
                                    0.4871980101337966,
                                ],
                                [
                                    0.044735328758620074,
                                    0.9318096327260459,
                                    0.0010744706085363783,
                                    0.02238056790679763,
                                ],
                                [
                                    0.02183042907504185,
                                    0.023979370292114607,
                                    0.4547145324096241,
                                    0.4994756682232194,
                                ],
                                [
                                    0.02183042907504185,
                                    0.4547145324096241,
                                    0.023979370292114607,
                                    0.4994756682232194,
                                ],
                                [
                                    0.08042207642817698,
                                    0.0008801141077719145,
                                    0.9087527034643431,
                                    0.009945105999707968,
                                ],
                                [
                                    0.08042207642817698,
                                    0.9087527034643431,
                                    0.0008801141077719145,
                                    0.009945105999707968,
                                ],
                                [
                                    0.044727846023729326,
                                    0.0004894875890314843,
                                    0.9444469338687908,
                                    0.010335732518448399,
                                ],
                                [
                                    0.017881613936215936,
                                    0.2020585109034627,
                                    0.06342057659973295,
                                    0.7166392985605884,
                                ],
                                [
                                    0.017881613936215936,
                                    0.06342057659973295,
                                    0.2020585109034627,
                                    0.7166392985605884,
                                ],
                                [
                                    0.044727846023729326,
                                    0.9444469338687908,
                                    0.0004894875890314843,
                                    0.010335732518448399,
                                ],
                                [
                                    0.00994510599970801,
                                    0.035272227613052806,
                                    0.2099950188399706,
                                    0.7447876475472686,
                                ],
                                [
                                    0.00994510599970801,
                                    0.2099950188399706,
                                    0.035272227613052806,
                                    0.7447876475472686,
                                ],
                                [
                                    0.08932527291547418,
                                    0.00019699871171643306,
                                    0.9084741717575026,
                                    0.0020035566153067765,
                                ],
                                [
                                    0.08932527291547418,
                                    0.9084741717575026,
                                    0.00019699871171643306,
                                    0.0020035566153067765,
                                ],
                                [
                                    0.04471413698798296,
                                    9.861293556281759e-05,
                                    0.9530853076849938,
                                    0.002101942391460392,
                                ],
                                [
                                    0.0040024979462754675,
                                    0.04070702375736937,
                                    0.08551977368091515,
                                    0.86977070461544,
                                ],
                                [
                                    0.0040024979462754675,
                                    0.08551977368091515,
                                    0.04070702375736937,
                                    0.86977070461544,
                                ],
                                [
                                    0.04471413698798296,
                                    0.9530853076849938,
                                    9.861293556281759e-05,
                                    0.002101942391460392,
                                ],
                                [
                                    0.0020035566153067787,
                                    0.042809193308239,
                                    0.04270596508833806,
                                    0.9124812849881162,
                                ],
                                [
                                    0.0020035566153067787,
                                    0.04270596508833806,
                                    0.042809193308239,
                                    0.9124812849881162,
                                ],
                                [
                                    0.03822870955365617,
                                    0.010778694584134193,
                                    0.7418311656066652,
                                    0.20916143025554437,
                                ],
                                [
                                    0.03822870955365617,
                                    0.7418311656066652,
                                    0.010778694584134193,
                                    0.20916143025554437,
                                ],
                                [
                                    0.03651214463997505,
                                    0.010294704170792084,
                                    0.7435477305203463,
                                    0.20964542066888647,
                                ],
                                [
                                    0.03592976845047935,
                                    0.6972200296791741,
                                    0.013077635687311018,
                                    0.25377256618303556,
                                ],
                                [
                                    0.03592976845047935,
                                    0.013077635687311018,
                                    0.6972200296791741,
                                    0.25377256618303556,
                                ],
                                [
                                    0.03651214463997505,
                                    0.7435477305203463,
                                    0.010294704170792084,
                                    0.20964542066888647,
                                ],
                                [
                                    0.03431643175669913,
                                    0.012490417054068,
                                    0.6988333663729542,
                                    0.2543597848162786,
                                ],
                                [
                                    0.03431643175669913,
                                    0.6988333663729542,
                                    0.012490417054068,
                                    0.2543597848162786,
                                ],
                                [
                                    0.04706887978213961,
                                    0.010158605446892486,
                                    0.775418419699283,
                                    0.16735409507168492,
                                ],
                                [
                                    0.04706887978213961,
                                    0.775418419699283,
                                    0.010158605446892486,
                                    0.16735409507168492,
                                ],
                                [
                                    0.03816527372964648,
                                    0.008236991391905727,
                                    0.7843220257517761,
                                    0.16927570912667167,
                                ],
                                [
                                    0.0338627594128036,
                                    0.5578591951214605,
                                    0.023364725816228494,
                                    0.38491331964950737,
                                ],
                                [
                                    0.0338627594128036,
                                    0.023364725816228494,
                                    0.5578591951214605,
                                    0.38491331964950737,
                                ],
                                [
                                    0.03816527372964648,
                                    0.7843220257517761,
                                    0.008236991391905727,
                                    0.16927570912667167,
                                ],
                                [
                                    0.027457239012541986,
                                    0.018945026109010225,
                                    0.5642647155217222,
                                    0.38933301935672565,
                                ],
                                [
                                    0.027457239012541986,
                                    0.5642647155217222,
                                    0.018945026109010225,
                                    0.38933301935672565,
                                ],
                                [
                                    0.061272875779159526,
                                    0.007991962103330964,
                                    0.8233444517472612,
                                    0.10739071037024826,
                                ],
                                [
                                    0.061272875779159526,
                                    0.8233444517472612,
                                    0.007991962103330964,
                                    0.10739071037024826,
                                ],
                                [
                                    0.04052414229069547,
                                    0.00528565707646099,
                                    0.8440931852357253,
                                    0.11009701539711823,
                                ],
                                [
                                    0.026640456837914283,
                                    0.3579768706885065,
                                    0.042624381044576214,
                                    0.572758291429003,
                                ],
                                [
                                    0.026640456837914283,
                                    0.042624381044576214,
                                    0.3579768706885065,
                                    0.572758291429003,
                                ],
                                [
                                    0.04052414229069547,
                                    0.8440931852357253,
                                    0.00528565707646099,
                                    0.11009701539711823,
                                ],
                                [
                                    0.017619242607117235,
                                    0.02819055676003922,
                                    0.3669980849193035,
                                    0.58719211571354,
                                ],
                                [
                                    0.017619242607117235,
                                    0.3669980849193035,
                                    0.02819055676003922,
                                    0.58719211571354,
                                ],
                                [
                                    0.07697263389207326,
                                    0.004329556643875633,
                                    0.8697747216793457,
                                    0.04892308778470541,
                                ],
                                [
                                    0.07697263389207326,
                                    0.8697747216793457,
                                    0.004329556643875633,
                                    0.04892308778470541,
                                ],
                                [
                                    0.042809391023871934,
                                    0.0024079425888888775,
                                    0.903937964547547,
                                    0.05084470183969216,
                                ],
                                [
                                    0.01443217140011222,
                                    0.16308052911846527,
                                    0.06687001913583668,
                                    0.7556172803455858,
                                ],
                                [
                                    0.01443217140011222,
                                    0.06687001913583668,
                                    0.16308052911846527,
                                    0.7556172803455858,
                                ],
                                [
                                    0.042809391023871934,
                                    0.903937964547547,
                                    0.0024079425888888775,
                                    0.05084470183969216,
                                ],
                                [
                                    0.008026650999850617,
                                    0.0371906826129102,
                                    0.16948604951872687,
                                    0.7852966168685124,
                                ],
                                [
                                    0.008026650999850617,
                                    0.16948604951872687,
                                    0.0371906826129102,
                                    0.7852966168685124,
                                ],
                                [
                                    0.08855317333230468,
                                    0.0009690982948859406,
                                    0.9006216065602154,
                                    0.009856121812593953,
                                ],
                                [
                                    0.08855317333230468,
                                    0.9006216065602154,
                                    0.0009690982948859406,
                                    0.009856121812593953,
                                ],
                                [
                                    0.044327642042001944,
                                    0.00048510788154383584,
                                    0.9448471378505182,
                                    0.010340112225936057,
                                ],
                                [
                                    0.003230398363105963,
                                    0.03285445856008223,
                                    0.08629187326408466,
                                    0.8776232698127272,
                                ],
                                [
                                    0.003230398363105963,
                                    0.08629187326408466,
                                    0.03285445856008223,
                                    0.8776232698127272,
                                ],
                                [
                                    0.044327642042001944,
                                    0.9448471378505182,
                                    0.00048510788154383584,
                                    0.010340112225936057,
                                ],
                                [
                                    0.001617061669325762,
                                    0.043195688254220016,
                                    0.03446779525386243,
                                    0.9207194548225918,
                                ],
                                [
                                    0.001617061669325762,
                                    0.03446779525386243,
                                    0.043195688254220016,
                                    0.9207194548225918,
                                ],
                                [
                                    0.025653172620483597,
                                    0.02335423151730677,
                                    0.4978018658948504,
                                    0.4531907299673592,
                                ],
                                [
                                    0.025653172620483597,
                                    0.4978018658948504,
                                    0.02335423151730677,
                                    0.4531907299673592,
                                ],
                                [
                                    0.024501280847021526,
                                    0.022305567963745606,
                                    0.4989537576683125,
                                    0.45423939352092035,
                                ],
                                [
                                    0.02335423151730677,
                                    0.4531907299673592,
                                    0.025653172620483597,
                                    0.4978018658948504,
                                ],
                                [
                                    0.02335423151730677,
                                    0.025653172620483597,
                                    0.4531907299673592,
                                    0.4978018658948504,
                                ],
                                [
                                    0.024501280847021526,
                                    0.4989537576683125,
                                    0.022305567963745606,
                                    0.45423939352092035,
                                ],
                                [
                                    0.022305567963745606,
                                    0.024501280847021526,
                                    0.45423939352092035,
                                    0.4989537576683125,
                                ],
                                [
                                    0.022305567963745606,
                                    0.45423939352092035,
                                    0.024501280847021526,
                                    0.4989537576683125,
                                ],
                                [
                                    0.03521680279918405,
                                    0.022010682429848043,
                                    0.5801658696743952,
                                    0.3626066450965727,
                                ],
                                [
                                    0.03521680279918405,
                                    0.5801658696743952,
                                    0.022010682429848043,
                                    0.3626066450965727,
                                ],
                                [
                                    0.028555149919328355,
                                    0.017847115202223856,
                                    0.5868275225542509,
                                    0.3667702123241969,
                                ],
                                [
                                    0.02201068242984805,
                                    0.3626066450965728,
                                    0.035216802799184044,
                                    0.5801658696743951,
                                ],
                                [
                                    0.02201068242984805,
                                    0.035216802799184044,
                                    0.3626066450965728,
                                    0.5801658696743951,
                                ],
                                [
                                    0.028555149919328355,
                                    0.5868275225542509,
                                    0.017847115202223856,
                                    0.3667702123241969,
                                ],
                                [
                                    0.017847115202223863,
                                    0.028555149919328348,
                                    0.366770212324197,
                                    0.5868275225542507,
                                ],
                                [
                                    0.017847115202223863,
                                    0.366770212324197,
                                    0.028555149919328348,
                                    0.5868275225542507,
                                ],
                                [
                                    0.05194862841186787,
                                    0.017316209470622623,
                                    0.6980513715881321,
                                    0.23268379052937738,
                                ],
                                [
                                    0.05194862841186787,
                                    0.6980513715881321,
                                    0.017316209470622623,
                                    0.23268379052937738,
                                ],
                                [
                                    0.03435734952536734,
                                    0.011452449841789114,
                                    0.7156426504746327,
                                    0.23854755015821089,
                                ],
                                [
                                    0.017316209470622623,
                                    0.23268379052937738,
                                    0.05194862841186787,
                                    0.6980513715881321,
                                ],
                                [
                                    0.017316209470622623,
                                    0.05194862841186787,
                                    0.23268379052937738,
                                    0.6980513715881321,
                                ],
                                [
                                    0.03435734952536734,
                                    0.7156426504746327,
                                    0.011452449841789114,
                                    0.23854755015821089,
                                ],
                                [
                                    0.011452449841789114,
                                    0.03435734952536734,
                                    0.23854755015821089,
                                    0.7156426504746327,
                                ],
                                [
                                    0.011452449841789114,
                                    0.23854755015821089,
                                    0.03435734952536734,
                                    0.7156426504746327,
                                ],
                                [
                                    0.07192132651395497,
                                    0.009380864021993925,
                                    0.8126960010124658,
                                    0.10600180845158533,
                                ],
                                [
                                    0.07192132651395497,
                                    0.8126960010124658,
                                    0.009380864021993925,
                                    0.10600180845158533,
                                ],
                                [
                                    0.040000036818391066,
                                    0.005217296794369747,
                                    0.8446172907080297,
                                    0.1101653756792095,
                                ],
                                [
                                    0.009380864021993925,
                                    0.10600180845158533,
                                    0.07192132651395497,
                                    0.8126960010124658,
                                ],
                                [
                                    0.009380864021993925,
                                    0.07192132651395497,
                                    0.10600180845158533,
                                    0.8126960010124658,
                                ],
                                [
                                    0.040000036818391066,
                                    0.8446172907080297,
                                    0.005217296794369747,
                                    0.1101653756792095,
                                ],
                                [
                                    0.005217296794369747,
                                    0.040000036818391066,
                                    0.1101653756792095,
                                    0.8446172907080297,
                                ],
                                [
                                    0.005217296794369747,
                                    0.1101653756792095,
                                    0.040000036818391066,
                                    0.8446172907080297,
                                ],
                                [
                                    0.08742252329819467,
                                    0.0020997483289959514,
                                    0.8891224381864713,
                                    0.021355290186338086,
                                ],
                                [
                                    0.08742252329819467,
                                    0.8891224381864713,
                                    0.0020997483289959514,
                                    0.021355290186338086,
                                ],
                                [
                                    0.04376166514811098,
                                    0.0010510847754347987,
                                    0.932783296336555,
                                    0.02240395373989924,
                                ],
                                [
                                    0.0020997483289959514,
                                    0.021355290186338086,
                                    0.08742252329819467,
                                    0.8891224381864713,
                                ],
                                [
                                    0.0020997483289959514,
                                    0.08742252329819467,
                                    0.021355290186338086,
                                    0.8891224381864713,
                                ],
                                [
                                    0.04376166514811098,
                                    0.932783296336555,
                                    0.0010510847754347987,
                                    0.02240395373989924,
                                ],
                                [
                                    0.0010510847754347987,
                                    0.04376166514811098,
                                    0.02240395373989924,
                                    0.932783296336555,
                                ],
                                [
                                    0.0010510847754347987,
                                    0.02240395373989924,
                                    0.04376166514811098,
                                    0.932783296336555,
                                ],
                                [
                                    0.013077635687311023,
                                    0.03592976845047934,
                                    0.2537725661830357,
                                    0.697220029679174,
                                ],
                                [
                                    0.013077635687311023,
                                    0.2537725661830357,
                                    0.03592976845047934,
                                    0.697220029679174,
                                ],
                                [
                                    0.012490417054068005,
                                    0.03431643175669913,
                                    0.2543597848162787,
                                    0.6988333663729542,
                                ],
                                [
                                    0.010778694584134196,
                                    0.20916143025554443,
                                    0.03822870955365617,
                                    0.7418311656066652,
                                ],
                                [
                                    0.010778694584134196,
                                    0.03822870955365617,
                                    0.20916143025554443,
                                    0.7418311656066652,
                                ],
                                [
                                    0.012490417054068005,
                                    0.2543597848162787,
                                    0.03431643175669913,
                                    0.6988333663729542,
                                ],
                                [
                                    0.010294704170792085,
                                    0.03651214463997505,
                                    0.20964542066888653,
                                    0.7435477305203463,
                                ],
                                [
                                    0.010294704170792085,
                                    0.20964542066888653,
                                    0.03651214463997505,
                                    0.7435477305203463,
                                ],
                                [
                                    0.0233647258162285,
                                    0.033862759412803596,
                                    0.3849133196495075,
                                    0.5578591951214604,
                                ],
                                [
                                    0.0233647258162285,
                                    0.3849133196495075,
                                    0.033862759412803596,
                                    0.5578591951214604,
                                ],
                                [
                                    0.018945026109010228,
                                    0.027457239012541983,
                                    0.38933301935672576,
                                    0.5642647155217221,
                                ],
                                [
                                    0.010158605446892491,
                                    0.167354095071685,
                                    0.047068879782139604,
                                    0.7754184196992829,
                                ],
                                [
                                    0.010158605446892491,
                                    0.047068879782139604,
                                    0.167354095071685,
                                    0.7754184196992829,
                                ],
                                [
                                    0.018945026109010228,
                                    0.38933301935672576,
                                    0.027457239012541983,
                                    0.5642647155217221,
                                ],
                                [
                                    0.008236991391905731,
                                    0.03816527372964648,
                                    0.16927570912667175,
                                    0.784322025751776,
                                ],
                                [
                                    0.008236991391905731,
                                    0.16927570912667175,
                                    0.03816527372964648,
                                    0.784322025751776,
                                ],
                                [
                                    0.042624381044576214,
                                    0.026640456837914283,
                                    0.572758291429003,
                                    0.3579768706885065,
                                ],
                                [
                                    0.042624381044576214,
                                    0.572758291429003,
                                    0.026640456837914283,
                                    0.3579768706885065,
                                ],
                                [
                                    0.02819055676003922,
                                    0.017619242607117235,
                                    0.58719211571354,
                                    0.3669980849193035,
                                ],
                                [
                                    0.007991962103330965,
                                    0.10739071037024829,
                                    0.061272875779159526,
                                    0.8233444517472612,
                                ],
                                [
                                    0.007991962103330965,
                                    0.061272875779159526,
                                    0.10739071037024829,
                                    0.8233444517472612,
                                ],
                                [
                                    0.02819055676003922,
                                    0.58719211571354,
                                    0.017619242607117235,
                                    0.3669980849193035,
                                ],
                                [
                                    0.005285657076460991,
                                    0.04052414229069547,
                                    0.11009701539711826,
                                    0.8440931852357253,
                                ],
                                [
                                    0.005285657076460991,
                                    0.11009701539711826,
                                    0.04052414229069547,
                                    0.8440931852357253,
                                ],
                                [
                                    0.06687001913583668,
                                    0.014432171400112218,
                                    0.7556172803455858,
                                    0.16308052911846524,
                                ],
                                [
                                    0.06687001913583668,
                                    0.7556172803455858,
                                    0.014432171400112218,
                                    0.16308052911846524,
                                ],
                                [
                                    0.0371906826129102,
                                    0.008026650999850615,
                                    0.7852966168685124,
                                    0.16948604951872684,
                                ],
                                [
                                    0.004329556643875632,
                                    0.04892308778470539,
                                    0.07697263389207326,
                                    0.8697747216793457,
                                ],
                                [
                                    0.004329556643875632,
                                    0.07697263389207326,
                                    0.04892308778470539,
                                    0.8697747216793457,
                                ],
                                [
                                    0.0371906826129102,
                                    0.7852966168685124,
                                    0.008026650999850615,
                                    0.16948604951872684,
                                ],
                                [
                                    0.002407942588888876,
                                    0.042809391023871934,
                                    0.05084470183969214,
                                    0.903937964547547,
                                ],
                                [
                                    0.002407942588888876,
                                    0.05084470183969214,
                                    0.042809391023871934,
                                    0.903937964547547,
                                ],
                                [
                                    0.08629187326408466,
                                    0.0032303983631059617,
                                    0.8776232698127272,
                                    0.03285445856008221,
                                ],
                                [
                                    0.08629187326408466,
                                    0.8776232698127272,
                                    0.0032303983631059617,
                                    0.03285445856008221,
                                ],
                                [
                                    0.043195688254220016,
                                    0.0016170616693257614,
                                    0.9207194548225918,
                                    0.03446779525386241,
                                ],
                                [
                                    0.0009690982948859397,
                                    0.009856121812593942,
                                    0.08855317333230468,
                                    0.9006216065602154,
                                ],
                                [
                                    0.0009690982948859397,
                                    0.08855317333230468,
                                    0.009856121812593942,
                                    0.9006216065602154,
                                ],
                                [
                                    0.043195688254220016,
                                    0.9207194548225918,
                                    0.0016170616693257614,
                                    0.03446779525386241,
                                ],
                                [
                                    0.00048510788154383535,
                                    0.044327642042001944,
                                    0.010340112225936048,
                                    0.9448471378505182,
                                ],
                                [
                                    0.00048510788154383535,
                                    0.010340112225936048,
                                    0.044327642042001944,
                                    0.9448471378505182,
                                ],
                                [
                                    0.00449003870211466,
                                    0.04451736543567571,
                                    0.08712956003219825,
                                    0.8638630358300113,
                                ],
                                [
                                    0.00449003870211466,
                                    0.08712956003219825,
                                    0.04451736543567571,
                                    0.8638630358300113,
                                ],
                                [
                                    0.0042884247060601365,
                                    0.042518424104707,
                                    0.08733117402825277,
                                    0.8658619771609801,
                                ],
                                [
                                    0.0021910975989378324,
                                    0.042518424104707006,
                                    0.046816306538852534,
                                    0.9084741717575027,
                                ],
                                [
                                    0.0021910975989378324,
                                    0.046816306538852534,
                                    0.042518424104707006,
                                    0.9084741717575027,
                                ],
                                [
                                    0.0042884247060601365,
                                    0.08733117402825277,
                                    0.042518424104707,
                                    0.8658619771609801,
                                ],
                                [
                                    0.002092711822784216,
                                    0.04471413698798292,
                                    0.042616809880860626,
                                    0.9105763413083723,
                                ],
                                [
                                    0.002092711822784216,
                                    0.042616809880860626,
                                    0.04471413698798292,
                                    0.9105763413083723,
                                ],
                                [
                                    0.015271165985899497,
                                    0.041956319243132596,
                                    0.2515790358844472,
                                    0.6911934788865207,
                                ],
                                [
                                    0.015271165985899497,
                                    0.2515790358844472,
                                    0.041956319243132596,
                                    0.6911934788865207,
                                ],
                                [
                                    0.012382453814927554,
                                    0.03401981130662465,
                                    0.25446774805541916,
                                    0.6991299868230286,
                                ],
                                [
                                    0.002065045616563489,
                                    0.0340198113066247,
                                    0.055162439612468604,
                                    0.9087527034643432,
                                ],
                                [
                                    0.002065045616563489,
                                    0.055162439612468604,
                                    0.0340198113066247,
                                    0.9087527034643432,
                                ],
                                [
                                    0.012382453814927554,
                                    0.25446774805541916,
                                    0.03401981130662465,
                                    0.6991299868230286,
                                ],
                                [
                                    0.0016744190978230573,
                                    0.04472784602372915,
                                    0.03441043782536513,
                                    0.9191872970530827,
                                ],
                                [
                                    0.0016744190978230573,
                                    0.03441043782536513,
                                    0.04472784602372915,
                                    0.9191872970530827,
                                ],
                                [
                                    0.03625702838153743,
                                    0.03300780950095306,
                                    0.4871980101337966,
                                    0.4435371519837129,
                                ],
                                [
                                    0.03625702838153743,
                                    0.4871980101337966,
                                    0.03300780950095306,
                                    0.4435371519837129,
                                ],
                                [
                                    0.023979370292114607,
                                    0.02183042907504185,
                                    0.4994756682232194,
                                    0.4547145324096241,
                                ],
                                [
                                    0.0016246094402921827,
                                    0.021830429075041853,
                                    0.06764022844219832,
                                    0.9089047330424677,
                                ],
                                [
                                    0.0016246094402921827,
                                    0.06764022844219832,
                                    0.021830429075041853,
                                    0.9089047330424677,
                                ],
                                [
                                    0.023979370292114607,
                                    0.4994756682232194,
                                    0.02183042907504185,
                                    0.4547145324096241,
                                ],
                                [
                                    0.0010744706085363794,
                                    0.044735328758620074,
                                    0.02238056790679766,
                                    0.9318096327260459,
                                ],
                                [
                                    0.0010744706085363794,
                                    0.02238056790679766,
                                    0.044735328758620074,
                                    0.9318096327260459,
                                ],
                                [
                                    0.06342057659973295,
                                    0.017881613936215936,
                                    0.7166392985605884,
                                    0.2020585109034627,
                                ],
                                [
                                    0.06342057659973295,
                                    0.7166392985605884,
                                    0.017881613936215936,
                                    0.2020585109034627,
                                ],
                                [
                                    0.035272227613052806,
                                    0.00994510599970801,
                                    0.7447876475472686,
                                    0.2099950188399706,
                                ],
                                [
                                    0.0008801141077719145,
                                    0.009945105999707968,
                                    0.08042207642817698,
                                    0.9087527034643431,
                                ],
                                [
                                    0.0008801141077719145,
                                    0.08042207642817698,
                                    0.009945105999707968,
                                    0.9087527034643431,
                                ],
                                [
                                    0.035272227613052806,
                                    0.7447876475472686,
                                    0.00994510599970801,
                                    0.2099950188399706,
                                ],
                                [
                                    0.0004894875890314843,
                                    0.044727846023729326,
                                    0.010335732518448399,
                                    0.9444469338687908,
                                ],
                                [
                                    0.0004894875890314843,
                                    0.010335732518448399,
                                    0.044727846023729326,
                                    0.9444469338687908,
                                ],
                                [
                                    0.08551977368091515,
                                    0.004002497946275469,
                                    0.86977070461544,
                                    0.04070702375736939,
                                ],
                                [
                                    0.08551977368091515,
                                    0.86977070461544,
                                    0.004002497946275469,
                                    0.04070702375736939,
                                ],
                                [
                                    0.042809193308239,
                                    0.0020035566153067796,
                                    0.9124812849881162,
                                    0.04270596508833808,
                                ],
                                [
                                    0.0001969987117164353,
                                    0.0020035566153067995,
                                    0.08932527291547418,
                                    0.9084741717575026,
                                ],
                                [
                                    0.0001969987117164353,
                                    0.08932527291547418,
                                    0.0020035566153067995,
                                    0.9084741717575026,
                                ],
                                [
                                    0.042809193308239,
                                    0.9124812849881162,
                                    0.0020035566153067796,
                                    0.04270596508833808,
                                ],
                                [
                                    9.861293556281873e-05,
                                    0.04471413698798296,
                                    0.002101942391460416,
                                    0.9530853076849938,
                                ],
                                [
                                    9.861293556281873e-05,
                                    0.002101942391460416,
                                    0.04471413698798296,
                                    0.9530853076849938,
                                ],
                                [
                                    0.9109628362543533,
                                    0.04263489862409449,
                                    0.04432764204200188,
                                    0.002074623079550319,
                                ],
                                [
                                    0.9109628362543533,
                                    0.04432764204200188,
                                    0.04263489862409449,
                                    0.002074623079550319,
                                ],
                                [
                                    0.9006216065602155,
                                    0.04215090821075239,
                                    0.05466887173613966,
                                    0.0025586134928924226,
                                ],
                                [
                                    0.8662294930549348,
                                    0.042150908210752396,
                                    0.08736824182351302,
                                    0.004251356910799813,
                                ],
                                [
                                    0.8662294930549348,
                                    0.08736824182351302,
                                    0.042150908210752396,
                                    0.004251356910799813,
                                ],
                                [
                                    0.9006216065602155,
                                    0.05466887173613966,
                                    0.04215090821075239,
                                    0.0025586134928924226,
                                ],
                                [
                                    0.8563960752699128,
                                    0.0863764395010551,
                                    0.05198432599577435,
                                    0.005243159233257733,
                                ],
                                [
                                    0.8563960752699128,
                                    0.05198432599577435,
                                    0.0863764395010551,
                                    0.005243159233257733,
                                ],
                                [
                                    0.92110575205294,
                                    0.03448225656862339,
                                    0.04280939102387176,
                                    0.0016026003545647465,
                                ],
                                [
                                    0.92110575205294,
                                    0.04280939102387176,
                                    0.03448225656862339,
                                    0.0016026003545647465,
                                ],
                                [
                                    0.8697747216793458,
                                    0.03256064251363663,
                                    0.09414042139746602,
                                    0.0035242144095515046,
                                ],
                                [
                                    0.7005891556160168,
                                    0.032560642513636634,
                                    0.2549988530055467,
                                    0.011851348864799875,
                                ],
                                [
                                    0.7005891556160168,
                                    0.2549988530055467,
                                    0.032560642513636634,
                                    0.011851348864799875,
                                ],
                                [
                                    0.8697747216793458,
                                    0.09414042139746602,
                                    0.03256064251363663,
                                    0.0035242144095515046,
                                ],
                                [
                                    0.6615469901033324,
                                    0.24078837408965006,
                                    0.07160280802632103,
                                    0.02606182778069651,
                                ],
                                [
                                    0.6615469901033324,
                                    0.07160280802632103,
                                    0.24078837408965006,
                                    0.02606182778069651,
                                ],
                                [
                                    0.9360208191939705,
                                    0.022481713829101357,
                                    0.040524142290695425,
                                    0.0009733246862326492,
                                ],
                                [
                                    0.9360208191939705,
                                    0.040524142290695425,
                                    0.022481713829101357,
                                    0.0009733246862326492,
                                ],
                                [
                                    0.8233444517472613,
                                    0.01977540880223139,
                                    0.15320050973740468,
                                    0.003679629713102619,
                                ],
                                [
                                    0.4567695526824345,
                                    0.019775408802231387,
                                    0.5017329803406373,
                                    0.02172205817469669,
                                ],
                                [
                                    0.4567695526824345,
                                    0.5017329803406373,
                                    0.019775408802231387,
                                    0.02172205817469669,
                                ],
                                [
                                    0.8233444517472613,
                                    0.15320050973740468,
                                    0.01977540880223139,
                                    0.003679629713102619,
                                ],
                                [
                                    0.401784521472515,
                                    0.44133533907697775,
                                    0.07476044001215103,
                                    0.08211969943835627,
                                ],
                                [
                                    0.401784521472515,
                                    0.07476044001215103,
                                    0.44133533907697775,
                                    0.08211969943835627,
                                ],
                                [
                                    0.9510095061628737,
                                    0.01040755126170671,
                                    0.038165273729646475,
                                    0.0004176688457731745,
                                ],
                                [
                                    0.9510095061628737,
                                    0.038165273729646475,
                                    0.01040755126170671,
                                    0.0004176688457731745,
                                ],
                                [
                                    0.7754184196992829,
                                    0.00848593720671995,
                                    0.2137563601932371,
                                    0.002339282900759933,
                                ],
                                [
                                    0.21145418763295867,
                                    0.00848593720671995,
                                    0.7499628697916217,
                                    0.030097005368699702,
                                ],
                                [
                                    0.21145418763295867,
                                    0.7499628697916217,
                                    0.00848593720671995,
                                    0.030097005368699702,
                                ],
                                [
                                    0.7754184196992829,
                                    0.2137563601932371,
                                    0.00848593720671995,
                                    0.002339282900759933,
                                ],
                                [
                                    0.17241202212027426,
                                    0.6114923347857286,
                                    0.047528102719404344,
                                    0.1685675403745927,
                                ],
                                [
                                    0.17241202212027426,
                                    0.047528102719404344,
                                    0.6114923347857286,
                                    0.1685675403745927,
                                ],
                                [
                                    0.9612873000330018,
                                    0.002120031134694287,
                                    0.036512144639975035,
                                    8.052419232892265e-05,
                                ],
                                [
                                    0.9612873000330018,
                                    0.036512144639975035,
                                    0.002120031134694287,
                                    8.052419232892265e-05,
                                ],
                                [
                                    0.7418311656066653,
                                    0.0016360407213521825,
                                    0.2559682790663115,
                                    0.000564514605671027,
                                ],
                                [
                                    0.043073480982292654,
                                    0.0016360407213521818,
                                    0.9203338501854034,
                                    0.03495662811095177,
                                ],
                                [
                                    0.043073480982292654,
                                    0.9203338501854034,
                                    0.0016360407213521818,
                                    0.03495662811095177,
                                ],
                                [
                                    0.7418311656066653,
                                    0.2559682790663115,
                                    0.0016360407213521825,
                                    0.000564514605671027,
                                ],
                                [
                                    0.03324006319727069,
                                    0.7102271431307468,
                                    0.011469458506374146,
                                    0.24506333516560835,
                                ],
                                [
                                    0.03324006319727069,
                                    0.011469458506374146,
                                    0.7102271431307468,
                                    0.24506333516560835,
                                ],
                                [
                                    0.7438633300224472,
                                    0.2097344048560005,
                                    0.036196545137874146,
                                    0.010205719983678054,
                                ],
                                [
                                    0.7438633300224472,
                                    0.036196545137874146,
                                    0.2097344048560005,
                                    0.010205719983678054,
                                ],
                                [
                                    0.7354190101768234,
                                    0.2073535045941444,
                                    0.0446408649834979,
                                    0.012586620245534176,
                                ],
                                [
                                    0.6991299868230287,
                                    0.03401981130662465,
                                    0.25446774805541905,
                                    0.012382453814927547,
                                ],
                                [
                                    0.6991299868230287,
                                    0.25446774805541905,
                                    0.03401981130662465,
                                    0.012382453814927547,
                                ],
                                [
                                    0.7354190101768234,
                                    0.0446408649834979,
                                    0.2073535045941444,
                                    0.012586620245534176,
                                ],
                                [
                                    0.6911934788865208,
                                    0.2515790358844471,
                                    0.04195631924313259,
                                    0.015271165985899487,
                                ],
                                [
                                    0.6911934788865208,
                                    0.04195631924313259,
                                    0.2515790358844471,
                                    0.015271165985899487,
                                ],
                                [
                                    0.7859590006279802,
                                    0.16962900799358335,
                                    0.03652829885344247,
                                    0.00788369252499404,
                                ],
                                [
                                    0.7859590006279802,
                                    0.03652829885344247,
                                    0.16962900799358335,
                                    0.00788369252499404,
                                ],
                                [
                                    0.7421593769216721,
                                    0.16017598727131035,
                                    0.0803279225597505,
                                    0.017336713247267033,
                                ],
                                [
                                    0.5654424041910567,
                                    0.02627955034320734,
                                    0.39014560443050667,
                                    0.01813244103522917,
                                ],
                                [
                                    0.5654424041910567,
                                    0.39014560443050667,
                                    0.02627955034320734,
                                    0.01813244103522917,
                                ],
                                [
                                    0.7421593769216721,
                                    0.0803279225597505,
                                    0.16017598727131035,
                                    0.017336713247267033,
                                ],
                                [
                                    0.5339316453456586,
                                    0.3684037188473238,
                                    0.0577903091886055,
                                    0.03987432661841204,
                                ],
                                [
                                    0.5339316453456586,
                                    0.0577903091886055,
                                    0.3684037188473238,
                                    0.03987432661841204,
                                ],
                                [
                                    0.8479079491901746,
                                    0.11059458383289715,
                                    0.03670937833624601,
                                    0.004788088640682062,
                                ],
                                [
                                    0.8479079491901746,
                                    0.03670937833624601,
                                    0.11059458383289715,
                                    0.004788088640682062,
                                ],
                                [
                                    0.7458384378237408,
                                    0.09728142272575191,
                                    0.13877888970268,
                                    0.018101249747827317,
                                ],
                                [
                                    0.36865668267863877,
                                    0.015960644847781976,
                                    0.5898458503444332,
                                    0.0255368221291461,
                                ],
                                [
                                    0.36865668267863877,
                                    0.5898458503444332,
                                    0.015960644847781976,
                                    0.0255368221291461,
                                ],
                                [
                                    0.7458384378237408,
                                    0.13877888970268,
                                    0.09728142272575191,
                                    0.018101249747827317,
                                ],
                                [
                                    0.32427850754899445,
                                    0.5188413530004983,
                                    0.06033881997742633,
                                    0.09654131947308098,
                                ],
                                [
                                    0.32427850754899445,
                                    0.06033881997742633,
                                    0.5188413530004983,
                                    0.09654131947308098,
                                ],
                                [
                                    0.9102190567179765,
                                    0.05119800070660386,
                                    0.03652829885344247,
                                    0.0020546437219771834,
                                ],
                                [
                                    0.9102190567179765,
                                    0.03652829885344247,
                                    0.05119800070660386,
                                    0.0020546437219771834,
                                ],
                                [
                                    0.7421593769216721,
                                    0.04174497998433086,
                                    0.20458797864974687,
                                    0.011507664444250179,
                                ],
                                [
                                    0.17066373818806155,
                                    0.006848962330515941,
                                    0.7907533192365188,
                                    0.03173398024490371,
                                ],
                                [
                                    0.17066373818806155,
                                    0.7907533192365188,
                                    0.006848962330515941,
                                    0.03173398024490371,
                                ],
                                [
                                    0.7421593769216721,
                                    0.20458797864974687,
                                    0.04174497998433086,
                                    0.011507664444250179,
                                ],
                                [
                                    0.13915297934266338,
                                    0.6447513775633396,
                                    0.0383597211759141,
                                    0.17773592191808293,
                                ],
                                [
                                    0.13915297934266338,
                                    0.0383597211759141,
                                    0.6447513775633396,
                                    0.17773592191808293,
                                ],
                                [
                                    0.9529782347546459,
                                    0.010429096413050084,
                                    0.036196545137874146,
                                    0.00039612369442980957,
                                ],
                                [
                                    0.9529782347546459,
                                    0.036196545137874146,
                                    0.010429096413050084,
                                    0.00039612369442980957,
                                ],
                                [
                                    0.7354190101768235,
                                    0.008048196151193957,
                                    0.2537557697156966,
                                    0.002777023956285936,
                                ],
                                [
                                    0.034764415703936895,
                                    0.0013204412192512963,
                                    0.9286429154637592,
                                    0.03527222761305266,
                                ],
                                [
                                    0.034764415703936895,
                                    0.9286429154637592,
                                    0.0013204412192512963,
                                    0.03527222761305266,
                                ],
                                [
                                    0.7354190101768235,
                                    0.2537557697156966,
                                    0.008048196151193957,
                                    0.002777023956285936,
                                ],
                                [
                                    0.026827907767428945,
                                    0.7166392985605885,
                                    0.009256949155759246,
                                    0.24727584451622325,
                                ],
                                [
                                    0.026827907767428945,
                                    0.009256949155759246,
                                    0.7166392985605885,
                                    0.24727584451622325,
                                ],
                                [
                                    0.4991655390389332,
                                    0.4544321958395146,
                                    0.02428949947640085,
                                    0.022112765645151355,
                                ],
                                [
                                    0.4991655390389332,
                                    0.02428949947640085,
                                    0.4544321958395146,
                                    0.022112765645151355,
                                ],
                                [
                                    0.4934990230306353,
                                    0.4492734917403326,
                                    0.029956015484698697,
                                    0.027271469744333383,
                                ],
                                [
                                    0.4544321958395146,
                                    0.022112765645151355,
                                    0.4991655390389332,
                                    0.02428949947640085,
                                ],
                                [
                                    0.4544321958395146,
                                    0.4991655390389332,
                                    0.022112765645151355,
                                    0.02428949947640085,
                                ],
                                [
                                    0.4934990230306353,
                                    0.029956015484698697,
                                    0.4492734917403326,
                                    0.027271469744333383,
                                ],
                                [
                                    0.4492734917403326,
                                    0.4934990230306353,
                                    0.027271469744333383,
                                    0.029956015484698697,
                                ],
                                [
                                    0.4492734917403326,
                                    0.027271469744333383,
                                    0.4934990230306353,
                                    0.029956015484698697,
                                ],
                                [
                                    0.5880523025292435,
                                    0.36753570609232006,
                                    0.02733036994433582,
                                    0.017081621434100688,
                                ],
                                [
                                    0.5880523025292435,
                                    0.02733036994433582,
                                    0.36753570609232006,
                                    0.017081621434100688,
                                ],
                                [
                                    0.5552815478844979,
                                    0.3470538163084845,
                                    0.060101124589081276,
                                    0.03756351121793626,
                                ],
                                [
                                    0.36753570609232017,
                                    0.017081621434100695,
                                    0.5880523025292433,
                                    0.027330369944335815,
                                ],
                                [
                                    0.36753570609232017,
                                    0.5880523025292433,
                                    0.017081621434100695,
                                    0.027330369944335815,
                                ],
                                [
                                    0.5552815478844979,
                                    0.060101124589081276,
                                    0.3470538163084845,
                                    0.03756351121793626,
                                ],
                                [
                                    0.3470538163084846,
                                    0.5552815478844979,
                                    0.037563511217936274,
                                    0.06010112458908126,
                                ],
                                [
                                    0.3470538163084846,
                                    0.037563511217936274,
                                    0.5552815478844979,
                                    0.06010112458908126,
                                ],
                                [
                                    0.7188768997673038,
                                    0.23962563325576797,
                                    0.031123100232696058,
                                    0.01037436674423202,
                                ],
                                [
                                    0.7188768997673038,
                                    0.031123100232696058,
                                    0.23962563325576797,
                                    0.01037436674423202,
                                ],
                                [
                                    0.6323398954121195,
                                    0.21077996513737318,
                                    0.11766010458788048,
                                    0.039220034862626825,
                                ],
                                [
                                    0.23962563325576797,
                                    0.01037436674423202,
                                    0.7188768997673038,
                                    0.031123100232696058,
                                ],
                                [
                                    0.23962563325576797,
                                    0.7188768997673038,
                                    0.01037436674423202,
                                    0.031123100232696058,
                                ],
                                [
                                    0.6323398954121195,
                                    0.11766010458788048,
                                    0.21077996513737318,
                                    0.039220034862626825,
                                ],
                                [
                                    0.21077996513737318,
                                    0.6323398954121195,
                                    0.039220034862626825,
                                    0.11766010458788048,
                                ],
                                [
                                    0.21077996513737318,
                                    0.039220034862626825,
                                    0.6323398954121195,
                                    0.11766010458788048,
                                ],
                                [
                                    0.8504861879772477,
                                    0.1109308694473327,
                                    0.03413113954917309,
                                    0.004451803026246562,
                                ],
                                [
                                    0.8504861879772477,
                                    0.03413113954917309,
                                    0.1109308694473327,
                                    0.004451803026246562,
                                ],
                                [
                                    0.6934553772425058,
                                    0.0904489796634971,
                                    0.1911619502839149,
                                    0.024933692810082137,
                                ],
                                [
                                    0.1109308694473327,
                                    0.004451803026246562,
                                    0.8504861879772477,
                                    0.03413113954917309,
                                ],
                                [
                                    0.1109308694473327,
                                    0.8504861879772477,
                                    0.004451803026246562,
                                    0.03413113954917309,
                                ],
                                [
                                    0.6934553772425058,
                                    0.1911619502839149,
                                    0.0904489796634971,
                                    0.024933692810082137,
                                ],
                                [
                                    0.0904489796634971,
                                    0.6934553772425058,
                                    0.024933692810082137,
                                    0.1911619502839149,
                                ],
                                [
                                    0.0904489796634971,
                                    0.024933692810082137,
                                    0.6934553772425058,
                                    0.1911619502839149,
                                ],
                                [
                                    0.9408105751092025,
                                    0.022596756058493483,
                                    0.0357343863754634,
                                    0.0008582824568405527,
                                ],
                                [
                                    0.9408105751092025,
                                    0.0357343863754634,
                                    0.022596756058493483,
                                    0.0008582824568405527,
                                ],
                                [
                                    0.726029154368706,
                                    0.017438051959311446,
                                    0.25051580711595994,
                                    0.006016986556022589,
                                ],
                                [
                                    0.022596756058493483,
                                    0.0008582824568405527,
                                    0.9408105751092025,
                                    0.0357343863754634,
                                ],
                                [
                                    0.022596756058493483,
                                    0.9408105751092025,
                                    0.0008582824568405527,
                                    0.0357343863754634,
                                ],
                                [
                                    0.726029154368706,
                                    0.25051580711595994,
                                    0.017438051959311446,
                                    0.006016986556022589,
                                ],
                                [
                                    0.017438051959311446,
                                    0.726029154368706,
                                    0.006016986556022589,
                                    0.25051580711595994,
                                ],
                                [
                                    0.017438051959311446,
                                    0.006016986556022589,
                                    0.726029154368706,
                                    0.25051580711595994,
                                ],
                                [
                                    0.25446774805541916,
                                    0.6991299868230286,
                                    0.012382453814927552,
                                    0.03401981130662465,
                                ],
                                [
                                    0.25446774805541916,
                                    0.012382453814927552,
                                    0.6991299868230286,
                                    0.03401981130662465,
                                ],
                                [
                                    0.2515790358844472,
                                    0.6911934788865207,
                                    0.015271165985899494,
                                    0.04195631924313258,
                                ],
                                [
                                    0.20973440485600056,
                                    0.010205719983678056,
                                    0.7438633300224472,
                                    0.036196545137874146,
                                ],
                                [
                                    0.20973440485600056,
                                    0.7438633300224472,
                                    0.010205719983678056,
                                    0.036196545137874146,
                                ],
                                [
                                    0.2515790358844472,
                                    0.015271165985899494,
                                    0.6911934788865207,
                                    0.04195631924313258,
                                ],
                                [
                                    0.20735350459414445,
                                    0.7354190101768234,
                                    0.01258662024553418,
                                    0.0446408649834979,
                                ],
                                [
                                    0.20735350459414445,
                                    0.01258662024553418,
                                    0.7354190101768234,
                                    0.0446408649834979,
                                ],
                                [
                                    0.3901456044305068,
                                    0.5654424041910566,
                                    0.018132441035229176,
                                    0.026279550343207333,
                                ],
                                [
                                    0.3901456044305068,
                                    0.018132441035229176,
                                    0.5654424041910566,
                                    0.026279550343207333,
                                ],
                                [
                                    0.3684037188473239,
                                    0.5339316453456585,
                                    0.03987432661841205,
                                    0.05779030918860548,
                                ],
                                [
                                    0.16962900799358344,
                                    0.007883692524994046,
                                    0.7859590006279801,
                                    0.03652829885344246,
                                ],
                                [
                                    0.16962900799358344,
                                    0.7859590006279801,
                                    0.007883692524994046,
                                    0.03652829885344246,
                                ],
                                [
                                    0.3684037188473239,
                                    0.03987432661841205,
                                    0.5339316453456585,
                                    0.05779030918860548,
                                ],
                                [
                                    0.16017598727131044,
                                    0.742159376921672,
                                    0.017336713247267044,
                                    0.08032792255975049,
                                ],
                                [
                                    0.16017598727131044,
                                    0.017336713247267044,
                                    0.742159376921672,
                                    0.08032792255975049,
                                ],
                                [
                                    0.5898458503444332,
                                    0.36865668267863877,
                                    0.0255368221291461,
                                    0.015960644847781976,
                                ],
                                [
                                    0.5898458503444332,
                                    0.0255368221291461,
                                    0.36865668267863877,
                                    0.015960644847781976,
                                ],
                                [
                                    0.5188413530004983,
                                    0.32427850754899445,
                                    0.09654131947308098,
                                    0.06033881997742633,
                                ],
                                [
                                    0.11059458383289718,
                                    0.004788088640682063,
                                    0.8479079491901746,
                                    0.03670937833624601,
                                ],
                                [
                                    0.11059458383289718,
                                    0.8479079491901746,
                                    0.004788088640682063,
                                    0.03670937833624601,
                                ],
                                [
                                    0.5188413530004983,
                                    0.09654131947308098,
                                    0.32427850754899445,
                                    0.06033881997742633,
                                ],
                                [
                                    0.09728142272575194,
                                    0.7458384378237408,
                                    0.018101249747827324,
                                    0.13877888970268,
                                ],
                                [
                                    0.09728142272575194,
                                    0.018101249747827324,
                                    0.7458384378237408,
                                    0.13877888970268,
                                ],
                                [
                                    0.7907533192365188,
                                    0.17066373818806152,
                                    0.03173398024490371,
                                    0.00684896233051594,
                                ],
                                [
                                    0.7907533192365188,
                                    0.03173398024490371,
                                    0.17066373818806152,
                                    0.00684896233051594,
                                ],
                                [
                                    0.6447513775633396,
                                    0.13915297934266335,
                                    0.17773592191808293,
                                    0.038359721175914095,
                                ],
                                [
                                    0.05119800070660384,
                                    0.0020546437219771826,
                                    0.9102190567179765,
                                    0.03652829885344247,
                                ],
                                [
                                    0.05119800070660384,
                                    0.9102190567179765,
                                    0.0020546437219771826,
                                    0.03652829885344247,
                                ],
                                [
                                    0.6447513775633396,
                                    0.17773592191808293,
                                    0.13915297934266335,
                                    0.038359721175914095,
                                ],
                                [
                                    0.04174497998433084,
                                    0.7421593769216721,
                                    0.011507664444250174,
                                    0.20458797864974687,
                                ],
                                [
                                    0.04174497998433084,
                                    0.011507664444250174,
                                    0.7421593769216721,
                                    0.20458797864974687,
                                ],
                                [
                                    0.9286429154637592,
                                    0.03476441570393688,
                                    0.03527222761305266,
                                    0.0013204412192512956,
                                ],
                                [
                                    0.9286429154637592,
                                    0.03527222761305266,
                                    0.03476441570393688,
                                    0.0013204412192512956,
                                ],
                                [
                                    0.7166392985605885,
                                    0.026827907767428934,
                                    0.24727584451622325,
                                    0.009256949155759243,
                                ],
                                [
                                    0.010429096413050074,
                                    0.0003961236944298092,
                                    0.9529782347546459,
                                    0.036196545137874146,
                                ],
                                [
                                    0.010429096413050074,
                                    0.9529782347546459,
                                    0.0003961236944298092,
                                    0.036196545137874146,
                                ],
                                [
                                    0.7166392985605885,
                                    0.24727584451622325,
                                    0.026827907767428934,
                                    0.009256949155759243,
                                ],
                                [
                                    0.008048196151193949,
                                    0.7354190101768235,
                                    0.002777023956285933,
                                    0.2537557697156966,
                                ],
                                [
                                    0.008048196151193949,
                                    0.002777023956285933,
                                    0.7354190101768235,
                                    0.2537557697156966,
                                ],
                                [
                                    0.08736824182351309,
                                    0.8662294930549347,
                                    0.004251356910799816,
                                    0.04215090821075239,
                                ],
                                [
                                    0.08736824182351309,
                                    0.004251356910799816,
                                    0.8662294930549347,
                                    0.04215090821075239,
                                ],
                                [
                                    0.08637643950105517,
                                    0.8563960752699127,
                                    0.0052431592332577385,
                                    0.05198432599577434,
                                ],
                                [
                                    0.04263489862409452,
                                    0.00207462307955032,
                                    0.9109628362543533,
                                    0.04432764204200188,
                                ],
                                [
                                    0.04263489862409452,
                                    0.9109628362543533,
                                    0.00207462307955032,
                                    0.04432764204200188,
                                ],
                                [
                                    0.08637643950105517,
                                    0.0052431592332577385,
                                    0.8563960752699127,
                                    0.05198432599577434,
                                ],
                                [
                                    0.042150908210752416,
                                    0.9006216065602155,
                                    0.0025586134928924243,
                                    0.05466887173613966,
                                ],
                                [
                                    0.042150908210752416,
                                    0.0025586134928924243,
                                    0.9006216065602155,
                                    0.05466887173613966,
                                ],
                                [
                                    0.2549988530055468,
                                    0.7005891556160166,
                                    0.011851348864799879,
                                    0.03256064251363663,
                                ],
                                [
                                    0.2549988530055468,
                                    0.011851348864799879,
                                    0.7005891556160166,
                                    0.03256064251363663,
                                ],
                                [
                                    0.24078837408965018,
                                    0.6615469901033323,
                                    0.02606182778069652,
                                    0.07160280802632102,
                                ],
                                [
                                    0.03448225656862344,
                                    0.001602600354564749,
                                    0.92110575205294,
                                    0.04280939102387176,
                                ],
                                [
                                    0.03448225656862344,
                                    0.92110575205294,
                                    0.001602600354564749,
                                    0.04280939102387176,
                                ],
                                [
                                    0.24078837408965018,
                                    0.02606182778069652,
                                    0.6615469901033323,
                                    0.07160280802632102,
                                ],
                                [
                                    0.03256064251363668,
                                    0.8697747216793458,
                                    0.0035242144095515102,
                                    0.09414042139746602,
                                ],
                                [
                                    0.03256064251363668,
                                    0.0035242144095515102,
                                    0.8697747216793458,
                                    0.09414042139746602,
                                ],
                                [
                                    0.5017329803406373,
                                    0.4567695526824345,
                                    0.02172205817469669,
                                    0.019775408802231387,
                                ],
                                [
                                    0.5017329803406373,
                                    0.02172205817469669,
                                    0.4567695526824345,
                                    0.019775408802231387,
                                ],
                                [
                                    0.44133533907697775,
                                    0.401784521472515,
                                    0.08211969943835627,
                                    0.07476044001215103,
                                ],
                                [
                                    0.022481713829101385,
                                    0.0009733246862326504,
                                    0.9360208191939705,
                                    0.040524142290695425,
                                ],
                                [
                                    0.022481713829101385,
                                    0.9360208191939705,
                                    0.0009733246862326504,
                                    0.040524142290695425,
                                ],
                                [
                                    0.44133533907697775,
                                    0.08211969943835627,
                                    0.401784521472515,
                                    0.07476044001215103,
                                ],
                                [
                                    0.019775408802231415,
                                    0.8233444517472613,
                                    0.003679629713102623,
                                    0.15320050973740468,
                                ],
                                [
                                    0.019775408802231415,
                                    0.003679629713102623,
                                    0.8233444517472613,
                                    0.15320050973740468,
                                ],
                                [
                                    0.7499628697916217,
                                    0.21145418763295867,
                                    0.030097005368699702,
                                    0.00848593720671995,
                                ],
                                [
                                    0.7499628697916217,
                                    0.030097005368699702,
                                    0.21145418763295867,
                                    0.00848593720671995,
                                ],
                                [
                                    0.6114923347857286,
                                    0.17241202212027426,
                                    0.1685675403745927,
                                    0.047528102719404344,
                                ],
                                [
                                    0.01040755126170671,
                                    0.0004176688457731745,
                                    0.9510095061628737,
                                    0.038165273729646475,
                                ],
                                [
                                    0.01040755126170671,
                                    0.9510095061628737,
                                    0.0004176688457731745,
                                    0.038165273729646475,
                                ],
                                [
                                    0.6114923347857286,
                                    0.1685675403745927,
                                    0.17241202212027426,
                                    0.047528102719404344,
                                ],
                                [
                                    0.00848593720671995,
                                    0.7754184196992829,
                                    0.002339282900759933,
                                    0.2137563601932371,
                                ],
                                [
                                    0.00848593720671995,
                                    0.002339282900759933,
                                    0.7754184196992829,
                                    0.2137563601932371,
                                ],
                                [
                                    0.9203338501854034,
                                    0.043073480982292675,
                                    0.03495662811095177,
                                    0.0016360407213521825,
                                ],
                                [
                                    0.9203338501854034,
                                    0.03495662811095177,
                                    0.043073480982292675,
                                    0.0016360407213521825,
                                ],
                                [
                                    0.7102271431307468,
                                    0.03324006319727071,
                                    0.24506333516560835,
                                    0.011469458506374151,
                                ],
                                [
                                    0.0021200311346943113,
                                    8.052419232892357e-05,
                                    0.9612873000330018,
                                    0.036512144639975035,
                                ],
                                [
                                    0.0021200311346943113,
                                    0.9612873000330018,
                                    8.052419232892357e-05,
                                    0.036512144639975035,
                                ],
                                [
                                    0.7102271431307468,
                                    0.24506333516560835,
                                    0.03324006319727071,
                                    0.011469458506374151,
                                ],
                                [
                                    0.0016360407213522011,
                                    0.7418311656066653,
                                    0.0005645146056710335,
                                    0.2559682790663115,
                                ],
                                [
                                    0.0016360407213522011,
                                    0.0005645146056710335,
                                    0.7418311656066653,
                                    0.2559682790663115,
                                ],
                                [
                                    0.7372289389851062,
                                    0.034503801719966753,
                                    0.2180615393112489,
                                    0.010205719983678054,
                                ],
                                [
                                    0.7372289389851062,
                                    0.2180615393112489,
                                    0.034503801719966753,
                                    0.010205719983678054,
                                ],
                                [
                                    0.7268877092909685,
                                    0.03401981130662465,
                                    0.22840276900538667,
                                    0.010689710397020158,
                                ],
                                [
                                    0.7010268966715427,
                                    0.2073535045941444,
                                    0.07070584403353028,
                                    0.020913754700782546,
                                ],
                                [
                                    0.7010268966715427,
                                    0.07070584403353028,
                                    0.2073535045941444,
                                    0.020913754700782546,
                                ],
                                [
                                    0.7268877092909685,
                                    0.22840276900538667,
                                    0.03401981130662465,
                                    0.010689710397020158,
                                ],
                                [
                                    0.6911934788865208,
                                    0.06971404171107236,
                                    0.21718692237916637,
                                    0.021905557023240468,
                                ],
                                [
                                    0.6911934788865208,
                                    0.21718692237916637,
                                    0.06971404171107236,
                                    0.021905557023240468,
                                ],
                                [
                                    0.7533223555155574,
                                    0.028201164398194097,
                                    0.21059278756125452,
                                    0.00788369252499404,
                                ],
                                [
                                    0.7533223555155574,
                                    0.21059278756125452,
                                    0.028201164398194097,
                                    0.00788369252499404,
                                ],
                                [
                                    0.7019913251419629,
                                    0.026279550343207333,
                                    0.2619238179348488,
                                    0.009805306579980801,
                                ],
                                [
                                    0.5729738108583431,
                                    0.16017598727131038,
                                    0.2085497090554084,
                                    0.05830049281493818,
                                ],
                                [
                                    0.5729738108583431,
                                    0.2085497090554084,
                                    0.16017598727131038,
                                    0.05830049281493818,
                                ],
                                [
                                    0.7019913251419629,
                                    0.2619238179348488,
                                    0.026279550343207333,
                                    0.009805306579980801,
                                ],
                                [
                                    0.5339316453456586,
                                    0.19433923013951174,
                                    0.1992181527839948,
                                    0.07251097173083483,
                                ],
                                [
                                    0.5339316453456586,
                                    0.1992181527839948,
                                    0.19433923013951174,
                                    0.07251097173083483,
                                ],
                                [
                                    0.7771940273924801,
                                    0.018666949874651947,
                                    0.19935093409218588,
                                    0.004788088640682062,
                                ],
                                [
                                    0.7771940273924801,
                                    0.19935093409218588,
                                    0.018666949874651947,
                                    0.004788088640682062,
                                ],
                                [
                                    0.6645176599457708,
                                    0.015960644847781976,
                                    0.3120273015388951,
                                    0.007494393667552031,
                                ],
                                [
                                    0.3792635387589141,
                                    0.0972814227257519,
                                    0.416597438508218,
                                    0.10685760000711604,
                                ],
                                [
                                    0.3792635387589141,
                                    0.416597438508218,
                                    0.0972814227257519,
                                    0.10685760000711604,
                                ],
                                [
                                    0.6645176599457708,
                                    0.3120273015388951,
                                    0.015960644847781976,
                                    0.007494393667552031,
                                ],
                                [
                                    0.32427850754899445,
                                    0.3561997972445584,
                                    0.15226645393567154,
                                    0.1672552412707756,
                                ],
                                [
                                    0.32427850754899445,
                                    0.15226645393567154,
                                    0.3561997972445584,
                                    0.1672552412707756,
                                ],
                                [
                                    0.80142785823501,
                                    0.008770576385502698,
                                    0.1877469216575101,
                                    0.0020546437219771834,
                                ],
                                [
                                    0.80142785823501,
                                    0.1877469216575101,
                                    0.008770576385502698,
                                    0.0020546437219771834,
                                ],
                                [
                                    0.6258367717714194,
                                    0.00684896233051594,
                                    0.3633380081211008,
                                    0.003976257776963942,
                                ],
                                [
                                    0.17819514485534776,
                                    0.04174497998433086,
                                    0.632003289765165,
                                    0.14805658539515645,
                                ],
                                [
                                    0.17819514485534776,
                                    0.632003289765165,
                                    0.04174497998433086,
                                    0.14805658539515645,
                                ],
                                [
                                    0.6258367717714194,
                                    0.3633380081211008,
                                    0.00684896233051594,
                                    0.003976257776963942,
                                ],
                                [
                                    0.13915297934266335,
                                    0.49353275475927194,
                                    0.08078714549701525,
                                    0.28652712040104944,
                                ],
                                [
                                    0.13915297934266335,
                                    0.08078714549701525,
                                    0.49353275475927194,
                                    0.28652712040104944,
                                ],
                                [
                                    0.8181847821965976,
                                    0.0018044316325934002,
                                    0.1796146624763791,
                                    0.0003961236944298095,
                                ],
                                [
                                    0.8181847821965976,
                                    0.1796146624763791,
                                    0.0018044316325934002,
                                    0.0003961236944298095,
                                ],
                                [
                                    0.5987286477702611,
                                    0.0013204412192512956,
                                    0.3990707969027156,
                                    0.000880114107771914,
                                ],
                                [
                                    0.036661325552450885,
                                    0.008048196151193952,
                                    0.7833278882767402,
                                    0.17196259001961497,
                                ],
                                [
                                    0.036661325552450885,
                                    0.7833278882767402,
                                    0.008048196151193952,
                                    0.17196259001961497,
                                ],
                                [
                                    0.5987286477702611,
                                    0.3990707969027156,
                                    0.0013204412192512956,
                                    0.000880114107771914,
                                ],
                                [
                                    0.02682790776742892,
                                    0.5732211812220835,
                                    0.01788161393621592,
                                    0.3820692970742716,
                                ],
                                [
                                    0.02682790776742892,
                                    0.01788161393621592,
                                    0.5732211812220835,
                                    0.3820692970742716,
                                ],
                                [
                                    0.601997745371532,
                                    0.16973499533354106,
                                    0.17806212978878944,
                                    0.05020512950613751,
                                ],
                                [
                                    0.601997745371532,
                                    0.17806212978878944,
                                    0.16973499533354106,
                                    0.05020512950613751,
                                ],
                                [
                                    0.5935534255259082,
                                    0.16735409507168492,
                                    0.18650644963441318,
                                    0.05258602976799363,
                                ],
                                [
                                    0.5657957030579684,
                                    0.16735409507168494,
                                    0.20593703764710458,
                                    0.060913164223242,
                                ],
                                [
                                    0.5657957030579684,
                                    0.20593703764710458,
                                    0.16735409507168494,
                                    0.060913164223242,
                                ],
                                [
                                    0.5935534255259082,
                                    0.18650644963441318,
                                    0.16735409507168492,
                                    0.05258602976799363,
                                ],
                                [
                                    0.5578591951214605,
                                    0.20304832547613264,
                                    0.17529060300819288,
                                    0.06380187639421395,
                                ],
                                [
                                    0.5578591951214605,
                                    0.17529060300819288,
                                    0.20304832547613264,
                                    0.06380187639421395,
                                ],
                                [
                                    0.6427931693750772,
                                    0.13873035053867422,
                                    0.17969413010634538,
                                    0.03878234997990318,
                                ],
                                [
                                    0.6427931693750772,
                                    0.17969413010634538,
                                    0.13873035053867422,
                                    0.03878234997990318,
                                ],
                                [
                                    0.5989935456687692,
                                    0.12927732981640122,
                                    0.22349375381265343,
                                    0.04823537070217618,
                                ],
                                [
                                    0.4624446247178629,
                                    0.12927732981640125,
                                    0.31907889519588856,
                                    0.08919915026984733,
                                ],
                                [
                                    0.4624446247178629,
                                    0.31907889519588856,
                                    0.12927732981640125,
                                    0.08919915026984733,
                                ],
                                [
                                    0.5989935456687692,
                                    0.22349375381265343,
                                    0.12927732981640122,
                                    0.04823537070217618,
                                ],
                                [
                                    0.4309338658724647,
                                    0.29733700961270565,
                                    0.16078808866179942,
                                    0.11094103585303021,
                                ],
                                [
                                    0.4309338658724647,
                                    0.16078808866179942,
                                    0.29733700961270565,
                                    0.11094103585303021,
                                ],
                                [
                                    0.7040324107926159,
                                    0.09182856647451619,
                                    0.1805849167338049,
                                    0.023554105999063043,
                                ],
                                [
                                    0.7040324107926159,
                                    0.1805849167338049,
                                    0.09182856647451619,
                                    0.023554105999063043,
                                ],
                                [
                                    0.601962899426182,
                                    0.07851540536737092,
                                    0.28265442810023883,
                                    0.0368672671062083,
                                ],
                                [
                                    0.30610192215904986,
                                    0.07851540536737092,
                                    0.48975905510808226,
                                    0.12562361736549701,
                                ],
                                [
                                    0.30610192215904986,
                                    0.48975905510808226,
                                    0.07851540536737092,
                                    0.12562361736549701,
                                ],
                                [
                                    0.601962899426182,
                                    0.28265442810023883,
                                    0.07851540536737092,
                                    0.0368672671062083,
                                ],
                                [
                                    0.2617237470294055,
                                    0.4187545577641474,
                                    0.12289358049701526,
                                    0.19662811470943187,
                                ],
                                [
                                    0.2617237470294055,
                                    0.12289358049701526,
                                    0.4187545577641474,
                                    0.19662811470943187,
                                ],
                                [
                                    0.7670532254650736,
                                    0.043145209155439124,
                                    0.17969413010634538,
                                    0.010107435273141915,
                                ],
                                [
                                    0.7670532254650736,
                                    0.17969413010634538,
                                    0.043145209155439124,
                                    0.010107435273141915,
                                ],
                                [
                                    0.5989935456687692,
                                    0.03369218843316613,
                                    0.3477538099026498,
                                    0.01956045599541491,
                                ],
                                [
                                    0.14382051208541136,
                                    0.03369218843316613,
                                    0.6663779225351013,
                                    0.15610937694632118,
                                ],
                                [
                                    0.14382051208541136,
                                    0.6663779225351013,
                                    0.03369218843316613,
                                    0.15610937694632118,
                                ],
                                [
                                    0.5989935456687692,
                                    0.3477538099026498,
                                    0.03369218843316613,
                                    0.01956045599541491,
                                ],
                                [
                                    0.11230975324001319,
                                    0.5203759808619222,
                                    0.0652029472785643,
                                    0.3021113186195004,
                                ],
                                [
                                    0.11230975324001319,
                                    0.0652029472785643,
                                    0.5203759808619222,
                                    0.3021113186195004,
                                ],
                                [
                                    0.8111126501037307,
                                    0.008876563725460388,
                                    0.17806212978878944,
                                    0.0019486563820195044,
                                ],
                                [
                                    0.8111126501037307,
                                    0.17806212978878944,
                                    0.008876563725460388,
                                    0.0019486563820195044,
                                ],
                                [
                                    0.5935534255259082,
                                    0.006495663463604262,
                                    0.3956213543666119,
                                    0.004329556643875631,
                                ],
                                [
                                    0.02958919345958393,
                                    0.006495663463604264,
                                    0.7904000203696072,
                                    0.17351512270720468,
                                ],
                                [
                                    0.02958919345958393,
                                    0.7904000203696072,
                                    0.006495663463604264,
                                    0.17351512270720468,
                                ],
                                [
                                    0.5935534255259082,
                                    0.3956213543666119,
                                    0.006495663463604262,
                                    0.004329556643875631,
                                ],
                                [
                                    0.021652685523075976,
                                    0.5783964034664365,
                                    0.014432171400112215,
                                    0.3855187396103753,
                                ],
                                [
                                    0.021652685523075976,
                                    0.014432171400112215,
                                    0.5783964034664365,
                                    0.3855187396103753,
                                ],
                                [
                                    0.4039673915093183,
                                    0.3677653491957547,
                                    0.11948764700601572,
                                    0.10877961228891123,
                                ],
                                [
                                    0.4039673915093183,
                                    0.11948764700601572,
                                    0.3677653491957547,
                                    0.10877961228891123,
                                ],
                                [
                                    0.39830087550102045,
                                    0.3626066450965727,
                                    0.12515416301431356,
                                    0.11393831638809325,
                                ],
                                [
                                    0.3677653491957547,
                                    0.10877961228891123,
                                    0.4039673915093183,
                                    0.11948764700601572,
                                ],
                                [
                                    0.3677653491957547,
                                    0.4039673915093183,
                                    0.10877961228891123,
                                    0.11948764700601572,
                                ],
                                [
                                    0.39830087550102045,
                                    0.12515416301431356,
                                    0.3626066450965727,
                                    0.11393831638809325,
                                ],
                                [
                                    0.3626066450965727,
                                    0.39830087550102045,
                                    0.11393831638809325,
                                    0.12515416301431356,
                                ],
                                [
                                    0.3626066450965727,
                                    0.11393831638809325,
                                    0.39830087550102045,
                                    0.12515416301431356,
                                ],
                                [
                                    0.48093603228548293,
                                    0.30058748762826853,
                                    0.13444664018809635,
                                    0.0840298398981522,
                                ],
                                [
                                    0.48093603228548293,
                                    0.13444664018809635,
                                    0.30058748762826853,
                                    0.0840298398981522,
                                ],
                                [
                                    0.4481652776407374,
                                    0.28010559784443295,
                                    0.16721739483284181,
                                    0.10451172968198778,
                                ],
                                [
                                    0.30058748762826865,
                                    0.08402983989815223,
                                    0.4809360322854828,
                                    0.13444664018809632,
                                ],
                                [
                                    0.30058748762826865,
                                    0.4809360322854828,
                                    0.08402983989815223,
                                    0.13444664018809632,
                                ],
                                [
                                    0.4481652776407374,
                                    0.16721739483284181,
                                    0.28010559784443295,
                                    0.10451172968198778,
                                ],
                                [
                                    0.280105597844433,
                                    0.4481652776407373,
                                    0.10451172968198781,
                                    0.1672173948328418,
                                ],
                                [
                                    0.280105597844433,
                                    0.10451172968198781,
                                    0.4481652776407373,
                                    0.1672173948328418,
                                ],
                                [
                                    0.596895732950349,
                                    0.19896524431678303,
                                    0.15310426704965097,
                                    0.051034755683216984,
                                ],
                                [
                                    0.596895732950349,
                                    0.15310426704965097,
                                    0.19896524431678303,
                                    0.051034755683216984,
                                ],
                                [
                                    0.5103587285951646,
                                    0.17011957619838822,
                                    0.23964127140483535,
                                    0.07988042380161178,
                                ],
                                [
                                    0.19896524431678303,
                                    0.051034755683216984,
                                    0.596895732950349,
                                    0.15310426704965097,
                                ],
                                [
                                    0.19896524431678303,
                                    0.596895732950349,
                                    0.051034755683216984,
                                    0.15310426704965097,
                                ],
                                [
                                    0.5103587285951646,
                                    0.23964127140483535,
                                    0.17011957619838822,
                                    0.07988042380161178,
                                ],
                                [
                                    0.17011957619838822,
                                    0.5103587285951646,
                                    0.07988042380161178,
                                    0.23964127140483535,
                                ],
                                [
                                    0.17011957619838822,
                                    0.07988042380161178,
                                    0.5103587285951646,
                                    0.23964127140483535,
                                ],
                                [
                                    0.7167155740000875,
                                    0.09348286062042523,
                                    0.1679017535263333,
                                    0.02189981185315402,
                                ],
                                [
                                    0.7167155740000875,
                                    0.1679017535263333,
                                    0.09348286062042523,
                                    0.02189981185315402,
                                ],
                                [
                                    0.5596847632653457,
                                    0.07300097083658966,
                                    0.3249325642610751,
                                    0.0423817016369896,
                                ],
                                [
                                    0.09348286062042523,
                                    0.02189981185315402,
                                    0.7167155740000875,
                                    0.1679017535263333,
                                ],
                                [
                                    0.09348286062042523,
                                    0.7167155740000875,
                                    0.02189981185315402,
                                    0.1679017535263333,
                                ],
                                [
                                    0.5596847632653457,
                                    0.3249325642610751,
                                    0.07300097083658966,
                                    0.0423817016369896,
                                ],
                                [
                                    0.07300097083658966,
                                    0.5596847632653457,
                                    0.0423817016369896,
                                    0.3249325642610751,
                                ],
                                [
                                    0.07300097083658966,
                                    0.0423817016369896,
                                    0.5596847632653457,
                                    0.3249325642610751,
                                ],
                                [
                                    0.8007563352366689,
                                    0.019232878592522155,
                                    0.17578862624799704,
                                    0.004222159922811883,
                                ],
                                [
                                    0.8007563352366689,
                                    0.17578862624799704,
                                    0.019232878592522155,
                                    0.004222159922811883,
                                ],
                                [
                                    0.5859749144961723,
                                    0.014074174493340115,
                                    0.3905700469884936,
                                    0.009380864021993921,
                                ],
                                [
                                    0.019232878592522155,
                                    0.004222159922811883,
                                    0.8007563352366689,
                                    0.17578862624799704,
                                ],
                                [
                                    0.019232878592522155,
                                    0.8007563352366689,
                                    0.004222159922811883,
                                    0.17578862624799704,
                                ],
                                [
                                    0.5859749144961723,
                                    0.3905700469884936,
                                    0.014074174493340115,
                                    0.009380864021993921,
                                ],
                                [
                                    0.014074174493340115,
                                    0.5859749144961723,
                                    0.009380864021993921,
                                    0.3905700469884936,
                                ],
                                [
                                    0.014074174493340115,
                                    0.009380864021993921,
                                    0.5859749144961723,
                                    0.3905700469884936,
                                ],
                                [
                                    0.20593703764710466,
                                    0.5657957030579683,
                                    0.06091316422324203,
                                    0.16735409507168492,
                                ],
                                [
                                    0.20593703764710466,
                                    0.06091316422324203,
                                    0.5657957030579683,
                                    0.16735409507168492,
                                ],
                                [
                                    0.20304832547613272,
                                    0.5578591951214604,
                                    0.06380187639421397,
                                    0.17529060300819285,
                                ],
                                [
                                    0.16973499533354108,
                                    0.05020512950613752,
                                    0.601997745371532,
                                    0.17806212978878944,
                                ],
                                [
                                    0.16973499533354108,
                                    0.601997745371532,
                                    0.05020512950613752,
                                    0.17806212978878944,
                                ],
                                [
                                    0.20304832547613272,
                                    0.06380187639421397,
                                    0.5578591951214604,
                                    0.17529060300819285,
                                ],
                                [
                                    0.16735409507168497,
                                    0.5935534255259082,
                                    0.05258602976799365,
                                    0.18650644963441318,
                                ],
                                [
                                    0.16735409507168497,
                                    0.05258602976799365,
                                    0.5935534255259082,
                                    0.18650644963441318,
                                ],
                                [
                                    0.31907889519588867,
                                    0.4624446247178628,
                                    0.08919915026984736,
                                    0.12927732981640122,
                                ],
                                [
                                    0.31907889519588867,
                                    0.08919915026984736,
                                    0.4624446247178628,
                                    0.12927732981640122,
                                ],
                                [
                                    0.2973370096127057,
                                    0.4309338658724646,
                                    0.11094103585303024,
                                    0.16078808866179936,
                                ],
                                [
                                    0.1387303505386743,
                                    0.0387823499799032,
                                    0.6427931693750771,
                                    0.17969413010634536,
                                ],
                                [
                                    0.1387303505386743,
                                    0.6427931693750771,
                                    0.0387823499799032,
                                    0.17969413010634536,
                                ],
                                [
                                    0.2973370096127057,
                                    0.11094103585303024,
                                    0.4309338658724646,
                                    0.16078808866179936,
                                ],
                                [
                                    0.12927732981640128,
                                    0.5989935456687691,
                                    0.0482353707021762,
                                    0.2234937538126534,
                                ],
                                [
                                    0.12927732981640128,
                                    0.0482353707021762,
                                    0.5989935456687691,
                                    0.2234937538126534,
                                ],
                                [
                                    0.48975905510808226,
                                    0.30610192215904986,
                                    0.12562361736549701,
                                    0.07851540536737092,
                                ],
                                [
                                    0.48975905510808226,
                                    0.12562361736549701,
                                    0.30610192215904986,
                                    0.07851540536737092,
                                ],
                                [
                                    0.4187545577641474,
                                    0.2617237470294055,
                                    0.19662811470943187,
                                    0.12289358049701526,
                                ],
                                [
                                    0.0918285664745162,
                                    0.02355410599906305,
                                    0.7040324107926159,
                                    0.1805849167338049,
                                ],
                                [
                                    0.0918285664745162,
                                    0.7040324107926159,
                                    0.02355410599906305,
                                    0.1805849167338049,
                                ],
                                [
                                    0.4187545577641474,
                                    0.19662811470943187,
                                    0.2617237470294055,
                                    0.12289358049701526,
                                ],
                                [
                                    0.07851540536737095,
                                    0.601962899426182,
                                    0.03686726710620831,
                                    0.28265442810023883,
                                ],
                                [
                                    0.07851540536737095,
                                    0.03686726710620831,
                                    0.601962899426182,
                                    0.28265442810023883,
                                ],
                                [
                                    0.6663779225351013,
                                    0.14382051208541133,
                                    0.15610937694632118,
                                    0.033692188433166126,
                                ],
                                [
                                    0.6663779225351013,
                                    0.15610937694632118,
                                    0.14382051208541133,
                                    0.033692188433166126,
                                ],
                                [
                                    0.5203759808619222,
                                    0.11230975324001316,
                                    0.3021113186195004,
                                    0.0652029472785643,
                                ],
                                [
                                    0.04314520915543911,
                                    0.010107435273141912,
                                    0.7670532254650736,
                                    0.17969413010634538,
                                ],
                                [
                                    0.04314520915543911,
                                    0.7670532254650736,
                                    0.010107435273141912,
                                    0.17969413010634538,
                                ],
                                [
                                    0.5203759808619222,
                                    0.3021113186195004,
                                    0.11230975324001316,
                                    0.0652029472785643,
                                ],
                                [
                                    0.03369218843316612,
                                    0.5989935456687692,
                                    0.019560455995414904,
                                    0.3477538099026498,
                                ],
                                [
                                    0.03369218843316612,
                                    0.019560455995414904,
                                    0.5989935456687692,
                                    0.3477538099026498,
                                ],
                                [
                                    0.7904000203696072,
                                    0.029589193459583916,
                                    0.17351512270720468,
                                    0.006495663463604261,
                                ],
                                [
                                    0.7904000203696072,
                                    0.17351512270720468,
                                    0.029589193459583916,
                                    0.006495663463604261,
                                ],
                                [
                                    0.5783964034664365,
                                    0.02165268552307597,
                                    0.3855187396103753,
                                    0.01443217140011221,
                                ],
                                [
                                    0.00887656372546038,
                                    0.0019486563820195024,
                                    0.8111126501037307,
                                    0.17806212978878944,
                                ],
                                [
                                    0.00887656372546038,
                                    0.8111126501037307,
                                    0.0019486563820195024,
                                    0.17806212978878944,
                                ],
                                [
                                    0.5783964034664365,
                                    0.3855187396103753,
                                    0.02165268552307597,
                                    0.01443217140011221,
                                ],
                                [
                                    0.006495663463604256,
                                    0.5935534255259082,
                                    0.0043295566438756265,
                                    0.3956213543666119,
                                ],
                                [
                                    0.006495663463604256,
                                    0.0043295566438756265,
                                    0.5935534255259082,
                                    0.3956213543666119,
                                ],
                                [
                                    0.07070584403353035,
                                    0.7010268966715427,
                                    0.020913754700782567,
                                    0.20735350459414437,
                                ],
                                [
                                    0.07070584403353035,
                                    0.020913754700782567,
                                    0.7010268966715427,
                                    0.20735350459414437,
                                ],
                                [
                                    0.06971404171107243,
                                    0.6911934788865207,
                                    0.02190555702324049,
                                    0.21718692237916634,
                                ],
                                [
                                    0.034503801719966774,
                                    0.010205719983678061,
                                    0.7372289389851062,
                                    0.2180615393112489,
                                ],
                                [
                                    0.034503801719966774,
                                    0.7372289389851062,
                                    0.010205719983678061,
                                    0.2180615393112489,
                                ],
                                [
                                    0.06971404171107243,
                                    0.02190555702324049,
                                    0.6911934788865207,
                                    0.21718692237916634,
                                ],
                                [
                                    0.034019811306624674,
                                    0.7268877092909685,
                                    0.010689710397020165,
                                    0.22840276900538667,
                                ],
                                [
                                    0.034019811306624674,
                                    0.010689710397020165,
                                    0.7268877092909685,
                                    0.22840276900538667,
                                ],
                                [
                                    0.20854970905540848,
                                    0.572973810858343,
                                    0.05830049281493821,
                                    0.16017598727131035,
                                ],
                                [
                                    0.20854970905540848,
                                    0.05830049281493821,
                                    0.572973810858343,
                                    0.16017598727131035,
                                ],
                                [
                                    0.19433923013951182,
                                    0.5339316453456585,
                                    0.07251097173083486,
                                    0.19921815278399477,
                                ],
                                [
                                    0.028201164398194138,
                                    0.007883692524994053,
                                    0.7533223555155574,
                                    0.21059278756125452,
                                ],
                                [
                                    0.028201164398194138,
                                    0.7533223555155574,
                                    0.007883692524994053,
                                    0.21059278756125452,
                                ],
                                [
                                    0.19433923013951182,
                                    0.07251097173083486,
                                    0.5339316453456585,
                                    0.19921815278399477,
                                ],
                                [
                                    0.026279550343207374,
                                    0.7019913251419629,
                                    0.009805306579980815,
                                    0.2619238179348488,
                                ],
                                [
                                    0.026279550343207374,
                                    0.009805306579980815,
                                    0.7019913251419629,
                                    0.2619238179348488,
                                ],
                                [
                                    0.416597438508218,
                                    0.3792635387589141,
                                    0.10685760000711604,
                                    0.0972814227257519,
                                ],
                                [
                                    0.416597438508218,
                                    0.10685760000711604,
                                    0.3792635387589141,
                                    0.0972814227257519,
                                ],
                                [
                                    0.3561997972445584,
                                    0.32427850754899445,
                                    0.1672552412707756,
                                    0.15226645393567154,
                                ],
                                [
                                    0.01866694987465197,
                                    0.0047880886406820675,
                                    0.7771940273924801,
                                    0.19935093409218588,
                                ],
                                [
                                    0.01866694987465197,
                                    0.7771940273924801,
                                    0.0047880886406820675,
                                    0.19935093409218588,
                                ],
                                [
                                    0.3561997972445584,
                                    0.1672552412707756,
                                    0.32427850754899445,
                                    0.15226645393567154,
                                ],
                                [
                                    0.015960644847781997,
                                    0.6645176599457708,
                                    0.007494393667552041,
                                    0.3120273015388951,
                                ],
                                [
                                    0.015960644847781997,
                                    0.007494393667552041,
                                    0.6645176599457708,
                                    0.3120273015388951,
                                ],
                                [
                                    0.632003289765165,
                                    0.17819514485534776,
                                    0.14805658539515645,
                                    0.04174497998433086,
                                ],
                                [
                                    0.632003289765165,
                                    0.14805658539515645,
                                    0.17819514485534776,
                                    0.04174497998433086,
                                ],
                                [
                                    0.49353275475927194,
                                    0.13915297934266335,
                                    0.28652712040104944,
                                    0.08078714549701525,
                                ],
                                [
                                    0.008770576385502698,
                                    0.0020546437219771834,
                                    0.80142785823501,
                                    0.1877469216575101,
                                ],
                                [
                                    0.008770576385502698,
                                    0.80142785823501,
                                    0.0020546437219771834,
                                    0.1877469216575101,
                                ],
                                [
                                    0.49353275475927194,
                                    0.28652712040104944,
                                    0.13915297934266335,
                                    0.08078714549701525,
                                ],
                                [
                                    0.00684896233051594,
                                    0.6258367717714194,
                                    0.003976257776963942,
                                    0.3633380081211008,
                                ],
                                [
                                    0.00684896233051594,
                                    0.003976257776963942,
                                    0.6258367717714194,
                                    0.3633380081211008,
                                ],
                                [
                                    0.7833278882767402,
                                    0.036661325552450906,
                                    0.17196259001961497,
                                    0.008048196151193955,
                                ],
                                [
                                    0.7833278882767402,
                                    0.17196259001961497,
                                    0.036661325552450906,
                                    0.008048196151193955,
                                ],
                                [
                                    0.5732211812220835,
                                    0.026827907767428934,
                                    0.3820692970742716,
                                    0.017881613936215925,
                                ],
                                [
                                    0.0018044316325934208,
                                    0.000396123694429814,
                                    0.8181847821965976,
                                    0.1796146624763791,
                                ],
                                [
                                    0.0018044316325934208,
                                    0.8181847821965976,
                                    0.000396123694429814,
                                    0.1796146624763791,
                                ],
                                [
                                    0.5732211812220835,
                                    0.3820692970742716,
                                    0.026827907767428934,
                                    0.017881613936215925,
                                ],
                                [
                                    0.0013204412192513108,
                                    0.5987286477702611,
                                    0.0008801141077719241,
                                    0.3990707969027156,
                                ],
                                [
                                    0.0013204412192513108,
                                    0.0008801141077719241,
                                    0.5987286477702611,
                                    0.3990707969027156,
                                ],
                                [
                                    0.48281585399524646,
                                    0.02259675605849346,
                                    0.4724746243011087,
                                    0.022112765645151352,
                                ],
                                [
                                    0.48281585399524646,
                                    0.4724746243011087,
                                    0.02259675605849346,
                                    0.022112765645151352,
                                ],
                                [
                                    0.4724746243011087,
                                    0.022112765645151352,
                                    0.48281585399524646,
                                    0.02259675605849346,
                                ],
                                [
                                    0.4591069095253546,
                                    0.4492734917403326,
                                    0.046305700528385375,
                                    0.045313898205927454,
                                ],
                                [
                                    0.4591069095253546,
                                    0.046305700528385375,
                                    0.4492734917403326,
                                    0.045313898205927454,
                                ],
                                [
                                    0.4724746243011087,
                                    0.48281585399524646,
                                    0.022112765645151352,
                                    0.02259675605849346,
                                ],
                                [
                                    0.4492734917403326,
                                    0.045313898205927454,
                                    0.4591069095253546,
                                    0.046305700528385375,
                                ],
                                [
                                    0.4492734917403326,
                                    0.4591069095253546,
                                    0.045313898205927454,
                                    0.046305700528385375,
                                ],
                                [
                                    0.5076230867252031,
                                    0.019003235489087448,
                                    0.4562920563516088,
                                    0.017081621434100688,
                                ],
                                [
                                    0.5076230867252031,
                                    0.4562920563516088,
                                    0.019003235489087448,
                                    0.017081621434100688,
                                ],
                                [
                                    0.4562920563516088,
                                    0.017081621434100688,
                                    0.5076230867252031,
                                    0.019003235489087448,
                                ],
                                [
                                    0.3860959818211689,
                                    0.34705381630848453,
                                    0.1405303403931216,
                                    0.126319861477225,
                                ],
                                [
                                    0.3860959818211689,
                                    0.1405303403931216,
                                    0.34705381630848453,
                                    0.126319861477225,
                                ],
                                [
                                    0.4562920563516088,
                                    0.5076230867252031,
                                    0.017081621434100688,
                                    0.019003235489087448,
                                ],
                                [
                                    0.34705381630848453,
                                    0.126319861477225,
                                    0.3860959818211689,
                                    0.1405303403931216,
                                ],
                                [
                                    0.34705381630848453,
                                    0.3860959818211689,
                                    0.126319861477225,
                                    0.1405303403931216,
                                ],
                                [
                                    0.5446106644656876,
                                    0.013080671771101992,
                                    0.43193429701897834,
                                    0.01037436674423202,
                                ],
                                [
                                    0.5446106644656876,
                                    0.43193429701897834,
                                    0.013080671771101992,
                                    0.01037436674423202,
                                ],
                                [
                                    0.4319342970189784,
                                    0.010374366744232021,
                                    0.5446106644656875,
                                    0.013080671771101988,
                                ],
                                [
                                    0.26576499634729284,
                                    0.21077996513737315,
                                    0.29192633988949684,
                                    0.23152869862583722,
                                ],
                                [
                                    0.26576499634729284,
                                    0.29192633988949684,
                                    0.21077996513737315,
                                    0.23152869862583722,
                                ],
                                [
                                    0.4319342970189784,
                                    0.5446106644656875,
                                    0.010374366744232021,
                                    0.013080671771101988,
                                ],
                                [
                                    0.21077996513737318,
                                    0.23152869862583725,
                                    0.2657649963472928,
                                    0.2919263398894968,
                                ],
                                [
                                    0.21077996513737318,
                                    0.2657649963472928,
                                    0.23152869862583725,
                                    0.2919263398894968,
                                ],
                                [
                                    0.5823829331780555,
                                    0.006373417081233321,
                                    0.4067918467144648,
                                    0.004451803026246562,
                                ],
                                [
                                    0.5823829331780555,
                                    0.4067918467144648,
                                    0.006373417081233321,
                                    0.004451803026246562,
                                ],
                                [
                                    0.4067918467144647,
                                    0.004451803026246561,
                                    0.5823829331780555,
                                    0.006373417081233321,
                                ],
                                [
                                    0.12949114517618152,
                                    0.09044897966349712,
                                    0.4592652050831072,
                                    0.3207946700772142,
                                ],
                                [
                                    0.12949114517618152,
                                    0.4592652050831072,
                                    0.09044897966349712,
                                    0.3207946700772142,
                                ],
                                [
                                    0.4067918467144647,
                                    0.5823829331780555,
                                    0.004451803026246561,
                                    0.006373417081233321,
                                ],
                                [
                                    0.0904489796634971,
                                    0.3207946700772142,
                                    0.12949114517618152,
                                    0.4592652050831072,
                                ],
                                [
                                    0.0904489796634971,
                                    0.12949114517618152,
                                    0.3207946700772142,
                                    0.4592652050831072,
                                ],
                                [
                                    0.6086277895496567,
                                    0.001342272870182657,
                                    0.38917165512332014,
                                    0.0008582824568405525,
                                ],
                                [
                                    0.6086277895496567,
                                    0.38917165512332014,
                                    0.001342272870182657,
                                    0.0008582824568405525,
                                ],
                                [
                                    0.38917165512332025,
                                    0.0008582824568405528,
                                    0.6086277895496566,
                                    0.0013422728701826569,
                                ],
                                [
                                    0.027271469744333404,
                                    0.017438051959311435,
                                    0.5826985926755059,
                                    0.3725918856208493,
                                ],
                                [
                                    0.027271469744333404,
                                    0.5826985926755059,
                                    0.017438051959311435,
                                    0.3725918856208493,
                                ],
                                [
                                    0.38917165512332025,
                                    0.6086277895496566,
                                    0.0008582824568405528,
                                    0.0013422728701826569,
                                ],
                                [
                                    0.017438051959311442,
                                    0.3725918856208494,
                                    0.027271469744333397,
                                    0.5826985926755058,
                                ],
                                [
                                    0.017438051959311442,
                                    0.027271469744333397,
                                    0.3725918856208494,
                                    0.5826985926755058,
                                ],
                                [
                                    0.3942520975029726,
                                    0.11116051255076734,
                                    0.3858077776573488,
                                    0.10877961228891123,
                                ],
                                [
                                    0.3942520975029726,
                                    0.3858077776573488,
                                    0.11116051255076734,
                                    0.10877961228891123,
                                ],
                                [
                                    0.3858077776573488,
                                    0.10877961228891123,
                                    0.3942520975029726,
                                    0.11116051255076734,
                                ],
                                [
                                    0.37054315303308066,
                                    0.36260664509657276,
                                    0.13486945702065925,
                                    0.13198074484968733,
                                ],
                                [
                                    0.37054315303308066,
                                    0.13486945702065925,
                                    0.36260664509657276,
                                    0.13198074484968733,
                                ],
                                [
                                    0.3858077776573488,
                                    0.3942520975029726,
                                    0.10877961228891123,
                                    0.11116051255076734,
                                ],
                                [
                                    0.36260664509657276,
                                    0.13198074484968733,
                                    0.37054315303308066,
                                    0.13486945702065925,
                                ],
                                [
                                    0.36260664509657276,
                                    0.37054315303308066,
                                    0.13198074484968733,
                                    0.13486945702065925,
                                ],
                                [
                                    0.43314346159386535,
                                    0.0934828606204252,
                                    0.3893438378875573,
                                    0.0840298398981522,
                                ],
                                [
                                    0.43314346159386535,
                                    0.3893438378875573,
                                    0.0934828606204252,
                                    0.0840298398981522,
                                ],
                                [
                                    0.3893438378875573,
                                    0.0840298398981522,
                                    0.43314346159386535,
                                    0.0934828606204252,
                                ],
                                [
                                    0.3116163566898311,
                                    0.280105597844433,
                                    0.21500996552445936,
                                    0.1932680799412765,
                                ],
                                [
                                    0.3116163566898311,
                                    0.21500996552445936,
                                    0.280105597844433,
                                    0.1932680799412765,
                                ],
                                [
                                    0.3893438378875573,
                                    0.43314346159386535,
                                    0.0840298398981522,
                                    0.0934828606204252,
                                ],
                                [
                                    0.280105597844433,
                                    0.1932680799412765,
                                    0.3116163566898311,
                                    0.21500996552445936,
                                ],
                                [
                                    0.280105597844433,
                                    0.3116163566898311,
                                    0.1932680799412765,
                                    0.21500996552445936,
                                ],
                                [
                                    0.4933434194464274,
                                    0.06434791679036225,
                                    0.3912739080799934,
                                    0.051034755683216984,
                                ],
                                [
                                    0.4933434194464274,
                                    0.3912739080799934,
                                    0.06434791679036225,
                                    0.051034755683216984,
                                ],
                                [
                                    0.3912739080799934,
                                    0.05103475568321699,
                                    0.49334341944642734,
                                    0.06434791679036224,
                                ],
                                [
                                    0.2144977513280326,
                                    0.1701195761983882,
                                    0.3431935849087571,
                                    0.2721890875648222,
                                ],
                                [
                                    0.2144977513280326,
                                    0.3431935849087571,
                                    0.1701195761983882,
                                    0.2721890875648222,
                                ],
                                [
                                    0.3912739080799934,
                                    0.49334341944642734,
                                    0.05103475568321699,
                                    0.06434791679036224,
                                ],
                                [
                                    0.17011957619838822,
                                    0.27218908756482224,
                                    0.21449775132803253,
                                    0.343193584908757,
                                ],
                                [
                                    0.17011957619838822,
                                    0.21449775132803253,
                                    0.27218908756482224,
                                    0.343193584908757,
                                ],
                                [
                                    0.5574035176838618,
                                    0.03135283257542702,
                                    0.3893438378875573,
                                    0.021899811853154025,
                                ],
                                [
                                    0.5574035176838618,
                                    0.3893438378875573,
                                    0.03135283257542702,
                                    0.021899811853154025,
                                ],
                                [
                                    0.3893438378875572,
                                    0.02189981185315402,
                                    0.5574035176838618,
                                    0.03135283257542702,
                                ],
                                [
                                    0.10451172968198782,
                                    0.07300097083658966,
                                    0.4842446205773009,
                                    0.33824267890412163,
                                ],
                                [
                                    0.10451172968198782,
                                    0.4842446205773009,
                                    0.07300097083658966,
                                    0.33824267890412163,
                                ],
                                [
                                    0.3893438378875572,
                                    0.5574035176838618,
                                    0.02189981185315402,
                                    0.03135283257542702,
                                ],
                                [
                                    0.07300097083658966,
                                    0.33824267890412163,
                                    0.10451172968198782,
                                    0.4842446205773009,
                                ],
                                [
                                    0.07300097083658966,
                                    0.10451172968198782,
                                    0.33824267890412163,
                                    0.4842446205773009,
                                ],
                                [
                                    0.6033670022351713,
                                    0.00660306018466801,
                                    0.3858077776573488,
                                    0.004222159922811883,
                                ],
                                [
                                    0.6033670022351713,
                                    0.3858077776573488,
                                    0.00660306018466801,
                                    0.004222159922811883,
                                ],
                                [
                                    0.3858077776573489,
                                    0.004222159922811885,
                                    0.6033670022351711,
                                    0.006603060184668008,
                                ],
                                [
                                    0.02201068242984807,
                                    0.014074174493340119,
                                    0.5879593799899913,
                                    0.37595576308682055,
                                ],
                                [
                                    0.02201068242984807,
                                    0.5879593799899913,
                                    0.014074174493340119,
                                    0.37595576308682055,
                                ],
                                [
                                    0.3858077776573489,
                                    0.6033670022351711,
                                    0.004222159922811885,
                                    0.006603060184668008,
                                ],
                                [
                                    0.014074174493340124,
                                    0.37595576308682066,
                                    0.022010682429848067,
                                    0.5879593799899911,
                                ],
                                [
                                    0.014074174493340124,
                                    0.022010682429848067,
                                    0.37595576308682066,
                                    0.5879593799899911,
                                ],
                                [
                                    0.2645607772618159,
                                    0.240851832791924,
                                    0.2588942612535181,
                                    0.23569312869274198,
                                ],
                                [
                                    0.2645607772618159,
                                    0.2588942612535181,
                                    0.240851832791924,
                                    0.23569312869274198,
                                ],
                                [
                                    0.2588942612535181,
                                    0.23569312869274198,
                                    0.2645607772618159,
                                    0.240851832791924,
                                ],
                                [
                                    0.240851832791924,
                                    0.23569312869274198,
                                    0.2645607772618159,
                                    0.2588942612535181,
                                ],
                                [
                                    0.240851832791924,
                                    0.2645607772618159,
                                    0.23569312869274198,
                                    0.2588942612535181,
                                ],
                                [
                                    0.2588942612535181,
                                    0.2645607772618159,
                                    0.23569312869274198,
                                    0.240851832791924,
                                ],
                                [
                                    0.23569312869274198,
                                    0.2588942612535181,
                                    0.240851832791924,
                                    0.2645607772618159,
                                ],
                                [
                                    0.23569312869274198,
                                    0.240851832791924,
                                    0.2588942612535181,
                                    0.2645607772618159,
                                ],
                                [
                                    0.32407671355916234,
                                    0.20254960865512817,
                                    0.2913059589144169,
                                    0.18206771887129258,
                                ],
                                [
                                    0.32407671355916234,
                                    0.2913059589144169,
                                    0.20254960865512817,
                                    0.18206771887129258,
                                ],
                                [
                                    0.2913059589144169,
                                    0.18206771887129258,
                                    0.32407671355916234,
                                    0.20254960865512817,
                                ],
                                [
                                    0.20254960865512822,
                                    0.18206771887129264,
                                    0.3240767135591623,
                                    0.29130595891441685,
                                ],
                                [
                                    0.20254960865512822,
                                    0.3240767135591623,
                                    0.18206771887129264,
                                    0.29130595891441685,
                                ],
                                [
                                    0.2913059589144169,
                                    0.32407671355916234,
                                    0.18206771887129258,
                                    0.20254960865512817,
                                ],
                                [
                                    0.18206771887129264,
                                    0.29130595891441685,
                                    0.20254960865512822,
                                    0.3240767135591623,
                                ],
                                [
                                    0.18206771887129264,
                                    0.20254960865512822,
                                    0.29130595891441685,
                                    0.3240767135591623,
                                ],
                                [
                                    0.41826850217759226,
                                    0.13942283405919742,
                                    0.3317314978224078,
                                    0.1105771659408026,
                                ],
                                [
                                    0.41826850217759226,
                                    0.3317314978224078,
                                    0.13942283405919742,
                                    0.1105771659408026,
                                ],
                                [
                                    0.33173149782240785,
                                    0.11057716594080261,
                                    0.41826850217759215,
                                    0.1394228340591974,
                                ],
                                [
                                    0.13942283405919742,
                                    0.1105771659408026,
                                    0.41826850217759226,
                                    0.3317314978224078,
                                ],
                                [
                                    0.13942283405919742,
                                    0.41826850217759226,
                                    0.1105771659408026,
                                    0.3317314978224078,
                                ],
                                [
                                    0.33173149782240785,
                                    0.41826850217759215,
                                    0.11057716594080261,
                                    0.1394228340591974,
                                ],
                                [
                                    0.11057716594080261,
                                    0.33173149782240785,
                                    0.1394228340591974,
                                    0.41826850217759215,
                                ],
                                [
                                    0.11057716594080261,
                                    0.1394228340591974,
                                    0.33173149782240785,
                                    0.41826850217759215,
                                ],
                                [
                                    0.5208240691305813,
                                    0.06793228112870742,
                                    0.3637932583958395,
                                    0.04745039134487184,
                                ],
                                [
                                    0.5208240691305813,
                                    0.3637932583958395,
                                    0.06793228112870742,
                                    0.04745039134487184,
                                ],
                                [
                                    0.3637932583958394,
                                    0.047450391344871834,
                                    0.5208240691305813,
                                    0.06793228112870742,
                                ],
                                [
                                    0.06793228112870742,
                                    0.04745039134487184,
                                    0.5208240691305813,
                                    0.3637932583958395,
                                ],
                                [
                                    0.06793228112870742,
                                    0.5208240691305813,
                                    0.04745039134487184,
                                    0.3637932583958395,
                                ],
                                [
                                    0.3637932583958394,
                                    0.5208240691305813,
                                    0.047450391344871834,
                                    0.06793228112870742,
                                ],
                                [
                                    0.047450391344871834,
                                    0.3637932583958394,
                                    0.06793228112870742,
                                    0.5208240691305813,
                                ],
                                [
                                    0.047450391344871834,
                                    0.06793228112870742,
                                    0.3637932583958394,
                                    0.5208240691305813,
                                ],
                                [
                                    0.5956631911125813,
                                    0.014306871307258037,
                                    0.3808817703720847,
                                    0.009148167208076,
                                ],
                                [
                                    0.5956631911125813,
                                    0.3808817703720847,
                                    0.014306871307258037,
                                    0.009148167208076,
                                ],
                                [
                                    0.3808817703720848,
                                    0.009148167208076001,
                                    0.5956631911125811,
                                    0.014306871307258036,
                                ],
                                [
                                    0.014306871307258037,
                                    0.009148167208076,
                                    0.5956631911125813,
                                    0.3808817703720847,
                                ],
                                [
                                    0.014306871307258037,
                                    0.5956631911125813,
                                    0.009148167208076,
                                    0.3808817703720847,
                                ],
                                [
                                    0.3808817703720848,
                                    0.5956631911125811,
                                    0.009148167208076001,
                                    0.014306871307258036,
                                ],
                                [
                                    0.009148167208076001,
                                    0.3808817703720848,
                                    0.014306871307258036,
                                    0.5956631911125811,
                                ],
                                [
                                    0.009148167208076001,
                                    0.014306871307258036,
                                    0.3808817703720848,
                                    0.5956631911125811,
                                ],
                                [
                                    0.1348694570206593,
                                    0.3705431530330806,
                                    0.1319807448496874,
                                    0.3626066450965727,
                                ],
                                [
                                    0.1348694570206593,
                                    0.1319807448496874,
                                    0.3705431530330806,
                                    0.3626066450965727,
                                ],
                                [
                                    0.1319807448496874,
                                    0.3626066450965727,
                                    0.1348694570206593,
                                    0.3705431530330806,
                                ],
                                [
                                    0.11116051255076737,
                                    0.10877961228891125,
                                    0.3942520975029726,
                                    0.3858077776573488,
                                ],
                                [
                                    0.11116051255076737,
                                    0.3942520975029726,
                                    0.10877961228891125,
                                    0.3858077776573488,
                                ],
                                [
                                    0.1319807448496874,
                                    0.1348694570206593,
                                    0.3626066450965727,
                                    0.3705431530330806,
                                ],
                                [
                                    0.10877961228891125,
                                    0.3858077776573488,
                                    0.11116051255076737,
                                    0.3942520975029726,
                                ],
                                [
                                    0.10877961228891125,
                                    0.11116051255076737,
                                    0.3858077776573488,
                                    0.3942520975029726,
                                ],
                                [
                                    0.21500996552445942,
                                    0.31161635668983106,
                                    0.19326807994127657,
                                    0.28010559784443295,
                                ],
                                [
                                    0.21500996552445942,
                                    0.19326807994127657,
                                    0.31161635668983106,
                                    0.28010559784443295,
                                ],
                                [
                                    0.19326807994127657,
                                    0.28010559784443295,
                                    0.21500996552445942,
                                    0.31161635668983106,
                                ],
                                [
                                    0.09348286062042524,
                                    0.08402983989815224,
                                    0.4331434615938653,
                                    0.3893438378875572,
                                ],
                                [
                                    0.09348286062042524,
                                    0.4331434615938653,
                                    0.08402983989815224,
                                    0.3893438378875572,
                                ],
                                [
                                    0.19326807994127657,
                                    0.21500996552445942,
                                    0.28010559784443295,
                                    0.31161635668983106,
                                ],
                                [
                                    0.08402983989815224,
                                    0.3893438378875572,
                                    0.09348286062042524,
                                    0.4331434615938653,
                                ],
                                [
                                    0.08402983989815224,
                                    0.09348286062042524,
                                    0.3893438378875572,
                                    0.4331434615938653,
                                ],
                                [
                                    0.3431935849087571,
                                    0.2144977513280326,
                                    0.2721890875648222,
                                    0.1701195761983882,
                                ],
                                [
                                    0.3431935849087571,
                                    0.2721890875648222,
                                    0.2144977513280326,
                                    0.1701195761983882,
                                ],
                                [
                                    0.27218908756482224,
                                    0.17011957619838822,
                                    0.343193584908757,
                                    0.21449775132803253,
                                ],
                                [
                                    0.06434791679036227,
                                    0.05103475568321699,
                                    0.4933434194464274,
                                    0.3912739080799934,
                                ],
                                [
                                    0.06434791679036227,
                                    0.4933434194464274,
                                    0.05103475568321699,
                                    0.3912739080799934,
                                ],
                                [
                                    0.27218908756482224,
                                    0.343193584908757,
                                    0.17011957619838822,
                                    0.21449775132803253,
                                ],
                                [
                                    0.051034755683217,
                                    0.3912739080799934,
                                    0.06434791679036225,
                                    0.49334341944642734,
                                ],
                                [
                                    0.051034755683217,
                                    0.06434791679036225,
                                    0.3912739080799934,
                                    0.49334341944642734,
                                ],
                                [
                                    0.4842446205773009,
                                    0.10451172968198781,
                                    0.33824267890412163,
                                    0.07300097083658966,
                                ],
                                [
                                    0.4842446205773009,
                                    0.33824267890412163,
                                    0.10451172968198781,
                                    0.07300097083658966,
                                ],
                                [
                                    0.33824267890412163,
                                    0.07300097083658964,
                                    0.4842446205773009,
                                    0.10451172968198781,
                                ],
                                [
                                    0.03135283257542701,
                                    0.021899811853154014,
                                    0.5574035176838618,
                                    0.3893438378875573,
                                ],
                                [
                                    0.03135283257542701,
                                    0.5574035176838618,
                                    0.021899811853154014,
                                    0.3893438378875573,
                                ],
                                [
                                    0.33824267890412163,
                                    0.4842446205773009,
                                    0.07300097083658964,
                                    0.10451172968198781,
                                ],
                                [
                                    0.02189981185315401,
                                    0.3893438378875572,
                                    0.03135283257542701,
                                    0.5574035176838618,
                                ],
                                [
                                    0.02189981185315401,
                                    0.03135283257542701,
                                    0.3893438378875572,
                                    0.5574035176838618,
                                ],
                                [
                                    0.5879593799899913,
                                    0.022010682429848064,
                                    0.37595576308682055,
                                    0.014074174493340114,
                                ],
                                [
                                    0.5879593799899913,
                                    0.37595576308682055,
                                    0.022010682429848064,
                                    0.014074174493340114,
                                ],
                                [
                                    0.37595576308682066,
                                    0.014074174493340119,
                                    0.5879593799899911,
                                    0.02201068242984806,
                                ],
                                [
                                    0.006603060184668004,
                                    0.004222159922811879,
                                    0.6033670022351713,
                                    0.3858077776573488,
                                ],
                                [
                                    0.006603060184668004,
                                    0.6033670022351713,
                                    0.004222159922811879,
                                    0.3858077776573488,
                                ],
                                [
                                    0.37595576308682066,
                                    0.5879593799899911,
                                    0.014074174493340119,
                                    0.02201068242984806,
                                ],
                                [
                                    0.00422215992281188,
                                    0.3858077776573489,
                                    0.006603060184668002,
                                    0.6033670022351711,
                                ],
                                [
                                    0.00422215992281188,
                                    0.006603060184668002,
                                    0.3858077776573489,
                                    0.6033670022351711,
                                ],
                                [
                                    0.04630570052838542,
                                    0.45910690952535455,
                                    0.045313898205927496,
                                    0.44927349174033254,
                                ],
                                [
                                    0.04630570052838542,
                                    0.045313898205927496,
                                    0.45910690952535455,
                                    0.44927349174033254,
                                ],
                                [
                                    0.045313898205927496,
                                    0.44927349174033254,
                                    0.04630570052838542,
                                    0.45910690952535455,
                                ],
                                [
                                    0.022596756058493473,
                                    0.022112765645151366,
                                    0.48281585399524646,
                                    0.4724746243011087,
                                ],
                                [
                                    0.022596756058493473,
                                    0.48281585399524646,
                                    0.022112765645151366,
                                    0.4724746243011087,
                                ],
                                [
                                    0.045313898205927496,
                                    0.04630570052838542,
                                    0.44927349174033254,
                                    0.45910690952535455,
                                ],
                                [
                                    0.022112765645151366,
                                    0.4724746243011087,
                                    0.022596756058493473,
                                    0.48281585399524646,
                                ],
                                [
                                    0.022112765645151366,
                                    0.022596756058493473,
                                    0.4724746243011087,
                                    0.48281585399524646,
                                ],
                                [
                                    0.14053034039312168,
                                    0.38609598182116883,
                                    0.12631986147722502,
                                    0.3470538163084845,
                                ],
                                [
                                    0.14053034039312168,
                                    0.12631986147722502,
                                    0.38609598182116883,
                                    0.3470538163084845,
                                ],
                                [
                                    0.12631986147722502,
                                    0.3470538163084845,
                                    0.14053034039312168,
                                    0.38609598182116883,
                                ],
                                [
                                    0.019003235489087476,
                                    0.017081621434100715,
                                    0.5076230867252031,
                                    0.4562920563516088,
                                ],
                                [
                                    0.019003235489087476,
                                    0.5076230867252031,
                                    0.017081621434100715,
                                    0.4562920563516088,
                                ],
                                [
                                    0.12631986147722502,
                                    0.14053034039312168,
                                    0.3470538163084845,
                                    0.38609598182116883,
                                ],
                                [
                                    0.017081621434100715,
                                    0.4562920563516088,
                                    0.019003235489087476,
                                    0.5076230867252031,
                                ],
                                [
                                    0.017081621434100715,
                                    0.019003235489087476,
                                    0.4562920563516088,
                                    0.5076230867252031,
                                ],
                                [
                                    0.29192633988949684,
                                    0.26576499634729284,
                                    0.23152869862583722,
                                    0.21077996513737315,
                                ],
                                [
                                    0.29192633988949684,
                                    0.23152869862583722,
                                    0.26576499634729284,
                                    0.21077996513737315,
                                ],
                                [
                                    0.23152869862583725,
                                    0.21077996513737318,
                                    0.2919263398894968,
                                    0.2657649963472928,
                                ],
                                [
                                    0.013080671771102007,
                                    0.010374366744232031,
                                    0.5446106644656876,
                                    0.43193429701897834,
                                ],
                                [
                                    0.013080671771102007,
                                    0.5446106644656876,
                                    0.010374366744232031,
                                    0.43193429701897834,
                                ],
                                [
                                    0.23152869862583725,
                                    0.2919263398894968,
                                    0.21077996513737318,
                                    0.2657649963472928,
                                ],
                                [
                                    0.010374366744232033,
                                    0.4319342970189784,
                                    0.013080671771102004,
                                    0.5446106644656875,
                                ],
                                [
                                    0.010374366744232033,
                                    0.013080671771102004,
                                    0.4319342970189784,
                                    0.5446106644656875,
                                ],
                                [
                                    0.4592652050831072,
                                    0.12949114517618152,
                                    0.3207946700772142,
                                    0.09044897966349712,
                                ],
                                [
                                    0.4592652050831072,
                                    0.3207946700772142,
                                    0.12949114517618152,
                                    0.09044897966349712,
                                ],
                                [
                                    0.3207946700772142,
                                    0.0904489796634971,
                                    0.4592652050831072,
                                    0.12949114517618152,
                                ],
                                [
                                    0.006373417081233321,
                                    0.004451803026246562,
                                    0.5823829331780555,
                                    0.4067918467144648,
                                ],
                                [
                                    0.006373417081233321,
                                    0.5823829331780555,
                                    0.004451803026246562,
                                    0.4067918467144648,
                                ],
                                [
                                    0.3207946700772142,
                                    0.4592652050831072,
                                    0.0904489796634971,
                                    0.12949114517618152,
                                ],
                                [
                                    0.004451803026246561,
                                    0.4067918467144647,
                                    0.006373417081233321,
                                    0.5823829331780555,
                                ],
                                [
                                    0.004451803026246561,
                                    0.006373417081233321,
                                    0.4067918467144647,
                                    0.5823829331780555,
                                ],
                                [
                                    0.5826985926755059,
                                    0.027271469744333414,
                                    0.3725918856208493,
                                    0.017438051959311446,
                                ],
                                [
                                    0.5826985926755059,
                                    0.3725918856208493,
                                    0.027271469744333414,
                                    0.017438051959311446,
                                ],
                                [
                                    0.3725918856208494,
                                    0.01743805195931145,
                                    0.5826985926755058,
                                    0.02727146974433341,
                                ],
                                [
                                    0.0013422728701826725,
                                    0.0008582824568405624,
                                    0.6086277895496567,
                                    0.38917165512332014,
                                ],
                                [
                                    0.0013422728701826725,
                                    0.6086277895496567,
                                    0.0008582824568405624,
                                    0.38917165512332014,
                                ],
                                [
                                    0.3725918856208494,
                                    0.5826985926755058,
                                    0.01743805195931145,
                                    0.02727146974433341,
                                ],
                                [
                                    0.0008582824568405626,
                                    0.38917165512332025,
                                    0.0013422728701826723,
                                    0.6086277895496566,
                                ],
                                [
                                    0.0008582824568405626,
                                    0.0013422728701826723,
                                    0.38917165512332025,
                                    0.6086277895496566,
                                ],
                                [
                                    0.2284027690053867,
                                    0.01068971039702016,
                                    0.7268877092909685,
                                    0.03401981130662465,
                                ],
                                [
                                    0.2284027690053867,
                                    0.7268877092909685,
                                    0.01068971039702016,
                                    0.03401981130662465,
                                ],
                                [
                                    0.21806153931124891,
                                    0.010205719983678056,
                                    0.7372289389851062,
                                    0.034503801719966753,
                                ],
                                [
                                    0.2171869223791664,
                                    0.6911934788865208,
                                    0.02190555702324047,
                                    0.06971404171107236,
                                ],
                                [
                                    0.2171869223791664,
                                    0.02190555702324047,
                                    0.6911934788865208,
                                    0.06971404171107236,
                                ],
                                [
                                    0.21806153931124891,
                                    0.7372289389851062,
                                    0.010205719983678056,
                                    0.034503801719966753,
                                ],
                                [
                                    0.20735350459414442,
                                    0.02091375470078255,
                                    0.7010268966715427,
                                    0.07070584403353028,
                                ],
                                [
                                    0.20735350459414442,
                                    0.7010268966715427,
                                    0.02091375470078255,
                                    0.07070584403353028,
                                ],
                                [
                                    0.26192381793484887,
                                    0.009805306579980803,
                                    0.7019913251419629,
                                    0.026279550343207333,
                                ],
                                [
                                    0.26192381793484887,
                                    0.7019913251419629,
                                    0.009805306579980803,
                                    0.026279550343207333,
                                ],
                                [
                                    0.2105927875612546,
                                    0.007883692524994044,
                                    0.7533223555155573,
                                    0.02820116439819409,
                                ],
                                [
                                    0.19921815278399482,
                                    0.5339316453456586,
                                    0.07251097173083484,
                                    0.19433923013951174,
                                ],
                                [
                                    0.19921815278399482,
                                    0.07251097173083484,
                                    0.5339316453456586,
                                    0.19433923013951174,
                                ],
                                [
                                    0.2105927875612546,
                                    0.7533223555155573,
                                    0.007883692524994044,
                                    0.02820116439819409,
                                ],
                                [
                                    0.16017598727131044,
                                    0.05830049281493821,
                                    0.572973810858343,
                                    0.20854970905540837,
                                ],
                                [
                                    0.16017598727131044,
                                    0.572973810858343,
                                    0.05830049281493821,
                                    0.20854970905540837,
                                ],
                                [
                                    0.3120273015388952,
                                    0.007494393667552034,
                                    0.6645176599457707,
                                    0.015960644847781976,
                                ],
                                [
                                    0.3120273015388952,
                                    0.6645176599457707,
                                    0.007494393667552034,
                                    0.015960644847781976,
                                ],
                                [
                                    0.19935093409218593,
                                    0.004788088640682063,
                                    0.77719402739248,
                                    0.018666949874651947,
                                ],
                                [
                                    0.1522664539356716,
                                    0.3242785075489944,
                                    0.16725524127077565,
                                    0.35619979724455836,
                                ],
                                [
                                    0.1522664539356716,
                                    0.16725524127077565,
                                    0.3242785075489944,
                                    0.35619979724455836,
                                ],
                                [
                                    0.19935093409218593,
                                    0.77719402739248,
                                    0.004788088640682063,
                                    0.018666949874651947,
                                ],
                                [
                                    0.09728142272575192,
                                    0.10685760000711607,
                                    0.37926353875891405,
                                    0.41659743850821795,
                                ],
                                [
                                    0.09728142272575192,
                                    0.37926353875891405,
                                    0.10685760000711607,
                                    0.41659743850821795,
                                ],
                                [
                                    0.3633380081211008,
                                    0.003976257776963942,
                                    0.6258367717714194,
                                    0.00684896233051594,
                                ],
                                [
                                    0.3633380081211008,
                                    0.6258367717714194,
                                    0.003976257776963942,
                                    0.00684896233051594,
                                ],
                                [
                                    0.18774692165751014,
                                    0.002054643721977184,
                                    0.80142785823501,
                                    0.008770576385502698,
                                ],
                                [
                                    0.08078714549701525,
                                    0.13915297934266335,
                                    0.28652712040104944,
                                    0.49353275475927194,
                                ],
                                [
                                    0.08078714549701525,
                                    0.28652712040104944,
                                    0.13915297934266335,
                                    0.49353275475927194,
                                ],
                                [
                                    0.18774692165751014,
                                    0.80142785823501,
                                    0.002054643721977184,
                                    0.008770576385502698,
                                ],
                                [
                                    0.04174497998433087,
                                    0.14805658539515648,
                                    0.17819514485534776,
                                    0.632003289765165,
                                ],
                                [
                                    0.04174497998433087,
                                    0.17819514485534776,
                                    0.14805658539515648,
                                    0.632003289765165,
                                ],
                                [
                                    0.3990707969027157,
                                    0.0008801141077719142,
                                    0.598728647770261,
                                    0.0013204412192512954,
                                ],
                                [
                                    0.3990707969027157,
                                    0.598728647770261,
                                    0.0008801141077719142,
                                    0.0013204412192512954,
                                ],
                                [
                                    0.1796146624763793,
                                    0.00039612369442980995,
                                    0.8181847821965974,
                                    0.0018044316325933998,
                                ],
                                [
                                    0.017881613936215922,
                                    0.026827907767428917,
                                    0.38206929707427173,
                                    0.5732211812220834,
                                ],
                                [
                                    0.017881613936215922,
                                    0.38206929707427173,
                                    0.026827907767428917,
                                    0.5732211812220834,
                                ],
                                [
                                    0.1796146624763793,
                                    0.8181847821965974,
                                    0.00039612369442980995,
                                    0.0018044316325933998,
                                ],
                                [
                                    0.00804819615119396,
                                    0.17196259001961517,
                                    0.03666132555245088,
                                    0.78332788827674,
                                ],
                                [
                                    0.00804819615119396,
                                    0.03666132555245088,
                                    0.17196259001961517,
                                    0.78332788827674,
                                ],
                                [
                                    0.1865064496344132,
                                    0.05258602976799364,
                                    0.5935534255259082,
                                    0.16735409507168492,
                                ],
                                [
                                    0.1865064496344132,
                                    0.5935534255259082,
                                    0.05258602976799364,
                                    0.16735409507168492,
                                ],
                                [
                                    0.17806212978878944,
                                    0.050205129506137515,
                                    0.601997745371532,
                                    0.16973499533354106,
                                ],
                                [
                                    0.1752906030081929,
                                    0.5578591951214605,
                                    0.06380187639421395,
                                    0.20304832547613264,
                                ],
                                [
                                    0.1752906030081929,
                                    0.06380187639421395,
                                    0.5578591951214605,
                                    0.20304832547613264,
                                ],
                                [
                                    0.17806212978878944,
                                    0.601997745371532,
                                    0.050205129506137515,
                                    0.16973499533354106,
                                ],
                                [
                                    0.16735409507168497,
                                    0.06091316422324201,
                                    0.5657957030579684,
                                    0.20593703764710458,
                                ],
                                [
                                    0.16735409507168497,
                                    0.5657957030579684,
                                    0.06091316422324201,
                                    0.20593703764710458,
                                ],
                                [
                                    0.2234937538126535,
                                    0.048235370702176185,
                                    0.5989935456687692,
                                    0.12927732981640122,
                                ],
                                [
                                    0.2234937538126535,
                                    0.5989935456687692,
                                    0.048235370702176185,
                                    0.12927732981640122,
                                ],
                                [
                                    0.17969413010634547,
                                    0.038782349979903194,
                                    0.6427931693750771,
                                    0.1387303505386742,
                                ],
                                [
                                    0.16078808866179944,
                                    0.4309338658724647,
                                    0.11094103585303024,
                                    0.29733700961270565,
                                ],
                                [
                                    0.16078808866179944,
                                    0.11094103585303024,
                                    0.4309338658724647,
                                    0.29733700961270565,
                                ],
                                [
                                    0.17969413010634547,
                                    0.6427931693750771,
                                    0.038782349979903194,
                                    0.1387303505386742,
                                ],
                                [
                                    0.12927732981640128,
                                    0.08919915026984736,
                                    0.46244462471786285,
                                    0.3190788951958885,
                                ],
                                [
                                    0.12927732981640128,
                                    0.46244462471786285,
                                    0.08919915026984736,
                                    0.3190788951958885,
                                ],
                                [
                                    0.28265442810023894,
                                    0.03686726710620831,
                                    0.6019628994261819,
                                    0.07851540536737091,
                                ],
                                [
                                    0.28265442810023894,
                                    0.6019628994261819,
                                    0.03686726710620831,
                                    0.07851540536737091,
                                ],
                                [
                                    0.18058491673380495,
                                    0.02355410599906305,
                                    0.7040324107926158,
                                    0.09182856647451618,
                                ],
                                [
                                    0.1228935804970153,
                                    0.26172374702940543,
                                    0.19662811470943195,
                                    0.41875455776414733,
                                ],
                                [
                                    0.1228935804970153,
                                    0.19662811470943195,
                                    0.26172374702940543,
                                    0.41875455776414733,
                                ],
                                [
                                    0.18058491673380495,
                                    0.7040324107926158,
                                    0.02355410599906305,
                                    0.09182856647451618,
                                ],
                                [
                                    0.07851540536737094,
                                    0.12562361736549704,
                                    0.3061019221590498,
                                    0.4897590551080822,
                                ],
                                [
                                    0.07851540536737094,
                                    0.3061019221590498,
                                    0.12562361736549704,
                                    0.4897590551080822,
                                ],
                                [
                                    0.3477538099026498,
                                    0.01956045599541491,
                                    0.5989935456687692,
                                    0.03369218843316613,
                                ],
                                [
                                    0.3477538099026498,
                                    0.5989935456687692,
                                    0.01956045599541491,
                                    0.03369218843316613,
                                ],
                                [
                                    0.1796941301063454,
                                    0.010107435273141917,
                                    0.7670532254650736,
                                    0.043145209155439124,
                                ],
                                [
                                    0.0652029472785643,
                                    0.11230975324001319,
                                    0.3021113186195004,
                                    0.5203759808619222,
                                ],
                                [
                                    0.0652029472785643,
                                    0.3021113186195004,
                                    0.11230975324001319,
                                    0.5203759808619222,
                                ],
                                [
                                    0.1796941301063454,
                                    0.7670532254650736,
                                    0.010107435273141917,
                                    0.043145209155439124,
                                ],
                                [
                                    0.03369218843316614,
                                    0.1561093769463212,
                                    0.14382051208541136,
                                    0.6663779225351013,
                                ],
                                [
                                    0.03369218843316614,
                                    0.14382051208541136,
                                    0.1561093769463212,
                                    0.6663779225351013,
                                ],
                                [
                                    0.395621354366612,
                                    0.004329556643875632,
                                    0.5935534255259081,
                                    0.006495663463604261,
                                ],
                                [
                                    0.395621354366612,
                                    0.5935534255259081,
                                    0.004329556643875632,
                                    0.006495663463604261,
                                ],
                                [
                                    0.17806212978878963,
                                    0.0019486563820195063,
                                    0.8111126501037305,
                                    0.008876563725460387,
                                ],
                                [
                                    0.014432171400112218,
                                    0.021652685523075973,
                                    0.3855187396103754,
                                    0.5783964034664364,
                                ],
                                [
                                    0.014432171400112218,
                                    0.3855187396103754,
                                    0.021652685523075973,
                                    0.5783964034664364,
                                ],
                                [
                                    0.17806212978878963,
                                    0.8111126501037305,
                                    0.0019486563820195063,
                                    0.008876563725460387,
                                ],
                                [
                                    0.006495663463604271,
                                    0.17351512270720484,
                                    0.02958919345958392,
                                    0.790400020369607,
                                ],
                                [
                                    0.006495663463604271,
                                    0.02958919345958392,
                                    0.17351512270720484,
                                    0.790400020369607,
                                ],
                                [
                                    0.1251541630143136,
                                    0.11393831638809326,
                                    0.39830087550102045,
                                    0.3626066450965727,
                                ],
                                [
                                    0.1251541630143136,
                                    0.39830087550102045,
                                    0.11393831638809326,
                                    0.3626066450965727,
                                ],
                                [
                                    0.11948764700601575,
                                    0.10877961228891123,
                                    0.4039673915093183,
                                    0.3677653491957547,
                                ],
                                [
                                    0.11393831638809326,
                                    0.3626066450965727,
                                    0.1251541630143136,
                                    0.39830087550102045,
                                ],
                                [
                                    0.11393831638809326,
                                    0.1251541630143136,
                                    0.3626066450965727,
                                    0.39830087550102045,
                                ],
                                [
                                    0.11948764700601575,
                                    0.4039673915093183,
                                    0.10877961228891123,
                                    0.3677653491957547,
                                ],
                                [
                                    0.10877961228891123,
                                    0.11948764700601575,
                                    0.3677653491957547,
                                    0.4039673915093183,
                                ],
                                [
                                    0.10877961228891123,
                                    0.3677653491957547,
                                    0.11948764700601575,
                                    0.4039673915093183,
                                ],
                                [
                                    0.16721739483284187,
                                    0.10451172968198781,
                                    0.4481652776407374,
                                    0.28010559784443295,
                                ],
                                [
                                    0.16721739483284187,
                                    0.4481652776407374,
                                    0.10451172968198781,
                                    0.28010559784443295,
                                ],
                                [
                                    0.1344466401880964,
                                    0.08402983989815224,
                                    0.4809360322854828,
                                    0.30058748762826853,
                                ],
                                [
                                    0.10451172968198784,
                                    0.280105597844433,
                                    0.16721739483284184,
                                    0.4481652776407373,
                                ],
                                [
                                    0.10451172968198784,
                                    0.16721739483284184,
                                    0.280105597844433,
                                    0.4481652776407373,
                                ],
                                [
                                    0.1344466401880964,
                                    0.4809360322854828,
                                    0.08402983989815224,
                                    0.30058748762826853,
                                ],
                                [
                                    0.08402983989815226,
                                    0.13444664018809638,
                                    0.3005874876282686,
                                    0.48093603228548276,
                                ],
                                [
                                    0.08402983989815226,
                                    0.3005874876282686,
                                    0.13444664018809638,
                                    0.48093603228548276,
                                ],
                                [
                                    0.23964127140483543,
                                    0.07988042380161181,
                                    0.5103587285951645,
                                    0.1701195761983882,
                                ],
                                [
                                    0.23964127140483543,
                                    0.5103587285951645,
                                    0.07988042380161181,
                                    0.1701195761983882,
                                ],
                                [
                                    0.153104267049651,
                                    0.051034755683217,
                                    0.596895732950349,
                                    0.198965244316783,
                                ],
                                [
                                    0.07988042380161181,
                                    0.1701195761983882,
                                    0.23964127140483543,
                                    0.5103587285951645,
                                ],
                                [
                                    0.07988042380161181,
                                    0.23964127140483543,
                                    0.1701195761983882,
                                    0.5103587285951645,
                                ],
                                [
                                    0.153104267049651,
                                    0.596895732950349,
                                    0.051034755683217,
                                    0.198965244316783,
                                ],
                                [
                                    0.051034755683217,
                                    0.153104267049651,
                                    0.198965244316783,
                                    0.596895732950349,
                                ],
                                [
                                    0.051034755683217,
                                    0.198965244316783,
                                    0.153104267049651,
                                    0.596895732950349,
                                ],
                                [
                                    0.3249325642610751,
                                    0.0423817016369896,
                                    0.5596847632653457,
                                    0.07300097083658966,
                                ],
                                [
                                    0.3249325642610751,
                                    0.5596847632653457,
                                    0.0423817016369896,
                                    0.07300097083658966,
                                ],
                                [
                                    0.1679017535263333,
                                    0.021899811853154025,
                                    0.7167155740000875,
                                    0.09348286062042523,
                                ],
                                [
                                    0.0423817016369896,
                                    0.07300097083658966,
                                    0.3249325642610751,
                                    0.5596847632653457,
                                ],
                                [
                                    0.0423817016369896,
                                    0.3249325642610751,
                                    0.07300097083658966,
                                    0.5596847632653457,
                                ],
                                [
                                    0.1679017535263333,
                                    0.7167155740000875,
                                    0.021899811853154025,
                                    0.09348286062042523,
                                ],
                                [
                                    0.021899811853154025,
                                    0.1679017535263333,
                                    0.09348286062042523,
                                    0.7167155740000875,
                                ],
                                [
                                    0.021899811853154025,
                                    0.09348286062042523,
                                    0.1679017535263333,
                                    0.7167155740000875,
                                ],
                                [
                                    0.3905700469884937,
                                    0.009380864021993923,
                                    0.5859749144961722,
                                    0.014074174493340114,
                                ],
                                [
                                    0.3905700469884937,
                                    0.5859749144961722,
                                    0.009380864021993923,
                                    0.014074174493340114,
                                ],
                                [
                                    0.17578862624799724,
                                    0.004222159922811887,
                                    0.8007563352366688,
                                    0.019232878592522148,
                                ],
                                [
                                    0.009380864021993923,
                                    0.014074174493340114,
                                    0.3905700469884937,
                                    0.5859749144961722,
                                ],
                                [
                                    0.009380864021993923,
                                    0.3905700469884937,
                                    0.014074174493340114,
                                    0.5859749144961722,
                                ],
                                [
                                    0.17578862624799724,
                                    0.8007563352366688,
                                    0.004222159922811887,
                                    0.019232878592522148,
                                ],
                                [
                                    0.004222159922811887,
                                    0.17578862624799724,
                                    0.019232878592522148,
                                    0.8007563352366688,
                                ],
                                [
                                    0.004222159922811887,
                                    0.019232878592522148,
                                    0.17578862624799724,
                                    0.8007563352366688,
                                ],
                                [
                                    0.06380187639421397,
                                    0.17529060300819288,
                                    0.20304832547613272,
                                    0.5578591951214604,
                                ],
                                [
                                    0.06380187639421397,
                                    0.20304832547613272,
                                    0.17529060300819288,
                                    0.5578591951214604,
                                ],
                                [
                                    0.060913164223242035,
                                    0.16735409507168494,
                                    0.20593703764710466,
                                    0.5657957030579683,
                                ],
                                [
                                    0.052586029767993654,
                                    0.16735409507168497,
                                    0.1865064496344132,
                                    0.5935534255259082,
                                ],
                                [
                                    0.052586029767993654,
                                    0.1865064496344132,
                                    0.16735409507168497,
                                    0.5935534255259082,
                                ],
                                [
                                    0.060913164223242035,
                                    0.20593703764710466,
                                    0.16735409507168494,
                                    0.5657957030579683,
                                ],
                                [
                                    0.05020512950613753,
                                    0.17806212978878944,
                                    0.16973499533354108,
                                    0.601997745371532,
                                ],
                                [
                                    0.05020512950613753,
                                    0.16973499533354108,
                                    0.17806212978878944,
                                    0.601997745371532,
                                ],
                                [
                                    0.11094103585303026,
                                    0.16078808866179942,
                                    0.2973370096127057,
                                    0.4309338658724646,
                                ],
                                [
                                    0.11094103585303026,
                                    0.2973370096127057,
                                    0.16078808866179942,
                                    0.4309338658724646,
                                ],
                                [
                                    0.08919915026984739,
                                    0.12927732981640125,
                                    0.3190788951958886,
                                    0.46244462471786274,
                                ],
                                [
                                    0.04823537070217621,
                                    0.12927732981640128,
                                    0.22349375381265346,
                                    0.5989935456687691,
                                ],
                                [
                                    0.04823537070217621,
                                    0.22349375381265346,
                                    0.12927732981640128,
                                    0.5989935456687691,
                                ],
                                [
                                    0.08919915026984739,
                                    0.3190788951958886,
                                    0.12927732981640125,
                                    0.46244462471786274,
                                ],
                                [
                                    0.038782349979903215,
                                    0.17969413010634544,
                                    0.13873035053867427,
                                    0.6427931693750771,
                                ],
                                [
                                    0.038782349979903215,
                                    0.13873035053867427,
                                    0.17969413010634544,
                                    0.6427931693750771,
                                ],
                                [
                                    0.19662811470943195,
                                    0.1228935804970153,
                                    0.41875455776414733,
                                    0.26172374702940543,
                                ],
                                [
                                    0.19662811470943195,
                                    0.41875455776414733,
                                    0.1228935804970153,
                                    0.26172374702940543,
                                ],
                                [
                                    0.12562361736549704,
                                    0.07851540536737094,
                                    0.4897590551080822,
                                    0.3061019221590498,
                                ],
                                [
                                    0.03686726710620832,
                                    0.07851540536737094,
                                    0.28265442810023894,
                                    0.6019628994261819,
                                ],
                                [
                                    0.03686726710620832,
                                    0.28265442810023894,
                                    0.07851540536737094,
                                    0.6019628994261819,
                                ],
                                [
                                    0.12562361736549704,
                                    0.4897590551080822,
                                    0.07851540536737094,
                                    0.3061019221590498,
                                ],
                                [
                                    0.023554105999063057,
                                    0.18058491673380495,
                                    0.09182856647451619,
                                    0.7040324107926158,
                                ],
                                [
                                    0.023554105999063057,
                                    0.09182856647451619,
                                    0.18058491673380495,
                                    0.7040324107926158,
                                ],
                                [
                                    0.3021113186195004,
                                    0.0652029472785643,
                                    0.5203759808619222,
                                    0.11230975324001316,
                                ],
                                [
                                    0.3021113186195004,
                                    0.5203759808619222,
                                    0.0652029472785643,
                                    0.11230975324001316,
                                ],
                                [
                                    0.1561093769463212,
                                    0.03369218843316613,
                                    0.6663779225351013,
                                    0.14382051208541133,
                                ],
                                [
                                    0.019560455995414904,
                                    0.03369218843316612,
                                    0.3477538099026498,
                                    0.5989935456687692,
                                ],
                                [
                                    0.019560455995414904,
                                    0.3477538099026498,
                                    0.03369218843316612,
                                    0.5989935456687692,
                                ],
                                [
                                    0.1561093769463212,
                                    0.6663779225351013,
                                    0.03369218843316613,
                                    0.14382051208541133,
                                ],
                                [
                                    0.010107435273141913,
                                    0.1796941301063454,
                                    0.04314520915543911,
                                    0.7670532254650736,
                                ],
                                [
                                    0.010107435273141913,
                                    0.04314520915543911,
                                    0.1796941301063454,
                                    0.7670532254650736,
                                ],
                                [
                                    0.3855187396103754,
                                    0.014432171400112213,
                                    0.5783964034664364,
                                    0.021652685523075962,
                                ],
                                [
                                    0.3855187396103754,
                                    0.5783964034664364,
                                    0.014432171400112213,
                                    0.021652685523075962,
                                ],
                                [
                                    0.17351512270720484,
                                    0.006495663463604268,
                                    0.790400020369607,
                                    0.02958919345958391,
                                ],
                                [
                                    0.004329556643875628,
                                    0.006495663463604254,
                                    0.395621354366612,
                                    0.5935534255259081,
                                ],
                                [
                                    0.004329556643875628,
                                    0.395621354366612,
                                    0.006495663463604254,
                                    0.5935534255259081,
                                ],
                                [
                                    0.17351512270720484,
                                    0.790400020369607,
                                    0.006495663463604268,
                                    0.02958919345958391,
                                ],
                                [
                                    0.0019486563820195046,
                                    0.17806212978878963,
                                    0.008876563725460378,
                                    0.8111126501037305,
                                ],
                                [
                                    0.0019486563820195046,
                                    0.008876563725460378,
                                    0.17806212978878963,
                                    0.8111126501037305,
                                ],
                                [
                                    0.021905557023240492,
                                    0.21718692237916637,
                                    0.06971404171107243,
                                    0.6911934788865207,
                                ],
                                [
                                    0.021905557023240492,
                                    0.06971404171107243,
                                    0.21718692237916637,
                                    0.6911934788865207,
                                ],
                                [
                                    0.020913754700782567,
                                    0.2073535045941444,
                                    0.07070584403353035,
                                    0.7010268966715427,
                                ],
                                [
                                    0.010689710397020167,
                                    0.034019811306624674,
                                    0.2284027690053867,
                                    0.7268877092909685,
                                ],
                                [
                                    0.010689710397020167,
                                    0.2284027690053867,
                                    0.034019811306624674,
                                    0.7268877092909685,
                                ],
                                [
                                    0.020913754700782567,
                                    0.07070584403353035,
                                    0.2073535045941444,
                                    0.7010268966715427,
                                ],
                                [
                                    0.010205719983678061,
                                    0.21806153931124891,
                                    0.034503801719966774,
                                    0.7372289389851062,
                                ],
                                [
                                    0.010205719983678061,
                                    0.034503801719966774,
                                    0.21806153931124891,
                                    0.7372289389851062,
                                ],
                                [
                                    0.07251097173083487,
                                    0.1992181527839948,
                                    0.19433923013951182,
                                    0.5339316453456585,
                                ],
                                [
                                    0.07251097173083487,
                                    0.19433923013951182,
                                    0.1992181527839948,
                                    0.5339316453456585,
                                ],
                                [
                                    0.05830049281493823,
                                    0.1601759872713104,
                                    0.20854970905540846,
                                    0.5729738108583429,
                                ],
                                [
                                    0.009805306579980817,
                                    0.026279550343207374,
                                    0.26192381793484887,
                                    0.7019913251419629,
                                ],
                                [
                                    0.009805306579980817,
                                    0.26192381793484887,
                                    0.026279550343207374,
                                    0.7019913251419629,
                                ],
                                [
                                    0.05830049281493823,
                                    0.20854970905540846,
                                    0.1601759872713104,
                                    0.5729738108583429,
                                ],
                                [
                                    0.007883692524994056,
                                    0.2105927875612546,
                                    0.028201164398194135,
                                    0.7533223555155573,
                                ],
                                [
                                    0.007883692524994056,
                                    0.028201164398194135,
                                    0.2105927875612546,
                                    0.7533223555155573,
                                ],
                                [
                                    0.16725524127077565,
                                    0.1522664539356716,
                                    0.35619979724455836,
                                    0.3242785075489944,
                                ],
                                [
                                    0.16725524127077565,
                                    0.35619979724455836,
                                    0.1522664539356716,
                                    0.3242785075489944,
                                ],
                                [
                                    0.10685760000711607,
                                    0.09728142272575192,
                                    0.41659743850821795,
                                    0.37926353875891405,
                                ],
                                [
                                    0.007494393667552043,
                                    0.015960644847781993,
                                    0.3120273015388952,
                                    0.6645176599457707,
                                ],
                                [
                                    0.007494393667552043,
                                    0.3120273015388952,
                                    0.015960644847781993,
                                    0.6645176599457707,
                                ],
                                [
                                    0.10685760000711607,
                                    0.41659743850821795,
                                    0.09728142272575192,
                                    0.37926353875891405,
                                ],
                                [
                                    0.004788088640682069,
                                    0.19935093409218593,
                                    0.018666949874651968,
                                    0.77719402739248,
                                ],
                                [
                                    0.004788088640682069,
                                    0.018666949874651968,
                                    0.19935093409218593,
                                    0.77719402739248,
                                ],
                                [
                                    0.28652712040104944,
                                    0.08078714549701525,
                                    0.49353275475927194,
                                    0.13915297934266335,
                                ],
                                [
                                    0.28652712040104944,
                                    0.49353275475927194,
                                    0.08078714549701525,
                                    0.13915297934266335,
                                ],
                                [
                                    0.14805658539515648,
                                    0.04174497998433087,
                                    0.632003289765165,
                                    0.17819514485534776,
                                ],
                                [
                                    0.003976257776963942,
                                    0.00684896233051594,
                                    0.3633380081211008,
                                    0.6258367717714194,
                                ],
                                [
                                    0.003976257776963942,
                                    0.3633380081211008,
                                    0.00684896233051594,
                                    0.6258367717714194,
                                ],
                                [
                                    0.14805658539515648,
                                    0.632003289765165,
                                    0.04174497998433087,
                                    0.17819514485534776,
                                ],
                                [
                                    0.002054643721977184,
                                    0.18774692165751014,
                                    0.008770576385502698,
                                    0.80142785823501,
                                ],
                                [
                                    0.002054643721977184,
                                    0.008770576385502698,
                                    0.18774692165751014,
                                    0.80142785823501,
                                ],
                                [
                                    0.38206929707427173,
                                    0.017881613936215932,
                                    0.5732211812220834,
                                    0.026827907767428927,
                                ],
                                [
                                    0.38206929707427173,
                                    0.5732211812220834,
                                    0.017881613936215932,
                                    0.026827907767428927,
                                ],
                                [
                                    0.17196259001961517,
                                    0.008048196151193964,
                                    0.78332788827674,
                                    0.03666132555245089,
                                ],
                                [
                                    0.0008801141077719243,
                                    0.0013204412192513106,
                                    0.3990707969027157,
                                    0.598728647770261,
                                ],
                                [
                                    0.0008801141077719243,
                                    0.3990707969027157,
                                    0.0013204412192513106,
                                    0.598728647770261,
                                ],
                                [
                                    0.17196259001961517,
                                    0.78332788827674,
                                    0.008048196151193964,
                                    0.03666132555245089,
                                ],
                                [
                                    0.00039612369442981445,
                                    0.1796146624763793,
                                    0.0018044316325934204,
                                    0.8181847821965974,
                                ],
                                [
                                    0.00039612369442981445,
                                    0.0018044316325934204,
                                    0.1796146624763793,
                                    0.8181847821965974,
                                ],
                                [
                                    0.05466887173613967,
                                    0.0025586134928924234,
                                    0.9006216065602155,
                                    0.04215090821075239,
                                ],
                                [
                                    0.05466887173613967,
                                    0.9006216065602155,
                                    0.0025586134928924234,
                                    0.04215090821075239,
                                ],
                                [
                                    0.04432764204200189,
                                    0.0020746230795503193,
                                    0.9109628362543533,
                                    0.04263489862409449,
                                ],
                                [
                                    0.05198432599577436,
                                    0.8563960752699128,
                                    0.005243159233257735,
                                    0.0863764395010551,
                                ],
                                [
                                    0.05198432599577436,
                                    0.005243159233257735,
                                    0.8563960752699128,
                                    0.0863764395010551,
                                ],
                                [
                                    0.04432764204200189,
                                    0.9109628362543533,
                                    0.0020746230795503193,
                                    0.04263489862409449,
                                ],
                                [
                                    0.042150908210752396,
                                    0.004251356910799814,
                                    0.8662294930549348,
                                    0.08736824182351302,
                                ],
                                [
                                    0.042150908210752396,
                                    0.8662294930549348,
                                    0.004251356910799814,
                                    0.08736824182351302,
                                ],
                                [
                                    0.09414042139746605,
                                    0.0035242144095515055,
                                    0.8697747216793458,
                                    0.03256064251363663,
                                ],
                                [
                                    0.09414042139746605,
                                    0.8697747216793458,
                                    0.0035242144095515055,
                                    0.03256064251363663,
                                ],
                                [
                                    0.042809391023871796,
                                    0.0016026003545647476,
                                    0.92110575205294,
                                    0.03448225656862339,
                                ],
                                [
                                    0.07160280802632105,
                                    0.6615469901033324,
                                    0.026061827780696517,
                                    0.24078837408965006,
                                ],
                                [
                                    0.07160280802632105,
                                    0.026061827780696517,
                                    0.6615469901033324,
                                    0.24078837408965006,
                                ],
                                [
                                    0.042809391023871796,
                                    0.92110575205294,
                                    0.0016026003545647476,
                                    0.03448225656862339,
                                ],
                                [
                                    0.03256064251363666,
                                    0.011851348864799884,
                                    0.7005891556160168,
                                    0.2549988530055467,
                                ],
                                [
                                    0.03256064251363666,
                                    0.7005891556160168,
                                    0.011851348864799884,
                                    0.2549988530055467,
                                ],
                                [
                                    0.15320050973740476,
                                    0.003679629713102621,
                                    0.8233444517472612,
                                    0.019775408802231387,
                                ],
                                [
                                    0.15320050973740476,
                                    0.8233444517472612,
                                    0.003679629713102621,
                                    0.019775408802231387,
                                ],
                                [
                                    0.04052414229069548,
                                    0.0009733246862326505,
                                    0.9360208191939705,
                                    0.022481713829101357,
                                ],
                                [
                                    0.07476044001215107,
                                    0.4017845214725149,
                                    0.08211969943835631,
                                    0.4413353390769777,
                                ],
                                [
                                    0.07476044001215107,
                                    0.08211969943835631,
                                    0.4017845214725149,
                                    0.4413353390769777,
                                ],
                                [
                                    0.04052414229069548,
                                    0.9360208191939705,
                                    0.0009733246862326505,
                                    0.022481713829101357,
                                ],
                                [
                                    0.019775408802231415,
                                    0.021722058174696718,
                                    0.4567695526824345,
                                    0.5017329803406373,
                                ],
                                [
                                    0.019775408802231415,
                                    0.4567695526824345,
                                    0.021722058174696718,
                                    0.5017329803406373,
                                ],
                                [
                                    0.21375636019323715,
                                    0.0023392829007599335,
                                    0.7754184196992829,
                                    0.00848593720671995,
                                ],
                                [
                                    0.21375636019323715,
                                    0.7754184196992829,
                                    0.0023392829007599335,
                                    0.00848593720671995,
                                ],
                                [
                                    0.038165273729646544,
                                    0.0004176688457731752,
                                    0.9510095061628736,
                                    0.010407551261706708,
                                ],
                                [
                                    0.04752810271940436,
                                    0.17241202212027426,
                                    0.16856754037459273,
                                    0.6114923347857286,
                                ],
                                [
                                    0.04752810271940436,
                                    0.16856754037459273,
                                    0.17241202212027426,
                                    0.6114923347857286,
                                ],
                                [
                                    0.038165273729646544,
                                    0.9510095061628736,
                                    0.0004176688457731752,
                                    0.010407551261706708,
                                ],
                                [
                                    0.008485937206719965,
                                    0.030097005368699758,
                                    0.21145418763295865,
                                    0.7499628697916216,
                                ],
                                [
                                    0.008485937206719965,
                                    0.21145418763295865,
                                    0.030097005368699758,
                                    0.7499628697916216,
                                ],
                                [
                                    0.25596827906631153,
                                    0.0005645146056710271,
                                    0.7418311656066653,
                                    0.0016360407213521825,
                                ],
                                [
                                    0.25596827906631153,
                                    0.7418311656066653,
                                    0.0005645146056710271,
                                    0.0016360407213521825,
                                ],
                                [
                                    0.03651214463997502,
                                    8.052419232892261e-05,
                                    0.9612873000330018,
                                    0.002120031134694287,
                                ],
                                [
                                    0.011469458506374148,
                                    0.03324006319727069,
                                    0.2450633351656084,
                                    0.7102271431307468,
                                ],
                                [
                                    0.011469458506374148,
                                    0.2450633351656084,
                                    0.03324006319727069,
                                    0.7102271431307468,
                                ],
                                [
                                    0.03651214463997502,
                                    0.9612873000330018,
                                    8.052419232892261e-05,
                                    0.002120031134694287,
                                ],
                                [
                                    0.0016360407213521812,
                                    0.03495662811095176,
                                    0.043073480982292654,
                                    0.9203338501854034,
                                ],
                                [
                                    0.0016360407213521812,
                                    0.043073480982292654,
                                    0.03495662811095176,
                                    0.9203338501854034,
                                ],
                                [
                                    0.04464086498349791,
                                    0.01258662024553418,
                                    0.7354190101768234,
                                    0.2073535045941444,
                                ],
                                [
                                    0.04464086498349791,
                                    0.7354190101768234,
                                    0.01258662024553418,
                                    0.2073535045941444,
                                ],
                                [
                                    0.03619654513787415,
                                    0.010205719983678056,
                                    0.7438633300224472,
                                    0.2097344048560005,
                                ],
                                [
                                    0.0419563192431326,
                                    0.6911934788865208,
                                    0.015271165985899492,
                                    0.2515790358844471,
                                ],
                                [
                                    0.0419563192431326,
                                    0.015271165985899492,
                                    0.6911934788865208,
                                    0.2515790358844471,
                                ],
                                [
                                    0.03619654513787415,
                                    0.7438633300224472,
                                    0.010205719983678056,
                                    0.2097344048560005,
                                ],
                                [
                                    0.03401981130662466,
                                    0.012382453814927549,
                                    0.6991299868230287,
                                    0.25446774805541905,
                                ],
                                [
                                    0.03401981130662466,
                                    0.6991299868230287,
                                    0.012382453814927549,
                                    0.25446774805541905,
                                ],
                                [
                                    0.08032792255975053,
                                    0.01733671324726704,
                                    0.7421593769216721,
                                    0.16017598727131035,
                                ],
                                [
                                    0.08032792255975053,
                                    0.7421593769216721,
                                    0.01733671324726704,
                                    0.16017598727131035,
                                ],
                                [
                                    0.0365282988534425,
                                    0.007883692524994048,
                                    0.7859590006279802,
                                    0.16962900799358335,
                                ],
                                [
                                    0.05779030918860551,
                                    0.5339316453456586,
                                    0.03987432661841205,
                                    0.3684037188473238,
                                ],
                                [
                                    0.05779030918860551,
                                    0.03987432661841205,
                                    0.5339316453456586,
                                    0.3684037188473238,
                                ],
                                [
                                    0.0365282988534425,
                                    0.7859590006279802,
                                    0.007883692524994048,
                                    0.16962900799358335,
                                ],
                                [
                                    0.02627955034320736,
                                    0.018132441035229183,
                                    0.5654424041910567,
                                    0.39014560443050667,
                                ],
                                [
                                    0.02627955034320736,
                                    0.5654424041910567,
                                    0.018132441035229183,
                                    0.39014560443050667,
                                ],
                                [
                                    0.13877888970268004,
                                    0.018101249747827328,
                                    0.7458384378237407,
                                    0.0972814227257519,
                                ],
                                [
                                    0.13877888970268004,
                                    0.7458384378237407,
                                    0.018101249747827328,
                                    0.0972814227257519,
                                ],
                                [
                                    0.03670937833624606,
                                    0.004788088640682068,
                                    0.8479079491901746,
                                    0.11059458383289715,
                                ],
                                [
                                    0.06033881997742636,
                                    0.3242785075489944,
                                    0.09654131947308102,
                                    0.5188413530004983,
                                ],
                                [
                                    0.06033881997742636,
                                    0.09654131947308102,
                                    0.3242785075489944,
                                    0.5188413530004983,
                                ],
                                [
                                    0.03670937833624606,
                                    0.8479079491901746,
                                    0.004788088640682068,
                                    0.11059458383289715,
                                ],
                                [
                                    0.015960644847781997,
                                    0.025536822129146135,
                                    0.36865668267863877,
                                    0.5898458503444332,
                                ],
                                [
                                    0.015960644847781997,
                                    0.36865668267863877,
                                    0.025536822129146135,
                                    0.5898458503444332,
                                ],
                                [
                                    0.20458797864974693,
                                    0.01150766444425018,
                                    0.7421593769216721,
                                    0.04174497998433086,
                                ],
                                [
                                    0.20458797864974693,
                                    0.7421593769216721,
                                    0.01150766444425018,
                                    0.04174497998433086,
                                ],
                                [
                                    0.03652829885344253,
                                    0.0020546437219771873,
                                    0.9102190567179764,
                                    0.05119800070660385,
                                ],
                                [
                                    0.03835972117591411,
                                    0.13915297934266338,
                                    0.177735921918083,
                                    0.6447513775633396,
                                ],
                                [
                                    0.03835972117591411,
                                    0.177735921918083,
                                    0.13915297934266338,
                                    0.6447513775633396,
                                ],
                                [
                                    0.03652829885344253,
                                    0.9102190567179764,
                                    0.0020546437219771873,
                                    0.05119800070660385,
                                ],
                                [
                                    0.006848962330515953,
                                    0.031733980244903766,
                                    0.17066373818806152,
                                    0.7907533192365187,
                                ],
                                [
                                    0.006848962330515953,
                                    0.17066373818806152,
                                    0.031733980244903766,
                                    0.7907533192365187,
                                ],
                                [
                                    0.25375576971569663,
                                    0.0027770239562859363,
                                    0.7354190101768235,
                                    0.008048196151193957,
                                ],
                                [
                                    0.25375576971569663,
                                    0.7354190101768235,
                                    0.0027770239562859363,
                                    0.008048196151193957,
                                ],
                                [
                                    0.03619654513787413,
                                    0.0003961236944298094,
                                    0.9529782347546459,
                                    0.010429096413050084,
                                ],
                                [
                                    0.009256949155759248,
                                    0.026827907767428945,
                                    0.2472758445162233,
                                    0.7166392985605885,
                                ],
                                [
                                    0.009256949155759248,
                                    0.2472758445162233,
                                    0.026827907767428945,
                                    0.7166392985605885,
                                ],
                                [
                                    0.03619654513787413,
                                    0.9529782347546459,
                                    0.0003961236944298094,
                                    0.010429096413050084,
                                ],
                                [
                                    0.0013204412192512956,
                                    0.03527222761305265,
                                    0.034764415703936895,
                                    0.9286429154637592,
                                ],
                                [
                                    0.0013204412192512956,
                                    0.034764415703936895,
                                    0.03527222761305265,
                                    0.9286429154637592,
                                ],
                                [
                                    0.029956015484698704,
                                    0.02727146974433339,
                                    0.4934990230306353,
                                    0.4492734917403326,
                                ],
                                [
                                    0.029956015484698704,
                                    0.4934990230306353,
                                    0.02727146974433339,
                                    0.4492734917403326,
                                ],
                                [
                                    0.024289499476400855,
                                    0.022112765645151355,
                                    0.4991655390389332,
                                    0.4544321958395146,
                                ],
                                [
                                    0.02727146974433339,
                                    0.4492734917403326,
                                    0.029956015484698704,
                                    0.4934990230306353,
                                ],
                                [
                                    0.02727146974433339,
                                    0.029956015484698704,
                                    0.4492734917403326,
                                    0.4934990230306353,
                                ],
                                [
                                    0.024289499476400855,
                                    0.4991655390389332,
                                    0.022112765645151355,
                                    0.4544321958395146,
                                ],
                                [
                                    0.022112765645151355,
                                    0.024289499476400855,
                                    0.4544321958395146,
                                    0.4991655390389332,
                                ],
                                [
                                    0.022112765645151355,
                                    0.4544321958395146,
                                    0.024289499476400855,
                                    0.4991655390389332,
                                ],
                                [
                                    0.06010112458908129,
                                    0.037563511217936274,
                                    0.5552815478844979,
                                    0.3470538163084845,
                                ],
                                [
                                    0.06010112458908129,
                                    0.5552815478844979,
                                    0.037563511217936274,
                                    0.3470538163084845,
                                ],
                                [
                                    0.027330369944335842,
                                    0.0170816214341007,
                                    0.5880523025292435,
                                    0.36753570609232006,
                                ],
                                [
                                    0.03756351121793629,
                                    0.3470538163084846,
                                    0.060101124589081276,
                                    0.5552815478844979,
                                ],
                                [
                                    0.03756351121793629,
                                    0.060101124589081276,
                                    0.3470538163084846,
                                    0.5552815478844979,
                                ],
                                [
                                    0.027330369944335842,
                                    0.5880523025292435,
                                    0.0170816214341007,
                                    0.36753570609232006,
                                ],
                                [
                                    0.01708162143410071,
                                    0.027330369944335835,
                                    0.36753570609232017,
                                    0.5880523025292433,
                                ],
                                [
                                    0.01708162143410071,
                                    0.36753570609232017,
                                    0.027330369944335835,
                                    0.5880523025292433,
                                ],
                                [
                                    0.11766010458788054,
                                    0.039220034862626846,
                                    0.6323398954121194,
                                    0.21077996513737315,
                                ],
                                [
                                    0.11766010458788054,
                                    0.6323398954121194,
                                    0.039220034862626846,
                                    0.21077996513737315,
                                ],
                                [
                                    0.0311231002326961,
                                    0.010374366744232033,
                                    0.7188768997673038,
                                    0.23962563325576797,
                                ],
                                [
                                    0.039220034862626846,
                                    0.21077996513737315,
                                    0.11766010458788054,
                                    0.6323398954121194,
                                ],
                                [
                                    0.039220034862626846,
                                    0.11766010458788054,
                                    0.21077996513737315,
                                    0.6323398954121194,
                                ],
                                [
                                    0.0311231002326961,
                                    0.7188768997673038,
                                    0.010374366744232033,
                                    0.23962563325576797,
                                ],
                                [
                                    0.010374366744232033,
                                    0.0311231002326961,
                                    0.23962563325576797,
                                    0.7188768997673038,
                                ],
                                [
                                    0.010374366744232033,
                                    0.23962563325576797,
                                    0.0311231002326961,
                                    0.7188768997673038,
                                ],
                                [
                                    0.19116195028391494,
                                    0.024933692810082144,
                                    0.6934553772425058,
                                    0.0904489796634971,
                                ],
                                [
                                    0.19116195028391494,
                                    0.6934553772425058,
                                    0.024933692810082144,
                                    0.0904489796634971,
                                ],
                                [
                                    0.03413113954917315,
                                    0.00445180302624657,
                                    0.8504861879772476,
                                    0.11093086944733269,
                                ],
                                [
                                    0.024933692810082144,
                                    0.0904489796634971,
                                    0.19116195028391494,
                                    0.6934553772425058,
                                ],
                                [
                                    0.024933692810082144,
                                    0.19116195028391494,
                                    0.0904489796634971,
                                    0.6934553772425058,
                                ],
                                [
                                    0.03413113954917315,
                                    0.8504861879772476,
                                    0.00445180302624657,
                                    0.11093086944733269,
                                ],
                                [
                                    0.00445180302624657,
                                    0.03413113954917315,
                                    0.11093086944733269,
                                    0.8504861879772476,
                                ],
                                [
                                    0.00445180302624657,
                                    0.11093086944733269,
                                    0.03413113954917315,
                                    0.8504861879772476,
                                ],
                                [
                                    0.25051580711596,
                                    0.006016986556022591,
                                    0.726029154368706,
                                    0.017438051959311446,
                                ],
                                [
                                    0.25051580711596,
                                    0.726029154368706,
                                    0.006016986556022591,
                                    0.017438051959311446,
                                ],
                                [
                                    0.03573438637546339,
                                    0.0008582824568405524,
                                    0.9408105751092025,
                                    0.022596756058493483,
                                ],
                                [
                                    0.006016986556022591,
                                    0.017438051959311446,
                                    0.25051580711596,
                                    0.726029154368706,
                                ],
                                [
                                    0.006016986556022591,
                                    0.25051580711596,
                                    0.017438051959311446,
                                    0.726029154368706,
                                ],
                                [
                                    0.03573438637546339,
                                    0.9408105751092025,
                                    0.0008582824568405524,
                                    0.022596756058493483,
                                ],
                                [
                                    0.0008582824568405524,
                                    0.03573438637546339,
                                    0.022596756058493483,
                                    0.9408105751092025,
                                ],
                                [
                                    0.0008582824568405524,
                                    0.022596756058493483,
                                    0.03573438637546339,
                                    0.9408105751092025,
                                ],
                                [
                                    0.015271165985899497,
                                    0.041956319243132596,
                                    0.2515790358844472,
                                    0.6911934788865207,
                                ],
                                [
                                    0.015271165985899497,
                                    0.2515790358844472,
                                    0.041956319243132596,
                                    0.6911934788865207,
                                ],
                                [
                                    0.012382453814927554,
                                    0.03401981130662465,
                                    0.25446774805541916,
                                    0.6991299868230286,
                                ],
                                [
                                    0.012586620245534183,
                                    0.20735350459414445,
                                    0.04464086498349791,
                                    0.7354190101768234,
                                ],
                                [
                                    0.012586620245534183,
                                    0.04464086498349791,
                                    0.20735350459414445,
                                    0.7354190101768234,
                                ],
                                [
                                    0.012382453814927554,
                                    0.25446774805541916,
                                    0.03401981130662465,
                                    0.6991299868230286,
                                ],
                                [
                                    0.010205719983678058,
                                    0.03619654513787415,
                                    0.20973440485600056,
                                    0.7438633300224472,
                                ],
                                [
                                    0.010205719983678058,
                                    0.20973440485600056,
                                    0.03619654513787415,
                                    0.7438633300224472,
                                ],
                                [
                                    0.039874326618412066,
                                    0.0577903091886055,
                                    0.3684037188473239,
                                    0.5339316453456585,
                                ],
                                [
                                    0.039874326618412066,
                                    0.3684037188473239,
                                    0.0577903091886055,
                                    0.5339316453456585,
                                ],
                                [
                                    0.01813244103522919,
                                    0.026279550343207354,
                                    0.3901456044305068,
                                    0.5654424041910566,
                                ],
                                [
                                    0.017336713247267047,
                                    0.16017598727131044,
                                    0.08032792255975052,
                                    0.742159376921672,
                                ],
                                [
                                    0.017336713247267047,
                                    0.08032792255975052,
                                    0.16017598727131044,
                                    0.742159376921672,
                                ],
                                [
                                    0.01813244103522919,
                                    0.3901456044305068,
                                    0.026279550343207354,
                                    0.5654424041910566,
                                ],
                                [
                                    0.007883692524994051,
                                    0.03652829885344249,
                                    0.16962900799358344,
                                    0.7859590006279801,
                                ],
                                [
                                    0.007883692524994051,
                                    0.16962900799358344,
                                    0.03652829885344249,
                                    0.7859590006279801,
                                ],
                                [
                                    0.09654131947308102,
                                    0.06033881997742636,
                                    0.5188413530004983,
                                    0.3242785075489944,
                                ],
                                [
                                    0.09654131947308102,
                                    0.5188413530004983,
                                    0.06033881997742636,
                                    0.3242785075489944,
                                ],
                                [
                                    0.025536822129146135,
                                    0.015960644847781997,
                                    0.5898458503444332,
                                    0.36865668267863877,
                                ],
                                [
                                    0.01810124974782733,
                                    0.09728142272575192,
                                    0.13877888970268004,
                                    0.7458384378237407,
                                ],
                                [
                                    0.01810124974782733,
                                    0.13877888970268004,
                                    0.09728142272575192,
                                    0.7458384378237407,
                                ],
                                [
                                    0.025536822129146135,
                                    0.5898458503444332,
                                    0.015960644847781997,
                                    0.36865668267863877,
                                ],
                                [
                                    0.004788088640682069,
                                    0.03670937833624606,
                                    0.11059458383289718,
                                    0.8479079491901746,
                                ],
                                [
                                    0.004788088640682069,
                                    0.11059458383289718,
                                    0.03670937833624606,
                                    0.8479079491901746,
                                ],
                                [
                                    0.177735921918083,
                                    0.03835972117591411,
                                    0.6447513775633396,
                                    0.13915297934266335,
                                ],
                                [
                                    0.177735921918083,
                                    0.6447513775633396,
                                    0.03835972117591411,
                                    0.13915297934266335,
                                ],
                                [
                                    0.031733980244903766,
                                    0.006848962330515952,
                                    0.7907533192365187,
                                    0.1706637381880615,
                                ],
                                [
                                    0.011507664444250177,
                                    0.04174497998433084,
                                    0.20458797864974693,
                                    0.7421593769216721,
                                ],
                                [
                                    0.011507664444250177,
                                    0.20458797864974693,
                                    0.04174497998433084,
                                    0.7421593769216721,
                                ],
                                [
                                    0.031733980244903766,
                                    0.7907533192365187,
                                    0.006848962330515952,
                                    0.1706637381880615,
                                ],
                                [
                                    0.0020546437219771865,
                                    0.03652829885344253,
                                    0.05119800070660383,
                                    0.9102190567179764,
                                ],
                                [
                                    0.0020546437219771865,
                                    0.05119800070660383,
                                    0.03652829885344253,
                                    0.9102190567179764,
                                ],
                                [
                                    0.2472758445162233,
                                    0.009256949155759244,
                                    0.7166392985605885,
                                    0.026827907767428934,
                                ],
                                [
                                    0.2472758445162233,
                                    0.7166392985605885,
                                    0.009256949155759244,
                                    0.026827907767428934,
                                ],
                                [
                                    0.03527222761305265,
                                    0.0013204412192512952,
                                    0.9286429154637592,
                                    0.03476441570393688,
                                ],
                                [
                                    0.0027770239562859337,
                                    0.008048196151193949,
                                    0.25375576971569663,
                                    0.7354190101768235,
                                ],
                                [
                                    0.0027770239562859337,
                                    0.25375576971569663,
                                    0.008048196151193949,
                                    0.7354190101768235,
                                ],
                                [
                                    0.03527222761305265,
                                    0.9286429154637592,
                                    0.0013204412192512952,
                                    0.03476441570393688,
                                ],
                                [
                                    0.00039612369442980903,
                                    0.03619654513787413,
                                    0.010429096413050074,
                                    0.9529782347546459,
                                ],
                                [
                                    0.00039612369442980903,
                                    0.010429096413050074,
                                    0.03619654513787413,
                                    0.9529782347546459,
                                ],
                                [
                                    0.005243159233257739,
                                    0.05198432599577436,
                                    0.08637643950105517,
                                    0.8563960752699127,
                                ],
                                [
                                    0.005243159233257739,
                                    0.08637643950105517,
                                    0.05198432599577436,
                                    0.8563960752699127,
                                ],
                                [
                                    0.004251356910799817,
                                    0.042150908210752396,
                                    0.08736824182351309,
                                    0.8662294930549347,
                                ],
                                [
                                    0.0025586134928924247,
                                    0.042150908210752416,
                                    0.05466887173613967,
                                    0.9006216065602155,
                                ],
                                [
                                    0.0025586134928924247,
                                    0.05466887173613967,
                                    0.042150908210752416,
                                    0.9006216065602155,
                                ],
                                [
                                    0.004251356910799817,
                                    0.08736824182351309,
                                    0.042150908210752396,
                                    0.8662294930549347,
                                ],
                                [
                                    0.0020746230795503206,
                                    0.04432764204200189,
                                    0.04263489862409452,
                                    0.9109628362543533,
                                ],
                                [
                                    0.0020746230795503206,
                                    0.04263489862409452,
                                    0.04432764204200189,
                                    0.9109628362543533,
                                ],
                                [
                                    0.026061827780696527,
                                    0.07160280802632103,
                                    0.24078837408965018,
                                    0.6615469901033323,
                                ],
                                [
                                    0.026061827780696527,
                                    0.24078837408965018,
                                    0.07160280802632103,
                                    0.6615469901033323,
                                ],
                                [
                                    0.011851348864799889,
                                    0.032560642513636655,
                                    0.2549988530055468,
                                    0.7005891556160166,
                                ],
                                [
                                    0.003524214409551511,
                                    0.03256064251363668,
                                    0.09414042139746605,
                                    0.8697747216793458,
                                ],
                                [
                                    0.003524214409551511,
                                    0.09414042139746605,
                                    0.03256064251363668,
                                    0.8697747216793458,
                                ],
                                [
                                    0.011851348864799889,
                                    0.2549988530055468,
                                    0.032560642513636655,
                                    0.7005891556160166,
                                ],
                                [
                                    0.0016026003545647502,
                                    0.042809391023871796,
                                    0.03448225656862344,
                                    0.92110575205294,
                                ],
                                [
                                    0.0016026003545647502,
                                    0.03448225656862344,
                                    0.042809391023871796,
                                    0.92110575205294,
                                ],
                                [
                                    0.08211969943835631,
                                    0.07476044001215107,
                                    0.4413353390769777,
                                    0.4017845214725149,
                                ],
                                [
                                    0.08211969943835631,
                                    0.4413353390769777,
                                    0.07476044001215107,
                                    0.4017845214725149,
                                ],
                                [
                                    0.021722058174696718,
                                    0.019775408802231415,
                                    0.5017329803406373,
                                    0.4567695526824345,
                                ],
                                [
                                    0.0036796297131026254,
                                    0.01977540880223141,
                                    0.15320050973740476,
                                    0.8233444517472612,
                                ],
                                [
                                    0.0036796297131026254,
                                    0.15320050973740476,
                                    0.01977540880223141,
                                    0.8233444517472612,
                                ],
                                [
                                    0.021722058174696718,
                                    0.5017329803406373,
                                    0.019775408802231415,
                                    0.4567695526824345,
                                ],
                                [
                                    0.0009733246862326517,
                                    0.04052414229069548,
                                    0.022481713829101385,
                                    0.9360208191939705,
                                ],
                                [
                                    0.0009733246862326517,
                                    0.022481713829101385,
                                    0.04052414229069548,
                                    0.9360208191939705,
                                ],
                                [
                                    0.16856754037459273,
                                    0.04752810271940436,
                                    0.6114923347857286,
                                    0.17241202212027426,
                                ],
                                [
                                    0.16856754037459273,
                                    0.6114923347857286,
                                    0.04752810271940436,
                                    0.17241202212027426,
                                ],
                                [
                                    0.030097005368699758,
                                    0.008485937206719965,
                                    0.7499628697916216,
                                    0.21145418763295865,
                                ],
                                [
                                    0.0023392829007599335,
                                    0.00848593720671995,
                                    0.21375636019323715,
                                    0.7754184196992829,
                                ],
                                [
                                    0.0023392829007599335,
                                    0.21375636019323715,
                                    0.00848593720671995,
                                    0.7754184196992829,
                                ],
                                [
                                    0.030097005368699758,
                                    0.7499628697916216,
                                    0.008485937206719965,
                                    0.21145418763295865,
                                ],
                                [
                                    0.0004176688457731752,
                                    0.038165273729646544,
                                    0.010407551261706708,
                                    0.9510095061628736,
                                ],
                                [
                                    0.0004176688457731752,
                                    0.010407551261706708,
                                    0.038165273729646544,
                                    0.9510095061628736,
                                ],
                                [
                                    0.2450633351656084,
                                    0.011469458506374153,
                                    0.7102271431307468,
                                    0.03324006319727071,
                                ],
                                [
                                    0.2450633351656084,
                                    0.7102271431307468,
                                    0.011469458506374153,
                                    0.03324006319727071,
                                ],
                                [
                                    0.03495662811095176,
                                    0.001636040721352182,
                                    0.9203338501854034,
                                    0.043073480982292675,
                                ],
                                [
                                    0.0005645146056710336,
                                    0.0016360407213522011,
                                    0.25596827906631153,
                                    0.7418311656066653,
                                ],
                                [
                                    0.0005645146056710336,
                                    0.25596827906631153,
                                    0.0016360407213522011,
                                    0.7418311656066653,
                                ],
                                [
                                    0.03495662811095176,
                                    0.9203338501854034,
                                    0.001636040721352182,
                                    0.043073480982292675,
                                ],
                                [
                                    8.052419232892353e-05,
                                    0.03651214463997502,
                                    0.0021200311346943113,
                                    0.9612873000330018,
                                ],
                                [
                                    8.052419232892353e-05,
                                    0.0021200311346943113,
                                    0.03651214463997502,
                                    0.9612873000330018,
                                ],
                                [
                                    0.9115288131482442,
                                    0.042661387484599314,
                                    0.04376166514811092,
                                    0.002048134219045494,
                                ],
                                [
                                    0.9115288131482442,
                                    0.04376166514811092,
                                    0.042661387484599314,
                                    0.002048134219045494,
                                ],
                                [
                                    0.8891224381864714,
                                    0.04161272393103817,
                                    0.06616804010988378,
                                    0.003096797772606645,
                                ],
                                [
                                    0.866767677334649,
                                    0.04161272393103817,
                                    0.08742252329819458,
                                    0.004197075436118249,
                                ],
                                [
                                    0.866767677334649,
                                    0.08742252329819458,
                                    0.04161272393103817,
                                    0.004197075436118249,
                                ],
                                [
                                    0.8891224381864714,
                                    0.06616804010988378,
                                    0.04161272393103817,
                                    0.003096797772606645,
                                ],
                                [
                                    0.8454615800363878,
                                    0.08527358208112183,
                                    0.06291882122929943,
                                    0.006346016653191003,
                                ],
                                [
                                    0.8454615800363878,
                                    0.06291882122929943,
                                    0.08527358208112183,
                                    0.006346016653191003,
                                ],
                                [
                                    0.9239151062584209,
                                    0.03458742676465096,
                                    0.0400000368183909,
                                    0.0014974301585371742,
                                ],
                                [
                                    0.9239151062584209,
                                    0.0400000368183909,
                                    0.03458742676465096,
                                    0.0014974301585371742,
                                ],
                                [
                                    0.8126960010124659,
                                    0.030423859537026778,
                                    0.15121914206434595,
                                    0.005660997386161358,
                                ],
                                [
                                    0.7027259385926266,
                                    0.030423859537026778,
                                    0.25577659443044526,
                                    0.011073607439901299,
                                ],
                                [
                                    0.7027259385926266,
                                    0.25577659443044526,
                                    0.030423859537026778,
                                    0.011073607439901299,
                                ],
                                [
                                    0.8126960010124659,
                                    0.15121914206434595,
                                    0.030423859537026778,
                                    0.005660997386161358,
                                ],
                                [
                                    0.6181331555609622,
                                    0.2249867049885306,
                                    0.1150166425686913,
                                    0.041863496881815995,
                                ],
                                [
                                    0.6181331555609622,
                                    0.1150166425686913,
                                    0.2249867049885306,
                                    0.041863496881815995,
                                ],
                                [
                                    0.9421876119592986,
                                    0.022629830267700306,
                                    0.03435734952536731,
                                    0.0008252082476337027,
                                ],
                                [
                                    0.9421876119592986,
                                    0.03435734952536731,
                                    0.022629830267700306,
                                    0.0008252082476337027,
                                ],
                                [
                                    0.6980513715881322,
                                    0.016766070638866804,
                                    0.2784935898965338,
                                    0.006688967876467205,
                                ],
                                [
                                    0.45977889084579915,
                                    0.016766070638866804,
                                    0.5050385513811998,
                                    0.01841648713413421,
                                ],
                                [
                                    0.45977889084579915,
                                    0.5050385513811998,
                                    0.016766070638866804,
                                    0.01841648713413421,
                                ],
                                [
                                    0.6980513715881322,
                                    0.2784935898965338,
                                    0.016766070638866804,
                                    0.006688967876467205,
                                ],
                                [
                                    0.3406426504746327,
                                    0.37417479175236634,
                                    0.13590231101003328,
                                    0.14928024676296772,
                                ],
                                [
                                    0.3406426504746327,
                                    0.13590231101003328,
                                    0.37417479175236634,
                                    0.14928024676296772,
                                ],
                                [
                                    0.9606196299731917,
                                    0.01051272145773428,
                                    0.028555149919328348,
                                    0.0003124986497456022,
                                ],
                                [
                                    0.9606196299731917,
                                    0.028555149919328348,
                                    0.01051272145773428,
                                    0.0003124986497456022,
                                ],
                                [
                                    0.5801658696743952,
                                    0.006349154230110094,
                                    0.40900891021812497,
                                    0.004476065877369788,
                                ],
                                [
                                    0.21359097060956853,
                                    0.006349154230110094,
                                    0.7575413808213575,
                                    0.022518494338963857,
                                ],
                                [
                                    0.21359097060956853,
                                    0.7575413808213575,
                                    0.006349154230110094,
                                    0.022518494338963857,
                                ],
                                [
                                    0.5801658696743952,
                                    0.40900891021812497,
                                    0.006349154230110094,
                                    0.004476065877369788,
                                ],
                                [
                                    0.128998187577904,
                                    0.4575168363266013,
                                    0.09094193726177464,
                                    0.3225430388337201,
                                ],
                                [
                                    0.128998187577904,
                                    0.09094193726177464,
                                    0.4575168363266013,
                                    0.3225430388337201,
                                ],
                                [
                                    0.9732981638259552,
                                    0.0021465199951991114,
                                    0.024501280847021516,
                                    5.4035331824097916e-05,
                                ],
                                [
                                    0.9732981638259552,
                                    0.024501280847021516,
                                    0.0021465199951991114,
                                    5.4035331824097916e-05,
                                ],
                                [
                                    0.4978018658948504,
                                    0.0010978564416379596,
                                    0.49999757877812634,
                                    0.00110269888538525,
                                ],
                                [
                                    0.043611665262006875,
                                    0.0010978564416379592,
                                    0.9318330185591475,
                                    0.023457459737207653,
                                ],
                                [
                                    0.043611665262006875,
                                    0.9318330185591475,
                                    0.0010978564416379592,
                                    0.023457459737207653,
                                ],
                                [
                                    0.4978018658948504,
                                    0.49999757877812634,
                                    0.0010978564416379596,
                                    0.00110269888538525,
                                ],
                                [
                                    0.02230556796374561,
                                    0.4765941543727428,
                                    0.02240395373989923,
                                    0.4786963239236124,
                                ],
                                [
                                    0.02230556796374561,
                                    0.02240395373989923,
                                    0.4765941543727428,
                                    0.4786963239236124,
                                ],
                                [
                                    0.7443254887848579,
                                    0.20986471184798555,
                                    0.0357343863754634,
                                    0.01007541299169301,
                                ],
                                [
                                    0.7443254887848579,
                                    0.0357343863754634,
                                    0.20986471184798555,
                                    0.01007541299169301,
                                ],
                                [
                                    0.7260291543687061,
                                    0.20470600774880354,
                                    0.05403072079161538,
                                    0.01523411709087504,
                                ],
                                [
                                    0.6995643529712627,
                                    0.03358544515839065,
                                    0.2546258476615808,
                                    0.012224354208765765,
                                ],
                                [
                                    0.6995643529712627,
                                    0.2546258476615808,
                                    0.03358544515839065,
                                    0.012224354208765765,
                                ],
                                [
                                    0.7260291543687061,
                                    0.05403072079161538,
                                    0.20470600774880354,
                                    0.01523411709087504,
                                ],
                                [
                                    0.6823682962186224,
                                    0.2483668658988872,
                                    0.05078150191103103,
                                    0.0184833359714594,
                                ],
                                [
                                    0.6823682962186224,
                                    0.05078150191103103,
                                    0.2483668658988872,
                                    0.0184833359714594,
                                ],
                                [
                                    0.7883561599322495,
                                    0.1701463730908224,
                                    0.03413113954917309,
                                    0.007366327427754989,
                                ],
                                [
                                    0.7883561599322495,
                                    0.03413113954917309,
                                    0.1701463730908224,
                                    0.007366327427754989,
                                ],
                                [
                                    0.6934553772425059,
                                    0.14966448330698684,
                                    0.12903192223891674,
                                    0.027848217211590563,
                                ],
                                [
                                    0.5671669922664552,
                                    0.024554962267808962,
                                    0.39133554075661675,
                                    0.016942504709119115,
                                ],
                                [
                                    0.5671669922664552,
                                    0.39133554075661675,
                                    0.024554962267808962,
                                    0.016942504709119115,
                                ],
                                [
                                    0.6934553772425059,
                                    0.12903192223891674,
                                    0.14966448330698684,
                                    0.027848217211590563,
                                ],
                                [
                                    0.49889253179100207,
                                    0.34422732875849066,
                                    0.0928294227432621,
                                    0.0640507167072452,
                                ],
                                [
                                    0.49889253179100207,
                                    0.0928294227432621,
                                    0.34422732875849066,
                                    0.0640507167072452,
                                ],
                                [
                                    0.8534942272937247,
                                    0.11132321493327427,
                                    0.031123100232696058,
                                    0.004059457540304955,
                                ],
                                [
                                    0.8534942272937247,
                                    0.031123100232696058,
                                    0.11132321493327427,
                                    0.004059457540304955,
                                ],
                                [
                                    0.6323398954121195,
                                    0.08247754681487947,
                                    0.25227743211430126,
                                    0.03290512565869976,
                                ],
                                [
                                    0.3710855061802252,
                                    0.01353182134619555,
                                    0.5937319360467738,
                                    0.021650736426805463,
                                ],
                                [
                                    0.3710855061802252,
                                    0.5937319360467738,
                                    0.01353182134619555,
                                    0.021650736426805463,
                                ],
                                [
                                    0.6323398954121195,
                                    0.25227743211430126,
                                    0.08247754681487947,
                                    0.03290512565869976,
                                ],
                                [
                                    0.27493117429862,
                                    0.43988626792837904,
                                    0.10968615322780073,
                                    0.17549640454520027,
                                ],
                                [
                                    0.27493117429862,
                                    0.10968615322780073,
                                    0.43988626792837904,
                                    0.17549640454520027,
                                ],
                                [
                                    0.9194169856270832,
                                    0.05171536580384291,
                                    0.027330369944335818,
                                    0.0015372786247381314,
                                ],
                                [
                                    0.9194169856270832,
                                    0.027330369944335818,
                                    0.05171536580384291,
                                    0.0015372786247381314,
                                ],
                                [
                                    0.5552815478844979,
                                    0.03123347602000733,
                                    0.391465807686921,
                                    0.022019168408573712,
                                ],
                                [
                                    0.1723883262634599,
                                    0.005124374255117566,
                                    0.7987440251674661,
                                    0.023743274313956383,
                                ],
                                [
                                    0.1723883262634599,
                                    0.7987440251674661,
                                    0.005124374255117566,
                                    0.023743274313956383,
                                ],
                                [
                                    0.5552815478844979,
                                    0.391465807686921,
                                    0.03123347602000733,
                                    0.022019168408573712,
                                ],
                                [
                                    0.10411386578800676,
                                    0.48240115811649853,
                                    0.07339883473057073,
                                    0.340086141364924,
                                ],
                                [
                                    0.10411386578800676,
                                    0.07339883473057073,
                                    0.48240115811649853,
                                    0.340086141364924,
                                ],
                                [
                                    0.9648852804161192,
                                    0.010559403405035127,
                                    0.02428949947640085,
                                    0.00026581670244476586,
                                ],
                                [
                                    0.9648852804161192,
                                    0.02428949947640085,
                                    0.010559403405035127,
                                    0.00026581670244476586,
                                ],
                                [
                                    0.4934990230306353,
                                    0.0054006993058530895,
                                    0.4956757568618848,
                                    0.0054245208016268035,
                                ],
                                [
                                    0.035198781852170895,
                                    0.0008860750710172921,
                                    0.9402459019689835,
                                    0.02366924110782832,
                                ],
                                [
                                    0.035198781852170895,
                                    0.9402459019689835,
                                    0.0008860750710172921,
                                    0.02366924110782832,
                                ],
                                [
                                    0.4934990230306353,
                                    0.4956757568618848,
                                    0.0054006993058530895,
                                    0.0054245208016268035,
                                ],
                                [
                                    0.0180027250995305,
                                    0.4808969972369579,
                                    0.018082131823657692,
                                    0.4830181458398539,
                                ],
                                [
                                    0.0180027250995305,
                                    0.018082131823657692,
                                    0.4808969972369579,
                                    0.4830181458398539,
                                ],
                                [
                                    0.4994756682232194,
                                    0.4547145324096241,
                                    0.023979370292114586,
                                    0.02183042907504183,
                                ],
                                [
                                    0.4994756682232194,
                                    0.023979370292114586,
                                    0.4547145324096241,
                                    0.02183042907504183,
                                ],
                                [
                                    0.48719801013379666,
                                    0.44353715198371296,
                                    0.036257028381537396,
                                    0.03300780950095303,
                                ],
                                [
                                    0.4547145324096241,
                                    0.02183042907504183,
                                    0.4994756682232194,
                                    0.023979370292114586,
                                ],
                                [
                                    0.4547145324096241,
                                    0.4994756682232194,
                                    0.02183042907504183,
                                    0.023979370292114586,
                                ],
                                [
                                    0.48719801013379666,
                                    0.036257028381537396,
                                    0.44353715198371296,
                                    0.03300780950095303,
                                ],
                                [
                                    0.44353715198371296,
                                    0.48719801013379666,
                                    0.03300780950095303,
                                    0.036257028381537396,
                                ],
                                [
                                    0.44353715198371296,
                                    0.03300780950095303,
                                    0.48719801013379666,
                                    0.036257028381537396,
                                ],
                                [
                                    0.5898458503444332,
                                    0.36865668267863877,
                                    0.0255368221291461,
                                    0.015960644847781976,
                                ],
                                [
                                    0.5898458503444332,
                                    0.0255368221291461,
                                    0.36865668267863877,
                                    0.015960644847781976,
                                ],
                                [
                                    0.5188413530004983,
                                    0.32427850754899445,
                                    0.09654131947308098,
                                    0.06033881997742633,
                                ],
                                [
                                    0.3686566826786389,
                                    0.01596064484778198,
                                    0.589845850344433,
                                    0.025536822129146097,
                                ],
                                [
                                    0.3686566826786389,
                                    0.589845850344433,
                                    0.01596064484778198,
                                    0.025536822129146097,
                                ],
                                [
                                    0.5188413530004983,
                                    0.09654131947308098,
                                    0.32427850754899445,
                                    0.06033881997742633,
                                ],
                                [
                                    0.3242785075489945,
                                    0.5188413530004982,
                                    0.06033881997742634,
                                    0.09654131947308095,
                                ],
                                [
                                    0.3242785075489945,
                                    0.06033881997742634,
                                    0.5188413530004982,
                                    0.09654131947308095,
                                ],
                                [
                                    0.7236130816702492,
                                    0.24120436055674974,
                                    0.02638691832975076,
                                    0.008795639443250253,
                                ],
                                [
                                    0.7236130816702492,
                                    0.02638691832975076,
                                    0.24120436055674974,
                                    0.008795639443250253,
                                ],
                                [
                                    0.5361130816702493,
                                    0.17870436055674976,
                                    0.21388691832975076,
                                    0.07129563944325025,
                                ],
                                [
                                    0.24120436055674974,
                                    0.008795639443250253,
                                    0.7236130816702492,
                                    0.02638691832975076,
                                ],
                                [
                                    0.24120436055674974,
                                    0.7236130816702492,
                                    0.008795639443250253,
                                    0.02638691832975076,
                                ],
                                [
                                    0.5361130816702493,
                                    0.21388691832975076,
                                    0.17870436055674976,
                                    0.07129563944325025,
                                ],
                                [
                                    0.17870436055674976,
                                    0.5361130816702493,
                                    0.07129563944325025,
                                    0.21388691832975076,
                                ],
                                [
                                    0.17870436055674976,
                                    0.07129563944325025,
                                    0.5361130816702493,
                                    0.21388691832975076,
                                ],
                                [
                                    0.8590805053972747,
                                    0.1120518460336514,
                                    0.0255368221291461,
                                    0.0033308264399278483,
                                ],
                                [
                                    0.8590805053972747,
                                    0.0255368221291461,
                                    0.1120518460336514,
                                    0.0033308264399278483,
                                ],
                                [
                                    0.5188413530004983,
                                    0.06767367090400704,
                                    0.36577597452592253,
                                    0.04770900156957222,
                                ],
                                [
                                    0.1120518460336514,
                                    0.0033308264399278483,
                                    0.8590805053972747,
                                    0.0255368221291461,
                                ],
                                [
                                    0.1120518460336514,
                                    0.8590805053972747,
                                    0.0033308264399278483,
                                    0.0255368221291461,
                                ],
                                [
                                    0.5188413530004983,
                                    0.36577597452592253,
                                    0.06767367090400704,
                                    0.04770900156957222,
                                ],
                                [
                                    0.06767367090400704,
                                    0.5188413530004983,
                                    0.04770900156957222,
                                    0.36577597452592253,
                                ],
                                [
                                    0.06767367090400704,
                                    0.04770900156957222,
                                    0.5188413530004983,
                                    0.36577597452592253,
                                ],
                                [
                                    0.9525655911925514,
                                    0.022879092628603007,
                                    0.023979370292114582,
                                    0.0005759458867310289,
                                ],
                                [
                                    0.9525655911925514,
                                    0.023979370292114582,
                                    0.022879092628603007,
                                    0.0005759458867310289,
                                ],
                                [
                                    0.4871980101337966,
                                    0.011701712202691792,
                                    0.48934695135086936,
                                    0.011753326312642245,
                                ],
                                [
                                    0.022879092628603007,
                                    0.0005759458867310289,
                                    0.9525655911925514,
                                    0.023979370292114582,
                                ],
                                [
                                    0.022879092628603007,
                                    0.9525655911925514,
                                    0.0005759458867310289,
                                    0.023979370292114582,
                                ],
                                [
                                    0.4871980101337966,
                                    0.48934695135086936,
                                    0.011701712202691792,
                                    0.011753326312642245,
                                ],
                                [
                                    0.011701712202691792,
                                    0.4871980101337966,
                                    0.011753326312642245,
                                    0.48934695135086936,
                                ],
                                [
                                    0.011701712202691792,
                                    0.011753326312642245,
                                    0.4871980101337966,
                                    0.48934695135086936,
                                ],
                                [
                                    0.2546258476615809,
                                    0.6995643529712626,
                                    0.01222435420876577,
                                    0.033585445158390646,
                                ],
                                [
                                    0.2546258476615809,
                                    0.01222435420876577,
                                    0.6995643529712626,
                                    0.033585445158390646,
                                ],
                                [
                                    0.2483668658988873,
                                    0.6823682962186223,
                                    0.018483335971459406,
                                    0.050781501911031014,
                                ],
                                [
                                    0.2098647118479856,
                                    0.010075412991693013,
                                    0.7443254887848579,
                                    0.0357343863754634,
                                ],
                                [
                                    0.2098647118479856,
                                    0.7443254887848579,
                                    0.010075412991693013,
                                    0.0357343863754634,
                                ],
                                [
                                    0.2483668658988873,
                                    0.018483335971459406,
                                    0.6823682962186223,
                                    0.050781501911031014,
                                ],
                                [
                                    0.20470600774880357,
                                    0.7260291543687061,
                                    0.015234117090875045,
                                    0.05403072079161538,
                                ],
                                [
                                    0.20470600774880357,
                                    0.015234117090875045,
                                    0.7260291543687061,
                                    0.05403072079161538,
                                ],
                                [
                                    0.39133554075661686,
                                    0.5671669922664551,
                                    0.016942504709119118,
                                    0.02455496226780896,
                                ],
                                [
                                    0.39133554075661686,
                                    0.016942504709119118,
                                    0.5671669922664551,
                                    0.02455496226780896,
                                ],
                                [
                                    0.34422732875849077,
                                    0.49889253179100196,
                                    0.06405071670724521,
                                    0.09282942274326209,
                                ],
                                [
                                    0.17014637309082248,
                                    0.007366327427754993,
                                    0.7883561599322494,
                                    0.03413113954917309,
                                ],
                                [
                                    0.17014637309082248,
                                    0.7883561599322494,
                                    0.007366327427754993,
                                    0.03413113954917309,
                                ],
                                [
                                    0.34422732875849077,
                                    0.06405071670724521,
                                    0.49889253179100196,
                                    0.09282942274326209,
                                ],
                                [
                                    0.14966448330698692,
                                    0.6934553772425058,
                                    0.027848217211590576,
                                    0.1290319222389167,
                                ],
                                [
                                    0.14966448330698692,
                                    0.027848217211590576,
                                    0.6934553772425058,
                                    0.1290319222389167,
                                ],
                                [
                                    0.5937319360467738,
                                    0.3710855061802252,
                                    0.021650736426805463,
                                    0.01353182134619555,
                                ],
                                [
                                    0.5937319360467738,
                                    0.021650736426805463,
                                    0.3710855061802252,
                                    0.01353182134619555,
                                ],
                                [
                                    0.43988626792837904,
                                    0.27493117429862,
                                    0.17549640454520027,
                                    0.10968615322780073,
                                ],
                                [
                                    0.1113232149332743,
                                    0.004059457540304956,
                                    0.8534942272937247,
                                    0.031123100232696058,
                                ],
                                [
                                    0.1113232149332743,
                                    0.8534942272937247,
                                    0.004059457540304956,
                                    0.031123100232696058,
                                ],
                                [
                                    0.43988626792837904,
                                    0.17549640454520027,
                                    0.27493117429862,
                                    0.10968615322780073,
                                ],
                                [
                                    0.0824775468148795,
                                    0.6323398954121195,
                                    0.03290512565869977,
                                    0.25227743211430126,
                                ],
                                [
                                    0.0824775468148795,
                                    0.03290512565869977,
                                    0.6323398954121195,
                                    0.25227743211430126,
                                ],
                                [
                                    0.7987440251674661,
                                    0.17238832626345987,
                                    0.023743274313956383,
                                    0.005124374255117565,
                                ],
                                [
                                    0.7987440251674661,
                                    0.023743274313956383,
                                    0.17238832626345987,
                                    0.005124374255117565,
                                ],
                                [
                                    0.48240115811649853,
                                    0.10411386578800674,
                                    0.340086141364924,
                                    0.07339883473057071,
                                ],
                                [
                                    0.05171536580384289,
                                    0.0015372786247381308,
                                    0.9194169856270832,
                                    0.027330369944335818,
                                ],
                                [
                                    0.05171536580384289,
                                    0.9194169856270832,
                                    0.0015372786247381308,
                                    0.027330369944335818,
                                ],
                                [
                                    0.48240115811649853,
                                    0.340086141364924,
                                    0.10411386578800674,
                                    0.07339883473057071,
                                ],
                                [
                                    0.031233476020007315,
                                    0.5552815478844979,
                                    0.022019168408573705,
                                    0.391465807686921,
                                ],
                                [
                                    0.031233476020007315,
                                    0.022019168408573705,
                                    0.5552815478844979,
                                    0.391465807686921,
                                ],
                                [
                                    0.9402459019689835,
                                    0.03519878185217088,
                                    0.02366924110782832,
                                    0.0008860750710172917,
                                ],
                                [
                                    0.9402459019689835,
                                    0.02366924110782832,
                                    0.03519878185217088,
                                    0.0008860750710172917,
                                ],
                                [
                                    0.4808969972369579,
                                    0.018002725099530492,
                                    0.4830181458398539,
                                    0.018082131823657685,
                                ],
                                [
                                    0.010559403405035117,
                                    0.0002658167024447656,
                                    0.9648852804161192,
                                    0.02428949947640085,
                                ],
                                [
                                    0.010559403405035117,
                                    0.9648852804161192,
                                    0.0002658167024447656,
                                    0.02428949947640085,
                                ],
                                [
                                    0.4808969972369579,
                                    0.4830181458398539,
                                    0.018002725099530492,
                                    0.018082131823657685,
                                ],
                                [
                                    0.005400699305853084,
                                    0.4934990230306353,
                                    0.005424520801626798,
                                    0.4956757568618848,
                                ],
                                [
                                    0.005400699305853084,
                                    0.005424520801626798,
                                    0.4934990230306353,
                                    0.4956757568618848,
                                ],
                                [
                                    0.08742252329819465,
                                    0.8667676773346489,
                                    0.004197075436118252,
                                    0.04161272393103816,
                                ],
                                [
                                    0.08742252329819465,
                                    0.004197075436118252,
                                    0.8667676773346489,
                                    0.04161272393103816,
                                ],
                                [
                                    0.0852735820811219,
                                    0.8454615800363877,
                                    0.0063460166531910086,
                                    0.06291882122929941,
                                ],
                                [
                                    0.04266138748459934,
                                    0.0020481342190454953,
                                    0.9115288131482442,
                                    0.04376166514811092,
                                ],
                                [
                                    0.04266138748459934,
                                    0.9115288131482442,
                                    0.0020481342190454953,
                                    0.04376166514811092,
                                ],
                                [
                                    0.0852735820811219,
                                    0.0063460166531910086,
                                    0.8454615800363877,
                                    0.06291882122929941,
                                ],
                                [
                                    0.041612723931038195,
                                    0.8891224381864714,
                                    0.0030967977726066467,
                                    0.06616804010988378,
                                ],
                                [
                                    0.041612723931038195,
                                    0.0030967977726066467,
                                    0.8891224381864714,
                                    0.06616804010988378,
                                ],
                                [
                                    0.25577659443044537,
                                    0.7027259385926264,
                                    0.011073607439901302,
                                    0.030423859537026775,
                                ],
                                [
                                    0.25577659443044537,
                                    0.011073607439901302,
                                    0.7027259385926264,
                                    0.030423859537026775,
                                ],
                                [
                                    0.22498670498853068,
                                    0.618133155560962,
                                    0.041863496881816016,
                                    0.11501664256869129,
                                ],
                                [
                                    0.034587426764651014,
                                    0.0014974301585371763,
                                    0.9239151062584209,
                                    0.0400000368183909,
                                ],
                                [
                                    0.034587426764651014,
                                    0.9239151062584209,
                                    0.0014974301585371763,
                                    0.0400000368183909,
                                ],
                                [
                                    0.22498670498853068,
                                    0.041863496881816016,
                                    0.618133155560962,
                                    0.11501664256869129,
                                ],
                                [
                                    0.030423859537026823,
                                    0.8126960010124659,
                                    0.005660997386161367,
                                    0.15121914206434595,
                                ],
                                [
                                    0.030423859537026823,
                                    0.005660997386161367,
                                    0.8126960010124659,
                                    0.15121914206434595,
                                ],
                                [
                                    0.5050385513811998,
                                    0.45977889084579915,
                                    0.01841648713413421,
                                    0.016766070638866804,
                                ],
                                [
                                    0.5050385513811998,
                                    0.01841648713413421,
                                    0.45977889084579915,
                                    0.016766070638866804,
                                ],
                                [
                                    0.37417479175236634,
                                    0.3406426504746327,
                                    0.14928024676296772,
                                    0.13590231101003328,
                                ],
                                [
                                    0.02262983026770033,
                                    0.0008252082476337037,
                                    0.9421876119592986,
                                    0.03435734952536731,
                                ],
                                [
                                    0.02262983026770033,
                                    0.9421876119592986,
                                    0.0008252082476337037,
                                    0.03435734952536731,
                                ],
                                [
                                    0.37417479175236634,
                                    0.14928024676296772,
                                    0.3406426504746327,
                                    0.13590231101003328,
                                ],
                                [
                                    0.016766070638866825,
                                    0.6980513715881322,
                                    0.006688967876467213,
                                    0.2784935898965338,
                                ],
                                [
                                    0.016766070638866825,
                                    0.006688967876467213,
                                    0.6980513715881322,
                                    0.2784935898965338,
                                ],
                                [
                                    0.7575413808213575,
                                    0.21359097060956853,
                                    0.022518494338963857,
                                    0.006349154230110094,
                                ],
                                [
                                    0.7575413808213575,
                                    0.022518494338963857,
                                    0.21359097060956853,
                                    0.006349154230110094,
                                ],
                                [
                                    0.4575168363266013,
                                    0.128998187577904,
                                    0.3225430388337201,
                                    0.09094193726177464,
                                ],
                                [
                                    0.01051272145773428,
                                    0.0003124986497456022,
                                    0.9606196299731917,
                                    0.028555149919328348,
                                ],
                                [
                                    0.01051272145773428,
                                    0.9606196299731917,
                                    0.0003124986497456022,
                                    0.028555149919328348,
                                ],
                                [
                                    0.4575168363266013,
                                    0.3225430388337201,
                                    0.128998187577904,
                                    0.09094193726177464,
                                ],
                                [
                                    0.006349154230110094,
                                    0.5801658696743952,
                                    0.004476065877369788,
                                    0.40900891021812497,
                                ],
                                [
                                    0.006349154230110094,
                                    0.004476065877369788,
                                    0.5801658696743952,
                                    0.40900891021812497,
                                ],
                                [
                                    0.9318330185591475,
                                    0.043611665262006896,
                                    0.023457459737207653,
                                    0.0010978564416379596,
                                ],
                                [
                                    0.9318330185591475,
                                    0.023457459737207653,
                                    0.043611665262006896,
                                    0.0010978564416379596,
                                ],
                                [
                                    0.4765941543727428,
                                    0.02230556796374562,
                                    0.4786963239236124,
                                    0.02240395373989924,
                                ],
                                [
                                    0.002146519995199136,
                                    5.403533182409853e-05,
                                    0.9732981638259552,
                                    0.024501280847021516,
                                ],
                                [
                                    0.002146519995199136,
                                    0.9732981638259552,
                                    5.403533182409853e-05,
                                    0.024501280847021516,
                                ],
                                [
                                    0.4765941543727428,
                                    0.4786963239236124,
                                    0.02230556796374562,
                                    0.02240395373989924,
                                ],
                                [
                                    0.0010978564416379722,
                                    0.4978018658948504,
                                    0.0011026988853852625,
                                    0.49999757877812634,
                                ],
                                [
                                    0.0010978564416379722,
                                    0.0011026988853852625,
                                    0.4978018658948504,
                                    0.49999757877812634,
                                ],
                                [
                                    0.7400131563946296,
                                    0.0346341087119518,
                                    0.2152773219017255,
                                    0.01007541299169301,
                                ],
                                [
                                    0.7400131563946296,
                                    0.2152773219017255,
                                    0.0346341087119518,
                                    0.01007541299169301,
                                ],
                                [
                                    0.7176067814328568,
                                    0.03358544515839065,
                                    0.23768369686349836,
                                    0.011124076545254161,
                                ],
                                [
                                    0.7036743935168837,
                                    0.20470600774880354,
                                    0.07097287158969784,
                                    0.02064672714461498,
                                ],
                                [
                                    0.7036743935168837,
                                    0.07097287158969784,
                                    0.20470600774880354,
                                    0.02064672714461498,
                                ],
                                [
                                    0.7176067814328568,
                                    0.23768369686349836,
                                    0.03358544515839065,
                                    0.011124076545254161,
                                ],
                                [
                                    0.6823682962186224,
                                    0.0688239303726251,
                                    0.2260121050470648,
                                    0.022795668361687733,
                                ],
                                [
                                    0.6823682962186224,
                                    0.2260121050470648,
                                    0.0688239303726251,
                                    0.022795668361687733,
                                ],
                                [
                                    0.7671424477716989,
                                    0.02871852949543315,
                                    0.19677269530511293,
                                    0.00736632742775499,
                                ],
                                [
                                    0.7671424477716989,
                                    0.19677269530511293,
                                    0.02871852949543315,
                                    0.00736632742775499,
                                ],
                                [
                                    0.6559233425257439,
                                    0.024554962267808962,
                                    0.30799180055106795,
                                    0.011529894655379173,
                                ],
                                [
                                    0.5834853148226666,
                                    0.14966448330698687,
                                    0.2123756624444655,
                                    0.054474539425881076,
                                ],
                                [
                                    0.5834853148226666,
                                    0.2123756624444655,
                                    0.14966448330698687,
                                    0.054474539425881076,
                                ],
                                [
                                    0.6559233425257439,
                                    0.30799180055106795,
                                    0.024554962267808962,
                                    0.011529894655379173,
                                ],
                                [
                                    0.49889253179100207,
                                    0.18158577300255083,
                                    0.23425726633865138,
                                    0.08526442886779577,
                                ],
                                [
                                    0.49889253179100207,
                                    0.23425726633865138,
                                    0.18158577300255083,
                                    0.08526442886779577,
                                ],
                                [
                                    0.8075304103146022,
                                    0.019395580975029053,
                                    0.16901455117006386,
                                    0.004059457540304954,
                                ],
                                [
                                    0.8075304103146022,
                                    0.16901455117006386,
                                    0.019395580975029053,
                                    0.004059457540304954,
                                ],
                                [
                                    0.5633941699434356,
                                    0.013531821346195553,
                                    0.41315079154123036,
                                    0.009923217169138457,
                                ],
                                [
                                    0.3940674146697865,
                                    0.08247754681487945,
                                    0.43285857661984467,
                                    0.09059646189548937,
                                ],
                                [
                                    0.3940674146697865,
                                    0.43285857661984467,
                                    0.08247754681487945,
                                    0.09059646189548937,
                                ],
                                [
                                    0.5633941699434356,
                                    0.41315079154123036,
                                    0.013531821346195553,
                                    0.009923217169138457,
                                ],
                                [
                                    0.27493117429862,
                                    0.30199481699101116,
                                    0.20161378718604595,
                                    0.22146022152432288,
                                ],
                                [
                                    0.27493117429862,
                                    0.20161378718604595,
                                    0.30199481699101116,
                                    0.22146022152432288,
                                ],
                                [
                                    0.8487030638293885,
                                    0.00928794148274175,
                                    0.1404717160631316,
                                    0.0015372786247381312,
                                ],
                                [
                                    0.8487030638293885,
                                    0.1404717160631316,
                                    0.00928794148274175,
                                    0.0015372786247381312,
                                ],
                                [
                                    0.4682493035305919,
                                    0.005124374255117565,
                                    0.5209254763619282,
                                    0.005700845852362317,
                                ],
                                [
                                    0.18870664881967128,
                                    0.031233476020007325,
                                    0.669284356492459,
                                    0.11077551866786241,
                                ],
                                [
                                    0.18870664881967128,
                                    0.669284356492459,
                                    0.031233476020007325,
                                    0.11077551866786241,
                                ],
                                [
                                    0.4682493035305919,
                                    0.5209254763619282,
                                    0.005124374255117565,
                                    0.005700845852362317,
                                ],
                                [
                                    0.10411386578800674,
                                    0.36925981199770275,
                                    0.11582625905167188,
                                    0.41080006316261863,
                                ],
                                [
                                    0.10411386578800674,
                                    0.11582625905167188,
                                    0.36925981199770275,
                                    0.41080006316261863,
                                ],
                                [
                                    0.8772699788481023,
                                    0.0019347386245784437,
                                    0.1205294658248744,
                                    0.0002658167024447658,
                                ],
                                [
                                    0.8772699788481023,
                                    0.1205294658248744,
                                    0.0019347386245784437,
                                    0.0002658167024447658,
                                ],
                                [
                                    0.40177368091699756,
                                    0.0008860750710172918,
                                    0.5960257637559793,
                                    0.0013144802560059179,
                                ],
                                [
                                    0.03930882239779175,
                                    0.005400699305853086,
                                    0.839895895074889,
                                    0.11539458322146608,
                                ],
                                [
                                    0.03930882239779175,
                                    0.839895895074889,
                                    0.005400699305853086,
                                    0.11539458322146608,
                                ],
                                [
                                    0.40177368091699756,
                                    0.5960257637559793,
                                    0.0008860750710172918,
                                    0.0013144802560059179,
                                ],
                                [
                                    0.018002725099530485,
                                    0.38465703088848435,
                                    0.026706796604114354,
                                    0.5706334474078708,
                                ],
                                [
                                    0.018002725099530485,
                                    0.026706796604114354,
                                    0.38465703088848435,
                                    0.5706334474078708,
                                ],
                                [
                                    0.6042712489123243,
                                    0.1703760161942571,
                                    0.17578862624799704,
                                    0.049564108645421455,
                                ],
                                [
                                    0.6042712489123243,
                                    0.17578862624799704,
                                    0.1703760161942571,
                                    0.049564108645421455,
                                ],
                                [
                                    0.5859749144961723,
                                    0.1652173120950751,
                                    0.19408496066414901,
                                    0.054722812744603486,
                                ],
                                [
                                    0.5679324860345782,
                                    0.1652173120950751,
                                    0.20671477907200314,
                                    0.06013542279834343,
                                ],
                                [
                                    0.5679324860345782,
                                    0.20671477907200314,
                                    0.1652173120950751,
                                    0.06013542279834343,
                                ],
                                [
                                    0.5859749144961723,
                                    0.19408496066414901,
                                    0.1652173120950751,
                                    0.054722812744603486,
                                ],
                                [
                                    0.550736429281938,
                                    0.20045579730930954,
                                    0.18241336884771545,
                                    0.06639440456103705,
                                ],
                                [
                                    0.550736429281938,
                                    0.18241336884771545,
                                    0.20045579730930954,
                                    0.06639440456103705,
                                ],
                                [
                                    0.6545855459550893,
                                    0.14127543131204276,
                                    0.1679017535263333,
                                    0.036237269206534646,
                                ],
                                [
                                    0.6545855459550893,
                                    0.1679017535263333,
                                    0.14127543131204276,
                                    0.036237269206534646,
                                ],
                                [
                                    0.5596847632653457,
                                    0.12079354152820718,
                                    0.2628025362160769,
                                    0.056719158990370215,
                                ],
                                [
                                    0.470928413006057,
                                    0.12079354152820719,
                                    0.32493256426107514,
                                    0.08334548120466075,
                                ],
                                [
                                    0.470928413006057,
                                    0.32493256426107514,
                                    0.12079354152820719,
                                    0.08334548120466075,
                                ],
                                [
                                    0.5596847632653457,
                                    0.2628025362160769,
                                    0.12079354152820718,
                                    0.056719158990370215,
                                ],
                                [
                                    0.4026539525306038,
                                    0.27782435226294905,
                                    0.1890680020036603,
                                    0.13045369320278682,
                                ],
                                [
                                    0.4026539525306038,
                                    0.1890680020036603,
                                    0.27782435226294905,
                                    0.13045369320278682,
                                ],
                                [
                                    0.7315130604767698,
                                    0.09541293081286134,
                                    0.15310426704965094,
                                    0.019969741660717882,
                                ],
                                [
                                    0.7315130604767698,
                                    0.15310426704965094,
                                    0.09541293081286134,
                                    0.019969741660717882,
                                ],
                                [
                                    0.5103587285951646,
                                    0.06656726269446653,
                                    0.3742585989312561,
                                    0.04881540977911269,
                                ],
                                [
                                    0.31805006483195425,
                                    0.06656726269446653,
                                    0.508875926457677,
                                    0.10650674601590229,
                                ],
                                [
                                    0.31805006483195425,
                                    0.508875926457677,
                                    0.06656726269446653,
                                    0.10650674601590229,
                                ],
                                [
                                    0.5103587285951646,
                                    0.3742585989312561,
                                    0.06656726269446653,
                                    0.04881540977911269,
                                ],
                                [
                                    0.22189573295034903,
                                    0.35503025833928215,
                                    0.16272159457607172,
                                    0.2603524141342971,
                                ],
                                [
                                    0.22189573295034903,
                                    0.16272159457607172,
                                    0.35503025833928215,
                                    0.2603524141342971,
                                ],
                                [
                                    0.8123007153833226,
                                    0.04569028992880766,
                                    0.13444664018809635,
                                    0.007562354499773381,
                                ],
                                [
                                    0.8123007153833226,
                                    0.13444664018809635,
                                    0.04569028992880766,
                                    0.007562354499773381,
                                ],
                                [
                                    0.44816527764073744,
                                    0.02520840014497208,
                                    0.49858207793068154,
                                    0.028044244283608962,
                                ],
                                [
                                    0.1523043003736054,
                                    0.025208400144972082,
                                    0.7056867049385248,
                                    0.11680059454289765,
                                ],
                                [
                                    0.1523043003736054,
                                    0.7056867049385248,
                                    0.025208400144972082,
                                    0.11680059454289765,
                                ],
                                [
                                    0.44816527764073744,
                                    0.49858207793068154,
                                    0.02520840014497208,
                                    0.028044244283608962,
                                ],
                                [
                                    0.08402983989815224,
                                    0.3893438378875572,
                                    0.09348286062042524,
                                    0.4331434615938653,
                                ],
                                [
                                    0.08402983989815224,
                                    0.09348286062042524,
                                    0.3893438378875572,
                                    0.4331434615938653,
                                ],
                                [
                                    0.8696871328865043,
                                    0.009517584586176443,
                                    0.11948764700601572,
                                    0.00130763552130345,
                                ],
                                [
                                    0.8696871328865043,
                                    0.11948764700601572,
                                    0.009517584586176443,
                                    0.00130763552130345,
                                ],
                                [
                                    0.39830087550102045,
                                    0.004358880486994406,
                                    0.5908739043914997,
                                    0.006466339620485487,
                                ],
                                [
                                    0.031725976436193785,
                                    0.0043588804869944065,
                                    0.847478741036487,
                                    0.11643640204032475,
                                ],
                                [
                                    0.031725976436193785,
                                    0.847478741036487,
                                    0.0043588804869944065,
                                    0.11643640204032475,
                                ],
                                [
                                    0.39830087550102045,
                                    0.5908739043914997,
                                    0.004358880486994406,
                                    0.006466339620485487,
                                ],
                                [
                                    0.014529919683553385,
                                    0.38812983630446146,
                                    0.021554937239634805,
                                    0.5757853067723504,
                                ],
                                [
                                    0.014529919683553385,
                                    0.021554937239634805,
                                    0.38812983630446146,
                                    0.5757853067723504,
                                ],
                                [
                                    0.40549301399216375,
                                    0.3691542511144177,
                                    0.11796202452317024,
                                    0.10739071037024826,
                                ],
                                [
                                    0.40549301399216375,
                                    0.11796202452317024,
                                    0.3691542511144177,
                                    0.10739071037024826,
                                ],
                                [
                                    0.393215355902741,
                                    0.35797687068850653,
                                    0.13023968261259306,
                                    0.11856809079615946,
                                ],
                                [
                                    0.3691542511144177,
                                    0.10739071037024826,
                                    0.40549301399216375,
                                    0.11796202452317024,
                                ],
                                [
                                    0.3691542511144177,
                                    0.40549301399216375,
                                    0.10739071037024826,
                                    0.11796202452317024,
                                ],
                                [
                                    0.393215355902741,
                                    0.13023968261259306,
                                    0.35797687068850653,
                                    0.11856809079615946,
                                ],
                                [
                                    0.35797687068850653,
                                    0.393215355902741,
                                    0.11856809079615946,
                                    0.13023968261259306,
                                ],
                                [
                                    0.35797687068850653,
                                    0.11856809079615946,
                                    0.393215355902741,
                                    0.13023968261259306,
                                ],
                                [
                                    0.48975905510808226,
                                    0.30610192215904986,
                                    0.12562361736549701,
                                    0.07851540536737092,
                                ],
                                [
                                    0.48975905510808226,
                                    0.12562361736549701,
                                    0.30610192215904986,
                                    0.07851540536737092,
                                ],
                                [
                                    0.4187545577641474,
                                    0.2617237470294055,
                                    0.19662811470943187,
                                    0.12289358049701526,
                                ],
                                [
                                    0.30610192215904997,
                                    0.07851540536737094,
                                    0.48975905510808215,
                                    0.125623617365497,
                                ],
                                [
                                    0.30610192215904997,
                                    0.48975905510808215,
                                    0.07851540536737094,
                                    0.125623617365497,
                                ],
                                [
                                    0.4187545577641474,
                                    0.19662811470943187,
                                    0.2617237470294055,
                                    0.12289358049701526,
                                ],
                                [
                                    0.26172374702940554,
                                    0.41875455776414733,
                                    0.12289358049701529,
                                    0.19662811470943184,
                                ],
                                [
                                    0.26172374702940554,
                                    0.12289358049701529,
                                    0.41875455776414733,
                                    0.19662811470943184,
                                ],
                                [
                                    0.6201944934672234,
                                    0.2067314978224078,
                                    0.12980550653277662,
                                    0.043268502177592205,
                                ],
                                [
                                    0.6201944934672234,
                                    0.12980550653277662,
                                    0.2067314978224078,
                                    0.043268502177592205,
                                ],
                                [
                                    0.4326944934672234,
                                    0.1442314978224078,
                                    0.3173055065327766,
                                    0.1057685021775922,
                                ],
                                [
                                    0.2067314978224078,
                                    0.043268502177592205,
                                    0.6201944934672234,
                                    0.12980550653277662,
                                ],
                                [
                                    0.2067314978224078,
                                    0.6201944934672234,
                                    0.043268502177592205,
                                    0.12980550653277662,
                                ],
                                [
                                    0.4326944934672234,
                                    0.3173055065327766,
                                    0.1442314978224078,
                                    0.1057685021775922,
                                ],
                                [
                                    0.1442314978224078,
                                    0.4326944934672234,
                                    0.1057685021775922,
                                    0.3173055065327766,
                                ],
                                [
                                    0.1442314978224078,
                                    0.1057685021775922,
                                    0.4326944934672234,
                                    0.3173055065327766,
                                ],
                                [
                                    0.7589937101609238,
                                    0.09899729515120652,
                                    0.12562361736549701,
                                    0.01638537732237273,
                                ],
                                [
                                    0.7589937101609238,
                                    0.12562361736549701,
                                    0.09899729515120652,
                                    0.01638537732237273,
                                ],
                                [
                                    0.41875455776414733,
                                    0.054619120021562155,
                                    0.4658627697622734,
                                    0.060763552452017096,
                                ],
                                [
                                    0.09899729515120652,
                                    0.01638537732237273,
                                    0.7589937101609238,
                                    0.12562361736549701,
                                ],
                                [
                                    0.09899729515120652,
                                    0.7589937101609238,
                                    0.01638537732237273,
                                    0.12562361736549701,
                                ],
                                [
                                    0.41875455776414733,
                                    0.4658627697622734,
                                    0.054619120021562155,
                                    0.060763552452017096,
                                ],
                                [
                                    0.054619120021562155,
                                    0.41875455776414733,
                                    0.060763552452017096,
                                    0.4658627697622734,
                                ],
                                [
                                    0.054619120021562155,
                                    0.060763552452017096,
                                    0.41875455776414733,
                                    0.4658627697622734,
                                ],
                                [
                                    0.8585829369614957,
                                    0.020621780511185107,
                                    0.11796202452317024,
                                    0.0028332580041489277,
                                ],
                                [
                                    0.8585829369614957,
                                    0.11796202452317024,
                                    0.020621780511185107,
                                    0.0028332580041489277,
                                ],
                                [
                                    0.3932153559027409,
                                    0.009444400085273892,
                                    0.583329605581925,
                                    0.014010638430060144,
                                ],
                                [
                                    0.020621780511185107,
                                    0.0028332580041489277,
                                    0.8585829369614957,
                                    0.11796202452317024,
                                ],
                                [
                                    0.020621780511185107,
                                    0.8585829369614957,
                                    0.0028332580041489277,
                                    0.11796202452317024,
                                ],
                                [
                                    0.3932153559027409,
                                    0.583329605581925,
                                    0.009444400085273892,
                                    0.014010638430060144,
                                ],
                                [
                                    0.009444400085273892,
                                    0.3932153559027409,
                                    0.014010638430060144,
                                    0.583329605581925,
                                ],
                                [
                                    0.009444400085273892,
                                    0.014010638430060144,
                                    0.3932153559027409,
                                    0.583329605581925,
                                ],
                                [
                                    0.20671477907200322,
                                    0.5679324860345782,
                                    0.06013542279834345,
                                    0.16521731209507506,
                                ],
                                [
                                    0.20671477907200322,
                                    0.06013542279834345,
                                    0.5679324860345782,
                                    0.16521731209507506,
                                ],
                                [
                                    0.20045579730930962,
                                    0.5507364292819379,
                                    0.06639440456103708,
                                    0.18241336884771542,
                                ],
                                [
                                    0.17037601619425713,
                                    0.04956410864542147,
                                    0.6042712489123243,
                                    0.17578862624799704,
                                ],
                                [
                                    0.17037601619425713,
                                    0.6042712489123243,
                                    0.04956410864542147,
                                    0.17578862624799704,
                                ],
                                [
                                    0.20045579730930962,
                                    0.06639440456103708,
                                    0.5507364292819379,
                                    0.18241336884771542,
                                ],
                                [
                                    0.16521731209507512,
                                    0.5859749144961723,
                                    0.0547228127446035,
                                    0.19408496066414901,
                                ],
                                [
                                    0.16521731209507512,
                                    0.0547228127446035,
                                    0.5859749144961723,
                                    0.19408496066414901,
                                ],
                                [
                                    0.32493256426107525,
                                    0.47092841300605687,
                                    0.08334548120466077,
                                    0.12079354152820716,
                                ],
                                [
                                    0.32493256426107525,
                                    0.08334548120466077,
                                    0.47092841300605687,
                                    0.12079354152820716,
                                ],
                                [
                                    0.2778243522629491,
                                    0.40265395253060376,
                                    0.13045369320278685,
                                    0.18906800200366028,
                                ],
                                [
                                    0.14127543131204282,
                                    0.03623726920653467,
                                    0.6545855459550893,
                                    0.16790175352633327,
                                ],
                                [
                                    0.14127543131204282,
                                    0.6545855459550893,
                                    0.03623726920653467,
                                    0.16790175352633327,
                                ],
                                [
                                    0.2778243522629491,
                                    0.13045369320278685,
                                    0.40265395253060376,
                                    0.18906800200366028,
                                ],
                                [
                                    0.12079354152820723,
                                    0.5596847632653457,
                                    0.05671915899037024,
                                    0.2628025362160769,
                                ],
                                [
                                    0.12079354152820723,
                                    0.05671915899037024,
                                    0.5596847632653457,
                                    0.2628025362160769,
                                ],
                                [
                                    0.508875926457677,
                                    0.31805006483195425,
                                    0.10650674601590229,
                                    0.06656726269446653,
                                ],
                                [
                                    0.508875926457677,
                                    0.10650674601590229,
                                    0.31805006483195425,
                                    0.06656726269446653,
                                ],
                                [
                                    0.35503025833928215,
                                    0.22189573295034903,
                                    0.2603524141342971,
                                    0.16272159457607172,
                                ],
                                [
                                    0.09541293081286137,
                                    0.01996974166071789,
                                    0.7315130604767698,
                                    0.15310426704965094,
                                ],
                                [
                                    0.09541293081286137,
                                    0.7315130604767698,
                                    0.01996974166071789,
                                    0.15310426704965094,
                                ],
                                [
                                    0.35503025833928215,
                                    0.2603524141342971,
                                    0.22189573295034903,
                                    0.16272159457607172,
                                ],
                                [
                                    0.06656726269446656,
                                    0.5103587285951646,
                                    0.0488154097791127,
                                    0.3742585989312561,
                                ],
                                [
                                    0.06656726269446656,
                                    0.0488154097791127,
                                    0.5103587285951646,
                                    0.3742585989312561,
                                ],
                                [
                                    0.7056867049385248,
                                    0.15230430037360537,
                                    0.11680059454289765,
                                    0.025208400144972075,
                                ],
                                [
                                    0.7056867049385248,
                                    0.11680059454289765,
                                    0.15230430037360537,
                                    0.025208400144972075,
                                ],
                                [
                                    0.3893438378875572,
                                    0.08402983989815223,
                                    0.4331434615938653,
                                    0.09348286062042523,
                                ],
                                [
                                    0.045690289928807644,
                                    0.0075623544997733775,
                                    0.8123007153833226,
                                    0.13444664018809635,
                                ],
                                [
                                    0.045690289928807644,
                                    0.8123007153833226,
                                    0.0075623544997733775,
                                    0.13444664018809635,
                                ],
                                [
                                    0.3893438378875572,
                                    0.4331434615938653,
                                    0.08402983989815223,
                                    0.09348286062042523,
                                ],
                                [
                                    0.025208400144972068,
                                    0.44816527764073744,
                                    0.02804424428360895,
                                    0.49858207793068154,
                                ],
                                [
                                    0.025208400144972068,
                                    0.02804424428360895,
                                    0.44816527764073744,
                                    0.49858207793068154,
                                ],
                                [
                                    0.847478741036487,
                                    0.03172597643619377,
                                    0.11643640204032475,
                                    0.004358880486994405,
                                ],
                                [
                                    0.847478741036487,
                                    0.11643640204032475,
                                    0.03172597643619377,
                                    0.004358880486994405,
                                ],
                                [
                                    0.38812983630446146,
                                    0.01452991968355338,
                                    0.5757853067723504,
                                    0.021554937239634798,
                                ],
                                [
                                    0.009517584586176433,
                                    0.0013076355213034487,
                                    0.8696871328865043,
                                    0.11948764700601572,
                                ],
                                [
                                    0.009517584586176433,
                                    0.8696871328865043,
                                    0.0013076355213034487,
                                    0.11948764700601572,
                                ],
                                [
                                    0.38812983630446146,
                                    0.5757853067723504,
                                    0.01452991968355338,
                                    0.021554937239634798,
                                ],
                                [
                                    0.004358880486994401,
                                    0.39830087550102045,
                                    0.006466339620485481,
                                    0.5908739043914997,
                                ],
                                [
                                    0.004358880486994401,
                                    0.006466339620485481,
                                    0.39830087550102045,
                                    0.5908739043914997,
                                ],
                                [
                                    0.07097287158969791,
                                    0.7036743935168835,
                                    0.020646727144615,
                                    0.20470600774880351,
                                ],
                                [
                                    0.07097287158969791,
                                    0.020646727144615,
                                    0.7036743935168835,
                                    0.20470600774880351,
                                ],
                                [
                                    0.06882393037262516,
                                    0.6823682962186224,
                                    0.022795668361687754,
                                    0.22601210504706476,
                                ],
                                [
                                    0.03463410871195182,
                                    0.010075412991693017,
                                    0.7400131563946296,
                                    0.2152773219017255,
                                ],
                                [
                                    0.03463410871195182,
                                    0.7400131563946296,
                                    0.010075412991693017,
                                    0.2152773219017255,
                                ],
                                [
                                    0.06882393037262516,
                                    0.022795668361687754,
                                    0.6823682962186224,
                                    0.22601210504706476,
                                ],
                                [
                                    0.033585445158390674,
                                    0.7176067814328568,
                                    0.011124076545254168,
                                    0.23768369686349836,
                                ],
                                [
                                    0.033585445158390674,
                                    0.011124076545254168,
                                    0.7176067814328568,
                                    0.23768369686349836,
                                ],
                                [
                                    0.2123756624444656,
                                    0.5834853148226665,
                                    0.054474539425881104,
                                    0.14966448330698684,
                                ],
                                [
                                    0.2123756624444656,
                                    0.054474539425881104,
                                    0.5834853148226665,
                                    0.14966448330698684,
                                ],
                                [
                                    0.18158577300255088,
                                    0.49889253179100196,
                                    0.08526442886779581,
                                    0.23425726633865132,
                                ],
                                [
                                    0.02871852949543319,
                                    0.007366327427755001,
                                    0.7671424477716989,
                                    0.19677269530511293,
                                ],
                                [
                                    0.02871852949543319,
                                    0.7671424477716989,
                                    0.007366327427755001,
                                    0.19677269530511293,
                                ],
                                [
                                    0.18158577300255088,
                                    0.08526442886779581,
                                    0.49889253179100196,
                                    0.23425726633865132,
                                ],
                                [
                                    0.024554962267809,
                                    0.6559233425257439,
                                    0.01152989465537919,
                                    0.30799180055106795,
                                ],
                                [
                                    0.024554962267809,
                                    0.01152989465537919,
                                    0.6559233425257439,
                                    0.30799180055106795,
                                ],
                                [
                                    0.43285857661984467,
                                    0.3940674146697865,
                                    0.09059646189548937,
                                    0.08247754681487945,
                                ],
                                [
                                    0.43285857661984467,
                                    0.09059646189548937,
                                    0.3940674146697865,
                                    0.08247754681487945,
                                ],
                                [
                                    0.30199481699101116,
                                    0.27493117429862,
                                    0.22146022152432288,
                                    0.20161378718604595,
                                ],
                                [
                                    0.019395580975029077,
                                    0.0040594575403049594,
                                    0.8075304103146022,
                                    0.16901455117006386,
                                ],
                                [
                                    0.019395580975029077,
                                    0.8075304103146022,
                                    0.0040594575403049594,
                                    0.16901455117006386,
                                ],
                                [
                                    0.30199481699101116,
                                    0.22146022152432288,
                                    0.27493117429862,
                                    0.20161378718604595,
                                ],
                                [
                                    0.013531821346195568,
                                    0.5633941699434356,
                                    0.009923217169138469,
                                    0.41315079154123036,
                                ],
                                [
                                    0.013531821346195568,
                                    0.009923217169138469,
                                    0.5633941699434356,
                                    0.41315079154123036,
                                ],
                                [
                                    0.669284356492459,
                                    0.18870664881967128,
                                    0.11077551866786241,
                                    0.031233476020007325,
                                ],
                                [
                                    0.669284356492459,
                                    0.11077551866786241,
                                    0.18870664881967128,
                                    0.031233476020007325,
                                ],
                                [
                                    0.36925981199770275,
                                    0.10411386578800674,
                                    0.41080006316261863,
                                    0.11582625905167188,
                                ],
                                [
                                    0.00928794148274175,
                                    0.0015372786247381312,
                                    0.8487030638293885,
                                    0.1404717160631316,
                                ],
                                [
                                    0.00928794148274175,
                                    0.8487030638293885,
                                    0.0015372786247381312,
                                    0.1404717160631316,
                                ],
                                [
                                    0.36925981199770275,
                                    0.41080006316261863,
                                    0.10411386578800674,
                                    0.11582625905167188,
                                ],
                                [
                                    0.005124374255117565,
                                    0.4682493035305919,
                                    0.005700845852362317,
                                    0.5209254763619282,
                                ],
                                [
                                    0.005124374255117565,
                                    0.005700845852362317,
                                    0.4682493035305919,
                                    0.5209254763619282,
                                ],
                                [
                                    0.839895895074889,
                                    0.03930882239779177,
                                    0.11539458322146608,
                                    0.005400699305853089,
                                ],
                                [
                                    0.839895895074889,
                                    0.11539458322146608,
                                    0.03930882239779177,
                                    0.005400699305853089,
                                ],
                                [
                                    0.38465703088848435,
                                    0.018002725099530492,
                                    0.5706334474078708,
                                    0.026706796604114368,
                                ],
                                [
                                    0.0019347386245784659,
                                    0.00026581670244476885,
                                    0.8772699788481023,
                                    0.1205294658248744,
                                ],
                                [
                                    0.0019347386245784659,
                                    0.8772699788481023,
                                    0.00026581670244476885,
                                    0.1205294658248744,
                                ],
                                [
                                    0.38465703088848435,
                                    0.5706334474078708,
                                    0.018002725099530492,
                                    0.026706796604114368,
                                ],
                                [
                                    0.0008860750710173019,
                                    0.40177368091699756,
                                    0.0013144802560059328,
                                    0.5960257637559793,
                                ],
                                [
                                    0.0008860750710173019,
                                    0.0013144802560059328,
                                    0.40177368091699756,
                                    0.5960257637559793,
                                ],
                                [
                                    0.488848426629064,
                                    0.022879092628602982,
                                    0.46644205166729114,
                                    0.02183042907504183,
                                ],
                                [
                                    0.488848426629064,
                                    0.46644205166729114,
                                    0.022879092628602982,
                                    0.02183042907504183,
                                ],
                                [
                                    0.46644205166729114,
                                    0.02183042907504183,
                                    0.488848426629064,
                                    0.022879092628602982,
                                ],
                                [
                                    0.46484324928197424,
                                    0.44353715198371296,
                                    0.04688426997569279,
                                    0.04473532875862004,
                                ],
                                [
                                    0.46484324928197424,
                                    0.04688426997569279,
                                    0.44353715198371296,
                                    0.04473532875862004,
                                ],
                                [
                                    0.46644205166729114,
                                    0.488848426629064,
                                    0.02183042907504183,
                                    0.022879092628602982,
                                ],
                                [
                                    0.44353715198371296,
                                    0.04473532875862004,
                                    0.46484324928197424,
                                    0.04688426997569279,
                                ],
                                [
                                    0.44353715198371296,
                                    0.46484324928197424,
                                    0.04473532875862004,
                                    0.04688426997569279,
                                ],
                                [
                                    0.5375671241613835,
                                    0.020124212075406163,
                                    0.4263480189154284,
                                    0.015960644847781976,
                                ],
                                [
                                    0.5375671241613835,
                                    0.4263480189154284,
                                    0.020124212075406163,
                                    0.015960644847781976,
                                ],
                                [
                                    0.42634801891542845,
                                    0.015960644847781976,
                                    0.5375671241613834,
                                    0.02012421207540616,
                                ],
                                [
                                    0.408871290580659,
                                    0.32427850754899445,
                                    0.14882004565613066,
                                    0.11803015621421593,
                                ],
                                [
                                    0.408871290580659,
                                    0.14882004565613066,
                                    0.32427850754899445,
                                    0.11803015621421593,
                                ],
                                [
                                    0.42634801891542845,
                                    0.5375671241613834,
                                    0.015960644847781976,
                                    0.02012421207540616,
                                ],
                                [
                                    0.32427850754899445,
                                    0.11803015621421595,
                                    0.40887129058065896,
                                    0.14882004565613063,
                                ],
                                [
                                    0.32427850754899445,
                                    0.40887129058065896,
                                    0.11803015621421595,
                                    0.14882004565613063,
                                ],
                                [
                                    0.6103406009279162,
                                    0.014659399072083756,
                                    0.36620436055674976,
                                    0.008795639443250253,
                                ],
                                [
                                    0.6103406009279162,
                                    0.36620436055674976,
                                    0.014659399072083756,
                                    0.008795639443250253,
                                ],
                                [
                                    0.36620436055674976,
                                    0.008795639443250253,
                                    0.6103406009279162,
                                    0.014659399072083756,
                                ],
                                [
                                    0.2978406009279162,
                                    0.17870436055674974,
                                    0.3271593990720838,
                                    0.19629563944325026,
                                ],
                                [
                                    0.2978406009279162,
                                    0.3271593990720838,
                                    0.17870436055674974,
                                    0.19629563944325026,
                                ],
                                [
                                    0.36620436055674976,
                                    0.6103406009279162,
                                    0.008795639443250253,
                                    0.014659399072083756,
                                ],
                                [
                                    0.17870436055674974,
                                    0.19629563944325026,
                                    0.2978406009279162,
                                    0.3271593990720838,
                                ],
                                [
                                    0.17870436055674974,
                                    0.2978406009279162,
                                    0.19629563944325026,
                                    0.3271593990720838,
                                ],
                                [
                                    0.6848142700956583,
                                    0.007494393667552034,
                                    0.3043605097968618,
                                    0.0033308264399278483,
                                ],
                                [
                                    0.6848142700956583,
                                    0.3043605097968618,
                                    0.007494393667552034,
                                    0.0033308264399278483,
                                ],
                                [
                                    0.30436050979686186,
                                    0.003330826439927849,
                                    0.6848142700956583,
                                    0.007494393667552034,
                                ],
                                [
                                    0.15226645393567156,
                                    0.06767367090400704,
                                    0.5400422098275387,
                                    0.2400176653327826,
                                ],
                                [
                                    0.15226645393567156,
                                    0.5400422098275387,
                                    0.06767367090400704,
                                    0.2400176653327826,
                                ],
                                [
                                    0.30436050979686186,
                                    0.6848142700956583,
                                    0.003330826439927849,
                                    0.007494393667552034,
                                ],
                                [
                                    0.06767367090400705,
                                    0.24001766533278263,
                                    0.15226645393567156,
                                    0.5400422098275387,
                                ],
                                [
                                    0.06767367090400705,
                                    0.15226645393567156,
                                    0.24001766533278263,
                                    0.5400422098275387,
                                ],
                                [
                                    0.7366478713020408,
                                    0.0016246094402921807,
                                    0.261151573370936,
                                    0.0005759458867310288,
                                ],
                                [
                                    0.7366478713020408,
                                    0.261151573370936,
                                    0.0016246094402921807,
                                    0.0005759458867310288,
                                ],
                                [
                                    0.261151573370936,
                                    0.0005759458867310288,
                                    0.7366478713020408,
                                    0.0016246094402921807,
                                ],
                                [
                                    0.033007809500953056,
                                    0.011701712202691786,
                                    0.7052646712413799,
                                    0.25002580705497524,
                                ],
                                [
                                    0.033007809500953056,
                                    0.7052646712413799,
                                    0.011701712202691786,
                                    0.25002580705497524,
                                ],
                                [
                                    0.261151573370936,
                                    0.7366478713020408,
                                    0.0005759458867310288,
                                    0.0016246094402921807,
                                ],
                                [
                                    0.011701712202691786,
                                    0.25002580705497524,
                                    0.033007809500953056,
                                    0.7052646712413799,
                                ],
                                [
                                    0.011701712202691786,
                                    0.033007809500953056,
                                    0.25002580705497524,
                                    0.7052646712413799,
                                ],
                                [
                                    0.3991781047882367,
                                    0.1125494144694303,
                                    0.3808817703720847,
                                    0.10739071037024826,
                                ],
                                [
                                    0.3991781047882367,
                                    0.3808817703720847,
                                    0.1125494144694303,
                                    0.10739071037024826,
                                ],
                                [
                                    0.3808817703720847,
                                    0.10739071037024826,
                                    0.3991781047882367,
                                    0.1125494144694303,
                                ],
                                [
                                    0.3751729274411469,
                                    0.35797687068850653,
                                    0.1365545918165201,
                                    0.13029561005382648,
                                ],
                                [
                                    0.3751729274411469,
                                    0.1365545918165201,
                                    0.35797687068850653,
                                    0.13029561005382648,
                                ],
                                [
                                    0.3808817703720847,
                                    0.3991781047882367,
                                    0.10739071037024826,
                                    0.1125494144694303,
                                ],
                                [
                                    0.35797687068850653,
                                    0.13029561005382648,
                                    0.3751729274411469,
                                    0.1365545918165201,
                                ],
                                [
                                    0.35797687068850653,
                                    0.3751729274411469,
                                    0.13029561005382648,
                                    0.1365545918165201,
                                ],
                                [
                                    0.4586940410855832,
                                    0.0989972951512065,
                                    0.3637932583958395,
                                    0.07851540536737091,
                                ],
                                [
                                    0.4586940410855832,
                                    0.3637932583958395,
                                    0.0989972951512065,
                                    0.07851540536737091,
                                ],
                                [
                                    0.36379325839583954,
                                    0.07851540536737092,
                                    0.4586940410855831,
                                    0.09899729515120648,
                                ],
                                [
                                    0.3299982075048587,
                                    0.2617237470294055,
                                    0.227693128731931,
                                    0.1805849167338049,
                                ],
                                [
                                    0.3299982075048587,
                                    0.227693128731931,
                                    0.2617237470294055,
                                    0.1805849167338049,
                                ],
                                [
                                    0.36379325839583954,
                                    0.4586940410855831,
                                    0.07851540536737092,
                                    0.09899729515120648,
                                ],
                                [
                                    0.26172374702940554,
                                    0.18058491673380492,
                                    0.3299982075048586,
                                    0.22769312873193095,
                                ],
                                [
                                    0.26172374702940554,
                                    0.3299982075048586,
                                    0.18058491673380492,
                                    0.22769312873193095,
                                ],
                                [
                                    0.552885829704013,
                                    0.07211417029598702,
                                    0.3317314978224078,
                                    0.043268502177592205,
                                ],
                                [
                                    0.552885829704013,
                                    0.3317314978224078,
                                    0.07211417029598702,
                                    0.043268502177592205,
                                ],
                                [
                                    0.3317314978224078,
                                    0.043268502177592205,
                                    0.552885829704013,
                                    0.07211417029598702,
                                ],
                                [
                                    0.24038582970401295,
                                    0.1442314978224078,
                                    0.38461417029598705,
                                    0.2307685021775922,
                                ],
                                [
                                    0.24038582970401295,
                                    0.38461417029598705,
                                    0.1442314978224078,
                                    0.2307685021775922,
                                ],
                                [
                                    0.3317314978224078,
                                    0.552885829704013,
                                    0.043268502177592205,
                                    0.07211417029598702,
                                ],
                                [
                                    0.1442314978224078,
                                    0.2307685021775922,
                                    0.24038582970401295,
                                    0.38461417029598705,
                                ],
                                [
                                    0.1442314978224078,
                                    0.24038582970401295,
                                    0.2307685021775922,
                                    0.38461417029598705,
                                ],
                                [
                                    0.6554413966570021,
                                    0.03686726710620831,
                                    0.2913059589144169,
                                    0.016385377322372732,
                                ],
                                [
                                    0.6554413966570021,
                                    0.2913059589144169,
                                    0.03686726710620831,
                                    0.016385377322372732,
                                ],
                                [
                                    0.29130595891441696,
                                    0.016385377322372732,
                                    0.6554413966570021,
                                    0.03686726710620831,
                                ],
                                [
                                    0.1228935804970153,
                                    0.05461912002156216,
                                    0.569415083266195,
                                    0.25307221621522746,
                                ],
                                [
                                    0.1228935804970153,
                                    0.569415083266195,
                                    0.05461912002156216,
                                    0.25307221621522746,
                                ],
                                [
                                    0.29130595891441696,
                                    0.6554413966570021,
                                    0.016385377322372732,
                                    0.03686726710620831,
                                ],
                                [
                                    0.054619120021562176,
                                    0.2530722162152275,
                                    0.1228935804970153,
                                    0.569415083266195,
                                ],
                                [
                                    0.054619120021562176,
                                    0.1228935804970153,
                                    0.2530722162152275,
                                    0.569415083266195,
                                ],
                                [
                                    0.730280518639002,
                                    0.007991962103330965,
                                    0.2588942612535181,
                                    0.002833258004148928,
                                ],
                                [
                                    0.730280518639002,
                                    0.2588942612535181,
                                    0.007991962103330965,
                                    0.002833258004148928,
                                ],
                                [
                                    0.2588942612535181,
                                    0.002833258004148928,
                                    0.730280518639002,
                                    0.007991962103330965,
                                ],
                                [
                                    0.026640456837914293,
                                    0.009444400085273896,
                                    0.7116320239044187,
                                    0.2522831191723931,
                                ],
                                [
                                    0.026640456837914293,
                                    0.7116320239044187,
                                    0.009444400085273896,
                                    0.2522831191723931,
                                ],
                                [
                                    0.2588942612535181,
                                    0.730280518639002,
                                    0.002833258004148928,
                                    0.007991962103330965,
                                ],
                                [
                                    0.009444400085273896,
                                    0.2522831191723931,
                                    0.026640456837914293,
                                    0.7116320239044187,
                                ],
                                [
                                    0.009444400085273896,
                                    0.026640456837914293,
                                    0.2522831191723931,
                                    0.7116320239044187,
                                ],
                                [
                                    0.26786634830237843,
                                    0.2438611709552886,
                                    0.2555886902129556,
                                    0.23268379052937738,
                                ],
                                [
                                    0.26786634830237843,
                                    0.2555886902129556,
                                    0.2438611709552886,
                                    0.23268379052937738,
                                ],
                                [
                                    0.2555886902129556,
                                    0.23268379052937738,
                                    0.26786634830237843,
                                    0.2438611709552886,
                                ],
                                [
                                    0.2438611709552886,
                                    0.23268379052937738,
                                    0.26786634830237843,
                                    0.2555886902129556,
                                ],
                                [
                                    0.2438611709552886,
                                    0.26786634830237843,
                                    0.23268379052937738,
                                    0.2555886902129556,
                                ],
                                [
                                    0.2555886902129556,
                                    0.26786634830237843,
                                    0.23268379052937738,
                                    0.2438611709552886,
                                ],
                                [
                                    0.23268379052937738,
                                    0.2555886902129556,
                                    0.2438611709552886,
                                    0.26786634830237843,
                                ],
                                [
                                    0.23268379052937738,
                                    0.2438611709552886,
                                    0.2555886902129556,
                                    0.26786634830237843,
                                ],
                                [
                                    0.3431935849087571,
                                    0.2144977513280326,
                                    0.2721890875648222,
                                    0.1701195761983882,
                                ],
                                [
                                    0.3431935849087571,
                                    0.2721890875648222,
                                    0.2144977513280326,
                                    0.1701195761983882,
                                ],
                                [
                                    0.27218908756482224,
                                    0.17011957619838822,
                                    0.343193584908757,
                                    0.21449775132803253,
                                ],
                                [
                                    0.21449775132803264,
                                    0.17011957619838824,
                                    0.34319358490875707,
                                    0.27218908756482213,
                                ],
                                [
                                    0.21449775132803264,
                                    0.34319358490875707,
                                    0.17011957619838824,
                                    0.27218908756482213,
                                ],
                                [
                                    0.27218908756482224,
                                    0.343193584908757,
                                    0.17011957619838822,
                                    0.21449775132803253,
                                ],
                                [
                                    0.17011957619838827,
                                    0.2721890875648222,
                                    0.2144977513280326,
                                    0.34319358490875695,
                                ],
                                [
                                    0.17011957619838827,
                                    0.2144977513280326,
                                    0.2721890875648222,
                                    0.34319358490875695,
                                ],
                                [0.46875, 0.15625, 0.28125, 0.09375],
                                [0.46875, 0.28125, 0.15625, 0.09375],
                                [0.28125, 0.09375, 0.46875, 0.15625],
                                [0.15625, 0.09375, 0.46875, 0.28125],
                                [0.15625, 0.46875, 0.09375, 0.28125],
                                [0.28125, 0.46875, 0.09375, 0.15625],
                                [0.09375, 0.28125, 0.15625, 0.46875],
                                [0.09375, 0.15625, 0.28125, 0.46875],
                                [
                                    0.6124282399615986,
                                    0.0798804238016118,
                                    0.2721890875648222,
                                    0.03550224867196745,
                                ],
                                [
                                    0.6124282399615986,
                                    0.2721890875648222,
                                    0.0798804238016118,
                                    0.03550224867196745,
                                ],
                                [
                                    0.27218908756482224,
                                    0.035502248671967454,
                                    0.6124282399615986,
                                    0.0798804238016118,
                                ],
                                [
                                    0.0798804238016118,
                                    0.03550224867196745,
                                    0.6124282399615986,
                                    0.2721890875648222,
                                ],
                                [
                                    0.0798804238016118,
                                    0.6124282399615986,
                                    0.03550224867196745,
                                    0.2721890875648222,
                                ],
                                [
                                    0.27218908756482224,
                                    0.6124282399615986,
                                    0.035502248671967454,
                                    0.0798804238016118,
                                ],
                                [
                                    0.035502248671967454,
                                    0.27218908756482224,
                                    0.0798804238016118,
                                    0.6124282399615986,
                                ],
                                [
                                    0.035502248671967454,
                                    0.0798804238016118,
                                    0.27218908756482224,
                                    0.6124282399615986,
                                ],
                                [
                                    0.7209562712717104,
                                    0.017316209470622627,
                                    0.2555886902129556,
                                    0.006138829044711411,
                                ],
                                [
                                    0.7209562712717104,
                                    0.2555886902129556,
                                    0.017316209470622627,
                                    0.006138829044711411,
                                ],
                                [
                                    0.2555886902129556,
                                    0.006138829044711411,
                                    0.7209562712717104,
                                    0.017316209470622627,
                                ],
                                [
                                    0.017316209470622627,
                                    0.006138829044711411,
                                    0.7209562712717104,
                                    0.2555886902129556,
                                ],
                                [
                                    0.017316209470622627,
                                    0.7209562712717104,
                                    0.006138829044711411,
                                    0.2555886902129556,
                                ],
                                [
                                    0.2555886902129556,
                                    0.7209562712717104,
                                    0.006138829044711411,
                                    0.017316209470622627,
                                ],
                                [
                                    0.006138829044711411,
                                    0.2555886902129556,
                                    0.017316209470622627,
                                    0.7209562712717104,
                                ],
                                [
                                    0.006138829044711411,
                                    0.017316209470622627,
                                    0.2555886902129556,
                                    0.7209562712717104,
                                ],
                                [
                                    0.13655459181652016,
                                    0.37517292744114683,
                                    0.13029561005382653,
                                    0.3579768706885065,
                                ],
                                [
                                    0.13655459181652016,
                                    0.13029561005382653,
                                    0.37517292744114683,
                                    0.3579768706885065,
                                ],
                                [
                                    0.13029561005382653,
                                    0.3579768706885065,
                                    0.13655459181652016,
                                    0.37517292744114683,
                                ],
                                [
                                    0.11254941446943033,
                                    0.10739071037024829,
                                    0.3991781047882367,
                                    0.3808817703720847,
                                ],
                                [
                                    0.11254941446943033,
                                    0.3991781047882367,
                                    0.10739071037024829,
                                    0.3808817703720847,
                                ],
                                [
                                    0.13029561005382653,
                                    0.13655459181652016,
                                    0.3579768706885065,
                                    0.37517292744114683,
                                ],
                                [
                                    0.10739071037024829,
                                    0.3808817703720847,
                                    0.11254941446943033,
                                    0.3991781047882367,
                                ],
                                [
                                    0.10739071037024829,
                                    0.11254941446943033,
                                    0.3808817703720847,
                                    0.3991781047882367,
                                ],
                                [
                                    0.22769312873193107,
                                    0.3299982075048586,
                                    0.18058491673380495,
                                    0.26172374702940543,
                                ],
                                [
                                    0.22769312873193107,
                                    0.18058491673380495,
                                    0.3299982075048586,
                                    0.26172374702940543,
                                ],
                                [
                                    0.18058491673380495,
                                    0.2617237470294055,
                                    0.22769312873193104,
                                    0.32999820750485853,
                                ],
                                [
                                    0.09899729515120655,
                                    0.07851540536737095,
                                    0.45869404108558315,
                                    0.3637932583958394,
                                ],
                                [
                                    0.09899729515120655,
                                    0.45869404108558315,
                                    0.07851540536737095,
                                    0.3637932583958394,
                                ],
                                [
                                    0.18058491673380495,
                                    0.22769312873193104,
                                    0.2617237470294055,
                                    0.32999820750485853,
                                ],
                                [
                                    0.07851540536737096,
                                    0.3637932583958395,
                                    0.09899729515120652,
                                    0.45869404108558304,
                                ],
                                [
                                    0.07851540536737096,
                                    0.09899729515120652,
                                    0.3637932583958395,
                                    0.45869404108558304,
                                ],
                                [
                                    0.38461417029598705,
                                    0.24038582970401295,
                                    0.2307685021775922,
                                    0.1442314978224078,
                                ],
                                [
                                    0.38461417029598705,
                                    0.2307685021775922,
                                    0.24038582970401295,
                                    0.1442314978224078,
                                ],
                                [
                                    0.2307685021775922,
                                    0.1442314978224078,
                                    0.38461417029598705,
                                    0.24038582970401295,
                                ],
                                [
                                    0.07211417029598703,
                                    0.04326850217759222,
                                    0.552885829704013,
                                    0.3317314978224078,
                                ],
                                [
                                    0.07211417029598703,
                                    0.552885829704013,
                                    0.04326850217759222,
                                    0.3317314978224078,
                                ],
                                [
                                    0.2307685021775922,
                                    0.38461417029598705,
                                    0.1442314978224078,
                                    0.24038582970401295,
                                ],
                                [
                                    0.04326850217759222,
                                    0.3317314978224078,
                                    0.07211417029598703,
                                    0.552885829704013,
                                ],
                                [
                                    0.04326850217759222,
                                    0.07211417029598703,
                                    0.3317314978224078,
                                    0.552885829704013,
                                ],
                                [
                                    0.569415083266195,
                                    0.12289358049701529,
                                    0.25307221621522746,
                                    0.054619120021562155,
                                ],
                                [
                                    0.569415083266195,
                                    0.25307221621522746,
                                    0.12289358049701529,
                                    0.054619120021562155,
                                ],
                                [
                                    0.2530722162152275,
                                    0.05461912002156217,
                                    0.569415083266195,
                                    0.12289358049701529,
                                ],
                                [
                                    0.036867267106208294,
                                    0.016385377322372725,
                                    0.6554413966570021,
                                    0.2913059589144169,
                                ],
                                [
                                    0.036867267106208294,
                                    0.6554413966570021,
                                    0.016385377322372725,
                                    0.2913059589144169,
                                ],
                                [
                                    0.2530722162152275,
                                    0.569415083266195,
                                    0.05461912002156217,
                                    0.12289358049701529,
                                ],
                                [
                                    0.01638537732237273,
                                    0.29130595891441696,
                                    0.036867267106208294,
                                    0.6554413966570021,
                                ],
                                [
                                    0.01638537732237273,
                                    0.036867267106208294,
                                    0.29130595891441696,
                                    0.6554413966570021,
                                ],
                                [
                                    0.7116320239044187,
                                    0.026640456837914283,
                                    0.2522831191723931,
                                    0.009444400085273892,
                                ],
                                [
                                    0.7116320239044187,
                                    0.2522831191723931,
                                    0.026640456837914283,
                                    0.009444400085273892,
                                ],
                                [
                                    0.2522831191723931,
                                    0.009444400085273892,
                                    0.7116320239044187,
                                    0.026640456837914283,
                                ],
                                [
                                    0.007991962103330957,
                                    0.002833258004148925,
                                    0.730280518639002,
                                    0.2588942612535181,
                                ],
                                [
                                    0.007991962103330957,
                                    0.730280518639002,
                                    0.002833258004148925,
                                    0.2588942612535181,
                                ],
                                [
                                    0.2522831191723931,
                                    0.7116320239044187,
                                    0.009444400085273892,
                                    0.026640456837914283,
                                ],
                                [
                                    0.002833258004148925,
                                    0.2588942612535181,
                                    0.007991962103330957,
                                    0.730280518639002,
                                ],
                                [
                                    0.002833258004148925,
                                    0.007991962103330957,
                                    0.2588942612535181,
                                    0.730280518639002,
                                ],
                                [
                                    0.04688426997569284,
                                    0.4648432492819742,
                                    0.044735328758620074,
                                    0.4435371519837129,
                                ],
                                [
                                    0.04688426997569284,
                                    0.044735328758620074,
                                    0.4648432492819742,
                                    0.4435371519837129,
                                ],
                                [
                                    0.044735328758620074,
                                    0.4435371519837129,
                                    0.04688426997569284,
                                    0.4648432492819742,
                                ],
                                [
                                    0.022879092628602996,
                                    0.021830429075041843,
                                    0.488848426629064,
                                    0.46644205166729114,
                                ],
                                [
                                    0.022879092628602996,
                                    0.488848426629064,
                                    0.021830429075041843,
                                    0.46644205166729114,
                                ],
                                [
                                    0.044735328758620074,
                                    0.04688426997569284,
                                    0.4435371519837129,
                                    0.4648432492819742,
                                ],
                                [
                                    0.021830429075041843,
                                    0.46644205166729114,
                                    0.022879092628602996,
                                    0.488848426629064,
                                ],
                                [
                                    0.021830429075041843,
                                    0.022879092628602996,
                                    0.46644205166729114,
                                    0.488848426629064,
                                ],
                                [
                                    0.14882004565613072,
                                    0.40887129058065896,
                                    0.11803015621421599,
                                    0.3242785075489944,
                                ],
                                [
                                    0.14882004565613072,
                                    0.11803015621421599,
                                    0.40887129058065896,
                                    0.3242785075489944,
                                ],
                                [
                                    0.118030156214216,
                                    0.32427850754899445,
                                    0.1488200456561307,
                                    0.40887129058065885,
                                ],
                                [
                                    0.020124212075406194,
                                    0.015960644847782,
                                    0.5375671241613835,
                                    0.4263480189154284,
                                ],
                                [
                                    0.020124212075406194,
                                    0.5375671241613835,
                                    0.015960644847782,
                                    0.4263480189154284,
                                ],
                                [
                                    0.118030156214216,
                                    0.1488200456561307,
                                    0.32427850754899445,
                                    0.40887129058065885,
                                ],
                                [
                                    0.015960644847782,
                                    0.42634801891542845,
                                    0.02012421207540619,
                                    0.5375671241613834,
                                ],
                                [
                                    0.015960644847782,
                                    0.02012421207540619,
                                    0.42634801891542845,
                                    0.5375671241613834,
                                ],
                                [
                                    0.3271593990720838,
                                    0.2978406009279162,
                                    0.19629563944325026,
                                    0.17870436055674974,
                                ],
                                [
                                    0.3271593990720838,
                                    0.19629563944325026,
                                    0.2978406009279162,
                                    0.17870436055674974,
                                ],
                                [
                                    0.19629563944325026,
                                    0.17870436055674974,
                                    0.3271593990720838,
                                    0.2978406009279162,
                                ],
                                [
                                    0.014659399072083773,
                                    0.008795639443250264,
                                    0.6103406009279162,
                                    0.36620436055674976,
                                ],
                                [
                                    0.014659399072083773,
                                    0.6103406009279162,
                                    0.008795639443250264,
                                    0.36620436055674976,
                                ],
                                [
                                    0.19629563944325026,
                                    0.3271593990720838,
                                    0.17870436055674974,
                                    0.2978406009279162,
                                ],
                                [
                                    0.008795639443250264,
                                    0.36620436055674976,
                                    0.014659399072083773,
                                    0.6103406009279162,
                                ],
                                [
                                    0.008795639443250264,
                                    0.014659399072083773,
                                    0.36620436055674976,
                                    0.6103406009279162,
                                ],
                                [
                                    0.5400422098275387,
                                    0.15226645393567156,
                                    0.2400176653327826,
                                    0.06767367090400704,
                                ],
                                [
                                    0.5400422098275387,
                                    0.2400176653327826,
                                    0.15226645393567156,
                                    0.06767367090400704,
                                ],
                                [
                                    0.24001766533278263,
                                    0.06767367090400705,
                                    0.5400422098275387,
                                    0.15226645393567156,
                                ],
                                [
                                    0.007494393667552034,
                                    0.0033308264399278483,
                                    0.6848142700956583,
                                    0.3043605097968618,
                                ],
                                [
                                    0.007494393667552034,
                                    0.6848142700956583,
                                    0.0033308264399278483,
                                    0.3043605097968618,
                                ],
                                [
                                    0.24001766533278263,
                                    0.5400422098275387,
                                    0.06767367090400705,
                                    0.15226645393567156,
                                ],
                                [
                                    0.003330826439927849,
                                    0.30436050979686186,
                                    0.007494393667552034,
                                    0.6848142700956583,
                                ],
                                [
                                    0.003330826439927849,
                                    0.007494393667552034,
                                    0.30436050979686186,
                                    0.6848142700956583,
                                ],
                                [
                                    0.7052646712413799,
                                    0.03300780950095307,
                                    0.25002580705497524,
                                    0.011701712202691792,
                                ],
                                [
                                    0.7052646712413799,
                                    0.25002580705497524,
                                    0.03300780950095307,
                                    0.011701712202691792,
                                ],
                                [
                                    0.25002580705497524,
                                    0.011701712202691792,
                                    0.7052646712413799,
                                    0.03300780950095307,
                                ],
                                [
                                    0.0016246094402921993,
                                    0.0005759458867310354,
                                    0.7366478713020408,
                                    0.261151573370936,
                                ],
                                [
                                    0.0016246094402921993,
                                    0.7366478713020408,
                                    0.0005759458867310354,
                                    0.261151573370936,
                                ],
                                [
                                    0.25002580705497524,
                                    0.7052646712413799,
                                    0.011701712202691792,
                                    0.03300780950095307,
                                ],
                                [
                                    0.0005759458867310354,
                                    0.261151573370936,
                                    0.0016246094402921993,
                                    0.7366478713020408,
                                ],
                                [
                                    0.0005759458867310354,
                                    0.0016246094402921993,
                                    0.261151573370936,
                                    0.7366478713020408,
                                ],
                                [
                                    0.23768369686349844,
                                    0.011124076545254165,
                                    0.7176067814328567,
                                    0.033585445158390646,
                                ],
                                [
                                    0.23768369686349844,
                                    0.7176067814328567,
                                    0.011124076545254165,
                                    0.033585445158390646,
                                ],
                                [
                                    0.21527732190172555,
                                    0.010075412991693013,
                                    0.7400131563946296,
                                    0.0346341087119518,
                                ],
                                [
                                    0.22601210504706487,
                                    0.6823682962186224,
                                    0.022795668361687744,
                                    0.06882393037262509,
                                ],
                                [
                                    0.22601210504706487,
                                    0.022795668361687744,
                                    0.6823682962186224,
                                    0.06882393037262509,
                                ],
                                [
                                    0.21527732190172555,
                                    0.7400131563946296,
                                    0.010075412991693013,
                                    0.0346341087119518,
                                ],
                                [
                                    0.20470600774880357,
                                    0.020646727144614987,
                                    0.7036743935168837,
                                    0.07097287158969784,
                                ],
                                [
                                    0.20470600774880357,
                                    0.7036743935168837,
                                    0.020646727144614987,
                                    0.07097287158969784,
                                ],
                                [
                                    0.30799180055106806,
                                    0.011529894655379177,
                                    0.6559233425257438,
                                    0.02455496226780896,
                                ],
                                [
                                    0.30799180055106806,
                                    0.6559233425257438,
                                    0.011529894655379177,
                                    0.02455496226780896,
                                ],
                                [
                                    0.196772695305113,
                                    0.007366327427754992,
                                    0.7671424477716988,
                                    0.028718529495433145,
                                ],
                                [
                                    0.23425726633865143,
                                    0.49889253179100196,
                                    0.0852644288677958,
                                    0.18158577300255077,
                                ],
                                [
                                    0.23425726633865143,
                                    0.0852644288677958,
                                    0.49889253179100196,
                                    0.18158577300255077,
                                ],
                                [
                                    0.196772695305113,
                                    0.7671424477716988,
                                    0.007366327427754992,
                                    0.028718529495433145,
                                ],
                                [
                                    0.1496644833069869,
                                    0.0544745394258811,
                                    0.5834853148226665,
                                    0.21237566244446549,
                                ],
                                [
                                    0.1496644833069869,
                                    0.5834853148226665,
                                    0.0544745394258811,
                                    0.21237566244446549,
                                ],
                                [
                                    0.41315079154123036,
                                    0.009923217169138457,
                                    0.5633941699434356,
                                    0.013531821346195553,
                                ],
                                [
                                    0.41315079154123036,
                                    0.5633941699434356,
                                    0.009923217169138457,
                                    0.013531821346195553,
                                ],
                                [
                                    0.16901455117006386,
                                    0.004059457540304954,
                                    0.8075304103146022,
                                    0.019395580975029053,
                                ],
                                [
                                    0.20161378718604595,
                                    0.27493117429862,
                                    0.22146022152432288,
                                    0.30199481699101116,
                                ],
                                [
                                    0.20161378718604595,
                                    0.22146022152432288,
                                    0.27493117429862,
                                    0.30199481699101116,
                                ],
                                [
                                    0.16901455117006386,
                                    0.8075304103146022,
                                    0.004059457540304954,
                                    0.019395580975029053,
                                ],
                                [
                                    0.08247754681487945,
                                    0.09059646189548937,
                                    0.3940674146697865,
                                    0.43285857661984467,
                                ],
                                [
                                    0.08247754681487945,
                                    0.3940674146697865,
                                    0.09059646189548937,
                                    0.43285857661984467,
                                ],
                                [
                                    0.5209254763619282,
                                    0.005700845852362317,
                                    0.4682493035305919,
                                    0.005124374255117565,
                                ],
                                [
                                    0.5209254763619282,
                                    0.4682493035305919,
                                    0.005700845852362317,
                                    0.005124374255117565,
                                ],
                                [
                                    0.14047171606313164,
                                    0.0015372786247381317,
                                    0.8487030638293885,
                                    0.00928794148274175,
                                ],
                                [
                                    0.11582625905167188,
                                    0.10411386578800674,
                                    0.41080006316261863,
                                    0.36925981199770275,
                                ],
                                [
                                    0.11582625905167188,
                                    0.41080006316261863,
                                    0.10411386578800674,
                                    0.36925981199770275,
                                ],
                                [
                                    0.14047171606313164,
                                    0.8487030638293885,
                                    0.0015372786247381317,
                                    0.00928794148274175,
                                ],
                                [
                                    0.031233476020007332,
                                    0.11077551866786242,
                                    0.18870664881967128,
                                    0.669284356492459,
                                ],
                                [
                                    0.031233476020007332,
                                    0.18870664881967128,
                                    0.11077551866786242,
                                    0.669284356492459,
                                ],
                                [
                                    0.5960257637559793,
                                    0.0013144802560059179,
                                    0.40177368091699756,
                                    0.0008860750710172918,
                                ],
                                [
                                    0.5960257637559793,
                                    0.40177368091699756,
                                    0.0013144802560059179,
                                    0.0008860750710172918,
                                ],
                                [
                                    0.12052946582487442,
                                    0.00026581670244476586,
                                    0.8772699788481023,
                                    0.0019347386245784437,
                                ],
                                [
                                    0.026706796604114354,
                                    0.018002725099530485,
                                    0.5706334474078708,
                                    0.38465703088848435,
                                ],
                                [
                                    0.026706796604114354,
                                    0.5706334474078708,
                                    0.018002725099530485,
                                    0.38465703088848435,
                                ],
                                [
                                    0.12052946582487442,
                                    0.8772699788481023,
                                    0.00026581670244476586,
                                    0.0019347386245784437,
                                ],
                                [
                                    0.005400699305853088,
                                    0.1153945832214661,
                                    0.03930882239779175,
                                    0.839895895074889,
                                ],
                                [
                                    0.005400699305853088,
                                    0.03930882239779175,
                                    0.1153945832214661,
                                    0.839895895074889,
                                ],
                                [
                                    0.19408496066414907,
                                    0.0547228127446035,
                                    0.5859749144961723,
                                    0.16521731209507506,
                                ],
                                [
                                    0.19408496066414907,
                                    0.5859749144961723,
                                    0.0547228127446035,
                                    0.16521731209507506,
                                ],
                                [
                                    0.17578862624799707,
                                    0.04956410864542147,
                                    0.6042712489123243,
                                    0.1703760161942571,
                                ],
                                [
                                    0.18241336884771553,
                                    0.5507364292819379,
                                    0.06639440456103708,
                                    0.2004557973093095,
                                ],
                                [
                                    0.18241336884771553,
                                    0.06639440456103708,
                                    0.5507364292819379,
                                    0.2004557973093095,
                                ],
                                [
                                    0.17578862624799707,
                                    0.6042712489123243,
                                    0.04956410864542147,
                                    0.1703760161942571,
                                ],
                                [
                                    0.16521731209507512,
                                    0.06013542279834344,
                                    0.5679324860345782,
                                    0.20671477907200314,
                                ],
                                [
                                    0.16521731209507512,
                                    0.5679324860345782,
                                    0.06013542279834344,
                                    0.20671477907200314,
                                ],
                                [
                                    0.262802536216077,
                                    0.056719158990370236,
                                    0.5596847632653457,
                                    0.12079354152820716,
                                ],
                                [
                                    0.262802536216077,
                                    0.5596847632653457,
                                    0.056719158990370236,
                                    0.12079354152820716,
                                ],
                                [
                                    0.16790175352633332,
                                    0.03623726920653466,
                                    0.6545855459550893,
                                    0.14127543131204273,
                                ],
                                [
                                    0.18906800200366036,
                                    0.40265395253060376,
                                    0.13045369320278688,
                                    0.277824352262949,
                                ],
                                [
                                    0.18906800200366036,
                                    0.13045369320278688,
                                    0.40265395253060376,
                                    0.277824352262949,
                                ],
                                [
                                    0.16790175352633332,
                                    0.6545855459550893,
                                    0.03623726920653466,
                                    0.14127543131204273,
                                ],
                                [
                                    0.12079354152820722,
                                    0.08334548120466077,
                                    0.4709284130060569,
                                    0.3249325642610751,
                                ],
                                [
                                    0.12079354152820722,
                                    0.4709284130060569,
                                    0.08334548120466077,
                                    0.3249325642610751,
                                ],
                                [
                                    0.3742585989312561,
                                    0.04881540977911269,
                                    0.5103587285951646,
                                    0.06656726269446653,
                                ],
                                [
                                    0.3742585989312561,
                                    0.5103587285951646,
                                    0.04881540977911269,
                                    0.06656726269446653,
                                ],
                                [
                                    0.15310426704965094,
                                    0.019969741660717882,
                                    0.7315130604767698,
                                    0.09541293081286134,
                                ],
                                [
                                    0.16272159457607172,
                                    0.22189573295034903,
                                    0.2603524141342971,
                                    0.35503025833928215,
                                ],
                                [
                                    0.16272159457607172,
                                    0.2603524141342971,
                                    0.22189573295034903,
                                    0.35503025833928215,
                                ],
                                [
                                    0.15310426704965094,
                                    0.7315130604767698,
                                    0.019969741660717882,
                                    0.09541293081286134,
                                ],
                                [
                                    0.06656726269446653,
                                    0.10650674601590229,
                                    0.31805006483195425,
                                    0.508875926457677,
                                ],
                                [
                                    0.06656726269446653,
                                    0.31805006483195425,
                                    0.10650674601590229,
                                    0.508875926457677,
                                ],
                                [
                                    0.49858207793068154,
                                    0.028044244283608962,
                                    0.44816527764073744,
                                    0.02520840014497208,
                                ],
                                [
                                    0.49858207793068154,
                                    0.44816527764073744,
                                    0.028044244283608962,
                                    0.02520840014497208,
                                ],
                                [
                                    0.13444664018809638,
                                    0.007562354499773382,
                                    0.8123007153833226,
                                    0.04569028992880766,
                                ],
                                [
                                    0.09348286062042524,
                                    0.08402983989815224,
                                    0.4331434615938653,
                                    0.3893438378875572,
                                ],
                                [
                                    0.09348286062042524,
                                    0.4331434615938653,
                                    0.08402983989815224,
                                    0.3893438378875572,
                                ],
                                [
                                    0.13444664018809638,
                                    0.8123007153833226,
                                    0.007562354499773382,
                                    0.04569028992880766,
                                ],
                                [
                                    0.025208400144972085,
                                    0.11680059454289768,
                                    0.1523043003736054,
                                    0.7056867049385248,
                                ],
                                [
                                    0.025208400144972085,
                                    0.1523043003736054,
                                    0.11680059454289768,
                                    0.7056867049385248,
                                ],
                                [
                                    0.5908739043914997,
                                    0.006466339620485487,
                                    0.39830087550102045,
                                    0.004358880486994406,
                                ],
                                [
                                    0.5908739043914997,
                                    0.39830087550102045,
                                    0.006466339620485487,
                                    0.004358880486994406,
                                ],
                                [
                                    0.11948764700601575,
                                    0.0013076355213034504,
                                    0.8696871328865043,
                                    0.009517584586176443,
                                ],
                                [
                                    0.021554937239634805,
                                    0.014529919683553385,
                                    0.5757853067723504,
                                    0.38812983630446146,
                                ],
                                [
                                    0.021554937239634805,
                                    0.5757853067723504,
                                    0.014529919683553385,
                                    0.38812983630446146,
                                ],
                                [
                                    0.11948764700601575,
                                    0.8696871328865043,
                                    0.0013076355213034504,
                                    0.009517584586176443,
                                ],
                                [
                                    0.004358880486994407,
                                    0.11643640204032478,
                                    0.031725976436193785,
                                    0.847478741036487,
                                ],
                                [
                                    0.004358880486994407,
                                    0.031725976436193785,
                                    0.11643640204032478,
                                    0.847478741036487,
                                ],
                                [
                                    0.13023968261259308,
                                    0.1185680907961595,
                                    0.3932153559027409,
                                    0.3579768706885065,
                                ],
                                [
                                    0.13023968261259308,
                                    0.3932153559027409,
                                    0.1185680907961595,
                                    0.3579768706885065,
                                ],
                                [
                                    0.11796202452317027,
                                    0.10739071037024829,
                                    0.40549301399216375,
                                    0.3691542511144177,
                                ],
                                [
                                    0.1185680907961595,
                                    0.3579768706885065,
                                    0.13023968261259308,
                                    0.3932153559027409,
                                ],
                                [
                                    0.1185680907961595,
                                    0.13023968261259308,
                                    0.3579768706885065,
                                    0.3932153559027409,
                                ],
                                [
                                    0.11796202452317027,
                                    0.40549301399216375,
                                    0.10739071037024829,
                                    0.3691542511144177,
                                ],
                                [
                                    0.10739071037024829,
                                    0.11796202452317027,
                                    0.3691542511144177,
                                    0.40549301399216375,
                                ],
                                [
                                    0.10739071037024829,
                                    0.3691542511144177,
                                    0.11796202452317027,
                                    0.40549301399216375,
                                ],
                                [
                                    0.19662811470943195,
                                    0.1228935804970153,
                                    0.41875455776414733,
                                    0.26172374702940543,
                                ],
                                [
                                    0.19662811470943195,
                                    0.41875455776414733,
                                    0.1228935804970153,
                                    0.26172374702940543,
                                ],
                                [
                                    0.12562361736549704,
                                    0.07851540536737094,
                                    0.4897590551080822,
                                    0.3061019221590498,
                                ],
                                [
                                    0.12289358049701533,
                                    0.26172374702940554,
                                    0.1966281147094319,
                                    0.4187545577641472,
                                ],
                                [
                                    0.12289358049701533,
                                    0.1966281147094319,
                                    0.26172374702940554,
                                    0.4187545577641472,
                                ],
                                [
                                    0.12562361736549704,
                                    0.4897590551080822,
                                    0.07851540536737094,
                                    0.3061019221590498,
                                ],
                                [
                                    0.07851540536737096,
                                    0.12562361736549704,
                                    0.3061019221590499,
                                    0.4897590551080821,
                                ],
                                [
                                    0.07851540536737096,
                                    0.3061019221590499,
                                    0.12562361736549704,
                                    0.4897590551080821,
                                ],
                                [
                                    0.3173055065327766,
                                    0.1057685021775922,
                                    0.4326944934672234,
                                    0.1442314978224078,
                                ],
                                [
                                    0.3173055065327766,
                                    0.4326944934672234,
                                    0.1057685021775922,
                                    0.1442314978224078,
                                ],
                                [
                                    0.12980550653277662,
                                    0.043268502177592205,
                                    0.6201944934672234,
                                    0.2067314978224078,
                                ],
                                [
                                    0.1057685021775922,
                                    0.1442314978224078,
                                    0.3173055065327766,
                                    0.4326944934672234,
                                ],
                                [
                                    0.1057685021775922,
                                    0.3173055065327766,
                                    0.1442314978224078,
                                    0.4326944934672234,
                                ],
                                [
                                    0.12980550653277662,
                                    0.6201944934672234,
                                    0.043268502177592205,
                                    0.2067314978224078,
                                ],
                                [
                                    0.043268502177592205,
                                    0.12980550653277662,
                                    0.2067314978224078,
                                    0.6201944934672234,
                                ],
                                [
                                    0.043268502177592205,
                                    0.2067314978224078,
                                    0.12980550653277662,
                                    0.6201944934672234,
                                ],
                                [
                                    0.4658627697622734,
                                    0.060763552452017096,
                                    0.41875455776414733,
                                    0.054619120021562155,
                                ],
                                [
                                    0.4658627697622734,
                                    0.41875455776414733,
                                    0.060763552452017096,
                                    0.054619120021562155,
                                ],
                                [
                                    0.12562361736549701,
                                    0.016385377322372732,
                                    0.7589937101609238,
                                    0.09899729515120652,
                                ],
                                [
                                    0.060763552452017096,
                                    0.054619120021562155,
                                    0.4658627697622734,
                                    0.41875455776414733,
                                ],
                                [
                                    0.060763552452017096,
                                    0.4658627697622734,
                                    0.054619120021562155,
                                    0.41875455776414733,
                                ],
                                [
                                    0.12562361736549701,
                                    0.7589937101609238,
                                    0.016385377322372732,
                                    0.09899729515120652,
                                ],
                                [
                                    0.016385377322372732,
                                    0.12562361736549701,
                                    0.09899729515120652,
                                    0.7589937101609238,
                                ],
                                [
                                    0.016385377322372732,
                                    0.09899729515120652,
                                    0.12562361736549701,
                                    0.7589937101609238,
                                ],
                                [
                                    0.583329605581925,
                                    0.014010638430060144,
                                    0.3932153559027409,
                                    0.009444400085273892,
                                ],
                                [
                                    0.583329605581925,
                                    0.3932153559027409,
                                    0.014010638430060144,
                                    0.009444400085273892,
                                ],
                                [
                                    0.11796202452317027,
                                    0.002833258004148928,
                                    0.8585829369614957,
                                    0.020621780511185107,
                                ],
                                [
                                    0.014010638430060144,
                                    0.009444400085273892,
                                    0.583329605581925,
                                    0.3932153559027409,
                                ],
                                [
                                    0.014010638430060144,
                                    0.583329605581925,
                                    0.009444400085273892,
                                    0.3932153559027409,
                                ],
                                [
                                    0.11796202452317027,
                                    0.8585829369614957,
                                    0.002833258004148928,
                                    0.020621780511185107,
                                ],
                                [
                                    0.002833258004148928,
                                    0.11796202452317027,
                                    0.020621780511185107,
                                    0.8585829369614957,
                                ],
                                [
                                    0.002833258004148928,
                                    0.020621780511185107,
                                    0.11796202452317027,
                                    0.8585829369614957,
                                ],
                                [
                                    0.06639440456103711,
                                    0.1824133688477155,
                                    0.2004557973093096,
                                    0.5507364292819378,
                                ],
                                [
                                    0.06639440456103711,
                                    0.2004557973093096,
                                    0.1824133688477155,
                                    0.5507364292819378,
                                ],
                                [
                                    0.06013542279834346,
                                    0.1652173120950751,
                                    0.20671477907200322,
                                    0.5679324860345782,
                                ],
                                [
                                    0.05472281274460351,
                                    0.1652173120950751,
                                    0.19408496066414907,
                                    0.5859749144961723,
                                ],
                                [
                                    0.05472281274460351,
                                    0.19408496066414907,
                                    0.1652173120950751,
                                    0.5859749144961723,
                                ],
                                [
                                    0.06013542279834346,
                                    0.20671477907200322,
                                    0.1652173120950751,
                                    0.5679324860345782,
                                ],
                                [
                                    0.049564108645421476,
                                    0.17578862624799707,
                                    0.17037601619425713,
                                    0.6042712489123243,
                                ],
                                [
                                    0.049564108645421476,
                                    0.17037601619425713,
                                    0.17578862624799707,
                                    0.6042712489123243,
                                ],
                                [
                                    0.1304536932027869,
                                    0.18906800200366033,
                                    0.2778243522629491,
                                    0.40265395253060365,
                                ],
                                [
                                    0.1304536932027869,
                                    0.2778243522629491,
                                    0.18906800200366033,
                                    0.40265395253060365,
                                ],
                                [
                                    0.08334548120466079,
                                    0.1207935415282072,
                                    0.3249325642610752,
                                    0.4709284130060568,
                                ],
                                [
                                    0.056719158990370264,
                                    0.12079354152820722,
                                    0.26280253621607697,
                                    0.5596847632653456,
                                ],
                                [
                                    0.056719158990370264,
                                    0.26280253621607697,
                                    0.12079354152820722,
                                    0.5596847632653456,
                                ],
                                [
                                    0.08334548120466079,
                                    0.3249325642610752,
                                    0.1207935415282072,
                                    0.4709284130060568,
                                ],
                                [
                                    0.036237269206534674,
                                    0.16790175352633332,
                                    0.14127543131204282,
                                    0.6545855459550892,
                                ],
                                [
                                    0.036237269206534674,
                                    0.14127543131204282,
                                    0.16790175352633332,
                                    0.6545855459550892,
                                ],
                                [
                                    0.2603524141342971,
                                    0.16272159457607172,
                                    0.35503025833928215,
                                    0.22189573295034903,
                                ],
                                [
                                    0.2603524141342971,
                                    0.35503025833928215,
                                    0.16272159457607172,
                                    0.22189573295034903,
                                ],
                                [
                                    0.10650674601590229,
                                    0.06656726269446653,
                                    0.508875926457677,
                                    0.31805006483195425,
                                ],
                                [
                                    0.0488154097791127,
                                    0.06656726269446656,
                                    0.3742585989312561,
                                    0.5103587285951646,
                                ],
                                [
                                    0.0488154097791127,
                                    0.3742585989312561,
                                    0.06656726269446656,
                                    0.5103587285951646,
                                ],
                                [
                                    0.10650674601590229,
                                    0.508875926457677,
                                    0.06656726269446653,
                                    0.31805006483195425,
                                ],
                                [
                                    0.01996974166071789,
                                    0.15310426704965094,
                                    0.09541293081286137,
                                    0.7315130604767698,
                                ],
                                [
                                    0.01996974166071789,
                                    0.09541293081286137,
                                    0.15310426704965094,
                                    0.7315130604767698,
                                ],
                                [
                                    0.4331434615938653,
                                    0.09348286062042523,
                                    0.3893438378875572,
                                    0.08402983989815223,
                                ],
                                [
                                    0.4331434615938653,
                                    0.3893438378875572,
                                    0.09348286062042523,
                                    0.08402983989815223,
                                ],
                                [
                                    0.11680059454289768,
                                    0.025208400144972082,
                                    0.7056867049385248,
                                    0.15230430037360537,
                                ],
                                [
                                    0.02804424428360895,
                                    0.025208400144972068,
                                    0.49858207793068154,
                                    0.44816527764073744,
                                ],
                                [
                                    0.02804424428360895,
                                    0.49858207793068154,
                                    0.025208400144972068,
                                    0.44816527764073744,
                                ],
                                [
                                    0.11680059454289768,
                                    0.7056867049385248,
                                    0.025208400144972082,
                                    0.15230430037360537,
                                ],
                                [
                                    0.007562354499773379,
                                    0.13444664018809638,
                                    0.045690289928807644,
                                    0.8123007153833226,
                                ],
                                [
                                    0.007562354499773379,
                                    0.045690289928807644,
                                    0.13444664018809638,
                                    0.8123007153833226,
                                ],
                                [
                                    0.5757853067723504,
                                    0.021554937239634798,
                                    0.38812983630446146,
                                    0.01452991968355338,
                                ],
                                [
                                    0.5757853067723504,
                                    0.38812983630446146,
                                    0.021554937239634798,
                                    0.01452991968355338,
                                ],
                                [
                                    0.11643640204032478,
                                    0.004358880486994406,
                                    0.847478741036487,
                                    0.03172597643619377,
                                ],
                                [
                                    0.006466339620485481,
                                    0.004358880486994401,
                                    0.5908739043914997,
                                    0.39830087550102045,
                                ],
                                [
                                    0.006466339620485481,
                                    0.5908739043914997,
                                    0.004358880486994401,
                                    0.39830087550102045,
                                ],
                                [
                                    0.11643640204032478,
                                    0.847478741036487,
                                    0.004358880486994406,
                                    0.03172597643619377,
                                ],
                                [
                                    0.0013076355213034491,
                                    0.11948764700601575,
                                    0.009517584586176433,
                                    0.8696871328865043,
                                ],
                                [
                                    0.0013076355213034491,
                                    0.009517584586176433,
                                    0.11948764700601575,
                                    0.8696871328865043,
                                ],
                                [
                                    0.022795668361687765,
                                    0.22601210504706484,
                                    0.06882393037262514,
                                    0.6823682962186223,
                                ],
                                [
                                    0.022795668361687765,
                                    0.06882393037262514,
                                    0.22601210504706484,
                                    0.6823682962186223,
                                ],
                                [
                                    0.020646727144615004,
                                    0.20470600774880354,
                                    0.07097287158969791,
                                    0.7036743935168835,
                                ],
                                [
                                    0.011124076545254172,
                                    0.03358544515839067,
                                    0.23768369686349844,
                                    0.7176067814328567,
                                ],
                                [
                                    0.011124076545254172,
                                    0.23768369686349844,
                                    0.03358544515839067,
                                    0.7176067814328567,
                                ],
                                [
                                    0.020646727144615004,
                                    0.07097287158969791,
                                    0.20470600774880354,
                                    0.7036743935168835,
                                ],
                                [
                                    0.010075412991693018,
                                    0.21527732190172555,
                                    0.03463410871195182,
                                    0.7400131563946296,
                                ],
                                [
                                    0.010075412991693018,
                                    0.03463410871195182,
                                    0.21527732190172555,
                                    0.7400131563946296,
                                ],
                                [
                                    0.08526442886779584,
                                    0.2342572663386514,
                                    0.18158577300255085,
                                    0.4988925317910019,
                                ],
                                [
                                    0.08526442886779584,
                                    0.18158577300255085,
                                    0.2342572663386514,
                                    0.4988925317910019,
                                ],
                                [
                                    0.05447453942588112,
                                    0.14966448330698687,
                                    0.21237566244446557,
                                    0.5834853148226664,
                                ],
                                [
                                    0.011529894655379194,
                                    0.024554962267808997,
                                    0.30799180055106806,
                                    0.6559233425257438,
                                ],
                                [
                                    0.011529894655379194,
                                    0.30799180055106806,
                                    0.024554962267808997,
                                    0.6559233425257438,
                                ],
                                [
                                    0.05447453942588112,
                                    0.21237566244446557,
                                    0.14966448330698687,
                                    0.5834853148226664,
                                ],
                                [
                                    0.007366327427755003,
                                    0.196772695305113,
                                    0.028718529495433187,
                                    0.7671424477716988,
                                ],
                                [
                                    0.007366327427755003,
                                    0.028718529495433187,
                                    0.196772695305113,
                                    0.7671424477716988,
                                ],
                                [
                                    0.22146022152432288,
                                    0.20161378718604595,
                                    0.30199481699101116,
                                    0.27493117429862,
                                ],
                                [
                                    0.22146022152432288,
                                    0.30199481699101116,
                                    0.20161378718604595,
                                    0.27493117429862,
                                ],
                                [
                                    0.09059646189548937,
                                    0.08247754681487945,
                                    0.43285857661984467,
                                    0.3940674146697865,
                                ],
                                [
                                    0.009923217169138469,
                                    0.013531821346195568,
                                    0.41315079154123036,
                                    0.5633941699434356,
                                ],
                                [
                                    0.009923217169138469,
                                    0.41315079154123036,
                                    0.013531821346195568,
                                    0.5633941699434356,
                                ],
                                [
                                    0.09059646189548937,
                                    0.43285857661984467,
                                    0.08247754681487945,
                                    0.3940674146697865,
                                ],
                                [
                                    0.0040594575403049594,
                                    0.16901455117006386,
                                    0.019395580975029077,
                                    0.8075304103146022,
                                ],
                                [
                                    0.0040594575403049594,
                                    0.019395580975029077,
                                    0.16901455117006386,
                                    0.8075304103146022,
                                ],
                                [
                                    0.41080006316261863,
                                    0.11582625905167188,
                                    0.36925981199770275,
                                    0.10411386578800674,
                                ],
                                [
                                    0.41080006316261863,
                                    0.36925981199770275,
                                    0.11582625905167188,
                                    0.10411386578800674,
                                ],
                                [
                                    0.11077551866786242,
                                    0.031233476020007332,
                                    0.669284356492459,
                                    0.18870664881967128,
                                ],
                                [
                                    0.005700845852362317,
                                    0.005124374255117565,
                                    0.5209254763619282,
                                    0.4682493035305919,
                                ],
                                [
                                    0.005700845852362317,
                                    0.5209254763619282,
                                    0.005124374255117565,
                                    0.4682493035305919,
                                ],
                                [
                                    0.11077551866786242,
                                    0.669284356492459,
                                    0.031233476020007332,
                                    0.18870664881967128,
                                ],
                                [
                                    0.0015372786247381317,
                                    0.14047171606313164,
                                    0.00928794148274175,
                                    0.8487030638293885,
                                ],
                                [
                                    0.0015372786247381317,
                                    0.00928794148274175,
                                    0.14047171606313164,
                                    0.8487030638293885,
                                ],
                                [
                                    0.5706334474078708,
                                    0.026706796604114368,
                                    0.38465703088848435,
                                    0.018002725099530492,
                                ],
                                [
                                    0.5706334474078708,
                                    0.38465703088848435,
                                    0.026706796604114368,
                                    0.018002725099530492,
                                ],
                                [
                                    0.1153945832214661,
                                    0.00540069930585309,
                                    0.839895895074889,
                                    0.03930882239779177,
                                ],
                                [
                                    0.0013144802560059328,
                                    0.0008860750710173019,
                                    0.5960257637559793,
                                    0.40177368091699756,
                                ],
                                [
                                    0.0013144802560059328,
                                    0.5960257637559793,
                                    0.0008860750710173019,
                                    0.40177368091699756,
                                ],
                                [
                                    0.1153945832214661,
                                    0.839895895074889,
                                    0.00540069930585309,
                                    0.03930882239779177,
                                ],
                                [
                                    0.0002658167024447689,
                                    0.12052946582487442,
                                    0.0019347386245784659,
                                    0.8772699788481023,
                                ],
                                [
                                    0.0002658167024447689,
                                    0.0019347386245784659,
                                    0.12052946582487442,
                                    0.8772699788481023,
                                ],
                                [
                                    0.06616804010988385,
                                    0.003096797772606648,
                                    0.8891224381864713,
                                    0.04161272393103816,
                                ],
                                [
                                    0.06616804010988385,
                                    0.8891224381864713,
                                    0.003096797772606648,
                                    0.04161272393103816,
                                ],
                                [
                                    0.04376166514811096,
                                    0.0020481342190454958,
                                    0.9115288131482442,
                                    0.042661387484599314,
                                ],
                                [
                                    0.06291882122929948,
                                    0.8454615800363877,
                                    0.006346016653191009,
                                    0.08527358208112182,
                                ],
                                [
                                    0.06291882122929948,
                                    0.006346016653191009,
                                    0.8454615800363877,
                                    0.08527358208112182,
                                ],
                                [
                                    0.04376166514811096,
                                    0.9115288131482442,
                                    0.0020481342190454958,
                                    0.042661387484599314,
                                ],
                                [
                                    0.0416127239310382,
                                    0.004197075436118252,
                                    0.866767677334649,
                                    0.08742252329819458,
                                ],
                                [
                                    0.0416127239310382,
                                    0.866767677334649,
                                    0.004197075436118252,
                                    0.08742252329819458,
                                ],
                                [
                                    0.151219142064346,
                                    0.005660997386161362,
                                    0.8126960010124658,
                                    0.030423859537026775,
                                ],
                                [
                                    0.151219142064346,
                                    0.8126960010124658,
                                    0.005660997386161362,
                                    0.030423859537026775,
                                ],
                                [
                                    0.040000036818390955,
                                    0.0014974301585371761,
                                    0.9239151062584209,
                                    0.03458742676465096,
                                ],
                                [
                                    0.11501664256869136,
                                    0.618133155560962,
                                    0.041863496881816016,
                                    0.22498670498853057,
                                ],
                                [
                                    0.11501664256869136,
                                    0.041863496881816016,
                                    0.618133155560962,
                                    0.22498670498853057,
                                ],
                                [
                                    0.040000036818390955,
                                    0.9239151062584209,
                                    0.0014974301585371761,
                                    0.03458742676465096,
                                ],
                                [
                                    0.03042385953702682,
                                    0.011073607439901312,
                                    0.7027259385926266,
                                    0.25577659443044526,
                                ],
                                [
                                    0.03042385953702682,
                                    0.7027259385926266,
                                    0.011073607439901312,
                                    0.25577659443044526,
                                ],
                                [
                                    0.27849358989653383,
                                    0.006688967876467206,
                                    0.6980513715881321,
                                    0.016766070638866804,
                                ],
                                [
                                    0.27849358989653383,
                                    0.6980513715881321,
                                    0.006688967876467206,
                                    0.016766070638866804,
                                ],
                                [
                                    0.03435734952536735,
                                    0.0008252082476337037,
                                    0.9421876119592986,
                                    0.022629830267700306,
                                ],
                                [
                                    0.1359023110100333,
                                    0.34064265047463266,
                                    0.14928024676296775,
                                    0.3741747917523663,
                                ],
                                [
                                    0.1359023110100333,
                                    0.14928024676296775,
                                    0.34064265047463266,
                                    0.3741747917523663,
                                ],
                                [
                                    0.03435734952536735,
                                    0.9421876119592986,
                                    0.0008252082476337037,
                                    0.022629830267700306,
                                ],
                                [
                                    0.01676607063886682,
                                    0.018416487134134234,
                                    0.45977889084579915,
                                    0.5050385513811998,
                                ],
                                [
                                    0.01676607063886682,
                                    0.45977889084579915,
                                    0.018416487134134234,
                                    0.5050385513811998,
                                ],
                                [
                                    0.40900891021812497,
                                    0.004476065877369788,
                                    0.5801658696743952,
                                    0.006349154230110094,
                                ],
                                [
                                    0.40900891021812497,
                                    0.5801658696743952,
                                    0.004476065877369788,
                                    0.006349154230110094,
                                ],
                                [
                                    0.028555149919328376,
                                    0.0003124986497456025,
                                    0.9606196299731917,
                                    0.01051272145773428,
                                ],
                                [
                                    0.09094193726177464,
                                    0.128998187577904,
                                    0.3225430388337201,
                                    0.4575168363266013,
                                ],
                                [
                                    0.09094193726177464,
                                    0.3225430388337201,
                                    0.128998187577904,
                                    0.4575168363266013,
                                ],
                                [
                                    0.028555149919328376,
                                    0.9606196299731917,
                                    0.0003124986497456025,
                                    0.01051272145773428,
                                ],
                                [
                                    0.0063491542301101,
                                    0.022518494338963878,
                                    0.21359097060956853,
                                    0.7575413808213575,
                                ],
                                [
                                    0.0063491542301101,
                                    0.21359097060956853,
                                    0.022518494338963878,
                                    0.7575413808213575,
                                ],
                                [
                                    0.49999757877812634,
                                    0.00110269888538525,
                                    0.4978018658948504,
                                    0.0010978564416379596,
                                ],
                                [
                                    0.49999757877812634,
                                    0.4978018658948504,
                                    0.00110269888538525,
                                    0.0010978564416379596,
                                ],
                                [
                                    0.024501280847021554,
                                    5.403533182409801e-05,
                                    0.9732981638259552,
                                    0.0021465199951991114,
                                ],
                                [
                                    0.02240395373989923,
                                    0.02230556796374561,
                                    0.4786963239236124,
                                    0.4765941543727428,
                                ],
                                [
                                    0.02240395373989923,
                                    0.4786963239236124,
                                    0.02230556796374561,
                                    0.4765941543727428,
                                ],
                                [
                                    0.024501280847021554,
                                    0.9732981638259552,
                                    5.403533182409801e-05,
                                    0.0021465199951991114,
                                ],
                                [
                                    0.001097856441637961,
                                    0.023457459737207694,
                                    0.043611665262006875,
                                    0.9318330185591475,
                                ],
                                [
                                    0.001097856441637961,
                                    0.043611665262006875,
                                    0.023457459737207694,
                                    0.9318330185591475,
                                ],
                                [
                                    0.05403072079161543,
                                    0.015234117090875056,
                                    0.726029154368706,
                                    0.20470600774880351,
                                ],
                                [
                                    0.05403072079161543,
                                    0.726029154368706,
                                    0.015234117090875056,
                                    0.20470600774880351,
                                ],
                                [
                                    0.03573438637546344,
                                    0.010075412991693018,
                                    0.7443254887848579,
                                    0.20986471184798555,
                                ],
                                [
                                    0.05078150191103108,
                                    0.6823682962186224,
                                    0.018483335971459416,
                                    0.24836686589888715,
                                ],
                                [
                                    0.05078150191103108,
                                    0.018483335971459416,
                                    0.6823682962186224,
                                    0.24836686589888715,
                                ],
                                [
                                    0.03573438637546344,
                                    0.7443254887848579,
                                    0.010075412991693018,
                                    0.20986471184798555,
                                ],
                                [
                                    0.03358544515839068,
                                    0.012224354208765775,
                                    0.6995643529712627,
                                    0.2546258476615808,
                                ],
                                [
                                    0.03358544515839068,
                                    0.6995643529712627,
                                    0.012224354208765775,
                                    0.2546258476615808,
                                ],
                                [
                                    0.12903192223891682,
                                    0.027848217211590576,
                                    0.6934553772425058,
                                    0.1496644833069868,
                                ],
                                [
                                    0.12903192223891682,
                                    0.6934553772425058,
                                    0.027848217211590576,
                                    0.1496644833069868,
                                ],
                                [
                                    0.034131139549173135,
                                    0.007366327427754999,
                                    0.7883561599322495,
                                    0.1701463730908224,
                                ],
                                [
                                    0.09282942274326214,
                                    0.49889253179100196,
                                    0.06405071670724524,
                                    0.34422732875849066,
                                ],
                                [
                                    0.09282942274326214,
                                    0.06405071670724524,
                                    0.49889253179100196,
                                    0.34422732875849066,
                                ],
                                [
                                    0.034131139549173135,
                                    0.7883561599322495,
                                    0.007366327427754999,
                                    0.1701463730908224,
                                ],
                                [
                                    0.024554962267808997,
                                    0.016942504709119136,
                                    0.5671669922664552,
                                    0.39133554075661675,
                                ],
                                [
                                    0.024554962267808997,
                                    0.5671669922664552,
                                    0.016942504709119136,
                                    0.39133554075661675,
                                ],
                                [
                                    0.25227743211430126,
                                    0.03290512565869977,
                                    0.6323398954121194,
                                    0.08247754681487945,
                                ],
                                [
                                    0.25227743211430126,
                                    0.6323398954121194,
                                    0.03290512565869977,
                                    0.08247754681487945,
                                ],
                                [
                                    0.031123100232696096,
                                    0.0040594575403049594,
                                    0.8534942272937247,
                                    0.11132321493327427,
                                ],
                                [
                                    0.10968615322780076,
                                    0.27493117429862,
                                    0.1754964045452003,
                                    0.4398862679283789,
                                ],
                                [
                                    0.10968615322780076,
                                    0.1754964045452003,
                                    0.27493117429862,
                                    0.4398862679283789,
                                ],
                                [
                                    0.031123100232696096,
                                    0.8534942272937247,
                                    0.0040594575403049594,
                                    0.11132321493327427,
                                ],
                                [
                                    0.013531821346195566,
                                    0.021650736426805487,
                                    0.3710855061802252,
                                    0.5937319360467738,
                                ],
                                [
                                    0.013531821346195566,
                                    0.3710855061802252,
                                    0.021650736426805487,
                                    0.5937319360467738,
                                ],
                                [
                                    0.391465807686921,
                                    0.022019168408573712,
                                    0.5552815478844979,
                                    0.03123347602000733,
                                ],
                                [
                                    0.391465807686921,
                                    0.5552815478844979,
                                    0.022019168408573712,
                                    0.03123347602000733,
                                ],
                                [
                                    0.027330369944335846,
                                    0.0015372786247381327,
                                    0.9194169856270832,
                                    0.05171536580384291,
                                ],
                                [
                                    0.07339883473057073,
                                    0.10411386578800676,
                                    0.340086141364924,
                                    0.48240115811649853,
                                ],
                                [
                                    0.07339883473057073,
                                    0.340086141364924,
                                    0.10411386578800676,
                                    0.48240115811649853,
                                ],
                                [
                                    0.027330369944335846,
                                    0.9194169856270832,
                                    0.0015372786247381327,
                                    0.05171536580384291,
                                ],
                                [
                                    0.005124374255117571,
                                    0.023743274313956408,
                                    0.1723883262634599,
                                    0.7987440251674661,
                                ],
                                [
                                    0.005124374255117571,
                                    0.1723883262634599,
                                    0.023743274313956408,
                                    0.7987440251674661,
                                ],
                                [
                                    0.4956757568618848,
                                    0.0054245208016268035,
                                    0.4934990230306353,
                                    0.0054006993058530895,
                                ],
                                [
                                    0.4956757568618848,
                                    0.4934990230306353,
                                    0.0054245208016268035,
                                    0.0054006993058530895,
                                ],
                                [
                                    0.024289499476400887,
                                    0.0002658167024447663,
                                    0.9648852804161192,
                                    0.010559403405035127,
                                ],
                                [
                                    0.018082131823657692,
                                    0.0180027250995305,
                                    0.4830181458398539,
                                    0.4808969972369579,
                                ],
                                [
                                    0.018082131823657692,
                                    0.4830181458398539,
                                    0.0180027250995305,
                                    0.4808969972369579,
                                ],
                                [
                                    0.024289499476400887,
                                    0.9648852804161192,
                                    0.0002658167024447663,
                                    0.010559403405035127,
                                ],
                                [
                                    0.0008860750710172936,
                                    0.02366924110782836,
                                    0.035198781852170895,
                                    0.9402459019689835,
                                ],
                                [
                                    0.0008860750710172936,
                                    0.035198781852170895,
                                    0.02366924110782836,
                                    0.9402459019689835,
                                ],
                                [
                                    0.03625702838153743,
                                    0.03300780950095306,
                                    0.4871980101337966,
                                    0.4435371519837129,
                                ],
                                [
                                    0.03625702838153743,
                                    0.4871980101337966,
                                    0.03300780950095306,
                                    0.4435371519837129,
                                ],
                                [
                                    0.023979370292114607,
                                    0.02183042907504185,
                                    0.4994756682232194,
                                    0.4547145324096241,
                                ],
                                [
                                    0.03300780950095306,
                                    0.4435371519837129,
                                    0.03625702838153743,
                                    0.4871980101337966,
                                ],
                                [
                                    0.03300780950095306,
                                    0.03625702838153743,
                                    0.4435371519837129,
                                    0.4871980101337966,
                                ],
                                [
                                    0.023979370292114607,
                                    0.4994756682232194,
                                    0.02183042907504185,
                                    0.4547145324096241,
                                ],
                                [
                                    0.02183042907504185,
                                    0.023979370292114607,
                                    0.4547145324096241,
                                    0.4994756682232194,
                                ],
                                [
                                    0.02183042907504185,
                                    0.4547145324096241,
                                    0.023979370292114607,
                                    0.4994756682232194,
                                ],
                                [
                                    0.09654131947308102,
                                    0.06033881997742636,
                                    0.5188413530004983,
                                    0.3242785075489944,
                                ],
                                [
                                    0.09654131947308102,
                                    0.5188413530004983,
                                    0.06033881997742636,
                                    0.3242785075489944,
                                ],
                                [
                                    0.025536822129146135,
                                    0.015960644847781997,
                                    0.5898458503444332,
                                    0.36865668267863877,
                                ],
                                [
                                    0.06033881997742638,
                                    0.3242785075489945,
                                    0.096541319473081,
                                    0.5188413530004982,
                                ],
                                [
                                    0.06033881997742638,
                                    0.096541319473081,
                                    0.3242785075489945,
                                    0.5188413530004982,
                                ],
                                [
                                    0.025536822129146135,
                                    0.5898458503444332,
                                    0.015960644847781997,
                                    0.36865668267863877,
                                ],
                                [
                                    0.015960644847782,
                                    0.025536822129146132,
                                    0.3686566826786389,
                                    0.589845850344433,
                                ],
                                [
                                    0.015960644847782,
                                    0.3686566826786389,
                                    0.025536822129146132,
                                    0.589845850344433,
                                ],
                                [
                                    0.2138869183297508,
                                    0.07129563944325026,
                                    0.5361130816702492,
                                    0.17870436055674974,
                                ],
                                [
                                    0.2138869183297508,
                                    0.5361130816702492,
                                    0.07129563944325026,
                                    0.17870436055674974,
                                ],
                                [
                                    0.02638691832975079,
                                    0.008795639443250264,
                                    0.7236130816702492,
                                    0.24120436055674974,
                                ],
                                [
                                    0.07129563944325026,
                                    0.17870436055674974,
                                    0.2138869183297508,
                                    0.5361130816702492,
                                ],
                                [
                                    0.07129563944325026,
                                    0.2138869183297508,
                                    0.17870436055674974,
                                    0.5361130816702492,
                                ],
                                [
                                    0.02638691832975079,
                                    0.7236130816702492,
                                    0.008795639443250264,
                                    0.24120436055674974,
                                ],
                                [
                                    0.008795639443250264,
                                    0.02638691832975079,
                                    0.24120436055674974,
                                    0.7236130816702492,
                                ],
                                [
                                    0.008795639443250264,
                                    0.24120436055674974,
                                    0.02638691832975079,
                                    0.7236130816702492,
                                ],
                                [
                                    0.36577597452592253,
                                    0.04770900156957222,
                                    0.5188413530004983,
                                    0.06767367090400704,
                                ],
                                [
                                    0.36577597452592253,
                                    0.5188413530004983,
                                    0.04770900156957222,
                                    0.06767367090400704,
                                ],
                                [
                                    0.025536822129146125,
                                    0.0033308264399278514,
                                    0.8590805053972747,
                                    0.1120518460336514,
                                ],
                                [
                                    0.04770900156957222,
                                    0.06767367090400704,
                                    0.36577597452592253,
                                    0.5188413530004983,
                                ],
                                [
                                    0.04770900156957222,
                                    0.36577597452592253,
                                    0.06767367090400704,
                                    0.5188413530004983,
                                ],
                                [
                                    0.025536822129146125,
                                    0.8590805053972747,
                                    0.0033308264399278514,
                                    0.1120518460336514,
                                ],
                                [
                                    0.0033308264399278514,
                                    0.025536822129146125,
                                    0.1120518460336514,
                                    0.8590805053972747,
                                ],
                                [
                                    0.0033308264399278514,
                                    0.1120518460336514,
                                    0.025536822129146125,
                                    0.8590805053972747,
                                ],
                                [
                                    0.48934695135086936,
                                    0.011753326312642245,
                                    0.4871980101337966,
                                    0.011701712202691792,
                                ],
                                [
                                    0.48934695135086936,
                                    0.4871980101337966,
                                    0.011753326312642245,
                                    0.011701712202691792,
                                ],
                                [
                                    0.023979370292114624,
                                    0.0005759458867310299,
                                    0.9525655911925514,
                                    0.022879092628603007,
                                ],
                                [
                                    0.011753326312642245,
                                    0.011701712202691792,
                                    0.48934695135086936,
                                    0.4871980101337966,
                                ],
                                [
                                    0.011753326312642245,
                                    0.48934695135086936,
                                    0.011701712202691792,
                                    0.4871980101337966,
                                ],
                                [
                                    0.023979370292114624,
                                    0.9525655911925514,
                                    0.0005759458867310299,
                                    0.022879092628603007,
                                ],
                                [
                                    0.0005759458867310299,
                                    0.023979370292114624,
                                    0.022879092628603007,
                                    0.9525655911925514,
                                ],
                                [
                                    0.0005759458867310299,
                                    0.022879092628603007,
                                    0.023979370292114624,
                                    0.9525655911925514,
                                ],
                                [
                                    0.018483335971459423,
                                    0.05078150191103107,
                                    0.24836686589888726,
                                    0.6823682962186223,
                                ],
                                [
                                    0.018483335971459423,
                                    0.24836686589888726,
                                    0.05078150191103107,
                                    0.6823682962186223,
                                ],
                                [
                                    0.01222435420876578,
                                    0.033585445158390674,
                                    0.2546258476615809,
                                    0.6995643529712626,
                                ],
                                [
                                    0.01523411709087506,
                                    0.20470600774880357,
                                    0.05403072079161543,
                                    0.726029154368706,
                                ],
                                [
                                    0.01523411709087506,
                                    0.05403072079161543,
                                    0.20470600774880357,
                                    0.726029154368706,
                                ],
                                [
                                    0.01222435420876578,
                                    0.2546258476615809,
                                    0.033585445158390674,
                                    0.6995643529712626,
                                ],
                                [
                                    0.010075412991693022,
                                    0.03573438637546344,
                                    0.2098647118479856,
                                    0.7443254887848579,
                                ],
                                [
                                    0.010075412991693022,
                                    0.2098647118479856,
                                    0.03573438637546344,
                                    0.7443254887848579,
                                ],
                                [
                                    0.06405071670724526,
                                    0.09282942274326213,
                                    0.3442273287584907,
                                    0.4988925317910019,
                                ],
                                [
                                    0.06405071670724526,
                                    0.3442273287584907,
                                    0.09282942274326213,
                                    0.4988925317910019,
                                ],
                                [
                                    0.016942504709119142,
                                    0.02455496226780899,
                                    0.39133554075661686,
                                    0.5671669922664551,
                                ],
                                [
                                    0.02784821721159059,
                                    0.1496644833069869,
                                    0.1290319222389168,
                                    0.6934553772425057,
                                ],
                                [
                                    0.02784821721159059,
                                    0.1290319222389168,
                                    0.1496644833069869,
                                    0.6934553772425057,
                                ],
                                [
                                    0.016942504709119142,
                                    0.39133554075661686,
                                    0.02455496226780899,
                                    0.5671669922664551,
                                ],
                                [
                                    0.007366327427755002,
                                    0.03413113954917313,
                                    0.17014637309082248,
                                    0.7883561599322494,
                                ],
                                [
                                    0.007366327427755002,
                                    0.17014637309082248,
                                    0.03413113954917313,
                                    0.7883561599322494,
                                ],
                                [
                                    0.1754964045452003,
                                    0.10968615322780076,
                                    0.4398862679283789,
                                    0.27493117429862,
                                ],
                                [
                                    0.1754964045452003,
                                    0.4398862679283789,
                                    0.10968615322780076,
                                    0.27493117429862,
                                ],
                                [
                                    0.021650736426805487,
                                    0.013531821346195566,
                                    0.5937319360467738,
                                    0.3710855061802252,
                                ],
                                [
                                    0.032905125658699776,
                                    0.08247754681487948,
                                    0.25227743211430126,
                                    0.6323398954121194,
                                ],
                                [
                                    0.032905125658699776,
                                    0.25227743211430126,
                                    0.08247754681487948,
                                    0.6323398954121194,
                                ],
                                [
                                    0.021650736426805487,
                                    0.5937319360467738,
                                    0.013531821346195566,
                                    0.3710855061802252,
                                ],
                                [
                                    0.00405945754030496,
                                    0.031123100232696096,
                                    0.1113232149332743,
                                    0.8534942272937247,
                                ],
                                [
                                    0.00405945754030496,
                                    0.1113232149332743,
                                    0.031123100232696096,
                                    0.8534942272937247,
                                ],
                                [
                                    0.340086141364924,
                                    0.07339883473057071,
                                    0.48240115811649853,
                                    0.10411386578800674,
                                ],
                                [
                                    0.340086141364924,
                                    0.48240115811649853,
                                    0.07339883473057071,
                                    0.10411386578800674,
                                ],
                                [
                                    0.023743274313956408,
                                    0.00512437425511757,
                                    0.7987440251674661,
                                    0.17238832626345987,
                                ],
                                [
                                    0.022019168408573705,
                                    0.031233476020007315,
                                    0.391465807686921,
                                    0.5552815478844979,
                                ],
                                [
                                    0.022019168408573705,
                                    0.391465807686921,
                                    0.031233476020007315,
                                    0.5552815478844979,
                                ],
                                [
                                    0.023743274313956408,
                                    0.7987440251674661,
                                    0.00512437425511757,
                                    0.17238832626345987,
                                ],
                                [
                                    0.0015372786247381323,
                                    0.027330369944335846,
                                    0.05171536580384289,
                                    0.9194169856270832,
                                ],
                                [
                                    0.0015372786247381323,
                                    0.05171536580384289,
                                    0.027330369944335846,
                                    0.9194169856270832,
                                ],
                                [
                                    0.4830181458398539,
                                    0.018082131823657685,
                                    0.4808969972369579,
                                    0.018002725099530492,
                                ],
                                [
                                    0.4830181458398539,
                                    0.4808969972369579,
                                    0.018082131823657685,
                                    0.018002725099530492,
                                ],
                                [
                                    0.02366924110782836,
                                    0.0008860750710172932,
                                    0.9402459019689835,
                                    0.03519878185217088,
                                ],
                                [
                                    0.005424520801626798,
                                    0.005400699305853084,
                                    0.4956757568618848,
                                    0.4934990230306353,
                                ],
                                [
                                    0.005424520801626798,
                                    0.4956757568618848,
                                    0.005400699305853084,
                                    0.4934990230306353,
                                ],
                                [
                                    0.02366924110782836,
                                    0.9402459019689835,
                                    0.0008860750710172932,
                                    0.03519878185217088,
                                ],
                                [
                                    0.00026581670244476603,
                                    0.024289499476400887,
                                    0.010559403405035117,
                                    0.9648852804161192,
                                ],
                                [
                                    0.00026581670244476603,
                                    0.010559403405035117,
                                    0.024289499476400887,
                                    0.9648852804161192,
                                ],
                                [
                                    0.0063460166531910155,
                                    0.06291882122929948,
                                    0.0852735820811219,
                                    0.8454615800363876,
                                ],
                                [
                                    0.0063460166531910155,
                                    0.0852735820811219,
                                    0.06291882122929948,
                                    0.8454615800363876,
                                ],
                                [
                                    0.004197075436118256,
                                    0.0416127239310382,
                                    0.08742252329819465,
                                    0.8667676773346489,
                                ],
                                [
                                    0.0030967977726066498,
                                    0.04161272393103819,
                                    0.06616804010988385,
                                    0.8891224381864713,
                                ],
                                [
                                    0.0030967977726066498,
                                    0.06616804010988385,
                                    0.04161272393103819,
                                    0.8891224381864713,
                                ],
                                [
                                    0.004197075436118256,
                                    0.08742252329819465,
                                    0.0416127239310382,
                                    0.8667676773346489,
                                ],
                                [
                                    0.002048134219045497,
                                    0.04376166514811096,
                                    0.04266138748459934,
                                    0.9115288131482442,
                                ],
                                [
                                    0.002048134219045497,
                                    0.04266138748459934,
                                    0.04376166514811096,
                                    0.9115288131482442,
                                ],
                                [
                                    0.04186349688181604,
                                    0.11501664256869135,
                                    0.22498670498853066,
                                    0.6181331555609619,
                                ],
                                [
                                    0.04186349688181604,
                                    0.22498670498853066,
                                    0.11501664256869135,
                                    0.6181331555609619,
                                ],
                                [
                                    0.011073607439901318,
                                    0.030423859537026816,
                                    0.25577659443044537,
                                    0.7027259385926264,
                                ],
                                [
                                    0.00566099738616137,
                                    0.03042385953702682,
                                    0.151219142064346,
                                    0.8126960010124658,
                                ],
                                [
                                    0.00566099738616137,
                                    0.151219142064346,
                                    0.03042385953702682,
                                    0.8126960010124658,
                                ],
                                [
                                    0.011073607439901318,
                                    0.25577659443044537,
                                    0.030423859537026816,
                                    0.7027259385926264,
                                ],
                                [
                                    0.0014974301585371785,
                                    0.040000036818390955,
                                    0.034587426764651014,
                                    0.9239151062584209,
                                ],
                                [
                                    0.0014974301585371785,
                                    0.034587426764651014,
                                    0.040000036818390955,
                                    0.9239151062584209,
                                ],
                                [
                                    0.14928024676296775,
                                    0.1359023110100333,
                                    0.3741747917523663,
                                    0.34064265047463266,
                                ],
                                [
                                    0.14928024676296775,
                                    0.3741747917523663,
                                    0.1359023110100333,
                                    0.34064265047463266,
                                ],
                                [
                                    0.018416487134134234,
                                    0.01676607063886682,
                                    0.5050385513811998,
                                    0.45977889084579915,
                                ],
                                [
                                    0.006688967876467214,
                                    0.01676607063886682,
                                    0.27849358989653383,
                                    0.6980513715881321,
                                ],
                                [
                                    0.006688967876467214,
                                    0.27849358989653383,
                                    0.01676607063886682,
                                    0.6980513715881321,
                                ],
                                [
                                    0.018416487134134234,
                                    0.5050385513811998,
                                    0.01676607063886682,
                                    0.45977889084579915,
                                ],
                                [
                                    0.0008252082476337047,
                                    0.03435734952536735,
                                    0.02262983026770033,
                                    0.9421876119592986,
                                ],
                                [
                                    0.0008252082476337047,
                                    0.02262983026770033,
                                    0.03435734952536735,
                                    0.9421876119592986,
                                ],
                                [
                                    0.3225430388337201,
                                    0.09094193726177464,
                                    0.4575168363266013,
                                    0.128998187577904,
                                ],
                                [
                                    0.3225430388337201,
                                    0.4575168363266013,
                                    0.09094193726177464,
                                    0.128998187577904,
                                ],
                                [
                                    0.022518494338963878,
                                    0.0063491542301101,
                                    0.7575413808213575,
                                    0.21359097060956853,
                                ],
                                [
                                    0.004476065877369788,
                                    0.006349154230110094,
                                    0.40900891021812497,
                                    0.5801658696743952,
                                ],
                                [
                                    0.004476065877369788,
                                    0.40900891021812497,
                                    0.006349154230110094,
                                    0.5801658696743952,
                                ],
                                [
                                    0.022518494338963878,
                                    0.7575413808213575,
                                    0.0063491542301101,
                                    0.21359097060956853,
                                ],
                                [
                                    0.0003124986497456025,
                                    0.028555149919328376,
                                    0.01051272145773428,
                                    0.9606196299731917,
                                ],
                                [
                                    0.0003124986497456025,
                                    0.01051272145773428,
                                    0.028555149919328376,
                                    0.9606196299731917,
                                ],
                                [
                                    0.4786963239236124,
                                    0.02240395373989924,
                                    0.4765941543727428,
                                    0.02230556796374562,
                                ],
                                [
                                    0.4786963239236124,
                                    0.4765941543727428,
                                    0.02240395373989924,
                                    0.02230556796374562,
                                ],
                                [
                                    0.023457459737207694,
                                    0.0010978564416379616,
                                    0.9318330185591475,
                                    0.043611665262006896,
                                ],
                                [
                                    0.0011026988853852625,
                                    0.0010978564416379722,
                                    0.49999757877812634,
                                    0.4978018658948504,
                                ],
                                [
                                    0.0011026988853852625,
                                    0.49999757877812634,
                                    0.0010978564416379722,
                                    0.4978018658948504,
                                ],
                                [
                                    0.023457459737207694,
                                    0.9318330185591475,
                                    0.0010978564416379616,
                                    0.043611665262006896,
                                ],
                                [
                                    5.403533182409863e-05,
                                    0.024501280847021554,
                                    0.002146519995199136,
                                    0.9732981638259552,
                                ],
                                [
                                    5.403533182409863e-05,
                                    0.002146519995199136,
                                    0.024501280847021554,
                                    0.9732981638259552,
                                ],
                                [
                                    0.9120947900421352,
                                    0.042687876345104146,
                                    0.043195688254219954,
                                    0.0020216453585406692,
                                ],
                                [
                                    0.9120947900421352,
                                    0.043195688254219954,
                                    0.042687876345104146,
                                    0.0020216453585406692,
                                ],
                                [
                                    0.8776232698127272,
                                    0.041074539651323946,
                                    0.07766720848362789,
                                    0.0036349820523208665,
                                ],
                                [
                                    0.8673058616143633,
                                    0.04107453965132394,
                                    0.08747680477287614,
                                    0.004142793961436684,
                                ],
                                [
                                    0.8673058616143633,
                                    0.08747680477287614,
                                    0.04107453965132394,
                                    0.004142793961436684,
                                ],
                                [
                                    0.8776232698127272,
                                    0.07766720848362789,
                                    0.041074539651323946,
                                    0.0036349820523208665,
                                ],
                                [
                                    0.8345270848028626,
                                    0.08417072466118855,
                                    0.07385331646282449,
                                    0.007448874073124271,
                                ],
                                [
                                    0.8345270848028626,
                                    0.07385331646282449,
                                    0.08417072466118855,
                                    0.007448874073124271,
                                ],
                                [
                                    0.9267244604639018,
                                    0.034692596960678536,
                                    0.037190682612910045,
                                    0.001392259962509602,
                                ],
                                [
                                    0.9267244604639018,
                                    0.037190682612910045,
                                    0.034692596960678536,
                                    0.001392259962509602,
                                ],
                                [
                                    0.755617280345586,
                                    0.028287076560416922,
                                    0.2082978627312258,
                                    0.007797780362771211,
                                ],
                                [
                                    0.7048627215692366,
                                    0.028287076560416926,
                                    0.2565543358553439,
                                    0.010295866015002724,
                                ],
                                [
                                    0.7048627215692366,
                                    0.2565543358553439,
                                    0.028287076560416926,
                                    0.010295866015002724,
                                ],
                                [
                                    0.755617280345586,
                                    0.2082978627312258,
                                    0.028287076560416922,
                                    0.007797780362771211,
                                ],
                                [
                                    0.5747193210185918,
                                    0.20918503588741108,
                                    0.15843047711106156,
                                    0.05766516598293547,
                                ],
                                [
                                    0.5747193210185918,
                                    0.15843047711106156,
                                    0.20918503588741108,
                                    0.05766516598293547,
                                ],
                                [
                                    0.9483544047246267,
                                    0.022777946706299252,
                                    0.028190556760039193,
                                    0.0006770918090347562,
                                ],
                                [
                                    0.9483544047246267,
                                    0.028190556760039193,
                                    0.022777946706299252,
                                    0.0006770918090347562,
                                ],
                                [
                                    0.572758291429003,
                                    0.013756732475502218,
                                    0.40378667005566293,
                                    0.009698306039831791,
                                ],
                                [
                                    0.4627882290091637,
                                    0.013756732475502218,
                                    0.5083441224217623,
                                    0.015110916093571732,
                                ],
                                [
                                    0.4627882290091637,
                                    0.5083441224217623,
                                    0.013756732475502218,
                                    0.015110916093571732,
                                ],
                                [
                                    0.572758291429003,
                                    0.40378667005566293,
                                    0.013756732475502218,
                                    0.009698306039831791,
                                ],
                                [
                                    0.2795007794767504,
                                    0.3070142444277549,
                                    0.19704418200791557,
                                    0.21644079408757916,
                                ],
                                [
                                    0.2795007794767504,
                                    0.19704418200791557,
                                    0.3070142444277549,
                                    0.21644079408757916,
                                ],
                                [
                                    0.97022975378351,
                                    0.010617891653761853,
                                    0.01894502610901022,
                                    0.00020732845371802995,
                                ],
                                [
                                    0.97022975378351,
                                    0.01894502610901022,
                                    0.010617891653761853,
                                    0.00020732845371802995,
                                ],
                                [
                                    0.3849133196495075,
                                    0.004212371253500241,
                                    0.6042614602430126,
                                    0.0066128488539796415,
                                ],
                                [
                                    0.21572775358617838,
                                    0.00421237125350024,
                                    0.7651198918510934,
                                    0.014939983309228012,
                                ],
                                [
                                    0.21572775358617838,
                                    0.7651198918510934,
                                    0.00421237125350024,
                                    0.014939983309228012,
                                ],
                                [
                                    0.3849133196495075,
                                    0.6042614602430126,
                                    0.004212371253500241,
                                    0.0066128488539796415,
                                ],
                                [
                                    0.08558435303553372,
                                    0.303541337867474,
                                    0.1343557718041449,
                                    0.4765185372928474,
                                ],
                                [
                                    0.08558435303553372,
                                    0.1343557718041449,
                                    0.303541337867474,
                                    0.4765185372928474,
                                ],
                                [
                                    0.9853090276189088,
                                    0.0021730088557039362,
                                    0.012490417054068,
                                    2.75464713192732e-05,
                                ],
                                [
                                    0.9853090276189088,
                                    0.012490417054068,
                                    0.0021730088557039362,
                                    2.75464713192732e-05,
                                ],
                                [
                                    0.2537725661830357,
                                    0.0005596721619237371,
                                    0.7440268784899411,
                                    0.0016408831650994726,
                                ],
                                [
                                    0.0441498495417211,
                                    0.0005596721619237368,
                                    0.9433321869328917,
                                    0.011958291363463536,
                                ],
                                [
                                    0.0441498495417211,
                                    0.9433321869328917,
                                    0.0005596721619237368,
                                    0.011958291363463536,
                                ],
                                [
                                    0.2537725661830357,
                                    0.7440268784899411,
                                    0.0005596721619237371,
                                    0.0016408831650994726,
                                ],
                                [
                                    0.011371072730220536,
                                    0.2429611656147389,
                                    0.033338448973424306,
                                    0.7123293126816163,
                                ],
                                [
                                    0.011371072730220536,
                                    0.033338448973424306,
                                    0.2429611656147389,
                                    0.7123293126816163,
                                ],
                                [
                                    0.7447876475472688,
                                    0.2099950188399706,
                                    0.03527222761305266,
                                    0.009945105999707965,
                                ],
                                [
                                    0.7447876475472688,
                                    0.03527222761305266,
                                    0.2099950188399706,
                                    0.009945105999707965,
                                ],
                                [
                                    0.7166392985605885,
                                    0.20205851090346266,
                                    0.06342057659973285,
                                    0.0178816139362159,
                                ],
                                [
                                    0.6999987191194968,
                                    0.033151079010156646,
                                    0.2547839472677426,
                                    0.01206625460260398,
                                ],
                                [
                                    0.6999987191194968,
                                    0.2547839472677426,
                                    0.033151079010156646,
                                    0.01206625460260398,
                                ],
                                [
                                    0.7166392985605885,
                                    0.06342057659973285,
                                    0.20205851090346266,
                                    0.0178816139362159,
                                ],
                                [
                                    0.6735431135507239,
                                    0.24515469591332728,
                                    0.059606684578929446,
                                    0.021695505957019308,
                                ],
                                [
                                    0.6735431135507239,
                                    0.059606684578929446,
                                    0.24515469591332728,
                                    0.021695505957019308,
                                ],
                                [
                                    0.7907533192365189,
                                    0.17066373818806146,
                                    0.03173398024490372,
                                    0.006848962330515938,
                                ],
                                [
                                    0.7907533192365189,
                                    0.03173398024490372,
                                    0.17066373818806146,
                                    0.006848962330515938,
                                ],
                                [
                                    0.6447513775633397,
                                    0.1391529793426633,
                                    0.17773592191808296,
                                    0.03835972117591408,
                                ],
                                [
                                    0.5688915803418536,
                                    0.02283037419241059,
                                    0.39252547708272684,
                                    0.01575256838300906,
                                ],
                                [
                                    0.5688915803418536,
                                    0.39252547708272684,
                                    0.02283037419241059,
                                    0.01575256838300906,
                                ],
                                [
                                    0.6447513775633397,
                                    0.17773592191808296,
                                    0.1391529793426633,
                                    0.03835972117591408,
                                ],
                                [
                                    0.4638534182363454,
                                    0.3200509386696575,
                                    0.1278685362979187,
                                    0.08822710679607836,
                                ],
                                [
                                    0.4638534182363454,
                                    0.1278685362979187,
                                    0.3200509386696575,
                                    0.08822710679607836,
                                ],
                                [
                                    0.8590805053972747,
                                    0.11205184603365137,
                                    0.0255368221291461,
                                    0.0033308264399278475,
                                ],
                                [
                                    0.8590805053972747,
                                    0.0255368221291461,
                                    0.11205184603365137,
                                    0.0033308264399278475,
                                ],
                                [
                                    0.5188413530004983,
                                    0.06767367090400703,
                                    0.36577597452592253,
                                    0.0477090015695722,
                                ],
                                [
                                    0.3735143296818116,
                                    0.011102997844609127,
                                    0.5976180217491144,
                                    0.017764650724464825,
                                ],
                                [
                                    0.3735143296818116,
                                    0.5976180217491144,
                                    0.011102997844609127,
                                    0.017764650724464825,
                                ],
                                [
                                    0.5188413530004983,
                                    0.36577597452592253,
                                    0.06767367090400703,
                                    0.0477090015695722,
                                ],
                                [
                                    0.2255838410482456,
                                    0.3609311828562597,
                                    0.15903348647817514,
                                    0.25445148961731956,
                                ],
                                [
                                    0.2255838410482456,
                                    0.15903348647817514,
                                    0.3609311828562597,
                                    0.25445148961731956,
                                ],
                                [
                                    0.9286149145361898,
                                    0.052232730901081964,
                                    0.018132441035229173,
                                    0.0010199135274990793,
                                ],
                                [
                                    0.9286149145361898,
                                    0.018132441035229173,
                                    0.052232730901081964,
                                    0.0010199135274990793,
                                ],
                                [
                                    0.368403718847324,
                                    0.020721972055683803,
                                    0.5783436367240951,
                                    0.03253067237289724,
                                ],
                                [
                                    0.17411291433885828,
                                    0.0033997861797191915,
                                    0.8067347310984134,
                                    0.01575256838300906,
                                ],
                                [
                                    0.17411291433885828,
                                    0.8067347310984134,
                                    0.0033997861797191915,
                                    0.01575256838300906,
                                ],
                                [
                                    0.368403718847324,
                                    0.5783436367240951,
                                    0.020721972055683803,
                                    0.03253067237289724,
                                ],
                                [
                                    0.06907475223335016,
                                    0.32005093866965756,
                                    0.10843794828522732,
                                    0.5024363608117649,
                                ],
                                [
                                    0.06907475223335016,
                                    0.10843794828522732,
                                    0.32005093866965756,
                                    0.5024363608117649,
                                ],
                                [
                                    0.9767923260775926,
                                    0.010689710397020172,
                                    0.012382453814927552,
                                    0.00013550971045972221,
                                ],
                                [
                                    0.9767923260775926,
                                    0.012382453814927552,
                                    0.010689710397020172,
                                    0.00013550971045972221,
                                ],
                                [
                                    0.25157903588444724,
                                    0.0027532024605122236,
                                    0.7375957440080729,
                                    0.00807201764696767,
                                ],
                                [
                                    0.0356331480004049,
                                    0.0004517089227832882,
                                    0.9518488884742078,
                                    0.012066254602603986,
                                ],
                                [
                                    0.0356331480004049,
                                    0.9518488884742078,
                                    0.0004517089227832882,
                                    0.012066254602603986,
                                ],
                                [
                                    0.25157903588444724,
                                    0.7375957440080729,
                                    0.0027532024605122236,
                                    0.00807201764696767,
                                ],
                                [
                                    0.009177542431632059,
                                    0.2451546959133274,
                                    0.02690731449155613,
                                    0.7187604471634844,
                                ],
                                [
                                    0.009177542431632059,
                                    0.02690731449155613,
                                    0.2451546959133274,
                                    0.7187604471634844,
                                ],
                                [
                                    0.4997857974075057,
                                    0.4549968689797337,
                                    0.023669241107828323,
                                    0.021548092504932302,
                                ],
                                [
                                    0.4997857974075057,
                                    0.023669241107828323,
                                    0.4549968689797337,
                                    0.021548092504932302,
                                ],
                                [
                                    0.48089699723695795,
                                    0.4378008122270933,
                                    0.042558041278376084,
                                    0.03874414925757267,
                                ],
                                [
                                    0.4549968689797337,
                                    0.021548092504932302,
                                    0.4997857974075057,
                                    0.023669241107828323,
                                ],
                                [
                                    0.4549968689797337,
                                    0.4997857974075057,
                                    0.021548092504932302,
                                    0.023669241107828323,
                                ],
                                [
                                    0.48089699723695795,
                                    0.042558041278376084,
                                    0.4378008122270933,
                                    0.03874414925757267,
                                ],
                                [
                                    0.4378008122270933,
                                    0.48089699723695795,
                                    0.03874414925757267,
                                    0.042558041278376084,
                                ],
                                [
                                    0.4378008122270933,
                                    0.03874414925757267,
                                    0.48089699723695795,
                                    0.042558041278376084,
                                ],
                                [
                                    0.5916393981596229,
                                    0.3697776592649575,
                                    0.023743274313956387,
                                    0.014839668261463265,
                                ],
                                [
                                    0.5916393981596229,
                                    0.023743274313956387,
                                    0.3697776592649575,
                                    0.014839668261463265,
                                ],
                                [
                                    0.4824011581164986,
                                    0.3015031987895043,
                                    0.13298151435708067,
                                    0.08311412873691638,
                                ],
                                [
                                    0.3697776592649576,
                                    0.014839668261463268,
                                    0.5916393981596227,
                                    0.023743274313956383,
                                ],
                                [
                                    0.3697776592649576,
                                    0.5916393981596227,
                                    0.014839668261463268,
                                    0.023743274313956383,
                                ],
                                [
                                    0.4824011581164986,
                                    0.13298151435708067,
                                    0.3015031987895043,
                                    0.08311412873691638,
                                ],
                                [
                                    0.30150319878950443,
                                    0.4824011581164985,
                                    0.0831141287369164,
                                    0.13298151435708064,
                                ],
                                [
                                    0.30150319878950443,
                                    0.0831141287369164,
                                    0.4824011581164985,
                                    0.13298151435708064,
                                ],
                                [
                                    0.7283492635731945,
                                    0.2427830878577315,
                                    0.021650736426805463,
                                    0.007216912142268488,
                                ],
                                [
                                    0.7283492635731945,
                                    0.021650736426805463,
                                    0.2427830878577315,
                                    0.007216912142268488,
                                ],
                                [
                                    0.4398862679283789,
                                    0.14662875597612632,
                                    0.3101137320716211,
                                    0.10337124402387368,
                                ],
                                [
                                    0.2427830878577315,
                                    0.007216912142268488,
                                    0.7283492635731945,
                                    0.021650736426805463,
                                ],
                                [
                                    0.2427830878577315,
                                    0.7283492635731945,
                                    0.007216912142268488,
                                    0.021650736426805463,
                                ],
                                [
                                    0.4398862679283789,
                                    0.3101137320716211,
                                    0.14662875597612632,
                                    0.10337124402387368,
                                ],
                                [
                                    0.14662875597612632,
                                    0.4398862679283789,
                                    0.10337124402387368,
                                    0.3101137320716211,
                                ],
                                [
                                    0.14662875597612632,
                                    0.10337124402387368,
                                    0.4398862679283789,
                                    0.3101137320716211,
                                ],
                                [
                                    0.8676748228173017,
                                    0.11317282261997012,
                                    0.016942504709119118,
                                    0.002209849853609135,
                                ],
                                [
                                    0.8676748228173017,
                                    0.016942504709119118,
                                    0.11317282261997012,
                                    0.002209849853609135,
                                ],
                                [
                                    0.34422732875849077,
                                    0.04489836214451698,
                                    0.54038999876793,
                                    0.07048431032906227,
                                ],
                                [
                                    0.11317282261997012,
                                    0.002209849853609135,
                                    0.8676748228173017,
                                    0.016942504709119118,
                                ],
                                [
                                    0.11317282261997012,
                                    0.8676748228173017,
                                    0.002209849853609135,
                                    0.016942504709119118,
                                ],
                                [
                                    0.34422732875849077,
                                    0.54038999876793,
                                    0.04489836214451698,
                                    0.07048431032906227,
                                ],
                                [
                                    0.04489836214451698,
                                    0.34422732875849077,
                                    0.07048431032906227,
                                    0.54038999876793,
                                ],
                                [
                                    0.04489836214451698,
                                    0.07048431032906227,
                                    0.34422732875849077,
                                    0.54038999876793,
                                ],
                                [
                                    0.9643206072759002,
                                    0.023161429198712533,
                                    0.012224354208765768,
                                    0.0002936093166215051,
                                ],
                                [
                                    0.9643206072759002,
                                    0.012224354208765768,
                                    0.023161429198712533,
                                    0.0002936093166215051,
                                ],
                                [
                                    0.2483668658988873,
                                    0.00596537244607214,
                                    0.7281780955857786,
                                    0.017489666069261896,
                                ],
                                [
                                    0.023161429198712533,
                                    0.0002936093166215051,
                                    0.9643206072759002,
                                    0.012224354208765768,
                                ],
                                [
                                    0.023161429198712533,
                                    0.9643206072759002,
                                    0.0002936093166215051,
                                    0.012224354208765768,
                                ],
                                [
                                    0.2483668658988873,
                                    0.7281780955857786,
                                    0.00596537244607214,
                                    0.017489666069261896,
                                ],
                                [
                                    0.00596537244607214,
                                    0.2483668658988873,
                                    0.017489666069261896,
                                    0.7281780955857786,
                                ],
                                [
                                    0.00596537244607214,
                                    0.017489666069261896,
                                    0.2483668658988873,
                                    0.7281780955857786,
                                ],
                                [
                                    0.2547839472677427,
                                    0.6999987191194967,
                                    0.012066254602603986,
                                    0.03315107901015664,
                                ],
                                [
                                    0.2547839472677427,
                                    0.012066254602603986,
                                    0.6999987191194967,
                                    0.03315107901015664,
                                ],
                                [
                                    0.24515469591332736,
                                    0.6735431135507238,
                                    0.021695505957019315,
                                    0.05960668457892944,
                                ],
                                [
                                    0.20999501883997065,
                                    0.009945105999707968,
                                    0.7447876475472688,
                                    0.03527222761305266,
                                ],
                                [
                                    0.20999501883997065,
                                    0.7447876475472688,
                                    0.009945105999707968,
                                    0.03527222761305266,
                                ],
                                [
                                    0.24515469591332736,
                                    0.021695505957019315,
                                    0.6735431135507238,
                                    0.05960668457892944,
                                ],
                                [
                                    0.20205851090346272,
                                    0.7166392985605885,
                                    0.017881613936215908,
                                    0.06342057659973285,
                                ],
                                [
                                    0.20205851090346272,
                                    0.017881613936215908,
                                    0.7166392985605885,
                                    0.06342057659973285,
                                ],
                                [
                                    0.39252547708272695,
                                    0.5688915803418535,
                                    0.015752568383009063,
                                    0.022830374192410588,
                                ],
                                [
                                    0.39252547708272695,
                                    0.015752568383009063,
                                    0.5688915803418535,
                                    0.022830374192410588,
                                ],
                                [
                                    0.32005093866965756,
                                    0.46385341823634535,
                                    0.08822710679607838,
                                    0.12786853629791867,
                                ],
                                [
                                    0.17066373818806155,
                                    0.006848962330515941,
                                    0.7907533192365188,
                                    0.03173398024490371,
                                ],
                                [
                                    0.17066373818806155,
                                    0.7907533192365188,
                                    0.006848962330515941,
                                    0.03173398024490371,
                                ],
                                [
                                    0.32005093866965756,
                                    0.08822710679607838,
                                    0.46385341823634535,
                                    0.12786853629791867,
                                ],
                                [
                                    0.13915297934266338,
                                    0.6447513775633396,
                                    0.0383597211759141,
                                    0.17773592191808293,
                                ],
                                [
                                    0.13915297934266338,
                                    0.0383597211759141,
                                    0.6447513775633396,
                                    0.17773592191808293,
                                ],
                                [
                                    0.5976180217491144,
                                    0.3735143296818116,
                                    0.017764650724464825,
                                    0.011102997844609127,
                                ],
                                [
                                    0.5976180217491144,
                                    0.017764650724464825,
                                    0.3735143296818116,
                                    0.011102997844609127,
                                ],
                                [
                                    0.3609311828562597,
                                    0.2255838410482456,
                                    0.25445148961731956,
                                    0.15903348647817514,
                                ],
                                [
                                    0.1120518460336514,
                                    0.0033308264399278483,
                                    0.8590805053972747,
                                    0.0255368221291461,
                                ],
                                [
                                    0.1120518460336514,
                                    0.8590805053972747,
                                    0.0033308264399278483,
                                    0.0255368221291461,
                                ],
                                [
                                    0.3609311828562597,
                                    0.25445148961731956,
                                    0.2255838410482456,
                                    0.15903348647817514,
                                ],
                                [
                                    0.06767367090400704,
                                    0.5188413530004983,
                                    0.04770900156957222,
                                    0.36577597452592253,
                                ],
                                [
                                    0.06767367090400704,
                                    0.04770900156957222,
                                    0.5188413530004983,
                                    0.36577597452592253,
                                ],
                                [
                                    0.8067347310984134,
                                    0.17411291433885825,
                                    0.01575256838300906,
                                    0.0033997861797191906,
                                ],
                                [
                                    0.8067347310984134,
                                    0.01575256838300906,
                                    0.17411291433885825,
                                    0.0033997861797191906,
                                ],
                                [
                                    0.32005093866965756,
                                    0.06907475223335015,
                                    0.5024363608117649,
                                    0.1084379482852273,
                                ],
                                [
                                    0.05223273090108194,
                                    0.001019913527499079,
                                    0.9286149145361898,
                                    0.018132441035229173,
                                ],
                                [
                                    0.05223273090108194,
                                    0.9286149145361898,
                                    0.001019913527499079,
                                    0.018132441035229173,
                                ],
                                [
                                    0.32005093866965756,
                                    0.5024363608117649,
                                    0.06907475223335015,
                                    0.1084379482852273,
                                ],
                                [
                                    0.020721972055683796,
                                    0.368403718847324,
                                    0.032530672372897224,
                                    0.5783436367240951,
                                ],
                                [
                                    0.020721972055683796,
                                    0.032530672372897224,
                                    0.368403718847324,
                                    0.5783436367240951,
                                ],
                                [
                                    0.9518488884742078,
                                    0.03563314800040489,
                                    0.012066254602603986,
                                    0.00045170892278328803,
                                ],
                                [
                                    0.9518488884742078,
                                    0.012066254602603986,
                                    0.03563314800040489,
                                    0.00045170892278328803,
                                ],
                                [
                                    0.2451546959133274,
                                    0.009177542431632055,
                                    0.7187604471634844,
                                    0.02690731449155612,
                                ],
                                [
                                    0.010689710397020161,
                                    0.00013550971045972208,
                                    0.9767923260775926,
                                    0.012382453814927552,
                                ],
                                [
                                    0.010689710397020161,
                                    0.9767923260775926,
                                    0.00013550971045972208,
                                    0.012382453814927552,
                                ],
                                [
                                    0.2451546959133274,
                                    0.7187604471634844,
                                    0.009177542431632055,
                                    0.02690731449155612,
                                ],
                                [
                                    0.002753202460512221,
                                    0.25157903588444724,
                                    0.008072017646967663,
                                    0.7375957440080729,
                                ],
                                [
                                    0.002753202460512221,
                                    0.008072017646967663,
                                    0.25157903588444724,
                                    0.7375957440080729,
                                ],
                                [
                                    0.08747680477287623,
                                    0.8673058616143632,
                                    0.004142793961436688,
                                    0.04107453965132394,
                                ],
                                [
                                    0.08747680477287623,
                                    0.004142793961436688,
                                    0.8673058616143632,
                                    0.04107453965132394,
                                ],
                                [
                                    0.08417072466118863,
                                    0.8345270848028626,
                                    0.007448874073124278,
                                    0.07385331646282448,
                                ],
                                [
                                    0.04268787634510417,
                                    0.0020216453585406705,
                                    0.9120947900421352,
                                    0.043195688254219954,
                                ],
                                [
                                    0.04268787634510417,
                                    0.9120947900421352,
                                    0.0020216453585406705,
                                    0.043195688254219954,
                                ],
                                [
                                    0.08417072466118863,
                                    0.007448874073124278,
                                    0.8345270848028626,
                                    0.07385331646282448,
                                ],
                                [
                                    0.04107453965132397,
                                    0.8776232698127272,
                                    0.0036349820523208687,
                                    0.07766720848362789,
                                ],
                                [
                                    0.04107453965132397,
                                    0.0036349820523208687,
                                    0.8776232698127272,
                                    0.07766720848362789,
                                ],
                                [
                                    0.256554335855344,
                                    0.7048627215692365,
                                    0.010295866015002729,
                                    0.028287076560416922,
                                ],
                                [
                                    0.256554335855344,
                                    0.010295866015002729,
                                    0.7048627215692365,
                                    0.028287076560416922,
                                ],
                                [
                                    0.2091850358874112,
                                    0.5747193210185917,
                                    0.0576651659829355,
                                    0.15843047711106154,
                                ],
                                [
                                    0.03469259696067859,
                                    0.0013922599625096042,
                                    0.9267244604639018,
                                    0.037190682612910045,
                                ],
                                [
                                    0.03469259696067859,
                                    0.9267244604639018,
                                    0.0013922599625096042,
                                    0.037190682612910045,
                                ],
                                [
                                    0.2091850358874112,
                                    0.0576651659829355,
                                    0.5747193210185917,
                                    0.15843047711106154,
                                ],
                                [
                                    0.028287076560416964,
                                    0.755617280345586,
                                    0.0077977803627712235,
                                    0.2082978627312258,
                                ],
                                [
                                    0.028287076560416964,
                                    0.0077977803627712235,
                                    0.755617280345586,
                                    0.2082978627312258,
                                ],
                                [
                                    0.5083441224217623,
                                    0.4627882290091637,
                                    0.015110916093571732,
                                    0.013756732475502218,
                                ],
                                [
                                    0.5083441224217623,
                                    0.015110916093571732,
                                    0.4627882290091637,
                                    0.013756732475502218,
                                ],
                                [
                                    0.3070142444277549,
                                    0.2795007794767504,
                                    0.21644079408757916,
                                    0.19704418200791557,
                                ],
                                [
                                    0.02277794670629928,
                                    0.000677091809034757,
                                    0.9483544047246267,
                                    0.028190556760039193,
                                ],
                                [
                                    0.02277794670629928,
                                    0.9483544047246267,
                                    0.000677091809034757,
                                    0.028190556760039193,
                                ],
                                [
                                    0.3070142444277549,
                                    0.21644079408757916,
                                    0.2795007794767504,
                                    0.19704418200791557,
                                ],
                                [
                                    0.013756732475502234,
                                    0.572758291429003,
                                    0.009698306039831803,
                                    0.40378667005566293,
                                ],
                                [
                                    0.013756732475502234,
                                    0.009698306039831803,
                                    0.572758291429003,
                                    0.40378667005566293,
                                ],
                                [
                                    0.7651198918510934,
                                    0.21572775358617838,
                                    0.014939983309228012,
                                    0.00421237125350024,
                                ],
                                [
                                    0.7651198918510934,
                                    0.014939983309228012,
                                    0.21572775358617838,
                                    0.00421237125350024,
                                ],
                                [
                                    0.303541337867474,
                                    0.08558435303553372,
                                    0.4765185372928474,
                                    0.1343557718041449,
                                ],
                                [
                                    0.010617891653761853,
                                    0.00020732845371802995,
                                    0.97022975378351,
                                    0.01894502610901022,
                                ],
                                [
                                    0.010617891653761853,
                                    0.97022975378351,
                                    0.00020732845371802995,
                                    0.01894502610901022,
                                ],
                                [
                                    0.303541337867474,
                                    0.4765185372928474,
                                    0.08558435303553372,
                                    0.1343557718041449,
                                ],
                                [
                                    0.004212371253500241,
                                    0.3849133196495075,
                                    0.0066128488539796415,
                                    0.6042614602430126,
                                ],
                                [
                                    0.004212371253500241,
                                    0.0066128488539796415,
                                    0.3849133196495075,
                                    0.6042614602430126,
                                ],
                                [
                                    0.9433321869328917,
                                    0.044149849541721124,
                                    0.011958291363463536,
                                    0.000559672161923737,
                                ],
                                [
                                    0.9433321869328917,
                                    0.011958291363463536,
                                    0.044149849541721124,
                                    0.000559672161923737,
                                ],
                                [
                                    0.2429611656147389,
                                    0.011371072730220541,
                                    0.7123293126816163,
                                    0.03333844897342432,
                                ],
                                [
                                    0.0021730088557039614,
                                    2.7546471319273517e-05,
                                    0.9853090276189088,
                                    0.012490417054068,
                                ],
                                [
                                    0.0021730088557039614,
                                    0.9853090276189088,
                                    2.7546471319273517e-05,
                                    0.012490417054068,
                                ],
                                [
                                    0.2429611656147389,
                                    0.7123293126816163,
                                    0.011371072730220541,
                                    0.03333844897342432,
                                ],
                                [
                                    0.0005596721619237435,
                                    0.2537725661830357,
                                    0.0016408831650994913,
                                    0.7440268784899411,
                                ],
                                [
                                    0.0005596721619237435,
                                    0.0016408831650994913,
                                    0.2537725661830357,
                                    0.7440268784899411,
                                ],
                                [
                                    0.7427973738041531,
                                    0.034764415703936846,
                                    0.2124931044922021,
                                    0.009945105999707967,
                                ],
                                [
                                    0.7427973738041531,
                                    0.2124931044922021,
                                    0.034764415703936846,
                                    0.009945105999707967,
                                ],
                                [
                                    0.7083258535747451,
                                    0.033151079010156646,
                                    0.24696462472161004,
                                    0.011558442693488165,
                                ],
                                [
                                    0.7063218903622246,
                                    0.20205851090346266,
                                    0.07123989914586541,
                                    0.020379699588447413,
                                ],
                                [
                                    0.7063218903622246,
                                    0.07123989914586541,
                                    0.20205851090346266,
                                    0.020379699588447413,
                                ],
                                [
                                    0.7083258535747451,
                                    0.24696462472161004,
                                    0.033151079010156646,
                                    0.011558442693488165,
                                ],
                                [
                                    0.6735431135507239,
                                    0.06793381903417782,
                                    0.23483728771496323,
                                    0.023685779700135003,
                                ],
                                [
                                    0.6735431135507239,
                                    0.23483728771496323,
                                    0.06793381903417782,
                                    0.023685779700135003,
                                ],
                                [
                                    0.7809625400278404,
                                    0.029235894592672198,
                                    0.18295260304897135,
                                    0.0068489623305159385,
                                ],
                                [
                                    0.7809625400278404,
                                    0.18295260304897135,
                                    0.029235894592672198,
                                    0.0068489623305159385,
                                ],
                                [
                                    0.6098553599095247,
                                    0.022830374192410588,
                                    0.35405978316728715,
                                    0.013254482730777548,
                                ],
                                [
                                    0.5939968187869901,
                                    0.13915297934266332,
                                    0.2162016158335226,
                                    0.05064858603682397,
                                ],
                                [
                                    0.5939968187869901,
                                    0.2162016158335226,
                                    0.13915297934266332,
                                    0.05064858603682397,
                                ],
                                [
                                    0.6098553599095247,
                                    0.35405978316728715,
                                    0.022830374192410588,
                                    0.013254482730777548,
                                ],
                                [
                                    0.46385341823634546,
                                    0.16883231586558986,
                                    0.26929637989330796,
                                    0.09801788600475674,
                                ],
                                [
                                    0.46385341823634546,
                                    0.26929637989330796,
                                    0.16883231586558986,
                                    0.09801788600475674,
                                ],
                                [
                                    0.8378667932367241,
                                    0.02012421207540616,
                                    0.13867816824794188,
                                    0.0033308264399278475,
                                ],
                                [
                                    0.8378667932367241,
                                    0.13867816824794188,
                                    0.02012421207540616,
                                    0.0033308264399278475,
                                ],
                                [
                                    0.4622706799411003,
                                    0.011102997844609127,
                                    0.5142742815435656,
                                    0.012352040670724882,
                                ],
                                [
                                    0.4088712905806589,
                                    0.06767367090400701,
                                    0.44911971473147133,
                                    0.07433532378386272,
                                ],
                                [
                                    0.4088712905806589,
                                    0.44911971473147133,
                                    0.06767367090400701,
                                    0.07433532378386272,
                                ],
                                [
                                    0.4622706799411003,
                                    0.5142742815435656,
                                    0.011102997844609127,
                                    0.012352040670724882,
                                ],
                                [
                                    0.2255838410482456,
                                    0.24778983673746388,
                                    0.2509611204364204,
                                    0.27566520177787013,
                                ],
                                [
                                    0.2255838410482456,
                                    0.2509611204364204,
                                    0.24778983673746388,
                                    0.27566520177787013,
                                ],
                                [
                                    0.895978269423767,
                                    0.009805306579980803,
                                    0.09319651046875312,
                                    0.0010199135274990795,
                                ],
                                [
                                    0.895978269423767,
                                    0.09319651046875312,
                                    0.009805306579980803,
                                    0.0010199135274990795,
                                ],
                                [
                                    0.3106618352897646,
                                    0.0033997861797191915,
                                    0.6785129446027555,
                                    0.007425433927760691,
                                ],
                                [
                                    0.19921815278399482,
                                    0.0207219720556838,
                                    0.706565423219753,
                                    0.0734944519405684,
                                ],
                                [
                                    0.19921815278399482,
                                    0.706565423219753,
                                    0.0207219720556838,
                                    0.0734944519405684,
                                ],
                                [
                                    0.3106618352897646,
                                    0.6785129446027555,
                                    0.0033997861797191915,
                                    0.007425433927760691,
                                ],
                                [
                                    0.06907475223335016,
                                    0.24498686923613364,
                                    0.15086537260632846,
                                    0.5350730059241877,
                                ],
                                [
                                    0.06907475223335016,
                                    0.15086537260632846,
                                    0.24498686923613364,
                                    0.5350730059241877,
                                ],
                                [
                                    0.9363551754996071,
                                    0.0020650456165634875,
                                    0.061444269173369696,
                                    0.0001355097104597222,
                                ],
                                [
                                    0.9363551754996071,
                                    0.061444269173369696,
                                    0.0020650456165634875,
                                    0.0001355097104597222,
                                ],
                                [
                                    0.20481871406373403,
                                    0.0004517089227832882,
                                    0.7929807306092428,
                                    0.0017488464042399213,
                                ],
                                [
                                    0.04195631924313262,
                                    0.002753202460512222,
                                    0.896463901873038,
                                    0.0588265764233172,
                                ],
                                [
                                    0.04195631924313262,
                                    0.896463901873038,
                                    0.002753202460512222,
                                    0.0588265764233172,
                                ],
                                [
                                    0.20481871406373403,
                                    0.7929807306092428,
                                    0.0004517089227832882,
                                    0.0017488464042399213,
                                ],
                                [
                                    0.009177542431632053,
                                    0.19609288055488527,
                                    0.035531979272012786,
                                    0.7591975977414699,
                                ],
                                [
                                    0.009177542431632053,
                                    0.035531979272012786,
                                    0.19609288055488527,
                                    0.7591975977414699,
                                ],
                                [
                                    0.6065447524531168,
                                    0.17101703705497318,
                                    0.17351512270720465,
                                    0.048923087784705395,
                                ],
                                [
                                    0.6065447524531168,
                                    0.17351512270720465,
                                    0.17101703705497318,
                                    0.048923087784705395,
                                ],
                                [
                                    0.5783964034664365,
                                    0.1630805291184652,
                                    0.20166347169388488,
                                    0.056859595721213345,
                                ],
                                [
                                    0.5700692690111883,
                                    0.1630805291184652,
                                    0.20749252049690176,
                                    0.05935768137344485,
                                ],
                                [
                                    0.5700692690111883,
                                    0.20749252049690176,
                                    0.1630805291184652,
                                    0.05935768137344485,
                                ],
                                [
                                    0.5783964034664365,
                                    0.20166347169388488,
                                    0.1630805291184652,
                                    0.056859595721213345,
                                ],
                                [
                                    0.5436136634424154,
                                    0.1978632691424864,
                                    0.18953613468723804,
                                    0.06898693272786018,
                                ],
                                [
                                    0.5436136634424154,
                                    0.18953613468723804,
                                    0.1978632691424864,
                                    0.06898693272786018,
                                ],
                                [
                                    0.6663779225351014,
                                    0.14382051208541127,
                                    0.15610937694632118,
                                    0.03369218843316612,
                                ],
                                [
                                    0.6663779225351014,
                                    0.15610937694632118,
                                    0.14382051208541127,
                                    0.03369218843316612,
                                ],
                                [
                                    0.5203759808619222,
                                    0.11230975324001313,
                                    0.30211131861950047,
                                    0.06520294727856427,
                                ],
                                [
                                    0.47941220129425094,
                                    0.11230975324001315,
                                    0.3307862333262617,
                                    0.07749181213947416,
                                ],
                                [
                                    0.47941220129425094,
                                    0.3307862333262617,
                                    0.11230975324001315,
                                    0.07749181213947416,
                                ],
                                [
                                    0.5203759808619222,
                                    0.30211131861950047,
                                    0.11230975324001313,
                                    0.06520294727856427,
                                ],
                                [
                                    0.3743740391887429,
                                    0.2583116949131924,
                                    0.21734791534552125,
                                    0.14996635055254345,
                                ],
                                [
                                    0.3743740391887429,
                                    0.21734791534552125,
                                    0.2583116949131924,
                                    0.14996635055254345,
                                ],
                                [
                                    0.7589937101609238,
                                    0.09899729515120649,
                                    0.12562361736549701,
                                    0.016385377322372725,
                                ],
                                [
                                    0.7589937101609238,
                                    0.12562361736549701,
                                    0.09899729515120649,
                                    0.016385377322372725,
                                ],
                                [
                                    0.41875455776414733,
                                    0.05461912002156214,
                                    0.4658627697622734,
                                    0.06076355245201708,
                                ],
                                [
                                    0.3299982075048586,
                                    0.054619120021562134,
                                    0.5279927978072716,
                                    0.0873898746663076,
                                ],
                                [
                                    0.3299982075048586,
                                    0.5279927978072716,
                                    0.054619120021562134,
                                    0.0873898746663076,
                                ],
                                [
                                    0.41875455776414733,
                                    0.4658627697622734,
                                    0.05461912002156214,
                                    0.06076355245201708,
                                ],
                                [
                                    0.18206771887129258,
                                    0.2913059589144169,
                                    0.20254960865512817,
                                    0.32407671355916234,
                                ],
                                [
                                    0.18206771887129258,
                                    0.20254960865512817,
                                    0.2913059589144169,
                                    0.32407671355916234,
                                ],
                                [
                                    0.8575482053015716,
                                    0.04823537070217619,
                                    0.08919915026984736,
                                    0.005017273726404849,
                                ],
                                [
                                    0.8575482053015716,
                                    0.08919915026984736,
                                    0.04823537070217619,
                                    0.005017273726404849,
                                ],
                                [
                                    0.29733700961270576,
                                    0.016724611856778034,
                                    0.6494103459587132,
                                    0.03652803257180301,
                                ],
                                [
                                    0.16078808866179944,
                                    0.016724611856778034,
                                    0.7449954873419483,
                                    0.07749181213947416,
                                ],
                                [
                                    0.16078808866179944,
                                    0.7449954873419483,
                                    0.016724611856778034,
                                    0.07749181213947416,
                                ],
                                [
                                    0.29733700961270576,
                                    0.6494103459587132,
                                    0.016724611856778034,
                                    0.03652803257180301,
                                ],
                                [
                                    0.055749926556291324,
                                    0.2583116949131925,
                                    0.12176277396228616,
                                    0.56417560456823,
                                ],
                                [
                                    0.055749926556291324,
                                    0.12176277396228616,
                                    0.2583116949131925,
                                    0.56417560456823,
                                ],
                                [
                                    0.9282616156692781,
                                    0.010158605446892498,
                                    0.06091316422324203,
                                    0.0006666146605873959,
                                ],
                                [
                                    0.9282616156692781,
                                    0.06091316422324203,
                                    0.010158605446892498,
                                    0.0006666146605873959,
                                ],
                                [
                                    0.20304832547613277,
                                    0.0022220975103845503,
                                    0.7861264544163874,
                                    0.008603122597095343,
                                ],
                                [
                                    0.033862759412803645,
                                    0.00222209751038455,
                                    0.904557461703367,
                                    0.05935768137344487,
                                ],
                                [
                                    0.033862759412803645,
                                    0.904557461703367,
                                    0.00222209751038455,
                                    0.05935768137344487,
                                ],
                                [
                                    0.20304832547613277,
                                    0.7861264544163874,
                                    0.0022220975103845503,
                                    0.008603122597095343,
                                ],
                                [
                                    0.007407153844030798,
                                    0.19786326914248653,
                                    0.028677703079157395,
                                    0.7660518739343253,
                                ],
                                [
                                    0.007407153844030798,
                                    0.028677703079157395,
                                    0.19786326914248653,
                                    0.7660518739343253,
                                ],
                                [
                                    0.4070186364750093,
                                    0.37054315303308066,
                                    0.11643640204032477,
                                    0.1060018084515853,
                                ],
                                [
                                    0.4070186364750093,
                                    0.11643640204032477,
                                    0.37054315303308066,
                                    0.1060018084515853,
                                ],
                                [
                                    0.3881298363044615,
                                    0.35334709628044025,
                                    0.13532520221087255,
                                    0.12319786520422568,
                                ],
                                [
                                    0.37054315303308066,
                                    0.1060018084515853,
                                    0.4070186364750093,
                                    0.11643640204032477,
                                ],
                                [
                                    0.37054315303308066,
                                    0.4070186364750093,
                                    0.1060018084515853,
                                    0.11643640204032477,
                                ],
                                [
                                    0.3881298363044615,
                                    0.13532520221087255,
                                    0.35334709628044025,
                                    0.12319786520422568,
                                ],
                                [
                                    0.35334709628044025,
                                    0.3881298363044615,
                                    0.12319786520422568,
                                    0.13532520221087255,
                                ],
                                [
                                    0.35334709628044025,
                                    0.12319786520422568,
                                    0.3881298363044615,
                                    0.13532520221087255,
                                ],
                                [
                                    0.49858207793068154,
                                    0.3116163566898311,
                                    0.11680059454289768,
                                    0.07300097083658963,
                                ],
                                [
                                    0.49858207793068154,
                                    0.11680059454289768,
                                    0.3116163566898311,
                                    0.07300097083658963,
                                ],
                                [
                                    0.3893438378875573,
                                    0.243341896214378,
                                    0.22603883458602195,
                                    0.14127543131204276,
                                ],
                                [
                                    0.3116163566898312,
                                    0.07300097083658966,
                                    0.4985820779306815,
                                    0.11680059454289765,
                                ],
                                [
                                    0.3116163566898312,
                                    0.4985820779306815,
                                    0.07300097083658966,
                                    0.11680059454289765,
                                ],
                                [
                                    0.3893438378875573,
                                    0.22603883458602195,
                                    0.243341896214378,
                                    0.14127543131204276,
                                ],
                                [
                                    0.24334189621437807,
                                    0.3893438378875572,
                                    0.1412754313120428,
                                    0.22603883458602192,
                                ],
                                [
                                    0.24334189621437807,
                                    0.1412754313120428,
                                    0.3893438378875572,
                                    0.22603883458602192,
                                ],
                                [
                                    0.6434932539840976,
                                    0.21449775132803256,
                                    0.10650674601590229,
                                    0.03550224867196743,
                                ],
                                [
                                    0.6434932539840976,
                                    0.10650674601590229,
                                    0.21449775132803256,
                                    0.03550224867196743,
                                ],
                                [
                                    0.35503025833928215,
                                    0.11834341944642737,
                                    0.39496974166071785,
                                    0.13165658055357263,
                                ],
                                [
                                    0.21449775132803256,
                                    0.03550224867196743,
                                    0.6434932539840976,
                                    0.10650674601590229,
                                ],
                                [
                                    0.21449775132803256,
                                    0.6434932539840976,
                                    0.03550224867196743,
                                    0.10650674601590229,
                                ],
                                [
                                    0.35503025833928215,
                                    0.39496974166071785,
                                    0.11834341944642737,
                                    0.13165658055357263,
                                ],
                                [
                                    0.11834341944642737,
                                    0.35503025833928215,
                                    0.13165658055357263,
                                    0.39496974166071785,
                                ],
                                [
                                    0.11834341944642737,
                                    0.13165658055357263,
                                    0.35503025833928215,
                                    0.39496974166071785,
                                ],
                                [
                                    0.80127184632176,
                                    0.10451172968198781,
                                    0.08334548120466076,
                                    0.01087094279159144,
                                ],
                                [
                                    0.80127184632176,
                                    0.08334548120466076,
                                    0.10451172968198781,
                                    0.01087094279159144,
                                ],
                                [
                                    0.2778243522629491,
                                    0.036237269206534674,
                                    0.6067929752634716,
                                    0.07914540326704457,
                                ],
                                [
                                    0.10451172968198781,
                                    0.01087094279159144,
                                    0.80127184632176,
                                    0.08334548120466076,
                                ],
                                [
                                    0.10451172968198781,
                                    0.80127184632176,
                                    0.01087094279159144,
                                    0.08334548120466076,
                                ],
                                [
                                    0.2778243522629491,
                                    0.6067929752634716,
                                    0.036237269206534674,
                                    0.07914540326704457,
                                ],
                                [
                                    0.036237269206534674,
                                    0.2778243522629491,
                                    0.07914540326704457,
                                    0.6067929752634716,
                                ],
                                [
                                    0.036237269206534674,
                                    0.07914540326704457,
                                    0.2778243522629491,
                                    0.6067929752634716,
                                ],
                                [
                                    0.9164095386863226,
                                    0.022010682429848064,
                                    0.06013542279834345,
                                    0.0014443560854859726,
                                ],
                                [
                                    0.9164095386863226,
                                    0.06013542279834345,
                                    0.022010682429848064,
                                    0.0014443560854859726,
                                ],
                                [
                                    0.20045579730930965,
                                    0.004814625677207673,
                                    0.7760891641753563,
                                    0.018640412838126365,
                                ],
                                [
                                    0.022010682429848064,
                                    0.0014443560854859726,
                                    0.9164095386863226,
                                    0.06013542279834345,
                                ],
                                [
                                    0.022010682429848064,
                                    0.9164095386863226,
                                    0.0014443560854859726,
                                    0.06013542279834345,
                                ],
                                [
                                    0.20045579730930965,
                                    0.7760891641753563,
                                    0.004814625677207673,
                                    0.018640412838126365,
                                ],
                                [
                                    0.004814625677207673,
                                    0.20045579730930965,
                                    0.018640412838126365,
                                    0.7760891641753563,
                                ],
                                [
                                    0.004814625677207673,
                                    0.018640412838126365,
                                    0.20045579730930965,
                                    0.7760891641753563,
                                ],
                                [
                                    0.20749252049690184,
                                    0.5700692690111882,
                                    0.05935768137344487,
                                    0.16308052911846518,
                                ],
                                [
                                    0.20749252049690184,
                                    0.05935768137344487,
                                    0.5700692690111882,
                                    0.16308052911846518,
                                ],
                                [
                                    0.19786326914248648,
                                    0.5436136634424152,
                                    0.0689869327278602,
                                    0.189536134687238,
                                ],
                                [
                                    0.1710170370549732,
                                    0.04892308778470541,
                                    0.6065447524531168,
                                    0.17351512270720465,
                                ],
                                [
                                    0.1710170370549732,
                                    0.6065447524531168,
                                    0.04892308778470541,
                                    0.17351512270720465,
                                ],
                                [
                                    0.19786326914248648,
                                    0.0689869327278602,
                                    0.5436136634424152,
                                    0.189536134687238,
                                ],
                                [
                                    0.16308052911846527,
                                    0.5783964034664365,
                                    0.05685959572121336,
                                    0.20166347169388488,
                                ],
                                [
                                    0.16308052911846527,
                                    0.05685959572121336,
                                    0.5783964034664365,
                                    0.20166347169388488,
                                ],
                                [
                                    0.3307862333262618,
                                    0.4794122012942509,
                                    0.07749181213947418,
                                    0.11230975324001313,
                                ],
                                [
                                    0.3307862333262618,
                                    0.07749181213947418,
                                    0.4794122012942509,
                                    0.11230975324001313,
                                ],
                                [
                                    0.2583116949131925,
                                    0.3743740391887428,
                                    0.1499663505525435,
                                    0.2173479153455212,
                                ],
                                [
                                    0.14382051208541136,
                                    0.03369218843316613,
                                    0.6663779225351013,
                                    0.15610937694632118,
                                ],
                                [
                                    0.14382051208541136,
                                    0.6663779225351013,
                                    0.03369218843316613,
                                    0.15610937694632118,
                                ],
                                [
                                    0.2583116949131925,
                                    0.1499663505525435,
                                    0.3743740391887428,
                                    0.2173479153455212,
                                ],
                                [
                                    0.11230975324001319,
                                    0.5203759808619222,
                                    0.0652029472785643,
                                    0.3021113186195004,
                                ],
                                [
                                    0.11230975324001319,
                                    0.0652029472785643,
                                    0.5203759808619222,
                                    0.3021113186195004,
                                ],
                                [
                                    0.5279927978072716,
                                    0.3299982075048586,
                                    0.0873898746663076,
                                    0.054619120021562134,
                                ],
                                [
                                    0.5279927978072716,
                                    0.0873898746663076,
                                    0.3299982075048586,
                                    0.054619120021562134,
                                ],
                                [
                                    0.2913059589144169,
                                    0.18206771887129258,
                                    0.32407671355916234,
                                    0.20254960865512817,
                                ],
                                [
                                    0.09899729515120652,
                                    0.01638537732237273,
                                    0.7589937101609238,
                                    0.12562361736549701,
                                ],
                                [
                                    0.09899729515120652,
                                    0.7589937101609238,
                                    0.01638537732237273,
                                    0.12562361736549701,
                                ],
                                [
                                    0.2913059589144169,
                                    0.32407671355916234,
                                    0.18206771887129258,
                                    0.20254960865512817,
                                ],
                                [
                                    0.054619120021562155,
                                    0.41875455776414733,
                                    0.060763552452017096,
                                    0.4658627697622734,
                                ],
                                [
                                    0.054619120021562155,
                                    0.060763552452017096,
                                    0.41875455776414733,
                                    0.4658627697622734,
                                ],
                                [
                                    0.7449954873419483,
                                    0.16078808866179942,
                                    0.07749181213947416,
                                    0.01672461185677803,
                                ],
                                [
                                    0.7449954873419483,
                                    0.07749181213947416,
                                    0.16078808866179942,
                                    0.01672461185677803,
                                ],
                                [
                                    0.2583116949131925,
                                    0.05574992655629131,
                                    0.56417560456823,
                                    0.12176277396228614,
                                ],
                                [
                                    0.04823537070217617,
                                    0.005017273726404847,
                                    0.8575482053015716,
                                    0.08919915026984736,
                                ],
                                [
                                    0.04823537070217617,
                                    0.8575482053015716,
                                    0.005017273726404847,
                                    0.08919915026984736,
                                ],
                                [
                                    0.2583116949131925,
                                    0.56417560456823,
                                    0.05574992655629131,
                                    0.12176277396228614,
                                ],
                                [
                                    0.016724611856778027,
                                    0.29733700961270576,
                                    0.03652803257180299,
                                    0.6494103459587132,
                                ],
                                [
                                    0.016724611856778027,
                                    0.03652803257180299,
                                    0.29733700961270576,
                                    0.6494103459587132,
                                ],
                                [
                                    0.904557461703367,
                                    0.03386275941280363,
                                    0.05935768137344487,
                                    0.002222097510384549,
                                ],
                                [
                                    0.904557461703367,
                                    0.05935768137344487,
                                    0.03386275941280363,
                                    0.002222097510384549,
                                ],
                                [
                                    0.19786326914248653,
                                    0.007407153844030795,
                                    0.7660518739343253,
                                    0.02867770307915738,
                                ],
                                [
                                    0.010158605446892488,
                                    0.0006666146605873954,
                                    0.9282616156692781,
                                    0.06091316422324203,
                                ],
                                [
                                    0.010158605446892488,
                                    0.9282616156692781,
                                    0.0006666146605873954,
                                    0.06091316422324203,
                                ],
                                [
                                    0.19786326914248653,
                                    0.7660518739343253,
                                    0.007407153844030795,
                                    0.02867770307915738,
                                ],
                                [
                                    0.002222097510384548,
                                    0.20304832547613277,
                                    0.008603122597095334,
                                    0.7861264544163874,
                                ],
                                [
                                    0.002222097510384548,
                                    0.008603122597095334,
                                    0.20304832547613277,
                                    0.7861264544163874,
                                ],
                                [
                                    0.07123989914586548,
                                    0.7063218903622245,
                                    0.020379699588447434,
                                    0.20205851090346263,
                                ],
                                [
                                    0.07123989914586548,
                                    0.020379699588447434,
                                    0.7063218903622245,
                                    0.20205851090346263,
                                ],
                                [
                                    0.06793381903417789,
                                    0.6735431135507239,
                                    0.023685779700135027,
                                    0.2348372877149632,
                                ],
                                [
                                    0.03476441570393687,
                                    0.009945105999707972,
                                    0.7427973738041531,
                                    0.2124931044922021,
                                ],
                                [
                                    0.03476441570393687,
                                    0.7427973738041531,
                                    0.009945105999707972,
                                    0.2124931044922021,
                                ],
                                [
                                    0.06793381903417789,
                                    0.023685779700135027,
                                    0.6735431135507239,
                                    0.2348372877149632,
                                ],
                                [
                                    0.03315107901015667,
                                    0.7083258535747451,
                                    0.011558442693488172,
                                    0.24696462472161004,
                                ],
                                [
                                    0.03315107901015667,
                                    0.011558442693488172,
                                    0.7083258535747451,
                                    0.24696462472161004,
                                ],
                                [
                                    0.21620161583352268,
                                    0.59399681878699,
                                    0.05064858603682399,
                                    0.13915297934266332,
                                ],
                                [
                                    0.21620161583352268,
                                    0.05064858603682399,
                                    0.59399681878699,
                                    0.13915297934266332,
                                ],
                                [
                                    0.16883231586558992,
                                    0.46385341823634535,
                                    0.09801788600475676,
                                    0.26929637989330796,
                                ],
                                [
                                    0.029235894592672243,
                                    0.006848962330515949,
                                    0.7809625400278404,
                                    0.18295260304897135,
                                ],
                                [
                                    0.029235894592672243,
                                    0.7809625400278404,
                                    0.006848962330515949,
                                    0.18295260304897135,
                                ],
                                [
                                    0.16883231586558992,
                                    0.09801788600475676,
                                    0.46385341823634535,
                                    0.26929637989330796,
                                ],
                                [
                                    0.022830374192410623,
                                    0.6098553599095247,
                                    0.013254482730777568,
                                    0.35405978316728715,
                                ],
                                [
                                    0.022830374192410623,
                                    0.013254482730777568,
                                    0.6098553599095247,
                                    0.35405978316728715,
                                ],
                                [
                                    0.44911971473147133,
                                    0.4088712905806589,
                                    0.07433532378386272,
                                    0.06767367090400701,
                                ],
                                [
                                    0.44911971473147133,
                                    0.07433532378386272,
                                    0.4088712905806589,
                                    0.06767367090400701,
                                ],
                                [
                                    0.24778983673746388,
                                    0.2255838410482456,
                                    0.27566520177787013,
                                    0.2509611204364204,
                                ],
                                [
                                    0.020124212075406184,
                                    0.0033308264399278514,
                                    0.8378667932367241,
                                    0.13867816824794188,
                                ],
                                [
                                    0.020124212075406184,
                                    0.8378667932367241,
                                    0.0033308264399278514,
                                    0.13867816824794188,
                                ],
                                [
                                    0.24778983673746388,
                                    0.27566520177787013,
                                    0.2255838410482456,
                                    0.2509611204364204,
                                ],
                                [
                                    0.01110299784460914,
                                    0.4622706799411003,
                                    0.012352040670724897,
                                    0.5142742815435656,
                                ],
                                [
                                    0.01110299784460914,
                                    0.012352040670724897,
                                    0.4622706799411003,
                                    0.5142742815435656,
                                ],
                                [
                                    0.706565423219753,
                                    0.19921815278399482,
                                    0.0734944519405684,
                                    0.0207219720556838,
                                ],
                                [
                                    0.706565423219753,
                                    0.0734944519405684,
                                    0.19921815278399482,
                                    0.0207219720556838,
                                ],
                                [
                                    0.24498686923613364,
                                    0.06907475223335016,
                                    0.5350730059241877,
                                    0.15086537260632846,
                                ],
                                [
                                    0.009805306579980803,
                                    0.0010199135274990795,
                                    0.895978269423767,
                                    0.09319651046875312,
                                ],
                                [
                                    0.009805306579980803,
                                    0.895978269423767,
                                    0.0010199135274990795,
                                    0.09319651046875312,
                                ],
                                [
                                    0.24498686923613364,
                                    0.5350730059241877,
                                    0.06907475223335016,
                                    0.15086537260632846,
                                ],
                                [
                                    0.0033997861797191915,
                                    0.3106618352897646,
                                    0.007425433927760691,
                                    0.6785129446027555,
                                ],
                                [
                                    0.0033997861797191915,
                                    0.007425433927760691,
                                    0.3106618352897646,
                                    0.6785129446027555,
                                ],
                                [
                                    0.896463901873038,
                                    0.04195631924313264,
                                    0.0588265764233172,
                                    0.002753202460512223,
                                ],
                                [
                                    0.896463901873038,
                                    0.0588265764233172,
                                    0.04195631924313264,
                                    0.002753202460512223,
                                ],
                                [
                                    0.19609288055488527,
                                    0.009177542431632057,
                                    0.7591975977414699,
                                    0.0355319792720128,
                                ],
                                [
                                    0.002065045616563511,
                                    0.00013550971045972373,
                                    0.9363551754996071,
                                    0.061444269173369696,
                                ],
                                [
                                    0.002065045616563511,
                                    0.9363551754996071,
                                    0.00013550971045972373,
                                    0.061444269173369696,
                                ],
                                [
                                    0.19609288055488527,
                                    0.7591975977414699,
                                    0.009177542431632057,
                                    0.0355319792720128,
                                ],
                                [
                                    0.00045170892278329335,
                                    0.20481871406373403,
                                    0.0017488464042399415,
                                    0.7929807306092428,
                                ],
                                [
                                    0.00045170892278329335,
                                    0.0017488464042399415,
                                    0.20481871406373403,
                                    0.7929807306092428,
                                ],
                                [
                                    0.4948809992628816,
                                    0.023161429198712506,
                                    0.46040947903347357,
                                    0.021548092504932306,
                                ],
                                [
                                    0.4948809992628816,
                                    0.46040947903347357,
                                    0.023161429198712506,
                                    0.021548092504932306,
                                ],
                                [
                                    0.46040947903347357,
                                    0.021548092504932306,
                                    0.4948809992628816,
                                    0.023161429198712506,
                                ],
                                [
                                    0.4705795890385939,
                                    0.4378008122270933,
                                    0.04746283942300021,
                                    0.04415675931131262,
                                ],
                                [
                                    0.4705795890385939,
                                    0.04746283942300021,
                                    0.4378008122270933,
                                    0.04415675931131262,
                                ],
                                [
                                    0.46040947903347357,
                                    0.4948809992628816,
                                    0.021548092504932306,
                                    0.023161429198712506,
                                ],
                                [
                                    0.4378008122270933,
                                    0.04415675931131262,
                                    0.4705795890385939,
                                    0.04746283942300021,
                                ],
                                [
                                    0.4378008122270933,
                                    0.4705795890385939,
                                    0.04415675931131262,
                                    0.04746283942300021,
                                ],
                                [
                                    0.5675111615975639,
                                    0.021245188661724874,
                                    0.39640398147924805,
                                    0.014839668261463263,
                                ],
                                [
                                    0.5675111615975639,
                                    0.39640398147924805,
                                    0.021245188661724874,
                                    0.014839668261463263,
                                ],
                                [
                                    0.396403981479248,
                                    0.014839668261463261,
                                    0.5675111615975639,
                                    0.021245188661724874,
                                ],
                                [
                                    0.43164659934014904,
                                    0.3015031987895044,
                                    0.15710975091913967,
                                    0.10974045095120692,
                                ],
                                [
                                    0.43164659934014904,
                                    0.15710975091913967,
                                    0.3015031987895044,
                                    0.10974045095120692,
                                ],
                                [
                                    0.396403981479248,
                                    0.5675111615975639,
                                    0.014839668261463261,
                                    0.021245188661724874,
                                ],
                                [
                                    0.3015031987895044,
                                    0.10974045095120691,
                                    0.43164659934014904,
                                    0.15710975091913967,
                                ],
                                [
                                    0.3015031987895044,
                                    0.43164659934014904,
                                    0.10974045095120691,
                                    0.15710975091913967,
                                ],
                                [
                                    0.6760705373901448,
                                    0.01623812637306552,
                                    0.30047442409452113,
                                    0.007216912142268488,
                                ],
                                [
                                    0.6760705373901448,
                                    0.30047442409452113,
                                    0.01623812637306552,
                                    0.007216912142268488,
                                ],
                                [
                                    0.3004744240945212,
                                    0.0072169121422684885,
                                    0.6760705373901448,
                                    0.01623812637306552,
                                ],
                                [
                                    0.3299162055085396,
                                    0.14662875597612632,
                                    0.3623924582546707,
                                    0.1610625802606633,
                                ],
                                [
                                    0.3299162055085396,
                                    0.3623924582546707,
                                    0.14662875597612632,
                                    0.1610625802606633,
                                ],
                                [
                                    0.3004744240945212,
                                    0.6760705373901448,
                                    0.0072169121422684885,
                                    0.01623812637306552,
                                ],
                                [
                                    0.14662875597612635,
                                    0.16106258026066333,
                                    0.3299162055085396,
                                    0.3623924582546707,
                                ],
                                [
                                    0.14662875597612635,
                                    0.3299162055085396,
                                    0.16106258026066333,
                                    0.3623924582546707,
                                ],
                                [
                                    0.7872456070132613,
                                    0.008615370253870748,
                                    0.20192917287925885,
                                    0.0022098498536091355,
                                ],
                                [
                                    0.7872456070132613,
                                    0.20192917287925885,
                                    0.008615370253870748,
                                    0.0022098498536091355,
                                ],
                                [
                                    0.20192917287925885,
                                    0.0022098498536091355,
                                    0.7872456070132613,
                                    0.008615370253870748,
                                ],
                                [
                                    0.17504176269516164,
                                    0.04489836214451698,
                                    0.6208192145719703,
                                    0.159240660588351,
                                ],
                                [
                                    0.17504176269516164,
                                    0.6208192145719703,
                                    0.04489836214451698,
                                    0.159240660588351,
                                ],
                                [
                                    0.20192917287925885,
                                    0.7872456070132613,
                                    0.0022098498536091355,
                                    0.008615370253870748,
                                ],
                                [
                                    0.04489836214451698,
                                    0.159240660588351,
                                    0.17504176269516164,
                                    0.6208192145719703,
                                ],
                                [
                                    0.04489836214451698,
                                    0.17504176269516164,
                                    0.159240660588351,
                                    0.6208192145719703,
                                ],
                                [
                                    0.8646679530544249,
                                    0.0019069460104017045,
                                    0.13313149161855184,
                                    0.0002936093166215051,
                                ],
                                [
                                    0.8646679530544249,
                                    0.13313149161855184,
                                    0.0019069460104017045,
                                    0.0002936093166215051,
                                ],
                                [
                                    0.13313149161855184,
                                    0.0002936093166215051,
                                    0.8646679530544249,
                                    0.0019069460104017045,
                                ],
                                [
                                    0.038744149257572705,
                                    0.005965372446072136,
                                    0.8278307498072539,
                                    0.1274597284891012,
                                ],
                                [
                                    0.038744149257572705,
                                    0.8278307498072539,
                                    0.005965372446072136,
                                    0.1274597284891012,
                                ],
                                [
                                    0.13313149161855184,
                                    0.8646679530544249,
                                    0.0002936093166215051,
                                    0.0019069460104017045,
                                ],
                                [
                                    0.005965372446072136,
                                    0.1274597284891012,
                                    0.038744149257572705,
                                    0.8278307498072539,
                                ],
                                [
                                    0.005965372446072136,
                                    0.038744149257572705,
                                    0.1274597284891012,
                                    0.8278307498072539,
                                ],
                                [
                                    0.40410411207350083,
                                    0.11393831638809326,
                                    0.37595576308682055,
                                    0.1060018084515853,
                                ],
                                [
                                    0.40410411207350083,
                                    0.37595576308682055,
                                    0.11393831638809326,
                                    0.1060018084515853,
                                ],
                                [
                                    0.37595576308682055,
                                    0.1060018084515853,
                                    0.40410411207350083,
                                    0.11393831638809326,
                                ],
                                [
                                    0.3798027018492131,
                                    0.3533470962804403,
                                    0.13823972661238096,
                                    0.12861047525796562,
                                ],
                                [
                                    0.3798027018492131,
                                    0.13823972661238096,
                                    0.3533470962804403,
                                    0.12861047525796562,
                                ],
                                [
                                    0.37595576308682055,
                                    0.40410411207350083,
                                    0.1060018084515853,
                                    0.11393831638809326,
                                ],
                                [
                                    0.3533470962804403,
                                    0.12861047525796562,
                                    0.3798027018492131,
                                    0.13823972661238096,
                                ],
                                [
                                    0.3533470962804403,
                                    0.3798027018492131,
                                    0.12861047525796562,
                                    0.13823972661238096,
                                ],
                                [
                                    0.484244620577301,
                                    0.10451172968198778,
                                    0.3382426789041217,
                                    0.07300097083658963,
                                ],
                                [
                                    0.484244620577301,
                                    0.3382426789041217,
                                    0.10451172968198778,
                                    0.07300097083658963,
                                ],
                                [
                                    0.33824267890412163,
                                    0.07300097083658962,
                                    0.484244620577301,
                                    0.10451172968198778,
                                ],
                                [
                                    0.34838005831988617,
                                    0.24334189621437802,
                                    0.2403762919394026,
                                    0.1679017535263333,
                                ],
                                [
                                    0.34838005831988617,
                                    0.2403762919394026,
                                    0.24334189621437802,
                                    0.1679017535263333,
                                ],
                                [
                                    0.33824267890412163,
                                    0.484244620577301,
                                    0.07300097083658962,
                                    0.10451172968198778,
                                ],
                                [
                                    0.243341896214378,
                                    0.16790175352633327,
                                    0.34838005831988617,
                                    0.2403762919394026,
                                ],
                                [
                                    0.243341896214378,
                                    0.34838005831988617,
                                    0.16790175352633327,
                                    0.2403762919394026,
                                ],
                                [
                                    0.6124282399615986,
                                    0.07988042380161178,
                                    0.2721890875648222,
                                    0.03550224867196743,
                                ],
                                [
                                    0.6124282399615986,
                                    0.2721890875648222,
                                    0.07988042380161178,
                                    0.03550224867196743,
                                ],
                                [
                                    0.27218908756482224,
                                    0.03550224867196744,
                                    0.6124282399615986,
                                    0.07988042380161178,
                                ],
                                [
                                    0.26627390807999335,
                                    0.11834341944642737,
                                    0.42603475568321697,
                                    0.18934791679036225,
                                ],
                                [
                                    0.26627390807999335,
                                    0.42603475568321697,
                                    0.11834341944642737,
                                    0.18934791679036225,
                                ],
                                [
                                    0.27218908756482224,
                                    0.6124282399615986,
                                    0.03550224867196744,
                                    0.07988042380161178,
                                ],
                                [
                                    0.11834341944642739,
                                    0.18934791679036228,
                                    0.26627390807999335,
                                    0.42603475568321697,
                                ],
                                [
                                    0.11834341944642739,
                                    0.26627390807999335,
                                    0.18934791679036228,
                                    0.42603475568321697,
                                ],
                                [
                                    0.7534792756301424,
                                    0.0423817016369896,
                                    0.19326807994127657,
                                    0.010870942791591441,
                                ],
                                [
                                    0.7534792756301424,
                                    0.19326807994127657,
                                    0.0423817016369896,
                                    0.010870942791591441,
                                ],
                                [
                                    0.19326807994127657,
                                    0.010870942791591441,
                                    0.7534792756301424,
                                    0.0423817016369896,
                                ],
                                [
                                    0.14127543131204282,
                                    0.036237269206534674,
                                    0.6545855459550892,
                                    0.16790175352633332,
                                ],
                                [
                                    0.14127543131204282,
                                    0.6545855459550892,
                                    0.036237269206534674,
                                    0.16790175352633332,
                                ],
                                [
                                    0.19326807994127657,
                                    0.7534792756301424,
                                    0.010870942791591441,
                                    0.0423817016369896,
                                ],
                                [
                                    0.036237269206534674,
                                    0.16790175352633332,
                                    0.14127543131204282,
                                    0.6545855459550892,
                                ],
                                [
                                    0.036237269206534674,
                                    0.14127543131204282,
                                    0.16790175352633332,
                                    0.6545855459550892,
                                ],
                                [
                                    0.8571940350428328,
                                    0.00938086402199392,
                                    0.1319807448496874,
                                    0.0014443560854859728,
                                ],
                                [
                                    0.8571940350428328,
                                    0.1319807448496874,
                                    0.00938086402199392,
                                    0.0014443560854859728,
                                ],
                                [
                                    0.1319807448496874,
                                    0.0014443560854859728,
                                    0.8571940350428328,
                                    0.00938086402199392,
                                ],
                                [
                                    0.031270231245980516,
                                    0.004814625677207673,
                                    0.8353046678188462,
                                    0.12861047525796568,
                                ],
                                [
                                    0.031270231245980516,
                                    0.8353046678188462,
                                    0.004814625677207673,
                                    0.12861047525796568,
                                ],
                                [
                                    0.1319807448496874,
                                    0.8571940350428328,
                                    0.0014443560854859728,
                                    0.00938086402199392,
                                ],
                                [
                                    0.004814625677207673,
                                    0.12861047525796568,
                                    0.031270231245980516,
                                    0.8353046678188462,
                                ],
                                [
                                    0.004814625677207673,
                                    0.031270231245980516,
                                    0.12861047525796568,
                                    0.8353046678188462,
                                ],
                                [
                                    0.27117191934294094,
                                    0.2468705091186532,
                                    0.2522831191723931,
                                    0.22967445236601278,
                                ],
                                [
                                    0.27117191934294094,
                                    0.2522831191723931,
                                    0.2468705091186532,
                                    0.22967445236601278,
                                ],
                                [
                                    0.2522831191723931,
                                    0.22967445236601278,
                                    0.27117191934294094,
                                    0.2468705091186532,
                                ],
                                [
                                    0.2468705091186532,
                                    0.22967445236601278,
                                    0.27117191934294094,
                                    0.2522831191723931,
                                ],
                                [
                                    0.2468705091186532,
                                    0.27117191934294094,
                                    0.22967445236601278,
                                    0.2522831191723931,
                                ],
                                [
                                    0.2522831191723931,
                                    0.27117191934294094,
                                    0.22967445236601278,
                                    0.2468705091186532,
                                ],
                                [
                                    0.22967445236601278,
                                    0.2522831191723931,
                                    0.2468705091186532,
                                    0.27117191934294094,
                                ],
                                [
                                    0.22967445236601278,
                                    0.2468705091186532,
                                    0.2522831191723931,
                                    0.27117191934294094,
                                ],
                                [
                                    0.3623104562583518,
                                    0.22644589400093695,
                                    0.2530722162152275,
                                    0.15817143352548382,
                                ],
                                [
                                    0.3623104562583518,
                                    0.2530722162152275,
                                    0.22644589400093695,
                                    0.15817143352548382,
                                ],
                                [
                                    0.25307221621522746,
                                    0.1581714335254838,
                                    0.3623104562583518,
                                    0.22644589400093695,
                                ],
                                [
                                    0.226445894000937,
                                    0.15817143352548385,
                                    0.36231045625835173,
                                    0.25307221621522746,
                                ],
                                [
                                    0.226445894000937,
                                    0.36231045625835173,
                                    0.15817143352548385,
                                    0.25307221621522746,
                                ],
                                [
                                    0.25307221621522746,
                                    0.3623104562583518,
                                    0.1581714335254838,
                                    0.22644589400093695,
                                ],
                                [
                                    0.15817143352548385,
                                    0.2530722162152274,
                                    0.226445894000937,
                                    0.36231045625835173,
                                ],
                                [
                                    0.15817143352548385,
                                    0.226445894000937,
                                    0.2530722162152274,
                                    0.36231045625835173,
                                ],
                                [
                                    0.5192314978224077,
                                    0.17307716594080258,
                                    0.2307685021775922,
                                    0.0769228340591974,
                                ],
                                [
                                    0.5192314978224077,
                                    0.2307685021775922,
                                    0.17307716594080258,
                                    0.0769228340591974,
                                ],
                                [
                                    0.23076850217759226,
                                    0.07692283405919742,
                                    0.5192314978224077,
                                    0.17307716594080258,
                                ],
                                [
                                    0.17307716594080258,
                                    0.0769228340591974,
                                    0.5192314978224077,
                                    0.2307685021775922,
                                ],
                                [
                                    0.17307716594080258,
                                    0.5192314978224077,
                                    0.0769228340591974,
                                    0.2307685021775922,
                                ],
                                [
                                    0.23076850217759226,
                                    0.5192314978224077,
                                    0.07692283405919742,
                                    0.17307716594080258,
                                ],
                                [
                                    0.07692283405919742,
                                    0.23076850217759226,
                                    0.17307716594080258,
                                    0.5192314978224077,
                                ],
                                [
                                    0.07692283405919742,
                                    0.17307716594080258,
                                    0.23076850217759226,
                                    0.5192314978224077,
                                ],
                                [
                                    0.7040324107926158,
                                    0.09182856647451619,
                                    0.18058491673380495,
                                    0.023554105999063057,
                                ],
                                [
                                    0.7040324107926158,
                                    0.18058491673380495,
                                    0.09182856647451619,
                                    0.023554105999063057,
                                ],
                                [
                                    0.18058491673380495,
                                    0.023554105999063057,
                                    0.7040324107926158,
                                    0.09182856647451619,
                                ],
                                [
                                    0.09182856647451619,
                                    0.023554105999063057,
                                    0.7040324107926158,
                                    0.18058491673380495,
                                ],
                                [
                                    0.09182856647451619,
                                    0.7040324107926158,
                                    0.023554105999063057,
                                    0.18058491673380495,
                                ],
                                [
                                    0.18058491673380495,
                                    0.7040324107926158,
                                    0.023554105999063057,
                                    0.09182856647451619,
                                ],
                                [
                                    0.023554105999063057,
                                    0.18058491673380495,
                                    0.09182856647451619,
                                    0.7040324107926158,
                                ],
                                [
                                    0.023554105999063057,
                                    0.09182856647451619,
                                    0.18058491673380495,
                                    0.7040324107926158,
                                ],
                                [
                                    0.8462493514308395,
                                    0.020325547633987216,
                                    0.13029561005382653,
                                    0.0031294908813468223,
                                ],
                                [
                                    0.8462493514308395,
                                    0.13029561005382653,
                                    0.020325547633987216,
                                    0.0031294908813468223,
                                ],
                                [
                                    0.13029561005382653,
                                    0.0031294908813468223,
                                    0.8462493514308395,
                                    0.020325547633987216,
                                ],
                                [
                                    0.020325547633987216,
                                    0.0031294908813468223,
                                    0.8462493514308395,
                                    0.13029561005382653,
                                ],
                                [
                                    0.020325547633987216,
                                    0.8462493514308395,
                                    0.0031294908813468223,
                                    0.13029561005382653,
                                ],
                                [
                                    0.13029561005382653,
                                    0.8462493514308395,
                                    0.0031294908813468223,
                                    0.020325547633987216,
                                ],
                                [
                                    0.0031294908813468223,
                                    0.13029561005382653,
                                    0.020325547633987216,
                                    0.8462493514308395,
                                ],
                                [
                                    0.0031294908813468223,
                                    0.020325547633987216,
                                    0.13029561005382653,
                                    0.8462493514308395,
                                ],
                                [
                                    0.13823972661238101,
                                    0.37980270184921305,
                                    0.12861047525796568,
                                    0.35334709628044025,
                                ],
                                [
                                    0.13823972661238101,
                                    0.12861047525796568,
                                    0.37980270184921305,
                                    0.35334709628044025,
                                ],
                                [
                                    0.12861047525796568,
                                    0.35334709628044025,
                                    0.13823972661238101,
                                    0.37980270184921305,
                                ],
                                [
                                    0.11393831638809329,
                                    0.10600180845158533,
                                    0.40410411207350083,
                                    0.37595576308682055,
                                ],
                                [
                                    0.11393831638809329,
                                    0.40410411207350083,
                                    0.10600180845158533,
                                    0.37595576308682055,
                                ],
                                [
                                    0.12861047525796568,
                                    0.13823972661238101,
                                    0.35334709628044025,
                                    0.37980270184921305,
                                ],
                                [
                                    0.10600180845158533,
                                    0.37595576308682055,
                                    0.11393831638809329,
                                    0.40410411207350083,
                                ],
                                [
                                    0.10600180845158533,
                                    0.11393831638809329,
                                    0.37595576308682055,
                                    0.40410411207350083,
                                ],
                                [
                                    0.24037629193940266,
                                    0.34838005831988605,
                                    0.16790175352633332,
                                    0.243341896214378,
                                ],
                                [
                                    0.24037629193940266,
                                    0.16790175352633332,
                                    0.34838005831988605,
                                    0.243341896214378,
                                ],
                                [
                                    0.16790175352633332,
                                    0.24334189621437793,
                                    0.24037629193940266,
                                    0.34838005831988605,
                                ],
                                [
                                    0.10451172968198782,
                                    0.07300097083658966,
                                    0.4842446205773009,
                                    0.33824267890412163,
                                ],
                                [
                                    0.10451172968198782,
                                    0.4842446205773009,
                                    0.07300097083658966,
                                    0.33824267890412163,
                                ],
                                [
                                    0.16790175352633332,
                                    0.24037629193940266,
                                    0.24334189621437793,
                                    0.34838005831988605,
                                ],
                                [
                                    0.07300097083658966,
                                    0.33824267890412163,
                                    0.10451172968198782,
                                    0.4842446205773009,
                                ],
                                [
                                    0.07300097083658966,
                                    0.10451172968198782,
                                    0.33824267890412163,
                                    0.4842446205773009,
                                ],
                                [
                                    0.42603475568321697,
                                    0.26627390807999335,
                                    0.18934791679036225,
                                    0.11834341944642737,
                                ],
                                [
                                    0.42603475568321697,
                                    0.18934791679036225,
                                    0.26627390807999335,
                                    0.11834341944642737,
                                ],
                                [
                                    0.18934791679036228,
                                    0.11834341944642739,
                                    0.42603475568321697,
                                    0.26627390807999335,
                                ],
                                [
                                    0.0798804238016118,
                                    0.03550224867196745,
                                    0.6124282399615986,
                                    0.2721890875648222,
                                ],
                                [
                                    0.0798804238016118,
                                    0.6124282399615986,
                                    0.03550224867196745,
                                    0.2721890875648222,
                                ],
                                [
                                    0.18934791679036228,
                                    0.42603475568321697,
                                    0.11834341944642739,
                                    0.26627390807999335,
                                ],
                                [
                                    0.035502248671967454,
                                    0.27218908756482224,
                                    0.0798804238016118,
                                    0.6124282399615986,
                                ],
                                [
                                    0.035502248671967454,
                                    0.0798804238016118,
                                    0.27218908756482224,
                                    0.6124282399615986,
                                ],
                                [
                                    0.6545855459550892,
                                    0.1412754313120428,
                                    0.16790175352633332,
                                    0.036237269206534674,
                                ],
                                [
                                    0.6545855459550892,
                                    0.16790175352633332,
                                    0.1412754313120428,
                                    0.036237269206534674,
                                ],
                                [
                                    0.16790175352633332,
                                    0.036237269206534674,
                                    0.6545855459550892,
                                    0.1412754313120428,
                                ],
                                [
                                    0.04238170163698958,
                                    0.010870942791591436,
                                    0.7534792756301424,
                                    0.19326807994127657,
                                ],
                                [
                                    0.04238170163698958,
                                    0.7534792756301424,
                                    0.010870942791591436,
                                    0.19326807994127657,
                                ],
                                [
                                    0.16790175352633332,
                                    0.6545855459550892,
                                    0.036237269206534674,
                                    0.1412754313120428,
                                ],
                                [
                                    0.010870942791591436,
                                    0.19326807994127657,
                                    0.04238170163698958,
                                    0.7534792756301424,
                                ],
                                [
                                    0.010870942791591436,
                                    0.04238170163698958,
                                    0.19326807994127657,
                                    0.7534792756301424,
                                ],
                                [
                                    0.8353046678188462,
                                    0.03127023124598051,
                                    0.12861047525796568,
                                    0.004814625677207671,
                                ],
                                [
                                    0.8353046678188462,
                                    0.12861047525796568,
                                    0.03127023124598051,
                                    0.004814625677207671,
                                ],
                                [
                                    0.12861047525796568,
                                    0.004814625677207671,
                                    0.8353046678188462,
                                    0.03127023124598051,
                                ],
                                [
                                    0.009380864021993911,
                                    0.0014443560854859713,
                                    0.8571940350428328,
                                    0.1319807448496874,
                                ],
                                [
                                    0.009380864021993911,
                                    0.8571940350428328,
                                    0.0014443560854859713,
                                    0.1319807448496874,
                                ],
                                [
                                    0.12861047525796568,
                                    0.8353046678188462,
                                    0.004814625677207671,
                                    0.03127023124598051,
                                ],
                                [
                                    0.0014443560854859713,
                                    0.1319807448496874,
                                    0.009380864021993911,
                                    0.8571940350428328,
                                ],
                                [
                                    0.0014443560854859713,
                                    0.009380864021993911,
                                    0.1319807448496874,
                                    0.8571940350428328,
                                ],
                                [
                                    0.04746283942300025,
                                    0.4705795890385938,
                                    0.04415675931131266,
                                    0.4378008122270933,
                                ],
                                [
                                    0.04746283942300025,
                                    0.04415675931131266,
                                    0.4705795890385938,
                                    0.4378008122270933,
                                ],
                                [
                                    0.04415675931131266,
                                    0.4378008122270933,
                                    0.04746283942300025,
                                    0.4705795890385938,
                                ],
                                [
                                    0.02316142919871252,
                                    0.02154809250493232,
                                    0.4948809992628816,
                                    0.46040947903347357,
                                ],
                                [
                                    0.02316142919871252,
                                    0.4948809992628816,
                                    0.02154809250493232,
                                    0.46040947903347357,
                                ],
                                [
                                    0.04415675931131266,
                                    0.04746283942300025,
                                    0.4378008122270933,
                                    0.4705795890385938,
                                ],
                                [
                                    0.02154809250493232,
                                    0.46040947903347357,
                                    0.02316142919871252,
                                    0.4948809992628816,
                                ],
                                [
                                    0.02154809250493232,
                                    0.02316142919871252,
                                    0.46040947903347357,
                                    0.4948809992628816,
                                ],
                                [
                                    0.15710975091913976,
                                    0.431646599340149,
                                    0.10974045095120696,
                                    0.3015031987895044,
                                ],
                                [
                                    0.15710975091913976,
                                    0.10974045095120696,
                                    0.431646599340149,
                                    0.3015031987895044,
                                ],
                                [
                                    0.10974045095120695,
                                    0.3015031987895043,
                                    0.15710975091913976,
                                    0.431646599340149,
                                ],
                                [
                                    0.021245188661724906,
                                    0.014839668261463285,
                                    0.5675111615975639,
                                    0.39640398147924805,
                                ],
                                [
                                    0.021245188661724906,
                                    0.5675111615975639,
                                    0.014839668261463285,
                                    0.39640398147924805,
                                ],
                                [
                                    0.10974045095120695,
                                    0.15710975091913976,
                                    0.3015031987895043,
                                    0.431646599340149,
                                ],
                                [
                                    0.014839668261463284,
                                    0.396403981479248,
                                    0.021245188661724906,
                                    0.5675111615975639,
                                ],
                                [
                                    0.014839668261463284,
                                    0.021245188661724906,
                                    0.396403981479248,
                                    0.5675111615975639,
                                ],
                                [
                                    0.3623924582546707,
                                    0.3299162055085396,
                                    0.1610625802606633,
                                    0.14662875597612632,
                                ],
                                [
                                    0.3623924582546707,
                                    0.1610625802606633,
                                    0.3299162055085396,
                                    0.14662875597612632,
                                ],
                                [
                                    0.16106258026066333,
                                    0.14662875597612635,
                                    0.3623924582546707,
                                    0.3299162055085396,
                                ],
                                [
                                    0.01623812637306554,
                                    0.007216912142268496,
                                    0.6760705373901448,
                                    0.30047442409452113,
                                ],
                                [
                                    0.01623812637306554,
                                    0.6760705373901448,
                                    0.007216912142268496,
                                    0.30047442409452113,
                                ],
                                [
                                    0.16106258026066333,
                                    0.3623924582546707,
                                    0.14662875597612635,
                                    0.3299162055085396,
                                ],
                                [
                                    0.007216912142268497,
                                    0.3004744240945212,
                                    0.01623812637306554,
                                    0.6760705373901448,
                                ],
                                [
                                    0.007216912142268497,
                                    0.01623812637306554,
                                    0.3004744240945212,
                                    0.6760705373901448,
                                ],
                                [
                                    0.6208192145719703,
                                    0.17504176269516164,
                                    0.159240660588351,
                                    0.04489836214451698,
                                ],
                                [
                                    0.6208192145719703,
                                    0.159240660588351,
                                    0.17504176269516164,
                                    0.04489836214451698,
                                ],
                                [
                                    0.159240660588351,
                                    0.04489836214451698,
                                    0.6208192145719703,
                                    0.17504176269516164,
                                ],
                                [
                                    0.008615370253870748,
                                    0.0022098498536091355,
                                    0.7872456070132613,
                                    0.20192917287925885,
                                ],
                                [
                                    0.008615370253870748,
                                    0.7872456070132613,
                                    0.0022098498536091355,
                                    0.20192917287925885,
                                ],
                                [
                                    0.159240660588351,
                                    0.6208192145719703,
                                    0.04489836214451698,
                                    0.17504176269516164,
                                ],
                                [
                                    0.0022098498536091355,
                                    0.20192917287925885,
                                    0.008615370253870748,
                                    0.7872456070132613,
                                ],
                                [
                                    0.0022098498536091355,
                                    0.008615370253870748,
                                    0.20192917287925885,
                                    0.7872456070132613,
                                ],
                                [
                                    0.8278307498072539,
                                    0.03874414925757272,
                                    0.1274597284891012,
                                    0.0059653724460721385,
                                ],
                                [
                                    0.8278307498072539,
                                    0.1274597284891012,
                                    0.03874414925757272,
                                    0.0059653724460721385,
                                ],
                                [
                                    0.1274597284891012,
                                    0.0059653724460721385,
                                    0.8278307498072539,
                                    0.03874414925757272,
                                ],
                                [
                                    0.0019069460104017262,
                                    0.0002936093166215085,
                                    0.8646679530544249,
                                    0.13313149161855184,
                                ],
                                [
                                    0.0019069460104017262,
                                    0.8646679530544249,
                                    0.0002936093166215085,
                                    0.13313149161855184,
                                ],
                                [
                                    0.1274597284891012,
                                    0.8278307498072539,
                                    0.0059653724460721385,
                                    0.03874414925757272,
                                ],
                                [
                                    0.0002936093166215085,
                                    0.13313149161855184,
                                    0.0019069460104017262,
                                    0.8646679530544249,
                                ],
                                [
                                    0.0002936093166215085,
                                    0.0019069460104017262,
                                    0.13313149161855184,
                                    0.8646679530544249,
                                ],
                                [
                                    0.24696462472161015,
                                    0.01155844269348817,
                                    0.708325853574745,
                                    0.03315107901015664,
                                ],
                                [
                                    0.24696462472161015,
                                    0.708325853574745,
                                    0.01155844269348817,
                                    0.03315107901015664,
                                ],
                                [
                                    0.21249310449220227,
                                    0.009945105999707975,
                                    0.7427973738041529,
                                    0.03476441570393684,
                                ],
                                [
                                    0.23483728771496334,
                                    0.6735431135507238,
                                    0.023685779700135013,
                                    0.06793381903417782,
                                ],
                                [
                                    0.23483728771496334,
                                    0.023685779700135013,
                                    0.6735431135507238,
                                    0.06793381903417782,
                                ],
                                [
                                    0.21249310449220227,
                                    0.7427973738041529,
                                    0.009945105999707975,
                                    0.03476441570393684,
                                ],
                                [
                                    0.20205851090346283,
                                    0.02037969958844743,
                                    0.7063218903622244,
                                    0.0712398991458654,
                                ],
                                [
                                    0.20205851090346283,
                                    0.7063218903622244,
                                    0.02037969958844743,
                                    0.0712398991458654,
                                ],
                                [
                                    0.35405978316728715,
                                    0.013254482730777548,
                                    0.6098553599095247,
                                    0.022830374192410588,
                                ],
                                [
                                    0.35405978316728715,
                                    0.6098553599095247,
                                    0.013254482730777548,
                                    0.022830374192410588,
                                ],
                                [
                                    0.18295260304897137,
                                    0.006848962330515939,
                                    0.7809625400278404,
                                    0.029235894592672198,
                                ],
                                [
                                    0.26929637989330796,
                                    0.46385341823634546,
                                    0.09801788600475674,
                                    0.16883231586558986,
                                ],
                                [
                                    0.26929637989330796,
                                    0.09801788600475674,
                                    0.46385341823634546,
                                    0.16883231586558986,
                                ],
                                [
                                    0.18295260304897137,
                                    0.7809625400278404,
                                    0.006848962330515939,
                                    0.029235894592672198,
                                ],
                                [
                                    0.13915297934266335,
                                    0.050648586036823984,
                                    0.5939968187869901,
                                    0.2162016158335226,
                                ],
                                [
                                    0.13915297934266335,
                                    0.5939968187869901,
                                    0.050648586036823984,
                                    0.2162016158335226,
                                ],
                                [
                                    0.5142742815435656,
                                    0.012352040670724882,
                                    0.4622706799411003,
                                    0.011102997844609127,
                                ],
                                [
                                    0.5142742815435656,
                                    0.4622706799411003,
                                    0.012352040670724882,
                                    0.011102997844609127,
                                ],
                                [
                                    0.1386781682479419,
                                    0.003330826439927848,
                                    0.8378667932367241,
                                    0.02012421207540616,
                                ],
                                [
                                    0.2509611204364204,
                                    0.2255838410482456,
                                    0.27566520177787013,
                                    0.24778983673746388,
                                ],
                                [
                                    0.2509611204364204,
                                    0.27566520177787013,
                                    0.2255838410482456,
                                    0.24778983673746388,
                                ],
                                [
                                    0.1386781682479419,
                                    0.8378667932367241,
                                    0.003330826439927848,
                                    0.02012421207540616,
                                ],
                                [
                                    0.06767367090400703,
                                    0.07433532378386273,
                                    0.4088712905806589,
                                    0.44911971473147133,
                                ],
                                [
                                    0.06767367090400703,
                                    0.4088712905806589,
                                    0.07433532378386273,
                                    0.44911971473147133,
                                ],
                                [
                                    0.6785129446027555,
                                    0.007425433927760691,
                                    0.31066183528976454,
                                    0.003399786179719191,
                                ],
                                [
                                    0.6785129446027555,
                                    0.31066183528976454,
                                    0.007425433927760691,
                                    0.003399786179719191,
                                ],
                                [
                                    0.0931965104687531,
                                    0.0010199135274990793,
                                    0.895978269423767,
                                    0.009805306579980803,
                                ],
                                [
                                    0.15086537260632846,
                                    0.06907475223335015,
                                    0.5350730059241877,
                                    0.2449868692361336,
                                ],
                                [
                                    0.15086537260632846,
                                    0.5350730059241877,
                                    0.06907475223335015,
                                    0.2449868692361336,
                                ],
                                [
                                    0.0931965104687531,
                                    0.895978269423767,
                                    0.0010199135274990793,
                                    0.009805306579980803,
                                ],
                                [
                                    0.0207219720556838,
                                    0.07349445194056839,
                                    0.19921815278399482,
                                    0.706565423219753,
                                ],
                                [
                                    0.0207219720556838,
                                    0.19921815278399482,
                                    0.07349445194056839,
                                    0.706565423219753,
                                ],
                                [
                                    0.7929807306092429,
                                    0.0017488464042399216,
                                    0.20481871406373398,
                                    0.00045170892278328803,
                                ],
                                [
                                    0.7929807306092429,
                                    0.20481871406373398,
                                    0.0017488464042399216,
                                    0.00045170892278328803,
                                ],
                                [
                                    0.06144426917336976,
                                    0.00013550971045972232,
                                    0.936355175499607,
                                    0.002065045616563487,
                                ],
                                [
                                    0.03553197927201279,
                                    0.00917754243163205,
                                    0.75919759774147,
                                    0.19609288055488522,
                                ],
                                [
                                    0.03553197927201279,
                                    0.75919759774147,
                                    0.00917754243163205,
                                    0.19609288055488522,
                                ],
                                [
                                    0.06144426917336976,
                                    0.936355175499607,
                                    0.00013550971045972232,
                                    0.002065045616563487,
                                ],
                                [
                                    0.0027532024605122244,
                                    0.05882657642331726,
                                    0.04195631924313262,
                                    0.8964639018730379,
                                ],
                                [
                                    0.0027532024605122244,
                                    0.04195631924313262,
                                    0.05882657642331726,
                                    0.8964639018730379,
                                ],
                                [
                                    0.20166347169388496,
                                    0.056859595721213366,
                                    0.5783964034664364,
                                    0.16308052911846518,
                                ],
                                [
                                    0.20166347169388496,
                                    0.5783964034664364,
                                    0.056859595721213366,
                                    0.16308052911846518,
                                ],
                                [
                                    0.17351512270720482,
                                    0.048923087784705444,
                                    0.6065447524531166,
                                    0.17101703705497312,
                                ],
                                [
                                    0.18953613468723812,
                                    0.5436136634424152,
                                    0.06898693272786022,
                                    0.19786326914248636,
                                ],
                                [
                                    0.18953613468723812,
                                    0.06898693272786022,
                                    0.5436136634424152,
                                    0.19786326914248636,
                                ],
                                [
                                    0.17351512270720482,
                                    0.6065447524531166,
                                    0.048923087784705444,
                                    0.17101703705497312,
                                ],
                                [
                                    0.16308052911846535,
                                    0.059357681373444895,
                                    0.570069269011188,
                                    0.20749252049690167,
                                ],
                                [
                                    0.16308052911846535,
                                    0.570069269011188,
                                    0.059357681373444895,
                                    0.20749252049690167,
                                ],
                                [
                                    0.30211131861950047,
                                    0.06520294727856427,
                                    0.5203759808619222,
                                    0.11230975324001313,
                                ],
                                [
                                    0.30211131861950047,
                                    0.5203759808619222,
                                    0.06520294727856427,
                                    0.11230975324001313,
                                ],
                                [
                                    0.1561093769463212,
                                    0.033692188433166126,
                                    0.6663779225351014,
                                    0.14382051208541127,
                                ],
                                [
                                    0.21734791534552125,
                                    0.3743740391887429,
                                    0.14996635055254345,
                                    0.2583116949131924,
                                ],
                                [
                                    0.21734791534552125,
                                    0.14996635055254345,
                                    0.3743740391887429,
                                    0.2583116949131924,
                                ],
                                [
                                    0.1561093769463212,
                                    0.6663779225351014,
                                    0.033692188433166126,
                                    0.14382051208541127,
                                ],
                                [
                                    0.11230975324001316,
                                    0.07749181213947418,
                                    0.47941220129425094,
                                    0.3307862333262617,
                                ],
                                [
                                    0.11230975324001316,
                                    0.47941220129425094,
                                    0.07749181213947418,
                                    0.3307862333262617,
                                ],
                                [
                                    0.4658627697622734,
                                    0.06076355245201708,
                                    0.41875455776414733,
                                    0.05461912002156214,
                                ],
                                [
                                    0.4658627697622734,
                                    0.41875455776414733,
                                    0.06076355245201708,
                                    0.05461912002156214,
                                ],
                                [
                                    0.12562361736549701,
                                    0.01638537732237273,
                                    0.7589937101609238,
                                    0.09899729515120649,
                                ],
                                [
                                    0.20254960865512817,
                                    0.18206771887129258,
                                    0.32407671355916234,
                                    0.2913059589144169,
                                ],
                                [
                                    0.20254960865512817,
                                    0.32407671355916234,
                                    0.18206771887129258,
                                    0.2913059589144169,
                                ],
                                [
                                    0.12562361736549701,
                                    0.7589937101609238,
                                    0.01638537732237273,
                                    0.09899729515120649,
                                ],
                                [
                                    0.05461912002156215,
                                    0.08738987466630761,
                                    0.3299982075048586,
                                    0.5279927978072716,
                                ],
                                [
                                    0.05461912002156215,
                                    0.3299982075048586,
                                    0.08738987466630761,
                                    0.5279927978072716,
                                ],
                                [
                                    0.6494103459587132,
                                    0.03652803257180301,
                                    0.2973370096127057,
                                    0.01672461185677803,
                                ],
                                [
                                    0.6494103459587132,
                                    0.2973370096127057,
                                    0.03652803257180301,
                                    0.01672461185677803,
                                ],
                                [
                                    0.08919915026984734,
                                    0.005017273726404848,
                                    0.8575482053015716,
                                    0.04823537070217619,
                                ],
                                [
                                    0.12176277396228616,
                                    0.05574992655629131,
                                    0.56417560456823,
                                    0.25831169491319245,
                                ],
                                [
                                    0.12176277396228616,
                                    0.56417560456823,
                                    0.05574992655629131,
                                    0.25831169491319245,
                                ],
                                [
                                    0.08919915026984734,
                                    0.8575482053015716,
                                    0.005017273726404848,
                                    0.04823537070217619,
                                ],
                                [
                                    0.01672461185677803,
                                    0.07749181213947415,
                                    0.16078808866179944,
                                    0.7449954873419483,
                                ],
                                [
                                    0.01672461185677803,
                                    0.16078808866179944,
                                    0.07749181213947415,
                                    0.7449954873419483,
                                ],
                                [
                                    0.7861264544163875,
                                    0.008603122597095345,
                                    0.20304832547613272,
                                    0.0022220975103845494,
                                ],
                                [
                                    0.7861264544163875,
                                    0.20304832547613272,
                                    0.008603122597095345,
                                    0.0022220975103845494,
                                ],
                                [
                                    0.06091316422324209,
                                    0.0006666146605873967,
                                    0.928261615669278,
                                    0.010158605446892496,
                                ],
                                [
                                    0.028677703079157398,
                                    0.007407153844030796,
                                    0.7660518739343254,
                                    0.19786326914248648,
                                ],
                                [
                                    0.028677703079157398,
                                    0.7660518739343254,
                                    0.007407153844030796,
                                    0.19786326914248648,
                                ],
                                [
                                    0.06091316422324209,
                                    0.928261615669278,
                                    0.0006666146605873967,
                                    0.010158605446892496,
                                ],
                                [
                                    0.0022220975103845525,
                                    0.05935768137344493,
                                    0.03386275941280364,
                                    0.9045574617033669,
                                ],
                                [
                                    0.0022220975103845525,
                                    0.03386275941280364,
                                    0.05935768137344493,
                                    0.9045574617033669,
                                ],
                                [
                                    0.1353252022108726,
                                    0.12319786520422574,
                                    0.38812983630446146,
                                    0.3533470962804402,
                                ],
                                [
                                    0.1353252022108726,
                                    0.38812983630446146,
                                    0.12319786520422574,
                                    0.3533470962804402,
                                ],
                                [
                                    0.11643640204032486,
                                    0.1060018084515854,
                                    0.4070186364750092,
                                    0.37054315303308055,
                                ],
                                [
                                    0.12319786520422574,
                                    0.3533470962804402,
                                    0.1353252022108726,
                                    0.38812983630446146,
                                ],
                                [
                                    0.12319786520422574,
                                    0.1353252022108726,
                                    0.3533470962804402,
                                    0.38812983630446146,
                                ],
                                [
                                    0.11643640204032486,
                                    0.4070186364750092,
                                    0.1060018084515854,
                                    0.37054315303308055,
                                ],
                                [
                                    0.1060018084515854,
                                    0.11643640204032486,
                                    0.37054315303308055,
                                    0.4070186364750092,
                                ],
                                [
                                    0.1060018084515854,
                                    0.37054315303308055,
                                    0.11643640204032486,
                                    0.4070186364750092,
                                ],
                                [
                                    0.22603883458602195,
                                    0.14127543131204276,
                                    0.3893438378875573,
                                    0.243341896214378,
                                ],
                                [
                                    0.22603883458602195,
                                    0.3893438378875573,
                                    0.14127543131204276,
                                    0.243341896214378,
                                ],
                                [
                                    0.11680059454289769,
                                    0.07300097083658964,
                                    0.49858207793068154,
                                    0.3116163566898311,
                                ],
                                [
                                    0.1412754313120428,
                                    0.24334189621437807,
                                    0.22603883458602192,
                                    0.3893438378875572,
                                ],
                                [
                                    0.1412754313120428,
                                    0.22603883458602192,
                                    0.24334189621437807,
                                    0.3893438378875572,
                                ],
                                [
                                    0.11680059454289769,
                                    0.49858207793068154,
                                    0.07300097083658964,
                                    0.3116163566898311,
                                ],
                                [
                                    0.07300097083658966,
                                    0.11680059454289768,
                                    0.3116163566898312,
                                    0.4985820779306815,
                                ],
                                [
                                    0.07300097083658966,
                                    0.3116163566898312,
                                    0.11680059454289768,
                                    0.4985820779306815,
                                ],
                                [
                                    0.39496974166071785,
                                    0.13165658055357263,
                                    0.35503025833928215,
                                    0.11834341944642737,
                                ],
                                [
                                    0.39496974166071785,
                                    0.35503025833928215,
                                    0.13165658055357263,
                                    0.11834341944642737,
                                ],
                                [
                                    0.10650674601590232,
                                    0.03550224867196744,
                                    0.6434932539840976,
                                    0.21449775132803256,
                                ],
                                [
                                    0.13165658055357263,
                                    0.11834341944642737,
                                    0.39496974166071785,
                                    0.35503025833928215,
                                ],
                                [
                                    0.13165658055357263,
                                    0.39496974166071785,
                                    0.11834341944642737,
                                    0.35503025833928215,
                                ],
                                [
                                    0.10650674601590232,
                                    0.6434932539840976,
                                    0.03550224867196744,
                                    0.21449775132803256,
                                ],
                                [
                                    0.03550224867196744,
                                    0.10650674601590232,
                                    0.21449775132803256,
                                    0.6434932539840976,
                                ],
                                [
                                    0.03550224867196744,
                                    0.21449775132803256,
                                    0.10650674601590232,
                                    0.6434932539840976,
                                ],
                                [
                                    0.6067929752634716,
                                    0.07914540326704457,
                                    0.27782435226294905,
                                    0.03623726920653467,
                                ],
                                [
                                    0.6067929752634716,
                                    0.27782435226294905,
                                    0.07914540326704457,
                                    0.03623726920653467,
                                ],
                                [
                                    0.08334548120466075,
                                    0.010870942791591438,
                                    0.80127184632176,
                                    0.10451172968198781,
                                ],
                                [
                                    0.07914540326704457,
                                    0.03623726920653467,
                                    0.6067929752634716,
                                    0.27782435226294905,
                                ],
                                [
                                    0.07914540326704457,
                                    0.6067929752634716,
                                    0.03623726920653467,
                                    0.27782435226294905,
                                ],
                                [
                                    0.08334548120466075,
                                    0.80127184632176,
                                    0.010870942791591438,
                                    0.10451172968198781,
                                ],
                                [
                                    0.010870942791591438,
                                    0.08334548120466075,
                                    0.10451172968198781,
                                    0.80127184632176,
                                ],
                                [
                                    0.010870942791591438,
                                    0.10451172968198781,
                                    0.08334548120466075,
                                    0.80127184632176,
                                ],
                                [
                                    0.7760891641753564,
                                    0.018640412838126365,
                                    0.2004557973093096,
                                    0.004814625677207671,
                                ],
                                [
                                    0.7760891641753564,
                                    0.2004557973093096,
                                    0.018640412838126365,
                                    0.004814625677207671,
                                ],
                                [
                                    0.06013542279834351,
                                    0.0014443560854859741,
                                    0.9164095386863225,
                                    0.022010682429848064,
                                ],
                                [
                                    0.018640412838126365,
                                    0.004814625677207671,
                                    0.7760891641753564,
                                    0.2004557973093096,
                                ],
                                [
                                    0.018640412838126365,
                                    0.7760891641753564,
                                    0.004814625677207671,
                                    0.2004557973093096,
                                ],
                                [
                                    0.06013542279834351,
                                    0.9164095386863225,
                                    0.0014443560854859741,
                                    0.022010682429848064,
                                ],
                                [
                                    0.0014443560854859741,
                                    0.06013542279834351,
                                    0.022010682429848064,
                                    0.9164095386863225,
                                ],
                                [
                                    0.0014443560854859741,
                                    0.022010682429848064,
                                    0.06013542279834351,
                                    0.9164095386863225,
                                ],
                                [
                                    0.06898693272786025,
                                    0.1895361346872381,
                                    0.19786326914248645,
                                    0.5436136634424152,
                                ],
                                [
                                    0.06898693272786025,
                                    0.19786326914248645,
                                    0.1895361346872381,
                                    0.5436136634424152,
                                ],
                                [
                                    0.05935768137344492,
                                    0.16308052911846535,
                                    0.20749252049690178,
                                    0.5700692690111879,
                                ],
                                [
                                    0.05685959572121338,
                                    0.16308052911846524,
                                    0.20166347169388496,
                                    0.5783964034664364,
                                ],
                                [
                                    0.05685959572121338,
                                    0.20166347169388496,
                                    0.16308052911846524,
                                    0.5783964034664364,
                                ],
                                [
                                    0.05935768137344492,
                                    0.20749252049690178,
                                    0.16308052911846535,
                                    0.5700692690111879,
                                ],
                                [
                                    0.04892308778470545,
                                    0.17351512270720482,
                                    0.17101703705497318,
                                    0.6065447524531166,
                                ],
                                [
                                    0.04892308778470545,
                                    0.17101703705497318,
                                    0.17351512270720482,
                                    0.6065447524531166,
                                ],
                                [
                                    0.1499663505525435,
                                    0.2173479153455212,
                                    0.2583116949131925,
                                    0.3743740391887428,
                                ],
                                [
                                    0.1499663505525435,
                                    0.2583116949131925,
                                    0.2173479153455212,
                                    0.3743740391887428,
                                ],
                                [
                                    0.07749181213947419,
                                    0.11230975324001315,
                                    0.3307862333262618,
                                    0.4794122012942509,
                                ],
                                [
                                    0.0652029472785643,
                                    0.11230975324001319,
                                    0.3021113186195004,
                                    0.5203759808619222,
                                ],
                                [
                                    0.0652029472785643,
                                    0.3021113186195004,
                                    0.11230975324001319,
                                    0.5203759808619222,
                                ],
                                [
                                    0.07749181213947419,
                                    0.3307862333262618,
                                    0.11230975324001315,
                                    0.4794122012942509,
                                ],
                                [
                                    0.03369218843316614,
                                    0.1561093769463212,
                                    0.14382051208541136,
                                    0.6663779225351013,
                                ],
                                [
                                    0.03369218843316614,
                                    0.14382051208541136,
                                    0.1561093769463212,
                                    0.6663779225351013,
                                ],
                                [
                                    0.32407671355916234,
                                    0.20254960865512817,
                                    0.2913059589144169,
                                    0.18206771887129258,
                                ],
                                [
                                    0.32407671355916234,
                                    0.2913059589144169,
                                    0.20254960865512817,
                                    0.18206771887129258,
                                ],
                                [
                                    0.08738987466630761,
                                    0.05461912002156215,
                                    0.5279927978072716,
                                    0.3299982075048586,
                                ],
                                [
                                    0.060763552452017096,
                                    0.054619120021562155,
                                    0.4658627697622734,
                                    0.41875455776414733,
                                ],
                                [
                                    0.060763552452017096,
                                    0.4658627697622734,
                                    0.054619120021562155,
                                    0.41875455776414733,
                                ],
                                [
                                    0.08738987466630761,
                                    0.5279927978072716,
                                    0.05461912002156215,
                                    0.3299982075048586,
                                ],
                                [
                                    0.016385377322372732,
                                    0.12562361736549701,
                                    0.09899729515120652,
                                    0.7589937101609238,
                                ],
                                [
                                    0.016385377322372732,
                                    0.09899729515120652,
                                    0.12562361736549701,
                                    0.7589937101609238,
                                ],
                                [
                                    0.56417560456823,
                                    0.12176277396228614,
                                    0.25831169491319245,
                                    0.0557499265562913,
                                ],
                                [
                                    0.56417560456823,
                                    0.25831169491319245,
                                    0.12176277396228614,
                                    0.0557499265562913,
                                ],
                                [
                                    0.07749181213947415,
                                    0.016724611856778027,
                                    0.7449954873419483,
                                    0.16078808866179942,
                                ],
                                [
                                    0.03652803257180299,
                                    0.016724611856778024,
                                    0.6494103459587132,
                                    0.2973370096127057,
                                ],
                                [
                                    0.03652803257180299,
                                    0.6494103459587132,
                                    0.016724611856778024,
                                    0.2973370096127057,
                                ],
                                [
                                    0.07749181213947415,
                                    0.7449954873419483,
                                    0.016724611856778027,
                                    0.16078808866179942,
                                ],
                                [
                                    0.005017273726404846,
                                    0.08919915026984734,
                                    0.04823537070217617,
                                    0.8575482053015716,
                                ],
                                [
                                    0.005017273726404846,
                                    0.04823537070217617,
                                    0.08919915026984734,
                                    0.8575482053015716,
                                ],
                                [
                                    0.7660518739343254,
                                    0.028677703079157388,
                                    0.19786326914248648,
                                    0.007407153844030793,
                                ],
                                [
                                    0.7660518739343254,
                                    0.19786326914248648,
                                    0.028677703079157388,
                                    0.007407153844030793,
                                ],
                                [
                                    0.05935768137344493,
                                    0.0022220975103845516,
                                    0.9045574617033669,
                                    0.033862759412803624,
                                ],
                                [
                                    0.008603122597095336,
                                    0.0022220975103845473,
                                    0.7861264544163875,
                                    0.20304832547613272,
                                ],
                                [
                                    0.008603122597095336,
                                    0.7861264544163875,
                                    0.0022220975103845473,
                                    0.20304832547613272,
                                ],
                                [
                                    0.05935768137344493,
                                    0.9045574617033669,
                                    0.0022220975103845516,
                                    0.033862759412803624,
                                ],
                                [
                                    0.000666614660587396,
                                    0.06091316422324209,
                                    0.010158605446892486,
                                    0.928261615669278,
                                ],
                                [
                                    0.000666614660587396,
                                    0.010158605446892486,
                                    0.06091316422324209,
                                    0.928261615669278,
                                ],
                                [
                                    0.023685779700135037,
                                    0.23483728771496332,
                                    0.06793381903417788,
                                    0.6735431135507238,
                                ],
                                [
                                    0.023685779700135037,
                                    0.06793381903417788,
                                    0.23483728771496332,
                                    0.6735431135507238,
                                ],
                                [
                                    0.02037969958844745,
                                    0.2020585109034628,
                                    0.07123989914586547,
                                    0.7063218903622243,
                                ],
                                [
                                    0.011558442693488177,
                                    0.03315107901015666,
                                    0.24696462472161015,
                                    0.708325853574745,
                                ],
                                [
                                    0.011558442693488177,
                                    0.24696462472161015,
                                    0.03315107901015666,
                                    0.708325853574745,
                                ],
                                [
                                    0.02037969958844745,
                                    0.07123989914586547,
                                    0.2020585109034628,
                                    0.7063218903622243,
                                ],
                                [
                                    0.00994510599970798,
                                    0.21249310449220227,
                                    0.03476441570393686,
                                    0.7427973738041529,
                                ],
                                [
                                    0.00994510599970798,
                                    0.03476441570393686,
                                    0.21249310449220227,
                                    0.7427973738041529,
                                ],
                                [
                                    0.09801788600475676,
                                    0.26929637989330796,
                                    0.16883231586558992,
                                    0.46385341823634535,
                                ],
                                [
                                    0.09801788600475676,
                                    0.16883231586558992,
                                    0.26929637989330796,
                                    0.46385341823634535,
                                ],
                                [
                                    0.050648586036824005,
                                    0.13915297934266332,
                                    0.21620161583352268,
                                    0.59399681878699,
                                ],
                                [
                                    0.013254482730777568,
                                    0.022830374192410623,
                                    0.35405978316728715,
                                    0.6098553599095247,
                                ],
                                [
                                    0.013254482730777568,
                                    0.35405978316728715,
                                    0.022830374192410623,
                                    0.6098553599095247,
                                ],
                                [
                                    0.050648586036824005,
                                    0.21620161583352268,
                                    0.13915297934266332,
                                    0.59399681878699,
                                ],
                                [
                                    0.00684896233051595,
                                    0.18295260304897137,
                                    0.029235894592672243,
                                    0.7809625400278404,
                                ],
                                [
                                    0.00684896233051595,
                                    0.029235894592672243,
                                    0.18295260304897137,
                                    0.7809625400278404,
                                ],
                                [
                                    0.27566520177787013,
                                    0.2509611204364204,
                                    0.24778983673746388,
                                    0.2255838410482456,
                                ],
                                [
                                    0.27566520177787013,
                                    0.24778983673746388,
                                    0.2509611204364204,
                                    0.2255838410482456,
                                ],
                                [
                                    0.07433532378386273,
                                    0.06767367090400703,
                                    0.44911971473147133,
                                    0.4088712905806589,
                                ],
                                [
                                    0.012352040670724897,
                                    0.01110299784460914,
                                    0.5142742815435656,
                                    0.4622706799411003,
                                ],
                                [
                                    0.012352040670724897,
                                    0.5142742815435656,
                                    0.01110299784460914,
                                    0.4622706799411003,
                                ],
                                [
                                    0.07433532378386273,
                                    0.44911971473147133,
                                    0.06767367090400703,
                                    0.4088712905806589,
                                ],
                                [
                                    0.003330826439927852,
                                    0.1386781682479419,
                                    0.020124212075406184,
                                    0.8378667932367241,
                                ],
                                [
                                    0.003330826439927852,
                                    0.020124212075406184,
                                    0.1386781682479419,
                                    0.8378667932367241,
                                ],
                                [
                                    0.5350730059241877,
                                    0.15086537260632846,
                                    0.2449868692361336,
                                    0.06907475223335015,
                                ],
                                [
                                    0.5350730059241877,
                                    0.2449868692361336,
                                    0.15086537260632846,
                                    0.06907475223335015,
                                ],
                                [
                                    0.07349445194056839,
                                    0.0207219720556838,
                                    0.706565423219753,
                                    0.19921815278399482,
                                ],
                                [
                                    0.007425433927760691,
                                    0.003399786179719191,
                                    0.6785129446027555,
                                    0.31066183528976454,
                                ],
                                [
                                    0.007425433927760691,
                                    0.6785129446027555,
                                    0.003399786179719191,
                                    0.31066183528976454,
                                ],
                                [
                                    0.07349445194056839,
                                    0.706565423219753,
                                    0.0207219720556838,
                                    0.19921815278399482,
                                ],
                                [
                                    0.0010199135274990793,
                                    0.0931965104687531,
                                    0.009805306579980803,
                                    0.895978269423767,
                                ],
                                [
                                    0.0010199135274990793,
                                    0.009805306579980803,
                                    0.0931965104687531,
                                    0.895978269423767,
                                ],
                                [
                                    0.75919759774147,
                                    0.035531979272012806,
                                    0.19609288055488522,
                                    0.009177542431632055,
                                ],
                                [
                                    0.75919759774147,
                                    0.19609288055488522,
                                    0.035531979272012806,
                                    0.009177542431632055,
                                ],
                                [
                                    0.05882657642331726,
                                    0.0027532024605122257,
                                    0.8964639018730379,
                                    0.04195631924313263,
                                ],
                                [
                                    0.0017488464042399417,
                                    0.00045170892278329324,
                                    0.7929807306092429,
                                    0.20481871406373398,
                                ],
                                [
                                    0.0017488464042399417,
                                    0.7929807306092429,
                                    0.00045170892278329324,
                                    0.20481871406373398,
                                ],
                                [
                                    0.05882657642331726,
                                    0.8964639018730379,
                                    0.0027532024605122257,
                                    0.04195631924313263,
                                ],
                                [
                                    0.00013550971045972387,
                                    0.06144426917336976,
                                    0.002065045616563511,
                                    0.936355175499607,
                                ],
                                [
                                    0.00013550971045972387,
                                    0.002065045616563511,
                                    0.06144426917336976,
                                    0.936355175499607,
                                ],
                                [
                                    0.07766720848362801,
                                    0.0036349820523208726,
                                    0.8776232698127271,
                                    0.04107453965132394,
                                ],
                                [
                                    0.07766720848362801,
                                    0.8776232698127271,
                                    0.0036349820523208726,
                                    0.04107453965132394,
                                ],
                                [
                                    0.043195688254220134,
                                    0.0020216453585406775,
                                    0.912094790042135,
                                    0.04268787634510413,
                                ],
                                [
                                    0.07385331646282461,
                                    0.8345270848028626,
                                    0.007448874073124284,
                                    0.08417072466118855,
                                ],
                                [
                                    0.07385331646282461,
                                    0.007448874073124284,
                                    0.8345270848028626,
                                    0.08417072466118855,
                                ],
                                [
                                    0.043195688254220134,
                                    0.912094790042135,
                                    0.0020216453585406775,
                                    0.04268787634510413,
                                ],
                                [
                                    0.04107453965132411,
                                    0.004142793961436702,
                                    0.8673058616143631,
                                    0.08747680477287613,
                                ],
                                [
                                    0.04107453965132411,
                                    0.8673058616143631,
                                    0.004142793961436702,
                                    0.08747680477287613,
                                ],
                                [
                                    0.20829786273122586,
                                    0.007797780362771213,
                                    0.755617280345586,
                                    0.028287076560416922,
                                ],
                                [
                                    0.20829786273122586,
                                    0.755617280345586,
                                    0.007797780362771213,
                                    0.028287076560416922,
                                ],
                                [
                                    0.037190682612910114,
                                    0.0013922599625096046,
                                    0.9267244604639017,
                                    0.03469259696067853,
                                ],
                                [
                                    0.1584304771110616,
                                    0.5747193210185918,
                                    0.05766516598293549,
                                    0.20918503588741108,
                                ],
                                [
                                    0.1584304771110616,
                                    0.05766516598293549,
                                    0.5747193210185918,
                                    0.20918503588741108,
                                ],
                                [
                                    0.037190682612910114,
                                    0.9267244604639017,
                                    0.0013922599625096046,
                                    0.03469259696067853,
                                ],
                                [
                                    0.028287076560416978,
                                    0.010295866015002743,
                                    0.7048627215692365,
                                    0.2565543358553438,
                                ],
                                [
                                    0.028287076560416978,
                                    0.7048627215692365,
                                    0.010295866015002743,
                                    0.2565543358553438,
                                ],
                                [
                                    0.40378667005566293,
                                    0.009698306039831791,
                                    0.572758291429003,
                                    0.013756732475502218,
                                ],
                                [
                                    0.40378667005566293,
                                    0.572758291429003,
                                    0.009698306039831791,
                                    0.013756732475502218,
                                ],
                                [
                                    0.02819055676003922,
                                    0.0006770918090347568,
                                    0.9483544047246267,
                                    0.022777946706299252,
                                ],
                                [
                                    0.19704418200791557,
                                    0.2795007794767504,
                                    0.21644079408757916,
                                    0.3070142444277549,
                                ],
                                [
                                    0.19704418200791557,
                                    0.21644079408757916,
                                    0.2795007794767504,
                                    0.3070142444277549,
                                ],
                                [
                                    0.02819055676003922,
                                    0.9483544047246267,
                                    0.0006770918090347568,
                                    0.022777946706299252,
                                ],
                                [
                                    0.013756732475502232,
                                    0.015110916093571746,
                                    0.4627882290091637,
                                    0.5083441224217623,
                                ],
                                [
                                    0.013756732475502232,
                                    0.4627882290091637,
                                    0.015110916093571746,
                                    0.5083441224217623,
                                ],
                                [
                                    0.6042614602430127,
                                    0.006612848853979642,
                                    0.3849133196495075,
                                    0.00421237125350024,
                                ],
                                [
                                    0.6042614602430127,
                                    0.3849133196495075,
                                    0.006612848853979642,
                                    0.00421237125350024,
                                ],
                                [
                                    0.018945026109010315,
                                    0.00020732845371803098,
                                    0.9702297537835098,
                                    0.010617891653761851,
                                ],
                                [
                                    0.13435577180414493,
                                    0.0855843530355337,
                                    0.47651853729284743,
                                    0.303541337867474,
                                ],
                                [
                                    0.13435577180414493,
                                    0.47651853729284743,
                                    0.0855843530355337,
                                    0.303541337867474,
                                ],
                                [
                                    0.018945026109010315,
                                    0.9702297537835098,
                                    0.00020732845371803098,
                                    0.010617891653761851,
                                ],
                                [
                                    0.004212371253500261,
                                    0.014939983309228086,
                                    0.21572775358617835,
                                    0.7651198918510933,
                                ],
                                [
                                    0.004212371253500261,
                                    0.21572775358617835,
                                    0.014939983309228086,
                                    0.7651198918510933,
                                ],
                                [
                                    0.7440268784899412,
                                    0.0016408831650994728,
                                    0.2537725661830356,
                                    0.000559672161923737,
                                ],
                                [
                                    0.7440268784899412,
                                    0.2537725661830356,
                                    0.0016408831650994728,
                                    0.000559672161923737,
                                ],
                                [
                                    0.012490417054068092,
                                    2.7546471319273405e-05,
                                    0.9853090276189087,
                                    0.0021730088557039362,
                                ],
                                [
                                    0.033338448973424306,
                                    0.011371072730220533,
                                    0.7123293126816164,
                                    0.24296116561473885,
                                ],
                                [
                                    0.033338448973424306,
                                    0.7123293126816164,
                                    0.011371072730220533,
                                    0.24296116561473885,
                                ],
                                [
                                    0.012490417054068092,
                                    0.9853090276189087,
                                    2.7546471319273405e-05,
                                    0.0021730088557039362,
                                ],
                                [
                                    0.0005596721619237409,
                                    0.011958291363463625,
                                    0.044149849541721096,
                                    0.9433321869328916,
                                ],
                                [
                                    0.0005596721619237409,
                                    0.044149849541721096,
                                    0.011958291363463625,
                                    0.9433321869328916,
                                ],
                                [
                                    0.06342057659973295,
                                    0.017881613936215932,
                                    0.7166392985605884,
                                    0.20205851090346263,
                                ],
                                [
                                    0.06342057659973295,
                                    0.7166392985605884,
                                    0.017881613936215932,
                                    0.20205851090346263,
                                ],
                                [
                                    0.035272227613052806,
                                    0.009945105999708007,
                                    0.7447876475472686,
                                    0.20999501883997054,
                                ],
                                [
                                    0.05960668457892955,
                                    0.6735431135507238,
                                    0.021695505957019343,
                                    0.24515469591332723,
                                ],
                                [
                                    0.05960668457892955,
                                    0.021695505957019343,
                                    0.6735431135507238,
                                    0.24515469591332723,
                                ],
                                [
                                    0.035272227613052806,
                                    0.7447876475472686,
                                    0.009945105999708007,
                                    0.20999501883997054,
                                ],
                                [
                                    0.033151079010156785,
                                    0.012066254602604031,
                                    0.6999987191194966,
                                    0.25478394726774256,
                                ],
                                [
                                    0.033151079010156785,
                                    0.6999987191194966,
                                    0.012066254602604031,
                                    0.25478394726774256,
                                ],
                                [
                                    0.17773592191808302,
                                    0.038359721175914095,
                                    0.6447513775633397,
                                    0.1391529793426633,
                                ],
                                [
                                    0.17773592191808302,
                                    0.6447513775633397,
                                    0.038359721175914095,
                                    0.1391529793426633,
                                ],
                                [
                                    0.03173398024490377,
                                    0.006848962330515951,
                                    0.7907533192365188,
                                    0.17066373818806144,
                                ],
                                [
                                    0.12786853629791872,
                                    0.4638534182363454,
                                    0.08822710679607838,
                                    0.3200509386696575,
                                ],
                                [
                                    0.12786853629791872,
                                    0.08822710679607838,
                                    0.4638534182363454,
                                    0.3200509386696575,
                                ],
                                [
                                    0.03173398024490377,
                                    0.7907533192365188,
                                    0.006848962330515951,
                                    0.17066373818806144,
                                ],
                                [
                                    0.022830374192410633,
                                    0.015752568383009088,
                                    0.5688915803418535,
                                    0.3925254770827268,
                                ],
                                [
                                    0.022830374192410633,
                                    0.5688915803418535,
                                    0.015752568383009088,
                                    0.3925254770827268,
                                ],
                                [
                                    0.36577597452592253,
                                    0.0477090015695722,
                                    0.5188413530004983,
                                    0.06767367090400703,
                                ],
                                [
                                    0.36577597452592253,
                                    0.5188413530004983,
                                    0.0477090015695722,
                                    0.06767367090400703,
                                ],
                                [
                                    0.025536822129146125,
                                    0.003330826439927851,
                                    0.8590805053972747,
                                    0.11205184603365137,
                                ],
                                [
                                    0.15903348647817514,
                                    0.2255838410482456,
                                    0.25445148961731956,
                                    0.3609311828562597,
                                ],
                                [
                                    0.15903348647817514,
                                    0.25445148961731956,
                                    0.2255838410482456,
                                    0.3609311828562597,
                                ],
                                [
                                    0.025536822129146125,
                                    0.8590805053972747,
                                    0.003330826439927851,
                                    0.11205184603365137,
                                ],
                                [
                                    0.011102997844609138,
                                    0.017764650724464842,
                                    0.3735143296818116,
                                    0.5976180217491144,
                                ],
                                [
                                    0.011102997844609138,
                                    0.3735143296818116,
                                    0.017764650724464842,
                                    0.5976180217491144,
                                ],
                                [
                                    0.5783436367240952,
                                    0.032530672372897244,
                                    0.3684037188473239,
                                    0.0207219720556838,
                                ],
                                [
                                    0.5783436367240952,
                                    0.3684037188473239,
                                    0.032530672372897244,
                                    0.0207219720556838,
                                ],
                                [
                                    0.018132441035229263,
                                    0.0010199135274990845,
                                    0.9286149145361897,
                                    0.05223273090108196,
                                ],
                                [
                                    0.10843794828522733,
                                    0.06907475223335015,
                                    0.502436360811765,
                                    0.32005093866965756,
                                ],
                                [
                                    0.10843794828522733,
                                    0.502436360811765,
                                    0.06907475223335015,
                                    0.32005093866965756,
                                ],
                                [
                                    0.018132441035229263,
                                    0.9286149145361897,
                                    0.0010199135274990845,
                                    0.05223273090108196,
                                ],
                                [
                                    0.003399786179719208,
                                    0.01575256838300914,
                                    0.17411291433885828,
                                    0.8067347310984134,
                                ],
                                [
                                    0.003399786179719208,
                                    0.17411291433885828,
                                    0.01575256838300914,
                                    0.8067347310984134,
                                ],
                                [
                                    0.737595744008073,
                                    0.008072017646967671,
                                    0.2515790358844472,
                                    0.002753202460512223,
                                ],
                                [
                                    0.737595744008073,
                                    0.2515790358844472,
                                    0.008072017646967671,
                                    0.002753202460512223,
                                ],
                                [
                                    0.012382453814927643,
                                    0.0001355097104597232,
                                    0.9767923260775925,
                                    0.01068971039702017,
                                ],
                                [
                                    0.026907314491556138,
                                    0.009177542431632057,
                                    0.7187604471634845,
                                    0.24515469591332734,
                                ],
                                [
                                    0.026907314491556138,
                                    0.7187604471634845,
                                    0.009177542431632057,
                                    0.24515469591332734,
                                ],
                                [
                                    0.012382453814927643,
                                    0.9767923260775925,
                                    0.0001355097104597232,
                                    0.01068971039702017,
                                ],
                                [
                                    0.00045170892278329156,
                                    0.012066254602604074,
                                    0.0356331480004049,
                                    0.9518488884742078,
                                ],
                                [
                                    0.00045170892278329156,
                                    0.0356331480004049,
                                    0.012066254602604074,
                                    0.9518488884742078,
                                ],
                                [
                                    0.04255804127837615,
                                    0.03874414925757274,
                                    0.4808969972369579,
                                    0.4378008122270932,
                                ],
                                [
                                    0.04255804127837615,
                                    0.4808969972369579,
                                    0.03874414925757274,
                                    0.4378008122270932,
                                ],
                                [
                                    0.02366924110782842,
                                    0.021548092504932392,
                                    0.4997857974075056,
                                    0.45499686897973357,
                                ],
                                [
                                    0.03874414925757274,
                                    0.4378008122270932,
                                    0.04255804127837615,
                                    0.4808969972369579,
                                ],
                                [
                                    0.03874414925757274,
                                    0.04255804127837615,
                                    0.4378008122270932,
                                    0.4808969972369579,
                                ],
                                [
                                    0.02366924110782842,
                                    0.4997857974075056,
                                    0.021548092504932392,
                                    0.45499686897973357,
                                ],
                                [
                                    0.021548092504932392,
                                    0.02366924110782842,
                                    0.45499686897973357,
                                    0.4997857974075056,
                                ],
                                [
                                    0.021548092504932392,
                                    0.45499686897973357,
                                    0.02366924110782842,
                                    0.4997857974075056,
                                ],
                                [
                                    0.1329815143570807,
                                    0.0831141287369164,
                                    0.4824011581164986,
                                    0.3015031987895043,
                                ],
                                [
                                    0.1329815143570807,
                                    0.4824011581164986,
                                    0.0831141287369164,
                                    0.3015031987895043,
                                ],
                                [
                                    0.023743274313956432,
                                    0.01483966826146329,
                                    0.5916393981596229,
                                    0.3697776592649575,
                                ],
                                [
                                    0.08311412873691643,
                                    0.30150319878950443,
                                    0.13298151435708067,
                                    0.4824011581164985,
                                ],
                                [
                                    0.08311412873691643,
                                    0.13298151435708067,
                                    0.30150319878950443,
                                    0.4824011581164985,
                                ],
                                [
                                    0.023743274313956432,
                                    0.5916393981596229,
                                    0.01483966826146329,
                                    0.3697776592649575,
                                ],
                                [
                                    0.014839668261463294,
                                    0.023743274313956425,
                                    0.3697776592649576,
                                    0.5916393981596227,
                                ],
                                [
                                    0.014839668261463294,
                                    0.3697776592649576,
                                    0.023743274313956425,
                                    0.5916393981596227,
                                ],
                                [
                                    0.3101137320716211,
                                    0.10337124402387368,
                                    0.4398862679283789,
                                    0.14662875597612632,
                                ],
                                [
                                    0.3101137320716211,
                                    0.4398862679283789,
                                    0.10337124402387368,
                                    0.14662875597612632,
                                ],
                                [
                                    0.021650736426805484,
                                    0.0072169121422684945,
                                    0.7283492635731945,
                                    0.2427830878577315,
                                ],
                                [
                                    0.10337124402387368,
                                    0.14662875597612632,
                                    0.3101137320716211,
                                    0.4398862679283789,
                                ],
                                [
                                    0.10337124402387368,
                                    0.3101137320716211,
                                    0.14662875597612632,
                                    0.4398862679283789,
                                ],
                                [
                                    0.021650736426805484,
                                    0.7283492635731945,
                                    0.0072169121422684945,
                                    0.2427830878577315,
                                ],
                                [
                                    0.0072169121422684945,
                                    0.021650736426805484,
                                    0.2427830878577315,
                                    0.7283492635731945,
                                ],
                                [
                                    0.0072169121422684945,
                                    0.2427830878577315,
                                    0.021650736426805484,
                                    0.7283492635731945,
                                ],
                                [
                                    0.54038999876793,
                                    0.07048431032906229,
                                    0.3442273287584907,
                                    0.04489836214451697,
                                ],
                                [
                                    0.54038999876793,
                                    0.3442273287584907,
                                    0.07048431032906229,
                                    0.04489836214451697,
                                ],
                                [
                                    0.0169425047091192,
                                    0.002209849853609146,
                                    0.8676748228173016,
                                    0.11317282261997011,
                                ],
                                [
                                    0.07048431032906229,
                                    0.04489836214451697,
                                    0.54038999876793,
                                    0.3442273287584907,
                                ],
                                [
                                    0.07048431032906229,
                                    0.54038999876793,
                                    0.04489836214451697,
                                    0.3442273287584907,
                                ],
                                [
                                    0.0169425047091192,
                                    0.8676748228173016,
                                    0.002209849853609146,
                                    0.11317282261997011,
                                ],
                                [
                                    0.002209849853609146,
                                    0.0169425047091192,
                                    0.11317282261997011,
                                    0.8676748228173016,
                                ],
                                [
                                    0.002209849853609146,
                                    0.11317282261997011,
                                    0.0169425047091192,
                                    0.8676748228173016,
                                ],
                                [
                                    0.7281780955857787,
                                    0.0174896660692619,
                                    0.24836686589888723,
                                    0.0059653724460721385,
                                ],
                                [
                                    0.7281780955857787,
                                    0.24836686589888723,
                                    0.0174896660692619,
                                    0.0059653724460721385,
                                ],
                                [
                                    0.012224354208765859,
                                    0.0002936093166215073,
                                    0.9643206072759001,
                                    0.02316142919871253,
                                ],
                                [
                                    0.0174896660692619,
                                    0.0059653724460721385,
                                    0.7281780955857787,
                                    0.24836686589888723,
                                ],
                                [
                                    0.0174896660692619,
                                    0.7281780955857787,
                                    0.0059653724460721385,
                                    0.24836686589888723,
                                ],
                                [
                                    0.012224354208765859,
                                    0.9643206072759001,
                                    0.0002936093166215073,
                                    0.02316142919871253,
                                ],
                                [
                                    0.0002936093166215073,
                                    0.012224354208765859,
                                    0.02316142919871253,
                                    0.9643206072759001,
                                ],
                                [
                                    0.0002936093166215073,
                                    0.02316142919871253,
                                    0.012224354208765859,
                                    0.9643206072759001,
                                ],
                                [
                                    0.021695505957019353,
                                    0.05960668457892954,
                                    0.24515469591332734,
                                    0.6735431135507237,
                                ],
                                [
                                    0.021695505957019353,
                                    0.24515469591332734,
                                    0.05960668457892954,
                                    0.6735431135507237,
                                ],
                                [
                                    0.012066254602604036,
                                    0.03315107901015678,
                                    0.25478394726774267,
                                    0.6999987191194965,
                                ],
                                [
                                    0.017881613936215936,
                                    0.2020585109034627,
                                    0.06342057659973295,
                                    0.7166392985605884,
                                ],
                                [
                                    0.017881613936215936,
                                    0.06342057659973295,
                                    0.2020585109034627,
                                    0.7166392985605884,
                                ],
                                [
                                    0.012066254602604036,
                                    0.25478394726774267,
                                    0.03315107901015678,
                                    0.6999987191194965,
                                ],
                                [
                                    0.00994510599970801,
                                    0.035272227613052806,
                                    0.2099950188399706,
                                    0.7447876475472686,
                                ],
                                [
                                    0.00994510599970801,
                                    0.2099950188399706,
                                    0.035272227613052806,
                                    0.7447876475472686,
                                ],
                                [
                                    0.0882271067960784,
                                    0.1278685362979187,
                                    0.32005093866965756,
                                    0.46385341823634535,
                                ],
                                [
                                    0.0882271067960784,
                                    0.32005093866965756,
                                    0.1278685362979187,
                                    0.46385341823634535,
                                ],
                                [
                                    0.015752568383009095,
                                    0.022830374192410626,
                                    0.3925254770827269,
                                    0.5688915803418534,
                                ],
                                [
                                    0.03835972117591411,
                                    0.13915297934266338,
                                    0.177735921918083,
                                    0.6447513775633396,
                                ],
                                [
                                    0.03835972117591411,
                                    0.177735921918083,
                                    0.13915297934266338,
                                    0.6447513775633396,
                                ],
                                [
                                    0.015752568383009095,
                                    0.3925254770827269,
                                    0.022830374192410626,
                                    0.5688915803418534,
                                ],
                                [
                                    0.006848962330515953,
                                    0.031733980244903766,
                                    0.17066373818806152,
                                    0.7907533192365187,
                                ],
                                [
                                    0.006848962330515953,
                                    0.17066373818806152,
                                    0.031733980244903766,
                                    0.7907533192365187,
                                ],
                                [
                                    0.25445148961731956,
                                    0.15903348647817514,
                                    0.3609311828562597,
                                    0.2255838410482456,
                                ],
                                [
                                    0.25445148961731956,
                                    0.3609311828562597,
                                    0.15903348647817514,
                                    0.2255838410482456,
                                ],
                                [
                                    0.017764650724464842,
                                    0.011102997844609138,
                                    0.5976180217491144,
                                    0.3735143296818116,
                                ],
                                [
                                    0.04770900156957222,
                                    0.06767367090400704,
                                    0.36577597452592253,
                                    0.5188413530004983,
                                ],
                                [
                                    0.04770900156957222,
                                    0.36577597452592253,
                                    0.06767367090400704,
                                    0.5188413530004983,
                                ],
                                [
                                    0.017764650724464842,
                                    0.5976180217491144,
                                    0.011102997844609138,
                                    0.3735143296818116,
                                ],
                                [
                                    0.0033308264399278514,
                                    0.025536822129146125,
                                    0.1120518460336514,
                                    0.8590805053972747,
                                ],
                                [
                                    0.0033308264399278514,
                                    0.1120518460336514,
                                    0.025536822129146125,
                                    0.8590805053972747,
                                ],
                                [
                                    0.502436360811765,
                                    0.10843794828522732,
                                    0.32005093866965756,
                                    0.06907475223335015,
                                ],
                                [
                                    0.502436360811765,
                                    0.32005093866965756,
                                    0.10843794828522732,
                                    0.06907475223335015,
                                ],
                                [
                                    0.01575256838300914,
                                    0.0033997861797192075,
                                    0.8067347310984134,
                                    0.17411291433885825,
                                ],
                                [
                                    0.03253067237289723,
                                    0.020721972055683793,
                                    0.5783436367240952,
                                    0.3684037188473239,
                                ],
                                [
                                    0.03253067237289723,
                                    0.5783436367240952,
                                    0.020721972055683793,
                                    0.3684037188473239,
                                ],
                                [
                                    0.01575256838300914,
                                    0.8067347310984134,
                                    0.0033997861797192075,
                                    0.17411291433885825,
                                ],
                                [
                                    0.001019913527499084,
                                    0.018132441035229263,
                                    0.052232730901081936,
                                    0.9286149145361897,
                                ],
                                [
                                    0.001019913527499084,
                                    0.052232730901081936,
                                    0.018132441035229263,
                                    0.9286149145361897,
                                ],
                                [
                                    0.7187604471634845,
                                    0.026907314491556127,
                                    0.24515469591332734,
                                    0.009177542431632053,
                                ],
                                [
                                    0.7187604471634845,
                                    0.24515469591332734,
                                    0.026907314491556127,
                                    0.009177542431632053,
                                ],
                                [
                                    0.012066254602604074,
                                    0.00045170892278329134,
                                    0.9518488884742078,
                                    0.03563314800040489,
                                ],
                                [
                                    0.008072017646967663,
                                    0.0027532024605122205,
                                    0.737595744008073,
                                    0.2515790358844472,
                                ],
                                [
                                    0.008072017646967663,
                                    0.737595744008073,
                                    0.0027532024605122205,
                                    0.2515790358844472,
                                ],
                                [
                                    0.012066254602604074,
                                    0.9518488884742078,
                                    0.00045170892278329134,
                                    0.03563314800040489,
                                ],
                                [
                                    0.00013550971045972305,
                                    0.012382453814927643,
                                    0.01068971039702016,
                                    0.9767923260775925,
                                ],
                                [
                                    0.00013550971045972305,
                                    0.01068971039702016,
                                    0.012382453814927643,
                                    0.9767923260775925,
                                ],
                                [
                                    0.007448874073124291,
                                    0.0738533164628246,
                                    0.08417072466118862,
                                    0.8345270848028625,
                                ],
                                [
                                    0.007448874073124291,
                                    0.08417072466118862,
                                    0.0738533164628246,
                                    0.8345270848028625,
                                ],
                                [
                                    0.004142793961436705,
                                    0.041074539651324106,
                                    0.08747680477287621,
                                    0.867305861614363,
                                ],
                                [
                                    0.003634982052320875,
                                    0.04107453965132397,
                                    0.07766720848362801,
                                    0.8776232698127271,
                                ],
                                [
                                    0.003634982052320875,
                                    0.07766720848362801,
                                    0.04107453965132397,
                                    0.8776232698127271,
                                ],
                                [
                                    0.004142793961436705,
                                    0.08747680477287621,
                                    0.041074539651324106,
                                    0.867305861614363,
                                ],
                                [
                                    0.0020216453585406788,
                                    0.043195688254220134,
                                    0.04268787634510416,
                                    0.912094790042135,
                                ],
                                [
                                    0.0020216453585406788,
                                    0.04268787634510416,
                                    0.043195688254220134,
                                    0.912094790042135,
                                ],
                                [
                                    0.057665165982935515,
                                    0.1584304771110616,
                                    0.2091850358874112,
                                    0.5747193210185917,
                                ],
                                [
                                    0.057665165982935515,
                                    0.2091850358874112,
                                    0.1584304771110616,
                                    0.5747193210185917,
                                ],
                                [
                                    0.010295866015002746,
                                    0.028287076560416975,
                                    0.25655433585534393,
                                    0.7048627215692364,
                                ],
                                [
                                    0.007797780362771225,
                                    0.028287076560416964,
                                    0.20829786273122586,
                                    0.755617280345586,
                                ],
                                [
                                    0.007797780362771225,
                                    0.20829786273122586,
                                    0.028287076560416964,
                                    0.755617280345586,
                                ],
                                [
                                    0.010295866015002746,
                                    0.25655433585534393,
                                    0.028287076560416975,
                                    0.7048627215692364,
                                ],
                                [
                                    0.0013922599625096068,
                                    0.037190682612910114,
                                    0.034692596960678584,
                                    0.9267244604639017,
                                ],
                                [
                                    0.0013922599625096068,
                                    0.034692596960678584,
                                    0.037190682612910114,
                                    0.9267244604639017,
                                ],
                                [
                                    0.21644079408757916,
                                    0.19704418200791557,
                                    0.3070142444277549,
                                    0.2795007794767504,
                                ],
                                [
                                    0.21644079408757916,
                                    0.3070142444277549,
                                    0.19704418200791557,
                                    0.2795007794767504,
                                ],
                                [
                                    0.015110916093571746,
                                    0.013756732475502232,
                                    0.5083441224217623,
                                    0.4627882290091637,
                                ],
                                [
                                    0.009698306039831803,
                                    0.013756732475502234,
                                    0.40378667005566293,
                                    0.572758291429003,
                                ],
                                [
                                    0.009698306039831803,
                                    0.40378667005566293,
                                    0.013756732475502234,
                                    0.572758291429003,
                                ],
                                [
                                    0.015110916093571746,
                                    0.5083441224217623,
                                    0.013756732475502232,
                                    0.4627882290091637,
                                ],
                                [
                                    0.0006770918090347577,
                                    0.02819055676003922,
                                    0.02277794670629928,
                                    0.9483544047246267,
                                ],
                                [
                                    0.0006770918090347577,
                                    0.02277794670629928,
                                    0.02819055676003922,
                                    0.9483544047246267,
                                ],
                                [
                                    0.47651853729284743,
                                    0.13435577180414493,
                                    0.303541337867474,
                                    0.0855843530355337,
                                ],
                                [
                                    0.47651853729284743,
                                    0.303541337867474,
                                    0.13435577180414493,
                                    0.0855843530355337,
                                ],
                                [
                                    0.014939983309228086,
                                    0.004212371253500261,
                                    0.7651198918510933,
                                    0.21572775358617835,
                                ],
                                [
                                    0.006612848853979642,
                                    0.00421237125350024,
                                    0.6042614602430127,
                                    0.3849133196495075,
                                ],
                                [
                                    0.006612848853979642,
                                    0.6042614602430127,
                                    0.00421237125350024,
                                    0.3849133196495075,
                                ],
                                [
                                    0.014939983309228086,
                                    0.7651198918510933,
                                    0.004212371253500261,
                                    0.21572775358617835,
                                ],
                                [
                                    0.00020732845371803098,
                                    0.018945026109010315,
                                    0.010617891653761851,
                                    0.9702297537835098,
                                ],
                                [
                                    0.00020732845371803098,
                                    0.010617891653761851,
                                    0.018945026109010315,
                                    0.9702297537835098,
                                ],
                                [
                                    0.7123293126816164,
                                    0.03333844897342432,
                                    0.24296116561473885,
                                    0.01137107273022054,
                                ],
                                [
                                    0.7123293126816164,
                                    0.24296116561473885,
                                    0.03333844897342432,
                                    0.01137107273022054,
                                ],
                                [
                                    0.011958291363463625,
                                    0.0005596721619237411,
                                    0.9433321869328916,
                                    0.04414984954172112,
                                ],
                                [
                                    0.0016408831650994915,
                                    0.0005596721619237434,
                                    0.7440268784899412,
                                    0.2537725661830356,
                                ],
                                [
                                    0.0016408831650994915,
                                    0.7440268784899412,
                                    0.0005596721619237434,
                                    0.2537725661830356,
                                ],
                                [
                                    0.011958291363463625,
                                    0.9433321869328916,
                                    0.0005596721619237411,
                                    0.04414984954172112,
                                ],
                                [
                                    2.754647131927372e-05,
                                    0.012490417054068092,
                                    0.002173008855703961,
                                    0.9853090276189087,
                                ],
                                [
                                    2.754647131927372e-05,
                                    0.002173008855703961,
                                    0.012490417054068092,
                                    0.9853090276189087,
                                ],
                                [
                                    0.9124812849881163,
                                    0.04270596508833804,
                                    0.042809193308238944,
                                    0.002003556615306775,
                                ],
                                [
                                    0.9124812849881163,
                                    0.042809193308238944,
                                    0.04270596508833804,
                                    0.002003556615306775,
                                ],
                                [
                                    0.8697707046154401,
                                    0.04070702375736935,
                                    0.08551977368091507,
                                    0.0040024979462754615,
                                ],
                                [
                                    0.8676733775083179,
                                    0.04070702375736935,
                                    0.08751387256813646,
                                    0.004105726166176367,
                                ],
                                [
                                    0.8676733775083179,
                                    0.08751387256813646,
                                    0.04070702375736935,
                                    0.004105726166176367,
                                ],
                                [
                                    0.8697707046154401,
                                    0.08551977368091507,
                                    0.04070702375736935,
                                    0.0040024979462754615,
                                ],
                                [
                                    0.8270601242427641,
                                    0.08341760413004548,
                                    0.08132027702292319,
                                    0.008201994604267356,
                                ],
                                [
                                    0.8270601242427641,
                                    0.08132027702292319,
                                    0.08341760413004548,
                                    0.008201994604267356,
                                ],
                                [
                                    0.9286429154637592,
                                    0.03476441570393684,
                                    0.03527222761305266,
                                    0.001320441219251294,
                                ],
                                [
                                    0.9286429154637592,
                                    0.03527222761305266,
                                    0.03476441570393684,
                                    0.001320441219251294,
                                ],
                                [
                                    0.7166392985605885,
                                    0.026827907767428903,
                                    0.24727584451622325,
                                    0.009256949155759232,
                                ],
                                [
                                    0.7063218903622245,
                                    0.026827907767428907,
                                    0.2570854408054715,
                                    0.00976476106487505,
                                ],
                                [
                                    0.7063218903622245,
                                    0.2570854408054715,
                                    0.026827907767428907,
                                    0.00976476106487505,
                                ],
                                [
                                    0.7166392985605885,
                                    0.24727584451622325,
                                    0.026827907767428903,
                                    0.009256949155759232,
                                ],
                                [
                                    0.5450728322354034,
                                    0.19839437409261407,
                                    0.18807696589425002,
                                    0.0684558277777325,
                                ],
                                [
                                    0.5450728322354034,
                                    0.18807696589425002,
                                    0.19839437409261407,
                                    0.0684558277777325,
                                ],
                                [
                                    0.9525655911925514,
                                    0.02287909262860298,
                                    0.023979370292114582,
                                    0.0005759458867310281,
                                ],
                                [
                                    0.9525655911925514,
                                    0.023979370292114582,
                                    0.02287909262860298,
                                    0.0005759458867310281,
                                ],
                                [
                                    0.4871980101337966,
                                    0.011701712202691778,
                                    0.48934695135086936,
                                    0.011753326312642231,
                                ],
                                [
                                    0.4648432492819742,
                                    0.011701712202691778,
                                    0.5106014345391802,
                                    0.012853603976153835,
                                ],
                                [
                                    0.4648432492819742,
                                    0.5106014345391802,
                                    0.011701712202691778,
                                    0.012853603976153835,
                                ],
                                [
                                    0.4871980101337966,
                                    0.48934695135086936,
                                    0.011701712202691778,
                                    0.011753326312642231,
                                ],
                                [
                                    0.2377481489655524,
                                    0.261151573370936,
                                    0.23879681251911355,
                                    0.26230346514439806,
                                ],
                                [
                                    0.2377481489655524,
                                    0.23879681251911355,
                                    0.261151573370936,
                                    0.26230346514439806,
                                ],
                                [
                                    0.9767923260775926,
                                    0.010689710397020161,
                                    0.012382453814927552,
                                    0.00013550971045972208,
                                ],
                                [
                                    0.9767923260775926,
                                    0.012382453814927552,
                                    0.010689710397020161,
                                    0.00013550971045972208,
                                ],
                                [
                                    0.25157903588444724,
                                    0.002753202460512221,
                                    0.7375957440080729,
                                    0.008072017646967663,
                                ],
                                [
                                    0.2171869223791664,
                                    0.0027532024605122205,
                                    0.7702951140954464,
                                    0.009764761064875054,
                                ],
                                [
                                    0.2171869223791664,
                                    0.7702951140954464,
                                    0.0027532024605122205,
                                    0.009764761064875054,
                                ],
                                [
                                    0.25157903588444724,
                                    0.7375957440080729,
                                    0.002753202460512221,
                                    0.008072017646967663,
                                ],
                                [
                                    0.055937864252345273,
                                    0.19839437409261415,
                                    0.16400226058733333,
                                    0.5816655010677072,
                                ],
                                [
                                    0.055937864252345273,
                                    0.16400226058733333,
                                    0.19839437409261415,
                                    0.5816655010677072,
                                ],
                                [
                                    0.9935110199669166,
                                    0.002191097598937831,
                                    0.004288424706060135,
                                    9.457728085378388e-06,
                                ],
                                [
                                    0.9935110199669166,
                                    0.004288424706060135,
                                    0.002191097598937831,
                                    9.457728085378388e-06,
                                ],
                                [
                                    0.08712956003219824,
                                    0.00019215626796914277,
                                    0.9106698846407785,
                                    0.002008399059054067,
                                ],
                                [
                                    0.04451736543567569,
                                    0.00019215626796914272,
                                    0.9511847521301787,
                                    0.00410572616617637,
                                ],
                                [
                                    0.04451736543567569,
                                    0.9511847521301787,
                                    0.00019215626796914272,
                                    0.00410572616617637,
                                ],
                                [
                                    0.08712956003219824,
                                    0.9106698846407785,
                                    0.00019215626796914277,
                                    0.002008399059054067,
                                ],
                                [
                                    0.003904112170121851,
                                    0.08341760413004554,
                                    0.04080540953352299,
                                    0.8718728741663097,
                                ],
                                [
                                    0.003904112170121851,
                                    0.04080540953352299,
                                    0.08341760413004554,
                                    0.8718728741663097,
                                ],
                                [
                                    0.7451032470493697,
                                    0.21008400302708463,
                                    0.03495662811095177,
                                    0.00985612181259394,
                                ],
                                [
                                    0.7451032470493697,
                                    0.03495662811095177,
                                    0.21008400302708463,
                                    0.00985612181259394,
                                ],
                                [
                                    0.7102271431307468,
                                    0.20025058524206266,
                                    0.06983273202957463,
                                    0.0196895395976159,
                                ],
                                [
                                    0.7002953395695712,
                                    0.032854458560082185,
                                    0.25489191050688303,
                                    0.011958291363463533,
                                ],
                                [
                                    0.7002953395695712,
                                    0.25489191050688303,
                                    0.032854458560082185,
                                    0.011958291363463533,
                                ],
                                [
                                    0.7102271431307468,
                                    0.06983273202957463,
                                    0.20025058524206266,
                                    0.0196895395976159,
                                ],
                                [
                                    0.6675165627580707,
                                    0.2429611656147388,
                                    0.06563323537158273,
                                    0.023889036255607794,
                                ],
                                [
                                    0.6675165627580707,
                                    0.06563323537158273,
                                    0.2429611656147388,
                                    0.023889036255607794,
                                ],
                                [
                                    0.7923902941127229,
                                    0.17101703705497315,
                                    0.030097005368699706,
                                    0.0064956634636042536,
                                ],
                                [
                                    0.7923902941127229,
                                    0.030097005368699706,
                                    0.17101703705497315,
                                    0.0064956634636042536,
                                ],
                                [
                                    0.6114923347857287,
                                    0.13197487154228876,
                                    0.21099496469569387,
                                    0.045537828976288636,
                                ],
                                [
                                    0.5700692690111882,
                                    0.021652685523075945,
                                    0.39333806215650785,
                                    0.014939983309228012,
                                ],
                                [
                                    0.5700692690111882,
                                    0.39333806215650785,
                                    0.021652685523075945,
                                    0.014939983309228012,
                                ],
                                [
                                    0.6114923347857287,
                                    0.21099496469569387,
                                    0.13197487154228876,
                                    0.045537828976288636,
                                ],
                                [
                                    0.4399258684605435,
                                    0.30354133786747395,
                                    0.15179608607372058,
                                    0.10473670759826191,
                                ],
                                [
                                    0.4399258684605435,
                                    0.15179608607372058,
                                    0.30354133786747395,
                                    0.10473670759826191,
                                ],
                                [
                                    0.862895269351724,
                                    0.1125494144694303,
                                    0.021722058174696687,
                                    0.002833258004148924,
                                ],
                                [
                                    0.862895269351724,
                                    0.021722058174696687,
                                    0.1125494144694303,
                                    0.002833258004148924,
                                ],
                                [
                                    0.4413353390769777,
                                    0.05756438325951065,
                                    0.44328198844944305,
                                    0.05781828921406857,
                                ],
                                [
                                    0.37517292744114683,
                                    0.009444400085273882,
                                    0.6002717563800075,
                                    0.01511091609357173,
                                ],
                                [
                                    0.37517292744114683,
                                    0.6002717563800075,
                                    0.009444400085273882,
                                    0.01511091609357173,
                                ],
                                [
                                    0.4413353390769777,
                                    0.44328198844944305,
                                    0.05756438325951065,
                                    0.05781828921406857,
                                ],
                                [
                                    0.19188547790873353,
                                    0.3070142444277549,
                                    0.19273184961768722,
                                    0.30836842804582437,
                                ],
                                [
                                    0.19188547790873353,
                                    0.19273184961768722,
                                    0.3070142444277549,
                                    0.30836842804582437,
                                ],
                                [
                                    0.9348960067066191,
                                    0.05258602976799365,
                                    0.011851348864799879,
                                    0.0006666146605873953,
                                ],
                                [
                                    0.9348960067066191,
                                    0.011851348864799879,
                                    0.05258602976799365,
                                    0.0006666146605873953,
                                ],
                                [
                                    0.2407883740896502,
                                    0.013543864255309249,
                                    0.7059589814817688,
                                    0.03970878017327179,
                                ],
                                [
                                    0.17529060300819294,
                                    0.0022220975103845477,
                                    0.8121914334664198,
                                    0.010295866015002725,
                                ],
                                [
                                    0.17529060300819294,
                                    0.8121914334664198,
                                    0.0022220975103845477,
                                    0.010295866015002725,
                                ],
                                [
                                    0.2407883740896502,
                                    0.7059589814817688,
                                    0.013543864255309249,
                                    0.03970878017327179,
                                ],
                                [
                                    0.045147202457548254,
                                    0.2091850358874112,
                                    0.13236549806102924,
                                    0.6133022635940113,
                                ],
                                [
                                    0.045147202457548254,
                                    0.13236549806102924,
                                    0.2091850358874112,
                                    0.6133022635940113,
                                ],
                                [
                                    0.9849234229817203,
                                    0.010778694584134196,
                                    0.004251356910799817,
                                    4.652552334569664e-05,
                                ],
                                [
                                    0.9849234229817203,
                                    0.004251356910799817,
                                    0.010778694584134196,
                                    4.652552334569664e-05,
                                ],
                                [
                                    0.08637643950105516,
                                    0.0009452767991122267,
                                    0.902798340391465,
                                    0.009879943308367667,
                                ],
                                [
                                    0.03592976845047936,
                                    0.00015508847270882464,
                                    0.9597723491153751,
                                    0.004142793961436689,
                                ],
                                [
                                    0.03592976845047936,
                                    0.9597723491153751,
                                    0.00015508847270882464,
                                    0.004142793961436689,
                                ],
                                [
                                    0.08637643950105516,
                                    0.902798340391465,
                                    0.0009452767991122267,
                                    0.009879943308367667,
                                ],
                                [
                                    0.00315099163897877,
                                    0.08417072466118862,
                                    0.03293386528420942,
                                    0.8797444184156232,
                                ],
                                [
                                    0.00315099163897877,
                                    0.03293386528420942,
                                    0.08417072466118862,
                                    0.8797444184156232,
                                ],
                                [
                                    0.4999975787781264,
                                    0.45518967129832794,
                                    0.023457459737207656,
                                    0.021355290186338062,
                                ],
                                [
                                    0.4999975787781264,
                                    0.023457459737207656,
                                    0.45518967129832794,
                                    0.021355290186338062,
                                ],
                                [
                                    0.47659415437274283,
                                    0.43388357400006666,
                                    0.046860884142591215,
                                    0.04266138748459932,
                                ],
                                [
                                    0.45518967129832794,
                                    0.021355290186338062,
                                    0.4999975787781264,
                                    0.023457459737207656,
                                ],
                                [
                                    0.45518967129832794,
                                    0.4999975787781264,
                                    0.021355290186338062,
                                    0.023457459737207656,
                                ],
                                [
                                    0.47659415437274283,
                                    0.046860884142591215,
                                    0.43388357400006666,
                                    0.04266138748459932,
                                ],
                                [
                                    0.43388357400006666,
                                    0.47659415437274283,
                                    0.04266138748459932,
                                    0.046860884142591215,
                                ],
                                [
                                    0.43388357400006666,
                                    0.04266138748459932,
                                    0.47659415437274283,
                                    0.046860884142591215,
                                ],
                                [
                                    0.5928641781346154,
                                    0.37054315303308066,
                                    0.022518494338963857,
                                    0.0140741744933401,
                                ],
                                [
                                    0.5928641781346154,
                                    0.022518494338963857,
                                    0.37054315303308066,
                                    0.0140741744933401,
                                ],
                                [
                                    0.45751683632660134,
                                    0.2859503700014161,
                                    0.15786583614697788,
                                    0.09866695752500461,
                                ],
                                [
                                    0.3705431530330808,
                                    0.014074174493340103,
                                    0.5928641781346153,
                                    0.022518494338963854,
                                ],
                                [
                                    0.3705431530330808,
                                    0.5928641781346153,
                                    0.014074174493340103,
                                    0.022518494338963854,
                                ],
                                [
                                    0.45751683632660134,
                                    0.15786583614697788,
                                    0.2859503700014161,
                                    0.09866695752500461,
                                ],
                                [
                                    0.2859503700014162,
                                    0.45751683632660123,
                                    0.09866695752500464,
                                    0.15786583614697786,
                                ],
                                [
                                    0.2859503700014162,
                                    0.09866695752500464,
                                    0.45751683632660123,
                                    0.15786583614697786,
                                ],
                                [
                                    0.7315835128658658,
                                    0.2438611709552886,
                                    0.01841648713413421,
                                    0.006138829044711403,
                                ],
                                [
                                    0.7315835128658658,
                                    0.01841648713413421,
                                    0.2438611709552886,
                                    0.006138829044711403,
                                ],
                                [
                                    0.3741747917523663,
                                    0.1247249305841221,
                                    0.3758252082476337,
                                    0.1252750694158779,
                                ],
                                [
                                    0.2438611709552886,
                                    0.006138829044711403,
                                    0.7315835128658658,
                                    0.01841648713413421,
                                ],
                                [
                                    0.2438611709552886,
                                    0.7315835128658658,
                                    0.006138829044711403,
                                    0.01841648713413421,
                                ],
                                [
                                    0.3741747917523663,
                                    0.3758252082476337,
                                    0.1247249305841221,
                                    0.1252750694158779,
                                ],
                                [
                                    0.1247249305841221,
                                    0.3741747917523663,
                                    0.1252750694158779,
                                    0.3758252082476337,
                                ],
                                [
                                    0.1247249305841221,
                                    0.1252750694158779,
                                    0.3741747917523663,
                                    0.3758252082476337,
                                ],
                                [
                                    0.8735437200865195,
                                    0.11393831638809328,
                                    0.011073607439901302,
                                    0.0014443560854859713,
                                ],
                                [
                                    0.8735437200865195,
                                    0.011073607439901302,
                                    0.11393831638809328,
                                    0.0014443560854859713,
                                ],
                                [
                                    0.22498670498853068,
                                    0.029345533356428748,
                                    0.6596306225378901,
                                    0.0860371391171505,
                                ],
                                [
                                    0.11393831638809328,
                                    0.0014443560854859713,
                                    0.8735437200865195,
                                    0.011073607439901302,
                                ],
                                [
                                    0.11393831638809328,
                                    0.8735437200865195,
                                    0.0014443560854859713,
                                    0.011073607439901302,
                                ],
                                [
                                    0.22498670498853068,
                                    0.6596306225378901,
                                    0.029345533356428748,
                                    0.0860371391171505,
                                ],
                                [
                                    0.029345533356428748,
                                    0.22498670498853068,
                                    0.0860371391171505,
                                    0.6596306225378901,
                                ],
                                [
                                    0.029345533356428748,
                                    0.0860371391171505,
                                    0.22498670498853068,
                                    0.6596306225378901,
                                ],
                                [
                                    0.9723478860485477,
                                    0.023354231517306777,
                                    0.004197075436118252,
                                    0.00010080699802726062,
                                ],
                                [
                                    0.9723478860485477,
                                    0.004197075436118252,
                                    0.023354231517306777,
                                    0.00010080699802726062,
                                ],
                                [
                                    0.08527358208112189,
                                    0.002048134219045498,
                                    0.8912713794035441,
                                    0.02140690429628854,
                                ],
                                [
                                    0.023354231517306777,
                                    0.00010080699802726062,
                                    0.9723478860485477,
                                    0.004197075436118252,
                                ],
                                [
                                    0.023354231517306777,
                                    0.9723478860485477,
                                    0.00010080699802726062,
                                    0.004197075436118252,
                                ],
                                [
                                    0.08527358208112189,
                                    0.8912713794035441,
                                    0.002048134219045498,
                                    0.02140690429628854,
                                ],
                                [
                                    0.002048134219045498,
                                    0.08527358208112189,
                                    0.02140690429628854,
                                    0.8912713794035441,
                                ],
                                [
                                    0.002048134219045498,
                                    0.02140690429628854,
                                    0.08527358208112189,
                                    0.8912713794035441,
                                ],
                                [
                                    0.25489191050688315,
                                    0.7002953395695711,
                                    0.011958291363463538,
                                    0.03285445856008218,
                                ],
                                [
                                    0.25489191050688315,
                                    0.011958291363463538,
                                    0.7002953395695711,
                                    0.03285445856008218,
                                ],
                                [
                                    0.2429611656147389,
                                    0.6675165627580706,
                                    0.023889036255607805,
                                    0.06563323537158273,
                                ],
                                [
                                    0.2100840030270847,
                                    0.009856121812593944,
                                    0.7451032470493697,
                                    0.03495662811095177,
                                ],
                                [
                                    0.2100840030270847,
                                    0.7451032470493697,
                                    0.009856121812593944,
                                    0.03495662811095177,
                                ],
                                [
                                    0.2429611656147389,
                                    0.023889036255607805,
                                    0.6675165627580706,
                                    0.06563323537158273,
                                ],
                                [
                                    0.2002505852420627,
                                    0.7102271431307468,
                                    0.019689539597615907,
                                    0.06983273202957463,
                                ],
                                [
                                    0.2002505852420627,
                                    0.019689539597615907,
                                    0.7102271431307468,
                                    0.06983273202957463,
                                ],
                                [
                                    0.39333806215650796,
                                    0.570069269011188,
                                    0.014939983309228015,
                                    0.02165268552307594,
                                ],
                                [
                                    0.39333806215650796,
                                    0.014939983309228015,
                                    0.570069269011188,
                                    0.02165268552307594,
                                ],
                                [
                                    0.303541337867474,
                                    0.43992586846054343,
                                    0.10473670759826194,
                                    0.15179608607372055,
                                ],
                                [
                                    0.17101703705497323,
                                    0.006495663463604257,
                                    0.7923902941127229,
                                    0.0300970053686997,
                                ],
                                [
                                    0.17101703705497323,
                                    0.7923902941127229,
                                    0.006495663463604257,
                                    0.0300970053686997,
                                ],
                                [
                                    0.303541337867474,
                                    0.10473670759826194,
                                    0.43992586846054343,
                                    0.15179608607372055,
                                ],
                                [
                                    0.13197487154228882,
                                    0.6114923347857286,
                                    0.045537828976288657,
                                    0.21099496469569384,
                                ],
                                [
                                    0.13197487154228882,
                                    0.045537828976288657,
                                    0.6114923347857286,
                                    0.21099496469569384,
                                ],
                                [
                                    0.6002717563800075,
                                    0.37517292744114683,
                                    0.01511091609357173,
                                    0.009444400085273882,
                                ],
                                [
                                    0.6002717563800075,
                                    0.01511091609357173,
                                    0.37517292744114683,
                                    0.009444400085273882,
                                ],
                                [
                                    0.3070142444277549,
                                    0.19188547790873353,
                                    0.30836842804582437,
                                    0.19273184961768722,
                                ],
                                [
                                    0.11254941446943031,
                                    0.002833258004148925,
                                    0.862895269351724,
                                    0.021722058174696687,
                                ],
                                [
                                    0.11254941446943031,
                                    0.862895269351724,
                                    0.002833258004148925,
                                    0.021722058174696687,
                                ],
                                [
                                    0.3070142444277549,
                                    0.30836842804582437,
                                    0.19188547790873353,
                                    0.19273184961768722,
                                ],
                                [
                                    0.05756438325951067,
                                    0.4413353390769777,
                                    0.057818289214068584,
                                    0.44328198844944305,
                                ],
                                [
                                    0.05756438325951067,
                                    0.057818289214068584,
                                    0.4413353390769777,
                                    0.44328198844944305,
                                ],
                                [
                                    0.8121914334664198,
                                    0.1752906030081929,
                                    0.010295866015002725,
                                    0.0022220975103845473,
                                ],
                                [
                                    0.8121914334664198,
                                    0.010295866015002725,
                                    0.1752906030081929,
                                    0.0022220975103845473,
                                ],
                                [
                                    0.2091850358874112,
                                    0.04514720245754825,
                                    0.6133022635940113,
                                    0.1323654980610292,
                                ],
                                [
                                    0.052586029767993626,
                                    0.0006666146605873951,
                                    0.9348960067066191,
                                    0.011851348864799879,
                                ],
                                [
                                    0.052586029767993626,
                                    0.9348960067066191,
                                    0.0006666146605873951,
                                    0.011851348864799879,
                                ],
                                [
                                    0.2091850358874112,
                                    0.6133022635940113,
                                    0.04514720245754825,
                                    0.1323654980610292,
                                ],
                                [
                                    0.013543864255309243,
                                    0.2407883740896502,
                                    0.03970878017327178,
                                    0.7059589814817688,
                                ],
                                [
                                    0.013543864255309243,
                                    0.03970878017327178,
                                    0.2407883740896502,
                                    0.7059589814817688,
                                ],
                                [
                                    0.9597723491153751,
                                    0.03592976845047935,
                                    0.004142793961436689,
                                    0.0001550884727088246,
                                ],
                                [
                                    0.9597723491153751,
                                    0.004142793961436689,
                                    0.03592976845047935,
                                    0.0001550884727088246,
                                ],
                                [
                                    0.08417072466118862,
                                    0.003150991638978769,
                                    0.8797444184156232,
                                    0.032933865284209406,
                                ],
                                [
                                    0.010778694584134186,
                                    4.652552334569659e-05,
                                    0.9849234229817203,
                                    0.004251356910799817,
                                ],
                                [
                                    0.010778694584134186,
                                    0.9849234229817203,
                                    4.652552334569659e-05,
                                    0.004251356910799817,
                                ],
                                [
                                    0.08417072466118862,
                                    0.8797444184156232,
                                    0.003150991638978769,
                                    0.032933865284209406,
                                ],
                                [
                                    0.0009452767991122258,
                                    0.08637643950105516,
                                    0.009879943308367656,
                                    0.902798340391465,
                                ],
                                [
                                    0.0009452767991122258,
                                    0.009879943308367656,
                                    0.08637643950105516,
                                    0.902798340391465,
                                ],
                                [
                                    0.08751387256813654,
                                    0.8676733775083177,
                                    0.00410572616617637,
                                    0.04070702375736935,
                                ],
                                [
                                    0.08751387256813654,
                                    0.00410572616617637,
                                    0.8676733775083177,
                                    0.04070702375736935,
                                ],
                                [
                                    0.08341760413004555,
                                    0.827060124242764,
                                    0.008201994604267362,
                                    0.08132027702292317,
                                ],
                                [
                                    0.042705965088338065,
                                    0.0020035566153067757,
                                    0.9124812849881163,
                                    0.042809193308238944,
                                ],
                                [
                                    0.042705965088338065,
                                    0.9124812849881163,
                                    0.0020035566153067757,
                                    0.042809193308238944,
                                ],
                                [
                                    0.08341760413004555,
                                    0.008201994604267362,
                                    0.827060124242764,
                                    0.08132027702292317,
                                ],
                                [
                                    0.04070702375736938,
                                    0.8697707046154401,
                                    0.004002497946275464,
                                    0.08551977368091507,
                                ],
                                [
                                    0.04070702375736938,
                                    0.004002497946275464,
                                    0.8697707046154401,
                                    0.08551977368091507,
                                ],
                                [
                                    0.25708544080547163,
                                    0.7063218903622244,
                                    0.009764761064875055,
                                    0.026827907767428903,
                                ],
                                [
                                    0.25708544080547163,
                                    0.009764761064875055,
                                    0.7063218903622244,
                                    0.026827907767428903,
                                ],
                                [
                                    0.19839437409261415,
                                    0.5450728322354033,
                                    0.06845582777773253,
                                    0.18807696589424996,
                                ],
                                [
                                    0.034764415703936895,
                                    0.0013204412192512963,
                                    0.9286429154637592,
                                    0.03527222761305266,
                                ],
                                [
                                    0.034764415703936895,
                                    0.9286429154637592,
                                    0.0013204412192512963,
                                    0.03527222761305266,
                                ],
                                [
                                    0.19839437409261415,
                                    0.06845582777773253,
                                    0.5450728322354033,
                                    0.18807696589424996,
                                ],
                                [
                                    0.026827907767428945,
                                    0.7166392985605885,
                                    0.009256949155759246,
                                    0.24727584451622325,
                                ],
                                [
                                    0.026827907767428945,
                                    0.009256949155759246,
                                    0.7166392985605885,
                                    0.24727584451622325,
                                ],
                                [
                                    0.5106014345391802,
                                    0.4648432492819742,
                                    0.012853603976153835,
                                    0.011701712202691778,
                                ],
                                [
                                    0.5106014345391802,
                                    0.012853603976153835,
                                    0.4648432492819742,
                                    0.011701712202691778,
                                ],
                                [
                                    0.261151573370936,
                                    0.2377481489655524,
                                    0.26230346514439806,
                                    0.23879681251911355,
                                ],
                                [
                                    0.022879092628603007,
                                    0.0005759458867310289,
                                    0.9525655911925514,
                                    0.023979370292114582,
                                ],
                                [
                                    0.022879092628603007,
                                    0.9525655911925514,
                                    0.0005759458867310289,
                                    0.023979370292114582,
                                ],
                                [
                                    0.261151573370936,
                                    0.26230346514439806,
                                    0.2377481489655524,
                                    0.23879681251911355,
                                ],
                                [
                                    0.011701712202691792,
                                    0.4871980101337966,
                                    0.011753326312642245,
                                    0.48934695135086936,
                                ],
                                [
                                    0.011701712202691792,
                                    0.011753326312642245,
                                    0.4871980101337966,
                                    0.48934695135086936,
                                ],
                                [
                                    0.7702951140954464,
                                    0.2171869223791664,
                                    0.009764761064875054,
                                    0.0027532024605122205,
                                ],
                                [
                                    0.7702951140954464,
                                    0.009764761064875054,
                                    0.2171869223791664,
                                    0.0027532024605122205,
                                ],
                                [
                                    0.19839437409261415,
                                    0.055937864252345273,
                                    0.5816655010677072,
                                    0.16400226058733333,
                                ],
                                [
                                    0.010689710397020161,
                                    0.00013550971045972208,
                                    0.9767923260775926,
                                    0.012382453814927552,
                                ],
                                [
                                    0.010689710397020161,
                                    0.9767923260775926,
                                    0.00013550971045972208,
                                    0.012382453814927552,
                                ],
                                [
                                    0.19839437409261415,
                                    0.5816655010677072,
                                    0.055937864252345273,
                                    0.16400226058733333,
                                ],
                                [
                                    0.002753202460512221,
                                    0.25157903588444724,
                                    0.008072017646967663,
                                    0.7375957440080729,
                                ],
                                [
                                    0.002753202460512221,
                                    0.008072017646967663,
                                    0.25157903588444724,
                                    0.7375957440080729,
                                ],
                                [
                                    0.9511847521301787,
                                    0.044517365435675714,
                                    0.00410572616617637,
                                    0.00019215626796914283,
                                ],
                                [
                                    0.9511847521301787,
                                    0.00410572616617637,
                                    0.044517365435675714,
                                    0.00019215626796914283,
                                ],
                                [
                                    0.08341760413004554,
                                    0.0039041121701218527,
                                    0.8718728741663097,
                                    0.040805409533523004,
                                ],
                                [
                                    0.0021910975989378563,
                                    9.457728085378496e-06,
                                    0.9935110199669166,
                                    0.004288424706060135,
                                ],
                                [
                                    0.0021910975989378563,
                                    0.9935110199669166,
                                    9.457728085378496e-06,
                                    0.004288424706060135,
                                ],
                                [
                                    0.08341760413004554,
                                    0.8718728741663097,
                                    0.0039041121701218527,
                                    0.040805409533523004,
                                ],
                                [
                                    0.00019215626796914497,
                                    0.08712956003219824,
                                    0.00200839905905409,
                                    0.9106698846407785,
                                ],
                                [
                                    0.00019215626796914497,
                                    0.00200839905905409,
                                    0.08712956003219824,
                                    0.9106698846407785,
                                ],
                                [
                                    0.7446986633601548,
                                    0.03485339989105087,
                                    0.2105918149362004,
                                    0.00985612181259394,
                                ],
                                [
                                    0.7446986633601548,
                                    0.2105918149362004,
                                    0.03485339989105087,
                                    0.00985612181259394,
                                ],
                                [
                                    0.7019880829874786,
                                    0.032854458560082185,
                                    0.25330239530887655,
                                    0.011855063143562628,
                                ],
                                [
                                    0.7081298160236246,
                                    0.20025058524206266,
                                    0.07142224722758111,
                                    0.020197351506731714,
                                ],
                                [
                                    0.7081298160236246,
                                    0.07142224722758111,
                                    0.20025058524206266,
                                    0.020197351506731714,
                                ],
                                [
                                    0.7019880829874786,
                                    0.25330239530887655,
                                    0.032854458560082185,
                                    0.011855063143562628,
                                ],
                                [
                                    0.6675165627580707,
                                    0.06732597878949012,
                                    0.2408638385076165,
                                    0.024293619944822705,
                                ],
                                [
                                    0.6675165627580707,
                                    0.2408638385076165,
                                    0.06732597878949012,
                                    0.024293619944822705,
                                ],
                                [
                                    0.7904000203696072,
                                    0.029589193459583885,
                                    0.17351512270720468,
                                    0.0064956634636042536,
                                ],
                                [
                                    0.7904000203696072,
                                    0.17351512270720468,
                                    0.029589193459583885,
                                    0.0064956634636042536,
                                ],
                                [
                                    0.5783964034664365,
                                    0.02165268552307594,
                                    0.3855187396103753,
                                    0.014432171400112192,
                                ],
                                [
                                    0.6011749265873647,
                                    0.13197487154228876,
                                    0.21881428724182644,
                                    0.04803591462852016,
                                ],
                                [
                                    0.6011749265873647,
                                    0.21881428724182644,
                                    0.13197487154228876,
                                    0.04803591462852016,
                                ],
                                [
                                    0.5783964034664365,
                                    0.3855187396103753,
                                    0.02165268552307594,
                                    0.014432171400112192,
                                ],
                                [
                                    0.4399258684605435,
                                    0.16012322052896896,
                                    0.29322392966910993,
                                    0.10672698134137762,
                                ],
                                [
                                    0.4399258684605435,
                                    0.29322392966910993,
                                    0.16012322052896896,
                                    0.10672698134137762,
                                ],
                                [
                                    0.8585829369614957,
                                    0.020621780511185083,
                                    0.11796202452317024,
                                    0.002833258004148924,
                                ],
                                [
                                    0.8585829369614957,
                                    0.11796202452317024,
                                    0.020621780511185083,
                                    0.002833258004148924,
                                ],
                                [
                                    0.3932153559027409,
                                    0.009444400085273882,
                                    0.583329605581925,
                                    0.014010638430060127,
                                ],
                                [
                                    0.4189805782251553,
                                    0.05756438325951065,
                                    0.46022413924752553,
                                    0.0632308992678085,
                                ],
                                [
                                    0.4189805782251553,
                                    0.46022413924752553,
                                    0.05756438325951065,
                                    0.0632308992678085,
                                ],
                                [
                                    0.3932153559027409,
                                    0.583329605581925,
                                    0.009444400085273882,
                                    0.014010638430060127,
                                ],
                                [
                                    0.19188547790873353,
                                    0.2107742780792813,
                                    0.28465948357593246,
                                    0.3126807604360527,
                                ],
                                [
                                    0.19188547790873353,
                                    0.28465948357593246,
                                    0.2107742780792813,
                                    0.3126807604360527,
                                ],
                                [
                                    0.9282616156692781,
                                    0.010158605446892488,
                                    0.06091316422324203,
                                    0.0006666146605873954,
                                ],
                                [
                                    0.9282616156692781,
                                    0.06091316422324203,
                                    0.010158605446892488,
                                    0.0006666146605873954,
                                ],
                                [
                                    0.20304832547613277,
                                    0.002222097510384548,
                                    0.7861264544163874,
                                    0.008603122597095334,
                                ],
                                [
                                    0.20639626058436938,
                                    0.013543864255309249,
                                    0.7320239605318013,
                                    0.04803591462852017,
                                ],
                                [
                                    0.20639626058436938,
                                    0.7320239605318013,
                                    0.013543864255309249,
                                    0.04803591462852017,
                                ],
                                [
                                    0.20304832547613277,
                                    0.7861264544163874,
                                    0.002222097510384548,
                                    0.008603122597095334,
                                ],
                                [
                                    0.045147202457548254,
                                    0.16012322052896907,
                                    0.17479292238213037,
                                    0.6199366546313523,
                                ],
                                [
                                    0.045147202457548254,
                                    0.17479292238213037,
                                    0.16012322052896907,
                                    0.6199366546313523,
                                ],
                                [
                                    0.9767033418904785,
                                    0.002154029803677513,
                                    0.021096102782498263,
                                    4.6525523345696626e-05,
                                ],
                                [
                                    0.9767033418904785,
                                    0.021096102782498263,
                                    0.002154029803677513,
                                    4.6525523345696626e-05,
                                ],
                                [
                                    0.07032188195576007,
                                    0.00015508847270882445,
                                    0.9274775627172167,
                                    0.002045466854314385,
                                ],
                                [
                                    0.04376424490453261,
                                    0.0009452767991122263,
                                    0.9350931267896234,
                                    0.020197351506731735,
                                ],
                                [
                                    0.04376424490453261,
                                    0.9350931267896234,
                                    0.0009452767991122263,
                                    0.020197351506731735,
                                ],
                                [
                                    0.07032188195576007,
                                    0.9274775627172167,
                                    0.00015508847270882445,
                                    0.002045466854314385,
                                ],
                                [
                                    0.003150991638978766,
                                    0.06732597878949013,
                                    0.041558530064666074,
                                    0.8879644995068651,
                                ],
                                [
                                    0.003150991638978766,
                                    0.041558530064666074,
                                    0.06732597878949013,
                                    0.8879644995068651,
                                ],
                                [
                                    0.6080972851407064,
                                    0.17145477811049917,
                                    0.17196259001961497,
                                    0.048485346729179396,
                                ],
                                [
                                    0.6080972851407064,
                                    0.17196259001961497,
                                    0.17145477811049917,
                                    0.048485346729179396,
                                ],
                                [
                                    0.5732211812220835,
                                    0.1616213603254772,
                                    0.20683869393823784,
                                    0.058318764514201364,
                                ],
                                [
                                    0.5715284378041762,
                                    0.1616213603254772,
                                    0.2080236254470294,
                                    0.05882657642331717,
                                ],
                                [
                                    0.5715284378041762,
                                    0.2080236254470294,
                                    0.1616213603254772,
                                    0.05882657642331717,
                                ],
                                [
                                    0.5732211812220835,
                                    0.20683869393823784,
                                    0.1616213603254772,
                                    0.058318764514201364,
                                ],
                                [
                                    0.5387496609926756,
                                    0.19609288055488514,
                                    0.19440013713697776,
                                    0.07075732131546143,
                                ],
                                [
                                    0.5387496609926756,
                                    0.19440013713697776,
                                    0.19609288055488514,
                                    0.07075732131546143,
                                ],
                                [
                                    0.6744307140862662,
                                    0.14555849974292492,
                                    0.14805658539515645,
                                    0.03195420077565248,
                                ],
                                [
                                    0.6744307140862662,
                                    0.14805658539515645,
                                    0.14555849974292492,
                                    0.03195420077565248,
                                ],
                                [
                                    0.493532754759272,
                                    0.10651633423024053,
                                    0.32895454472215063,
                                    0.07099636628833687,
                                ],
                                [
                                    0.4852056203040236,
                                    0.10651633423024054,
                                    0.3347835935251675,
                                    0.07349445194056839,
                                ],
                                [
                                    0.4852056203040236,
                                    0.3347835935251675,
                                    0.10651633423024054,
                                    0.07349445194056839,
                                ],
                                [
                                    0.493532754759272,
                                    0.32895454472215063,
                                    0.10651633423024053,
                                    0.07099636628833687,
                                ],
                                [
                                    0.3550622197533789,
                                    0.24498686923613355,
                                    0.2366597347808852,
                                    0.16329117622960232,
                                ],
                                [
                                    0.3550622197533789,
                                    0.2366597347808852,
                                    0.24498686923613355,
                                    0.16329117622960232,
                                ],
                                [
                                    0.7777597275193047,
                                    0.10144498995337609,
                                    0.10685760000711603,
                                    0.013937682520203134,
                                ],
                                [
                                    0.7777597275193047,
                                    0.10685760000711603,
                                    0.10144498995337609,
                                    0.013937682520203134,
                                ],
                                [
                                    0.3561997972445584,
                                    0.046459958743456445,
                                    0.5284175302818623,
                                    0.06892271373012278,
                                ],
                                [
                                    0.3381573687829643,
                                    0.046459958743456445,
                                    0.5410473486897165,
                                    0.07433532378386272,
                                ],
                                [
                                    0.3381573687829643,
                                    0.5410473486897165,
                                    0.046459958743456445,
                                    0.07433532378386272,
                                ],
                                [
                                    0.3561997972445584,
                                    0.5284175302818623,
                                    0.046459958743456445,
                                    0.06892271373012278,
                                ],
                                [
                                    0.15486991925055096,
                                    0.24778983673746388,
                                    0.22974740827586979,
                                    0.3675928357361154,
                                ],
                                [
                                    0.15486991925055096,
                                    0.22974740827586979,
                                    0.24778983673746388,
                                    0.3675928357361154,
                                ],
                                [
                                    0.8884468627564808,
                                    0.04997335835968983,
                                    0.05830049281493821,
                                    0.003279286068891211,
                                ],
                                [
                                    0.8884468627564808,
                                    0.05830049281493821,
                                    0.04997335835968983,
                                    0.003279286068891211,
                                ],
                                [
                                    0.19433923013951188,
                                    0.010931192847005436,
                                    0.752408125431907,
                                    0.0423214515815756,
                                ],
                                [
                                    0.16658150767157207,
                                    0.010931192847005434,
                                    0.7718387134445985,
                                    0.05064858603682399,
                                ],
                                [
                                    0.16658150767157207,
                                    0.7718387134445985,
                                    0.010931192847005434,
                                    0.05064858603682399,
                                ],
                                [
                                    0.19433923013951188,
                                    0.752408125431907,
                                    0.010931192847005436,
                                    0.0423214515815756,
                                ],
                                [
                                    0.03643810712092737,
                                    0.16883231586558994,
                                    0.1410745933976501,
                                    0.6536549836158325,
                                ],
                                [
                                    0.03643810712092737,
                                    0.1410745933976501,
                                    0.16883231586558994,
                                    0.6536549836158325,
                                ],
                                [
                                    0.9682610251917375,
                                    0.010596346502418497,
                                    0.020913754700782567,
                                    0.0002288736050613956,
                                ],
                                [
                                    0.9682610251917375,
                                    0.020913754700782567,
                                    0.010596346502418497,
                                    0.0002288736050613956,
                                ],
                                [
                                    0.06971404171107237,
                                    0.0007629287173965273,
                                    0.9194607381814477,
                                    0.010062291390083366,
                                ],
                                [
                                    0.035321928205791664,
                                    0.0007629287173965281,
                                    0.9435354434883644,
                                    0.020379699588447434,
                                ],
                                [
                                    0.035321928205791664,
                                    0.9435354434883644,
                                    0.0007629287173965281,
                                    0.020379699588447434,
                                ],
                                [
                                    0.06971404171107237,
                                    0.9194607381814477,
                                    0.0007629287173965273,
                                    0.010062291390083366,
                                ],
                                [
                                    0.0025431513942910655,
                                    0.06793381903417783,
                                    0.033541705528897126,
                                    0.895981324042634,
                                ],
                                [
                                    0.0025431513942910655,
                                    0.033541705528897126,
                                    0.06793381903417783,
                                    0.895981324042634,
                                ],
                                [
                                    0.408060455293868,
                                    0.37149160795733766,
                                    0.11539458322146608,
                                    0.1050533535273283,
                                ],
                                [
                                    0.408060455293868,
                                    0.11539458322146608,
                                    0.37149160795733766,
                                    0.1050533535273283,
                                ],
                                [
                                    0.3846570308884844,
                                    0.3501855106590764,
                                    0.13879800762684966,
                                    0.12635945082558955,
                                ],
                                [
                                    0.37149160795733766,
                                    0.1050533535273283,
                                    0.408060455293868,
                                    0.11539458322146608,
                                ],
                                [
                                    0.37149160795733766,
                                    0.408060455293868,
                                    0.1050533535273283,
                                    0.11539458322146608,
                                ],
                                [
                                    0.3846570308884844,
                                    0.13879800762684966,
                                    0.3501855106590764,
                                    0.12635945082558955,
                                ],
                                [
                                    0.3501855106590764,
                                    0.3846570308884844,
                                    0.12635945082558955,
                                    0.13879800762684966,
                                ],
                                [
                                    0.3501855106590764,
                                    0.12635945082558955,
                                    0.3846570308884844,
                                    0.13879800762684966,
                                ],
                                [
                                    0.5046071538057169,
                                    0.31538206002347424,
                                    0.11077551866786242,
                                    0.06923526750294651,
                                ],
                                [
                                    0.5046071538057169,
                                    0.11077551866786242,
                                    0.31538206002347424,
                                    0.06923526750294651,
                                ],
                                [
                                    0.36925981199770275,
                                    0.2307892769918097,
                                    0.24612286047587648,
                                    0.15382805053461104,
                                ],
                                [
                                    0.31538206002347435,
                                    0.06923526750294653,
                                    0.5046071538057167,
                                    0.1107755186678624,
                                ],
                                [
                                    0.31538206002347435,
                                    0.5046071538057167,
                                    0.06923526750294653,
                                    0.1107755186678624,
                                ],
                                [
                                    0.36925981199770275,
                                    0.24612286047587648,
                                    0.2307892769918097,
                                    0.15382805053461104,
                                ],
                                [
                                    0.2307892769918098,
                                    0.3692598119977027,
                                    0.15382805053461107,
                                    0.24612286047587645,
                                ],
                                [
                                    0.2307892769918098,
                                    0.15382805053461107,
                                    0.3692598119977027,
                                    0.24612286047587645,
                                ],
                                [
                                    0.6594035381045106,
                                    0.2198011793681702,
                                    0.09059646189548937,
                                    0.03019882063182979,
                                ],
                                [
                                    0.6594035381045106,
                                    0.09059646189548937,
                                    0.2198011793681702,
                                    0.03019882063182979,
                                ],
                                [
                                    0.30199481699101116,
                                    0.10066493899700371,
                                    0.44800518300898884,
                                    0.1493350610029963,
                                ],
                                [
                                    0.2198011793681702,
                                    0.03019882063182979,
                                    0.6594035381045106,
                                    0.09059646189548937,
                                ],
                                [
                                    0.2198011793681702,
                                    0.6594035381045106,
                                    0.03019882063182979,
                                    0.09059646189548937,
                                ],
                                [
                                    0.30199481699101116,
                                    0.44800518300898884,
                                    0.10066493899700371,
                                    0.1493350610029963,
                                ],
                                [
                                    0.10066493899700371,
                                    0.30199481699101116,
                                    0.1493350610029963,
                                    0.44800518300898884,
                                ],
                                [
                                    0.10066493899700371,
                                    0.1493350610029963,
                                    0.30199481699101116,
                                    0.44800518300898884,
                                ],
                                [
                                    0.8301427881005397,
                                    0.10827743301563093,
                                    0.0544745394258811,
                                    0.007105239457948322,
                                ],
                                [
                                    0.8301427881005397,
                                    0.0544745394258811,
                                    0.10827743301563093,
                                    0.007105239457948322,
                                ],
                                [
                                    0.1815857730025509,
                                    0.0236846499839664,
                                    0.7030315545238698,
                                    0.09169802248961285,
                                ],
                                [
                                    0.10827743301563093,
                                    0.007105239457948322,
                                    0.8301427881005397,
                                    0.0544745394258811,
                                ],
                                [
                                    0.10827743301563093,
                                    0.8301427881005397,
                                    0.007105239457948322,
                                    0.0544745394258811,
                                ],
                                [
                                    0.1815857730025509,
                                    0.7030315545238698,
                                    0.0236846499839664,
                                    0.09169802248961285,
                                ],
                                [
                                    0.0236846499839664,
                                    0.1815857730025509,
                                    0.09169802248961285,
                                    0.7030315545238698,
                                ],
                                [
                                    0.0236846499839664,
                                    0.09169802248961285,
                                    0.1815857730025509,
                                    0.7030315545238698,
                                ],
                                [
                                    0.955898234340051,
                                    0.022959137354105073,
                                    0.020646727144615,
                                    0.0004959011612289617,
                                ],
                                [
                                    0.955898234340051,
                                    0.020646727144615,
                                    0.022959137354105073,
                                    0.0004959011612289617,
                                ],
                                [
                                    0.0688239303726251,
                                    0.0016530400558437959,
                                    0.9077210311120408,
                                    0.02180199845949024,
                                ],
                                [
                                    0.022959137354105073,
                                    0.0004959011612289617,
                                    0.955898234340051,
                                    0.020646727144615,
                                ],
                                [
                                    0.022959137354105073,
                                    0.955898234340051,
                                    0.0004959011612289617,
                                    0.020646727144615,
                                ],
                                [
                                    0.0688239303726251,
                                    0.9077210311120408,
                                    0.0016530400558437959,
                                    0.02180199845949024,
                                ],
                                [
                                    0.0016530400558437959,
                                    0.0688239303726251,
                                    0.02180199845949024,
                                    0.9077210311120408,
                                ],
                                [
                                    0.0016530400558437959,
                                    0.02180199845949024,
                                    0.0688239303726251,
                                    0.9077210311120408,
                                ],
                                [
                                    0.2080236254470295,
                                    0.5715284378041762,
                                    0.0588265764233172,
                                    0.16162136032547716,
                                ],
                                [
                                    0.2080236254470295,
                                    0.0588265764233172,
                                    0.5715284378041762,
                                    0.16162136032547716,
                                ],
                                [
                                    0.19609288055488522,
                                    0.5387496609926755,
                                    0.07075732131546147,
                                    0.19440013713697774,
                                ],
                                [
                                    0.17145477811049922,
                                    0.04848534672917941,
                                    0.6080972851407064,
                                    0.17196259001961497,
                                ],
                                [
                                    0.17145477811049922,
                                    0.6080972851407064,
                                    0.04848534672917941,
                                    0.17196259001961497,
                                ],
                                [
                                    0.19609288055488522,
                                    0.07075732131546147,
                                    0.5387496609926755,
                                    0.19440013713697774,
                                ],
                                [
                                    0.16162136032547725,
                                    0.5732211812220835,
                                    0.05831876451420138,
                                    0.20683869393823784,
                                ],
                                [
                                    0.16162136032547725,
                                    0.05831876451420138,
                                    0.5732211812220835,
                                    0.20683869393823784,
                                ],
                                [
                                    0.33478359352516757,
                                    0.48520562030402353,
                                    0.0734944519405684,
                                    0.10651633423024053,
                                ],
                                [
                                    0.33478359352516757,
                                    0.0734944519405684,
                                    0.48520562030402353,
                                    0.10651633423024053,
                                ],
                                [
                                    0.24498686923613364,
                                    0.35506221975337887,
                                    0.16329117622960235,
                                    0.23665973478088517,
                                ],
                                [
                                    0.14555849974292498,
                                    0.031954200775652496,
                                    0.6744307140862661,
                                    0.14805658539515643,
                                ],
                                [
                                    0.14555849974292498,
                                    0.6744307140862661,
                                    0.031954200775652496,
                                    0.14805658539515643,
                                ],
                                [
                                    0.24498686923613364,
                                    0.16329117622960235,
                                    0.35506221975337887,
                                    0.23665973478088517,
                                ],
                                [
                                    0.10651633423024058,
                                    0.4935327547592719,
                                    0.0709963662883369,
                                    0.32895454472215063,
                                ],
                                [
                                    0.10651633423024058,
                                    0.0709963662883369,
                                    0.4935327547592719,
                                    0.32895454472215063,
                                ],
                                [
                                    0.5410473486897165,
                                    0.3381573687829643,
                                    0.07433532378386272,
                                    0.046459958743456445,
                                ],
                                [
                                    0.5410473486897165,
                                    0.07433532378386272,
                                    0.3381573687829643,
                                    0.046459958743456445,
                                ],
                                [
                                    0.24778983673746388,
                                    0.15486991925055096,
                                    0.3675928357361154,
                                    0.22974740827586979,
                                ],
                                [
                                    0.10144498995337611,
                                    0.013937682520203137,
                                    0.7777597275193047,
                                    0.10685760000711603,
                                ],
                                [
                                    0.10144498995337611,
                                    0.7777597275193047,
                                    0.013937682520203137,
                                    0.10685760000711603,
                                ],
                                [
                                    0.24778983673746388,
                                    0.3675928357361154,
                                    0.15486991925055096,
                                    0.22974740827586979,
                                ],
                                [
                                    0.04645995874345646,
                                    0.3561997972445584,
                                    0.06892271373012279,
                                    0.5284175302818623,
                                ],
                                [
                                    0.04645995874345646,
                                    0.06892271373012279,
                                    0.3561997972445584,
                                    0.5284175302818623,
                                ],
                                [
                                    0.7718387134445985,
                                    0.16658150767157204,
                                    0.05064858603682399,
                                    0.010931192847005432,
                                ],
                                [
                                    0.7718387134445985,
                                    0.05064858603682399,
                                    0.16658150767157204,
                                    0.010931192847005432,
                                ],
                                [
                                    0.16883231586558994,
                                    0.03643810712092737,
                                    0.6536549836158325,
                                    0.14107459339765008,
                                ],
                                [
                                    0.049973358359689815,
                                    0.0032792860688912098,
                                    0.8884468627564808,
                                    0.05830049281493821,
                                ],
                                [
                                    0.049973358359689815,
                                    0.8884468627564808,
                                    0.0032792860688912098,
                                    0.05830049281493821,
                                ],
                                [
                                    0.16883231586558994,
                                    0.6536549836158325,
                                    0.03643810712092737,
                                    0.14107459339765008,
                                ],
                                [
                                    0.01093119284700543,
                                    0.19433923013951188,
                                    0.04232145158157559,
                                    0.752408125431907,
                                ],
                                [
                                    0.01093119284700543,
                                    0.04232145158157559,
                                    0.19433923013951188,
                                    0.752408125431907,
                                ],
                                [
                                    0.9435354434883644,
                                    0.03532192820579165,
                                    0.020379699588447434,
                                    0.0007629287173965278,
                                ],
                                [
                                    0.9435354434883644,
                                    0.020379699588447434,
                                    0.03532192820579165,
                                    0.0007629287173965278,
                                ],
                                [
                                    0.06793381903417783,
                                    0.002543151394291064,
                                    0.895981324042634,
                                    0.03354170552889711,
                                ],
                                [
                                    0.010596346502418487,
                                    0.00022887360506139537,
                                    0.9682610251917375,
                                    0.020913754700782567,
                                ],
                                [
                                    0.010596346502418487,
                                    0.9682610251917375,
                                    0.00022887360506139537,
                                    0.020913754700782567,
                                ],
                                [
                                    0.06793381903417783,
                                    0.895981324042634,
                                    0.002543151394291064,
                                    0.03354170552889711,
                                ],
                                [
                                    0.0007629287173965266,
                                    0.06971404171107237,
                                    0.010062291390083355,
                                    0.9194607381814477,
                                ],
                                [
                                    0.0007629287173965266,
                                    0.010062291390083355,
                                    0.06971404171107237,
                                    0.9194607381814477,
                                ],
                                [
                                    0.07142224722758118,
                                    0.7081298160236245,
                                    0.020197351506731735,
                                    0.20025058524206263,
                                ],
                                [
                                    0.07142224722758118,
                                    0.020197351506731735,
                                    0.7081298160236245,
                                    0.20025058524206263,
                                ],
                                [
                                    0.06732597878949019,
                                    0.6675165627580706,
                                    0.02429361994482273,
                                    0.24086383850761647,
                                ],
                                [
                                    0.03485339989105089,
                                    0.009856121812593946,
                                    0.7446986633601548,
                                    0.2105918149362004,
                                ],
                                [
                                    0.03485339989105089,
                                    0.7446986633601548,
                                    0.009856121812593946,
                                    0.2105918149362004,
                                ],
                                [
                                    0.06732597878949019,
                                    0.02429361994482273,
                                    0.6675165627580706,
                                    0.24086383850761647,
                                ],
                                [
                                    0.032854458560082206,
                                    0.7019880829874786,
                                    0.011855063143562635,
                                    0.25330239530887655,
                                ],
                                [
                                    0.032854458560082206,
                                    0.011855063143562635,
                                    0.7019880829874786,
                                    0.25330239530887655,
                                ],
                                [
                                    0.21881428724182653,
                                    0.6011749265873646,
                                    0.04803591462852017,
                                    0.13197487154228876,
                                ],
                                [
                                    0.21881428724182653,
                                    0.04803591462852017,
                                    0.6011749265873646,
                                    0.13197487154228876,
                                ],
                                [
                                    0.16012322052896905,
                                    0.43992586846054343,
                                    0.10672698134137766,
                                    0.2932239296691099,
                                ],
                                [
                                    0.02958919345958393,
                                    0.006495663463604264,
                                    0.7904000203696072,
                                    0.17351512270720468,
                                ],
                                [
                                    0.02958919345958393,
                                    0.7904000203696072,
                                    0.006495663463604264,
                                    0.17351512270720468,
                                ],
                                [
                                    0.16012322052896905,
                                    0.10672698134137766,
                                    0.43992586846054343,
                                    0.2932239296691099,
                                ],
                                [
                                    0.021652685523075976,
                                    0.5783964034664365,
                                    0.014432171400112215,
                                    0.3855187396103753,
                                ],
                                [
                                    0.021652685523075976,
                                    0.014432171400112215,
                                    0.5783964034664365,
                                    0.3855187396103753,
                                ],
                                [
                                    0.46022413924752553,
                                    0.4189805782251553,
                                    0.0632308992678085,
                                    0.05756438325951065,
                                ],
                                [
                                    0.46022413924752553,
                                    0.0632308992678085,
                                    0.4189805782251553,
                                    0.05756438325951065,
                                ],
                                [
                                    0.2107742780792813,
                                    0.19188547790873353,
                                    0.3126807604360527,
                                    0.28465948357593246,
                                ],
                                [
                                    0.020621780511185107,
                                    0.0028332580041489277,
                                    0.8585829369614957,
                                    0.11796202452317024,
                                ],
                                [
                                    0.020621780511185107,
                                    0.8585829369614957,
                                    0.0028332580041489277,
                                    0.11796202452317024,
                                ],
                                [
                                    0.2107742780792813,
                                    0.3126807604360527,
                                    0.19188547790873353,
                                    0.28465948357593246,
                                ],
                                [
                                    0.009444400085273892,
                                    0.3932153559027409,
                                    0.014010638430060144,
                                    0.583329605581925,
                                ],
                                [
                                    0.009444400085273892,
                                    0.014010638430060144,
                                    0.3932153559027409,
                                    0.583329605581925,
                                ],
                                [
                                    0.7320239605318013,
                                    0.20639626058436938,
                                    0.04803591462852017,
                                    0.013543864255309249,
                                ],
                                [
                                    0.7320239605318013,
                                    0.04803591462852017,
                                    0.20639626058436938,
                                    0.013543864255309249,
                                ],
                                [
                                    0.16012322052896907,
                                    0.045147202457548254,
                                    0.6199366546313523,
                                    0.17479292238213037,
                                ],
                                [
                                    0.010158605446892488,
                                    0.0006666146605873954,
                                    0.9282616156692781,
                                    0.06091316422324203,
                                ],
                                [
                                    0.010158605446892488,
                                    0.9282616156692781,
                                    0.0006666146605873954,
                                    0.06091316422324203,
                                ],
                                [
                                    0.16012322052896907,
                                    0.6199366546313523,
                                    0.045147202457548254,
                                    0.17479292238213037,
                                ],
                                [
                                    0.002222097510384548,
                                    0.20304832547613277,
                                    0.008603122597095334,
                                    0.7861264544163874,
                                ],
                                [
                                    0.002222097510384548,
                                    0.008603122597095334,
                                    0.20304832547613277,
                                    0.7861264544163874,
                                ],
                                [
                                    0.9350931267896234,
                                    0.04376424490453263,
                                    0.020197351506731735,
                                    0.0009452767991122268,
                                ],
                                [
                                    0.9350931267896234,
                                    0.020197351506731735,
                                    0.04376424490453263,
                                    0.0009452767991122268,
                                ],
                                [
                                    0.06732597878949013,
                                    0.003150991638978767,
                                    0.8879644995068651,
                                    0.041558530064666095,
                                ],
                                [
                                    0.0021540298036775373,
                                    4.652552334569716e-05,
                                    0.9767033418904785,
                                    0.021096102782498263,
                                ],
                                [
                                    0.0021540298036775373,
                                    0.9767033418904785,
                                    4.652552334569716e-05,
                                    0.021096102782498263,
                                ],
                                [
                                    0.06732597878949013,
                                    0.8879644995068651,
                                    0.003150991638978767,
                                    0.041558530064666095,
                                ],
                                [
                                    0.00015508847270882621,
                                    0.07032188195576007,
                                    0.0020454668543144084,
                                    0.9274775627172167,
                                ],
                                [
                                    0.00015508847270882621,
                                    0.0020454668543144084,
                                    0.07032188195576007,
                                    0.9274775627172167,
                                ],
                                [
                                    0.49900052933451566,
                                    0.02335423151730675,
                                    0.4562899489618395,
                                    0.021355290186338062,
                                ],
                                [
                                    0.49900052933451566,
                                    0.4562899489618395,
                                    0.02335423151730675,
                                    0.021355290186338062,
                                ],
                                [
                                    0.4562899489618395,
                                    0.021355290186338062,
                                    0.49900052933451566,
                                    0.02335423151730675,
                                ],
                                [
                                    0.47449682726562054,
                                    0.43388357400006666,
                                    0.04785793358620191,
                                    0.04376166514811092,
                                ],
                                [
                                    0.47449682726562054,
                                    0.04785793358620191,
                                    0.43388357400006666,
                                    0.04376166514811092,
                                ],
                                [
                                    0.4562899489618395,
                                    0.49900052933451566,
                                    0.021355290186338062,
                                    0.02335423151730675,
                                ],
                                [
                                    0.43388357400006666,
                                    0.04376166514811092,
                                    0.47449682726562054,
                                    0.04785793358620191,
                                ],
                                [
                                    0.43388357400006666,
                                    0.47449682726562054,
                                    0.04376166514811092,
                                    0.04785793358620191,
                                ],
                                [
                                    0.5879593799899913,
                                    0.02201068242984804,
                                    0.37595576308682055,
                                    0.014074174493340098,
                                ],
                                [
                                    0.5879593799899913,
                                    0.37595576308682055,
                                    0.02201068242984804,
                                    0.014074174493340098,
                                ],
                                [
                                    0.37595576308682066,
                                    0.014074174493340101,
                                    0.5879593799899911,
                                    0.022010682429848032,
                                ],
                                [
                                    0.44719942812823726,
                                    0.28595037000141615,
                                    0.16277063429160202,
                                    0.10407956757874455,
                                ],
                                [
                                    0.44719942812823726,
                                    0.16277063429160202,
                                    0.28595037000141615,
                                    0.10407956757874455,
                                ],
                                [
                                    0.37595576308682066,
                                    0.5879593799899911,
                                    0.014074174493340101,
                                    0.022010682429848032,
                                ],
                                [
                                    0.2859503700014162,
                                    0.10407956757874459,
                                    0.4471994281282372,
                                    0.162770634291602,
                                ],
                                [
                                    0.2859503700014162,
                                    0.4471994281282372,
                                    0.10407956757874459,
                                    0.162770634291602,
                                ],
                                [
                                    0.7209562712717104,
                                    0.017316209470622606,
                                    0.2555886902129556,
                                    0.006138829044711403,
                                ],
                                [
                                    0.7209562712717104,
                                    0.2555886902129556,
                                    0.017316209470622606,
                                    0.006138829044711403,
                                ],
                                [
                                    0.2555886902129556,
                                    0.006138829044711403,
                                    0.7209562712717104,
                                    0.017316209470622606,
                                ],
                                [
                                    0.35182003090054387,
                                    0.1247249305841221,
                                    0.3864524498417891,
                                    0.13700258867354492,
                                ],
                                [
                                    0.35182003090054387,
                                    0.3864524498417891,
                                    0.1247249305841221,
                                    0.13700258867354492,
                                ],
                                [
                                    0.2555886902129556,
                                    0.7209562712717104,
                                    0.006138829044711403,
                                    0.017316209470622606,
                                ],
                                [
                                    0.1247249305841221,
                                    0.13700258867354492,
                                    0.35182003090054387,
                                    0.3864524498417891,
                                ],
                                [
                                    0.1247249305841221,
                                    0.35182003090054387,
                                    0.13700258867354492,
                                    0.3864524498417891,
                                ],
                                [
                                    0.8571940350428328,
                                    0.009380864021993911,
                                    0.1319807448496874,
                                    0.0014443560854859713,
                                ],
                                [
                                    0.8571940350428328,
                                    0.1319807448496874,
                                    0.009380864021993911,
                                    0.0014443560854859713,
                                ],
                                [
                                    0.1319807448496874,
                                    0.0014443560854859713,
                                    0.8571940350428328,
                                    0.009380864021993911,
                                ],
                                [
                                    0.19059459148324986,
                                    0.029345533356428748,
                                    0.6759803075815768,
                                    0.1040795675787446,
                                ],
                                [
                                    0.19059459148324986,
                                    0.6759803075815768,
                                    0.029345533356428748,
                                    0.1040795675787446,
                                ],
                                [
                                    0.1319807448496874,
                                    0.8571940350428328,
                                    0.0014443560854859713,
                                    0.009380864021993911,
                                ],
                                [
                                    0.029345533356428748,
                                    0.1040795675787446,
                                    0.19059459148324986,
                                    0.6759803075815768,
                                ],
                                [
                                    0.029345533356428748,
                                    0.19059459148324986,
                                    0.1040795675787446,
                                    0.6759803075815768,
                                ],
                                [
                                    0.9520904523038476,
                                    0.002099748328995949,
                                    0.045708992369129196,
                                    0.00010080699802726059,
                                ],
                                [
                                    0.9520904523038476,
                                    0.045708992369129196,
                                    0.002099748328995949,
                                    0.00010080699802726059,
                                ],
                                [
                                    0.045708992369129196,
                                    0.00010080699802726059,
                                    0.9520904523038476,
                                    0.002099748328995949,
                                ],
                                [
                                    0.04266138748459934,
                                    0.002048134219045497,
                                    0.9115288131482442,
                                    0.04376166514811096,
                                ],
                                [
                                    0.04266138748459934,
                                    0.9115288131482442,
                                    0.002048134219045497,
                                    0.04376166514811096,
                                ],
                                [
                                    0.045708992369129196,
                                    0.9520904523038476,
                                    0.00010080699802726059,
                                    0.002099748328995949,
                                ],
                                [
                                    0.002048134219045497,
                                    0.04376166514811096,
                                    0.04266138748459934,
                                    0.9115288131482442,
                                ],
                                [
                                    0.002048134219045497,
                                    0.04266138748459934,
                                    0.04376166514811096,
                                    0.9115288131482442,
                                ],
                                [
                                    0.4074679895394721,
                                    0.11488677131235027,
                                    0.3725918856208493,
                                    0.1050533535273283,
                                ],
                                [
                                    0.4074679895394721,
                                    0.3725918856208493,
                                    0.11488677131235027,
                                    0.1050533535273283,
                                ],
                                [
                                    0.3725918856208493,
                                    0.1050533535273283,
                                    0.4074679895394721,
                                    0.11488677131235027,
                                ],
                                [
                                    0.382964287470577,
                                    0.35018551065907644,
                                    0.1393904733812454,
                                    0.12745972848910117,
                                ],
                                [
                                    0.382964287470577,
                                    0.1393904733812454,
                                    0.35018551065907644,
                                    0.12745972848910117,
                                ],
                                [
                                    0.3725918856208493,
                                    0.4074679895394721,
                                    0.1050533535273283,
                                    0.11488677131235027,
                                ],
                                [
                                    0.35018551065907644,
                                    0.12745972848910117,
                                    0.382964287470577,
                                    0.1393904733812454,
                                ],
                                [
                                    0.35018551065907644,
                                    0.382964287470577,
                                    0.12745972848910117,
                                    0.1393904733812454,
                                ],
                                [
                                    0.5016926294042084,
                                    0.10827743301563089,
                                    0.3207946700772142,
                                    0.06923526750294651,
                                ],
                                [
                                    0.5016926294042084,
                                    0.3207946700772142,
                                    0.10827743301563089,
                                    0.06923526750294651,
                                ],
                                [
                                    0.3207946700772143,
                                    0.06923526750294652,
                                    0.5016926294042083,
                                    0.10827743301563088,
                                ],
                                [
                                    0.3609326775424544,
                                    0.23078927699180973,
                                    0.24903738487738492,
                                    0.15924066058835096,
                                ],
                                [
                                    0.3609326775424544,
                                    0.24903738487738492,
                                    0.23078927699180973,
                                    0.15924066058835096,
                                ],
                                [
                                    0.3207946700772143,
                                    0.5016926294042083,
                                    0.06923526750294652,
                                    0.10827743301563088,
                                ],
                                [
                                    0.2307892769918098,
                                    0.159240660588351,
                                    0.36093267754245434,
                                    0.24903738487738486,
                                ],
                                [
                                    0.2307892769918098,
                                    0.36093267754245434,
                                    0.159240660588351,
                                    0.24903738487738486,
                                ],
                                [
                                    0.6530886289005835,
                                    0.08518385184174943,
                                    0.23152869862583722,
                                    0.03019882063182979,
                                ],
                                [
                                    0.6530886289005835,
                                    0.23152869862583722,
                                    0.08518385184174943,
                                    0.03019882063182979,
                                ],
                                [
                                    0.23152869862583722,
                                    0.03019882063182979,
                                    0.6530886289005835,
                                    0.08518385184174943,
                                ],
                                [
                                    0.28395238852941707,
                                    0.10066493899700371,
                                    0.4543200922129159,
                                    0.1610625802606633,
                                ],
                                [
                                    0.28395238852941707,
                                    0.4543200922129159,
                                    0.10066493899700371,
                                    0.1610625802606633,
                                ],
                                [
                                    0.23152869862583722,
                                    0.6530886289005835,
                                    0.03019882063182979,
                                    0.08518385184174943,
                                ],
                                [
                                    0.10066493899700371,
                                    0.1610625802606633,
                                    0.28395238852941707,
                                    0.4543200922129159,
                                ],
                                [
                                    0.10066493899700371,
                                    0.28395238852941707,
                                    0.1610625802606633,
                                    0.4543200922129159,
                                ],
                                [
                                    0.8204274940941939,
                                    0.046147404970632716,
                                    0.12631986147722502,
                                    0.007105239457948322,
                                ],
                                [
                                    0.8204274940941939,
                                    0.12631986147722502,
                                    0.046147404970632716,
                                    0.007105239457948322,
                                ],
                                [
                                    0.12631986147722502,
                                    0.007105239457948322,
                                    0.8204274940941939,
                                    0.046147404970632716,
                                ],
                                [
                                    0.15382805053461107,
                                    0.0236846499839664,
                                    0.7127468485302155,
                                    0.10974045095120695,
                                ],
                                [
                                    0.15382805053461107,
                                    0.7127468485302155,
                                    0.0236846499839664,
                                    0.10974045095120695,
                                ],
                                [
                                    0.12631986147722502,
                                    0.8204274940941939,
                                    0.007105239457948322,
                                    0.046147404970632716,
                                ],
                                [
                                    0.0236846499839664,
                                    0.10974045095120695,
                                    0.15382805053461107,
                                    0.7127468485302155,
                                ],
                                [
                                    0.0236846499839664,
                                    0.15382805053461107,
                                    0.10974045095120695,
                                    0.7127468485302155,
                                ],
                                [
                                    0.9438608816865927,
                                    0.01032931894625093,
                                    0.045313898205927496,
                                    0.0004959011612289618,
                                ],
                                [
                                    0.9438608816865927,
                                    0.045313898205927496,
                                    0.01032931894625093,
                                    0.0004959011612289618,
                                ],
                                [
                                    0.045313898205927496,
                                    0.0004959011612289618,
                                    0.9438608816865927,
                                    0.01032931894625093,
                                ],
                                [
                                    0.034431816867344395,
                                    0.0016530400558437976,
                                    0.9197583837654991,
                                    0.04415675931131266,
                                ],
                                [
                                    0.034431816867344395,
                                    0.9197583837654991,
                                    0.0016530400558437976,
                                    0.04415675931131266,
                                ],
                                [
                                    0.045313898205927496,
                                    0.9438608816865927,
                                    0.0004959011612289618,
                                    0.01032931894625093,
                                ],
                                [
                                    0.0016530400558437976,
                                    0.04415675931131266,
                                    0.034431816867344395,
                                    0.9197583837654991,
                                ],
                                [
                                    0.0016530400558437976,
                                    0.034431816867344395,
                                    0.04415675931131266,
                                    0.9197583837654991,
                                ],
                                [
                                    0.2734292314603588,
                                    0.24892552939146362,
                                    0.25002580705497524,
                                    0.22761943209320235,
                                ],
                                [
                                    0.2734292314603588,
                                    0.25002580705497524,
                                    0.24892552939146362,
                                    0.22761943209320235,
                                ],
                                [
                                    0.25002580705497524,
                                    0.22761943209320235,
                                    0.2734292314603588,
                                    0.24892552939146362,
                                ],
                                [
                                    0.24892552939146362,
                                    0.22761943209320235,
                                    0.2734292314603588,
                                    0.25002580705497524,
                                ],
                                [
                                    0.24892552939146362,
                                    0.2734292314603588,
                                    0.22761943209320235,
                                    0.25002580705497524,
                                ],
                                [
                                    0.25002580705497524,
                                    0.2734292314603588,
                                    0.22761943209320235,
                                    0.24892552939146362,
                                ],
                                [
                                    0.22761943209320235,
                                    0.25002580705497524,
                                    0.24892552939146362,
                                    0.2734292314603588,
                                ],
                                [
                                    0.22761943209320235,
                                    0.24892552939146362,
                                    0.25002580705497524,
                                    0.2734292314603588,
                                ],
                                [
                                    0.3753650071407967,
                                    0.23460505527904266,
                                    0.2400176653327826,
                                    0.1500122722473781,
                                ],
                                [
                                    0.3753650071407967,
                                    0.2400176653327826,
                                    0.23460505527904266,
                                    0.1500122722473781,
                                ],
                                [
                                    0.24001766533278265,
                                    0.15001227224737815,
                                    0.37536500714079657,
                                    0.2346050552790426,
                                ],
                                [
                                    0.2346050552790427,
                                    0.15001227224737815,
                                    0.3753650071407966,
                                    0.24001766533278254,
                                ],
                                [
                                    0.2346050552790427,
                                    0.3753650071407966,
                                    0.15001227224737815,
                                    0.24001766533278254,
                                ],
                                [
                                    0.24001766533278265,
                                    0.37536500714079657,
                                    0.15001227224737815,
                                    0.2346050552790426,
                                ],
                                [
                                    0.1500122722473782,
                                    0.2400176653327826,
                                    0.23460505527904266,
                                    0.3753650071407965,
                                ],
                                [
                                    0.1500122722473782,
                                    0.23460505527904266,
                                    0.2400176653327826,
                                    0.3753650071407965,
                                ],
                                [
                                    0.5537043605567498,
                                    0.18456812018558325,
                                    0.19629563944325026,
                                    0.06543187981441675,
                                ],
                                [
                                    0.5537043605567498,
                                    0.19629563944325026,
                                    0.18456812018558325,
                                    0.06543187981441675,
                                ],
                                [
                                    0.19629563944325026,
                                    0.06543187981441675,
                                    0.5537043605567498,
                                    0.18456812018558325,
                                ],
                                [
                                    0.18456812018558325,
                                    0.06543187981441675,
                                    0.5537043605567498,
                                    0.19629563944325026,
                                ],
                                [
                                    0.18456812018558325,
                                    0.5537043605567498,
                                    0.06543187981441675,
                                    0.19629563944325026,
                                ],
                                [
                                    0.19629563944325026,
                                    0.5537043605567498,
                                    0.06543187981441675,
                                    0.18456812018558325,
                                ],
                                [
                                    0.06543187981441675,
                                    0.19629563944325026,
                                    0.18456812018558325,
                                    0.5537043605567498,
                                ],
                                [
                                    0.06543187981441675,
                                    0.18456812018558325,
                                    0.19629563944325026,
                                    0.5537043605567498,
                                ],
                                [
                                    0.7665871713122048,
                                    0.0999877277526219,
                                    0.11803015621421599,
                                    0.015394944720957359,
                                ],
                                [
                                    0.7665871713122048,
                                    0.11803015621421599,
                                    0.0999877277526219,
                                    0.015394944720957359,
                                ],
                                [
                                    0.11803015621421599,
                                    0.015394944720957359,
                                    0.7665871713122048,
                                    0.0999877277526219,
                                ],
                                [
                                    0.0999877277526219,
                                    0.015394944720957359,
                                    0.7665871713122048,
                                    0.11803015621421599,
                                ],
                                [
                                    0.0999877277526219,
                                    0.7665871713122048,
                                    0.015394944720957359,
                                    0.11803015621421599,
                                ],
                                [
                                    0.11803015621421599,
                                    0.7665871713122048,
                                    0.015394944720957359,
                                    0.0999877277526219,
                                ],
                                [
                                    0.015394944720957359,
                                    0.11803015621421599,
                                    0.0999877277526219,
                                    0.7665871713122048,
                                ],
                                [
                                    0.015394944720957359,
                                    0.0999877277526219,
                                    0.11803015621421599,
                                    0.7665871713122048,
                                ],
                                [
                                    0.9318096327260459,
                                    0.02238056790679766,
                                    0.044735328758620074,
                                    0.0010744706085363794,
                                ],
                                [
                                    0.9318096327260459,
                                    0.044735328758620074,
                                    0.02238056790679766,
                                    0.0010744706085363794,
                                ],
                                [
                                    0.044735328758620074,
                                    0.0010744706085363794,
                                    0.9318096327260459,
                                    0.02238056790679766,
                                ],
                                [
                                    0.02238056790679766,
                                    0.0010744706085363794,
                                    0.9318096327260459,
                                    0.044735328758620074,
                                ],
                                [
                                    0.02238056790679766,
                                    0.9318096327260459,
                                    0.0010744706085363794,
                                    0.044735328758620074,
                                ],
                                [
                                    0.044735328758620074,
                                    0.9318096327260459,
                                    0.0010744706085363794,
                                    0.02238056790679766,
                                ],
                                [
                                    0.0010744706085363794,
                                    0.044735328758620074,
                                    0.02238056790679766,
                                    0.9318096327260459,
                                ],
                                [
                                    0.0010744706085363794,
                                    0.02238056790679766,
                                    0.044735328758620074,
                                    0.9318096327260459,
                                ],
                                [
                                    0.1393904733812455,
                                    0.3829642874705769,
                                    0.1274597284891012,
                                    0.3501855106590764,
                                ],
                                [
                                    0.1393904733812455,
                                    0.1274597284891012,
                                    0.3829642874705769,
                                    0.3501855106590764,
                                ],
                                [
                                    0.1274597284891012,
                                    0.3501855106590764,
                                    0.1393904733812455,
                                    0.3829642874705769,
                                ],
                                [
                                    0.1148867713123503,
                                    0.10505335352732832,
                                    0.4074679895394721,
                                    0.3725918856208493,
                                ],
                                [
                                    0.1148867713123503,
                                    0.4074679895394721,
                                    0.10505335352732832,
                                    0.3725918856208493,
                                ],
                                [
                                    0.1274597284891012,
                                    0.1393904733812455,
                                    0.3501855106590764,
                                    0.3829642874705769,
                                ],
                                [
                                    0.10505335352732832,
                                    0.3725918856208493,
                                    0.1148867713123503,
                                    0.4074679895394721,
                                ],
                                [
                                    0.10505335352732832,
                                    0.1148867713123503,
                                    0.3725918856208493,
                                    0.4074679895394721,
                                ],
                                [
                                    0.24903738487738497,
                                    0.36093267754245434,
                                    0.159240660588351,
                                    0.23078927699180968,
                                ],
                                [
                                    0.24903738487738497,
                                    0.159240660588351,
                                    0.36093267754245434,
                                    0.23078927699180968,
                                ],
                                [
                                    0.15924066058835107,
                                    0.23078927699180973,
                                    0.24903738487738492,
                                    0.3609326775424543,
                                ],
                                [
                                    0.10827743301563095,
                                    0.06923526750294653,
                                    0.5016926294042083,
                                    0.3207946700772142,
                                ],
                                [
                                    0.10827743301563095,
                                    0.5016926294042083,
                                    0.06923526750294653,
                                    0.3207946700772142,
                                ],
                                [
                                    0.15924066058835107,
                                    0.24903738487738492,
                                    0.23078927699180973,
                                    0.3609326775424543,
                                ],
                                [
                                    0.06923526750294655,
                                    0.32079467007721424,
                                    0.10827743301563093,
                                    0.5016926294042082,
                                ],
                                [
                                    0.06923526750294655,
                                    0.10827743301563093,
                                    0.32079467007721424,
                                    0.5016926294042082,
                                ],
                                [
                                    0.4543200922129159,
                                    0.28395238852941707,
                                    0.1610625802606633,
                                    0.10066493899700371,
                                ],
                                [
                                    0.4543200922129159,
                                    0.1610625802606633,
                                    0.28395238852941707,
                                    0.10066493899700371,
                                ],
                                [
                                    0.1610625802606633,
                                    0.10066493899700371,
                                    0.4543200922129159,
                                    0.28395238852941707,
                                ],
                                [
                                    0.08518385184174945,
                                    0.030198820631829798,
                                    0.6530886289005835,
                                    0.23152869862583722,
                                ],
                                [
                                    0.08518385184174945,
                                    0.6530886289005835,
                                    0.030198820631829798,
                                    0.23152869862583722,
                                ],
                                [
                                    0.1610625802606633,
                                    0.4543200922129159,
                                    0.10066493899700371,
                                    0.28395238852941707,
                                ],
                                [
                                    0.030198820631829798,
                                    0.23152869862583722,
                                    0.08518385184174945,
                                    0.6530886289005835,
                                ],
                                [
                                    0.030198820631829798,
                                    0.08518385184174945,
                                    0.23152869862583722,
                                    0.6530886289005835,
                                ],
                                [
                                    0.7127468485302155,
                                    0.15382805053461107,
                                    0.10974045095120695,
                                    0.023684649983966397,
                                ],
                                [
                                    0.7127468485302155,
                                    0.10974045095120695,
                                    0.15382805053461107,
                                    0.023684649983966397,
                                ],
                                [
                                    0.10974045095120695,
                                    0.023684649983966397,
                                    0.7127468485302155,
                                    0.15382805053461107,
                                ],
                                [
                                    0.0461474049706327,
                                    0.007105239457948319,
                                    0.8204274940941939,
                                    0.12631986147722502,
                                ],
                                [
                                    0.0461474049706327,
                                    0.8204274940941939,
                                    0.007105239457948319,
                                    0.12631986147722502,
                                ],
                                [
                                    0.10974045095120695,
                                    0.7127468485302155,
                                    0.023684649983966397,
                                    0.15382805053461107,
                                ],
                                [
                                    0.007105239457948319,
                                    0.12631986147722502,
                                    0.0461474049706327,
                                    0.8204274940941939,
                                ],
                                [
                                    0.007105239457948319,
                                    0.0461474049706327,
                                    0.12631986147722502,
                                    0.8204274940941939,
                                ],
                                [
                                    0.9197583837654991,
                                    0.03443181686734438,
                                    0.04415675931131266,
                                    0.001653040055843797,
                                ],
                                [
                                    0.9197583837654991,
                                    0.04415675931131266,
                                    0.03443181686734438,
                                    0.001653040055843797,
                                ],
                                [
                                    0.04415675931131266,
                                    0.001653040055843797,
                                    0.9197583837654991,
                                    0.03443181686734438,
                                ],
                                [
                                    0.010329318946250922,
                                    0.0004959011612289613,
                                    0.9438608816865927,
                                    0.045313898205927496,
                                ],
                                [
                                    0.010329318946250922,
                                    0.9438608816865927,
                                    0.0004959011612289613,
                                    0.045313898205927496,
                                ],
                                [
                                    0.04415675931131266,
                                    0.9197583837654991,
                                    0.001653040055843797,
                                    0.03443181686734438,
                                ],
                                [
                                    0.0004959011612289613,
                                    0.045313898205927496,
                                    0.010329318946250922,
                                    0.9438608816865927,
                                ],
                                [
                                    0.0004959011612289613,
                                    0.010329318946250922,
                                    0.045313898205927496,
                                    0.9438608816865927,
                                ],
                                [
                                    0.04785793358620195,
                                    0.4744968272656205,
                                    0.04376166514811096,
                                    0.4338835740000666,
                                ],
                                [
                                    0.04785793358620195,
                                    0.04376166514811096,
                                    0.4744968272656205,
                                    0.4338835740000666,
                                ],
                                [
                                    0.04376166514811096,
                                    0.4338835740000666,
                                    0.04785793358620195,
                                    0.4744968272656205,
                                ],
                                [
                                    0.023354231517306763,
                                    0.021355290186338076,
                                    0.49900052933451566,
                                    0.4562899489618395,
                                ],
                                [
                                    0.023354231517306763,
                                    0.49900052933451566,
                                    0.021355290186338076,
                                    0.4562899489618395,
                                ],
                                [
                                    0.04376166514811096,
                                    0.04785793358620195,
                                    0.4338835740000666,
                                    0.4744968272656205,
                                ],
                                [
                                    0.021355290186338076,
                                    0.4562899489618395,
                                    0.023354231517306763,
                                    0.49900052933451566,
                                ],
                                [
                                    0.021355290186338076,
                                    0.023354231517306763,
                                    0.4562899489618395,
                                    0.49900052933451566,
                                ],
                                [
                                    0.1627706342916021,
                                    0.4471994281282372,
                                    0.1040795675787446,
                                    0.2859503700014161,
                                ],
                                [
                                    0.1627706342916021,
                                    0.1040795675787446,
                                    0.4471994281282372,
                                    0.2859503700014161,
                                ],
                                [
                                    0.10407956757874463,
                                    0.28595037000141615,
                                    0.16277063429160207,
                                    0.44719942812823715,
                                ],
                                [
                                    0.02201068242984807,
                                    0.014074174493340119,
                                    0.5879593799899913,
                                    0.37595576308682055,
                                ],
                                [
                                    0.02201068242984807,
                                    0.5879593799899913,
                                    0.014074174493340119,
                                    0.37595576308682055,
                                ],
                                [
                                    0.10407956757874463,
                                    0.16277063429160207,
                                    0.28595037000141615,
                                    0.44719942812823715,
                                ],
                                [
                                    0.014074174493340124,
                                    0.37595576308682066,
                                    0.022010682429848067,
                                    0.5879593799899911,
                                ],
                                [
                                    0.014074174493340124,
                                    0.022010682429848067,
                                    0.37595576308682066,
                                    0.5879593799899911,
                                ],
                                [
                                    0.3864524498417891,
                                    0.35182003090054387,
                                    0.13700258867354492,
                                    0.1247249305841221,
                                ],
                                [
                                    0.3864524498417891,
                                    0.13700258867354492,
                                    0.35182003090054387,
                                    0.1247249305841221,
                                ],
                                [
                                    0.13700258867354492,
                                    0.1247249305841221,
                                    0.3864524498417891,
                                    0.35182003090054387,
                                ],
                                [
                                    0.017316209470622627,
                                    0.006138829044711411,
                                    0.7209562712717104,
                                    0.2555886902129556,
                                ],
                                [
                                    0.017316209470622627,
                                    0.7209562712717104,
                                    0.006138829044711411,
                                    0.2555886902129556,
                                ],
                                [
                                    0.13700258867354492,
                                    0.3864524498417891,
                                    0.1247249305841221,
                                    0.35182003090054387,
                                ],
                                [
                                    0.006138829044711411,
                                    0.2555886902129556,
                                    0.017316209470622627,
                                    0.7209562712717104,
                                ],
                                [
                                    0.006138829044711411,
                                    0.017316209470622627,
                                    0.2555886902129556,
                                    0.7209562712717104,
                                ],
                                [
                                    0.6759803075815768,
                                    0.19059459148324986,
                                    0.1040795675787446,
                                    0.029345533356428748,
                                ],
                                [
                                    0.6759803075815768,
                                    0.1040795675787446,
                                    0.19059459148324986,
                                    0.029345533356428748,
                                ],
                                [
                                    0.1040795675787446,
                                    0.029345533356428748,
                                    0.6759803075815768,
                                    0.19059459148324986,
                                ],
                                [
                                    0.009380864021993911,
                                    0.0014443560854859713,
                                    0.8571940350428328,
                                    0.1319807448496874,
                                ],
                                [
                                    0.009380864021993911,
                                    0.8571940350428328,
                                    0.0014443560854859713,
                                    0.1319807448496874,
                                ],
                                [
                                    0.1040795675787446,
                                    0.6759803075815768,
                                    0.029345533356428748,
                                    0.19059459148324986,
                                ],
                                [
                                    0.0014443560854859713,
                                    0.1319807448496874,
                                    0.009380864021993911,
                                    0.8571940350428328,
                                ],
                                [
                                    0.0014443560854859713,
                                    0.009380864021993911,
                                    0.1319807448496874,
                                    0.8571940350428328,
                                ],
                                [
                                    0.9115288131482442,
                                    0.04266138748459936,
                                    0.04376166514811096,
                                    0.002048134219045498,
                                ],
                                [
                                    0.9115288131482442,
                                    0.04376166514811096,
                                    0.04266138748459936,
                                    0.002048134219045498,
                                ],
                                [
                                    0.04376166514811096,
                                    0.002048134219045498,
                                    0.9115288131482442,
                                    0.04266138748459936,
                                ],
                                [
                                    0.002099748328995973,
                                    0.00010080699802726174,
                                    0.9520904523038476,
                                    0.045708992369129196,
                                ],
                                [
                                    0.002099748328995973,
                                    0.9520904523038476,
                                    0.00010080699802726174,
                                    0.045708992369129196,
                                ],
                                [
                                    0.04376166514811096,
                                    0.9115288131482442,
                                    0.002048134219045498,
                                    0.04266138748459936,
                                ],
                                [
                                    0.00010080699802726174,
                                    0.045708992369129196,
                                    0.002099748328995973,
                                    0.9520904523038476,
                                ],
                                [
                                    0.00010080699802726174,
                                    0.002099748328995973,
                                    0.045708992369129196,
                                    0.9520904523038476,
                                ],
                                [
                                    0.25330239530887666,
                                    0.011855063143562633,
                                    0.7019880829874785,
                                    0.03285445856008218,
                                ],
                                [
                                    0.25330239530887666,
                                    0.7019880829874785,
                                    0.011855063143562633,
                                    0.03285445856008218,
                                ],
                                [
                                    0.21059181493620052,
                                    0.009856121812593946,
                                    0.7446986633601547,
                                    0.034853399891050865,
                                ],
                                [
                                    0.2408638385076166,
                                    0.6675165627580706,
                                    0.024293619944822716,
                                    0.0673259787894901,
                                ],
                                [
                                    0.2408638385076166,
                                    0.024293619944822716,
                                    0.6675165627580706,
                                    0.0673259787894901,
                                ],
                                [
                                    0.21059181493620052,
                                    0.7446986633601547,
                                    0.009856121812593946,
                                    0.034853399891050865,
                                ],
                                [
                                    0.20025058524206277,
                                    0.020197351506731725,
                                    0.7081298160236245,
                                    0.0714222472275811,
                                ],
                                [
                                    0.20025058524206277,
                                    0.7081298160236245,
                                    0.020197351506731725,
                                    0.0714222472275811,
                                ],
                                [
                                    0.3855187396103754,
                                    0.014432171400112196,
                                    0.5783964034664364,
                                    0.021652685523075938,
                                ],
                                [
                                    0.3855187396103754,
                                    0.5783964034664364,
                                    0.014432171400112196,
                                    0.021652685523075938,
                                ],
                                [
                                    0.17351512270720484,
                                    0.0064956634636042605,
                                    0.790400020369607,
                                    0.029589193459583874,
                                ],
                                [
                                    0.29322392966911,
                                    0.43992586846054343,
                                    0.10672698134137765,
                                    0.16012322052896893,
                                ],
                                [
                                    0.29322392966911,
                                    0.10672698134137765,
                                    0.43992586846054343,
                                    0.16012322052896893,
                                ],
                                [
                                    0.17351512270720484,
                                    0.790400020369607,
                                    0.0064956634636042605,
                                    0.029589193459583874,
                                ],
                                [
                                    0.1319748715422889,
                                    0.04803591462852021,
                                    0.6011749265873645,
                                    0.21881428724182636,
                                ],
                                [
                                    0.1319748715422889,
                                    0.6011749265873645,
                                    0.04803591462852021,
                                    0.21881428724182636,
                                ],
                                [
                                    0.583329605581925,
                                    0.014010638430060127,
                                    0.3932153559027409,
                                    0.009444400085273882,
                                ],
                                [
                                    0.583329605581925,
                                    0.3932153559027409,
                                    0.014010638430060127,
                                    0.009444400085273882,
                                ],
                                [
                                    0.11796202452317027,
                                    0.002833258004148925,
                                    0.8585829369614957,
                                    0.020621780511185083,
                                ],
                                [
                                    0.28465948357593246,
                                    0.19188547790873353,
                                    0.3126807604360527,
                                    0.2107742780792813,
                                ],
                                [
                                    0.28465948357593246,
                                    0.3126807604360527,
                                    0.19188547790873353,
                                    0.2107742780792813,
                                ],
                                [
                                    0.11796202452317027,
                                    0.8585829369614957,
                                    0.002833258004148925,
                                    0.020621780511185083,
                                ],
                                [
                                    0.05756438325951067,
                                    0.06323089926780852,
                                    0.4189805782251553,
                                    0.46022413924752553,
                                ],
                                [
                                    0.05756438325951067,
                                    0.4189805782251553,
                                    0.06323089926780852,
                                    0.46022413924752553,
                                ],
                                [
                                    0.7861264544163875,
                                    0.008603122597095336,
                                    0.20304832547613272,
                                    0.0022220975103845473,
                                ],
                                [
                                    0.7861264544163875,
                                    0.20304832547613272,
                                    0.008603122597095336,
                                    0.0022220975103845473,
                                ],
                                [
                                    0.06091316422324209,
                                    0.000666614660587396,
                                    0.928261615669278,
                                    0.010158605446892486,
                                ],
                                [
                                    0.1747929223821304,
                                    0.04514720245754824,
                                    0.6199366546313524,
                                    0.16012322052896902,
                                ],
                                [
                                    0.1747929223821304,
                                    0.6199366546313524,
                                    0.04514720245754824,
                                    0.16012322052896902,
                                ],
                                [
                                    0.06091316422324209,
                                    0.928261615669278,
                                    0.000666614660587396,
                                    0.010158605446892486,
                                ],
                                [
                                    0.013543864255309263,
                                    0.04803591462852022,
                                    0.20639626058436936,
                                    0.7320239605318012,
                                ],
                                [
                                    0.013543864255309263,
                                    0.20639626058436936,
                                    0.04803591462852022,
                                    0.7320239605318012,
                                ],
                                [
                                    0.9274775627172167,
                                    0.002045466854314385,
                                    0.07032188195576011,
                                    0.00015508847270882453,
                                ],
                                [
                                    0.9274775627172167,
                                    0.07032188195576011,
                                    0.002045466854314385,
                                    0.00015508847270882453,
                                ],
                                [
                                    0.021096102782498315,
                                    4.652552334569674e-05,
                                    0.9767033418904785,
                                    0.002154029803677513,
                                ],
                                [
                                    0.041558530064666074,
                                    0.0031509916389787676,
                                    0.8879644995068651,
                                    0.06732597878949018,
                                ],
                                [
                                    0.041558530064666074,
                                    0.8879644995068651,
                                    0.0031509916389787676,
                                    0.06732597878949018,
                                ],
                                [
                                    0.021096102782498315,
                                    0.9767033418904785,
                                    4.652552334569674e-05,
                                    0.002154029803677513,
                                ],
                                [
                                    0.0009452767991122286,
                                    0.020197351506731784,
                                    0.04376424490453261,
                                    0.9350931267896234,
                                ],
                                [
                                    0.0009452767991122286,
                                    0.04376424490453261,
                                    0.020197351506731784,
                                    0.9350931267896234,
                                ],
                                [
                                    0.20683869393823792,
                                    0.058318764514201385,
                                    0.5732211812220834,
                                    0.16162136032547716,
                                ],
                                [
                                    0.20683869393823792,
                                    0.5732211812220834,
                                    0.058318764514201385,
                                    0.16162136032547716,
                                ],
                                [
                                    0.17196259001961506,
                                    0.048485346729179424,
                                    0.6080972851407064,
                                    0.17145477811049914,
                                ],
                                [
                                    0.19440013713697785,
                                    0.5387496609926755,
                                    0.07075732131546147,
                                    0.1960928805548851,
                                ],
                                [
                                    0.19440013713697785,
                                    0.07075732131546147,
                                    0.5387496609926755,
                                    0.1960928805548851,
                                ],
                                [
                                    0.17196259001961506,
                                    0.6080972851407064,
                                    0.048485346729179424,
                                    0.17145477811049914,
                                ],
                                [
                                    0.16162136032547728,
                                    0.0588265764233172,
                                    0.5715284378041762,
                                    0.20802362544702938,
                                ],
                                [
                                    0.16162136032547728,
                                    0.5715284378041762,
                                    0.0588265764233172,
                                    0.20802362544702938,
                                ],
                                [
                                    0.32895454472215074,
                                    0.07099636628833689,
                                    0.4935327547592719,
                                    0.10651633423024051,
                                ],
                                [
                                    0.32895454472215074,
                                    0.4935327547592719,
                                    0.07099636628833689,
                                    0.10651633423024051,
                                ],
                                [
                                    0.14805658539515662,
                                    0.031954200775652516,
                                    0.674430714086266,
                                    0.1455584997429249,
                                ],
                                [
                                    0.23665973478088528,
                                    0.35506221975337887,
                                    0.16329117622960235,
                                    0.24498686923613353,
                                ],
                                [
                                    0.23665973478088528,
                                    0.16329117622960235,
                                    0.35506221975337887,
                                    0.24498686923613353,
                                ],
                                [
                                    0.14805658539515662,
                                    0.674430714086266,
                                    0.031954200775652516,
                                    0.1455584997429249,
                                ],
                                [
                                    0.10651633423024066,
                                    0.07349445194056846,
                                    0.4852056203040235,
                                    0.3347835935251674,
                                ],
                                [
                                    0.10651633423024066,
                                    0.4852056203040235,
                                    0.07349445194056846,
                                    0.3347835935251674,
                                ],
                                [
                                    0.5284175302818623,
                                    0.06892271373012278,
                                    0.3561997972445584,
                                    0.046459958743456445,
                                ],
                                [
                                    0.5284175302818623,
                                    0.3561997972445584,
                                    0.06892271373012278,
                                    0.046459958743456445,
                                ],
                                [
                                    0.10685760000711605,
                                    0.013937682520203137,
                                    0.7777597275193047,
                                    0.10144498995337609,
                                ],
                                [
                                    0.22974740827586979,
                                    0.15486991925055096,
                                    0.3675928357361154,
                                    0.24778983673746388,
                                ],
                                [
                                    0.22974740827586979,
                                    0.3675928357361154,
                                    0.15486991925055096,
                                    0.24778983673746388,
                                ],
                                [
                                    0.10685760000711605,
                                    0.7777597275193047,
                                    0.013937682520203137,
                                    0.10144498995337609,
                                ],
                                [
                                    0.04645995874345646,
                                    0.07433532378386273,
                                    0.3381573687829643,
                                    0.5410473486897165,
                                ],
                                [
                                    0.04645995874345646,
                                    0.3381573687829643,
                                    0.07433532378386273,
                                    0.5410473486897165,
                                ],
                                [
                                    0.7524081254319072,
                                    0.04232145158157561,
                                    0.19433923013951185,
                                    0.010931192847005432,
                                ],
                                [
                                    0.7524081254319072,
                                    0.19433923013951185,
                                    0.04232145158157561,
                                    0.010931192847005432,
                                ],
                                [
                                    0.05830049281493827,
                                    0.0032792860688912145,
                                    0.8884468627564807,
                                    0.04997335835968983,
                                ],
                                [
                                    0.14107459339765013,
                                    0.03643810712092736,
                                    0.6536549836158326,
                                    0.16883231586558992,
                                ],
                                [
                                    0.14107459339765013,
                                    0.6536549836158326,
                                    0.03643810712092736,
                                    0.16883231586558992,
                                ],
                                [
                                    0.05830049281493827,
                                    0.8884468627564807,
                                    0.0032792860688912145,
                                    0.04997335835968983,
                                ],
                                [
                                    0.010931192847005444,
                                    0.05064858603682404,
                                    0.16658150767157204,
                                    0.7718387134445985,
                                ],
                                [
                                    0.010931192847005444,
                                    0.16658150767157204,
                                    0.05064858603682404,
                                    0.7718387134445985,
                                ],
                                [
                                    0.9194607381814477,
                                    0.010062291390083366,
                                    0.06971404171107241,
                                    0.0007629287173965278,
                                ],
                                [
                                    0.9194607381814477,
                                    0.06971404171107241,
                                    0.010062291390083366,
                                    0.0007629287173965278,
                                ],
                                [
                                    0.02091375470078262,
                                    0.00022887360506139616,
                                    0.9682610251917375,
                                    0.010596346502418497,
                                ],
                                [
                                    0.033541705528897126,
                                    0.002543151394291067,
                                    0.895981324042634,
                                    0.06793381903417788,
                                ],
                                [
                                    0.033541705528897126,
                                    0.895981324042634,
                                    0.002543151394291067,
                                    0.06793381903417788,
                                ],
                                [
                                    0.02091375470078262,
                                    0.9682610251917375,
                                    0.00022887360506139616,
                                    0.010596346502418497,
                                ],
                                [
                                    0.0007629287173965299,
                                    0.020379699588447483,
                                    0.035321928205791664,
                                    0.9435354434883644,
                                ],
                                [
                                    0.0007629287173965299,
                                    0.035321928205791664,
                                    0.020379699588447483,
                                    0.9435354434883644,
                                ],
                                [
                                    0.1387980076268497,
                                    0.1263594508255896,
                                    0.38465703088848435,
                                    0.3501855106590763,
                                ],
                                [
                                    0.1387980076268497,
                                    0.38465703088848435,
                                    0.1263594508255896,
                                    0.3501855106590763,
                                ],
                                [
                                    0.11539458322146613,
                                    0.10505335352732835,
                                    0.4080604552938679,
                                    0.3714916079573376,
                                ],
                                [
                                    0.1263594508255896,
                                    0.3501855106590763,
                                    0.1387980076268497,
                                    0.38465703088848435,
                                ],
                                [
                                    0.1263594508255896,
                                    0.1387980076268497,
                                    0.3501855106590763,
                                    0.38465703088848435,
                                ],
                                [
                                    0.11539458322146613,
                                    0.4080604552938679,
                                    0.10505335352732835,
                                    0.3714916079573376,
                                ],
                                [
                                    0.10505335352732835,
                                    0.11539458322146613,
                                    0.3714916079573376,
                                    0.4080604552938679,
                                ],
                                [
                                    0.10505335352732835,
                                    0.3714916079573376,
                                    0.11539458322146613,
                                    0.4080604552938679,
                                ],
                                [
                                    0.24612286047587656,
                                    0.15382805053461107,
                                    0.3692598119977027,
                                    0.23078927699180968,
                                ],
                                [
                                    0.24612286047587656,
                                    0.3692598119977027,
                                    0.15382805053461107,
                                    0.23078927699180968,
                                ],
                                [
                                    0.11077551866786255,
                                    0.06923526750294658,
                                    0.5046071538057167,
                                    0.3153820600234742,
                                ],
                                [
                                    0.15382805053461113,
                                    0.23078927699180973,
                                    0.2461228604758765,
                                    0.36925981199770264,
                                ],
                                [
                                    0.15382805053461113,
                                    0.2461228604758765,
                                    0.23078927699180973,
                                    0.36925981199770264,
                                ],
                                [
                                    0.11077551866786255,
                                    0.5046071538057167,
                                    0.06923526750294658,
                                    0.3153820600234742,
                                ],
                                [
                                    0.0692352675029466,
                                    0.11077551866786252,
                                    0.31538206002347424,
                                    0.5046071538057166,
                                ],
                                [
                                    0.0692352675029466,
                                    0.31538206002347424,
                                    0.11077551866786252,
                                    0.5046071538057166,
                                ],
                                [
                                    0.44800518300898884,
                                    0.1493350610029963,
                                    0.30199481699101116,
                                    0.10066493899700371,
                                ],
                                [
                                    0.44800518300898884,
                                    0.30199481699101116,
                                    0.1493350610029963,
                                    0.10066493899700371,
                                ],
                                [
                                    0.0905964618954894,
                                    0.030198820631829798,
                                    0.6594035381045106,
                                    0.2198011793681702,
                                ],
                                [
                                    0.1493350610029963,
                                    0.10066493899700371,
                                    0.44800518300898884,
                                    0.30199481699101116,
                                ],
                                [
                                    0.1493350610029963,
                                    0.44800518300898884,
                                    0.10066493899700371,
                                    0.30199481699101116,
                                ],
                                [
                                    0.0905964618954894,
                                    0.6594035381045106,
                                    0.030198820631829798,
                                    0.2198011793681702,
                                ],
                                [
                                    0.030198820631829798,
                                    0.0905964618954894,
                                    0.2198011793681702,
                                    0.6594035381045106,
                                ],
                                [
                                    0.030198820631829798,
                                    0.2198011793681702,
                                    0.0905964618954894,
                                    0.6594035381045106,
                                ],
                                [
                                    0.7030315545238699,
                                    0.09169802248961287,
                                    0.18158577300255088,
                                    0.023684649983966397,
                                ],
                                [
                                    0.7030315545238699,
                                    0.18158577300255088,
                                    0.09169802248961287,
                                    0.023684649983966397,
                                ],
                                [
                                    0.05447453942588115,
                                    0.007105239457948329,
                                    0.8301427881005395,
                                    0.10827743301563092,
                                ],
                                [
                                    0.09169802248961287,
                                    0.023684649983966397,
                                    0.7030315545238699,
                                    0.18158577300255088,
                                ],
                                [
                                    0.09169802248961287,
                                    0.7030315545238699,
                                    0.023684649983966397,
                                    0.18158577300255088,
                                ],
                                [
                                    0.05447453942588115,
                                    0.8301427881005395,
                                    0.007105239457948329,
                                    0.10827743301563092,
                                ],
                                [
                                    0.007105239457948329,
                                    0.05447453942588115,
                                    0.10827743301563092,
                                    0.8301427881005395,
                                ],
                                [
                                    0.007105239457948329,
                                    0.10827743301563092,
                                    0.05447453942588115,
                                    0.8301427881005395,
                                ],
                                [
                                    0.9077210311120408,
                                    0.02180199845949024,
                                    0.06882393037262514,
                                    0.001653040055843797,
                                ],
                                [
                                    0.9077210311120408,
                                    0.06882393037262514,
                                    0.02180199845949024,
                                    0.001653040055843797,
                                ],
                                [
                                    0.02064672714461505,
                                    0.000495901161228963,
                                    0.955898234340051,
                                    0.022959137354105073,
                                ],
                                [
                                    0.02180199845949024,
                                    0.001653040055843797,
                                    0.9077210311120408,
                                    0.06882393037262514,
                                ],
                                [
                                    0.02180199845949024,
                                    0.9077210311120408,
                                    0.001653040055843797,
                                    0.06882393037262514,
                                ],
                                [
                                    0.02064672714461505,
                                    0.955898234340051,
                                    0.000495901161228963,
                                    0.022959137354105073,
                                ],
                                [
                                    0.000495901161228963,
                                    0.02064672714461505,
                                    0.022959137354105073,
                                    0.955898234340051,
                                ],
                                [
                                    0.000495901161228963,
                                    0.022959137354105073,
                                    0.02064672714461505,
                                    0.955898234340051,
                                ],
                                [
                                    0.0707573213154615,
                                    0.19440013713697782,
                                    0.1960928805548852,
                                    0.5387496609926755,
                                ],
                                [
                                    0.0707573213154615,
                                    0.1960928805548852,
                                    0.19440013713697782,
                                    0.5387496609926755,
                                ],
                                [
                                    0.05882657642331723,
                                    0.16162136032547725,
                                    0.20802362544702946,
                                    0.5715284378041761,
                                ],
                                [
                                    0.0583187645142014,
                                    0.16162136032547722,
                                    0.20683869393823792,
                                    0.5732211812220834,
                                ],
                                [
                                    0.0583187645142014,
                                    0.20683869393823792,
                                    0.16162136032547722,
                                    0.5732211812220834,
                                ],
                                [
                                    0.05882657642331723,
                                    0.20802362544702946,
                                    0.16162136032547725,
                                    0.5715284378041761,
                                ],
                                [
                                    0.04848534672917944,
                                    0.17196259001961506,
                                    0.1714547781104992,
                                    0.6080972851407064,
                                ],
                                [
                                    0.04848534672917944,
                                    0.1714547781104992,
                                    0.17196259001961506,
                                    0.6080972851407064,
                                ],
                                [
                                    0.1632911762296024,
                                    0.23665973478088523,
                                    0.24498686923613358,
                                    0.35506221975337876,
                                ],
                                [
                                    0.1632911762296024,
                                    0.24498686923613358,
                                    0.23665973478088523,
                                    0.35506221975337876,
                                ],
                                [
                                    0.07349445194056849,
                                    0.10651633423024064,
                                    0.3347835935251675,
                                    0.48520562030402337,
                                ],
                                [
                                    0.07099636628833693,
                                    0.10651633423024055,
                                    0.3289545447221507,
                                    0.49353275475927183,
                                ],
                                [
                                    0.07099636628833693,
                                    0.3289545447221507,
                                    0.10651633423024055,
                                    0.49353275475927183,
                                ],
                                [
                                    0.07349445194056849,
                                    0.3347835935251675,
                                    0.10651633423024064,
                                    0.48520562030402337,
                                ],
                                [
                                    0.03195420077565253,
                                    0.1480565853951566,
                                    0.14555849974292495,
                                    0.6744307140862659,
                                ],
                                [
                                    0.03195420077565253,
                                    0.14555849974292495,
                                    0.1480565853951566,
                                    0.6744307140862659,
                                ],
                                [
                                    0.3675928357361154,
                                    0.22974740827586979,
                                    0.24778983673746388,
                                    0.15486991925055096,
                                ],
                                [
                                    0.3675928357361154,
                                    0.24778983673746388,
                                    0.22974740827586979,
                                    0.15486991925055096,
                                ],
                                [
                                    0.07433532378386273,
                                    0.04645995874345646,
                                    0.5410473486897165,
                                    0.3381573687829643,
                                ],
                                [
                                    0.06892271373012279,
                                    0.04645995874345646,
                                    0.5284175302818623,
                                    0.3561997972445584,
                                ],
                                [
                                    0.06892271373012279,
                                    0.5284175302818623,
                                    0.04645995874345646,
                                    0.3561997972445584,
                                ],
                                [
                                    0.07433532378386273,
                                    0.5410473486897165,
                                    0.04645995874345646,
                                    0.3381573687829643,
                                ],
                                [
                                    0.01393768252020314,
                                    0.10685760000711605,
                                    0.10144498995337611,
                                    0.7777597275193047,
                                ],
                                [
                                    0.01393768252020314,
                                    0.10144498995337611,
                                    0.10685760000711605,
                                    0.7777597275193047,
                                ],
                                [
                                    0.6536549836158326,
                                    0.1410745933976501,
                                    0.16883231586558992,
                                    0.036438107120927356,
                                ],
                                [
                                    0.6536549836158326,
                                    0.16883231586558992,
                                    0.1410745933976501,
                                    0.036438107120927356,
                                ],
                                [
                                    0.05064858603682404,
                                    0.010931192847005443,
                                    0.7718387134445985,
                                    0.166581507671572,
                                ],
                                [
                                    0.042321451581575596,
                                    0.010931192847005429,
                                    0.7524081254319072,
                                    0.19433923013951185,
                                ],
                                [
                                    0.042321451581575596,
                                    0.7524081254319072,
                                    0.010931192847005429,
                                    0.19433923013951185,
                                ],
                                [
                                    0.05064858603682404,
                                    0.7718387134445985,
                                    0.010931192847005443,
                                    0.166581507671572,
                                ],
                                [
                                    0.0032792860688912132,
                                    0.05830049281493827,
                                    0.04997335835968981,
                                    0.8884468627564807,
                                ],
                                [
                                    0.0032792860688912132,
                                    0.04997335835968981,
                                    0.05830049281493827,
                                    0.8884468627564807,
                                ],
                                [
                                    0.895981324042634,
                                    0.03354170552889711,
                                    0.06793381903417788,
                                    0.002543151394291066,
                                ],
                                [
                                    0.895981324042634,
                                    0.06793381903417788,
                                    0.03354170552889711,
                                    0.002543151394291066,
                                ],
                                [
                                    0.020379699588447483,
                                    0.0007629287173965296,
                                    0.9435354434883644,
                                    0.03532192820579165,
                                ],
                                [
                                    0.010062291390083355,
                                    0.000762928717396527,
                                    0.9194607381814477,
                                    0.06971404171107241,
                                ],
                                [
                                    0.010062291390083355,
                                    0.9194607381814477,
                                    0.000762928717396527,
                                    0.06971404171107241,
                                ],
                                [
                                    0.020379699588447483,
                                    0.9435354434883644,
                                    0.0007629287173965296,
                                    0.03532192820579165,
                                ],
                                [
                                    0.00022887360506139594,
                                    0.02091375470078262,
                                    0.010596346502418487,
                                    0.9682610251917375,
                                ],
                                [
                                    0.00022887360506139594,
                                    0.010596346502418487,
                                    0.02091375470078262,
                                    0.9682610251917375,
                                ],
                                [
                                    0.02429361994482274,
                                    0.24086383850761658,
                                    0.06732597878949018,
                                    0.6675165627580705,
                                ],
                                [
                                    0.02429361994482274,
                                    0.06732597878949018,
                                    0.24086383850761658,
                                    0.6675165627580705,
                                ],
                                [
                                    0.020197351506731746,
                                    0.20025058524206274,
                                    0.07142224722758117,
                                    0.7081298160236243,
                                ],
                                [
                                    0.01185506314356264,
                                    0.0328544585600822,
                                    0.25330239530887666,
                                    0.7019880829874785,
                                ],
                                [
                                    0.01185506314356264,
                                    0.25330239530887666,
                                    0.0328544585600822,
                                    0.7019880829874785,
                                ],
                                [
                                    0.020197351506731746,
                                    0.07142224722758117,
                                    0.20025058524206274,
                                    0.7081298160236243,
                                ],
                                [
                                    0.009856121812593951,
                                    0.21059181493620052,
                                    0.034853399891050886,
                                    0.7446986633601547,
                                ],
                                [
                                    0.009856121812593951,
                                    0.034853399891050886,
                                    0.21059181493620052,
                                    0.7446986633601547,
                                ],
                                [
                                    0.10672698134137769,
                                    0.29322392966910993,
                                    0.160123220528969,
                                    0.4399258684605434,
                                ],
                                [
                                    0.10672698134137769,
                                    0.160123220528969,
                                    0.29322392966910993,
                                    0.4399258684605434,
                                ],
                                [
                                    0.04803591462852023,
                                    0.1319748715422889,
                                    0.21881428724182647,
                                    0.6011749265873644,
                                ],
                                [
                                    0.014432171400112218,
                                    0.021652685523075973,
                                    0.3855187396103754,
                                    0.5783964034664364,
                                ],
                                [
                                    0.014432171400112218,
                                    0.3855187396103754,
                                    0.021652685523075973,
                                    0.5783964034664364,
                                ],
                                [
                                    0.04803591462852023,
                                    0.21881428724182647,
                                    0.1319748715422889,
                                    0.6011749265873644,
                                ],
                                [
                                    0.006495663463604271,
                                    0.17351512270720484,
                                    0.02958919345958392,
                                    0.790400020369607,
                                ],
                                [
                                    0.006495663463604271,
                                    0.02958919345958392,
                                    0.17351512270720484,
                                    0.790400020369607,
                                ],
                                [
                                    0.3126807604360527,
                                    0.28465948357593246,
                                    0.2107742780792813,
                                    0.19188547790873353,
                                ],
                                [
                                    0.3126807604360527,
                                    0.2107742780792813,
                                    0.28465948357593246,
                                    0.19188547790873353,
                                ],
                                [
                                    0.06323089926780852,
                                    0.05756438325951067,
                                    0.46022413924752553,
                                    0.4189805782251553,
                                ],
                                [
                                    0.014010638430060144,
                                    0.009444400085273892,
                                    0.583329605581925,
                                    0.3932153559027409,
                                ],
                                [
                                    0.014010638430060144,
                                    0.583329605581925,
                                    0.009444400085273892,
                                    0.3932153559027409,
                                ],
                                [
                                    0.06323089926780852,
                                    0.46022413924752553,
                                    0.05756438325951067,
                                    0.4189805782251553,
                                ],
                                [
                                    0.002833258004148928,
                                    0.11796202452317027,
                                    0.020621780511185107,
                                    0.8585829369614957,
                                ],
                                [
                                    0.002833258004148928,
                                    0.020621780511185107,
                                    0.11796202452317027,
                                    0.8585829369614957,
                                ],
                                [
                                    0.6199366546313524,
                                    0.1747929223821304,
                                    0.16012322052896902,
                                    0.04514720245754824,
                                ],
                                [
                                    0.6199366546313524,
                                    0.16012322052896902,
                                    0.1747929223821304,
                                    0.04514720245754824,
                                ],
                                [
                                    0.04803591462852022,
                                    0.013543864255309263,
                                    0.7320239605318012,
                                    0.20639626058436936,
                                ],
                                [
                                    0.008603122597095336,
                                    0.0022220975103845473,
                                    0.7861264544163875,
                                    0.20304832547613272,
                                ],
                                [
                                    0.008603122597095336,
                                    0.7861264544163875,
                                    0.0022220975103845473,
                                    0.20304832547613272,
                                ],
                                [
                                    0.04803591462852022,
                                    0.7320239605318012,
                                    0.013543864255309263,
                                    0.20639626058436936,
                                ],
                                [
                                    0.000666614660587396,
                                    0.06091316422324209,
                                    0.010158605446892486,
                                    0.928261615669278,
                                ],
                                [
                                    0.000666614660587396,
                                    0.010158605446892486,
                                    0.06091316422324209,
                                    0.928261615669278,
                                ],
                                [
                                    0.8879644995068651,
                                    0.041558530064666095,
                                    0.06732597878949018,
                                    0.003150991638978769,
                                ],
                                [
                                    0.8879644995068651,
                                    0.06732597878949018,
                                    0.041558530064666095,
                                    0.003150991638978769,
                                ],
                                [
                                    0.020197351506731784,
                                    0.0009452767991122291,
                                    0.9350931267896234,
                                    0.04376424490453263,
                                ],
                                [
                                    0.0020454668543144084,
                                    0.00015508847270882632,
                                    0.9274775627172167,
                                    0.07032188195576011,
                                ],
                                [
                                    0.0020454668543144084,
                                    0.9274775627172167,
                                    0.00015508847270882632,
                                    0.07032188195576011,
                                ],
                                [
                                    0.020197351506731784,
                                    0.9350931267896234,
                                    0.0009452767991122291,
                                    0.04376424490453263,
                                ],
                                [
                                    4.652552334569727e-05,
                                    0.021096102782498315,
                                    0.0021540298036775373,
                                    0.9767033418904785,
                                ],
                                [
                                    4.652552334569727e-05,
                                    0.0021540298036775373,
                                    0.021096102782498315,
                                    0.9767033418904785,
                                ],
                                [
                                    0.08551977368091515,
                                    0.004002497946275465,
                                    0.86977070461544,
                                    0.04070702375736934,
                                ],
                                [
                                    0.08551977368091515,
                                    0.86977070461544,
                                    0.004002497946275465,
                                    0.04070702375736934,
                                ],
                                [
                                    0.042809193308239,
                                    0.0020035566153067774,
                                    0.9124812849881162,
                                    0.04270596508833804,
                                ],
                                [
                                    0.08132027702292326,
                                    0.827060124242764,
                                    0.008201994604267362,
                                    0.08341760413004547,
                                ],
                                [
                                    0.08132027702292326,
                                    0.008201994604267362,
                                    0.827060124242764,
                                    0.08341760413004547,
                                ],
                                [
                                    0.042809193308239,
                                    0.9124812849881162,
                                    0.0020035566153067774,
                                    0.04270596508833804,
                                ],
                                [
                                    0.04070702375736941,
                                    0.004105726166176373,
                                    0.8676733775083177,
                                    0.08751387256813646,
                                ],
                                [
                                    0.04070702375736941,
                                    0.8676733775083177,
                                    0.004105726166176373,
                                    0.08751387256813646,
                                ],
                                [
                                    0.2472758445162233,
                                    0.009256949155759234,
                                    0.7166392985605885,
                                    0.026827907767428903,
                                ],
                                [
                                    0.2472758445162233,
                                    0.7166392985605885,
                                    0.009256949155759234,
                                    0.026827907767428903,
                                ],
                                [
                                    0.03527222761305265,
                                    0.0013204412192512937,
                                    0.9286429154637592,
                                    0.03476441570393684,
                                ],
                                [
                                    0.18807696589425005,
                                    0.5450728322354034,
                                    0.06845582777773251,
                                    0.19839437409261407,
                                ],
                                [
                                    0.18807696589425005,
                                    0.06845582777773251,
                                    0.5450728322354034,
                                    0.19839437409261407,
                                ],
                                [
                                    0.03527222761305265,
                                    0.9286429154637592,
                                    0.0013204412192512937,
                                    0.03476441570393684,
                                ],
                                [
                                    0.026827907767428896,
                                    0.009764761064875047,
                                    0.7063218903622245,
                                    0.2570854408054715,
                                ],
                                [
                                    0.026827907767428896,
                                    0.7063218903622245,
                                    0.009764761064875047,
                                    0.2570854408054715,
                                ],
                                [
                                    0.48934695135086936,
                                    0.011753326312642231,
                                    0.4871980101337966,
                                    0.011701712202691778,
                                ],
                                [
                                    0.48934695135086936,
                                    0.4871980101337966,
                                    0.011753326312642231,
                                    0.011701712202691778,
                                ],
                                [
                                    0.023979370292114624,
                                    0.0005759458867310291,
                                    0.9525655911925514,
                                    0.02287909262860298,
                                ],
                                [
                                    0.23879681251911355,
                                    0.2377481489655524,
                                    0.26230346514439806,
                                    0.261151573370936,
                                ],
                                [
                                    0.23879681251911355,
                                    0.26230346514439806,
                                    0.2377481489655524,
                                    0.261151573370936,
                                ],
                                [
                                    0.023979370292114624,
                                    0.9525655911925514,
                                    0.0005759458867310291,
                                    0.02287909262860298,
                                ],
                                [
                                    0.011701712202691797,
                                    0.012853603976153857,
                                    0.4648432492819742,
                                    0.5106014345391802,
                                ],
                                [
                                    0.011701712202691797,
                                    0.4648432492819742,
                                    0.012853603976153857,
                                    0.5106014345391802,
                                ],
                                [
                                    0.737595744008073,
                                    0.008072017646967663,
                                    0.2515790358844472,
                                    0.0027532024605122205,
                                ],
                                [
                                    0.737595744008073,
                                    0.2515790358844472,
                                    0.008072017646967663,
                                    0.0027532024605122205,
                                ],
                                [
                                    0.012382453814927643,
                                    0.00013550971045972305,
                                    0.9767923260775925,
                                    0.01068971039702016,
                                ],
                                [
                                    0.16400226058733336,
                                    0.05593786425234527,
                                    0.5816655010677073,
                                    0.19839437409261412,
                                ],
                                [
                                    0.16400226058733336,
                                    0.5816655010677073,
                                    0.05593786425234527,
                                    0.19839437409261412,
                                ],
                                [
                                    0.012382453814927643,
                                    0.9767923260775925,
                                    0.00013550971045972305,
                                    0.01068971039702016,
                                ],
                                [
                                    0.0027532024605122405,
                                    0.009764761064875125,
                                    0.21718692237916637,
                                    0.7702951140954463,
                                ],
                                [
                                    0.0027532024605122405,
                                    0.21718692237916637,
                                    0.009764761064875125,
                                    0.7702951140954463,
                                ],
                                [
                                    0.9106698846407785,
                                    0.002008399059054067,
                                    0.08712956003219825,
                                    0.0001921562679691428,
                                ],
                                [
                                    0.9106698846407785,
                                    0.08712956003219825,
                                    0.002008399059054067,
                                    0.0001921562679691428,
                                ],
                                [
                                    0.0042884247060601495,
                                    9.45772808537842e-06,
                                    0.9935110199669166,
                                    0.002191097598937831,
                                ],
                                [
                                    0.04080540953352299,
                                    0.0039041121701218514,
                                    0.8718728741663097,
                                    0.08341760413004555,
                                ],
                                [
                                    0.04080540953352299,
                                    0.8718728741663097,
                                    0.0039041121701218514,
                                    0.08341760413004555,
                                ],
                                [
                                    0.0042884247060601495,
                                    0.9935110199669166,
                                    9.45772808537842e-06,
                                    0.002191097598937831,
                                ],
                                [
                                    0.0001921562679691434,
                                    0.004105726166176385,
                                    0.04451736543567569,
                                    0.9511847521301787,
                                ],
                                [
                                    0.0001921562679691434,
                                    0.04451736543567569,
                                    0.004105726166176385,
                                    0.9511847521301787,
                                ],
                                [
                                    0.0698327320295747,
                                    0.019689539597615918,
                                    0.7102271431307466,
                                    0.20025058524206266,
                                ],
                                [
                                    0.0698327320295747,
                                    0.7102271431307466,
                                    0.019689539597615918,
                                    0.20025058524206266,
                                ],
                                [
                                    0.03495662811095182,
                                    0.009856121812593955,
                                    0.7451032470493696,
                                    0.2100840030270846,
                                ],
                                [
                                    0.0656332353715828,
                                    0.6675165627580706,
                                    0.02388903625560782,
                                    0.24296116561473877,
                                ],
                                [
                                    0.0656332353715828,
                                    0.02388903625560782,
                                    0.6675165627580706,
                                    0.24296116561473877,
                                ],
                                [
                                    0.03495662811095182,
                                    0.7451032470493696,
                                    0.009856121812593955,
                                    0.2100840030270846,
                                ],
                                [
                                    0.032854458560082234,
                                    0.01195829136346355,
                                    0.7002953395695712,
                                    0.25489191050688303,
                                ],
                                [
                                    0.032854458560082234,
                                    0.7002953395695712,
                                    0.01195829136346355,
                                    0.25489191050688303,
                                ],
                                [
                                    0.21099496469569393,
                                    0.04553782897628865,
                                    0.6114923347857287,
                                    0.13197487154228876,
                                ],
                                [
                                    0.21099496469569393,
                                    0.6114923347857287,
                                    0.04553782897628865,
                                    0.13197487154228876,
                                ],
                                [
                                    0.030097005368699692,
                                    0.006495663463604251,
                                    0.7923902941127229,
                                    0.17101703705497315,
                                ],
                                [
                                    0.15179608607372064,
                                    0.4399258684605435,
                                    0.10473670759826194,
                                    0.30354133786747395,
                                ],
                                [
                                    0.15179608607372064,
                                    0.10473670759826194,
                                    0.4399258684605435,
                                    0.30354133786747395,
                                ],
                                [
                                    0.030097005368699692,
                                    0.7923902941127229,
                                    0.006495663463604251,
                                    0.17101703705497315,
                                ],
                                [
                                    0.021652685523075938,
                                    0.014939983309228005,
                                    0.5700692690111882,
                                    0.39333806215650785,
                                ],
                                [
                                    0.021652685523075938,
                                    0.5700692690111882,
                                    0.014939983309228005,
                                    0.39333806215650785,
                                ],
                                [
                                    0.44328198844944305,
                                    0.05781828921406857,
                                    0.4413353390769777,
                                    0.05756438325951065,
                                ],
                                [
                                    0.44328198844944305,
                                    0.4413353390769777,
                                    0.05781828921406857,
                                    0.05756438325951065,
                                ],
                                [
                                    0.021722058174696725,
                                    0.002833258004148929,
                                    0.862895269351724,
                                    0.1125494144694303,
                                ],
                                [
                                    0.19273184961768722,
                                    0.19188547790873353,
                                    0.30836842804582437,
                                    0.3070142444277549,
                                ],
                                [
                                    0.19273184961768722,
                                    0.30836842804582437,
                                    0.19188547790873353,
                                    0.3070142444277549,
                                ],
                                [
                                    0.021722058174696725,
                                    0.862895269351724,
                                    0.002833258004148929,
                                    0.1125494144694303,
                                ],
                                [
                                    0.009444400085273898,
                                    0.015110916093571757,
                                    0.37517292744114683,
                                    0.6002717563800075,
                                ],
                                [
                                    0.009444400085273898,
                                    0.37517292744114683,
                                    0.015110916093571757,
                                    0.6002717563800075,
                                ],
                                [
                                    0.7059589814817689,
                                    0.0397087801732718,
                                    0.24078837408965015,
                                    0.013543864255309247,
                                ],
                                [
                                    0.7059589814817689,
                                    0.24078837408965015,
                                    0.0397087801732718,
                                    0.013543864255309247,
                                ],
                                [
                                    0.011851348864799965,
                                    0.0006666146605874002,
                                    0.934896006706619,
                                    0.05258602976799364,
                                ],
                                [
                                    0.13236549806102924,
                                    0.04514720245754824,
                                    0.6133022635940114,
                                    0.20918503588741114,
                                ],
                                [
                                    0.13236549806102924,
                                    0.6133022635940114,
                                    0.04514720245754824,
                                    0.20918503588741114,
                                ],
                                [
                                    0.011851348864799965,
                                    0.934896006706619,
                                    0.0006666146605874002,
                                    0.05258602976799364,
                                ],
                                [
                                    0.0022220975103845637,
                                    0.010295866015002802,
                                    0.1752906030081929,
                                    0.8121914334664198,
                                ],
                                [
                                    0.0022220975103845637,
                                    0.1752906030081929,
                                    0.010295866015002802,
                                    0.8121914334664198,
                                ],
                                [
                                    0.902798340391465,
                                    0.009879943308367667,
                                    0.08637643950105517,
                                    0.0009452767991122269,
                                ],
                                [
                                    0.902798340391465,
                                    0.08637643950105517,
                                    0.009879943308367667,
                                    0.0009452767991122269,
                                ],
                                [
                                    0.004251356910799831,
                                    4.6525523345696795e-05,
                                    0.9849234229817203,
                                    0.010778694584134196,
                                ],
                                [
                                    0.03293386528420942,
                                    0.0031509916389787706,
                                    0.8797444184156232,
                                    0.08417072466118863,
                                ],
                                [
                                    0.03293386528420942,
                                    0.8797444184156232,
                                    0.0031509916389787706,
                                    0.08417072466118863,
                                ],
                                [
                                    0.004251356910799831,
                                    0.9849234229817203,
                                    4.6525523345696795e-05,
                                    0.010778694584134196,
                                ],
                                [
                                    0.00015508847270882516,
                                    0.0041427939614367025,
                                    0.03592976845047936,
                                    0.9597723491153751,
                                ],
                                [
                                    0.00015508847270882516,
                                    0.03592976845047936,
                                    0.0041427939614367025,
                                    0.9597723491153751,
                                ],
                                [
                                    0.046860884142591264,
                                    0.042661387484599356,
                                    0.4765941543727428,
                                    0.4338835740000666,
                                ],
                                [
                                    0.046860884142591264,
                                    0.4765941543727428,
                                    0.042661387484599356,
                                    0.4338835740000666,
                                ],
                                [
                                    0.023457459737207687,
                                    0.021355290186338093,
                                    0.49999757877812634,
                                    0.4551896712983279,
                                ],
                                [
                                    0.042661387484599356,
                                    0.4338835740000666,
                                    0.046860884142591264,
                                    0.4765941543727428,
                                ],
                                [
                                    0.042661387484599356,
                                    0.046860884142591264,
                                    0.4338835740000666,
                                    0.4765941543727428,
                                ],
                                [
                                    0.023457459737207687,
                                    0.49999757877812634,
                                    0.021355290186338093,
                                    0.4551896712983279,
                                ],
                                [
                                    0.021355290186338093,
                                    0.023457459737207687,
                                    0.4551896712983279,
                                    0.49999757877812634,
                                ],
                                [
                                    0.021355290186338093,
                                    0.4551896712983279,
                                    0.023457459737207687,
                                    0.49999757877812634,
                                ],
                                [
                                    0.15786583614697794,
                                    0.09866695752500464,
                                    0.45751683632660134,
                                    0.2859503700014161,
                                ],
                                [
                                    0.15786583614697794,
                                    0.45751683632660134,
                                    0.09866695752500464,
                                    0.2859503700014161,
                                ],
                                [
                                    0.02251849433896385,
                                    0.014074174493340095,
                                    0.5928641781346154,
                                    0.37054315303308066,
                                ],
                                [
                                    0.09866695752500466,
                                    0.2859503700014162,
                                    0.1578658361469779,
                                    0.45751683632660123,
                                ],
                                [
                                    0.09866695752500466,
                                    0.1578658361469779,
                                    0.2859503700014162,
                                    0.45751683632660123,
                                ],
                                [
                                    0.02251849433896385,
                                    0.5928641781346154,
                                    0.014074174493340095,
                                    0.37054315303308066,
                                ],
                                [
                                    0.014074174493340098,
                                    0.022518494338963847,
                                    0.3705431530330808,
                                    0.5928641781346153,
                                ],
                                [
                                    0.014074174493340098,
                                    0.3705431530330808,
                                    0.022518494338963847,
                                    0.5928641781346153,
                                ],
                                [
                                    0.3758252082476337,
                                    0.1252750694158779,
                                    0.3741747917523663,
                                    0.1247249305841221,
                                ],
                                [
                                    0.3758252082476337,
                                    0.3741747917523663,
                                    0.1252750694158779,
                                    0.1247249305841221,
                                ],
                                [
                                    0.01841648713413424,
                                    0.0061388290447114136,
                                    0.7315835128658658,
                                    0.2438611709552886,
                                ],
                                [
                                    0.1252750694158779,
                                    0.1247249305841221,
                                    0.3758252082476337,
                                    0.3741747917523663,
                                ],
                                [
                                    0.1252750694158779,
                                    0.3758252082476337,
                                    0.1247249305841221,
                                    0.3741747917523663,
                                ],
                                [
                                    0.01841648713413424,
                                    0.7315835128658658,
                                    0.0061388290447114136,
                                    0.2438611709552886,
                                ],
                                [
                                    0.0061388290447114136,
                                    0.01841648713413424,
                                    0.2438611709552886,
                                    0.7315835128658658,
                                ],
                                [
                                    0.0061388290447114136,
                                    0.2438611709552886,
                                    0.01841648713413424,
                                    0.7315835128658658,
                                ],
                                [
                                    0.6596306225378902,
                                    0.08603713911715051,
                                    0.22498670498853063,
                                    0.02934553335642874,
                                ],
                                [
                                    0.6596306225378902,
                                    0.22498670498853063,
                                    0.08603713911715051,
                                    0.02934553335642874,
                                ],
                                [
                                    0.011073607439901384,
                                    0.001444356085485982,
                                    0.8735437200865194,
                                    0.11393831638809326,
                                ],
                                [
                                    0.08603713911715051,
                                    0.02934553335642874,
                                    0.6596306225378902,
                                    0.22498670498853063,
                                ],
                                [
                                    0.08603713911715051,
                                    0.6596306225378902,
                                    0.02934553335642874,
                                    0.22498670498853063,
                                ],
                                [
                                    0.011073607439901384,
                                    0.8735437200865194,
                                    0.001444356085485982,
                                    0.11393831638809326,
                                ],
                                [
                                    0.001444356085485982,
                                    0.011073607439901384,
                                    0.11393831638809326,
                                    0.8735437200865194,
                                ],
                                [
                                    0.001444356085485982,
                                    0.11393831638809326,
                                    0.011073607439901384,
                                    0.8735437200865194,
                                ],
                                [
                                    0.8912713794035441,
                                    0.02140690429628854,
                                    0.0852735820811219,
                                    0.0020481342190454984,
                                ],
                                [
                                    0.8912713794035441,
                                    0.0852735820811219,
                                    0.02140690429628854,
                                    0.0020481342190454984,
                                ],
                                [
                                    0.004197075436118267,
                                    0.00010080699802726096,
                                    0.9723478860485477,
                                    0.023354231517306777,
                                ],
                                [
                                    0.02140690429628854,
                                    0.0020481342190454984,
                                    0.8912713794035441,
                                    0.0852735820811219,
                                ],
                                [
                                    0.02140690429628854,
                                    0.8912713794035441,
                                    0.0020481342190454984,
                                    0.0852735820811219,
                                ],
                                [
                                    0.004197075436118267,
                                    0.9723478860485477,
                                    0.00010080699802726096,
                                    0.023354231517306777,
                                ],
                                [
                                    0.00010080699802726096,
                                    0.004197075436118267,
                                    0.023354231517306777,
                                    0.9723478860485477,
                                ],
                                [
                                    0.00010080699802726096,
                                    0.023354231517306777,
                                    0.004197075436118267,
                                    0.9723478860485477,
                                ],
                                [
                                    0.023889036255607825,
                                    0.06563323537158279,
                                    0.24296116561473888,
                                    0.6675165627580705,
                                ],
                                [
                                    0.023889036255607825,
                                    0.24296116561473888,
                                    0.06563323537158279,
                                    0.6675165627580705,
                                ],
                                [
                                    0.011958291363463555,
                                    0.03285445856008223,
                                    0.25489191050688315,
                                    0.7002953395695711,
                                ],
                                [
                                    0.019689539597615924,
                                    0.20025058524206268,
                                    0.0698327320295747,
                                    0.7102271431307466,
                                ],
                                [
                                    0.019689539597615924,
                                    0.0698327320295747,
                                    0.20025058524206268,
                                    0.7102271431307466,
                                ],
                                [
                                    0.011958291363463555,
                                    0.25489191050688315,
                                    0.03285445856008223,
                                    0.7002953395695711,
                                ],
                                [
                                    0.009856121812593958,
                                    0.03495662811095182,
                                    0.21008400302708466,
                                    0.7451032470493696,
                                ],
                                [
                                    0.009856121812593958,
                                    0.21008400302708466,
                                    0.03495662811095182,
                                    0.7451032470493696,
                                ],
                                [
                                    0.10473670759826197,
                                    0.1517960860737206,
                                    0.303541337867474,
                                    0.43992586846054343,
                                ],
                                [
                                    0.10473670759826197,
                                    0.303541337867474,
                                    0.1517960860737206,
                                    0.43992586846054343,
                                ],
                                [
                                    0.01493998330922801,
                                    0.021652685523075935,
                                    0.39333806215650796,
                                    0.570069269011188,
                                ],
                                [
                                    0.04553782897628867,
                                    0.13197487154228882,
                                    0.2109949646956939,
                                    0.6114923347857286,
                                ],
                                [
                                    0.04553782897628867,
                                    0.2109949646956939,
                                    0.13197487154228882,
                                    0.6114923347857286,
                                ],
                                [
                                    0.01493998330922801,
                                    0.39333806215650796,
                                    0.021652685523075935,
                                    0.570069269011188,
                                ],
                                [
                                    0.006495663463604254,
                                    0.03009700536869969,
                                    0.17101703705497323,
                                    0.7923902941127229,
                                ],
                                [
                                    0.006495663463604254,
                                    0.17101703705497323,
                                    0.03009700536869969,
                                    0.7923902941127229,
                                ],
                                [
                                    0.30836842804582437,
                                    0.19273184961768722,
                                    0.3070142444277549,
                                    0.19188547790873353,
                                ],
                                [
                                    0.30836842804582437,
                                    0.3070142444277549,
                                    0.19273184961768722,
                                    0.19188547790873353,
                                ],
                                [
                                    0.015110916093571757,
                                    0.009444400085273898,
                                    0.6002717563800075,
                                    0.37517292744114683,
                                ],
                                [
                                    0.057818289214068584,
                                    0.05756438325951067,
                                    0.44328198844944305,
                                    0.4413353390769777,
                                ],
                                [
                                    0.057818289214068584,
                                    0.44328198844944305,
                                    0.05756438325951067,
                                    0.4413353390769777,
                                ],
                                [
                                    0.015110916093571757,
                                    0.6002717563800075,
                                    0.009444400085273898,
                                    0.37517292744114683,
                                ],
                                [
                                    0.00283325800414893,
                                    0.021722058174696725,
                                    0.11254941446943031,
                                    0.862895269351724,
                                ],
                                [
                                    0.00283325800414893,
                                    0.11254941446943031,
                                    0.021722058174696725,
                                    0.862895269351724,
                                ],
                                [
                                    0.6133022635940114,
                                    0.13236549806102924,
                                    0.20918503588741114,
                                    0.04514720245754823,
                                ],
                                [
                                    0.6133022635940114,
                                    0.20918503588741114,
                                    0.13236549806102924,
                                    0.04514720245754823,
                                ],
                                [
                                    0.010295866015002802,
                                    0.0022220975103845633,
                                    0.8121914334664198,
                                    0.17529060300819288,
                                ],
                                [
                                    0.03970878017327178,
                                    0.013543864255309242,
                                    0.7059589814817689,
                                    0.24078837408965015,
                                ],
                                [
                                    0.03970878017327178,
                                    0.7059589814817689,
                                    0.013543864255309242,
                                    0.24078837408965015,
                                ],
                                [
                                    0.010295866015002802,
                                    0.8121914334664198,
                                    0.0022220975103845633,
                                    0.17529060300819288,
                                ],
                                [
                                    0.0006666146605873999,
                                    0.011851348864799965,
                                    0.05258602976799362,
                                    0.934896006706619,
                                ],
                                [
                                    0.0006666146605873999,
                                    0.05258602976799362,
                                    0.011851348864799965,
                                    0.934896006706619,
                                ],
                                [
                                    0.8797444184156232,
                                    0.032933865284209406,
                                    0.08417072466118863,
                                    0.0031509916389787693,
                                ],
                                [
                                    0.8797444184156232,
                                    0.08417072466118863,
                                    0.032933865284209406,
                                    0.0031509916389787693,
                                ],
                                [
                                    0.0041427939614367025,
                                    0.0001550884727088251,
                                    0.9597723491153751,
                                    0.03592976845047935,
                                ],
                                [
                                    0.009879943308367656,
                                    0.0009452767991122259,
                                    0.902798340391465,
                                    0.08637643950105517,
                                ],
                                [
                                    0.009879943308367656,
                                    0.902798340391465,
                                    0.0009452767991122259,
                                    0.08637643950105517,
                                ],
                                [
                                    0.0041427939614367025,
                                    0.9597723491153751,
                                    0.0001550884727088251,
                                    0.03592976845047935,
                                ],
                                [
                                    4.6525523345696755e-05,
                                    0.004251356910799831,
                                    0.010778694584134186,
                                    0.9849234229817203,
                                ],
                                [
                                    4.6525523345696755e-05,
                                    0.010778694584134186,
                                    0.004251356910799831,
                                    0.9849234229817203,
                                ],
                                [
                                    0.008201994604267371,
                                    0.08132027702292324,
                                    0.08341760413004554,
                                    0.8270601242427639,
                                ],
                                [
                                    0.008201994604267371,
                                    0.08341760413004554,
                                    0.08132027702292324,
                                    0.8270601242427639,
                                ],
                                [
                                    0.004105726166176376,
                                    0.040707023757369405,
                                    0.08751387256813653,
                                    0.8676733775083176,
                                ],
                                [
                                    0.0040024979462754675,
                                    0.04070702375736937,
                                    0.08551977368091515,
                                    0.86977070461544,
                                ],
                                [
                                    0.0040024979462754675,
                                    0.08551977368091515,
                                    0.04070702375736937,
                                    0.86977070461544,
                                ],
                                [
                                    0.004105726166176376,
                                    0.08751387256813653,
                                    0.040707023757369405,
                                    0.8676733775083176,
                                ],
                                [
                                    0.0020035566153067787,
                                    0.042809193308239,
                                    0.04270596508833806,
                                    0.9124812849881162,
                                ],
                                [
                                    0.0020035566153067787,
                                    0.04270596508833806,
                                    0.042809193308239,
                                    0.9124812849881162,
                                ],
                                [
                                    0.06845582777773254,
                                    0.18807696589425002,
                                    0.19839437409261415,
                                    0.5450728322354033,
                                ],
                                [
                                    0.06845582777773254,
                                    0.19839437409261415,
                                    0.18807696589425002,
                                    0.5450728322354033,
                                ],
                                [
                                    0.00976476106487505,
                                    0.026827907767428893,
                                    0.25708544080547163,
                                    0.7063218903622244,
                                ],
                                [
                                    0.009256949155759248,
                                    0.026827907767428945,
                                    0.2472758445162233,
                                    0.7166392985605885,
                                ],
                                [
                                    0.009256949155759248,
                                    0.2472758445162233,
                                    0.026827907767428945,
                                    0.7166392985605885,
                                ],
                                [
                                    0.00976476106487505,
                                    0.25708544080547163,
                                    0.026827907767428893,
                                    0.7063218903622244,
                                ],
                                [
                                    0.0013204412192512956,
                                    0.03527222761305265,
                                    0.034764415703936895,
                                    0.9286429154637592,
                                ],
                                [
                                    0.0013204412192512956,
                                    0.034764415703936895,
                                    0.03527222761305265,
                                    0.9286429154637592,
                                ],
                                [
                                    0.26230346514439806,
                                    0.23879681251911355,
                                    0.261151573370936,
                                    0.2377481489655524,
                                ],
                                [
                                    0.26230346514439806,
                                    0.261151573370936,
                                    0.23879681251911355,
                                    0.2377481489655524,
                                ],
                                [
                                    0.012853603976153857,
                                    0.011701712202691797,
                                    0.5106014345391802,
                                    0.4648432492819742,
                                ],
                                [
                                    0.011753326312642245,
                                    0.011701712202691792,
                                    0.48934695135086936,
                                    0.4871980101337966,
                                ],
                                [
                                    0.011753326312642245,
                                    0.48934695135086936,
                                    0.011701712202691792,
                                    0.4871980101337966,
                                ],
                                [
                                    0.012853603976153857,
                                    0.5106014345391802,
                                    0.011701712202691797,
                                    0.4648432492819742,
                                ],
                                [
                                    0.0005759458867310299,
                                    0.023979370292114624,
                                    0.022879092628603007,
                                    0.9525655911925514,
                                ],
                                [
                                    0.0005759458867310299,
                                    0.022879092628603007,
                                    0.023979370292114624,
                                    0.9525655911925514,
                                ],
                                [
                                    0.5816655010677073,
                                    0.16400226058733336,
                                    0.19839437409261412,
                                    0.05593786425234527,
                                ],
                                [
                                    0.5816655010677073,
                                    0.19839437409261412,
                                    0.16400226058733336,
                                    0.05593786425234527,
                                ],
                                [
                                    0.009764761064875125,
                                    0.0027532024605122405,
                                    0.7702951140954463,
                                    0.21718692237916637,
                                ],
                                [
                                    0.008072017646967663,
                                    0.0027532024605122205,
                                    0.737595744008073,
                                    0.2515790358844472,
                                ],
                                [
                                    0.008072017646967663,
                                    0.737595744008073,
                                    0.0027532024605122205,
                                    0.2515790358844472,
                                ],
                                [
                                    0.009764761064875125,
                                    0.7702951140954463,
                                    0.0027532024605122405,
                                    0.21718692237916637,
                                ],
                                [
                                    0.00013550971045972305,
                                    0.012382453814927643,
                                    0.01068971039702016,
                                    0.9767923260775925,
                                ],
                                [
                                    0.00013550971045972305,
                                    0.01068971039702016,
                                    0.012382453814927643,
                                    0.9767923260775925,
                                ],
                                [
                                    0.8718728741663097,
                                    0.040805409533523004,
                                    0.08341760413004555,
                                    0.0039041121701218536,
                                ],
                                [
                                    0.8718728741663097,
                                    0.08341760413004555,
                                    0.040805409533523004,
                                    0.0039041121701218536,
                                ],
                                [
                                    0.004105726166176385,
                                    0.00019215626796914348,
                                    0.9511847521301787,
                                    0.044517365435675714,
                                ],
                                [
                                    0.00200839905905409,
                                    0.000192156267969145,
                                    0.9106698846407785,
                                    0.08712956003219825,
                                ],
                                [
                                    0.00200839905905409,
                                    0.9106698846407785,
                                    0.000192156267969145,
                                    0.08712956003219825,
                                ],
                                [
                                    0.004105726166176385,
                                    0.9511847521301787,
                                    0.00019215626796914348,
                                    0.044517365435675714,
                                ],
                                [
                                    9.457728085378528e-06,
                                    0.0042884247060601495,
                                    0.0021910975989378563,
                                    0.9935110199669166,
                                ],
                                [
                                    9.457728085378528e-06,
                                    0.0021910975989378563,
                                    0.0042884247060601495,
                                    0.9935110199669166,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.8638630358300114,
                                    0.08712956003219817,
                                    0.044517365435675665,
                                    0.004490038702114651,
                                ],
                                [
                                    0.8638630358300114,
                                    0.044517365435675665,
                                    0.08712956003219817,
                                    0.004490038702114651,
                                ],
                                [
                                    0.8658619771609802,
                                    0.0873311740282527,
                                    0.042518424104706985,
                                    0.00428842470606013,
                                ],
                                [
                                    0.9084741717575027,
                                    0.046816306538852485,
                                    0.04251842410470698,
                                    0.002191097598937829,
                                ],
                                [
                                    0.9084741717575027,
                                    0.04251842410470698,
                                    0.046816306538852485,
                                    0.002191097598937829,
                                ],
                                [
                                    0.8658619771609802,
                                    0.042518424104706985,
                                    0.0873311740282527,
                                    0.00428842470606013,
                                ],
                                [
                                    0.9105763413083723,
                                    0.0426168098808606,
                                    0.0447141369879829,
                                    0.0020927118227842133,
                                ],
                                [
                                    0.9105763413083723,
                                    0.0447141369879829,
                                    0.0426168098808606,
                                    0.0020927118227842133,
                                ],
                                [
                                    0.6911934788865208,
                                    0.2515790358844471,
                                    0.04195631924313259,
                                    0.015271165985899487,
                                ],
                                [
                                    0.6911934788865208,
                                    0.04195631924313259,
                                    0.2515790358844471,
                                    0.015271165985899487,
                                ],
                                [
                                    0.6991299868230287,
                                    0.25446774805541905,
                                    0.03401981130662465,
                                    0.012382453814927547,
                                ],
                                [
                                    0.9087527034643432,
                                    0.05516243961246859,
                                    0.03401981130662465,
                                    0.002065045616563485,
                                ],
                                [
                                    0.9087527034643432,
                                    0.03401981130662465,
                                    0.05516243961246859,
                                    0.002065045616563485,
                                ],
                                [
                                    0.6991299868230287,
                                    0.03401981130662465,
                                    0.25446774805541905,
                                    0.012382453814927547,
                                ],
                                [
                                    0.9191872970530827,
                                    0.034410437825365084,
                                    0.044727846023729145,
                                    0.0016744190978230545,
                                ],
                                [
                                    0.9191872970530827,
                                    0.044727846023729145,
                                    0.034410437825365084,
                                    0.0016744190978230545,
                                ],
                                [
                                    0.44353715198371296,
                                    0.48719801013379666,
                                    0.03300780950095303,
                                    0.036257028381537396,
                                ],
                                [
                                    0.44353715198371296,
                                    0.03300780950095303,
                                    0.48719801013379666,
                                    0.036257028381537396,
                                ],
                                [
                                    0.4547145324096241,
                                    0.4994756682232194,
                                    0.02183042907504183,
                                    0.023979370292114586,
                                ],
                                [
                                    0.9089047330424678,
                                    0.06764022844219825,
                                    0.021830429075041832,
                                    0.001624609440292179,
                                ],
                                [
                                    0.9089047330424678,
                                    0.021830429075041832,
                                    0.06764022844219825,
                                    0.001624609440292179,
                                ],
                                [
                                    0.4547145324096241,
                                    0.02183042907504183,
                                    0.4994756682232194,
                                    0.023979370292114586,
                                ],
                                [
                                    0.9318096327260459,
                                    0.02238056790679763,
                                    0.04473532875862004,
                                    0.0010744706085363772,
                                ],
                                [
                                    0.9318096327260459,
                                    0.04473532875862004,
                                    0.02238056790679763,
                                    0.0010744706085363772,
                                ],
                                [
                                    0.20205851090346272,
                                    0.7166392985605885,
                                    0.017881613936215908,
                                    0.06342057659973285,
                                ],
                                [
                                    0.20205851090346272,
                                    0.017881613936215908,
                                    0.7166392985605885,
                                    0.06342057659973285,
                                ],
                                [
                                    0.20999501883997065,
                                    0.7447876475472688,
                                    0.009945105999707968,
                                    0.03527222761305266,
                                ],
                                [
                                    0.9087527034643432,
                                    0.08042207642817684,
                                    0.009945105999707968,
                                    0.000880114107771913,
                                ],
                                [
                                    0.9087527034643432,
                                    0.009945105999707968,
                                    0.08042207642817684,
                                    0.000880114107771913,
                                ],
                                [
                                    0.20999501883997065,
                                    0.009945105999707968,
                                    0.7447876475472688,
                                    0.03527222761305266,
                                ],
                                [
                                    0.944446933868791,
                                    0.0103357325184484,
                                    0.044727846023729145,
                                    0.0004894875890314823,
                                ],
                                [
                                    0.944446933868791,
                                    0.044727846023729145,
                                    0.0103357325184484,
                                    0.0004894875890314823,
                                ],
                                [
                                    0.04070702375736938,
                                    0.8697707046154401,
                                    0.004002497946275464,
                                    0.08551977368091507,
                                ],
                                [
                                    0.04070702375736938,
                                    0.004002497946275464,
                                    0.8697707046154401,
                                    0.08551977368091507,
                                ],
                                [
                                    0.042705965088338065,
                                    0.9124812849881163,
                                    0.0020035566153067757,
                                    0.042809193308238944,
                                ],
                                [
                                    0.9084741717575027,
                                    0.0893252729154741,
                                    0.002003556615306777,
                                    0.00019699871171643287,
                                ],
                                [
                                    0.9084741717575027,
                                    0.002003556615306777,
                                    0.0893252729154741,
                                    0.00019699871171643287,
                                ],
                                [
                                    0.042705965088338065,
                                    0.0020035566153067757,
                                    0.9124812849881163,
                                    0.042809193308238944,
                                ],
                                [
                                    0.9530853076849939,
                                    0.002101942391460392,
                                    0.0447141369879829,
                                    9.861293556281745e-05,
                                ],
                                [
                                    0.9530853076849939,
                                    0.0447141369879829,
                                    0.002101942391460392,
                                    9.861293556281745e-05,
                                ],
                                [
                                    0.6972200296791741,
                                    0.25377256618303556,
                                    0.035929768450479314,
                                    0.013077635687311006,
                                ],
                                [
                                    0.6972200296791741,
                                    0.035929768450479314,
                                    0.25377256618303556,
                                    0.013077635687311006,
                                ],
                                [
                                    0.6988333663729542,
                                    0.2543597848162786,
                                    0.034316431756699114,
                                    0.012490417054067995,
                                ],
                                [
                                    0.7418311656066652,
                                    0.038228709553656134,
                                    0.20916143025554437,
                                    0.010778694584134182,
                                ],
                                [
                                    0.7418311656066652,
                                    0.20916143025554437,
                                    0.038228709553656134,
                                    0.010778694584134182,
                                ],
                                [
                                    0.6988333663729542,
                                    0.034316431756699114,
                                    0.2543597848162786,
                                    0.012490417054067995,
                                ],
                                [
                                    0.7435477305203463,
                                    0.20964542066888647,
                                    0.03651214463997503,
                                    0.010294704170792078,
                                ],
                                [
                                    0.7435477305203463,
                                    0.03651214463997503,
                                    0.20964542066888647,
                                    0.010294704170792078,
                                ],
                                [
                                    0.5578591951214605,
                                    0.38491331964950737,
                                    0.03386275941280359,
                                    0.023364725816228487,
                                ],
                                [
                                    0.5578591951214605,
                                    0.03386275941280359,
                                    0.38491331964950737,
                                    0.023364725816228487,
                                ],
                                [
                                    0.5642647155217222,
                                    0.38933301935672565,
                                    0.027457239012541983,
                                    0.01894502610901022,
                                ],
                                [
                                    0.775418419699283,
                                    0.0470688797821396,
                                    0.16735409507168492,
                                    0.010158605446892482,
                                ],
                                [
                                    0.775418419699283,
                                    0.16735409507168492,
                                    0.0470688797821396,
                                    0.010158605446892482,
                                ],
                                [
                                    0.5642647155217222,
                                    0.027457239012541983,
                                    0.38933301935672565,
                                    0.01894502610901022,
                                ],
                                [
                                    0.7843220257517761,
                                    0.16927570912667167,
                                    0.03816527372964648,
                                    0.008236991391905726,
                                ],
                                [
                                    0.7843220257517761,
                                    0.03816527372964648,
                                    0.16927570912667167,
                                    0.008236991391905726,
                                ],
                                [
                                    0.35797687068850653,
                                    0.5727582914290031,
                                    0.026640456837914255,
                                    0.04262438104457617,
                                ],
                                [
                                    0.35797687068850653,
                                    0.026640456837914255,
                                    0.5727582914290031,
                                    0.04262438104457617,
                                ],
                                [
                                    0.3669980849193035,
                                    0.58719211571354,
                                    0.01761924260711722,
                                    0.028190556760039193,
                                ],
                                [
                                    0.8233444517472613,
                                    0.061272875779159464,
                                    0.10739071037024828,
                                    0.007991962103330955,
                                ],
                                [
                                    0.8233444517472613,
                                    0.10739071037024828,
                                    0.061272875779159464,
                                    0.007991962103330955,
                                ],
                                [
                                    0.3669980849193035,
                                    0.01761924260711722,
                                    0.58719211571354,
                                    0.028190556760039193,
                                ],
                                [
                                    0.8440931852357253,
                                    0.11009701539711823,
                                    0.040524142290695425,
                                    0.005285657076460985,
                                ],
                                [
                                    0.8440931852357253,
                                    0.040524142290695425,
                                    0.11009701539711823,
                                    0.005285657076460985,
                                ],
                                [
                                    0.1630805291184653,
                                    0.755617280345586,
                                    0.014432171400112196,
                                    0.06687001913583655,
                                ],
                                [
                                    0.1630805291184653,
                                    0.014432171400112196,
                                    0.755617280345586,
                                    0.06687001913583655,
                                ],
                                [
                                    0.1694860495187269,
                                    0.7852966168685125,
                                    0.008026650999850584,
                                    0.03719068261291004,
                                ],
                                [
                                    0.8697747216793458,
                                    0.07697263389207314,
                                    0.048923087784705416,
                                    0.004329556643875626,
                                ],
                                [
                                    0.8697747216793458,
                                    0.048923087784705416,
                                    0.07697263389207314,
                                    0.004329556643875626,
                                ],
                                [
                                    0.1694860495187269,
                                    0.008026650999850584,
                                    0.7852966168685125,
                                    0.03719068261291004,
                                ],
                                [
                                    0.9039379645475473,
                                    0.050844701839692176,
                                    0.04280939102387176,
                                    0.0024079425888888675,
                                ],
                                [
                                    0.9039379645475473,
                                    0.04280939102387176,
                                    0.050844701839692176,
                                    0.0024079425888888675,
                                ],
                                [
                                    0.032854458560082234,
                                    0.8776232698127273,
                                    0.00323039836310596,
                                    0.08629187326408458,
                                ],
                                [
                                    0.032854458560082234,
                                    0.00323039836310596,
                                    0.8776232698127273,
                                    0.08629187326408458,
                                ],
                                [
                                    0.034467795253862434,
                                    0.9207194548225919,
                                    0.0016170616693257597,
                                    0.04319568825421996,
                                ],
                                [
                                    0.9006216065602155,
                                    0.0885531733323046,
                                    0.009856121812593953,
                                    0.0009690982948859397,
                                ],
                                [
                                    0.9006216065602155,
                                    0.009856121812593953,
                                    0.0885531733323046,
                                    0.0009690982948859397,
                                ],
                                [
                                    0.034467795253862434,
                                    0.0016170616693257597,
                                    0.9207194548225919,
                                    0.04319568825421996,
                                ],
                                [
                                    0.9448471378505183,
                                    0.010340112225936058,
                                    0.04432764204200188,
                                    0.00048510788154383514,
                                ],
                                [
                                    0.9448471378505183,
                                    0.04432764204200188,
                                    0.010340112225936058,
                                    0.00048510788154383514,
                                ],
                                [
                                    0.4531907299673592,
                                    0.4978018658948504,
                                    0.023354231517306746,
                                    0.025653172620483573,
                                ],
                                [
                                    0.4531907299673592,
                                    0.023354231517306746,
                                    0.4978018658948504,
                                    0.025653172620483573,
                                ],
                                [
                                    0.45423939352092035,
                                    0.4989537576683125,
                                    0.022305567963745596,
                                    0.024501280847021516,
                                ],
                                [
                                    0.4978018658948504,
                                    0.025653172620483573,
                                    0.4531907299673592,
                                    0.023354231517306746,
                                ],
                                [
                                    0.4978018658948504,
                                    0.4531907299673592,
                                    0.025653172620483573,
                                    0.023354231517306746,
                                ],
                                [
                                    0.45423939352092035,
                                    0.022305567963745596,
                                    0.4989537576683125,
                                    0.024501280847021516,
                                ],
                                [
                                    0.4989537576683125,
                                    0.45423939352092035,
                                    0.024501280847021516,
                                    0.022305567963745596,
                                ],
                                [
                                    0.4989537576683125,
                                    0.024501280847021516,
                                    0.45423939352092035,
                                    0.022305567963745596,
                                ],
                                [
                                    0.3626066450965728,
                                    0.5801658696743951,
                                    0.022010682429848043,
                                    0.03521680279918404,
                                ],
                                [
                                    0.3626066450965728,
                                    0.022010682429848043,
                                    0.5801658696743951,
                                    0.03521680279918404,
                                ],
                                [
                                    0.366770212324197,
                                    0.5868275225542507,
                                    0.01784711520222386,
                                    0.028555149919328345,
                                ],
                                [
                                    0.5801658696743952,
                                    0.035216802799184044,
                                    0.3626066450965727,
                                    0.022010682429848036,
                                ],
                                [
                                    0.5801658696743952,
                                    0.3626066450965727,
                                    0.035216802799184044,
                                    0.022010682429848036,
                                ],
                                [
                                    0.366770212324197,
                                    0.01784711520222386,
                                    0.5868275225542507,
                                    0.028555149919328345,
                                ],
                                [
                                    0.5868275225542509,
                                    0.3667702123241969,
                                    0.02855514991932835,
                                    0.017847115202223852,
                                ],
                                [
                                    0.5868275225542509,
                                    0.02855514991932835,
                                    0.3667702123241969,
                                    0.017847115202223852,
                                ],
                                [
                                    0.2326837905293774,
                                    0.6980513715881322,
                                    0.017316209470622606,
                                    0.051948628411867814,
                                ],
                                [
                                    0.2326837905293774,
                                    0.017316209470622606,
                                    0.6980513715881322,
                                    0.051948628411867814,
                                ],
                                [
                                    0.23854755015821089,
                                    0.7156426504746327,
                                    0.011452449841789104,
                                    0.034357349525367314,
                                ],
                                [
                                    0.6980513715881322,
                                    0.051948628411867814,
                                    0.2326837905293774,
                                    0.017316209470622606,
                                ],
                                [
                                    0.6980513715881322,
                                    0.2326837905293774,
                                    0.051948628411867814,
                                    0.017316209470622606,
                                ],
                                [
                                    0.23854755015821089,
                                    0.011452449841789104,
                                    0.7156426504746327,
                                    0.034357349525367314,
                                ],
                                [
                                    0.7156426504746327,
                                    0.23854755015821089,
                                    0.034357349525367314,
                                    0.011452449841789104,
                                ],
                                [
                                    0.7156426504746327,
                                    0.034357349525367314,
                                    0.23854755015821089,
                                    0.011452449841789104,
                                ],
                                [
                                    0.10600180845158534,
                                    0.8126960010124659,
                                    0.00938086402199391,
                                    0.07192132651395484,
                                ],
                                [
                                    0.10600180845158534,
                                    0.00938086402199391,
                                    0.8126960010124659,
                                    0.07192132651395484,
                                ],
                                [
                                    0.11016537567920953,
                                    0.8446172907080299,
                                    0.005217296794369725,
                                    0.0400000368183909,
                                ],
                                [
                                    0.8126960010124659,
                                    0.07192132651395484,
                                    0.10600180845158534,
                                    0.00938086402199391,
                                ],
                                [
                                    0.8126960010124659,
                                    0.10600180845158534,
                                    0.07192132651395484,
                                    0.00938086402199391,
                                ],
                                [
                                    0.11016537567920953,
                                    0.005217296794369725,
                                    0.8446172907080299,
                                    0.0400000368183909,
                                ],
                                [
                                    0.8446172907080299,
                                    0.11016537567920953,
                                    0.0400000368183909,
                                    0.005217296794369725,
                                ],
                                [
                                    0.8446172907080299,
                                    0.0400000368183909,
                                    0.11016537567920953,
                                    0.005217296794369725,
                                ],
                                [
                                    0.021355290186338086,
                                    0.8891224381864714,
                                    0.0020997483289959496,
                                    0.08742252329819458,
                                ],
                                [
                                    0.021355290186338086,
                                    0.0020997483289959496,
                                    0.8891224381864714,
                                    0.08742252329819458,
                                ],
                                [
                                    0.02240395373989924,
                                    0.9327832963365551,
                                    0.0010510847754347972,
                                    0.04376166514811092,
                                ],
                                [
                                    0.8891224381864714,
                                    0.08742252329819458,
                                    0.021355290186338086,
                                    0.0020997483289959496,
                                ],
                                [
                                    0.8891224381864714,
                                    0.021355290186338086,
                                    0.08742252329819458,
                                    0.0020997483289959496,
                                ],
                                [
                                    0.02240395373989924,
                                    0.0010510847754347972,
                                    0.9327832963365551,
                                    0.04376166514811092,
                                ],
                                [
                                    0.9327832963365551,
                                    0.02240395373989924,
                                    0.04376166514811092,
                                    0.0010510847754347972,
                                ],
                                [
                                    0.9327832963365551,
                                    0.04376166514811092,
                                    0.02240395373989924,
                                    0.0010510847754347972,
                                ],
                                [
                                    0.20916143025554443,
                                    0.7418311656066652,
                                    0.010778694584134186,
                                    0.038228709553656134,
                                ],
                                [
                                    0.20916143025554443,
                                    0.010778694584134186,
                                    0.7418311656066652,
                                    0.038228709553656134,
                                ],
                                [
                                    0.20964542066888653,
                                    0.7435477305203463,
                                    0.010294704170792082,
                                    0.03651214463997503,
                                ],
                                [
                                    0.2537725661830357,
                                    0.01307763568731101,
                                    0.697220029679174,
                                    0.03592976845047931,
                                ],
                                [
                                    0.2537725661830357,
                                    0.697220029679174,
                                    0.01307763568731101,
                                    0.03592976845047931,
                                ],
                                [
                                    0.20964542066888653,
                                    0.010294704170792082,
                                    0.7435477305203463,
                                    0.03651214463997503,
                                ],
                                [
                                    0.2543597848162787,
                                    0.6988333663729542,
                                    0.012490417054068,
                                    0.03431643175669911,
                                ],
                                [
                                    0.2543597848162787,
                                    0.012490417054068,
                                    0.6988333663729542,
                                    0.03431643175669911,
                                ],
                                [
                                    0.167354095071685,
                                    0.7754184196992829,
                                    0.010158605446892488,
                                    0.04706887978213959,
                                ],
                                [
                                    0.167354095071685,
                                    0.010158605446892488,
                                    0.7754184196992829,
                                    0.04706887978213959,
                                ],
                                [
                                    0.16927570912667175,
                                    0.784322025751776,
                                    0.00823699139190573,
                                    0.038165273729646475,
                                ],
                                [
                                    0.3849133196495075,
                                    0.023364725816228494,
                                    0.5578591951214604,
                                    0.03386275941280359,
                                ],
                                [
                                    0.3849133196495075,
                                    0.5578591951214604,
                                    0.023364725816228494,
                                    0.03386275941280359,
                                ],
                                [
                                    0.16927570912667175,
                                    0.00823699139190573,
                                    0.784322025751776,
                                    0.038165273729646475,
                                ],
                                [
                                    0.38933301935672576,
                                    0.5642647155217221,
                                    0.018945026109010225,
                                    0.02745723901254198,
                                ],
                                [
                                    0.38933301935672576,
                                    0.018945026109010225,
                                    0.5642647155217221,
                                    0.02745723901254198,
                                ],
                                [
                                    0.1073907103702483,
                                    0.8233444517472613,
                                    0.007991962103330957,
                                    0.061272875779159464,
                                ],
                                [
                                    0.1073907103702483,
                                    0.007991962103330957,
                                    0.8233444517472613,
                                    0.061272875779159464,
                                ],
                                [
                                    0.11009701539711826,
                                    0.8440931852357253,
                                    0.005285657076460987,
                                    0.040524142290695425,
                                ],
                                [
                                    0.5727582914290031,
                                    0.04262438104457617,
                                    0.35797687068850653,
                                    0.026640456837914255,
                                ],
                                [
                                    0.5727582914290031,
                                    0.35797687068850653,
                                    0.04262438104457617,
                                    0.026640456837914255,
                                ],
                                [
                                    0.11009701539711826,
                                    0.005285657076460987,
                                    0.8440931852357253,
                                    0.040524142290695425,
                                ],
                                [
                                    0.58719211571354,
                                    0.3669980849193035,
                                    0.028190556760039193,
                                    0.01761924260711722,
                                ],
                                [
                                    0.58719211571354,
                                    0.028190556760039193,
                                    0.3669980849193035,
                                    0.01761924260711722,
                                ],
                                [
                                    0.048923087784705395,
                                    0.8697747216793458,
                                    0.004329556643875624,
                                    0.07697263389207314,
                                ],
                                [
                                    0.048923087784705395,
                                    0.004329556643875624,
                                    0.8697747216793458,
                                    0.07697263389207314,
                                ],
                                [
                                    0.050844701839692155,
                                    0.9039379645475473,
                                    0.002407942588888866,
                                    0.04280939102387176,
                                ],
                                [
                                    0.755617280345586,
                                    0.06687001913583655,
                                    0.16308052911846527,
                                    0.014432171400112194,
                                ],
                                [
                                    0.755617280345586,
                                    0.16308052911846527,
                                    0.06687001913583655,
                                    0.014432171400112194,
                                ],
                                [
                                    0.050844701839692155,
                                    0.002407942588888866,
                                    0.9039379645475473,
                                    0.04280939102387176,
                                ],
                                [
                                    0.7852966168685125,
                                    0.16948604951872687,
                                    0.03719068261291004,
                                    0.008026650999850582,
                                ],
                                [
                                    0.7852966168685125,
                                    0.03719068261291004,
                                    0.16948604951872687,
                                    0.008026650999850582,
                                ],
                                [
                                    0.009856121812593944,
                                    0.9006216065602155,
                                    0.0009690982948859387,
                                    0.0885531733323046,
                                ],
                                [
                                    0.009856121812593944,
                                    0.0009690982948859387,
                                    0.9006216065602155,
                                    0.0885531733323046,
                                ],
                                [
                                    0.010340112225936048,
                                    0.9448471378505183,
                                    0.0004851078815438347,
                                    0.04432764204200188,
                                ],
                                [
                                    0.8776232698127273,
                                    0.08629187326408458,
                                    0.03285445856008222,
                                    0.003230398363105959,
                                ],
                                [
                                    0.8776232698127273,
                                    0.03285445856008222,
                                    0.08629187326408458,
                                    0.003230398363105959,
                                ],
                                [
                                    0.010340112225936048,
                                    0.0004851078815438347,
                                    0.9448471378505183,
                                    0.04432764204200188,
                                ],
                                [
                                    0.9207194548225919,
                                    0.03446779525386242,
                                    0.04319568825421996,
                                    0.0016170616693257592,
                                ],
                                [
                                    0.9207194548225919,
                                    0.04319568825421996,
                                    0.03446779525386242,
                                    0.0016170616693257592,
                                ],
                                [
                                    0.042518424104707006,
                                    0.9084741717575027,
                                    0.0021910975989378302,
                                    0.046816306538852485,
                                ],
                                [
                                    0.042518424104707006,
                                    0.0021910975989378302,
                                    0.9084741717575027,
                                    0.046816306538852485,
                                ],
                                [
                                    0.042616809880860626,
                                    0.9105763413083723,
                                    0.0020927118227842146,
                                    0.0447141369879829,
                                ],
                                [
                                    0.08712956003219825,
                                    0.0044900387021146555,
                                    0.8638630358300113,
                                    0.044517365435675665,
                                ],
                                [
                                    0.08712956003219825,
                                    0.8638630358300113,
                                    0.0044900387021146555,
                                    0.044517365435675665,
                                ],
                                [
                                    0.042616809880860626,
                                    0.0020927118227842146,
                                    0.9105763413083723,
                                    0.0447141369879829,
                                ],
                                [
                                    0.08733117402825277,
                                    0.8658619771609801,
                                    0.004288424706060135,
                                    0.04251842410470698,
                                ],
                                [
                                    0.08733117402825277,
                                    0.004288424706060135,
                                    0.8658619771609801,
                                    0.04251842410470698,
                                ],
                                [
                                    0.0340198113066247,
                                    0.9087527034643432,
                                    0.0020650456165634884,
                                    0.05516243961246859,
                                ],
                                [
                                    0.0340198113066247,
                                    0.0020650456165634884,
                                    0.9087527034643432,
                                    0.05516243961246859,
                                ],
                                [
                                    0.03441043782536513,
                                    0.9191872970530827,
                                    0.001674419097823057,
                                    0.044727846023729145,
                                ],
                                [
                                    0.2515790358844472,
                                    0.015271165985899494,
                                    0.6911934788865207,
                                    0.04195631924313258,
                                ],
                                [
                                    0.2515790358844472,
                                    0.6911934788865207,
                                    0.015271165985899494,
                                    0.04195631924313258,
                                ],
                                [
                                    0.03441043782536513,
                                    0.001674419097823057,
                                    0.9191872970530827,
                                    0.044727846023729145,
                                ],
                                [
                                    0.25446774805541916,
                                    0.6991299868230286,
                                    0.012382453814927552,
                                    0.03401981130662465,
                                ],
                                [
                                    0.25446774805541916,
                                    0.012382453814927552,
                                    0.6991299868230286,
                                    0.03401981130662465,
                                ],
                                [
                                    0.021830429075041857,
                                    0.9089047330424678,
                                    0.001624609440292181,
                                    0.06764022844219825,
                                ],
                                [
                                    0.021830429075041857,
                                    0.001624609440292181,
                                    0.9089047330424678,
                                    0.06764022844219825,
                                ],
                                [
                                    0.02238056790679766,
                                    0.9318096327260459,
                                    0.0010744706085363785,
                                    0.04473532875862004,
                                ],
                                [
                                    0.48719801013379666,
                                    0.036257028381537396,
                                    0.44353715198371296,
                                    0.03300780950095303,
                                ],
                                [
                                    0.48719801013379666,
                                    0.44353715198371296,
                                    0.036257028381537396,
                                    0.03300780950095303,
                                ],
                                [
                                    0.02238056790679766,
                                    0.0010744706085363785,
                                    0.9318096327260459,
                                    0.04473532875862004,
                                ],
                                [
                                    0.4994756682232194,
                                    0.4547145324096241,
                                    0.023979370292114586,
                                    0.02183042907504183,
                                ],
                                [
                                    0.4994756682232194,
                                    0.023979370292114586,
                                    0.4547145324096241,
                                    0.02183042907504183,
                                ],
                                [
                                    0.009945105999707968,
                                    0.9087527034643432,
                                    0.000880114107771913,
                                    0.08042207642817684,
                                ],
                                [
                                    0.009945105999707968,
                                    0.000880114107771913,
                                    0.9087527034643432,
                                    0.08042207642817684,
                                ],
                                [
                                    0.0103357325184484,
                                    0.944446933868791,
                                    0.0004894875890314823,
                                    0.044727846023729145,
                                ],
                                [
                                    0.7166392985605885,
                                    0.06342057659973285,
                                    0.20205851090346272,
                                    0.017881613936215908,
                                ],
                                [
                                    0.7166392985605885,
                                    0.20205851090346272,
                                    0.06342057659973285,
                                    0.017881613936215908,
                                ],
                                [
                                    0.0103357325184484,
                                    0.0004894875890314823,
                                    0.944446933868791,
                                    0.044727846023729145,
                                ],
                                [
                                    0.7447876475472688,
                                    0.20999501883997065,
                                    0.03527222761305266,
                                    0.009945105999707968,
                                ],
                                [
                                    0.7447876475472688,
                                    0.03527222761305266,
                                    0.20999501883997065,
                                    0.009945105999707968,
                                ],
                                [
                                    0.0020035566153067995,
                                    0.9084741717575027,
                                    0.00019699871171643512,
                                    0.0893252729154741,
                                ],
                                [
                                    0.0020035566153067995,
                                    0.00019699871171643512,
                                    0.9084741717575027,
                                    0.0893252729154741,
                                ],
                                [
                                    0.0021019423914604165,
                                    0.9530853076849939,
                                    9.861293556281859e-05,
                                    0.0447141369879829,
                                ],
                                [
                                    0.8697707046154401,
                                    0.08551977368091507,
                                    0.0407070237573694,
                                    0.004002497946275466,
                                ],
                                [
                                    0.8697707046154401,
                                    0.0407070237573694,
                                    0.08551977368091507,
                                    0.004002497946275466,
                                ],
                                [
                                    0.0021019423914604165,
                                    9.861293556281859e-05,
                                    0.9530853076849939,
                                    0.0447141369879829,
                                ],
                                [
                                    0.9124812849881163,
                                    0.042705965088338085,
                                    0.042809193308238944,
                                    0.002003556615306777,
                                ],
                                [
                                    0.9124812849881163,
                                    0.042809193308238944,
                                    0.042705965088338085,
                                    0.002003556615306777,
                                ],
                                [
                                    0.6972200296791742,
                                    0.07032188195576007,
                                    0.21116037158651307,
                                    0.021297716778552765,
                                ],
                                [
                                    0.6972200296791742,
                                    0.21116037158651307,
                                    0.07032188195576007,
                                    0.021297716778552765,
                                ],
                                [
                                    0.6992189710101429,
                                    0.07052349595181458,
                                    0.20916143025554437,
                                    0.021096102782498242,
                                ],
                                [
                                    0.733225479878235,
                                    0.2220649984181201,
                                    0.03431643175669912,
                                    0.010393089946945693,
                                ],
                                [
                                    0.733225479878235,
                                    0.03431643175669912,
                                    0.2220649984181201,
                                    0.010393089946945693,
                                ],
                                [
                                    0.6992189710101429,
                                    0.20916143025554437,
                                    0.07052349595181458,
                                    0.021096102782498242,
                                ],
                                [
                                    0.7353276494291046,
                                    0.034414817532852734,
                                    0.21996282886725052,
                                    0.010294704170792078,
                                ],
                                [
                                    0.7353276494291046,
                                    0.21996282886725052,
                                    0.034414817532852734,
                                    0.010294704170792078,
                                ],
                                [
                                    0.5578591951214605,
                                    0.20304832547613264,
                                    0.17529060300819288,
                                    0.06380187639421395,
                                ],
                                [
                                    0.5578591951214605,
                                    0.17529060300819288,
                                    0.20304832547613264,
                                    0.06380187639421395,
                                ],
                                [
                                    0.5657957030579684,
                                    0.20593703764710458,
                                    0.16735409507168494,
                                    0.060913164223242,
                                ],
                                [
                                    0.7334502815850511,
                                    0.23046486149176065,
                                    0.02745723901254198,
                                    0.008627617910646156,
                                ],
                                [
                                    0.7334502815850511,
                                    0.02745723901254198,
                                    0.23046486149176065,
                                    0.008627617910646156,
                                ],
                                [
                                    0.5657957030579684,
                                    0.16735409507168494,
                                    0.20593703764710458,
                                    0.060913164223242,
                                ],
                                [
                                    0.7438848751737905,
                                    0.02784786553128241,
                                    0.22003026790302121,
                                    0.008236991391905726,
                                ],
                                [
                                    0.7438848751737905,
                                    0.22003026790302121,
                                    0.02784786553128241,
                                    0.008236991391905726,
                                ],
                                [
                                    0.35797687068850653,
                                    0.393215355902741,
                                    0.11856809079615946,
                                    0.13023968261259306,
                                ],
                                [
                                    0.35797687068850653,
                                    0.11856809079615946,
                                    0.393215355902741,
                                    0.13023968261259306,
                                ],
                                [
                                    0.3691542511144177,
                                    0.40549301399216375,
                                    0.10739071037024826,
                                    0.11796202452317024,
                                ],
                                [
                                    0.7335729839841303,
                                    0.24297197750053573,
                                    0.01761924260711722,
                                    0.005835795908216787,
                                ],
                                [
                                    0.7335729839841303,
                                    0.01761924260711722,
                                    0.24297197750053573,
                                    0.005835795908216787,
                                ],
                                [
                                    0.3691542511144177,
                                    0.10739071037024826,
                                    0.40549301399216375,
                                    0.11796202452317024,
                                ],
                                [
                                    0.7564778836677084,
                                    0.018169381438873023,
                                    0.2200670778169575,
                                    0.005285657076460985,
                                ],
                                [
                                    0.7564778836677084,
                                    0.2200670778169575,
                                    0.018169381438873023,
                                    0.005285657076460985,
                                ],
                                [
                                    0.16308052911846527,
                                    0.5783964034664365,
                                    0.05685959572121336,
                                    0.20166347169388488,
                                ],
                                [
                                    0.16308052911846527,
                                    0.05685959572121336,
                                    0.5783964034664365,
                                    0.20166347169388488,
                                ],
                                [
                                    0.1710170370549732,
                                    0.6065447524531168,
                                    0.04892308778470541,
                                    0.17351512270720465,
                                ],
                                [
                                    0.7334502815850512,
                                    0.2557244983074689,
                                    0.008026650999850584,
                                    0.0027985691076292986,
                                ],
                                [
                                    0.7334502815850512,
                                    0.008026650999850584,
                                    0.2557244983074689,
                                    0.0027985691076292986,
                                ],
                                [
                                    0.1710170370549732,
                                    0.04892308778470541,
                                    0.6065447524531168,
                                    0.17351512270720465,
                                ],
                                [
                                    0.769144511989499,
                                    0.008417277518591015,
                                    0.2200302679030212,
                                    0.0024079425888888675,
                                ],
                                [
                                    0.769144511989499,
                                    0.2200302679030212,
                                    0.008417277518591015,
                                    0.0024079425888888675,
                                ],
                                [
                                    0.032854458560082206,
                                    0.7019880829874786,
                                    0.011855063143562635,
                                    0.25330239530887655,
                                ],
                                [
                                    0.032854458560082206,
                                    0.011855063143562635,
                                    0.7019880829874786,
                                    0.25330239530887655,
                                ],
                                [
                                    0.03485339989105089,
                                    0.7446986633601548,
                                    0.009856121812593946,
                                    0.2105918149362004,
                                ],
                                [
                                    0.733225479878235,
                                    0.26457396479474177,
                                    0.001617061669325759,
                                    0.0005834936576974505,
                                ],
                                [
                                    0.733225479878235,
                                    0.001617061669325759,
                                    0.26457396479474177,
                                    0.0005834936576974505,
                                ],
                                [
                                    0.03485339989105089,
                                    0.009856121812593946,
                                    0.7446986633601548,
                                    0.2105918149362004,
                                ],
                                [
                                    0.7778366158057263,
                                    0.0017154474454793747,
                                    0.21996282886725052,
                                    0.00048510788154383503,
                                ],
                                [
                                    0.7778366158057263,
                                    0.21996282886725052,
                                    0.0017154474454793747,
                                    0.00048510788154383503,
                                ],
                                [
                                    0.5627231975712004,
                                    0.20481871406373392,
                                    0.17042660055845313,
                                    0.062031487806612676,
                                ],
                                [
                                    0.5627231975712004,
                                    0.17042660055845313,
                                    0.20481871406373392,
                                    0.062031487806612676,
                                ],
                                [
                                    0.5643365342649804,
                                    0.2054059326969769,
                                    0.16881326386467294,
                                    0.06144426917336967,
                                ],
                                [
                                    0.5987286477702612,
                                    0.1813312273900602,
                                    0.16881326386467296,
                                    0.05112686097500561,
                                ],
                                [
                                    0.5987286477702612,
                                    0.16881326386467296,
                                    0.1813312273900602,
                                    0.05112686097500561,
                                ],
                                [
                                    0.5643365342649804,
                                    0.16881326386467294,
                                    0.2054059326969769,
                                    0.06144426917336967,
                                ],
                                [
                                    0.6004452126839422,
                                    0.16929725427801506,
                                    0.17961466247637908,
                                    0.0506428705616635,
                                ],
                                [
                                    0.6004452126839422,
                                    0.17961466247637908,
                                    0.16929725427801506,
                                    0.0506428705616635,
                                ],
                                [
                                    0.45024568530782866,
                                    0.3106618352897645,
                                    0.14147626922643544,
                                    0.09761621017597137,
                                ],
                                [
                                    0.45024568530782866,
                                    0.14147626922643544,
                                    0.3106618352897645,
                                    0.09761621017597137,
                                ],
                                [
                                    0.45665120570809026,
                                    0.31508153499698277,
                                    0.13507074882617384,
                                    0.0931965104687531,
                                ],
                                [
                                    0.6258367717714194,
                                    0.19665052771000324,
                                    0.13507074882617381,
                                    0.04244195169240358,
                                ],
                                [
                                    0.6258367717714194,
                                    0.13507074882617381,
                                    0.19665052771000324,
                                    0.04244195169240358,
                                ],
                                [
                                    0.45665120570809026,
                                    0.13507074882617384,
                                    0.31508153499698277,
                                    0.0931965104687531,
                                ],
                                [
                                    0.6347403778239125,
                                    0.13699236288116057,
                                    0.18774692165751014,
                                    0.04052033763741682,
                                ],
                                [
                                    0.6347403778239125,
                                    0.18774692165751014,
                                    0.13699236288116057,
                                    0.04052033763741682,
                                ],
                                [
                                    0.28892154665014713,
                                    0.4622706799411004,
                                    0.09569578087627365,
                                    0.15311199253247887,
                                ],
                                [
                                    0.28892154665014713,
                                    0.09569578087627365,
                                    0.4622706799411004,
                                    0.15311199253247887,
                                ],
                                [
                                    0.2979427608809441,
                                    0.4767045042256373,
                                    0.08667456664547661,
                                    0.1386781682479419,
                                ],
                                [
                                    0.6645176599457708,
                                    0.2200996675806499,
                                    0.08667456664547663,
                                    0.028708105828102605,
                                ],
                                [
                                    0.6645176599457708,
                                    0.08667456664547663,
                                    0.2200996675806499,
                                    0.028708105828102605,
                                ],
                                [
                                    0.2979427608809441,
                                    0.08667456664547661,
                                    0.4767045042256373,
                                    0.1386781682479419,
                                ],
                                [
                                    0.6852663934342348,
                                    0.08938087167234658,
                                    0.19935093409218585,
                                    0.026001800801232634,
                                ],
                                [
                                    0.6852663934342348,
                                    0.19935093409218585,
                                    0.08938087167234658,
                                    0.026001800801232634,
                                ],
                                [
                                    0.13162157267537714,
                                    0.6098553599095247,
                                    0.04589112784320035,
                                    0.21263193957189788,
                                ],
                                [
                                    0.13162157267537714,
                                    0.04589112784320035,
                                    0.6098553599095247,
                                    0.21263193957189788,
                                ],
                                [
                                    0.13802709307563876,
                                    0.6395346964324512,
                                    0.03948560744293873,
                                    0.18295260304897135,
                                ],
                                [
                                    0.701991325141963,
                                    0.24475603042945593,
                                    0.039485607442938726,
                                    0.01376703698564231,
                                ],
                                [
                                    0.701991325141963,
                                    0.039485607442938726,
                                    0.24475603042945593,
                                    0.01376703698564231,
                                ],
                                [
                                    0.13802709307563876,
                                    0.03948560744293873,
                                    0.6395346964324512,
                                    0.18295260304897135,
                                ],
                                [
                                    0.7361545680101644,
                                    0.041407221497925494,
                                    0.21059278756125452,
                                    0.01184542293065555,
                                ],
                                [
                                    0.7361545680101644,
                                    0.21059278756125452,
                                    0.041407221497925494,
                                    0.01184542293065555,
                                ],
                                [
                                    0.026516687972815704,
                                    0.7083258535747451,
                                    0.009568168950372486,
                                    0.2555892895020667,
                                ],
                                [
                                    0.026516687972815704,
                                    0.009568168950372486,
                                    0.7083258535747451,
                                    0.2555892895020667,
                                ],
                                [
                                    0.028130024666595907,
                                    0.7514220385846098,
                                    0.007954832256592286,
                                    0.21249310449220207,
                                ],
                                [
                                    0.7268877092909685,
                                    0.2622870706015516,
                                    0.007954832256592284,
                                    0.0028703878508876094,
                                ],
                                [
                                    0.7268877092909685,
                                    0.007954832256592284,
                                    0.2622870706015516,
                                    0.0028703878508876094,
                                ],
                                [
                                    0.028130024666595907,
                                    0.007954832256592286,
                                    0.7514220385846098,
                                    0.21249310449220207,
                                ],
                                [
                                    0.7711132405812713,
                                    0.008438822669934388,
                                    0.21806153931124886,
                                    0.0023863974375455043,
                                ],
                                [
                                    0.7711132405812713,
                                    0.21806153931124886,
                                    0.008438822669934388,
                                    0.0023863974375455043,
                                ],
                                [
                                    0.3657682307179366,
                                    0.4017736809169976,
                                    0.11077673076672936,
                                    0.12168135759833645,
                                ],
                                [
                                    0.3657682307179366,
                                    0.11077673076672936,
                                    0.4017736809169976,
                                    0.12168135759833645,
                                ],
                                [
                                    0.3668168942714977,
                                    0.40292557269045964,
                                    0.10972806721316822,
                                    0.1205294658248744,
                                ],
                                [
                                    0.4017736809169976,
                                    0.12168135759833645,
                                    0.3657682307179366,
                                    0.11077673076672936,
                                ],
                                [
                                    0.4017736809169976,
                                    0.3657682307179366,
                                    0.12168135759833645,
                                    0.11077673076672936,
                                ],
                                [
                                    0.3668168942714977,
                                    0.10972806721316822,
                                    0.40292557269045964,
                                    0.1205294658248744,
                                ],
                                [
                                    0.40292557269045964,
                                    0.3668168942714977,
                                    0.1205294658248744,
                                    0.10972806721316822,
                                ],
                                [
                                    0.40292557269045964,
                                    0.1205294658248744,
                                    0.3668168942714977,
                                    0.10972806721316822,
                                ],
                                [
                                    0.2926582170670013,
                                    0.46824930353059185,
                                    0.09195911045941954,
                                    0.14713336894298729,
                                ],
                                [
                                    0.2926582170670013,
                                    0.09195911045941954,
                                    0.46824930353059185,
                                    0.14713336894298729,
                                ],
                                [
                                    0.2968217842946255,
                                    0.4749109564104475,
                                    0.08779554323179535,
                                    0.14047171606313158,
                                ],
                                [
                                    0.4682493035305919,
                                    0.1471333689429873,
                                    0.29265821706700124,
                                    0.09195911045941951,
                                ],
                                [
                                    0.4682493035305919,
                                    0.29265821706700124,
                                    0.1471333689429873,
                                    0.09195911045941951,
                                ],
                                [
                                    0.2968217842946255,
                                    0.08779554323179535,
                                    0.4749109564104475,
                                    0.14047171606313158,
                                ],
                                [
                                    0.4749109564104476,
                                    0.2968217842946254,
                                    0.1404717160631316,
                                    0.08779554323179532,
                                ],
                                [
                                    0.4749109564104476,
                                    0.1404717160631316,
                                    0.2968217842946254,
                                    0.08779554323179532,
                                ],
                                [
                                    0.18779805664781188,
                                    0.5633941699434356,
                                    0.06220194335218813,
                                    0.1866058300565644,
                                ],
                                [
                                    0.18779805664781188,
                                    0.06220194335218813,
                                    0.5633941699434356,
                                    0.1866058300565644,
                                ],
                                [
                                    0.19366181627664536,
                                    0.5809854488299361,
                                    0.056338183723354626,
                                    0.16901455117006386,
                                ],
                                [
                                    0.5633941699434356,
                                    0.1866058300565644,
                                    0.18779805664781188,
                                    0.06220194335218813,
                                ],
                                [
                                    0.5633941699434356,
                                    0.18779805664781188,
                                    0.1866058300565644,
                                    0.06220194335218813,
                                ],
                                [
                                    0.19366181627664536,
                                    0.056338183723354626,
                                    0.5809854488299361,
                                    0.16901455117006386,
                                ],
                                [
                                    0.5809854488299361,
                                    0.19366181627664536,
                                    0.16901455117006386,
                                    0.056338183723354626,
                                ],
                                [
                                    0.5809854488299361,
                                    0.16901455117006386,
                                    0.19366181627664536,
                                    0.056338183723354626,
                                ],
                                [
                                    0.08555359005915793,
                                    0.6559233425257438,
                                    0.029829082414421327,
                                    0.2286939850006769,
                                ],
                                [
                                    0.08555359005915793,
                                    0.029829082414421327,
                                    0.6559233425257438,
                                    0.2286939850006769,
                                ],
                                [
                                    0.08971715728678212,
                                    0.6878446322213079,
                                    0.02566551518679714,
                                    0.19677269530511293,
                                ],
                                [
                                    0.6559233425257438,
                                    0.2286939850006769,
                                    0.08555359005915793,
                                    0.029829082414421327,
                                ],
                                [
                                    0.6559233425257438,
                                    0.08555359005915793,
                                    0.2286939850006769,
                                    0.029829082414421327,
                                ],
                                [
                                    0.08971715728678212,
                                    0.02566551518679714,
                                    0.6878446322213079,
                                    0.19677269530511293,
                                ],
                                [
                                    0.6878446322213079,
                                    0.08971715728678212,
                                    0.19677269530511293,
                                    0.02566551518679714,
                                ],
                                [
                                    0.6878446322213079,
                                    0.19677269530511293,
                                    0.08971715728678212,
                                    0.02566551518679714,
                                ],
                                [
                                    0.017235760114703992,
                                    0.7176067814328568,
                                    0.0062192784006300465,
                                    0.2589381800518092,
                                ],
                                [
                                    0.017235760114703992,
                                    0.0062192784006300465,
                                    0.7176067814328568,
                                    0.2589381800518092,
                                ],
                                [
                                    0.018284423668265142,
                                    0.7612676395829405,
                                    0.005170614847068894,
                                    0.21527732190172547,
                                ],
                                [
                                    0.7176067814328568,
                                    0.2589381800518092,
                                    0.017235760114703992,
                                    0.0062192784006300465,
                                ],
                                [
                                    0.7176067814328568,
                                    0.017235760114703992,
                                    0.2589381800518092,
                                    0.0062192784006300465,
                                ],
                                [
                                    0.018284423668265142,
                                    0.005170614847068894,
                                    0.7612676395829405,
                                    0.21527732190172547,
                                ],
                                [
                                    0.7612676395829405,
                                    0.018284423668265142,
                                    0.21527732190172547,
                                    0.005170614847068894,
                                ],
                                [
                                    0.7612676395829405,
                                    0.21527732190172547,
                                    0.018284423668265142,
                                    0.005170614847068894,
                                ],
                                [
                                    0.16881326386467302,
                                    0.5987286477702612,
                                    0.05112686097500562,
                                    0.1813312273900602,
                                ],
                                [
                                    0.16881326386467302,
                                    0.05112686097500562,
                                    0.5987286477702612,
                                    0.1813312273900602,
                                ],
                                [
                                    0.1692972542780151,
                                    0.6004452126839422,
                                    0.050642870561663514,
                                    0.17961466247637908,
                                ],
                                [
                                    0.204818714063734,
                                    0.0620314878066127,
                                    0.5627231975712003,
                                    0.17042660055845313,
                                ],
                                [
                                    0.204818714063734,
                                    0.5627231975712003,
                                    0.0620314878066127,
                                    0.17042660055845313,
                                ],
                                [
                                    0.1692972542780151,
                                    0.050642870561663514,
                                    0.6004452126839422,
                                    0.17961466247637908,
                                ],
                                [
                                    0.205405932696977,
                                    0.5643365342649803,
                                    0.061444269173369696,
                                    0.1688132638646729,
                                ],
                                [
                                    0.205405932696977,
                                    0.061444269173369696,
                                    0.5643365342649803,
                                    0.1688132638646729,
                                ],
                                [
                                    0.13507074882617387,
                                    0.6258367717714193,
                                    0.0424419516924036,
                                    0.19665052771000324,
                                ],
                                [
                                    0.13507074882617387,
                                    0.0424419516924036,
                                    0.6258367717714193,
                                    0.19665052771000324,
                                ],
                                [
                                    0.13699236288116065,
                                    0.6347403778239123,
                                    0.04052033763741684,
                                    0.1877469216575101,
                                ],
                                [
                                    0.3106618352897646,
                                    0.0976162101759714,
                                    0.45024568530782855,
                                    0.14147626922643544,
                                ],
                                [
                                    0.3106618352897646,
                                    0.45024568530782855,
                                    0.0976162101759714,
                                    0.14147626922643544,
                                ],
                                [
                                    0.13699236288116065,
                                    0.04052033763741684,
                                    0.6347403778239123,
                                    0.1877469216575101,
                                ],
                                [
                                    0.3150815349969828,
                                    0.4566512057080902,
                                    0.09319651046875313,
                                    0.13507074882617381,
                                ],
                                [
                                    0.3150815349969828,
                                    0.09319651046875313,
                                    0.4566512057080902,
                                    0.13507074882617381,
                                ],
                                [
                                    0.08667456664547664,
                                    0.6645176599457708,
                                    0.028708105828102612,
                                    0.2200996675806499,
                                ],
                                [
                                    0.08667456664547664,
                                    0.028708105828102612,
                                    0.6645176599457708,
                                    0.2200996675806499,
                                ],
                                [
                                    0.08938087167234661,
                                    0.6852663934342348,
                                    0.02600180080123264,
                                    0.19935093409218585,
                                ],
                                [
                                    0.4622706799411004,
                                    0.15311199253247887,
                                    0.28892154665014713,
                                    0.09569578087627365,
                                ],
                                [
                                    0.4622706799411004,
                                    0.28892154665014713,
                                    0.15311199253247887,
                                    0.09569578087627365,
                                ],
                                [
                                    0.08938087167234661,
                                    0.02600180080123264,
                                    0.6852663934342348,
                                    0.19935093409218585,
                                ],
                                [
                                    0.4767045042256373,
                                    0.2979427608809441,
                                    0.1386781682479419,
                                    0.08667456664547661,
                                ],
                                [
                                    0.4767045042256373,
                                    0.1386781682479419,
                                    0.2979427608809441,
                                    0.08667456664547661,
                                ],
                                [
                                    0.03948560744293871,
                                    0.701991325141963,
                                    0.013767036985642305,
                                    0.24475603042945593,
                                ],
                                [
                                    0.03948560744293871,
                                    0.013767036985642305,
                                    0.701991325141963,
                                    0.24475603042945593,
                                ],
                                [
                                    0.04140722149792547,
                                    0.7361545680101644,
                                    0.011845422930655547,
                                    0.21059278756125452,
                                ],
                                [
                                    0.6098553599095247,
                                    0.21263193957189788,
                                    0.1316215726753771,
                                    0.04589112784320034,
                                ],
                                [
                                    0.6098553599095247,
                                    0.1316215726753771,
                                    0.21263193957189788,
                                    0.04589112784320034,
                                ],
                                [
                                    0.04140722149792547,
                                    0.011845422930655547,
                                    0.7361545680101644,
                                    0.21059278756125452,
                                ],
                                [
                                    0.6395346964324512,
                                    0.13802709307563873,
                                    0.18295260304897135,
                                    0.039485607442938726,
                                ],
                                [
                                    0.6395346964324512,
                                    0.18295260304897135,
                                    0.13802709307563873,
                                    0.039485607442938726,
                                ],
                                [
                                    0.007954832256592275,
                                    0.7268877092909685,
                                    0.0028703878508876063,
                                    0.2622870706015516,
                                ],
                                [
                                    0.007954832256592275,
                                    0.0028703878508876063,
                                    0.7268877092909685,
                                    0.2622870706015516,
                                ],
                                [
                                    0.008438822669934381,
                                    0.7711132405812713,
                                    0.002386397437545502,
                                    0.21806153931124886,
                                ],
                                [
                                    0.7083258535747451,
                                    0.2555892895020667,
                                    0.026516687972815693,
                                    0.009568168950372482,
                                ],
                                [
                                    0.7083258535747451,
                                    0.026516687972815693,
                                    0.2555892895020667,
                                    0.009568168950372482,
                                ],
                                [
                                    0.008438822669934381,
                                    0.002386397437545502,
                                    0.7711132405812713,
                                    0.21806153931124886,
                                ],
                                [
                                    0.7514220385846098,
                                    0.028130024666595897,
                                    0.21249310449220207,
                                    0.007954832256592282,
                                ],
                                [
                                    0.7514220385846098,
                                    0.21249310449220207,
                                    0.028130024666595897,
                                    0.007954832256592282,
                                ],
                                [
                                    0.03431643175669914,
                                    0.733225479878235,
                                    0.0103930899469457,
                                    0.2220649984181201,
                                ],
                                [
                                    0.03431643175669914,
                                    0.0103930899469457,
                                    0.733225479878235,
                                    0.2220649984181201,
                                ],
                                [
                                    0.034414817532852755,
                                    0.7353276494291046,
                                    0.010294704170792085,
                                    0.21996282886725052,
                                ],
                                [
                                    0.07032188195576014,
                                    0.021297716778552783,
                                    0.6972200296791741,
                                    0.21116037158651305,
                                ],
                                [
                                    0.07032188195576014,
                                    0.6972200296791741,
                                    0.021297716778552783,
                                    0.21116037158651305,
                                ],
                                [
                                    0.034414817532852755,
                                    0.010294704170792085,
                                    0.7353276494291046,
                                    0.21996282886725052,
                                ],
                                [
                                    0.07052349595181465,
                                    0.6992189710101427,
                                    0.021096102782498263,
                                    0.20916143025554434,
                                ],
                                [
                                    0.07052349595181465,
                                    0.021096102782498263,
                                    0.6992189710101427,
                                    0.20916143025554434,
                                ],
                                [
                                    0.02745723901254202,
                                    0.7334502815850511,
                                    0.00862761791064617,
                                    0.23046486149176065,
                                ],
                                [
                                    0.02745723901254202,
                                    0.00862761791064617,
                                    0.7334502815850511,
                                    0.23046486149176065,
                                ],
                                [
                                    0.02784786553128245,
                                    0.7438848751737905,
                                    0.008236991391905738,
                                    0.22003026790302121,
                                ],
                                [
                                    0.20304832547613272,
                                    0.06380187639421397,
                                    0.5578591951214604,
                                    0.17529060300819285,
                                ],
                                [
                                    0.20304832547613272,
                                    0.5578591951214604,
                                    0.06380187639421397,
                                    0.17529060300819285,
                                ],
                                [
                                    0.02784786553128245,
                                    0.008236991391905738,
                                    0.7438848751737905,
                                    0.22003026790302121,
                                ],
                                [
                                    0.20593703764710466,
                                    0.5657957030579683,
                                    0.06091316422324203,
                                    0.16735409507168492,
                                ],
                                [
                                    0.20593703764710466,
                                    0.06091316422324203,
                                    0.5657957030579683,
                                    0.16735409507168492,
                                ],
                                [
                                    0.017619242607117242,
                                    0.7335729839841303,
                                    0.005835795908216794,
                                    0.24297197750053573,
                                ],
                                [
                                    0.017619242607117242,
                                    0.005835795908216794,
                                    0.7335729839841303,
                                    0.24297197750053573,
                                ],
                                [
                                    0.018169381438873044,
                                    0.7564778836677084,
                                    0.005285657076460991,
                                    0.2200670778169575,
                                ],
                                [
                                    0.393215355902741,
                                    0.13023968261259306,
                                    0.35797687068850653,
                                    0.11856809079615946,
                                ],
                                [
                                    0.393215355902741,
                                    0.35797687068850653,
                                    0.13023968261259306,
                                    0.11856809079615946,
                                ],
                                [
                                    0.018169381438873044,
                                    0.005285657076460991,
                                    0.7564778836677084,
                                    0.2200670778169575,
                                ],
                                [
                                    0.40549301399216375,
                                    0.3691542511144177,
                                    0.11796202452317024,
                                    0.10739071037024826,
                                ],
                                [
                                    0.40549301399216375,
                                    0.11796202452317024,
                                    0.3691542511144177,
                                    0.10739071037024826,
                                ],
                                [
                                    0.008026650999850584,
                                    0.7334502815850512,
                                    0.0027985691076292986,
                                    0.2557244983074689,
                                ],
                                [
                                    0.008026650999850584,
                                    0.0027985691076292986,
                                    0.7334502815850512,
                                    0.2557244983074689,
                                ],
                                [
                                    0.008417277518591015,
                                    0.769144511989499,
                                    0.0024079425888888675,
                                    0.2200302679030212,
                                ],
                                [
                                    0.5783964034664365,
                                    0.20166347169388488,
                                    0.16308052911846527,
                                    0.05685959572121336,
                                ],
                                [
                                    0.5783964034664365,
                                    0.16308052911846527,
                                    0.20166347169388488,
                                    0.05685959572121336,
                                ],
                                [
                                    0.008417277518591015,
                                    0.0024079425888888675,
                                    0.769144511989499,
                                    0.2200302679030212,
                                ],
                                [
                                    0.6065447524531168,
                                    0.1710170370549732,
                                    0.17351512270720465,
                                    0.04892308778470541,
                                ],
                                [
                                    0.6065447524531168,
                                    0.17351512270720465,
                                    0.1710170370549732,
                                    0.04892308778470541,
                                ],
                                [
                                    0.0016170616693257777,
                                    0.733225479878235,
                                    0.0005834936576974572,
                                    0.26457396479474177,
                                ],
                                [
                                    0.0016170616693257777,
                                    0.0005834936576974572,
                                    0.733225479878235,
                                    0.26457396479474177,
                                ],
                                [
                                    0.0017154474454793942,
                                    0.7778366158057263,
                                    0.00048510788154384056,
                                    0.21996282886725052,
                                ],
                                [
                                    0.7019880829874786,
                                    0.25330239530887655,
                                    0.03285445856008222,
                                    0.011855063143562642,
                                ],
                                [
                                    0.7019880829874786,
                                    0.03285445856008222,
                                    0.25330239530887655,
                                    0.011855063143562642,
                                ],
                                [
                                    0.0017154474454793942,
                                    0.00048510788154384056,
                                    0.7778366158057263,
                                    0.21996282886725052,
                                ],
                                [
                                    0.7446986633601548,
                                    0.03485339989105091,
                                    0.2105918149362004,
                                    0.009856121812593951,
                                ],
                                [
                                    0.7446986633601548,
                                    0.2105918149362004,
                                    0.03485339989105091,
                                    0.009856121812593951,
                                ],
                                [
                                    0.45319072996735926,
                                    0.045708992369129155,
                                    0.45518967129832794,
                                    0.045910606365183675,
                                ],
                                [
                                    0.45319072996735926,
                                    0.45518967129832794,
                                    0.045708992369129155,
                                    0.045910606365183675,
                                ],
                                [
                                    0.45518967129832794,
                                    0.045910606365183675,
                                    0.45319072996735926,
                                    0.045708992369129155,
                                ],
                                [
                                    0.4765941543727428,
                                    0.4786963239236124,
                                    0.022305567963745596,
                                    0.022403953739899216,
                                ],
                                [
                                    0.4765941543727428,
                                    0.022305567963745596,
                                    0.4786963239236124,
                                    0.022403953739899216,
                                ],
                                [
                                    0.45518967129832794,
                                    0.45319072996735926,
                                    0.045910606365183675,
                                    0.045708992369129155,
                                ],
                                [
                                    0.4786963239236124,
                                    0.022403953739899216,
                                    0.4765941543727428,
                                    0.022305567963745596,
                                ],
                                [
                                    0.4786963239236124,
                                    0.4765941543727428,
                                    0.022403953739899216,
                                    0.022305567963745596,
                                ],
                                [
                                    0.36260664509657276,
                                    0.13198074484968733,
                                    0.37054315303308066,
                                    0.13486945702065925,
                                ],
                                [
                                    0.36260664509657276,
                                    0.37054315303308066,
                                    0.13198074484968733,
                                    0.13486945702065925,
                                ],
                                [
                                    0.37054315303308066,
                                    0.13486945702065925,
                                    0.36260664509657276,
                                    0.13198074484968733,
                                ],
                                [
                                    0.4767402747440362,
                                    0.4871748683327756,
                                    0.017847115202223852,
                                    0.018237741720964283,
                                ],
                                [
                                    0.4767402747440362,
                                    0.017847115202223852,
                                    0.4871748683327756,
                                    0.018237741720964283,
                                ],
                                [
                                    0.37054315303308066,
                                    0.36260664509657276,
                                    0.13486945702065925,
                                    0.13198074484968733,
                                ],
                                [
                                    0.4871748683327756,
                                    0.018237741720964283,
                                    0.4767402747440362,
                                    0.017847115202223852,
                                ],
                                [
                                    0.4871748683327756,
                                    0.4767402747440362,
                                    0.018237741720964283,
                                    0.017847115202223852,
                                ],
                                [
                                    0.23268379052937738,
                                    0.2555886902129556,
                                    0.2438611709552886,
                                    0.26786634830237843,
                                ],
                                [
                                    0.23268379052937738,
                                    0.2438611709552886,
                                    0.2555886902129556,
                                    0.26786634830237843,
                                ],
                                [
                                    0.2438611709552886,
                                    0.26786634830237843,
                                    0.23268379052937738,
                                    0.2555886902129556,
                                ],
                                [
                                    0.47682003090054387,
                                    0.4997249305841221,
                                    0.011452449841789104,
                                    0.012002588673544905,
                                ],
                                [
                                    0.47682003090054387,
                                    0.011452449841789104,
                                    0.4997249305841221,
                                    0.012002588673544905,
                                ],
                                [
                                    0.2438611709552886,
                                    0.23268379052937738,
                                    0.26786634830237843,
                                    0.2555886902129556,
                                ],
                                [
                                    0.4997249305841221,
                                    0.012002588673544905,
                                    0.47682003090054387,
                                    0.011452449841789104,
                                ],
                                [
                                    0.4997249305841221,
                                    0.47682003090054387,
                                    0.012002588673544905,
                                    0.011452449841789104,
                                ],
                                [
                                    0.10600180845158533,
                                    0.37595576308682055,
                                    0.11393831638809329,
                                    0.40410411207350083,
                                ],
                                [
                                    0.10600180845158533,
                                    0.11393831638809329,
                                    0.37595576308682055,
                                    0.40410411207350083,
                                ],
                                [
                                    0.11393831638809329,
                                    0.40410411207350083,
                                    0.10600180845158533,
                                    0.37595576308682055,
                                ],
                                [
                                    0.4767402747440362,
                                    0.512434505148484,
                                    0.005217296794369726,
                                    0.005607923313110157,
                                ],
                                [
                                    0.4767402747440362,
                                    0.005217296794369726,
                                    0.512434505148484,
                                    0.005607923313110157,
                                ],
                                [
                                    0.11393831638809329,
                                    0.10600180845158533,
                                    0.40410411207350083,
                                    0.37595576308682055,
                                ],
                                [
                                    0.512434505148484,
                                    0.005607923313110157,
                                    0.4767402747440362,
                                    0.005217296794369726,
                                ],
                                [
                                    0.512434505148484,
                                    0.4767402747440362,
                                    0.005607923313110157,
                                    0.005217296794369726,
                                ],
                                [
                                    0.021355290186338076,
                                    0.4562899489618395,
                                    0.023354231517306763,
                                    0.49900052933451566,
                                ],
                                [
                                    0.021355290186338076,
                                    0.023354231517306763,
                                    0.4562899489618395,
                                    0.49900052933451566,
                                ],
                                [
                                    0.023354231517306763,
                                    0.49900052933451566,
                                    0.021355290186338076,
                                    0.4562899489618395,
                                ],
                                [
                                    0.4765941543727428,
                                    0.521205290300234,
                                    0.001051084775434797,
                                    0.0011494705515884126,
                                ],
                                [
                                    0.4765941543727428,
                                    0.001051084775434797,
                                    0.521205290300234,
                                    0.0011494705515884126,
                                ],
                                [
                                    0.023354231517306763,
                                    0.021355290186338076,
                                    0.49900052933451566,
                                    0.4562899489618395,
                                ],
                                [
                                    0.521205290300234,
                                    0.0011494705515884126,
                                    0.4765941543727428,
                                    0.001051084775434797,
                                ],
                                [
                                    0.521205290300234,
                                    0.4765941543727428,
                                    0.0011494705515884126,
                                    0.001051084775434797,
                                ],
                                [
                                    0.3657682307179366,
                                    0.13313149161855178,
                                    0.3673815674117168,
                                    0.1337187102517948,
                                ],
                                [
                                    0.3657682307179366,
                                    0.3673815674117168,
                                    0.13313149161855178,
                                    0.1337187102517948,
                                ],
                                [
                                    0.3673815674117168,
                                    0.1337187102517948,
                                    0.3657682307179366,
                                    0.13313149161855178,
                                ],
                                [
                                    0.38917165512332014,
                                    0.39088822003700124,
                                    0.10972806721316823,
                                    0.11021205762651033,
                                ],
                                [
                                    0.38917165512332014,
                                    0.10972806721316823,
                                    0.39088822003700124,
                                    0.11021205762651033,
                                ],
                                [
                                    0.3673815674117168,
                                    0.3657682307179366,
                                    0.1337187102517948,
                                    0.13313149161855178,
                                ],
                                [
                                    0.39088822003700124,
                                    0.11021205762651033,
                                    0.38917165512332014,
                                    0.10972806721316823,
                                ],
                                [
                                    0.39088822003700124,
                                    0.38917165512332014,
                                    0.11021205762651033,
                                    0.10972806721316823,
                                ],
                                [
                                    0.29265821706700124,
                                    0.2019291728792588,
                                    0.2990637374672629,
                                    0.20634887258647708,
                                ],
                                [
                                    0.29265821706700124,
                                    0.2990637374672629,
                                    0.2019291728792588,
                                    0.20634887258647708,
                                ],
                                [
                                    0.2990637374672629,
                                    0.20634887258647708,
                                    0.29265821706700124,
                                    0.2019291728792588,
                                ],
                                [
                                    0.4067918467144648,
                                    0.41569545276695785,
                                    0.08779554323179532,
                                    0.08971715728678208,
                                ],
                                [
                                    0.4067918467144648,
                                    0.08779554323179532,
                                    0.41569545276695785,
                                    0.08971715728678208,
                                ],
                                [
                                    0.2990637374672629,
                                    0.29265821706700124,
                                    0.20634887258647708,
                                    0.2019291728792588,
                                ],
                                [
                                    0.41569545276695785,
                                    0.08971715728678208,
                                    0.4067918467144648,
                                    0.08779554323179532,
                                ],
                                [
                                    0.41569545276695785,
                                    0.4067918467144648,
                                    0.08971715728678208,
                                    0.08779554323179532,
                                ],
                                [
                                    0.18779805664781185,
                                    0.30047442409452113,
                                    0.1968192708786089,
                                    0.3149082483790581,
                                ],
                                [
                                    0.18779805664781185,
                                    0.1968192708786089,
                                    0.30047442409452113,
                                    0.3149082483790581,
                                ],
                                [
                                    0.1968192708786089,
                                    0.3149082483790581,
                                    0.18779805664781185,
                                    0.30047442409452113,
                                ],
                                [
                                    0.43193429701897834,
                                    0.4526830305074424,
                                    0.056338183723354626,
                                    0.0590444887502246,
                                ],
                                [
                                    0.43193429701897834,
                                    0.056338183723354626,
                                    0.4526830305074424,
                                    0.0590444887502246,
                                ],
                                [
                                    0.1968192708786089,
                                    0.18779805664781185,
                                    0.3149082483790581,
                                    0.30047442409452113,
                                ],
                                [
                                    0.4526830305074424,
                                    0.0590444887502246,
                                    0.43193429701897834,
                                    0.056338183723354626,
                                ],
                                [
                                    0.4526830305074424,
                                    0.43193429701897834,
                                    0.0590444887502246,
                                    0.056338183723354626,
                                ],
                                [
                                    0.08555359005915793,
                                    0.396403981479248,
                                    0.09195911045941955,
                                    0.4260833180021745,
                                ],
                                [
                                    0.08555359005915793,
                                    0.09195911045941955,
                                    0.396403981479248,
                                    0.4260833180021745,
                                ],
                                [
                                    0.09195911045941955,
                                    0.4260833180021745,
                                    0.08555359005915793,
                                    0.396403981479248,
                                ],
                                [
                                    0.4562920563516088,
                                    0.4904552992198102,
                                    0.02566551518679714,
                                    0.0275871292417839,
                                ],
                                [
                                    0.4562920563516088,
                                    0.02566551518679714,
                                    0.4904552992198102,
                                    0.0275871292417839,
                                ],
                                [
                                    0.09195911045941955,
                                    0.08555359005915793,
                                    0.4260833180021745,
                                    0.396403981479248,
                                ],
                                [
                                    0.4904552992198102,
                                    0.0275871292417839,
                                    0.4562920563516088,
                                    0.02566551518679714,
                                ],
                                [
                                    0.4904552992198102,
                                    0.4562920563516088,
                                    0.0275871292417839,
                                    0.02566551518679714,
                                ],
                                [
                                    0.017235760114703996,
                                    0.46040947903347357,
                                    0.018849096808484195,
                                    0.5035056640433382,
                                ],
                                [
                                    0.017235760114703996,
                                    0.018849096808484195,
                                    0.46040947903347357,
                                    0.5035056640433382,
                                ],
                                [
                                    0.018849096808484195,
                                    0.5035056640433382,
                                    0.017235760114703996,
                                    0.46040947903347357,
                                ],
                                [
                                    0.4724746243011087,
                                    0.5167001555914115,
                                    0.005170614847068894,
                                    0.005654605260410999,
                                ],
                                [
                                    0.4724746243011087,
                                    0.005170614847068894,
                                    0.5167001555914115,
                                    0.005654605260410999,
                                ],
                                [
                                    0.018849096808484195,
                                    0.017235760114703996,
                                    0.5035056640433382,
                                    0.46040947903347357,
                                ],
                                [
                                    0.5167001555914115,
                                    0.005654605260410999,
                                    0.4724746243011087,
                                    0.005170614847068894,
                                ],
                                [
                                    0.5167001555914115,
                                    0.4724746243011087,
                                    0.005654605260410999,
                                    0.005170614847068894,
                                ],
                                [
                                    0.2377481489655524,
                                    0.261151573370936,
                                    0.23879681251911355,
                                    0.26230346514439806,
                                ],
                                [
                                    0.2377481489655524,
                                    0.23879681251911355,
                                    0.261151573370936,
                                    0.26230346514439806,
                                ],
                                [
                                    0.23879681251911355,
                                    0.26230346514439806,
                                    0.2377481489655524,
                                    0.261151573370936,
                                ],
                                [
                                    0.261151573370936,
                                    0.26230346514439806,
                                    0.2377481489655524,
                                    0.23879681251911355,
                                ],
                                [
                                    0.261151573370936,
                                    0.2377481489655524,
                                    0.26230346514439806,
                                    0.23879681251911355,
                                ],
                                [
                                    0.23879681251911355,
                                    0.2377481489655524,
                                    0.26230346514439806,
                                    0.261151573370936,
                                ],
                                [
                                    0.26230346514439806,
                                    0.23879681251911355,
                                    0.261151573370936,
                                    0.2377481489655524,
                                ],
                                [
                                    0.26230346514439806,
                                    0.261151573370936,
                                    0.23879681251911355,
                                    0.2377481489655524,
                                ],
                                [
                                    0.19022688014939834,
                                    0.30436050979686174,
                                    0.19439044737702252,
                                    0.3110221626767174,
                                ],
                                [
                                    0.19022688014939834,
                                    0.19439044737702252,
                                    0.30436050979686174,
                                    0.3110221626767174,
                                ],
                                [
                                    0.19439044737702252,
                                    0.3110221626767174,
                                    0.19022688014939834,
                                    0.30436050979686174,
                                ],
                                [
                                    0.3043605097968618,
                                    0.31102216267671745,
                                    0.1902268801493983,
                                    0.19439044737702246,
                                ],
                                [
                                    0.3043605097968618,
                                    0.1902268801493983,
                                    0.31102216267671745,
                                    0.19439044737702246,
                                ],
                                [
                                    0.19439044737702252,
                                    0.19022688014939834,
                                    0.3110221626767174,
                                    0.30436050979686174,
                                ],
                                [
                                    0.31102216267671745,
                                    0.19439044737702246,
                                    0.3043605097968618,
                                    0.1902268801493983,
                                ],
                                [
                                    0.31102216267671745,
                                    0.3043605097968618,
                                    0.19439044737702246,
                                    0.1902268801493983,
                                ],
                                [
                                    0.12206812018558325,
                                    0.36620436055674976,
                                    0.12793187981441675,
                                    0.38379563944325024,
                                ],
                                [
                                    0.12206812018558325,
                                    0.12793187981441675,
                                    0.36620436055674976,
                                    0.38379563944325024,
                                ],
                                [
                                    0.12793187981441675,
                                    0.38379563944325024,
                                    0.12206812018558325,
                                    0.36620436055674976,
                                ],
                                [
                                    0.36620436055674976,
                                    0.38379563944325024,
                                    0.12206812018558325,
                                    0.12793187981441675,
                                ],
                                [
                                    0.36620436055674976,
                                    0.12206812018558325,
                                    0.38379563944325024,
                                    0.12793187981441675,
                                ],
                                [
                                    0.12793187981441675,
                                    0.12206812018558325,
                                    0.38379563944325024,
                                    0.36620436055674976,
                                ],
                                [
                                    0.38379563944325024,
                                    0.12793187981441675,
                                    0.36620436055674976,
                                    0.12206812018558325,
                                ],
                                [
                                    0.38379563944325024,
                                    0.36620436055674976,
                                    0.12793187981441675,
                                    0.12206812018558325,
                                ],
                                [
                                    0.05560955262297753,
                                    0.4263480189154284,
                                    0.05977311985060172,
                                    0.45826930861099235,
                                ],
                                [
                                    0.05560955262297753,
                                    0.05977311985060172,
                                    0.4263480189154284,
                                    0.45826930861099235,
                                ],
                                [
                                    0.05977311985060172,
                                    0.45826930861099235,
                                    0.05560955262297753,
                                    0.4263480189154284,
                                ],
                                [
                                    0.4263480189154284,
                                    0.45826930861099235,
                                    0.05560955262297753,
                                    0.05977311985060172,
                                ],
                                [
                                    0.4263480189154284,
                                    0.05560955262297753,
                                    0.45826930861099235,
                                    0.05977311985060172,
                                ],
                                [
                                    0.05977311985060172,
                                    0.05560955262297753,
                                    0.45826930861099235,
                                    0.4263480189154284,
                                ],
                                [
                                    0.45826930861099235,
                                    0.05977311985060172,
                                    0.4263480189154284,
                                    0.05560955262297753,
                                ],
                                [
                                    0.45826930861099235,
                                    0.4263480189154284,
                                    0.05977311985060172,
                                    0.05560955262297753,
                                ],
                                [
                                    0.011203187480886442,
                                    0.46644205166729114,
                                    0.012251851034447595,
                                    0.5101029098173748,
                                ],
                                [
                                    0.011203187480886442,
                                    0.012251851034447595,
                                    0.46644205166729114,
                                    0.5101029098173748,
                                ],
                                [
                                    0.012251851034447595,
                                    0.5101029098173748,
                                    0.011203187480886442,
                                    0.46644205166729114,
                                ],
                                [
                                    0.46644205166729114,
                                    0.5101029098173748,
                                    0.011203187480886442,
                                    0.012251851034447595,
                                ],
                                [
                                    0.46644205166729114,
                                    0.011203187480886442,
                                    0.5101029098173748,
                                    0.012251851034447595,
                                ],
                                [
                                    0.012251851034447595,
                                    0.011203187480886442,
                                    0.5101029098173748,
                                    0.46644205166729114,
                                ],
                                [
                                    0.5101029098173748,
                                    0.012251851034447595,
                                    0.46644205166729114,
                                    0.011203187480886442,
                                ],
                                [
                                    0.5101029098173748,
                                    0.46644205166729114,
                                    0.012251851034447595,
                                    0.011203187480886442,
                                ],
                                [
                                    0.10972806721316826,
                                    0.38917165512332014,
                                    0.11021205762651036,
                                    0.39088822003700124,
                                ],
                                [
                                    0.10972806721316826,
                                    0.11021205762651036,
                                    0.38917165512332014,
                                    0.39088822003700124,
                                ],
                                [
                                    0.11021205762651036,
                                    0.39088822003700124,
                                    0.10972806721316826,
                                    0.38917165512332014,
                                ],
                                [
                                    0.13313149161855184,
                                    0.13371871025179485,
                                    0.36576823071793657,
                                    0.36738156741171674,
                                ],
                                [
                                    0.13313149161855184,
                                    0.36576823071793657,
                                    0.13371871025179485,
                                    0.36738156741171674,
                                ],
                                [
                                    0.11021205762651036,
                                    0.10972806721316826,
                                    0.39088822003700124,
                                    0.38917165512332014,
                                ],
                                [
                                    0.13371871025179485,
                                    0.36738156741171674,
                                    0.13313149161855184,
                                    0.36576823071793657,
                                ],
                                [
                                    0.13371871025179485,
                                    0.13313149161855184,
                                    0.36738156741171674,
                                    0.36576823071793657,
                                ],
                                [
                                    0.08779554323179536,
                                    0.4067918467144647,
                                    0.08971715728678212,
                                    0.4156954527669578,
                                ],
                                [
                                    0.08779554323179536,
                                    0.08971715728678212,
                                    0.4067918467144647,
                                    0.4156954527669578,
                                ],
                                [
                                    0.08971715728678212,
                                    0.4156954527669578,
                                    0.08779554323179536,
                                    0.4067918467144647,
                                ],
                                [
                                    0.20192917287925885,
                                    0.20634887258647713,
                                    0.2926582170670012,
                                    0.29906373746726284,
                                ],
                                [
                                    0.20192917287925885,
                                    0.2926582170670012,
                                    0.20634887258647713,
                                    0.29906373746726284,
                                ],
                                [
                                    0.08971715728678212,
                                    0.08779554323179536,
                                    0.4156954527669578,
                                    0.4067918467144647,
                                ],
                                [
                                    0.20634887258647713,
                                    0.29906373746726284,
                                    0.20192917287925885,
                                    0.2926582170670012,
                                ],
                                [
                                    0.20634887258647713,
                                    0.20192917287925885,
                                    0.29906373746726284,
                                    0.2926582170670012,
                                ],
                                [
                                    0.05633818372335464,
                                    0.43193429701897834,
                                    0.05904448875022461,
                                    0.4526830305074424,
                                ],
                                [
                                    0.05633818372335464,
                                    0.05904448875022461,
                                    0.43193429701897834,
                                    0.4526830305074424,
                                ],
                                [
                                    0.05904448875022461,
                                    0.4526830305074424,
                                    0.05633818372335464,
                                    0.43193429701897834,
                                ],
                                [
                                    0.30047442409452113,
                                    0.3149082483790581,
                                    0.18779805664781185,
                                    0.1968192708786089,
                                ],
                                [
                                    0.30047442409452113,
                                    0.18779805664781185,
                                    0.3149082483790581,
                                    0.1968192708786089,
                                ],
                                [
                                    0.05904448875022461,
                                    0.05633818372335464,
                                    0.4526830305074424,
                                    0.43193429701897834,
                                ],
                                [
                                    0.3149082483790581,
                                    0.1968192708786089,
                                    0.30047442409452113,
                                    0.18779805664781185,
                                ],
                                [
                                    0.3149082483790581,
                                    0.30047442409452113,
                                    0.1968192708786089,
                                    0.18779805664781185,
                                ],
                                [
                                    0.02566551518679713,
                                    0.4562920563516088,
                                    0.02758712924178389,
                                    0.4904552992198102,
                                ],
                                [
                                    0.02566551518679713,
                                    0.02758712924178389,
                                    0.4562920563516088,
                                    0.4904552992198102,
                                ],
                                [
                                    0.02758712924178389,
                                    0.4904552992198102,
                                    0.02566551518679713,
                                    0.4562920563516088,
                                ],
                                [
                                    0.396403981479248,
                                    0.4260833180021745,
                                    0.08555359005915791,
                                    0.09195911045941954,
                                ],
                                [
                                    0.396403981479248,
                                    0.08555359005915791,
                                    0.4260833180021745,
                                    0.09195911045941954,
                                ],
                                [
                                    0.02758712924178389,
                                    0.02566551518679713,
                                    0.4904552992198102,
                                    0.4562920563516088,
                                ],
                                [
                                    0.4260833180021745,
                                    0.09195911045941954,
                                    0.396403981479248,
                                    0.08555359005915791,
                                ],
                                [
                                    0.4260833180021745,
                                    0.396403981479248,
                                    0.09195911045941954,
                                    0.08555359005915791,
                                ],
                                [
                                    0.0051706148470688894,
                                    0.4724746243011087,
                                    0.005654605260410993,
                                    0.5167001555914115,
                                ],
                                [
                                    0.0051706148470688894,
                                    0.005654605260410993,
                                    0.4724746243011087,
                                    0.5167001555914115,
                                ],
                                [
                                    0.005654605260410993,
                                    0.5167001555914115,
                                    0.0051706148470688894,
                                    0.4724746243011087,
                                ],
                                [
                                    0.46040947903347357,
                                    0.5035056640433382,
                                    0.01723576011470399,
                                    0.01884909680848419,
                                ],
                                [
                                    0.46040947903347357,
                                    0.01723576011470399,
                                    0.5035056640433382,
                                    0.01884909680848419,
                                ],
                                [
                                    0.005654605260410993,
                                    0.0051706148470688894,
                                    0.5167001555914115,
                                    0.4724746243011087,
                                ],
                                [
                                    0.5035056640433382,
                                    0.01884909680848419,
                                    0.46040947903347357,
                                    0.01723576011470399,
                                ],
                                [
                                    0.5035056640433382,
                                    0.46040947903347357,
                                    0.01884909680848419,
                                    0.01723576011470399,
                                ],
                                [
                                    0.02230556796374561,
                                    0.4765941543727428,
                                    0.02240395373989923,
                                    0.4786963239236124,
                                ],
                                [
                                    0.02230556796374561,
                                    0.02240395373989923,
                                    0.4765941543727428,
                                    0.4786963239236124,
                                ],
                                [
                                    0.02240395373989923,
                                    0.4786963239236124,
                                    0.02230556796374561,
                                    0.4765941543727428,
                                ],
                                [
                                    0.045708992369129196,
                                    0.045910606365183716,
                                    0.4531907299673592,
                                    0.4551896712983279,
                                ],
                                [
                                    0.045708992369129196,
                                    0.4531907299673592,
                                    0.045910606365183716,
                                    0.4551896712983279,
                                ],
                                [
                                    0.02240395373989923,
                                    0.02230556796374561,
                                    0.4786963239236124,
                                    0.4765941543727428,
                                ],
                                [
                                    0.045910606365183716,
                                    0.4551896712983279,
                                    0.045708992369129196,
                                    0.4531907299673592,
                                ],
                                [
                                    0.045910606365183716,
                                    0.045708992369129196,
                                    0.4551896712983279,
                                    0.4531907299673592,
                                ],
                                [
                                    0.01784711520222388,
                                    0.4767402747440362,
                                    0.01823774172096431,
                                    0.4871748683327756,
                                ],
                                [
                                    0.01784711520222388,
                                    0.01823774172096431,
                                    0.4767402747440362,
                                    0.4871748683327756,
                                ],
                                [
                                    0.01823774172096431,
                                    0.4871748683327756,
                                    0.01784711520222388,
                                    0.4767402747440362,
                                ],
                                [
                                    0.1319807448496874,
                                    0.1348694570206593,
                                    0.3626066450965727,
                                    0.3705431530330806,
                                ],
                                [
                                    0.1319807448496874,
                                    0.3626066450965727,
                                    0.1348694570206593,
                                    0.3705431530330806,
                                ],
                                [
                                    0.01823774172096431,
                                    0.01784711520222388,
                                    0.4871748683327756,
                                    0.4767402747440362,
                                ],
                                [
                                    0.1348694570206593,
                                    0.3705431530330806,
                                    0.1319807448496874,
                                    0.3626066450965727,
                                ],
                                [
                                    0.1348694570206593,
                                    0.1319807448496874,
                                    0.3705431530330806,
                                    0.3626066450965727,
                                ],
                                [
                                    0.011452449841789118,
                                    0.47682003090054387,
                                    0.01200258867354492,
                                    0.4997249305841221,
                                ],
                                [
                                    0.011452449841789118,
                                    0.01200258867354492,
                                    0.47682003090054387,
                                    0.4997249305841221,
                                ],
                                [
                                    0.01200258867354492,
                                    0.4997249305841221,
                                    0.011452449841789118,
                                    0.47682003090054387,
                                ],
                                [
                                    0.2555886902129556,
                                    0.26786634830237843,
                                    0.23268379052937738,
                                    0.2438611709552886,
                                ],
                                [
                                    0.2555886902129556,
                                    0.23268379052937738,
                                    0.26786634830237843,
                                    0.2438611709552886,
                                ],
                                [
                                    0.01200258867354492,
                                    0.011452449841789118,
                                    0.4997249305841221,
                                    0.47682003090054387,
                                ],
                                [
                                    0.26786634830237843,
                                    0.2438611709552886,
                                    0.2555886902129556,
                                    0.23268379052937738,
                                ],
                                [
                                    0.26786634830237843,
                                    0.2555886902129556,
                                    0.2438611709552886,
                                    0.23268379052937738,
                                ],
                                [
                                    0.005217296794369726,
                                    0.4767402747440362,
                                    0.005607923313110157,
                                    0.512434505148484,
                                ],
                                [
                                    0.005217296794369726,
                                    0.005607923313110157,
                                    0.4767402747440362,
                                    0.512434505148484,
                                ],
                                [
                                    0.005607923313110157,
                                    0.512434505148484,
                                    0.005217296794369726,
                                    0.4767402747440362,
                                ],
                                [
                                    0.37595576308682055,
                                    0.40410411207350083,
                                    0.10600180845158533,
                                    0.11393831638809329,
                                ],
                                [
                                    0.37595576308682055,
                                    0.10600180845158533,
                                    0.40410411207350083,
                                    0.11393831638809329,
                                ],
                                [
                                    0.005607923313110157,
                                    0.005217296794369726,
                                    0.512434505148484,
                                    0.4767402747440362,
                                ],
                                [
                                    0.40410411207350083,
                                    0.11393831638809329,
                                    0.37595576308682055,
                                    0.10600180845158533,
                                ],
                                [
                                    0.40410411207350083,
                                    0.37595576308682055,
                                    0.11393831638809329,
                                    0.10600180845158533,
                                ],
                                [
                                    0.0010510847754348091,
                                    0.4765941543727428,
                                    0.0011494705515884256,
                                    0.521205290300234,
                                ],
                                [
                                    0.0010510847754348091,
                                    0.0011494705515884256,
                                    0.4765941543727428,
                                    0.521205290300234,
                                ],
                                [
                                    0.0011494705515884256,
                                    0.521205290300234,
                                    0.0010510847754348091,
                                    0.4765941543727428,
                                ],
                                [
                                    0.4562899489618395,
                                    0.49900052933451566,
                                    0.021355290186338086,
                                    0.023354231517306773,
                                ],
                                [
                                    0.4562899489618395,
                                    0.021355290186338086,
                                    0.49900052933451566,
                                    0.023354231517306773,
                                ],
                                [
                                    0.0011494705515884256,
                                    0.0010510847754348091,
                                    0.521205290300234,
                                    0.4765941543727428,
                                ],
                                [
                                    0.49900052933451566,
                                    0.023354231517306773,
                                    0.4562899489618395,
                                    0.021355290186338086,
                                ],
                                [
                                    0.49900052933451566,
                                    0.4562899489618395,
                                    0.023354231517306773,
                                    0.021355290186338086,
                                ],
                                [
                                    0.2091614302555444,
                                    0.021096102782498245,
                                    0.6992189710101429,
                                    0.07052349595181458,
                                ],
                                [
                                    0.2091614302555444,
                                    0.6992189710101429,
                                    0.021096102782498245,
                                    0.07052349595181458,
                                ],
                                [
                                    0.2111603715865131,
                                    0.02129771677855277,
                                    0.6972200296791741,
                                    0.07032188195576006,
                                ],
                                [
                                    0.21996282886725055,
                                    0.7353276494291046,
                                    0.01029470417079208,
                                    0.034414817532852734,
                                ],
                                [
                                    0.21996282886725055,
                                    0.01029470417079208,
                                    0.7353276494291046,
                                    0.034414817532852734,
                                ],
                                [
                                    0.2111603715865131,
                                    0.6972200296791741,
                                    0.02129771677855277,
                                    0.07032188195576006,
                                ],
                                [
                                    0.22206499841812016,
                                    0.010393089946945697,
                                    0.7332254798782349,
                                    0.034316431756699114,
                                ],
                                [
                                    0.22206499841812016,
                                    0.7332254798782349,
                                    0.010393089946945697,
                                    0.034316431756699114,
                                ],
                                [
                                    0.16735409507168497,
                                    0.06091316422324201,
                                    0.5657957030579684,
                                    0.20593703764710458,
                                ],
                                [
                                    0.16735409507168497,
                                    0.5657957030579684,
                                    0.06091316422324201,
                                    0.20593703764710458,
                                ],
                                [
                                    0.1752906030081929,
                                    0.06380187639421395,
                                    0.5578591951214605,
                                    0.20304832547613264,
                                ],
                                [
                                    0.22003026790302124,
                                    0.7438848751737905,
                                    0.008236991391905727,
                                    0.02784786553128241,
                                ],
                                [
                                    0.22003026790302124,
                                    0.008236991391905727,
                                    0.7438848751737905,
                                    0.02784786553128241,
                                ],
                                [
                                    0.1752906030081929,
                                    0.5578591951214605,
                                    0.06380187639421395,
                                    0.20304832547613264,
                                ],
                                [
                                    0.23046486149176068,
                                    0.008627617910646158,
                                    0.7334502815850511,
                                    0.02745723901254198,
                                ],
                                [
                                    0.23046486149176068,
                                    0.7334502815850511,
                                    0.008627617910646158,
                                    0.02745723901254198,
                                ],
                                [
                                    0.10739071037024829,
                                    0.11796202452317027,
                                    0.3691542511144177,
                                    0.40549301399216375,
                                ],
                                [
                                    0.10739071037024829,
                                    0.3691542511144177,
                                    0.11796202452317027,
                                    0.40549301399216375,
                                ],
                                [
                                    0.1185680907961595,
                                    0.13023968261259308,
                                    0.3579768706885065,
                                    0.3932153559027409,
                                ],
                                [
                                    0.22006707781695756,
                                    0.7564778836677084,
                                    0.005285657076460987,
                                    0.018169381438873023,
                                ],
                                [
                                    0.22006707781695756,
                                    0.005285657076460987,
                                    0.7564778836677084,
                                    0.018169381438873023,
                                ],
                                [
                                    0.1185680907961595,
                                    0.3579768706885065,
                                    0.13023968261259308,
                                    0.3932153559027409,
                                ],
                                [
                                    0.2429719775005358,
                                    0.005835795908216789,
                                    0.7335729839841302,
                                    0.01761924260711722,
                                ],
                                [
                                    0.2429719775005358,
                                    0.7335729839841302,
                                    0.005835795908216789,
                                    0.01761924260711722,
                                ],
                                [
                                    0.04892308778470545,
                                    0.17351512270720482,
                                    0.17101703705497318,
                                    0.6065447524531166,
                                ],
                                [
                                    0.04892308778470545,
                                    0.17101703705497318,
                                    0.17351512270720482,
                                    0.6065447524531166,
                                ],
                                [
                                    0.05685959572121338,
                                    0.20166347169388496,
                                    0.16308052911846524,
                                    0.5783964034664364,
                                ],
                                [
                                    0.22003026790302138,
                                    0.7691445119894987,
                                    0.0024079425888888697,
                                    0.008417277518591013,
                                ],
                                [
                                    0.22003026790302138,
                                    0.0024079425888888697,
                                    0.7691445119894987,
                                    0.008417277518591013,
                                ],
                                [
                                    0.05685959572121338,
                                    0.16308052911846524,
                                    0.20166347169388496,
                                    0.5783964034664364,
                                ],
                                [
                                    0.255724498307469,
                                    0.0027985691076293,
                                    0.7334502815850511,
                                    0.008026650999850582,
                                ],
                                [
                                    0.255724498307469,
                                    0.7334502815850511,
                                    0.0027985691076293,
                                    0.008026650999850582,
                                ],
                                [
                                    0.009856121812593951,
                                    0.21059181493620052,
                                    0.034853399891050886,
                                    0.7446986633601547,
                                ],
                                [
                                    0.009856121812593951,
                                    0.034853399891050886,
                                    0.21059181493620052,
                                    0.7446986633601547,
                                ],
                                [
                                    0.01185506314356264,
                                    0.25330239530887666,
                                    0.0328544585600822,
                                    0.7019880829874785,
                                ],
                                [
                                    0.21996282886725063,
                                    0.7778366158057262,
                                    0.00048510788154383525,
                                    0.0017154474454793742,
                                ],
                                [
                                    0.21996282886725063,
                                    0.00048510788154383525,
                                    0.7778366158057262,
                                    0.0017154474454793742,
                                ],
                                [
                                    0.01185506314356264,
                                    0.0328544585600822,
                                    0.25330239530887666,
                                    0.7019880829874785,
                                ],
                                [
                                    0.2645739647947419,
                                    0.0005834936576974507,
                                    0.7332254798782349,
                                    0.0016170616693257588,
                                ],
                                [
                                    0.2645739647947419,
                                    0.7332254798782349,
                                    0.0005834936576974507,
                                    0.0016170616693257588,
                                ],
                                [
                                    0.16881326386467296,
                                    0.061444269173369676,
                                    0.5643365342649804,
                                    0.2054059326969769,
                                ],
                                [
                                    0.16881326386467296,
                                    0.5643365342649804,
                                    0.061444269173369676,
                                    0.2054059326969769,
                                ],
                                [
                                    0.17042660055845318,
                                    0.06203148780661269,
                                    0.5627231975712003,
                                    0.2048187140637339,
                                ],
                                [
                                    0.1796146624763791,
                                    0.6004452126839422,
                                    0.05064287056166351,
                                    0.16929725427801506,
                                ],
                                [
                                    0.1796146624763791,
                                    0.05064287056166351,
                                    0.6004452126839422,
                                    0.16929725427801506,
                                ],
                                [
                                    0.17042660055845318,
                                    0.5627231975712003,
                                    0.06203148780661269,
                                    0.2048187140637339,
                                ],
                                [
                                    0.18133122739006025,
                                    0.05112686097500562,
                                    0.5987286477702611,
                                    0.16881326386467294,
                                ],
                                [
                                    0.18133122739006025,
                                    0.5987286477702611,
                                    0.05112686097500562,
                                    0.16881326386467294,
                                ],
                                [
                                    0.13507074882617387,
                                    0.09319651046875312,
                                    0.45665120570809026,
                                    0.31508153499698277,
                                ],
                                [
                                    0.13507074882617387,
                                    0.45665120570809026,
                                    0.09319651046875312,
                                    0.31508153499698277,
                                ],
                                [
                                    0.14147626922643547,
                                    0.09761621017597139,
                                    0.45024568530782866,
                                    0.3106618352897645,
                                ],
                                [
                                    0.18774692165751014,
                                    0.6347403778239125,
                                    0.040520337637416824,
                                    0.13699236288116057,
                                ],
                                [
                                    0.18774692165751014,
                                    0.040520337637416824,
                                    0.6347403778239125,
                                    0.13699236288116057,
                                ],
                                [
                                    0.14147626922643547,
                                    0.45024568530782866,
                                    0.09761621017597139,
                                    0.3106618352897645,
                                ],
                                [
                                    0.19665052771000327,
                                    0.042441951692403584,
                                    0.6258367717714194,
                                    0.13507074882617381,
                                ],
                                [
                                    0.19665052771000327,
                                    0.6258367717714194,
                                    0.042441951692403584,
                                    0.13507074882617381,
                                ],
                                [
                                    0.08667456664547664,
                                    0.13867816824794194,
                                    0.2979427608809441,
                                    0.4767045042256373,
                                ],
                                [
                                    0.08667456664547664,
                                    0.2979427608809441,
                                    0.13867816824794194,
                                    0.4767045042256373,
                                ],
                                [
                                    0.09569578087627367,
                                    0.15311199253247892,
                                    0.2889215466501471,
                                    0.4622706799411003,
                                ],
                                [
                                    0.1993509340921859,
                                    0.6852663934342348,
                                    0.02600180080123264,
                                    0.08938087167234658,
                                ],
                                [
                                    0.1993509340921859,
                                    0.02600180080123264,
                                    0.6852663934342348,
                                    0.08938087167234658,
                                ],
                                [
                                    0.09569578087627367,
                                    0.2889215466501471,
                                    0.15311199253247892,
                                    0.4622706799411003,
                                ],
                                [
                                    0.22009966758064997,
                                    0.028708105828102615,
                                    0.6645176599457707,
                                    0.08667456664547661,
                                ],
                                [
                                    0.22009966758064997,
                                    0.6645176599457707,
                                    0.028708105828102615,
                                    0.08667456664547661,
                                ],
                                [
                                    0.03948560744293877,
                                    0.18295260304897148,
                                    0.1380270930756387,
                                    0.639534696432451,
                                ],
                                [
                                    0.03948560744293877,
                                    0.1380270930756387,
                                    0.18295260304897148,
                                    0.639534696432451,
                                ],
                                [
                                    0.04589112784320037,
                                    0.21263193957189797,
                                    0.1316215726753771,
                                    0.6098553599095246,
                                ],
                                [
                                    0.2105927875612547,
                                    0.7361545680101643,
                                    0.01184542293065556,
                                    0.04140722149792548,
                                ],
                                [
                                    0.2105927875612547,
                                    0.01184542293065556,
                                    0.7361545680101643,
                                    0.04140722149792548,
                                ],
                                [
                                    0.04589112784320037,
                                    0.1316215726753771,
                                    0.21263193957189797,
                                    0.6098553599095246,
                                ],
                                [
                                    0.24475603042945604,
                                    0.013767036985642318,
                                    0.7019913251419629,
                                    0.039485607442938726,
                                ],
                                [
                                    0.24475603042945604,
                                    0.7019913251419629,
                                    0.013767036985642318,
                                    0.039485607442938726,
                                ],
                                [
                                    0.00795483225659229,
                                    0.21249310449220218,
                                    0.028130024666595903,
                                    0.7514220385846097,
                                ],
                                [
                                    0.00795483225659229,
                                    0.028130024666595903,
                                    0.21249310449220218,
                                    0.7514220385846097,
                                ],
                                [
                                    0.009568168950372491,
                                    0.25558928950206683,
                                    0.0265166879728157,
                                    0.708325853574745,
                                ],
                                [
                                    0.21806153931124897,
                                    0.7711132405812712,
                                    0.0023863974375455056,
                                    0.008438822669934388,
                                ],
                                [
                                    0.21806153931124897,
                                    0.0023863974375455056,
                                    0.7711132405812712,
                                    0.008438822669934388,
                                ],
                                [
                                    0.009568168950372491,
                                    0.0265166879728157,
                                    0.25558928950206683,
                                    0.708325853574745,
                                ],
                                [
                                    0.2622870706015517,
                                    0.0028703878508876107,
                                    0.7268877092909684,
                                    0.007954832256592282,
                                ],
                                [
                                    0.2622870706015517,
                                    0.7268877092909684,
                                    0.0028703878508876107,
                                    0.007954832256592282,
                                ],
                                [
                                    0.10972806721316823,
                                    0.12052946582487441,
                                    0.3668168942714977,
                                    0.40292557269045964,
                                ],
                                [
                                    0.10972806721316823,
                                    0.3668168942714977,
                                    0.12052946582487441,
                                    0.40292557269045964,
                                ],
                                [
                                    0.11077673076672939,
                                    0.12168135759833648,
                                    0.36576823071793657,
                                    0.40177368091699756,
                                ],
                                [
                                    0.12052946582487441,
                                    0.40292557269045964,
                                    0.10972806721316823,
                                    0.3668168942714977,
                                ],
                                [
                                    0.12052946582487441,
                                    0.10972806721316823,
                                    0.40292557269045964,
                                    0.3668168942714977,
                                ],
                                [
                                    0.11077673076672939,
                                    0.36576823071793657,
                                    0.12168135759833648,
                                    0.40177368091699756,
                                ],
                                [
                                    0.12168135759833648,
                                    0.11077673076672939,
                                    0.40177368091699756,
                                    0.36576823071793657,
                                ],
                                [
                                    0.12168135759833648,
                                    0.40177368091699756,
                                    0.11077673076672939,
                                    0.36576823071793657,
                                ],
                                [
                                    0.08779554323179536,
                                    0.1404717160631316,
                                    0.2968217842946255,
                                    0.4749109564104475,
                                ],
                                [
                                    0.08779554323179536,
                                    0.2968217842946255,
                                    0.1404717160631316,
                                    0.4749109564104475,
                                ],
                                [
                                    0.09195911045941955,
                                    0.1471333689429873,
                                    0.2926582170670013,
                                    0.46824930353059185,
                                ],
                                [
                                    0.14047171606313164,
                                    0.4749109564104476,
                                    0.08779554323179534,
                                    0.2968217842946254,
                                ],
                                [
                                    0.14047171606313164,
                                    0.08779554323179534,
                                    0.4749109564104476,
                                    0.2968217842946254,
                                ],
                                [
                                    0.09195911045941955,
                                    0.2926582170670013,
                                    0.1471333689429873,
                                    0.46824930353059185,
                                ],
                                [
                                    0.14713336894298734,
                                    0.09195911045941953,
                                    0.4682493035305919,
                                    0.29265821706700124,
                                ],
                                [
                                    0.14713336894298734,
                                    0.4682493035305919,
                                    0.09195911045941953,
                                    0.29265821706700124,
                                ],
                                [
                                    0.05633818372335464,
                                    0.16901455117006392,
                                    0.19366181627664536,
                                    0.5809854488299361,
                                ],
                                [
                                    0.05633818372335464,
                                    0.19366181627664536,
                                    0.16901455117006392,
                                    0.5809854488299361,
                                ],
                                [
                                    0.06220194335218815,
                                    0.18660583005656445,
                                    0.18779805664781185,
                                    0.5633941699434355,
                                ],
                                [
                                    0.16901455117006392,
                                    0.5809854488299361,
                                    0.05633818372335464,
                                    0.19366181627664536,
                                ],
                                [
                                    0.16901455117006392,
                                    0.05633818372335464,
                                    0.5809854488299361,
                                    0.19366181627664536,
                                ],
                                [
                                    0.06220194335218815,
                                    0.18779805664781185,
                                    0.18660583005656445,
                                    0.5633941699434355,
                                ],
                                [
                                    0.18660583005656445,
                                    0.06220194335218815,
                                    0.5633941699434355,
                                    0.18779805664781185,
                                ],
                                [
                                    0.18660583005656445,
                                    0.5633941699434355,
                                    0.06220194335218815,
                                    0.18779805664781185,
                                ],
                                [
                                    0.02566551518679716,
                                    0.1967726953051131,
                                    0.08971715728678209,
                                    0.6878446322213077,
                                ],
                                [
                                    0.02566551518679716,
                                    0.08971715728678209,
                                    0.1967726953051131,
                                    0.6878446322213077,
                                ],
                                [
                                    0.02982908241442134,
                                    0.228693985000677,
                                    0.08555359005915791,
                                    0.6559233425257438,
                                ],
                                [
                                    0.1967726953051131,
                                    0.6878446322213077,
                                    0.02566551518679716,
                                    0.08971715728678209,
                                ],
                                [
                                    0.1967726953051131,
                                    0.02566551518679716,
                                    0.6878446322213077,
                                    0.08971715728678209,
                                ],
                                [
                                    0.02982908241442134,
                                    0.08555359005915791,
                                    0.228693985000677,
                                    0.6559233425257438,
                                ],
                                [
                                    0.228693985000677,
                                    0.02982908241442134,
                                    0.6559233425257438,
                                    0.08555359005915791,
                                ],
                                [
                                    0.228693985000677,
                                    0.6559233425257438,
                                    0.02982908241442134,
                                    0.08555359005915791,
                                ],
                                [
                                    0.005170614847068896,
                                    0.21527732190172558,
                                    0.018284423668265142,
                                    0.7612676395829404,
                                ],
                                [
                                    0.005170614847068896,
                                    0.018284423668265142,
                                    0.21527732190172558,
                                    0.7612676395829404,
                                ],
                                [
                                    0.006219278400630049,
                                    0.2589381800518093,
                                    0.01723576011470399,
                                    0.7176067814328567,
                                ],
                                [
                                    0.21527732190172558,
                                    0.7612676395829404,
                                    0.005170614847068896,
                                    0.018284423668265142,
                                ],
                                [
                                    0.21527732190172558,
                                    0.005170614847068896,
                                    0.7612676395829404,
                                    0.018284423668265142,
                                ],
                                [
                                    0.006219278400630049,
                                    0.01723576011470399,
                                    0.2589381800518093,
                                    0.7176067814328567,
                                ],
                                [
                                    0.2589381800518093,
                                    0.006219278400630049,
                                    0.7176067814328567,
                                    0.01723576011470399,
                                ],
                                [
                                    0.2589381800518093,
                                    0.7176067814328567,
                                    0.006219278400630049,
                                    0.01723576011470399,
                                ],
                                [
                                    0.05064287056166352,
                                    0.1796146624763791,
                                    0.1692972542780151,
                                    0.6004452126839422,
                                ],
                                [
                                    0.05064287056166352,
                                    0.1692972542780151,
                                    0.1796146624763791,
                                    0.6004452126839422,
                                ],
                                [
                                    0.051126860975005635,
                                    0.18133122739006025,
                                    0.168813263864673,
                                    0.5987286477702611,
                                ],
                                [
                                    0.0614442691733697,
                                    0.205405932696977,
                                    0.16881326386467294,
                                    0.5643365342649803,
                                ],
                                [
                                    0.0614442691733697,
                                    0.16881326386467294,
                                    0.205405932696977,
                                    0.5643365342649803,
                                ],
                                [
                                    0.051126860975005635,
                                    0.168813263864673,
                                    0.18133122739006025,
                                    0.5987286477702611,
                                ],
                                [
                                    0.06203148780661272,
                                    0.17042660055845316,
                                    0.20481871406373398,
                                    0.5627231975712002,
                                ],
                                [
                                    0.06203148780661272,
                                    0.20481871406373398,
                                    0.17042660055845316,
                                    0.5627231975712002,
                                ],
                                [
                                    0.040520337637416845,
                                    0.18774692165751014,
                                    0.13699236288116065,
                                    0.6347403778239123,
                                ],
                                [
                                    0.040520337637416845,
                                    0.13699236288116065,
                                    0.18774692165751014,
                                    0.6347403778239123,
                                ],
                                [
                                    0.042441951692403605,
                                    0.19665052771000324,
                                    0.13507074882617387,
                                    0.6258367717714193,
                                ],
                                [
                                    0.09319651046875314,
                                    0.3150815349969828,
                                    0.13507074882617384,
                                    0.4566512057080902,
                                ],
                                [
                                    0.09319651046875314,
                                    0.13507074882617384,
                                    0.3150815349969828,
                                    0.4566512057080902,
                                ],
                                [
                                    0.042441951692403605,
                                    0.13507074882617387,
                                    0.19665052771000324,
                                    0.6258367717714193,
                                ],
                                [
                                    0.09761621017597141,
                                    0.14147626922643544,
                                    0.3106618352897646,
                                    0.45024568530782855,
                                ],
                                [
                                    0.09761621017597141,
                                    0.3106618352897646,
                                    0.14147626922643544,
                                    0.45024568530782855,
                                ],
                                [
                                    0.026001800801232648,
                                    0.1993509340921859,
                                    0.08938087167234661,
                                    0.6852663934342348,
                                ],
                                [
                                    0.026001800801232648,
                                    0.08938087167234661,
                                    0.1993509340921859,
                                    0.6852663934342348,
                                ],
                                [
                                    0.028708105828102622,
                                    0.22009966758064997,
                                    0.08667456664547663,
                                    0.6645176599457707,
                                ],
                                [
                                    0.13867816824794194,
                                    0.4767045042256373,
                                    0.08667456664547664,
                                    0.2979427608809441,
                                ],
                                [
                                    0.13867816824794194,
                                    0.08667456664547664,
                                    0.4767045042256373,
                                    0.2979427608809441,
                                ],
                                [
                                    0.028708105828102622,
                                    0.08667456664547663,
                                    0.22009966758064997,
                                    0.6645176599457707,
                                ],
                                [
                                    0.15311199253247892,
                                    0.09569578087627367,
                                    0.4622706799411003,
                                    0.2889215466501471,
                                ],
                                [
                                    0.15311199253247892,
                                    0.4622706799411003,
                                    0.09569578087627367,
                                    0.2889215466501471,
                                ],
                                [
                                    0.011845422930655557,
                                    0.2105927875612547,
                                    0.041407221497925466,
                                    0.7361545680101643,
                                ],
                                [
                                    0.011845422930655557,
                                    0.041407221497925466,
                                    0.2105927875612547,
                                    0.7361545680101643,
                                ],
                                [
                                    0.013767036985642312,
                                    0.24475603042945604,
                                    0.039485607442938706,
                                    0.7019913251419629,
                                ],
                                [
                                    0.18295260304897148,
                                    0.639534696432451,
                                    0.03948560744293876,
                                    0.1380270930756387,
                                ],
                                [
                                    0.18295260304897148,
                                    0.03948560744293876,
                                    0.639534696432451,
                                    0.1380270930756387,
                                ],
                                [
                                    0.013767036985642312,
                                    0.039485607442938706,
                                    0.24475603042945604,
                                    0.7019913251419629,
                                ],
                                [
                                    0.21263193957189797,
                                    0.04589112784320036,
                                    0.6098553599095246,
                                    0.13162157267537708,
                                ],
                                [
                                    0.21263193957189797,
                                    0.6098553599095246,
                                    0.04589112784320036,
                                    0.13162157267537708,
                                ],
                                [
                                    0.0023863974375455035,
                                    0.21806153931124897,
                                    0.00843882266993438,
                                    0.7711132405812712,
                                ],
                                [
                                    0.0023863974375455035,
                                    0.00843882266993438,
                                    0.21806153931124897,
                                    0.7711132405812712,
                                ],
                                [
                                    0.0028703878508876076,
                                    0.2622870706015517,
                                    0.007954832256592275,
                                    0.7268877092909684,
                                ],
                                [
                                    0.21249310449220218,
                                    0.7514220385846097,
                                    0.007954832256592286,
                                    0.02813002466659589,
                                ],
                                [
                                    0.21249310449220218,
                                    0.007954832256592286,
                                    0.7514220385846097,
                                    0.02813002466659589,
                                ],
                                [
                                    0.0028703878508876076,
                                    0.007954832256592275,
                                    0.2622870706015517,
                                    0.7268877092909684,
                                ],
                                [
                                    0.25558928950206683,
                                    0.009568168950372486,
                                    0.708325853574745,
                                    0.02651668797281569,
                                ],
                                [
                                    0.25558928950206683,
                                    0.708325853574745,
                                    0.009568168950372486,
                                    0.02651668797281569,
                                ],
                                [
                                    0.010294704170792085,
                                    0.21996282886725055,
                                    0.034414817532852755,
                                    0.7353276494291046,
                                ],
                                [
                                    0.010294704170792085,
                                    0.034414817532852755,
                                    0.21996282886725055,
                                    0.7353276494291046,
                                ],
                                [
                                    0.010393089946945702,
                                    0.22206499841812016,
                                    0.034316431756699135,
                                    0.7332254798782349,
                                ],
                                [
                                    0.021096102782498266,
                                    0.07052349595181465,
                                    0.20916143025554437,
                                    0.6992189710101427,
                                ],
                                [
                                    0.021096102782498266,
                                    0.20916143025554437,
                                    0.07052349595181465,
                                    0.6992189710101427,
                                ],
                                [
                                    0.010393089946945702,
                                    0.034316431756699135,
                                    0.22206499841812016,
                                    0.7332254798782349,
                                ],
                                [
                                    0.02129771677855279,
                                    0.21116037158651307,
                                    0.07032188195576013,
                                    0.697220029679174,
                                ],
                                [
                                    0.02129771677855279,
                                    0.07032188195576013,
                                    0.21116037158651307,
                                    0.697220029679174,
                                ],
                                [
                                    0.00823699139190574,
                                    0.22003026790302124,
                                    0.02784786553128245,
                                    0.7438848751737905,
                                ],
                                [
                                    0.00823699139190574,
                                    0.02784786553128245,
                                    0.22003026790302124,
                                    0.7438848751737905,
                                ],
                                [
                                    0.00862761791064617,
                                    0.23046486149176068,
                                    0.02745723901254202,
                                    0.7334502815850511,
                                ],
                                [
                                    0.060913164223242035,
                                    0.20593703764710466,
                                    0.16735409507168494,
                                    0.5657957030579683,
                                ],
                                [
                                    0.060913164223242035,
                                    0.16735409507168494,
                                    0.20593703764710466,
                                    0.5657957030579683,
                                ],
                                [
                                    0.00862761791064617,
                                    0.02745723901254202,
                                    0.23046486149176068,
                                    0.7334502815850511,
                                ],
                                [
                                    0.06380187639421397,
                                    0.17529060300819288,
                                    0.20304832547613272,
                                    0.5578591951214604,
                                ],
                                [
                                    0.06380187639421397,
                                    0.20304832547613272,
                                    0.17529060300819288,
                                    0.5578591951214604,
                                ],
                                [
                                    0.005285657076460993,
                                    0.22006707781695756,
                                    0.018169381438873044,
                                    0.7564778836677084,
                                ],
                                [
                                    0.005285657076460993,
                                    0.018169381438873044,
                                    0.22006707781695756,
                                    0.7564778836677084,
                                ],
                                [
                                    0.0058357959082167956,
                                    0.2429719775005358,
                                    0.017619242607117242,
                                    0.7335729839841302,
                                ],
                                [
                                    0.11796202452317027,
                                    0.40549301399216375,
                                    0.10739071037024829,
                                    0.3691542511144177,
                                ],
                                [
                                    0.11796202452317027,
                                    0.10739071037024829,
                                    0.40549301399216375,
                                    0.3691542511144177,
                                ],
                                [
                                    0.0058357959082167956,
                                    0.017619242607117242,
                                    0.2429719775005358,
                                    0.7335729839841302,
                                ],
                                [
                                    0.13023968261259308,
                                    0.1185680907961595,
                                    0.3932153559027409,
                                    0.3579768706885065,
                                ],
                                [
                                    0.13023968261259308,
                                    0.3932153559027409,
                                    0.1185680907961595,
                                    0.3579768706885065,
                                ],
                                [
                                    0.0024079425888888697,
                                    0.22003026790302138,
                                    0.008417277518591013,
                                    0.7691445119894987,
                                ],
                                [
                                    0.0024079425888888697,
                                    0.008417277518591013,
                                    0.22003026790302138,
                                    0.7691445119894987,
                                ],
                                [
                                    0.0027985691076293,
                                    0.255724498307469,
                                    0.008026650999850582,
                                    0.7334502815850511,
                                ],
                                [
                                    0.17351512270720482,
                                    0.6065447524531166,
                                    0.04892308778470545,
                                    0.17101703705497318,
                                ],
                                [
                                    0.17351512270720482,
                                    0.04892308778470545,
                                    0.6065447524531166,
                                    0.17101703705497318,
                                ],
                                [
                                    0.0027985691076293,
                                    0.008026650999850582,
                                    0.255724498307469,
                                    0.7334502815850511,
                                ],
                                [
                                    0.20166347169388496,
                                    0.05685959572121338,
                                    0.5783964034664364,
                                    0.16308052911846524,
                                ],
                                [
                                    0.20166347169388496,
                                    0.5783964034664364,
                                    0.05685959572121338,
                                    0.16308052911846524,
                                ],
                                [
                                    0.00048510788154384083,
                                    0.21996282886725063,
                                    0.001715447445479394,
                                    0.7778366158057262,
                                ],
                                [
                                    0.00048510788154384083,
                                    0.001715447445479394,
                                    0.21996282886725063,
                                    0.7778366158057262,
                                ],
                                [
                                    0.0005834936576974574,
                                    0.2645739647947419,
                                    0.0016170616693257775,
                                    0.7332254798782349,
                                ],
                                [
                                    0.21059181493620052,
                                    0.7446986633601547,
                                    0.009856121812593956,
                                    0.03485339989105091,
                                ],
                                [
                                    0.21059181493620052,
                                    0.009856121812593956,
                                    0.7446986633601547,
                                    0.03485339989105091,
                                ],
                                [
                                    0.0005834936576974574,
                                    0.0016170616693257775,
                                    0.2645739647947419,
                                    0.7332254798782349,
                                ],
                                [
                                    0.25330239530887666,
                                    0.011855063143562645,
                                    0.7019880829874785,
                                    0.03285445856008221,
                                ],
                                [
                                    0.25330239530887666,
                                    0.7019880829874785,
                                    0.011855063143562645,
                                    0.03285445856008221,
                                ],
                                [
                                    0.042518424104707,
                                    0.004288424706060132,
                                    0.8658619771609802,
                                    0.0873311740282527,
                                ],
                                [
                                    0.042518424104707,
                                    0.8658619771609802,
                                    0.004288424706060132,
                                    0.0873311740282527,
                                ],
                                [
                                    0.044517365435675714,
                                    0.0044900387021146555,
                                    0.8638630358300114,
                                    0.08712956003219817,
                                ],
                                [
                                    0.04471413698798292,
                                    0.9105763413083723,
                                    0.0020927118227842146,
                                    0.0426168098808606,
                                ],
                                [
                                    0.04471413698798292,
                                    0.0020927118227842146,
                                    0.9105763413083723,
                                    0.0426168098808606,
                                ],
                                [
                                    0.044517365435675714,
                                    0.8638630358300114,
                                    0.0044900387021146555,
                                    0.08712956003219817,
                                ],
                                [
                                    0.046816306538852534,
                                    0.002191097598937831,
                                    0.9084741717575027,
                                    0.04251842410470698,
                                ],
                                [
                                    0.046816306538852534,
                                    0.9084741717575027,
                                    0.002191097598937831,
                                    0.04251842410470698,
                                ],
                                [
                                    0.03401981130662466,
                                    0.012382453814927549,
                                    0.6991299868230287,
                                    0.25446774805541905,
                                ],
                                [
                                    0.03401981130662466,
                                    0.6991299868230287,
                                    0.012382453814927549,
                                    0.25446774805541905,
                                ],
                                [
                                    0.0419563192431326,
                                    0.015271165985899492,
                                    0.6911934788865208,
                                    0.2515790358844471,
                                ],
                                [
                                    0.04472784602372915,
                                    0.9191872970530827,
                                    0.0016744190978230547,
                                    0.034410437825365084,
                                ],
                                [
                                    0.04472784602372915,
                                    0.0016744190978230547,
                                    0.9191872970530827,
                                    0.034410437825365084,
                                ],
                                [
                                    0.0419563192431326,
                                    0.6911934788865208,
                                    0.015271165985899492,
                                    0.2515790358844471,
                                ],
                                [
                                    0.055162439612468604,
                                    0.0020650456165634853,
                                    0.9087527034643432,
                                    0.03401981130662465,
                                ],
                                [
                                    0.055162439612468604,
                                    0.9087527034643432,
                                    0.0020650456165634853,
                                    0.03401981130662465,
                                ],
                                [
                                    0.02183042907504185,
                                    0.023979370292114607,
                                    0.4547145324096241,
                                    0.4994756682232194,
                                ],
                                [
                                    0.02183042907504185,
                                    0.4547145324096241,
                                    0.023979370292114607,
                                    0.4994756682232194,
                                ],
                                [
                                    0.03300780950095306,
                                    0.03625702838153743,
                                    0.4435371519837129,
                                    0.4871980101337966,
                                ],
                                [
                                    0.044735328758620074,
                                    0.9318096327260459,
                                    0.0010744706085363783,
                                    0.02238056790679763,
                                ],
                                [
                                    0.044735328758620074,
                                    0.0010744706085363783,
                                    0.9318096327260459,
                                    0.02238056790679763,
                                ],
                                [
                                    0.03300780950095306,
                                    0.4435371519837129,
                                    0.03625702838153743,
                                    0.4871980101337966,
                                ],
                                [
                                    0.06764022844219832,
                                    0.0016246094402921807,
                                    0.9089047330424677,
                                    0.02183042907504183,
                                ],
                                [
                                    0.06764022844219832,
                                    0.9089047330424677,
                                    0.0016246094402921807,
                                    0.02183042907504183,
                                ],
                                [
                                    0.00994510599970801,
                                    0.035272227613052806,
                                    0.2099950188399706,
                                    0.7447876475472686,
                                ],
                                [
                                    0.00994510599970801,
                                    0.2099950188399706,
                                    0.035272227613052806,
                                    0.7447876475472686,
                                ],
                                [
                                    0.017881613936215936,
                                    0.06342057659973295,
                                    0.2020585109034627,
                                    0.7166392985605884,
                                ],
                                [
                                    0.044727846023729326,
                                    0.9444469338687908,
                                    0.0004894875890314843,
                                    0.010335732518448399,
                                ],
                                [
                                    0.044727846023729326,
                                    0.0004894875890314843,
                                    0.9444469338687908,
                                    0.010335732518448399,
                                ],
                                [
                                    0.017881613936215936,
                                    0.2020585109034627,
                                    0.06342057659973295,
                                    0.7166392985605884,
                                ],
                                [
                                    0.08042207642817698,
                                    0.0008801141077719145,
                                    0.9087527034643431,
                                    0.009945105999707968,
                                ],
                                [
                                    0.08042207642817698,
                                    0.9087527034643431,
                                    0.0008801141077719145,
                                    0.009945105999707968,
                                ],
                                [
                                    0.0020035566153067787,
                                    0.042809193308239,
                                    0.04270596508833806,
                                    0.9124812849881162,
                                ],
                                [
                                    0.0020035566153067787,
                                    0.04270596508833806,
                                    0.042809193308239,
                                    0.9124812849881162,
                                ],
                                [
                                    0.0040024979462754675,
                                    0.08551977368091515,
                                    0.04070702375736937,
                                    0.86977070461544,
                                ],
                                [
                                    0.04471413698798296,
                                    0.9530853076849938,
                                    9.861293556281759e-05,
                                    0.002101942391460392,
                                ],
                                [
                                    0.04471413698798296,
                                    9.861293556281759e-05,
                                    0.9530853076849938,
                                    0.002101942391460392,
                                ],
                                [
                                    0.0040024979462754675,
                                    0.04070702375736937,
                                    0.08551977368091515,
                                    0.86977070461544,
                                ],
                                [
                                    0.08932527291547418,
                                    0.00019699871171643306,
                                    0.9084741717575026,
                                    0.0020035566153067765,
                                ],
                                [
                                    0.08932527291547418,
                                    0.9084741717575026,
                                    0.00019699871171643306,
                                    0.0020035566153067765,
                                ],
                                [
                                    0.03431643175669913,
                                    0.012490417054068,
                                    0.6988333663729542,
                                    0.2543597848162786,
                                ],
                                [
                                    0.03431643175669913,
                                    0.6988333663729542,
                                    0.012490417054068,
                                    0.2543597848162786,
                                ],
                                [
                                    0.03592976845047935,
                                    0.013077635687311018,
                                    0.6972200296791741,
                                    0.25377256618303556,
                                ],
                                [
                                    0.03651214463997505,
                                    0.7435477305203463,
                                    0.010294704170792084,
                                    0.20964542066888647,
                                ],
                                [
                                    0.03651214463997505,
                                    0.010294704170792084,
                                    0.7435477305203463,
                                    0.20964542066888647,
                                ],
                                [
                                    0.03592976845047935,
                                    0.6972200296791741,
                                    0.013077635687311018,
                                    0.25377256618303556,
                                ],
                                [
                                    0.03822870955365617,
                                    0.010778694584134193,
                                    0.7418311656066652,
                                    0.20916143025554437,
                                ],
                                [
                                    0.03822870955365617,
                                    0.7418311656066652,
                                    0.010778694584134193,
                                    0.20916143025554437,
                                ],
                                [
                                    0.027457239012541986,
                                    0.018945026109010225,
                                    0.5642647155217222,
                                    0.38933301935672565,
                                ],
                                [
                                    0.027457239012541986,
                                    0.5642647155217222,
                                    0.018945026109010225,
                                    0.38933301935672565,
                                ],
                                [
                                    0.0338627594128036,
                                    0.023364725816228494,
                                    0.5578591951214605,
                                    0.38491331964950737,
                                ],
                                [
                                    0.03816527372964648,
                                    0.7843220257517761,
                                    0.008236991391905727,
                                    0.16927570912667167,
                                ],
                                [
                                    0.03816527372964648,
                                    0.008236991391905727,
                                    0.7843220257517761,
                                    0.16927570912667167,
                                ],
                                [
                                    0.0338627594128036,
                                    0.5578591951214605,
                                    0.023364725816228494,
                                    0.38491331964950737,
                                ],
                                [
                                    0.04706887978213961,
                                    0.010158605446892486,
                                    0.775418419699283,
                                    0.16735409507168492,
                                ],
                                [
                                    0.04706887978213961,
                                    0.775418419699283,
                                    0.010158605446892486,
                                    0.16735409507168492,
                                ],
                                [
                                    0.017619242607117235,
                                    0.02819055676003922,
                                    0.3669980849193035,
                                    0.58719211571354,
                                ],
                                [
                                    0.017619242607117235,
                                    0.3669980849193035,
                                    0.02819055676003922,
                                    0.58719211571354,
                                ],
                                [
                                    0.026640456837914283,
                                    0.042624381044576214,
                                    0.3579768706885065,
                                    0.572758291429003,
                                ],
                                [
                                    0.04052414229069547,
                                    0.8440931852357253,
                                    0.00528565707646099,
                                    0.11009701539711823,
                                ],
                                [
                                    0.04052414229069547,
                                    0.00528565707646099,
                                    0.8440931852357253,
                                    0.11009701539711823,
                                ],
                                [
                                    0.026640456837914283,
                                    0.3579768706885065,
                                    0.042624381044576214,
                                    0.572758291429003,
                                ],
                                [
                                    0.061272875779159526,
                                    0.007991962103330964,
                                    0.8233444517472612,
                                    0.10739071037024826,
                                ],
                                [
                                    0.061272875779159526,
                                    0.8233444517472612,
                                    0.007991962103330964,
                                    0.10739071037024826,
                                ],
                                [
                                    0.008026650999850617,
                                    0.0371906826129102,
                                    0.16948604951872687,
                                    0.7852966168685124,
                                ],
                                [
                                    0.008026650999850617,
                                    0.16948604951872687,
                                    0.0371906826129102,
                                    0.7852966168685124,
                                ],
                                [
                                    0.01443217140011222,
                                    0.06687001913583668,
                                    0.16308052911846527,
                                    0.7556172803455858,
                                ],
                                [
                                    0.042809391023871934,
                                    0.903937964547547,
                                    0.0024079425888888775,
                                    0.05084470183969216,
                                ],
                                [
                                    0.042809391023871934,
                                    0.0024079425888888775,
                                    0.903937964547547,
                                    0.05084470183969216,
                                ],
                                [
                                    0.01443217140011222,
                                    0.16308052911846527,
                                    0.06687001913583668,
                                    0.7556172803455858,
                                ],
                                [
                                    0.07697263389207326,
                                    0.004329556643875633,
                                    0.8697747216793457,
                                    0.04892308778470541,
                                ],
                                [
                                    0.07697263389207326,
                                    0.8697747216793457,
                                    0.004329556643875633,
                                    0.04892308778470541,
                                ],
                                [
                                    0.001617061669325762,
                                    0.043195688254220016,
                                    0.03446779525386243,
                                    0.9207194548225918,
                                ],
                                [
                                    0.001617061669325762,
                                    0.03446779525386243,
                                    0.043195688254220016,
                                    0.9207194548225918,
                                ],
                                [
                                    0.003230398363105963,
                                    0.08629187326408466,
                                    0.03285445856008223,
                                    0.8776232698127272,
                                ],
                                [
                                    0.044327642042001944,
                                    0.9448471378505182,
                                    0.00048510788154383584,
                                    0.010340112225936057,
                                ],
                                [
                                    0.044327642042001944,
                                    0.00048510788154383584,
                                    0.9448471378505182,
                                    0.010340112225936057,
                                ],
                                [
                                    0.003230398363105963,
                                    0.03285445856008223,
                                    0.08629187326408466,
                                    0.8776232698127272,
                                ],
                                [
                                    0.08855317333230468,
                                    0.0009690982948859406,
                                    0.9006216065602154,
                                    0.009856121812593953,
                                ],
                                [
                                    0.08855317333230468,
                                    0.9006216065602154,
                                    0.0009690982948859406,
                                    0.009856121812593953,
                                ],
                                [
                                    0.022305567963745606,
                                    0.024501280847021526,
                                    0.45423939352092035,
                                    0.4989537576683125,
                                ],
                                [
                                    0.022305567963745606,
                                    0.45423939352092035,
                                    0.024501280847021526,
                                    0.4989537576683125,
                                ],
                                [
                                    0.02335423151730677,
                                    0.025653172620483597,
                                    0.4531907299673592,
                                    0.4978018658948504,
                                ],
                                [
                                    0.024501280847021526,
                                    0.4989537576683125,
                                    0.022305567963745606,
                                    0.45423939352092035,
                                ],
                                [
                                    0.024501280847021526,
                                    0.022305567963745606,
                                    0.4989537576683125,
                                    0.45423939352092035,
                                ],
                                [
                                    0.02335423151730677,
                                    0.4531907299673592,
                                    0.025653172620483597,
                                    0.4978018658948504,
                                ],
                                [
                                    0.025653172620483597,
                                    0.02335423151730677,
                                    0.4978018658948504,
                                    0.4531907299673592,
                                ],
                                [
                                    0.025653172620483597,
                                    0.4978018658948504,
                                    0.02335423151730677,
                                    0.4531907299673592,
                                ],
                                [
                                    0.017847115202223863,
                                    0.028555149919328348,
                                    0.366770212324197,
                                    0.5868275225542507,
                                ],
                                [
                                    0.017847115202223863,
                                    0.366770212324197,
                                    0.028555149919328348,
                                    0.5868275225542507,
                                ],
                                [
                                    0.02201068242984805,
                                    0.035216802799184044,
                                    0.3626066450965728,
                                    0.5801658696743951,
                                ],
                                [
                                    0.028555149919328355,
                                    0.5868275225542509,
                                    0.017847115202223856,
                                    0.3667702123241969,
                                ],
                                [
                                    0.028555149919328355,
                                    0.017847115202223856,
                                    0.5868275225542509,
                                    0.3667702123241969,
                                ],
                                [
                                    0.02201068242984805,
                                    0.3626066450965728,
                                    0.035216802799184044,
                                    0.5801658696743951,
                                ],
                                [
                                    0.03521680279918405,
                                    0.022010682429848043,
                                    0.5801658696743952,
                                    0.3626066450965727,
                                ],
                                [
                                    0.03521680279918405,
                                    0.5801658696743952,
                                    0.022010682429848043,
                                    0.3626066450965727,
                                ],
                                [
                                    0.011452449841789114,
                                    0.03435734952536734,
                                    0.23854755015821089,
                                    0.7156426504746327,
                                ],
                                [
                                    0.011452449841789114,
                                    0.23854755015821089,
                                    0.03435734952536734,
                                    0.7156426504746327,
                                ],
                                [
                                    0.017316209470622623,
                                    0.05194862841186787,
                                    0.23268379052937738,
                                    0.6980513715881321,
                                ],
                                [
                                    0.03435734952536734,
                                    0.7156426504746327,
                                    0.011452449841789114,
                                    0.23854755015821089,
                                ],
                                [
                                    0.03435734952536734,
                                    0.011452449841789114,
                                    0.7156426504746327,
                                    0.23854755015821089,
                                ],
                                [
                                    0.017316209470622623,
                                    0.23268379052937738,
                                    0.05194862841186787,
                                    0.6980513715881321,
                                ],
                                [
                                    0.05194862841186787,
                                    0.017316209470622623,
                                    0.6980513715881321,
                                    0.23268379052937738,
                                ],
                                [
                                    0.05194862841186787,
                                    0.6980513715881321,
                                    0.017316209470622623,
                                    0.23268379052937738,
                                ],
                                [
                                    0.005217296794369747,
                                    0.040000036818391066,
                                    0.1101653756792095,
                                    0.8446172907080297,
                                ],
                                [
                                    0.005217296794369747,
                                    0.1101653756792095,
                                    0.040000036818391066,
                                    0.8446172907080297,
                                ],
                                [
                                    0.009380864021993925,
                                    0.07192132651395497,
                                    0.10600180845158533,
                                    0.8126960010124658,
                                ],
                                [
                                    0.040000036818391066,
                                    0.8446172907080297,
                                    0.005217296794369747,
                                    0.1101653756792095,
                                ],
                                [
                                    0.040000036818391066,
                                    0.005217296794369747,
                                    0.8446172907080297,
                                    0.1101653756792095,
                                ],
                                [
                                    0.009380864021993925,
                                    0.10600180845158533,
                                    0.07192132651395497,
                                    0.8126960010124658,
                                ],
                                [
                                    0.07192132651395497,
                                    0.009380864021993925,
                                    0.8126960010124658,
                                    0.10600180845158533,
                                ],
                                [
                                    0.07192132651395497,
                                    0.8126960010124658,
                                    0.009380864021993925,
                                    0.10600180845158533,
                                ],
                                [
                                    0.0010510847754347987,
                                    0.04376166514811098,
                                    0.02240395373989924,
                                    0.932783296336555,
                                ],
                                [
                                    0.0010510847754347987,
                                    0.02240395373989924,
                                    0.04376166514811098,
                                    0.932783296336555,
                                ],
                                [
                                    0.0020997483289959514,
                                    0.08742252329819467,
                                    0.021355290186338086,
                                    0.8891224381864713,
                                ],
                                [
                                    0.04376166514811098,
                                    0.932783296336555,
                                    0.0010510847754347987,
                                    0.02240395373989924,
                                ],
                                [
                                    0.04376166514811098,
                                    0.0010510847754347987,
                                    0.932783296336555,
                                    0.02240395373989924,
                                ],
                                [
                                    0.0020997483289959514,
                                    0.021355290186338086,
                                    0.08742252329819467,
                                    0.8891224381864713,
                                ],
                                [
                                    0.08742252329819467,
                                    0.0020997483289959514,
                                    0.8891224381864713,
                                    0.021355290186338086,
                                ],
                                [
                                    0.08742252329819467,
                                    0.8891224381864713,
                                    0.0020997483289959514,
                                    0.021355290186338086,
                                ],
                                [
                                    0.010294704170792085,
                                    0.03651214463997505,
                                    0.20964542066888653,
                                    0.7435477305203463,
                                ],
                                [
                                    0.010294704170792085,
                                    0.20964542066888653,
                                    0.03651214463997505,
                                    0.7435477305203463,
                                ],
                                [
                                    0.010778694584134196,
                                    0.03822870955365617,
                                    0.20916143025554443,
                                    0.7418311656066652,
                                ],
                                [
                                    0.012490417054068005,
                                    0.2543597848162787,
                                    0.03431643175669913,
                                    0.6988333663729542,
                                ],
                                [
                                    0.012490417054068005,
                                    0.03431643175669913,
                                    0.2543597848162787,
                                    0.6988333663729542,
                                ],
                                [
                                    0.010778694584134196,
                                    0.20916143025554443,
                                    0.03822870955365617,
                                    0.7418311656066652,
                                ],
                                [
                                    0.013077635687311023,
                                    0.03592976845047934,
                                    0.2537725661830357,
                                    0.697220029679174,
                                ],
                                [
                                    0.013077635687311023,
                                    0.2537725661830357,
                                    0.03592976845047934,
                                    0.697220029679174,
                                ],
                                [
                                    0.008236991391905731,
                                    0.03816527372964648,
                                    0.16927570912667175,
                                    0.784322025751776,
                                ],
                                [
                                    0.008236991391905731,
                                    0.16927570912667175,
                                    0.03816527372964648,
                                    0.784322025751776,
                                ],
                                [
                                    0.010158605446892491,
                                    0.047068879782139604,
                                    0.167354095071685,
                                    0.7754184196992829,
                                ],
                                [
                                    0.018945026109010228,
                                    0.38933301935672576,
                                    0.027457239012541983,
                                    0.5642647155217221,
                                ],
                                [
                                    0.018945026109010228,
                                    0.027457239012541983,
                                    0.38933301935672576,
                                    0.5642647155217221,
                                ],
                                [
                                    0.010158605446892491,
                                    0.167354095071685,
                                    0.047068879782139604,
                                    0.7754184196992829,
                                ],
                                [
                                    0.0233647258162285,
                                    0.033862759412803596,
                                    0.3849133196495075,
                                    0.5578591951214604,
                                ],
                                [
                                    0.0233647258162285,
                                    0.3849133196495075,
                                    0.033862759412803596,
                                    0.5578591951214604,
                                ],
                                [
                                    0.005285657076460991,
                                    0.04052414229069547,
                                    0.11009701539711826,
                                    0.8440931852357253,
                                ],
                                [
                                    0.005285657076460991,
                                    0.11009701539711826,
                                    0.04052414229069547,
                                    0.8440931852357253,
                                ],
                                [
                                    0.007991962103330965,
                                    0.061272875779159526,
                                    0.10739071037024829,
                                    0.8233444517472612,
                                ],
                                [
                                    0.02819055676003922,
                                    0.58719211571354,
                                    0.017619242607117235,
                                    0.3669980849193035,
                                ],
                                [
                                    0.02819055676003922,
                                    0.017619242607117235,
                                    0.58719211571354,
                                    0.3669980849193035,
                                ],
                                [
                                    0.007991962103330965,
                                    0.10739071037024829,
                                    0.061272875779159526,
                                    0.8233444517472612,
                                ],
                                [
                                    0.042624381044576214,
                                    0.026640456837914283,
                                    0.572758291429003,
                                    0.3579768706885065,
                                ],
                                [
                                    0.042624381044576214,
                                    0.572758291429003,
                                    0.026640456837914283,
                                    0.3579768706885065,
                                ],
                                [
                                    0.002407942588888876,
                                    0.042809391023871934,
                                    0.05084470183969214,
                                    0.903937964547547,
                                ],
                                [
                                    0.002407942588888876,
                                    0.05084470183969214,
                                    0.042809391023871934,
                                    0.903937964547547,
                                ],
                                [
                                    0.004329556643875632,
                                    0.07697263389207326,
                                    0.04892308778470539,
                                    0.8697747216793457,
                                ],
                                [
                                    0.0371906826129102,
                                    0.7852966168685124,
                                    0.008026650999850615,
                                    0.16948604951872684,
                                ],
                                [
                                    0.0371906826129102,
                                    0.008026650999850615,
                                    0.7852966168685124,
                                    0.16948604951872684,
                                ],
                                [
                                    0.004329556643875632,
                                    0.04892308778470539,
                                    0.07697263389207326,
                                    0.8697747216793457,
                                ],
                                [
                                    0.06687001913583668,
                                    0.014432171400112218,
                                    0.7556172803455858,
                                    0.16308052911846524,
                                ],
                                [
                                    0.06687001913583668,
                                    0.7556172803455858,
                                    0.014432171400112218,
                                    0.16308052911846524,
                                ],
                                [
                                    0.00048510788154383535,
                                    0.044327642042001944,
                                    0.010340112225936048,
                                    0.9448471378505182,
                                ],
                                [
                                    0.00048510788154383535,
                                    0.010340112225936048,
                                    0.044327642042001944,
                                    0.9448471378505182,
                                ],
                                [
                                    0.0009690982948859397,
                                    0.08855317333230468,
                                    0.009856121812593942,
                                    0.9006216065602154,
                                ],
                                [
                                    0.043195688254220016,
                                    0.9207194548225918,
                                    0.0016170616693257614,
                                    0.03446779525386241,
                                ],
                                [
                                    0.043195688254220016,
                                    0.0016170616693257614,
                                    0.9207194548225918,
                                    0.03446779525386241,
                                ],
                                [
                                    0.0009690982948859397,
                                    0.009856121812593942,
                                    0.08855317333230468,
                                    0.9006216065602154,
                                ],
                                [
                                    0.08629187326408466,
                                    0.0032303983631059617,
                                    0.8776232698127272,
                                    0.03285445856008221,
                                ],
                                [
                                    0.08629187326408466,
                                    0.8776232698127272,
                                    0.0032303983631059617,
                                    0.03285445856008221,
                                ],
                                [
                                    0.002092711822784216,
                                    0.04471413698798292,
                                    0.042616809880860626,
                                    0.9105763413083723,
                                ],
                                [
                                    0.002092711822784216,
                                    0.042616809880860626,
                                    0.04471413698798292,
                                    0.9105763413083723,
                                ],
                                [
                                    0.0021910975989378324,
                                    0.046816306538852534,
                                    0.042518424104707006,
                                    0.9084741717575027,
                                ],
                                [
                                    0.0042884247060601365,
                                    0.08733117402825277,
                                    0.042518424104707,
                                    0.8658619771609801,
                                ],
                                [
                                    0.0042884247060601365,
                                    0.042518424104707,
                                    0.08733117402825277,
                                    0.8658619771609801,
                                ],
                                [
                                    0.0021910975989378324,
                                    0.042518424104707006,
                                    0.046816306538852534,
                                    0.9084741717575027,
                                ],
                                [
                                    0.00449003870211466,
                                    0.04451736543567571,
                                    0.08712956003219825,
                                    0.8638630358300113,
                                ],
                                [
                                    0.00449003870211466,
                                    0.08712956003219825,
                                    0.04451736543567571,
                                    0.8638630358300113,
                                ],
                                [
                                    0.0016744190978230573,
                                    0.04472784602372915,
                                    0.03441043782536513,
                                    0.9191872970530827,
                                ],
                                [
                                    0.0016744190978230573,
                                    0.03441043782536513,
                                    0.04472784602372915,
                                    0.9191872970530827,
                                ],
                                [
                                    0.002065045616563489,
                                    0.055162439612468604,
                                    0.0340198113066247,
                                    0.9087527034643432,
                                ],
                                [
                                    0.012382453814927554,
                                    0.25446774805541916,
                                    0.03401981130662465,
                                    0.6991299868230286,
                                ],
                                [
                                    0.012382453814927554,
                                    0.03401981130662465,
                                    0.25446774805541916,
                                    0.6991299868230286,
                                ],
                                [
                                    0.002065045616563489,
                                    0.0340198113066247,
                                    0.055162439612468604,
                                    0.9087527034643432,
                                ],
                                [
                                    0.015271165985899497,
                                    0.041956319243132596,
                                    0.2515790358844472,
                                    0.6911934788865207,
                                ],
                                [
                                    0.015271165985899497,
                                    0.2515790358844472,
                                    0.041956319243132596,
                                    0.6911934788865207,
                                ],
                                [
                                    0.0010744706085363794,
                                    0.044735328758620074,
                                    0.02238056790679766,
                                    0.9318096327260459,
                                ],
                                [
                                    0.0010744706085363794,
                                    0.02238056790679766,
                                    0.044735328758620074,
                                    0.9318096327260459,
                                ],
                                [
                                    0.0016246094402921827,
                                    0.06764022844219832,
                                    0.021830429075041853,
                                    0.9089047330424677,
                                ],
                                [
                                    0.023979370292114607,
                                    0.4994756682232194,
                                    0.02183042907504185,
                                    0.4547145324096241,
                                ],
                                [
                                    0.023979370292114607,
                                    0.02183042907504185,
                                    0.4994756682232194,
                                    0.4547145324096241,
                                ],
                                [
                                    0.0016246094402921827,
                                    0.021830429075041853,
                                    0.06764022844219832,
                                    0.9089047330424677,
                                ],
                                [
                                    0.03625702838153743,
                                    0.03300780950095306,
                                    0.4871980101337966,
                                    0.4435371519837129,
                                ],
                                [
                                    0.03625702838153743,
                                    0.4871980101337966,
                                    0.03300780950095306,
                                    0.4435371519837129,
                                ],
                                [
                                    0.0004894875890314843,
                                    0.044727846023729326,
                                    0.010335732518448399,
                                    0.9444469338687908,
                                ],
                                [
                                    0.0004894875890314843,
                                    0.010335732518448399,
                                    0.044727846023729326,
                                    0.9444469338687908,
                                ],
                                [
                                    0.0008801141077719145,
                                    0.08042207642817698,
                                    0.009945105999707968,
                                    0.9087527034643431,
                                ],
                                [
                                    0.035272227613052806,
                                    0.7447876475472686,
                                    0.00994510599970801,
                                    0.2099950188399706,
                                ],
                                [
                                    0.035272227613052806,
                                    0.00994510599970801,
                                    0.7447876475472686,
                                    0.2099950188399706,
                                ],
                                [
                                    0.0008801141077719145,
                                    0.009945105999707968,
                                    0.08042207642817698,
                                    0.9087527034643431,
                                ],
                                [
                                    0.06342057659973295,
                                    0.017881613936215936,
                                    0.7166392985605884,
                                    0.2020585109034627,
                                ],
                                [
                                    0.06342057659973295,
                                    0.7166392985605884,
                                    0.017881613936215936,
                                    0.2020585109034627,
                                ],
                                [
                                    9.861293556281873e-05,
                                    0.04471413698798296,
                                    0.002101942391460416,
                                    0.9530853076849938,
                                ],
                                [
                                    9.861293556281873e-05,
                                    0.002101942391460416,
                                    0.04471413698798296,
                                    0.9530853076849938,
                                ],
                                [
                                    0.0001969987117164353,
                                    0.08932527291547418,
                                    0.0020035566153067995,
                                    0.9084741717575026,
                                ],
                                [
                                    0.042809193308239,
                                    0.9124812849881162,
                                    0.0020035566153067796,
                                    0.04270596508833808,
                                ],
                                [
                                    0.042809193308239,
                                    0.0020035566153067796,
                                    0.9124812849881162,
                                    0.04270596508833808,
                                ],
                                [
                                    0.0001969987117164353,
                                    0.0020035566153067995,
                                    0.08932527291547418,
                                    0.9084741717575026,
                                ],
                                [
                                    0.08551977368091515,
                                    0.004002497946275469,
                                    0.86977070461544,
                                    0.04070702375736939,
                                ],
                                [
                                    0.08551977368091515,
                                    0.86977070461544,
                                    0.004002497946275469,
                                    0.04070702375736939,
                                ],
                                [
                                    0.8563960752699128,
                                    0.0863764395010551,
                                    0.05198432599577435,
                                    0.005243159233257733,
                                ],
                                [
                                    0.8563960752699128,
                                    0.05198432599577435,
                                    0.0863764395010551,
                                    0.005243159233257733,
                                ],
                                [
                                    0.8662294930549348,
                                    0.08736824182351302,
                                    0.042150908210752396,
                                    0.004251356910799813,
                                ],
                                [
                                    0.9006216065602155,
                                    0.05466887173613966,
                                    0.04215090821075239,
                                    0.0025586134928924226,
                                ],
                                [
                                    0.9006216065602155,
                                    0.04215090821075239,
                                    0.05466887173613966,
                                    0.0025586134928924226,
                                ],
                                [
                                    0.8662294930549348,
                                    0.042150908210752396,
                                    0.08736824182351302,
                                    0.004251356910799813,
                                ],
                                [
                                    0.9109628362543533,
                                    0.04263489862409449,
                                    0.04432764204200188,
                                    0.002074623079550319,
                                ],
                                [
                                    0.9109628362543533,
                                    0.04432764204200188,
                                    0.04263489862409449,
                                    0.002074623079550319,
                                ],
                                [
                                    0.6615469901033324,
                                    0.24078837408965006,
                                    0.07160280802632103,
                                    0.02606182778069651,
                                ],
                                [
                                    0.6615469901033324,
                                    0.07160280802632103,
                                    0.24078837408965006,
                                    0.02606182778069651,
                                ],
                                [
                                    0.7005891556160168,
                                    0.2549988530055467,
                                    0.032560642513636634,
                                    0.011851348864799875,
                                ],
                                [
                                    0.8697747216793458,
                                    0.09414042139746602,
                                    0.03256064251363663,
                                    0.0035242144095515046,
                                ],
                                [
                                    0.8697747216793458,
                                    0.03256064251363663,
                                    0.09414042139746602,
                                    0.0035242144095515046,
                                ],
                                [
                                    0.7005891556160168,
                                    0.032560642513636634,
                                    0.2549988530055467,
                                    0.011851348864799875,
                                ],
                                [
                                    0.92110575205294,
                                    0.03448225656862339,
                                    0.04280939102387176,
                                    0.0016026003545647465,
                                ],
                                [
                                    0.92110575205294,
                                    0.04280939102387176,
                                    0.03448225656862339,
                                    0.0016026003545647465,
                                ],
                                [
                                    0.401784521472515,
                                    0.44133533907697775,
                                    0.07476044001215103,
                                    0.08211969943835627,
                                ],
                                [
                                    0.401784521472515,
                                    0.07476044001215103,
                                    0.44133533907697775,
                                    0.08211969943835627,
                                ],
                                [
                                    0.4567695526824345,
                                    0.5017329803406373,
                                    0.019775408802231387,
                                    0.02172205817469669,
                                ],
                                [
                                    0.8233444517472613,
                                    0.15320050973740468,
                                    0.01977540880223139,
                                    0.003679629713102619,
                                ],
                                [
                                    0.8233444517472613,
                                    0.01977540880223139,
                                    0.15320050973740468,
                                    0.003679629713102619,
                                ],
                                [
                                    0.4567695526824345,
                                    0.019775408802231387,
                                    0.5017329803406373,
                                    0.02172205817469669,
                                ],
                                [
                                    0.9360208191939705,
                                    0.022481713829101357,
                                    0.040524142290695425,
                                    0.0009733246862326492,
                                ],
                                [
                                    0.9360208191939705,
                                    0.040524142290695425,
                                    0.022481713829101357,
                                    0.0009733246862326492,
                                ],
                                [
                                    0.17241202212027426,
                                    0.6114923347857286,
                                    0.047528102719404344,
                                    0.1685675403745927,
                                ],
                                [
                                    0.17241202212027426,
                                    0.047528102719404344,
                                    0.6114923347857286,
                                    0.1685675403745927,
                                ],
                                [
                                    0.21145418763295867,
                                    0.7499628697916217,
                                    0.00848593720671995,
                                    0.030097005368699702,
                                ],
                                [
                                    0.7754184196992829,
                                    0.2137563601932371,
                                    0.00848593720671995,
                                    0.002339282900759933,
                                ],
                                [
                                    0.7754184196992829,
                                    0.00848593720671995,
                                    0.2137563601932371,
                                    0.002339282900759933,
                                ],
                                [
                                    0.21145418763295867,
                                    0.00848593720671995,
                                    0.7499628697916217,
                                    0.030097005368699702,
                                ],
                                [
                                    0.9510095061628737,
                                    0.01040755126170671,
                                    0.038165273729646475,
                                    0.0004176688457731745,
                                ],
                                [
                                    0.9510095061628737,
                                    0.038165273729646475,
                                    0.01040755126170671,
                                    0.0004176688457731745,
                                ],
                                [
                                    0.03324006319727069,
                                    0.7102271431307468,
                                    0.011469458506374146,
                                    0.24506333516560835,
                                ],
                                [
                                    0.03324006319727069,
                                    0.011469458506374146,
                                    0.7102271431307468,
                                    0.24506333516560835,
                                ],
                                [
                                    0.043073480982292654,
                                    0.9203338501854034,
                                    0.0016360407213521818,
                                    0.03495662811095177,
                                ],
                                [
                                    0.7418311656066653,
                                    0.2559682790663115,
                                    0.0016360407213521825,
                                    0.000564514605671027,
                                ],
                                [
                                    0.7418311656066653,
                                    0.0016360407213521825,
                                    0.2559682790663115,
                                    0.000564514605671027,
                                ],
                                [
                                    0.043073480982292654,
                                    0.0016360407213521818,
                                    0.9203338501854034,
                                    0.03495662811095177,
                                ],
                                [
                                    0.9612873000330018,
                                    0.002120031134694287,
                                    0.036512144639975035,
                                    8.052419232892265e-05,
                                ],
                                [
                                    0.9612873000330018,
                                    0.036512144639975035,
                                    0.002120031134694287,
                                    8.052419232892265e-05,
                                ],
                                [
                                    0.6911934788865208,
                                    0.2515790358844471,
                                    0.04195631924313259,
                                    0.015271165985899487,
                                ],
                                [
                                    0.6911934788865208,
                                    0.04195631924313259,
                                    0.2515790358844471,
                                    0.015271165985899487,
                                ],
                                [
                                    0.6991299868230287,
                                    0.25446774805541905,
                                    0.03401981130662465,
                                    0.012382453814927547,
                                ],
                                [
                                    0.7354190101768234,
                                    0.0446408649834979,
                                    0.2073535045941444,
                                    0.012586620245534176,
                                ],
                                [
                                    0.7354190101768234,
                                    0.2073535045941444,
                                    0.0446408649834979,
                                    0.012586620245534176,
                                ],
                                [
                                    0.6991299868230287,
                                    0.03401981130662465,
                                    0.25446774805541905,
                                    0.012382453814927547,
                                ],
                                [
                                    0.7438633300224472,
                                    0.2097344048560005,
                                    0.036196545137874146,
                                    0.010205719983678054,
                                ],
                                [
                                    0.7438633300224472,
                                    0.036196545137874146,
                                    0.2097344048560005,
                                    0.010205719983678054,
                                ],
                                [
                                    0.5339316453456586,
                                    0.3684037188473238,
                                    0.0577903091886055,
                                    0.03987432661841204,
                                ],
                                [
                                    0.5339316453456586,
                                    0.0577903091886055,
                                    0.3684037188473238,
                                    0.03987432661841204,
                                ],
                                [
                                    0.5654424041910567,
                                    0.39014560443050667,
                                    0.02627955034320734,
                                    0.01813244103522917,
                                ],
                                [
                                    0.7421593769216721,
                                    0.0803279225597505,
                                    0.16017598727131035,
                                    0.017336713247267033,
                                ],
                                [
                                    0.7421593769216721,
                                    0.16017598727131035,
                                    0.0803279225597505,
                                    0.017336713247267033,
                                ],
                                [
                                    0.5654424041910567,
                                    0.02627955034320734,
                                    0.39014560443050667,
                                    0.01813244103522917,
                                ],
                                [
                                    0.7859590006279802,
                                    0.16962900799358335,
                                    0.03652829885344247,
                                    0.00788369252499404,
                                ],
                                [
                                    0.7859590006279802,
                                    0.03652829885344247,
                                    0.16962900799358335,
                                    0.00788369252499404,
                                ],
                                [
                                    0.32427850754899445,
                                    0.5188413530004983,
                                    0.06033881997742633,
                                    0.09654131947308098,
                                ],
                                [
                                    0.32427850754899445,
                                    0.06033881997742633,
                                    0.5188413530004983,
                                    0.09654131947308098,
                                ],
                                [
                                    0.36865668267863877,
                                    0.5898458503444332,
                                    0.015960644847781976,
                                    0.0255368221291461,
                                ],
                                [
                                    0.7458384378237408,
                                    0.13877888970268,
                                    0.09728142272575191,
                                    0.018101249747827317,
                                ],
                                [
                                    0.7458384378237408,
                                    0.09728142272575191,
                                    0.13877888970268,
                                    0.018101249747827317,
                                ],
                                [
                                    0.36865668267863877,
                                    0.015960644847781976,
                                    0.5898458503444332,
                                    0.0255368221291461,
                                ],
                                [
                                    0.8479079491901746,
                                    0.11059458383289715,
                                    0.03670937833624601,
                                    0.004788088640682062,
                                ],
                                [
                                    0.8479079491901746,
                                    0.03670937833624601,
                                    0.11059458383289715,
                                    0.004788088640682062,
                                ],
                                [
                                    0.13915297934266338,
                                    0.6447513775633396,
                                    0.0383597211759141,
                                    0.17773592191808293,
                                ],
                                [
                                    0.13915297934266338,
                                    0.0383597211759141,
                                    0.6447513775633396,
                                    0.17773592191808293,
                                ],
                                [
                                    0.17066373818806155,
                                    0.7907533192365188,
                                    0.006848962330515941,
                                    0.03173398024490371,
                                ],
                                [
                                    0.7421593769216721,
                                    0.20458797864974687,
                                    0.04174497998433086,
                                    0.011507664444250179,
                                ],
                                [
                                    0.7421593769216721,
                                    0.04174497998433086,
                                    0.20458797864974687,
                                    0.011507664444250179,
                                ],
                                [
                                    0.17066373818806155,
                                    0.006848962330515941,
                                    0.7907533192365188,
                                    0.03173398024490371,
                                ],
                                [
                                    0.9102190567179765,
                                    0.05119800070660386,
                                    0.03652829885344247,
                                    0.0020546437219771834,
                                ],
                                [
                                    0.9102190567179765,
                                    0.03652829885344247,
                                    0.05119800070660386,
                                    0.0020546437219771834,
                                ],
                                [
                                    0.026827907767428945,
                                    0.7166392985605885,
                                    0.009256949155759246,
                                    0.24727584451622325,
                                ],
                                [
                                    0.026827907767428945,
                                    0.009256949155759246,
                                    0.7166392985605885,
                                    0.24727584451622325,
                                ],
                                [
                                    0.034764415703936895,
                                    0.9286429154637592,
                                    0.0013204412192512963,
                                    0.03527222761305266,
                                ],
                                [
                                    0.7354190101768235,
                                    0.2537557697156966,
                                    0.008048196151193957,
                                    0.002777023956285936,
                                ],
                                [
                                    0.7354190101768235,
                                    0.008048196151193957,
                                    0.2537557697156966,
                                    0.002777023956285936,
                                ],
                                [
                                    0.034764415703936895,
                                    0.0013204412192512963,
                                    0.9286429154637592,
                                    0.03527222761305266,
                                ],
                                [
                                    0.9529782347546459,
                                    0.010429096413050084,
                                    0.036196545137874146,
                                    0.00039612369442980957,
                                ],
                                [
                                    0.9529782347546459,
                                    0.036196545137874146,
                                    0.010429096413050084,
                                    0.00039612369442980957,
                                ],
                                [
                                    0.4492734917403326,
                                    0.4934990230306353,
                                    0.027271469744333383,
                                    0.029956015484698697,
                                ],
                                [
                                    0.4492734917403326,
                                    0.027271469744333383,
                                    0.4934990230306353,
                                    0.029956015484698697,
                                ],
                                [
                                    0.4544321958395146,
                                    0.4991655390389332,
                                    0.022112765645151355,
                                    0.02428949947640085,
                                ],
                                [
                                    0.4934990230306353,
                                    0.029956015484698697,
                                    0.4492734917403326,
                                    0.027271469744333383,
                                ],
                                [
                                    0.4934990230306353,
                                    0.4492734917403326,
                                    0.029956015484698697,
                                    0.027271469744333383,
                                ],
                                [
                                    0.4544321958395146,
                                    0.022112765645151355,
                                    0.4991655390389332,
                                    0.02428949947640085,
                                ],
                                [
                                    0.4991655390389332,
                                    0.4544321958395146,
                                    0.02428949947640085,
                                    0.022112765645151355,
                                ],
                                [
                                    0.4991655390389332,
                                    0.02428949947640085,
                                    0.4544321958395146,
                                    0.022112765645151355,
                                ],
                                [
                                    0.3470538163084846,
                                    0.5552815478844979,
                                    0.037563511217936274,
                                    0.06010112458908126,
                                ],
                                [
                                    0.3470538163084846,
                                    0.037563511217936274,
                                    0.5552815478844979,
                                    0.06010112458908126,
                                ],
                                [
                                    0.36753570609232017,
                                    0.5880523025292433,
                                    0.017081621434100695,
                                    0.027330369944335815,
                                ],
                                [
                                    0.5552815478844979,
                                    0.060101124589081276,
                                    0.3470538163084845,
                                    0.03756351121793626,
                                ],
                                [
                                    0.5552815478844979,
                                    0.3470538163084845,
                                    0.060101124589081276,
                                    0.03756351121793626,
                                ],
                                [
                                    0.36753570609232017,
                                    0.017081621434100695,
                                    0.5880523025292433,
                                    0.027330369944335815,
                                ],
                                [
                                    0.5880523025292435,
                                    0.36753570609232006,
                                    0.02733036994433582,
                                    0.017081621434100688,
                                ],
                                [
                                    0.5880523025292435,
                                    0.02733036994433582,
                                    0.36753570609232006,
                                    0.017081621434100688,
                                ],
                                [
                                    0.21077996513737318,
                                    0.6323398954121195,
                                    0.039220034862626825,
                                    0.11766010458788048,
                                ],
                                [
                                    0.21077996513737318,
                                    0.039220034862626825,
                                    0.6323398954121195,
                                    0.11766010458788048,
                                ],
                                [
                                    0.23962563325576797,
                                    0.7188768997673038,
                                    0.01037436674423202,
                                    0.031123100232696058,
                                ],
                                [
                                    0.6323398954121195,
                                    0.11766010458788048,
                                    0.21077996513737318,
                                    0.039220034862626825,
                                ],
                                [
                                    0.6323398954121195,
                                    0.21077996513737318,
                                    0.11766010458788048,
                                    0.039220034862626825,
                                ],
                                [
                                    0.23962563325576797,
                                    0.01037436674423202,
                                    0.7188768997673038,
                                    0.031123100232696058,
                                ],
                                [
                                    0.7188768997673038,
                                    0.23962563325576797,
                                    0.031123100232696058,
                                    0.01037436674423202,
                                ],
                                [
                                    0.7188768997673038,
                                    0.031123100232696058,
                                    0.23962563325576797,
                                    0.01037436674423202,
                                ],
                                [
                                    0.0904489796634971,
                                    0.6934553772425058,
                                    0.024933692810082137,
                                    0.1911619502839149,
                                ],
                                [
                                    0.0904489796634971,
                                    0.024933692810082137,
                                    0.6934553772425058,
                                    0.1911619502839149,
                                ],
                                [
                                    0.1109308694473327,
                                    0.8504861879772477,
                                    0.004451803026246562,
                                    0.03413113954917309,
                                ],
                                [
                                    0.6934553772425058,
                                    0.1911619502839149,
                                    0.0904489796634971,
                                    0.024933692810082137,
                                ],
                                [
                                    0.6934553772425058,
                                    0.0904489796634971,
                                    0.1911619502839149,
                                    0.024933692810082137,
                                ],
                                [
                                    0.1109308694473327,
                                    0.004451803026246562,
                                    0.8504861879772477,
                                    0.03413113954917309,
                                ],
                                [
                                    0.8504861879772477,
                                    0.1109308694473327,
                                    0.03413113954917309,
                                    0.004451803026246562,
                                ],
                                [
                                    0.8504861879772477,
                                    0.03413113954917309,
                                    0.1109308694473327,
                                    0.004451803026246562,
                                ],
                                [
                                    0.017438051959311446,
                                    0.726029154368706,
                                    0.006016986556022589,
                                    0.25051580711595994,
                                ],
                                [
                                    0.017438051959311446,
                                    0.006016986556022589,
                                    0.726029154368706,
                                    0.25051580711595994,
                                ],
                                [
                                    0.022596756058493483,
                                    0.9408105751092025,
                                    0.0008582824568405527,
                                    0.0357343863754634,
                                ],
                                [
                                    0.726029154368706,
                                    0.25051580711595994,
                                    0.017438051959311446,
                                    0.006016986556022589,
                                ],
                                [
                                    0.726029154368706,
                                    0.017438051959311446,
                                    0.25051580711595994,
                                    0.006016986556022589,
                                ],
                                [
                                    0.022596756058493483,
                                    0.0008582824568405527,
                                    0.9408105751092025,
                                    0.0357343863754634,
                                ],
                                [
                                    0.9408105751092025,
                                    0.022596756058493483,
                                    0.0357343863754634,
                                    0.0008582824568405527,
                                ],
                                [
                                    0.9408105751092025,
                                    0.0357343863754634,
                                    0.022596756058493483,
                                    0.0008582824568405527,
                                ],
                                [
                                    0.20735350459414445,
                                    0.7354190101768234,
                                    0.01258662024553418,
                                    0.0446408649834979,
                                ],
                                [
                                    0.20735350459414445,
                                    0.01258662024553418,
                                    0.7354190101768234,
                                    0.0446408649834979,
                                ],
                                [
                                    0.20973440485600056,
                                    0.7438633300224472,
                                    0.010205719983678056,
                                    0.036196545137874146,
                                ],
                                [
                                    0.2515790358844472,
                                    0.015271165985899494,
                                    0.6911934788865207,
                                    0.04195631924313258,
                                ],
                                [
                                    0.2515790358844472,
                                    0.6911934788865207,
                                    0.015271165985899494,
                                    0.04195631924313258,
                                ],
                                [
                                    0.20973440485600056,
                                    0.010205719983678056,
                                    0.7438633300224472,
                                    0.036196545137874146,
                                ],
                                [
                                    0.25446774805541916,
                                    0.6991299868230286,
                                    0.012382453814927552,
                                    0.03401981130662465,
                                ],
                                [
                                    0.25446774805541916,
                                    0.012382453814927552,
                                    0.6991299868230286,
                                    0.03401981130662465,
                                ],
                                [
                                    0.16017598727131044,
                                    0.742159376921672,
                                    0.017336713247267044,
                                    0.08032792255975049,
                                ],
                                [
                                    0.16017598727131044,
                                    0.017336713247267044,
                                    0.742159376921672,
                                    0.08032792255975049,
                                ],
                                [
                                    0.16962900799358344,
                                    0.7859590006279801,
                                    0.007883692524994046,
                                    0.03652829885344246,
                                ],
                                [
                                    0.3684037188473239,
                                    0.03987432661841205,
                                    0.5339316453456585,
                                    0.05779030918860548,
                                ],
                                [
                                    0.3684037188473239,
                                    0.5339316453456585,
                                    0.03987432661841205,
                                    0.05779030918860548,
                                ],
                                [
                                    0.16962900799358344,
                                    0.007883692524994046,
                                    0.7859590006279801,
                                    0.03652829885344246,
                                ],
                                [
                                    0.3901456044305068,
                                    0.5654424041910566,
                                    0.018132441035229176,
                                    0.026279550343207333,
                                ],
                                [
                                    0.3901456044305068,
                                    0.018132441035229176,
                                    0.5654424041910566,
                                    0.026279550343207333,
                                ],
                                [
                                    0.09728142272575194,
                                    0.7458384378237408,
                                    0.018101249747827324,
                                    0.13877888970268,
                                ],
                                [
                                    0.09728142272575194,
                                    0.018101249747827324,
                                    0.7458384378237408,
                                    0.13877888970268,
                                ],
                                [
                                    0.11059458383289718,
                                    0.8479079491901746,
                                    0.004788088640682063,
                                    0.03670937833624601,
                                ],
                                [
                                    0.5188413530004983,
                                    0.09654131947308098,
                                    0.32427850754899445,
                                    0.06033881997742633,
                                ],
                                [
                                    0.5188413530004983,
                                    0.32427850754899445,
                                    0.09654131947308098,
                                    0.06033881997742633,
                                ],
                                [
                                    0.11059458383289718,
                                    0.004788088640682063,
                                    0.8479079491901746,
                                    0.03670937833624601,
                                ],
                                [
                                    0.5898458503444332,
                                    0.36865668267863877,
                                    0.0255368221291461,
                                    0.015960644847781976,
                                ],
                                [
                                    0.5898458503444332,
                                    0.0255368221291461,
                                    0.36865668267863877,
                                    0.015960644847781976,
                                ],
                                [
                                    0.04174497998433084,
                                    0.7421593769216721,
                                    0.011507664444250174,
                                    0.20458797864974687,
                                ],
                                [
                                    0.04174497998433084,
                                    0.011507664444250174,
                                    0.7421593769216721,
                                    0.20458797864974687,
                                ],
                                [
                                    0.05119800070660384,
                                    0.9102190567179765,
                                    0.0020546437219771826,
                                    0.03652829885344247,
                                ],
                                [
                                    0.6447513775633396,
                                    0.17773592191808293,
                                    0.13915297934266335,
                                    0.038359721175914095,
                                ],
                                [
                                    0.6447513775633396,
                                    0.13915297934266335,
                                    0.17773592191808293,
                                    0.038359721175914095,
                                ],
                                [
                                    0.05119800070660384,
                                    0.0020546437219771826,
                                    0.9102190567179765,
                                    0.03652829885344247,
                                ],
                                [
                                    0.7907533192365188,
                                    0.17066373818806152,
                                    0.03173398024490371,
                                    0.00684896233051594,
                                ],
                                [
                                    0.7907533192365188,
                                    0.03173398024490371,
                                    0.17066373818806152,
                                    0.00684896233051594,
                                ],
                                [
                                    0.008048196151193949,
                                    0.7354190101768235,
                                    0.002777023956285933,
                                    0.2537557697156966,
                                ],
                                [
                                    0.008048196151193949,
                                    0.002777023956285933,
                                    0.7354190101768235,
                                    0.2537557697156966,
                                ],
                                [
                                    0.010429096413050074,
                                    0.9529782347546459,
                                    0.0003961236944298092,
                                    0.036196545137874146,
                                ],
                                [
                                    0.7166392985605885,
                                    0.24727584451622325,
                                    0.026827907767428934,
                                    0.009256949155759243,
                                ],
                                [
                                    0.7166392985605885,
                                    0.026827907767428934,
                                    0.24727584451622325,
                                    0.009256949155759243,
                                ],
                                [
                                    0.010429096413050074,
                                    0.0003961236944298092,
                                    0.9529782347546459,
                                    0.036196545137874146,
                                ],
                                [
                                    0.9286429154637592,
                                    0.03476441570393688,
                                    0.03527222761305266,
                                    0.0013204412192512956,
                                ],
                                [
                                    0.9286429154637592,
                                    0.03527222761305266,
                                    0.03476441570393688,
                                    0.0013204412192512956,
                                ],
                                [
                                    0.042150908210752416,
                                    0.9006216065602155,
                                    0.0025586134928924243,
                                    0.05466887173613966,
                                ],
                                [
                                    0.042150908210752416,
                                    0.0025586134928924243,
                                    0.9006216065602155,
                                    0.05466887173613966,
                                ],
                                [
                                    0.04263489862409452,
                                    0.9109628362543533,
                                    0.00207462307955032,
                                    0.04432764204200188,
                                ],
                                [
                                    0.08637643950105517,
                                    0.0052431592332577385,
                                    0.8563960752699127,
                                    0.05198432599577434,
                                ],
                                [
                                    0.08637643950105517,
                                    0.8563960752699127,
                                    0.0052431592332577385,
                                    0.05198432599577434,
                                ],
                                [
                                    0.04263489862409452,
                                    0.00207462307955032,
                                    0.9109628362543533,
                                    0.04432764204200188,
                                ],
                                [
                                    0.08736824182351309,
                                    0.8662294930549347,
                                    0.004251356910799816,
                                    0.04215090821075239,
                                ],
                                [
                                    0.08736824182351309,
                                    0.004251356910799816,
                                    0.8662294930549347,
                                    0.04215090821075239,
                                ],
                                [
                                    0.03256064251363668,
                                    0.8697747216793458,
                                    0.0035242144095515102,
                                    0.09414042139746602,
                                ],
                                [
                                    0.03256064251363668,
                                    0.0035242144095515102,
                                    0.8697747216793458,
                                    0.09414042139746602,
                                ],
                                [
                                    0.03448225656862344,
                                    0.92110575205294,
                                    0.001602600354564749,
                                    0.04280939102387176,
                                ],
                                [
                                    0.24078837408965018,
                                    0.02606182778069652,
                                    0.6615469901033323,
                                    0.07160280802632102,
                                ],
                                [
                                    0.24078837408965018,
                                    0.6615469901033323,
                                    0.02606182778069652,
                                    0.07160280802632102,
                                ],
                                [
                                    0.03448225656862344,
                                    0.001602600354564749,
                                    0.92110575205294,
                                    0.04280939102387176,
                                ],
                                [
                                    0.2549988530055468,
                                    0.7005891556160166,
                                    0.011851348864799879,
                                    0.03256064251363663,
                                ],
                                [
                                    0.2549988530055468,
                                    0.011851348864799879,
                                    0.7005891556160166,
                                    0.03256064251363663,
                                ],
                                [
                                    0.019775408802231415,
                                    0.8233444517472613,
                                    0.003679629713102623,
                                    0.15320050973740468,
                                ],
                                [
                                    0.019775408802231415,
                                    0.003679629713102623,
                                    0.8233444517472613,
                                    0.15320050973740468,
                                ],
                                [
                                    0.022481713829101385,
                                    0.9360208191939705,
                                    0.0009733246862326504,
                                    0.040524142290695425,
                                ],
                                [
                                    0.44133533907697775,
                                    0.08211969943835627,
                                    0.401784521472515,
                                    0.07476044001215103,
                                ],
                                [
                                    0.44133533907697775,
                                    0.401784521472515,
                                    0.08211969943835627,
                                    0.07476044001215103,
                                ],
                                [
                                    0.022481713829101385,
                                    0.0009733246862326504,
                                    0.9360208191939705,
                                    0.040524142290695425,
                                ],
                                [
                                    0.5017329803406373,
                                    0.4567695526824345,
                                    0.02172205817469669,
                                    0.019775408802231387,
                                ],
                                [
                                    0.5017329803406373,
                                    0.02172205817469669,
                                    0.4567695526824345,
                                    0.019775408802231387,
                                ],
                                [
                                    0.00848593720671995,
                                    0.7754184196992829,
                                    0.002339282900759933,
                                    0.2137563601932371,
                                ],
                                [
                                    0.00848593720671995,
                                    0.002339282900759933,
                                    0.7754184196992829,
                                    0.2137563601932371,
                                ],
                                [
                                    0.01040755126170671,
                                    0.9510095061628737,
                                    0.0004176688457731745,
                                    0.038165273729646475,
                                ],
                                [
                                    0.6114923347857286,
                                    0.1685675403745927,
                                    0.17241202212027426,
                                    0.047528102719404344,
                                ],
                                [
                                    0.6114923347857286,
                                    0.17241202212027426,
                                    0.1685675403745927,
                                    0.047528102719404344,
                                ],
                                [
                                    0.01040755126170671,
                                    0.0004176688457731745,
                                    0.9510095061628737,
                                    0.038165273729646475,
                                ],
                                [
                                    0.7499628697916217,
                                    0.21145418763295867,
                                    0.030097005368699702,
                                    0.00848593720671995,
                                ],
                                [
                                    0.7499628697916217,
                                    0.030097005368699702,
                                    0.21145418763295867,
                                    0.00848593720671995,
                                ],
                                [
                                    0.0016360407213522011,
                                    0.7418311656066653,
                                    0.0005645146056710335,
                                    0.2559682790663115,
                                ],
                                [
                                    0.0016360407213522011,
                                    0.0005645146056710335,
                                    0.7418311656066653,
                                    0.2559682790663115,
                                ],
                                [
                                    0.0021200311346943113,
                                    0.9612873000330018,
                                    8.052419232892357e-05,
                                    0.036512144639975035,
                                ],
                                [
                                    0.7102271431307468,
                                    0.24506333516560835,
                                    0.03324006319727071,
                                    0.011469458506374151,
                                ],
                                [
                                    0.7102271431307468,
                                    0.03324006319727071,
                                    0.24506333516560835,
                                    0.011469458506374151,
                                ],
                                [
                                    0.0021200311346943113,
                                    8.052419232892357e-05,
                                    0.9612873000330018,
                                    0.036512144639975035,
                                ],
                                [
                                    0.9203338501854034,
                                    0.043073480982292675,
                                    0.03495662811095177,
                                    0.0016360407213521825,
                                ],
                                [
                                    0.9203338501854034,
                                    0.03495662811095177,
                                    0.043073480982292675,
                                    0.0016360407213521825,
                                ],
                                [
                                    0.6911934788865208,
                                    0.06971404171107236,
                                    0.21718692237916637,
                                    0.021905557023240468,
                                ],
                                [
                                    0.6911934788865208,
                                    0.21718692237916637,
                                    0.06971404171107236,
                                    0.021905557023240468,
                                ],
                                [
                                    0.7010268966715427,
                                    0.07070584403353028,
                                    0.2073535045941444,
                                    0.020913754700782546,
                                ],
                                [
                                    0.7268877092909685,
                                    0.22840276900538667,
                                    0.03401981130662465,
                                    0.010689710397020158,
                                ],
                                [
                                    0.7268877092909685,
                                    0.03401981130662465,
                                    0.22840276900538667,
                                    0.010689710397020158,
                                ],
                                [
                                    0.7010268966715427,
                                    0.2073535045941444,
                                    0.07070584403353028,
                                    0.020913754700782546,
                                ],
                                [
                                    0.7372289389851062,
                                    0.034503801719966753,
                                    0.2180615393112489,
                                    0.010205719983678054,
                                ],
                                [
                                    0.7372289389851062,
                                    0.2180615393112489,
                                    0.034503801719966753,
                                    0.010205719983678054,
                                ],
                                [
                                    0.5339316453456586,
                                    0.19433923013951174,
                                    0.1992181527839948,
                                    0.07251097173083483,
                                ],
                                [
                                    0.5339316453456586,
                                    0.1992181527839948,
                                    0.19433923013951174,
                                    0.07251097173083483,
                                ],
                                [
                                    0.5729738108583431,
                                    0.2085497090554084,
                                    0.16017598727131038,
                                    0.05830049281493818,
                                ],
                                [
                                    0.7019913251419629,
                                    0.2619238179348488,
                                    0.026279550343207333,
                                    0.009805306579980801,
                                ],
                                [
                                    0.7019913251419629,
                                    0.026279550343207333,
                                    0.2619238179348488,
                                    0.009805306579980801,
                                ],
                                [
                                    0.5729738108583431,
                                    0.16017598727131038,
                                    0.2085497090554084,
                                    0.05830049281493818,
                                ],
                                [
                                    0.7533223555155574,
                                    0.028201164398194097,
                                    0.21059278756125452,
                                    0.00788369252499404,
                                ],
                                [
                                    0.7533223555155574,
                                    0.21059278756125452,
                                    0.028201164398194097,
                                    0.00788369252499404,
                                ],
                                [
                                    0.32427850754899445,
                                    0.3561997972445584,
                                    0.15226645393567154,
                                    0.1672552412707756,
                                ],
                                [
                                    0.32427850754899445,
                                    0.15226645393567154,
                                    0.3561997972445584,
                                    0.1672552412707756,
                                ],
                                [
                                    0.3792635387589141,
                                    0.416597438508218,
                                    0.0972814227257519,
                                    0.10685760000711604,
                                ],
                                [
                                    0.6645176599457708,
                                    0.3120273015388951,
                                    0.015960644847781976,
                                    0.007494393667552031,
                                ],
                                [
                                    0.6645176599457708,
                                    0.015960644847781976,
                                    0.3120273015388951,
                                    0.007494393667552031,
                                ],
                                [
                                    0.3792635387589141,
                                    0.0972814227257519,
                                    0.416597438508218,
                                    0.10685760000711604,
                                ],
                                [
                                    0.7771940273924801,
                                    0.018666949874651947,
                                    0.19935093409218588,
                                    0.004788088640682062,
                                ],
                                [
                                    0.7771940273924801,
                                    0.19935093409218588,
                                    0.018666949874651947,
                                    0.004788088640682062,
                                ],
                                [
                                    0.13915297934266335,
                                    0.49353275475927194,
                                    0.08078714549701525,
                                    0.28652712040104944,
                                ],
                                [
                                    0.13915297934266335,
                                    0.08078714549701525,
                                    0.49353275475927194,
                                    0.28652712040104944,
                                ],
                                [
                                    0.17819514485534776,
                                    0.632003289765165,
                                    0.04174497998433086,
                                    0.14805658539515645,
                                ],
                                [
                                    0.6258367717714194,
                                    0.3633380081211008,
                                    0.00684896233051594,
                                    0.003976257776963942,
                                ],
                                [
                                    0.6258367717714194,
                                    0.00684896233051594,
                                    0.3633380081211008,
                                    0.003976257776963942,
                                ],
                                [
                                    0.17819514485534776,
                                    0.04174497998433086,
                                    0.632003289765165,
                                    0.14805658539515645,
                                ],
                                [
                                    0.80142785823501,
                                    0.008770576385502698,
                                    0.1877469216575101,
                                    0.0020546437219771834,
                                ],
                                [
                                    0.80142785823501,
                                    0.1877469216575101,
                                    0.008770576385502698,
                                    0.0020546437219771834,
                                ],
                                [
                                    0.02682790776742892,
                                    0.5732211812220835,
                                    0.01788161393621592,
                                    0.3820692970742716,
                                ],
                                [
                                    0.02682790776742892,
                                    0.01788161393621592,
                                    0.5732211812220835,
                                    0.3820692970742716,
                                ],
                                [
                                    0.036661325552450885,
                                    0.7833278882767402,
                                    0.008048196151193952,
                                    0.17196259001961497,
                                ],
                                [
                                    0.5987286477702611,
                                    0.3990707969027156,
                                    0.0013204412192512956,
                                    0.000880114107771914,
                                ],
                                [
                                    0.5987286477702611,
                                    0.0013204412192512956,
                                    0.3990707969027156,
                                    0.000880114107771914,
                                ],
                                [
                                    0.036661325552450885,
                                    0.008048196151193952,
                                    0.7833278882767402,
                                    0.17196259001961497,
                                ],
                                [
                                    0.8181847821965976,
                                    0.0018044316325934002,
                                    0.1796146624763791,
                                    0.0003961236944298095,
                                ],
                                [
                                    0.8181847821965976,
                                    0.1796146624763791,
                                    0.0018044316325934002,
                                    0.0003961236944298095,
                                ],
                                [
                                    0.5578591951214605,
                                    0.20304832547613264,
                                    0.17529060300819288,
                                    0.06380187639421395,
                                ],
                                [
                                    0.5578591951214605,
                                    0.17529060300819288,
                                    0.20304832547613264,
                                    0.06380187639421395,
                                ],
                                [
                                    0.5657957030579684,
                                    0.20593703764710458,
                                    0.16735409507168494,
                                    0.060913164223242,
                                ],
                                [
                                    0.5935534255259082,
                                    0.18650644963441318,
                                    0.16735409507168492,
                                    0.05258602976799363,
                                ],
                                [
                                    0.5935534255259082,
                                    0.16735409507168492,
                                    0.18650644963441318,
                                    0.05258602976799363,
                                ],
                                [
                                    0.5657957030579684,
                                    0.16735409507168494,
                                    0.20593703764710458,
                                    0.060913164223242,
                                ],
                                [
                                    0.601997745371532,
                                    0.16973499533354106,
                                    0.17806212978878944,
                                    0.05020512950613751,
                                ],
                                [
                                    0.601997745371532,
                                    0.17806212978878944,
                                    0.16973499533354106,
                                    0.05020512950613751,
                                ],
                                [
                                    0.4309338658724647,
                                    0.29733700961270565,
                                    0.16078808866179942,
                                    0.11094103585303021,
                                ],
                                [
                                    0.4309338658724647,
                                    0.16078808866179942,
                                    0.29733700961270565,
                                    0.11094103585303021,
                                ],
                                [
                                    0.4624446247178629,
                                    0.31907889519588856,
                                    0.12927732981640125,
                                    0.08919915026984733,
                                ],
                                [
                                    0.5989935456687692,
                                    0.22349375381265343,
                                    0.12927732981640122,
                                    0.04823537070217618,
                                ],
                                [
                                    0.5989935456687692,
                                    0.12927732981640122,
                                    0.22349375381265343,
                                    0.04823537070217618,
                                ],
                                [
                                    0.4624446247178629,
                                    0.12927732981640125,
                                    0.31907889519588856,
                                    0.08919915026984733,
                                ],
                                [
                                    0.6427931693750772,
                                    0.13873035053867422,
                                    0.17969413010634538,
                                    0.03878234997990318,
                                ],
                                [
                                    0.6427931693750772,
                                    0.17969413010634538,
                                    0.13873035053867422,
                                    0.03878234997990318,
                                ],
                                [
                                    0.2617237470294055,
                                    0.4187545577641474,
                                    0.12289358049701526,
                                    0.19662811470943187,
                                ],
                                [
                                    0.2617237470294055,
                                    0.12289358049701526,
                                    0.4187545577641474,
                                    0.19662811470943187,
                                ],
                                [
                                    0.30610192215904986,
                                    0.48975905510808226,
                                    0.07851540536737092,
                                    0.12562361736549701,
                                ],
                                [
                                    0.601962899426182,
                                    0.28265442810023883,
                                    0.07851540536737092,
                                    0.0368672671062083,
                                ],
                                [
                                    0.601962899426182,
                                    0.07851540536737092,
                                    0.28265442810023883,
                                    0.0368672671062083,
                                ],
                                [
                                    0.30610192215904986,
                                    0.07851540536737092,
                                    0.48975905510808226,
                                    0.12562361736549701,
                                ],
                                [
                                    0.7040324107926159,
                                    0.09182856647451619,
                                    0.1805849167338049,
                                    0.023554105999063043,
                                ],
                                [
                                    0.7040324107926159,
                                    0.1805849167338049,
                                    0.09182856647451619,
                                    0.023554105999063043,
                                ],
                                [
                                    0.11230975324001319,
                                    0.5203759808619222,
                                    0.0652029472785643,
                                    0.3021113186195004,
                                ],
                                [
                                    0.11230975324001319,
                                    0.0652029472785643,
                                    0.5203759808619222,
                                    0.3021113186195004,
                                ],
                                [
                                    0.14382051208541136,
                                    0.6663779225351013,
                                    0.03369218843316613,
                                    0.15610937694632118,
                                ],
                                [
                                    0.5989935456687692,
                                    0.3477538099026498,
                                    0.03369218843316613,
                                    0.01956045599541491,
                                ],
                                [
                                    0.5989935456687692,
                                    0.03369218843316613,
                                    0.3477538099026498,
                                    0.01956045599541491,
                                ],
                                [
                                    0.14382051208541136,
                                    0.03369218843316613,
                                    0.6663779225351013,
                                    0.15610937694632118,
                                ],
                                [
                                    0.7670532254650736,
                                    0.043145209155439124,
                                    0.17969413010634538,
                                    0.010107435273141915,
                                ],
                                [
                                    0.7670532254650736,
                                    0.17969413010634538,
                                    0.043145209155439124,
                                    0.010107435273141915,
                                ],
                                [
                                    0.021652685523075976,
                                    0.5783964034664365,
                                    0.014432171400112215,
                                    0.3855187396103753,
                                ],
                                [
                                    0.021652685523075976,
                                    0.014432171400112215,
                                    0.5783964034664365,
                                    0.3855187396103753,
                                ],
                                [
                                    0.02958919345958393,
                                    0.7904000203696072,
                                    0.006495663463604264,
                                    0.17351512270720468,
                                ],
                                [
                                    0.5935534255259082,
                                    0.3956213543666119,
                                    0.006495663463604262,
                                    0.004329556643875631,
                                ],
                                [
                                    0.5935534255259082,
                                    0.006495663463604262,
                                    0.3956213543666119,
                                    0.004329556643875631,
                                ],
                                [
                                    0.02958919345958393,
                                    0.006495663463604264,
                                    0.7904000203696072,
                                    0.17351512270720468,
                                ],
                                [
                                    0.8111126501037307,
                                    0.008876563725460388,
                                    0.17806212978878944,
                                    0.0019486563820195044,
                                ],
                                [
                                    0.8111126501037307,
                                    0.17806212978878944,
                                    0.008876563725460388,
                                    0.0019486563820195044,
                                ],
                                [
                                    0.3626066450965727,
                                    0.39830087550102045,
                                    0.11393831638809325,
                                    0.12515416301431356,
                                ],
                                [
                                    0.3626066450965727,
                                    0.11393831638809325,
                                    0.39830087550102045,
                                    0.12515416301431356,
                                ],
                                [
                                    0.3677653491957547,
                                    0.4039673915093183,
                                    0.10877961228891123,
                                    0.11948764700601572,
                                ],
                                [
                                    0.39830087550102045,
                                    0.12515416301431356,
                                    0.3626066450965727,
                                    0.11393831638809325,
                                ],
                                [
                                    0.39830087550102045,
                                    0.3626066450965727,
                                    0.12515416301431356,
                                    0.11393831638809325,
                                ],
                                [
                                    0.3677653491957547,
                                    0.10877961228891123,
                                    0.4039673915093183,
                                    0.11948764700601572,
                                ],
                                [
                                    0.4039673915093183,
                                    0.3677653491957547,
                                    0.11948764700601572,
                                    0.10877961228891123,
                                ],
                                [
                                    0.4039673915093183,
                                    0.11948764700601572,
                                    0.3677653491957547,
                                    0.10877961228891123,
                                ],
                                [
                                    0.280105597844433,
                                    0.4481652776407373,
                                    0.10451172968198781,
                                    0.1672173948328418,
                                ],
                                [
                                    0.280105597844433,
                                    0.10451172968198781,
                                    0.4481652776407373,
                                    0.1672173948328418,
                                ],
                                [
                                    0.30058748762826865,
                                    0.4809360322854828,
                                    0.08402983989815223,
                                    0.13444664018809632,
                                ],
                                [
                                    0.4481652776407374,
                                    0.16721739483284181,
                                    0.28010559784443295,
                                    0.10451172968198778,
                                ],
                                [
                                    0.4481652776407374,
                                    0.28010559784443295,
                                    0.16721739483284181,
                                    0.10451172968198778,
                                ],
                                [
                                    0.30058748762826865,
                                    0.08402983989815223,
                                    0.4809360322854828,
                                    0.13444664018809632,
                                ],
                                [
                                    0.48093603228548293,
                                    0.30058748762826853,
                                    0.13444664018809635,
                                    0.0840298398981522,
                                ],
                                [
                                    0.48093603228548293,
                                    0.13444664018809635,
                                    0.30058748762826853,
                                    0.0840298398981522,
                                ],
                                [
                                    0.17011957619838822,
                                    0.5103587285951646,
                                    0.07988042380161178,
                                    0.23964127140483535,
                                ],
                                [
                                    0.17011957619838822,
                                    0.07988042380161178,
                                    0.5103587285951646,
                                    0.23964127140483535,
                                ],
                                [
                                    0.19896524431678303,
                                    0.596895732950349,
                                    0.051034755683216984,
                                    0.15310426704965097,
                                ],
                                [
                                    0.5103587285951646,
                                    0.23964127140483535,
                                    0.17011957619838822,
                                    0.07988042380161178,
                                ],
                                [
                                    0.5103587285951646,
                                    0.17011957619838822,
                                    0.23964127140483535,
                                    0.07988042380161178,
                                ],
                                [
                                    0.19896524431678303,
                                    0.051034755683216984,
                                    0.596895732950349,
                                    0.15310426704965097,
                                ],
                                [
                                    0.596895732950349,
                                    0.19896524431678303,
                                    0.15310426704965097,
                                    0.051034755683216984,
                                ],
                                [
                                    0.596895732950349,
                                    0.15310426704965097,
                                    0.19896524431678303,
                                    0.051034755683216984,
                                ],
                                [
                                    0.07300097083658966,
                                    0.5596847632653457,
                                    0.0423817016369896,
                                    0.3249325642610751,
                                ],
                                [
                                    0.07300097083658966,
                                    0.0423817016369896,
                                    0.5596847632653457,
                                    0.3249325642610751,
                                ],
                                [
                                    0.09348286062042523,
                                    0.7167155740000875,
                                    0.02189981185315402,
                                    0.1679017535263333,
                                ],
                                [
                                    0.5596847632653457,
                                    0.3249325642610751,
                                    0.07300097083658966,
                                    0.0423817016369896,
                                ],
                                [
                                    0.5596847632653457,
                                    0.07300097083658966,
                                    0.3249325642610751,
                                    0.0423817016369896,
                                ],
                                [
                                    0.09348286062042523,
                                    0.02189981185315402,
                                    0.7167155740000875,
                                    0.1679017535263333,
                                ],
                                [
                                    0.7167155740000875,
                                    0.09348286062042523,
                                    0.1679017535263333,
                                    0.02189981185315402,
                                ],
                                [
                                    0.7167155740000875,
                                    0.1679017535263333,
                                    0.09348286062042523,
                                    0.02189981185315402,
                                ],
                                [
                                    0.014074174493340115,
                                    0.5859749144961723,
                                    0.009380864021993921,
                                    0.3905700469884936,
                                ],
                                [
                                    0.014074174493340115,
                                    0.009380864021993921,
                                    0.5859749144961723,
                                    0.3905700469884936,
                                ],
                                [
                                    0.019232878592522155,
                                    0.8007563352366689,
                                    0.004222159922811883,
                                    0.17578862624799704,
                                ],
                                [
                                    0.5859749144961723,
                                    0.3905700469884936,
                                    0.014074174493340115,
                                    0.009380864021993921,
                                ],
                                [
                                    0.5859749144961723,
                                    0.014074174493340115,
                                    0.3905700469884936,
                                    0.009380864021993921,
                                ],
                                [
                                    0.019232878592522155,
                                    0.004222159922811883,
                                    0.8007563352366689,
                                    0.17578862624799704,
                                ],
                                [
                                    0.8007563352366689,
                                    0.019232878592522155,
                                    0.17578862624799704,
                                    0.004222159922811883,
                                ],
                                [
                                    0.8007563352366689,
                                    0.17578862624799704,
                                    0.019232878592522155,
                                    0.004222159922811883,
                                ],
                                [
                                    0.16735409507168497,
                                    0.5935534255259082,
                                    0.05258602976799365,
                                    0.18650644963441318,
                                ],
                                [
                                    0.16735409507168497,
                                    0.05258602976799365,
                                    0.5935534255259082,
                                    0.18650644963441318,
                                ],
                                [
                                    0.16973499533354108,
                                    0.601997745371532,
                                    0.05020512950613752,
                                    0.17806212978878944,
                                ],
                                [
                                    0.20304832547613272,
                                    0.06380187639421397,
                                    0.5578591951214604,
                                    0.17529060300819285,
                                ],
                                [
                                    0.20304832547613272,
                                    0.5578591951214604,
                                    0.06380187639421397,
                                    0.17529060300819285,
                                ],
                                [
                                    0.16973499533354108,
                                    0.05020512950613752,
                                    0.601997745371532,
                                    0.17806212978878944,
                                ],
                                [
                                    0.20593703764710466,
                                    0.5657957030579683,
                                    0.06091316422324203,
                                    0.16735409507168492,
                                ],
                                [
                                    0.20593703764710466,
                                    0.06091316422324203,
                                    0.5657957030579683,
                                    0.16735409507168492,
                                ],
                                [
                                    0.12927732981640128,
                                    0.5989935456687691,
                                    0.0482353707021762,
                                    0.2234937538126534,
                                ],
                                [
                                    0.12927732981640128,
                                    0.0482353707021762,
                                    0.5989935456687691,
                                    0.2234937538126534,
                                ],
                                [
                                    0.1387303505386743,
                                    0.6427931693750771,
                                    0.0387823499799032,
                                    0.17969413010634536,
                                ],
                                [
                                    0.2973370096127057,
                                    0.11094103585303024,
                                    0.4309338658724646,
                                    0.16078808866179936,
                                ],
                                [
                                    0.2973370096127057,
                                    0.4309338658724646,
                                    0.11094103585303024,
                                    0.16078808866179936,
                                ],
                                [
                                    0.1387303505386743,
                                    0.0387823499799032,
                                    0.6427931693750771,
                                    0.17969413010634536,
                                ],
                                [
                                    0.31907889519588867,
                                    0.4624446247178628,
                                    0.08919915026984736,
                                    0.12927732981640122,
                                ],
                                [
                                    0.31907889519588867,
                                    0.08919915026984736,
                                    0.4624446247178628,
                                    0.12927732981640122,
                                ],
                                [
                                    0.07851540536737095,
                                    0.601962899426182,
                                    0.03686726710620831,
                                    0.28265442810023883,
                                ],
                                [
                                    0.07851540536737095,
                                    0.03686726710620831,
                                    0.601962899426182,
                                    0.28265442810023883,
                                ],
                                [
                                    0.0918285664745162,
                                    0.7040324107926159,
                                    0.02355410599906305,
                                    0.1805849167338049,
                                ],
                                [
                                    0.4187545577641474,
                                    0.19662811470943187,
                                    0.2617237470294055,
                                    0.12289358049701526,
                                ],
                                [
                                    0.4187545577641474,
                                    0.2617237470294055,
                                    0.19662811470943187,
                                    0.12289358049701526,
                                ],
                                [
                                    0.0918285664745162,
                                    0.02355410599906305,
                                    0.7040324107926159,
                                    0.1805849167338049,
                                ],
                                [
                                    0.48975905510808226,
                                    0.30610192215904986,
                                    0.12562361736549701,
                                    0.07851540536737092,
                                ],
                                [
                                    0.48975905510808226,
                                    0.12562361736549701,
                                    0.30610192215904986,
                                    0.07851540536737092,
                                ],
                                [
                                    0.03369218843316612,
                                    0.5989935456687692,
                                    0.019560455995414904,
                                    0.3477538099026498,
                                ],
                                [
                                    0.03369218843316612,
                                    0.019560455995414904,
                                    0.5989935456687692,
                                    0.3477538099026498,
                                ],
                                [
                                    0.04314520915543911,
                                    0.7670532254650736,
                                    0.010107435273141912,
                                    0.17969413010634538,
                                ],
                                [
                                    0.5203759808619222,
                                    0.3021113186195004,
                                    0.11230975324001316,
                                    0.0652029472785643,
                                ],
                                [
                                    0.5203759808619222,
                                    0.11230975324001316,
                                    0.3021113186195004,
                                    0.0652029472785643,
                                ],
                                [
                                    0.04314520915543911,
                                    0.010107435273141912,
                                    0.7670532254650736,
                                    0.17969413010634538,
                                ],
                                [
                                    0.6663779225351013,
                                    0.14382051208541133,
                                    0.15610937694632118,
                                    0.033692188433166126,
                                ],
                                [
                                    0.6663779225351013,
                                    0.15610937694632118,
                                    0.14382051208541133,
                                    0.033692188433166126,
                                ],
                                [
                                    0.006495663463604256,
                                    0.5935534255259082,
                                    0.0043295566438756265,
                                    0.3956213543666119,
                                ],
                                [
                                    0.006495663463604256,
                                    0.0043295566438756265,
                                    0.5935534255259082,
                                    0.3956213543666119,
                                ],
                                [
                                    0.00887656372546038,
                                    0.8111126501037307,
                                    0.0019486563820195024,
                                    0.17806212978878944,
                                ],
                                [
                                    0.5783964034664365,
                                    0.3855187396103753,
                                    0.02165268552307597,
                                    0.01443217140011221,
                                ],
                                [
                                    0.5783964034664365,
                                    0.02165268552307597,
                                    0.3855187396103753,
                                    0.01443217140011221,
                                ],
                                [
                                    0.00887656372546038,
                                    0.0019486563820195024,
                                    0.8111126501037307,
                                    0.17806212978878944,
                                ],
                                [
                                    0.7904000203696072,
                                    0.029589193459583916,
                                    0.17351512270720468,
                                    0.006495663463604261,
                                ],
                                [
                                    0.7904000203696072,
                                    0.17351512270720468,
                                    0.029589193459583916,
                                    0.006495663463604261,
                                ],
                                [
                                    0.034019811306624674,
                                    0.7268877092909685,
                                    0.010689710397020165,
                                    0.22840276900538667,
                                ],
                                [
                                    0.034019811306624674,
                                    0.010689710397020165,
                                    0.7268877092909685,
                                    0.22840276900538667,
                                ],
                                [
                                    0.034503801719966774,
                                    0.7372289389851062,
                                    0.010205719983678061,
                                    0.2180615393112489,
                                ],
                                [
                                    0.06971404171107243,
                                    0.02190555702324049,
                                    0.6911934788865207,
                                    0.21718692237916634,
                                ],
                                [
                                    0.06971404171107243,
                                    0.6911934788865207,
                                    0.02190555702324049,
                                    0.21718692237916634,
                                ],
                                [
                                    0.034503801719966774,
                                    0.010205719983678061,
                                    0.7372289389851062,
                                    0.2180615393112489,
                                ],
                                [
                                    0.07070584403353035,
                                    0.7010268966715427,
                                    0.020913754700782567,
                                    0.20735350459414437,
                                ],
                                [
                                    0.07070584403353035,
                                    0.020913754700782567,
                                    0.7010268966715427,
                                    0.20735350459414437,
                                ],
                                [
                                    0.026279550343207374,
                                    0.7019913251419629,
                                    0.009805306579980815,
                                    0.2619238179348488,
                                ],
                                [
                                    0.026279550343207374,
                                    0.009805306579980815,
                                    0.7019913251419629,
                                    0.2619238179348488,
                                ],
                                [
                                    0.028201164398194138,
                                    0.7533223555155574,
                                    0.007883692524994053,
                                    0.21059278756125452,
                                ],
                                [
                                    0.19433923013951182,
                                    0.07251097173083486,
                                    0.5339316453456585,
                                    0.19921815278399477,
                                ],
                                [
                                    0.19433923013951182,
                                    0.5339316453456585,
                                    0.07251097173083486,
                                    0.19921815278399477,
                                ],
                                [
                                    0.028201164398194138,
                                    0.007883692524994053,
                                    0.7533223555155574,
                                    0.21059278756125452,
                                ],
                                [
                                    0.20854970905540848,
                                    0.572973810858343,
                                    0.05830049281493821,
                                    0.16017598727131035,
                                ],
                                [
                                    0.20854970905540848,
                                    0.05830049281493821,
                                    0.572973810858343,
                                    0.16017598727131035,
                                ],
                                [
                                    0.015960644847781997,
                                    0.6645176599457708,
                                    0.007494393667552041,
                                    0.3120273015388951,
                                ],
                                [
                                    0.015960644847781997,
                                    0.007494393667552041,
                                    0.6645176599457708,
                                    0.3120273015388951,
                                ],
                                [
                                    0.01866694987465197,
                                    0.7771940273924801,
                                    0.0047880886406820675,
                                    0.19935093409218588,
                                ],
                                [
                                    0.3561997972445584,
                                    0.1672552412707756,
                                    0.32427850754899445,
                                    0.15226645393567154,
                                ],
                                [
                                    0.3561997972445584,
                                    0.32427850754899445,
                                    0.1672552412707756,
                                    0.15226645393567154,
                                ],
                                [
                                    0.01866694987465197,
                                    0.0047880886406820675,
                                    0.7771940273924801,
                                    0.19935093409218588,
                                ],
                                [
                                    0.416597438508218,
                                    0.3792635387589141,
                                    0.10685760000711604,
                                    0.0972814227257519,
                                ],
                                [
                                    0.416597438508218,
                                    0.10685760000711604,
                                    0.3792635387589141,
                                    0.0972814227257519,
                                ],
                                [
                                    0.00684896233051594,
                                    0.6258367717714194,
                                    0.003976257776963942,
                                    0.3633380081211008,
                                ],
                                [
                                    0.00684896233051594,
                                    0.003976257776963942,
                                    0.6258367717714194,
                                    0.3633380081211008,
                                ],
                                [
                                    0.008770576385502698,
                                    0.80142785823501,
                                    0.0020546437219771834,
                                    0.1877469216575101,
                                ],
                                [
                                    0.49353275475927194,
                                    0.28652712040104944,
                                    0.13915297934266335,
                                    0.08078714549701525,
                                ],
                                [
                                    0.49353275475927194,
                                    0.13915297934266335,
                                    0.28652712040104944,
                                    0.08078714549701525,
                                ],
                                [
                                    0.008770576385502698,
                                    0.0020546437219771834,
                                    0.80142785823501,
                                    0.1877469216575101,
                                ],
                                [
                                    0.632003289765165,
                                    0.17819514485534776,
                                    0.14805658539515645,
                                    0.04174497998433086,
                                ],
                                [
                                    0.632003289765165,
                                    0.14805658539515645,
                                    0.17819514485534776,
                                    0.04174497998433086,
                                ],
                                [
                                    0.0013204412192513108,
                                    0.5987286477702611,
                                    0.0008801141077719241,
                                    0.3990707969027156,
                                ],
                                [
                                    0.0013204412192513108,
                                    0.0008801141077719241,
                                    0.5987286477702611,
                                    0.3990707969027156,
                                ],
                                [
                                    0.0018044316325934208,
                                    0.8181847821965976,
                                    0.000396123694429814,
                                    0.1796146624763791,
                                ],
                                [
                                    0.5732211812220835,
                                    0.3820692970742716,
                                    0.026827907767428934,
                                    0.017881613936215925,
                                ],
                                [
                                    0.5732211812220835,
                                    0.026827907767428934,
                                    0.3820692970742716,
                                    0.017881613936215925,
                                ],
                                [
                                    0.0018044316325934208,
                                    0.000396123694429814,
                                    0.8181847821965976,
                                    0.1796146624763791,
                                ],
                                [
                                    0.7833278882767402,
                                    0.036661325552450906,
                                    0.17196259001961497,
                                    0.008048196151193955,
                                ],
                                [
                                    0.7833278882767402,
                                    0.17196259001961497,
                                    0.036661325552450906,
                                    0.008048196151193955,
                                ],
                                [
                                    0.4492734917403326,
                                    0.045313898205927454,
                                    0.4591069095253546,
                                    0.046305700528385375,
                                ],
                                [
                                    0.4492734917403326,
                                    0.4591069095253546,
                                    0.045313898205927454,
                                    0.046305700528385375,
                                ],
                                [
                                    0.4591069095253546,
                                    0.046305700528385375,
                                    0.4492734917403326,
                                    0.045313898205927454,
                                ],
                                [
                                    0.4724746243011087,
                                    0.48281585399524646,
                                    0.022112765645151352,
                                    0.02259675605849346,
                                ],
                                [
                                    0.4724746243011087,
                                    0.022112765645151352,
                                    0.48281585399524646,
                                    0.02259675605849346,
                                ],
                                [
                                    0.4591069095253546,
                                    0.4492734917403326,
                                    0.046305700528385375,
                                    0.045313898205927454,
                                ],
                                [
                                    0.48281585399524646,
                                    0.02259675605849346,
                                    0.4724746243011087,
                                    0.022112765645151352,
                                ],
                                [
                                    0.48281585399524646,
                                    0.4724746243011087,
                                    0.02259675605849346,
                                    0.022112765645151352,
                                ],
                                [
                                    0.34705381630848453,
                                    0.126319861477225,
                                    0.3860959818211689,
                                    0.1405303403931216,
                                ],
                                [
                                    0.34705381630848453,
                                    0.3860959818211689,
                                    0.126319861477225,
                                    0.1405303403931216,
                                ],
                                [
                                    0.3860959818211689,
                                    0.1405303403931216,
                                    0.34705381630848453,
                                    0.126319861477225,
                                ],
                                [
                                    0.4562920563516088,
                                    0.5076230867252031,
                                    0.017081621434100688,
                                    0.019003235489087448,
                                ],
                                [
                                    0.4562920563516088,
                                    0.017081621434100688,
                                    0.5076230867252031,
                                    0.019003235489087448,
                                ],
                                [
                                    0.3860959818211689,
                                    0.34705381630848453,
                                    0.1405303403931216,
                                    0.126319861477225,
                                ],
                                [
                                    0.5076230867252031,
                                    0.019003235489087448,
                                    0.4562920563516088,
                                    0.017081621434100688,
                                ],
                                [
                                    0.5076230867252031,
                                    0.4562920563516088,
                                    0.019003235489087448,
                                    0.017081621434100688,
                                ],
                                [
                                    0.21077996513737318,
                                    0.23152869862583725,
                                    0.2657649963472928,
                                    0.2919263398894968,
                                ],
                                [
                                    0.21077996513737318,
                                    0.2657649963472928,
                                    0.23152869862583725,
                                    0.2919263398894968,
                                ],
                                [
                                    0.26576499634729284,
                                    0.29192633988949684,
                                    0.21077996513737315,
                                    0.23152869862583722,
                                ],
                                [
                                    0.4319342970189784,
                                    0.5446106644656875,
                                    0.010374366744232021,
                                    0.013080671771101988,
                                ],
                                [
                                    0.4319342970189784,
                                    0.010374366744232021,
                                    0.5446106644656875,
                                    0.013080671771101988,
                                ],
                                [
                                    0.26576499634729284,
                                    0.21077996513737315,
                                    0.29192633988949684,
                                    0.23152869862583722,
                                ],
                                [
                                    0.5446106644656876,
                                    0.013080671771101992,
                                    0.43193429701897834,
                                    0.01037436674423202,
                                ],
                                [
                                    0.5446106644656876,
                                    0.43193429701897834,
                                    0.013080671771101992,
                                    0.01037436674423202,
                                ],
                                [
                                    0.0904489796634971,
                                    0.3207946700772142,
                                    0.12949114517618152,
                                    0.4592652050831072,
                                ],
                                [
                                    0.0904489796634971,
                                    0.12949114517618152,
                                    0.3207946700772142,
                                    0.4592652050831072,
                                ],
                                [
                                    0.12949114517618152,
                                    0.4592652050831072,
                                    0.09044897966349712,
                                    0.3207946700772142,
                                ],
                                [
                                    0.4067918467144647,
                                    0.5823829331780555,
                                    0.004451803026246561,
                                    0.006373417081233321,
                                ],
                                [
                                    0.4067918467144647,
                                    0.004451803026246561,
                                    0.5823829331780555,
                                    0.006373417081233321,
                                ],
                                [
                                    0.12949114517618152,
                                    0.09044897966349712,
                                    0.4592652050831072,
                                    0.3207946700772142,
                                ],
                                [
                                    0.5823829331780555,
                                    0.006373417081233321,
                                    0.4067918467144648,
                                    0.004451803026246562,
                                ],
                                [
                                    0.5823829331780555,
                                    0.4067918467144648,
                                    0.006373417081233321,
                                    0.004451803026246562,
                                ],
                                [
                                    0.017438051959311442,
                                    0.3725918856208494,
                                    0.027271469744333397,
                                    0.5826985926755058,
                                ],
                                [
                                    0.017438051959311442,
                                    0.027271469744333397,
                                    0.3725918856208494,
                                    0.5826985926755058,
                                ],
                                [
                                    0.027271469744333404,
                                    0.5826985926755059,
                                    0.017438051959311435,
                                    0.3725918856208493,
                                ],
                                [
                                    0.38917165512332025,
                                    0.6086277895496566,
                                    0.0008582824568405528,
                                    0.0013422728701826569,
                                ],
                                [
                                    0.38917165512332025,
                                    0.0008582824568405528,
                                    0.6086277895496566,
                                    0.0013422728701826569,
                                ],
                                [
                                    0.027271469744333404,
                                    0.017438051959311435,
                                    0.5826985926755059,
                                    0.3725918856208493,
                                ],
                                [
                                    0.6086277895496567,
                                    0.001342272870182657,
                                    0.38917165512332014,
                                    0.0008582824568405525,
                                ],
                                [
                                    0.6086277895496567,
                                    0.38917165512332014,
                                    0.001342272870182657,
                                    0.0008582824568405525,
                                ],
                                [
                                    0.36260664509657276,
                                    0.13198074484968733,
                                    0.37054315303308066,
                                    0.13486945702065925,
                                ],
                                [
                                    0.36260664509657276,
                                    0.37054315303308066,
                                    0.13198074484968733,
                                    0.13486945702065925,
                                ],
                                [
                                    0.37054315303308066,
                                    0.13486945702065925,
                                    0.36260664509657276,
                                    0.13198074484968733,
                                ],
                                [
                                    0.3858077776573488,
                                    0.3942520975029726,
                                    0.10877961228891123,
                                    0.11116051255076734,
                                ],
                                [
                                    0.3858077776573488,
                                    0.10877961228891123,
                                    0.3942520975029726,
                                    0.11116051255076734,
                                ],
                                [
                                    0.37054315303308066,
                                    0.36260664509657276,
                                    0.13486945702065925,
                                    0.13198074484968733,
                                ],
                                [
                                    0.3942520975029726,
                                    0.11116051255076734,
                                    0.3858077776573488,
                                    0.10877961228891123,
                                ],
                                [
                                    0.3942520975029726,
                                    0.3858077776573488,
                                    0.11116051255076734,
                                    0.10877961228891123,
                                ],
                                [
                                    0.280105597844433,
                                    0.1932680799412765,
                                    0.3116163566898311,
                                    0.21500996552445936,
                                ],
                                [
                                    0.280105597844433,
                                    0.3116163566898311,
                                    0.1932680799412765,
                                    0.21500996552445936,
                                ],
                                [
                                    0.3116163566898311,
                                    0.21500996552445936,
                                    0.280105597844433,
                                    0.1932680799412765,
                                ],
                                [
                                    0.3893438378875573,
                                    0.43314346159386535,
                                    0.0840298398981522,
                                    0.0934828606204252,
                                ],
                                [
                                    0.3893438378875573,
                                    0.0840298398981522,
                                    0.43314346159386535,
                                    0.0934828606204252,
                                ],
                                [
                                    0.3116163566898311,
                                    0.280105597844433,
                                    0.21500996552445936,
                                    0.1932680799412765,
                                ],
                                [
                                    0.43314346159386535,
                                    0.0934828606204252,
                                    0.3893438378875573,
                                    0.0840298398981522,
                                ],
                                [
                                    0.43314346159386535,
                                    0.3893438378875573,
                                    0.0934828606204252,
                                    0.0840298398981522,
                                ],
                                [
                                    0.17011957619838822,
                                    0.27218908756482224,
                                    0.21449775132803253,
                                    0.343193584908757,
                                ],
                                [
                                    0.17011957619838822,
                                    0.21449775132803253,
                                    0.27218908756482224,
                                    0.343193584908757,
                                ],
                                [
                                    0.2144977513280326,
                                    0.3431935849087571,
                                    0.1701195761983882,
                                    0.2721890875648222,
                                ],
                                [
                                    0.3912739080799934,
                                    0.49334341944642734,
                                    0.05103475568321699,
                                    0.06434791679036224,
                                ],
                                [
                                    0.3912739080799934,
                                    0.05103475568321699,
                                    0.49334341944642734,
                                    0.06434791679036224,
                                ],
                                [
                                    0.2144977513280326,
                                    0.1701195761983882,
                                    0.3431935849087571,
                                    0.2721890875648222,
                                ],
                                [
                                    0.4933434194464274,
                                    0.06434791679036225,
                                    0.3912739080799934,
                                    0.051034755683216984,
                                ],
                                [
                                    0.4933434194464274,
                                    0.3912739080799934,
                                    0.06434791679036225,
                                    0.051034755683216984,
                                ],
                                [
                                    0.07300097083658966,
                                    0.33824267890412163,
                                    0.10451172968198782,
                                    0.4842446205773009,
                                ],
                                [
                                    0.07300097083658966,
                                    0.10451172968198782,
                                    0.33824267890412163,
                                    0.4842446205773009,
                                ],
                                [
                                    0.10451172968198782,
                                    0.4842446205773009,
                                    0.07300097083658966,
                                    0.33824267890412163,
                                ],
                                [
                                    0.3893438378875572,
                                    0.5574035176838618,
                                    0.02189981185315402,
                                    0.03135283257542702,
                                ],
                                [
                                    0.3893438378875572,
                                    0.02189981185315402,
                                    0.5574035176838618,
                                    0.03135283257542702,
                                ],
                                [
                                    0.10451172968198782,
                                    0.07300097083658966,
                                    0.4842446205773009,
                                    0.33824267890412163,
                                ],
                                [
                                    0.5574035176838618,
                                    0.03135283257542702,
                                    0.3893438378875573,
                                    0.021899811853154025,
                                ],
                                [
                                    0.5574035176838618,
                                    0.3893438378875573,
                                    0.03135283257542702,
                                    0.021899811853154025,
                                ],
                                [
                                    0.014074174493340124,
                                    0.37595576308682066,
                                    0.022010682429848067,
                                    0.5879593799899911,
                                ],
                                [
                                    0.014074174493340124,
                                    0.022010682429848067,
                                    0.37595576308682066,
                                    0.5879593799899911,
                                ],
                                [
                                    0.02201068242984807,
                                    0.5879593799899913,
                                    0.014074174493340119,
                                    0.37595576308682055,
                                ],
                                [
                                    0.3858077776573489,
                                    0.6033670022351711,
                                    0.004222159922811885,
                                    0.006603060184668008,
                                ],
                                [
                                    0.3858077776573489,
                                    0.004222159922811885,
                                    0.6033670022351711,
                                    0.006603060184668008,
                                ],
                                [
                                    0.02201068242984807,
                                    0.014074174493340119,
                                    0.5879593799899913,
                                    0.37595576308682055,
                                ],
                                [
                                    0.6033670022351713,
                                    0.00660306018466801,
                                    0.3858077776573488,
                                    0.004222159922811883,
                                ],
                                [
                                    0.6033670022351713,
                                    0.3858077776573488,
                                    0.00660306018466801,
                                    0.004222159922811883,
                                ],
                                [
                                    0.23569312869274198,
                                    0.2588942612535181,
                                    0.240851832791924,
                                    0.2645607772618159,
                                ],
                                [
                                    0.23569312869274198,
                                    0.240851832791924,
                                    0.2588942612535181,
                                    0.2645607772618159,
                                ],
                                [
                                    0.240851832791924,
                                    0.2645607772618159,
                                    0.23569312869274198,
                                    0.2588942612535181,
                                ],
                                [
                                    0.2588942612535181,
                                    0.2645607772618159,
                                    0.23569312869274198,
                                    0.240851832791924,
                                ],
                                [
                                    0.2588942612535181,
                                    0.23569312869274198,
                                    0.2645607772618159,
                                    0.240851832791924,
                                ],
                                [
                                    0.240851832791924,
                                    0.23569312869274198,
                                    0.2645607772618159,
                                    0.2588942612535181,
                                ],
                                [
                                    0.2645607772618159,
                                    0.240851832791924,
                                    0.2588942612535181,
                                    0.23569312869274198,
                                ],
                                [
                                    0.2645607772618159,
                                    0.2588942612535181,
                                    0.240851832791924,
                                    0.23569312869274198,
                                ],
                                [
                                    0.18206771887129264,
                                    0.29130595891441685,
                                    0.20254960865512822,
                                    0.3240767135591623,
                                ],
                                [
                                    0.18206771887129264,
                                    0.20254960865512822,
                                    0.29130595891441685,
                                    0.3240767135591623,
                                ],
                                [
                                    0.20254960865512822,
                                    0.3240767135591623,
                                    0.18206771887129264,
                                    0.29130595891441685,
                                ],
                                [
                                    0.2913059589144169,
                                    0.32407671355916234,
                                    0.18206771887129258,
                                    0.20254960865512817,
                                ],
                                [
                                    0.2913059589144169,
                                    0.18206771887129258,
                                    0.32407671355916234,
                                    0.20254960865512817,
                                ],
                                [
                                    0.20254960865512822,
                                    0.18206771887129264,
                                    0.3240767135591623,
                                    0.29130595891441685,
                                ],
                                [
                                    0.32407671355916234,
                                    0.20254960865512817,
                                    0.2913059589144169,
                                    0.18206771887129258,
                                ],
                                [
                                    0.32407671355916234,
                                    0.2913059589144169,
                                    0.20254960865512817,
                                    0.18206771887129258,
                                ],
                                [
                                    0.11057716594080261,
                                    0.33173149782240785,
                                    0.1394228340591974,
                                    0.41826850217759215,
                                ],
                                [
                                    0.11057716594080261,
                                    0.1394228340591974,
                                    0.33173149782240785,
                                    0.41826850217759215,
                                ],
                                [
                                    0.13942283405919742,
                                    0.41826850217759226,
                                    0.1105771659408026,
                                    0.3317314978224078,
                                ],
                                [
                                    0.33173149782240785,
                                    0.41826850217759215,
                                    0.11057716594080261,
                                    0.1394228340591974,
                                ],
                                [
                                    0.33173149782240785,
                                    0.11057716594080261,
                                    0.41826850217759215,
                                    0.1394228340591974,
                                ],
                                [
                                    0.13942283405919742,
                                    0.1105771659408026,
                                    0.41826850217759226,
                                    0.3317314978224078,
                                ],
                                [
                                    0.41826850217759226,
                                    0.13942283405919742,
                                    0.3317314978224078,
                                    0.1105771659408026,
                                ],
                                [
                                    0.41826850217759226,
                                    0.3317314978224078,
                                    0.13942283405919742,
                                    0.1105771659408026,
                                ],
                                [
                                    0.047450391344871834,
                                    0.3637932583958394,
                                    0.06793228112870742,
                                    0.5208240691305813,
                                ],
                                [
                                    0.047450391344871834,
                                    0.06793228112870742,
                                    0.3637932583958394,
                                    0.5208240691305813,
                                ],
                                [
                                    0.06793228112870742,
                                    0.5208240691305813,
                                    0.04745039134487184,
                                    0.3637932583958395,
                                ],
                                [
                                    0.3637932583958394,
                                    0.5208240691305813,
                                    0.047450391344871834,
                                    0.06793228112870742,
                                ],
                                [
                                    0.3637932583958394,
                                    0.047450391344871834,
                                    0.5208240691305813,
                                    0.06793228112870742,
                                ],
                                [
                                    0.06793228112870742,
                                    0.04745039134487184,
                                    0.5208240691305813,
                                    0.3637932583958395,
                                ],
                                [
                                    0.5208240691305813,
                                    0.06793228112870742,
                                    0.3637932583958395,
                                    0.04745039134487184,
                                ],
                                [
                                    0.5208240691305813,
                                    0.3637932583958395,
                                    0.06793228112870742,
                                    0.04745039134487184,
                                ],
                                [
                                    0.009148167208076001,
                                    0.3808817703720848,
                                    0.014306871307258036,
                                    0.5956631911125811,
                                ],
                                [
                                    0.009148167208076001,
                                    0.014306871307258036,
                                    0.3808817703720848,
                                    0.5956631911125811,
                                ],
                                [
                                    0.014306871307258037,
                                    0.5956631911125813,
                                    0.009148167208076,
                                    0.3808817703720847,
                                ],
                                [
                                    0.3808817703720848,
                                    0.5956631911125811,
                                    0.009148167208076001,
                                    0.014306871307258036,
                                ],
                                [
                                    0.3808817703720848,
                                    0.009148167208076001,
                                    0.5956631911125811,
                                    0.014306871307258036,
                                ],
                                [
                                    0.014306871307258037,
                                    0.009148167208076,
                                    0.5956631911125813,
                                    0.3808817703720847,
                                ],
                                [
                                    0.5956631911125813,
                                    0.014306871307258037,
                                    0.3808817703720847,
                                    0.009148167208076,
                                ],
                                [
                                    0.5956631911125813,
                                    0.3808817703720847,
                                    0.014306871307258037,
                                    0.009148167208076,
                                ],
                                [
                                    0.10877961228891125,
                                    0.3858077776573488,
                                    0.11116051255076737,
                                    0.3942520975029726,
                                ],
                                [
                                    0.10877961228891125,
                                    0.11116051255076737,
                                    0.3858077776573488,
                                    0.3942520975029726,
                                ],
                                [
                                    0.11116051255076737,
                                    0.3942520975029726,
                                    0.10877961228891125,
                                    0.3858077776573488,
                                ],
                                [
                                    0.1319807448496874,
                                    0.1348694570206593,
                                    0.3626066450965727,
                                    0.3705431530330806,
                                ],
                                [
                                    0.1319807448496874,
                                    0.3626066450965727,
                                    0.1348694570206593,
                                    0.3705431530330806,
                                ],
                                [
                                    0.11116051255076737,
                                    0.10877961228891125,
                                    0.3942520975029726,
                                    0.3858077776573488,
                                ],
                                [
                                    0.1348694570206593,
                                    0.3705431530330806,
                                    0.1319807448496874,
                                    0.3626066450965727,
                                ],
                                [
                                    0.1348694570206593,
                                    0.1319807448496874,
                                    0.3705431530330806,
                                    0.3626066450965727,
                                ],
                                [
                                    0.08402983989815224,
                                    0.3893438378875572,
                                    0.09348286062042524,
                                    0.4331434615938653,
                                ],
                                [
                                    0.08402983989815224,
                                    0.09348286062042524,
                                    0.3893438378875572,
                                    0.4331434615938653,
                                ],
                                [
                                    0.09348286062042524,
                                    0.4331434615938653,
                                    0.08402983989815224,
                                    0.3893438378875572,
                                ],
                                [
                                    0.19326807994127657,
                                    0.21500996552445942,
                                    0.28010559784443295,
                                    0.31161635668983106,
                                ],
                                [
                                    0.19326807994127657,
                                    0.28010559784443295,
                                    0.21500996552445942,
                                    0.31161635668983106,
                                ],
                                [
                                    0.09348286062042524,
                                    0.08402983989815224,
                                    0.4331434615938653,
                                    0.3893438378875572,
                                ],
                                [
                                    0.21500996552445942,
                                    0.31161635668983106,
                                    0.19326807994127657,
                                    0.28010559784443295,
                                ],
                                [
                                    0.21500996552445942,
                                    0.19326807994127657,
                                    0.31161635668983106,
                                    0.28010559784443295,
                                ],
                                [
                                    0.051034755683217,
                                    0.3912739080799934,
                                    0.06434791679036225,
                                    0.49334341944642734,
                                ],
                                [
                                    0.051034755683217,
                                    0.06434791679036225,
                                    0.3912739080799934,
                                    0.49334341944642734,
                                ],
                                [
                                    0.06434791679036227,
                                    0.4933434194464274,
                                    0.05103475568321699,
                                    0.3912739080799934,
                                ],
                                [
                                    0.27218908756482224,
                                    0.343193584908757,
                                    0.17011957619838822,
                                    0.21449775132803253,
                                ],
                                [
                                    0.27218908756482224,
                                    0.17011957619838822,
                                    0.343193584908757,
                                    0.21449775132803253,
                                ],
                                [
                                    0.06434791679036227,
                                    0.05103475568321699,
                                    0.4933434194464274,
                                    0.3912739080799934,
                                ],
                                [
                                    0.3431935849087571,
                                    0.2144977513280326,
                                    0.2721890875648222,
                                    0.1701195761983882,
                                ],
                                [
                                    0.3431935849087571,
                                    0.2721890875648222,
                                    0.2144977513280326,
                                    0.1701195761983882,
                                ],
                                [
                                    0.02189981185315401,
                                    0.3893438378875572,
                                    0.03135283257542701,
                                    0.5574035176838618,
                                ],
                                [
                                    0.02189981185315401,
                                    0.03135283257542701,
                                    0.3893438378875572,
                                    0.5574035176838618,
                                ],
                                [
                                    0.03135283257542701,
                                    0.5574035176838618,
                                    0.021899811853154014,
                                    0.3893438378875573,
                                ],
                                [
                                    0.33824267890412163,
                                    0.4842446205773009,
                                    0.07300097083658964,
                                    0.10451172968198781,
                                ],
                                [
                                    0.33824267890412163,
                                    0.07300097083658964,
                                    0.4842446205773009,
                                    0.10451172968198781,
                                ],
                                [
                                    0.03135283257542701,
                                    0.021899811853154014,
                                    0.5574035176838618,
                                    0.3893438378875573,
                                ],
                                [
                                    0.4842446205773009,
                                    0.10451172968198781,
                                    0.33824267890412163,
                                    0.07300097083658966,
                                ],
                                [
                                    0.4842446205773009,
                                    0.33824267890412163,
                                    0.10451172968198781,
                                    0.07300097083658966,
                                ],
                                [
                                    0.00422215992281188,
                                    0.3858077776573489,
                                    0.006603060184668002,
                                    0.6033670022351711,
                                ],
                                [
                                    0.00422215992281188,
                                    0.006603060184668002,
                                    0.3858077776573489,
                                    0.6033670022351711,
                                ],
                                [
                                    0.006603060184668004,
                                    0.6033670022351713,
                                    0.004222159922811879,
                                    0.3858077776573488,
                                ],
                                [
                                    0.37595576308682066,
                                    0.5879593799899911,
                                    0.014074174493340119,
                                    0.02201068242984806,
                                ],
                                [
                                    0.37595576308682066,
                                    0.014074174493340119,
                                    0.5879593799899911,
                                    0.02201068242984806,
                                ],
                                [
                                    0.006603060184668004,
                                    0.004222159922811879,
                                    0.6033670022351713,
                                    0.3858077776573488,
                                ],
                                [
                                    0.5879593799899913,
                                    0.022010682429848064,
                                    0.37595576308682055,
                                    0.014074174493340114,
                                ],
                                [
                                    0.5879593799899913,
                                    0.37595576308682055,
                                    0.022010682429848064,
                                    0.014074174493340114,
                                ],
                                [
                                    0.022112765645151366,
                                    0.4724746243011087,
                                    0.022596756058493473,
                                    0.48281585399524646,
                                ],
                                [
                                    0.022112765645151366,
                                    0.022596756058493473,
                                    0.4724746243011087,
                                    0.48281585399524646,
                                ],
                                [
                                    0.022596756058493473,
                                    0.48281585399524646,
                                    0.022112765645151366,
                                    0.4724746243011087,
                                ],
                                [
                                    0.045313898205927496,
                                    0.04630570052838542,
                                    0.44927349174033254,
                                    0.45910690952535455,
                                ],
                                [
                                    0.045313898205927496,
                                    0.44927349174033254,
                                    0.04630570052838542,
                                    0.45910690952535455,
                                ],
                                [
                                    0.022596756058493473,
                                    0.022112765645151366,
                                    0.48281585399524646,
                                    0.4724746243011087,
                                ],
                                [
                                    0.04630570052838542,
                                    0.45910690952535455,
                                    0.045313898205927496,
                                    0.44927349174033254,
                                ],
                                [
                                    0.04630570052838542,
                                    0.045313898205927496,
                                    0.45910690952535455,
                                    0.44927349174033254,
                                ],
                                [
                                    0.017081621434100715,
                                    0.4562920563516088,
                                    0.019003235489087476,
                                    0.5076230867252031,
                                ],
                                [
                                    0.017081621434100715,
                                    0.019003235489087476,
                                    0.4562920563516088,
                                    0.5076230867252031,
                                ],
                                [
                                    0.019003235489087476,
                                    0.5076230867252031,
                                    0.017081621434100715,
                                    0.4562920563516088,
                                ],
                                [
                                    0.12631986147722502,
                                    0.14053034039312168,
                                    0.3470538163084845,
                                    0.38609598182116883,
                                ],
                                [
                                    0.12631986147722502,
                                    0.3470538163084845,
                                    0.14053034039312168,
                                    0.38609598182116883,
                                ],
                                [
                                    0.019003235489087476,
                                    0.017081621434100715,
                                    0.5076230867252031,
                                    0.4562920563516088,
                                ],
                                [
                                    0.14053034039312168,
                                    0.38609598182116883,
                                    0.12631986147722502,
                                    0.3470538163084845,
                                ],
                                [
                                    0.14053034039312168,
                                    0.12631986147722502,
                                    0.38609598182116883,
                                    0.3470538163084845,
                                ],
                                [
                                    0.010374366744232033,
                                    0.4319342970189784,
                                    0.013080671771102004,
                                    0.5446106644656875,
                                ],
                                [
                                    0.010374366744232033,
                                    0.013080671771102004,
                                    0.4319342970189784,
                                    0.5446106644656875,
                                ],
                                [
                                    0.013080671771102007,
                                    0.5446106644656876,
                                    0.010374366744232031,
                                    0.43193429701897834,
                                ],
                                [
                                    0.23152869862583725,
                                    0.2919263398894968,
                                    0.21077996513737318,
                                    0.2657649963472928,
                                ],
                                [
                                    0.23152869862583725,
                                    0.21077996513737318,
                                    0.2919263398894968,
                                    0.2657649963472928,
                                ],
                                [
                                    0.013080671771102007,
                                    0.010374366744232031,
                                    0.5446106644656876,
                                    0.43193429701897834,
                                ],
                                [
                                    0.29192633988949684,
                                    0.26576499634729284,
                                    0.23152869862583722,
                                    0.21077996513737315,
                                ],
                                [
                                    0.29192633988949684,
                                    0.23152869862583722,
                                    0.26576499634729284,
                                    0.21077996513737315,
                                ],
                                [
                                    0.004451803026246561,
                                    0.4067918467144647,
                                    0.006373417081233321,
                                    0.5823829331780555,
                                ],
                                [
                                    0.004451803026246561,
                                    0.006373417081233321,
                                    0.4067918467144647,
                                    0.5823829331780555,
                                ],
                                [
                                    0.006373417081233321,
                                    0.5823829331780555,
                                    0.004451803026246562,
                                    0.4067918467144648,
                                ],
                                [
                                    0.3207946700772142,
                                    0.4592652050831072,
                                    0.0904489796634971,
                                    0.12949114517618152,
                                ],
                                [
                                    0.3207946700772142,
                                    0.0904489796634971,
                                    0.4592652050831072,
                                    0.12949114517618152,
                                ],
                                [
                                    0.006373417081233321,
                                    0.004451803026246562,
                                    0.5823829331780555,
                                    0.4067918467144648,
                                ],
                                [
                                    0.4592652050831072,
                                    0.12949114517618152,
                                    0.3207946700772142,
                                    0.09044897966349712,
                                ],
                                [
                                    0.4592652050831072,
                                    0.3207946700772142,
                                    0.12949114517618152,
                                    0.09044897966349712,
                                ],
                                [
                                    0.0008582824568405626,
                                    0.38917165512332025,
                                    0.0013422728701826723,
                                    0.6086277895496566,
                                ],
                                [
                                    0.0008582824568405626,
                                    0.0013422728701826723,
                                    0.38917165512332025,
                                    0.6086277895496566,
                                ],
                                [
                                    0.0013422728701826725,
                                    0.6086277895496567,
                                    0.0008582824568405624,
                                    0.38917165512332014,
                                ],
                                [
                                    0.3725918856208494,
                                    0.5826985926755058,
                                    0.01743805195931145,
                                    0.02727146974433341,
                                ],
                                [
                                    0.3725918856208494,
                                    0.01743805195931145,
                                    0.5826985926755058,
                                    0.02727146974433341,
                                ],
                                [
                                    0.0013422728701826725,
                                    0.0008582824568405624,
                                    0.6086277895496567,
                                    0.38917165512332014,
                                ],
                                [
                                    0.5826985926755059,
                                    0.027271469744333414,
                                    0.3725918856208493,
                                    0.017438051959311446,
                                ],
                                [
                                    0.5826985926755059,
                                    0.3725918856208493,
                                    0.027271469744333414,
                                    0.017438051959311446,
                                ],
                                [
                                    0.20735350459414442,
                                    0.02091375470078255,
                                    0.7010268966715427,
                                    0.07070584403353028,
                                ],
                                [
                                    0.20735350459414442,
                                    0.7010268966715427,
                                    0.02091375470078255,
                                    0.07070584403353028,
                                ],
                                [
                                    0.2171869223791664,
                                    0.02190555702324047,
                                    0.6911934788865208,
                                    0.06971404171107236,
                                ],
                                [
                                    0.21806153931124891,
                                    0.7372289389851062,
                                    0.010205719983678056,
                                    0.034503801719966753,
                                ],
                                [
                                    0.21806153931124891,
                                    0.010205719983678056,
                                    0.7372289389851062,
                                    0.034503801719966753,
                                ],
                                [
                                    0.2171869223791664,
                                    0.6911934788865208,
                                    0.02190555702324047,
                                    0.06971404171107236,
                                ],
                                [
                                    0.2284027690053867,
                                    0.01068971039702016,
                                    0.7268877092909685,
                                    0.03401981130662465,
                                ],
                                [
                                    0.2284027690053867,
                                    0.7268877092909685,
                                    0.01068971039702016,
                                    0.03401981130662465,
                                ],
                                [
                                    0.16017598727131044,
                                    0.05830049281493821,
                                    0.572973810858343,
                                    0.20854970905540837,
                                ],
                                [
                                    0.16017598727131044,
                                    0.572973810858343,
                                    0.05830049281493821,
                                    0.20854970905540837,
                                ],
                                [
                                    0.19921815278399482,
                                    0.07251097173083484,
                                    0.5339316453456586,
                                    0.19433923013951174,
                                ],
                                [
                                    0.2105927875612546,
                                    0.7533223555155573,
                                    0.007883692524994044,
                                    0.02820116439819409,
                                ],
                                [
                                    0.2105927875612546,
                                    0.007883692524994044,
                                    0.7533223555155573,
                                    0.02820116439819409,
                                ],
                                [
                                    0.19921815278399482,
                                    0.5339316453456586,
                                    0.07251097173083484,
                                    0.19433923013951174,
                                ],
                                [
                                    0.26192381793484887,
                                    0.009805306579980803,
                                    0.7019913251419629,
                                    0.026279550343207333,
                                ],
                                [
                                    0.26192381793484887,
                                    0.7019913251419629,
                                    0.009805306579980803,
                                    0.026279550343207333,
                                ],
                                [
                                    0.09728142272575192,
                                    0.10685760000711607,
                                    0.37926353875891405,
                                    0.41659743850821795,
                                ],
                                [
                                    0.09728142272575192,
                                    0.37926353875891405,
                                    0.10685760000711607,
                                    0.41659743850821795,
                                ],
                                [
                                    0.1522664539356716,
                                    0.16725524127077565,
                                    0.3242785075489944,
                                    0.35619979724455836,
                                ],
                                [
                                    0.19935093409218593,
                                    0.77719402739248,
                                    0.004788088640682063,
                                    0.018666949874651947,
                                ],
                                [
                                    0.19935093409218593,
                                    0.004788088640682063,
                                    0.77719402739248,
                                    0.018666949874651947,
                                ],
                                [
                                    0.1522664539356716,
                                    0.3242785075489944,
                                    0.16725524127077565,
                                    0.35619979724455836,
                                ],
                                [
                                    0.3120273015388952,
                                    0.007494393667552034,
                                    0.6645176599457707,
                                    0.015960644847781976,
                                ],
                                [
                                    0.3120273015388952,
                                    0.6645176599457707,
                                    0.007494393667552034,
                                    0.015960644847781976,
                                ],
                                [
                                    0.04174497998433087,
                                    0.14805658539515648,
                                    0.17819514485534776,
                                    0.632003289765165,
                                ],
                                [
                                    0.04174497998433087,
                                    0.17819514485534776,
                                    0.14805658539515648,
                                    0.632003289765165,
                                ],
                                [
                                    0.08078714549701525,
                                    0.28652712040104944,
                                    0.13915297934266335,
                                    0.49353275475927194,
                                ],
                                [
                                    0.18774692165751014,
                                    0.80142785823501,
                                    0.002054643721977184,
                                    0.008770576385502698,
                                ],
                                [
                                    0.18774692165751014,
                                    0.002054643721977184,
                                    0.80142785823501,
                                    0.008770576385502698,
                                ],
                                [
                                    0.08078714549701525,
                                    0.13915297934266335,
                                    0.28652712040104944,
                                    0.49353275475927194,
                                ],
                                [
                                    0.3633380081211008,
                                    0.003976257776963942,
                                    0.6258367717714194,
                                    0.00684896233051594,
                                ],
                                [
                                    0.3633380081211008,
                                    0.6258367717714194,
                                    0.003976257776963942,
                                    0.00684896233051594,
                                ],
                                [
                                    0.00804819615119396,
                                    0.17196259001961517,
                                    0.03666132555245088,
                                    0.78332788827674,
                                ],
                                [
                                    0.00804819615119396,
                                    0.03666132555245088,
                                    0.17196259001961517,
                                    0.78332788827674,
                                ],
                                [
                                    0.017881613936215922,
                                    0.38206929707427173,
                                    0.026827907767428917,
                                    0.5732211812220834,
                                ],
                                [
                                    0.1796146624763793,
                                    0.8181847821965974,
                                    0.00039612369442980995,
                                    0.0018044316325933998,
                                ],
                                [
                                    0.1796146624763793,
                                    0.00039612369442980995,
                                    0.8181847821965974,
                                    0.0018044316325933998,
                                ],
                                [
                                    0.017881613936215922,
                                    0.026827907767428917,
                                    0.38206929707427173,
                                    0.5732211812220834,
                                ],
                                [
                                    0.3990707969027157,
                                    0.0008801141077719142,
                                    0.598728647770261,
                                    0.0013204412192512954,
                                ],
                                [
                                    0.3990707969027157,
                                    0.598728647770261,
                                    0.0008801141077719142,
                                    0.0013204412192512954,
                                ],
                                [
                                    0.16735409507168497,
                                    0.06091316422324201,
                                    0.5657957030579684,
                                    0.20593703764710458,
                                ],
                                [
                                    0.16735409507168497,
                                    0.5657957030579684,
                                    0.06091316422324201,
                                    0.20593703764710458,
                                ],
                                [
                                    0.1752906030081929,
                                    0.06380187639421395,
                                    0.5578591951214605,
                                    0.20304832547613264,
                                ],
                                [
                                    0.17806212978878944,
                                    0.601997745371532,
                                    0.050205129506137515,
                                    0.16973499533354106,
                                ],
                                [
                                    0.17806212978878944,
                                    0.050205129506137515,
                                    0.601997745371532,
                                    0.16973499533354106,
                                ],
                                [
                                    0.1752906030081929,
                                    0.5578591951214605,
                                    0.06380187639421395,
                                    0.20304832547613264,
                                ],
                                [
                                    0.1865064496344132,
                                    0.05258602976799364,
                                    0.5935534255259082,
                                    0.16735409507168492,
                                ],
                                [
                                    0.1865064496344132,
                                    0.5935534255259082,
                                    0.05258602976799364,
                                    0.16735409507168492,
                                ],
                                [
                                    0.12927732981640128,
                                    0.08919915026984736,
                                    0.46244462471786285,
                                    0.3190788951958885,
                                ],
                                [
                                    0.12927732981640128,
                                    0.46244462471786285,
                                    0.08919915026984736,
                                    0.3190788951958885,
                                ],
                                [
                                    0.16078808866179944,
                                    0.11094103585303024,
                                    0.4309338658724647,
                                    0.29733700961270565,
                                ],
                                [
                                    0.17969413010634547,
                                    0.6427931693750771,
                                    0.038782349979903194,
                                    0.1387303505386742,
                                ],
                                [
                                    0.17969413010634547,
                                    0.038782349979903194,
                                    0.6427931693750771,
                                    0.1387303505386742,
                                ],
                                [
                                    0.16078808866179944,
                                    0.4309338658724647,
                                    0.11094103585303024,
                                    0.29733700961270565,
                                ],
                                [
                                    0.2234937538126535,
                                    0.048235370702176185,
                                    0.5989935456687692,
                                    0.12927732981640122,
                                ],
                                [
                                    0.2234937538126535,
                                    0.5989935456687692,
                                    0.048235370702176185,
                                    0.12927732981640122,
                                ],
                                [
                                    0.07851540536737094,
                                    0.12562361736549704,
                                    0.3061019221590498,
                                    0.4897590551080822,
                                ],
                                [
                                    0.07851540536737094,
                                    0.3061019221590498,
                                    0.12562361736549704,
                                    0.4897590551080822,
                                ],
                                [
                                    0.1228935804970153,
                                    0.19662811470943195,
                                    0.26172374702940543,
                                    0.41875455776414733,
                                ],
                                [
                                    0.18058491673380495,
                                    0.7040324107926158,
                                    0.02355410599906305,
                                    0.09182856647451618,
                                ],
                                [
                                    0.18058491673380495,
                                    0.02355410599906305,
                                    0.7040324107926158,
                                    0.09182856647451618,
                                ],
                                [
                                    0.1228935804970153,
                                    0.26172374702940543,
                                    0.19662811470943195,
                                    0.41875455776414733,
                                ],
                                [
                                    0.28265442810023894,
                                    0.03686726710620831,
                                    0.6019628994261819,
                                    0.07851540536737091,
                                ],
                                [
                                    0.28265442810023894,
                                    0.6019628994261819,
                                    0.03686726710620831,
                                    0.07851540536737091,
                                ],
                                [
                                    0.03369218843316614,
                                    0.1561093769463212,
                                    0.14382051208541136,
                                    0.6663779225351013,
                                ],
                                [
                                    0.03369218843316614,
                                    0.14382051208541136,
                                    0.1561093769463212,
                                    0.6663779225351013,
                                ],
                                [
                                    0.0652029472785643,
                                    0.3021113186195004,
                                    0.11230975324001319,
                                    0.5203759808619222,
                                ],
                                [
                                    0.1796941301063454,
                                    0.7670532254650736,
                                    0.010107435273141917,
                                    0.043145209155439124,
                                ],
                                [
                                    0.1796941301063454,
                                    0.010107435273141917,
                                    0.7670532254650736,
                                    0.043145209155439124,
                                ],
                                [
                                    0.0652029472785643,
                                    0.11230975324001319,
                                    0.3021113186195004,
                                    0.5203759808619222,
                                ],
                                [
                                    0.3477538099026498,
                                    0.01956045599541491,
                                    0.5989935456687692,
                                    0.03369218843316613,
                                ],
                                [
                                    0.3477538099026498,
                                    0.5989935456687692,
                                    0.01956045599541491,
                                    0.03369218843316613,
                                ],
                                [
                                    0.006495663463604271,
                                    0.17351512270720484,
                                    0.02958919345958392,
                                    0.790400020369607,
                                ],
                                [
                                    0.006495663463604271,
                                    0.02958919345958392,
                                    0.17351512270720484,
                                    0.790400020369607,
                                ],
                                [
                                    0.014432171400112218,
                                    0.3855187396103754,
                                    0.021652685523075973,
                                    0.5783964034664364,
                                ],
                                [
                                    0.17806212978878963,
                                    0.8111126501037305,
                                    0.0019486563820195063,
                                    0.008876563725460387,
                                ],
                                [
                                    0.17806212978878963,
                                    0.0019486563820195063,
                                    0.8111126501037305,
                                    0.008876563725460387,
                                ],
                                [
                                    0.014432171400112218,
                                    0.021652685523075973,
                                    0.3855187396103754,
                                    0.5783964034664364,
                                ],
                                [
                                    0.395621354366612,
                                    0.004329556643875632,
                                    0.5935534255259081,
                                    0.006495663463604261,
                                ],
                                [
                                    0.395621354366612,
                                    0.5935534255259081,
                                    0.004329556643875632,
                                    0.006495663463604261,
                                ],
                                [
                                    0.10877961228891123,
                                    0.11948764700601575,
                                    0.3677653491957547,
                                    0.4039673915093183,
                                ],
                                [
                                    0.10877961228891123,
                                    0.3677653491957547,
                                    0.11948764700601575,
                                    0.4039673915093183,
                                ],
                                [
                                    0.11393831638809326,
                                    0.1251541630143136,
                                    0.3626066450965727,
                                    0.39830087550102045,
                                ],
                                [
                                    0.11948764700601575,
                                    0.4039673915093183,
                                    0.10877961228891123,
                                    0.3677653491957547,
                                ],
                                [
                                    0.11948764700601575,
                                    0.10877961228891123,
                                    0.4039673915093183,
                                    0.3677653491957547,
                                ],
                                [
                                    0.11393831638809326,
                                    0.3626066450965727,
                                    0.1251541630143136,
                                    0.39830087550102045,
                                ],
                                [
                                    0.1251541630143136,
                                    0.11393831638809326,
                                    0.39830087550102045,
                                    0.3626066450965727,
                                ],
                                [
                                    0.1251541630143136,
                                    0.39830087550102045,
                                    0.11393831638809326,
                                    0.3626066450965727,
                                ],
                                [
                                    0.08402983989815226,
                                    0.13444664018809638,
                                    0.3005874876282686,
                                    0.48093603228548276,
                                ],
                                [
                                    0.08402983989815226,
                                    0.3005874876282686,
                                    0.13444664018809638,
                                    0.48093603228548276,
                                ],
                                [
                                    0.10451172968198784,
                                    0.16721739483284184,
                                    0.280105597844433,
                                    0.4481652776407373,
                                ],
                                [
                                    0.1344466401880964,
                                    0.4809360322854828,
                                    0.08402983989815224,
                                    0.30058748762826853,
                                ],
                                [
                                    0.1344466401880964,
                                    0.08402983989815224,
                                    0.4809360322854828,
                                    0.30058748762826853,
                                ],
                                [
                                    0.10451172968198784,
                                    0.280105597844433,
                                    0.16721739483284184,
                                    0.4481652776407373,
                                ],
                                [
                                    0.16721739483284187,
                                    0.10451172968198781,
                                    0.4481652776407374,
                                    0.28010559784443295,
                                ],
                                [
                                    0.16721739483284187,
                                    0.4481652776407374,
                                    0.10451172968198781,
                                    0.28010559784443295,
                                ],
                                [
                                    0.051034755683217,
                                    0.153104267049651,
                                    0.198965244316783,
                                    0.596895732950349,
                                ],
                                [
                                    0.051034755683217,
                                    0.198965244316783,
                                    0.153104267049651,
                                    0.596895732950349,
                                ],
                                [
                                    0.07988042380161181,
                                    0.23964127140483543,
                                    0.1701195761983882,
                                    0.5103587285951645,
                                ],
                                [
                                    0.153104267049651,
                                    0.596895732950349,
                                    0.051034755683217,
                                    0.198965244316783,
                                ],
                                [
                                    0.153104267049651,
                                    0.051034755683217,
                                    0.596895732950349,
                                    0.198965244316783,
                                ],
                                [
                                    0.07988042380161181,
                                    0.1701195761983882,
                                    0.23964127140483543,
                                    0.5103587285951645,
                                ],
                                [
                                    0.23964127140483543,
                                    0.07988042380161181,
                                    0.5103587285951645,
                                    0.1701195761983882,
                                ],
                                [
                                    0.23964127140483543,
                                    0.5103587285951645,
                                    0.07988042380161181,
                                    0.1701195761983882,
                                ],
                                [
                                    0.021899811853154025,
                                    0.1679017535263333,
                                    0.09348286062042523,
                                    0.7167155740000875,
                                ],
                                [
                                    0.021899811853154025,
                                    0.09348286062042523,
                                    0.1679017535263333,
                                    0.7167155740000875,
                                ],
                                [
                                    0.0423817016369896,
                                    0.3249325642610751,
                                    0.07300097083658966,
                                    0.5596847632653457,
                                ],
                                [
                                    0.1679017535263333,
                                    0.7167155740000875,
                                    0.021899811853154025,
                                    0.09348286062042523,
                                ],
                                [
                                    0.1679017535263333,
                                    0.021899811853154025,
                                    0.7167155740000875,
                                    0.09348286062042523,
                                ],
                                [
                                    0.0423817016369896,
                                    0.07300097083658966,
                                    0.3249325642610751,
                                    0.5596847632653457,
                                ],
                                [
                                    0.3249325642610751,
                                    0.0423817016369896,
                                    0.5596847632653457,
                                    0.07300097083658966,
                                ],
                                [
                                    0.3249325642610751,
                                    0.5596847632653457,
                                    0.0423817016369896,
                                    0.07300097083658966,
                                ],
                                [
                                    0.004222159922811887,
                                    0.17578862624799724,
                                    0.019232878592522148,
                                    0.8007563352366688,
                                ],
                                [
                                    0.004222159922811887,
                                    0.019232878592522148,
                                    0.17578862624799724,
                                    0.8007563352366688,
                                ],
                                [
                                    0.009380864021993923,
                                    0.3905700469884937,
                                    0.014074174493340114,
                                    0.5859749144961722,
                                ],
                                [
                                    0.17578862624799724,
                                    0.8007563352366688,
                                    0.004222159922811887,
                                    0.019232878592522148,
                                ],
                                [
                                    0.17578862624799724,
                                    0.004222159922811887,
                                    0.8007563352366688,
                                    0.019232878592522148,
                                ],
                                [
                                    0.009380864021993923,
                                    0.014074174493340114,
                                    0.3905700469884937,
                                    0.5859749144961722,
                                ],
                                [
                                    0.3905700469884937,
                                    0.009380864021993923,
                                    0.5859749144961722,
                                    0.014074174493340114,
                                ],
                                [
                                    0.3905700469884937,
                                    0.5859749144961722,
                                    0.009380864021993923,
                                    0.014074174493340114,
                                ],
                                [
                                    0.05020512950613753,
                                    0.17806212978878944,
                                    0.16973499533354108,
                                    0.601997745371532,
                                ],
                                [
                                    0.05020512950613753,
                                    0.16973499533354108,
                                    0.17806212978878944,
                                    0.601997745371532,
                                ],
                                [
                                    0.052586029767993654,
                                    0.1865064496344132,
                                    0.16735409507168497,
                                    0.5935534255259082,
                                ],
                                [
                                    0.060913164223242035,
                                    0.20593703764710466,
                                    0.16735409507168494,
                                    0.5657957030579683,
                                ],
                                [
                                    0.060913164223242035,
                                    0.16735409507168494,
                                    0.20593703764710466,
                                    0.5657957030579683,
                                ],
                                [
                                    0.052586029767993654,
                                    0.16735409507168497,
                                    0.1865064496344132,
                                    0.5935534255259082,
                                ],
                                [
                                    0.06380187639421397,
                                    0.17529060300819288,
                                    0.20304832547613272,
                                    0.5578591951214604,
                                ],
                                [
                                    0.06380187639421397,
                                    0.20304832547613272,
                                    0.17529060300819288,
                                    0.5578591951214604,
                                ],
                                [
                                    0.038782349979903215,
                                    0.17969413010634544,
                                    0.13873035053867427,
                                    0.6427931693750771,
                                ],
                                [
                                    0.038782349979903215,
                                    0.13873035053867427,
                                    0.17969413010634544,
                                    0.6427931693750771,
                                ],
                                [
                                    0.04823537070217621,
                                    0.22349375381265346,
                                    0.12927732981640128,
                                    0.5989935456687691,
                                ],
                                [
                                    0.08919915026984739,
                                    0.3190788951958886,
                                    0.12927732981640125,
                                    0.46244462471786274,
                                ],
                                [
                                    0.08919915026984739,
                                    0.12927732981640125,
                                    0.3190788951958886,
                                    0.46244462471786274,
                                ],
                                [
                                    0.04823537070217621,
                                    0.12927732981640128,
                                    0.22349375381265346,
                                    0.5989935456687691,
                                ],
                                [
                                    0.11094103585303026,
                                    0.16078808866179942,
                                    0.2973370096127057,
                                    0.4309338658724646,
                                ],
                                [
                                    0.11094103585303026,
                                    0.2973370096127057,
                                    0.16078808866179942,
                                    0.4309338658724646,
                                ],
                                [
                                    0.023554105999063057,
                                    0.18058491673380495,
                                    0.09182856647451619,
                                    0.7040324107926158,
                                ],
                                [
                                    0.023554105999063057,
                                    0.09182856647451619,
                                    0.18058491673380495,
                                    0.7040324107926158,
                                ],
                                [
                                    0.03686726710620832,
                                    0.28265442810023894,
                                    0.07851540536737094,
                                    0.6019628994261819,
                                ],
                                [
                                    0.12562361736549704,
                                    0.4897590551080822,
                                    0.07851540536737094,
                                    0.3061019221590498,
                                ],
                                [
                                    0.12562361736549704,
                                    0.07851540536737094,
                                    0.4897590551080822,
                                    0.3061019221590498,
                                ],
                                [
                                    0.03686726710620832,
                                    0.07851540536737094,
                                    0.28265442810023894,
                                    0.6019628994261819,
                                ],
                                [
                                    0.19662811470943195,
                                    0.1228935804970153,
                                    0.41875455776414733,
                                    0.26172374702940543,
                                ],
                                [
                                    0.19662811470943195,
                                    0.41875455776414733,
                                    0.1228935804970153,
                                    0.26172374702940543,
                                ],
                                [
                                    0.010107435273141913,
                                    0.1796941301063454,
                                    0.04314520915543911,
                                    0.7670532254650736,
                                ],
                                [
                                    0.010107435273141913,
                                    0.04314520915543911,
                                    0.1796941301063454,
                                    0.7670532254650736,
                                ],
                                [
                                    0.019560455995414904,
                                    0.3477538099026498,
                                    0.03369218843316612,
                                    0.5989935456687692,
                                ],
                                [
                                    0.1561093769463212,
                                    0.6663779225351013,
                                    0.03369218843316613,
                                    0.14382051208541133,
                                ],
                                [
                                    0.1561093769463212,
                                    0.03369218843316613,
                                    0.6663779225351013,
                                    0.14382051208541133,
                                ],
                                [
                                    0.019560455995414904,
                                    0.03369218843316612,
                                    0.3477538099026498,
                                    0.5989935456687692,
                                ],
                                [
                                    0.3021113186195004,
                                    0.0652029472785643,
                                    0.5203759808619222,
                                    0.11230975324001316,
                                ],
                                [
                                    0.3021113186195004,
                                    0.5203759808619222,
                                    0.0652029472785643,
                                    0.11230975324001316,
                                ],
                                [
                                    0.0019486563820195046,
                                    0.17806212978878963,
                                    0.008876563725460378,
                                    0.8111126501037305,
                                ],
                                [
                                    0.0019486563820195046,
                                    0.008876563725460378,
                                    0.17806212978878963,
                                    0.8111126501037305,
                                ],
                                [
                                    0.004329556643875628,
                                    0.395621354366612,
                                    0.006495663463604254,
                                    0.5935534255259081,
                                ],
                                [
                                    0.17351512270720484,
                                    0.790400020369607,
                                    0.006495663463604268,
                                    0.02958919345958391,
                                ],
                                [
                                    0.17351512270720484,
                                    0.006495663463604268,
                                    0.790400020369607,
                                    0.02958919345958391,
                                ],
                                [
                                    0.004329556643875628,
                                    0.006495663463604254,
                                    0.395621354366612,
                                    0.5935534255259081,
                                ],
                                [
                                    0.3855187396103754,
                                    0.014432171400112213,
                                    0.5783964034664364,
                                    0.021652685523075962,
                                ],
                                [
                                    0.3855187396103754,
                                    0.5783964034664364,
                                    0.014432171400112213,
                                    0.021652685523075962,
                                ],
                                [
                                    0.010205719983678061,
                                    0.21806153931124891,
                                    0.034503801719966774,
                                    0.7372289389851062,
                                ],
                                [
                                    0.010205719983678061,
                                    0.034503801719966774,
                                    0.21806153931124891,
                                    0.7372289389851062,
                                ],
                                [
                                    0.010689710397020167,
                                    0.2284027690053867,
                                    0.034019811306624674,
                                    0.7268877092909685,
                                ],
                                [
                                    0.020913754700782567,
                                    0.07070584403353035,
                                    0.2073535045941444,
                                    0.7010268966715427,
                                ],
                                [
                                    0.020913754700782567,
                                    0.2073535045941444,
                                    0.07070584403353035,
                                    0.7010268966715427,
                                ],
                                [
                                    0.010689710397020167,
                                    0.034019811306624674,
                                    0.2284027690053867,
                                    0.7268877092909685,
                                ],
                                [
                                    0.021905557023240492,
                                    0.21718692237916637,
                                    0.06971404171107243,
                                    0.6911934788865207,
                                ],
                                [
                                    0.021905557023240492,
                                    0.06971404171107243,
                                    0.21718692237916637,
                                    0.6911934788865207,
                                ],
                                [
                                    0.007883692524994056,
                                    0.2105927875612546,
                                    0.028201164398194135,
                                    0.7533223555155573,
                                ],
                                [
                                    0.007883692524994056,
                                    0.028201164398194135,
                                    0.2105927875612546,
                                    0.7533223555155573,
                                ],
                                [
                                    0.009805306579980817,
                                    0.26192381793484887,
                                    0.026279550343207374,
                                    0.7019913251419629,
                                ],
                                [
                                    0.05830049281493823,
                                    0.20854970905540846,
                                    0.1601759872713104,
                                    0.5729738108583429,
                                ],
                                [
                                    0.05830049281493823,
                                    0.1601759872713104,
                                    0.20854970905540846,
                                    0.5729738108583429,
                                ],
                                [
                                    0.009805306579980817,
                                    0.026279550343207374,
                                    0.26192381793484887,
                                    0.7019913251419629,
                                ],
                                [
                                    0.07251097173083487,
                                    0.1992181527839948,
                                    0.19433923013951182,
                                    0.5339316453456585,
                                ],
                                [
                                    0.07251097173083487,
                                    0.19433923013951182,
                                    0.1992181527839948,
                                    0.5339316453456585,
                                ],
                                [
                                    0.004788088640682069,
                                    0.19935093409218593,
                                    0.018666949874651968,
                                    0.77719402739248,
                                ],
                                [
                                    0.004788088640682069,
                                    0.018666949874651968,
                                    0.19935093409218593,
                                    0.77719402739248,
                                ],
                                [
                                    0.007494393667552043,
                                    0.3120273015388952,
                                    0.015960644847781993,
                                    0.6645176599457707,
                                ],
                                [
                                    0.10685760000711607,
                                    0.41659743850821795,
                                    0.09728142272575192,
                                    0.37926353875891405,
                                ],
                                [
                                    0.10685760000711607,
                                    0.09728142272575192,
                                    0.41659743850821795,
                                    0.37926353875891405,
                                ],
                                [
                                    0.007494393667552043,
                                    0.015960644847781993,
                                    0.3120273015388952,
                                    0.6645176599457707,
                                ],
                                [
                                    0.16725524127077565,
                                    0.1522664539356716,
                                    0.35619979724455836,
                                    0.3242785075489944,
                                ],
                                [
                                    0.16725524127077565,
                                    0.35619979724455836,
                                    0.1522664539356716,
                                    0.3242785075489944,
                                ],
                                [
                                    0.002054643721977184,
                                    0.18774692165751014,
                                    0.008770576385502698,
                                    0.80142785823501,
                                ],
                                [
                                    0.002054643721977184,
                                    0.008770576385502698,
                                    0.18774692165751014,
                                    0.80142785823501,
                                ],
                                [
                                    0.003976257776963942,
                                    0.3633380081211008,
                                    0.00684896233051594,
                                    0.6258367717714194,
                                ],
                                [
                                    0.14805658539515648,
                                    0.632003289765165,
                                    0.04174497998433087,
                                    0.17819514485534776,
                                ],
                                [
                                    0.14805658539515648,
                                    0.04174497998433087,
                                    0.632003289765165,
                                    0.17819514485534776,
                                ],
                                [
                                    0.003976257776963942,
                                    0.00684896233051594,
                                    0.3633380081211008,
                                    0.6258367717714194,
                                ],
                                [
                                    0.28652712040104944,
                                    0.08078714549701525,
                                    0.49353275475927194,
                                    0.13915297934266335,
                                ],
                                [
                                    0.28652712040104944,
                                    0.49353275475927194,
                                    0.08078714549701525,
                                    0.13915297934266335,
                                ],
                                [
                                    0.00039612369442981445,
                                    0.1796146624763793,
                                    0.0018044316325934204,
                                    0.8181847821965974,
                                ],
                                [
                                    0.00039612369442981445,
                                    0.0018044316325934204,
                                    0.1796146624763793,
                                    0.8181847821965974,
                                ],
                                [
                                    0.0008801141077719243,
                                    0.3990707969027157,
                                    0.0013204412192513106,
                                    0.598728647770261,
                                ],
                                [
                                    0.17196259001961517,
                                    0.78332788827674,
                                    0.008048196151193964,
                                    0.03666132555245089,
                                ],
                                [
                                    0.17196259001961517,
                                    0.008048196151193964,
                                    0.78332788827674,
                                    0.03666132555245089,
                                ],
                                [
                                    0.0008801141077719243,
                                    0.0013204412192513106,
                                    0.3990707969027157,
                                    0.598728647770261,
                                ],
                                [
                                    0.38206929707427173,
                                    0.017881613936215932,
                                    0.5732211812220834,
                                    0.026827907767428927,
                                ],
                                [
                                    0.38206929707427173,
                                    0.5732211812220834,
                                    0.017881613936215932,
                                    0.026827907767428927,
                                ],
                                [
                                    0.042150908210752396,
                                    0.004251356910799814,
                                    0.8662294930549348,
                                    0.08736824182351302,
                                ],
                                [
                                    0.042150908210752396,
                                    0.8662294930549348,
                                    0.004251356910799814,
                                    0.08736824182351302,
                                ],
                                [
                                    0.05198432599577436,
                                    0.005243159233257735,
                                    0.8563960752699128,
                                    0.0863764395010551,
                                ],
                                [
                                    0.04432764204200189,
                                    0.9109628362543533,
                                    0.0020746230795503193,
                                    0.04263489862409449,
                                ],
                                [
                                    0.04432764204200189,
                                    0.0020746230795503193,
                                    0.9109628362543533,
                                    0.04263489862409449,
                                ],
                                [
                                    0.05198432599577436,
                                    0.8563960752699128,
                                    0.005243159233257735,
                                    0.0863764395010551,
                                ],
                                [
                                    0.05466887173613967,
                                    0.0025586134928924234,
                                    0.9006216065602155,
                                    0.04215090821075239,
                                ],
                                [
                                    0.05466887173613967,
                                    0.9006216065602155,
                                    0.0025586134928924234,
                                    0.04215090821075239,
                                ],
                                [
                                    0.03256064251363666,
                                    0.011851348864799884,
                                    0.7005891556160168,
                                    0.2549988530055467,
                                ],
                                [
                                    0.03256064251363666,
                                    0.7005891556160168,
                                    0.011851348864799884,
                                    0.2549988530055467,
                                ],
                                [
                                    0.07160280802632105,
                                    0.026061827780696517,
                                    0.6615469901033324,
                                    0.24078837408965006,
                                ],
                                [
                                    0.042809391023871796,
                                    0.92110575205294,
                                    0.0016026003545647476,
                                    0.03448225656862339,
                                ],
                                [
                                    0.042809391023871796,
                                    0.0016026003545647476,
                                    0.92110575205294,
                                    0.03448225656862339,
                                ],
                                [
                                    0.07160280802632105,
                                    0.6615469901033324,
                                    0.026061827780696517,
                                    0.24078837408965006,
                                ],
                                [
                                    0.09414042139746605,
                                    0.0035242144095515055,
                                    0.8697747216793458,
                                    0.03256064251363663,
                                ],
                                [
                                    0.09414042139746605,
                                    0.8697747216793458,
                                    0.0035242144095515055,
                                    0.03256064251363663,
                                ],
                                [
                                    0.019775408802231415,
                                    0.021722058174696718,
                                    0.4567695526824345,
                                    0.5017329803406373,
                                ],
                                [
                                    0.019775408802231415,
                                    0.4567695526824345,
                                    0.021722058174696718,
                                    0.5017329803406373,
                                ],
                                [
                                    0.07476044001215107,
                                    0.08211969943835631,
                                    0.4017845214725149,
                                    0.4413353390769777,
                                ],
                                [
                                    0.04052414229069548,
                                    0.9360208191939705,
                                    0.0009733246862326505,
                                    0.022481713829101357,
                                ],
                                [
                                    0.04052414229069548,
                                    0.0009733246862326505,
                                    0.9360208191939705,
                                    0.022481713829101357,
                                ],
                                [
                                    0.07476044001215107,
                                    0.4017845214725149,
                                    0.08211969943835631,
                                    0.4413353390769777,
                                ],
                                [
                                    0.15320050973740476,
                                    0.003679629713102621,
                                    0.8233444517472612,
                                    0.019775408802231387,
                                ],
                                [
                                    0.15320050973740476,
                                    0.8233444517472612,
                                    0.003679629713102621,
                                    0.019775408802231387,
                                ],
                                [
                                    0.008485937206719965,
                                    0.030097005368699758,
                                    0.21145418763295865,
                                    0.7499628697916216,
                                ],
                                [
                                    0.008485937206719965,
                                    0.21145418763295865,
                                    0.030097005368699758,
                                    0.7499628697916216,
                                ],
                                [
                                    0.04752810271940436,
                                    0.16856754037459273,
                                    0.17241202212027426,
                                    0.6114923347857286,
                                ],
                                [
                                    0.038165273729646544,
                                    0.9510095061628736,
                                    0.0004176688457731752,
                                    0.010407551261706708,
                                ],
                                [
                                    0.038165273729646544,
                                    0.0004176688457731752,
                                    0.9510095061628736,
                                    0.010407551261706708,
                                ],
                                [
                                    0.04752810271940436,
                                    0.17241202212027426,
                                    0.16856754037459273,
                                    0.6114923347857286,
                                ],
                                [
                                    0.21375636019323715,
                                    0.0023392829007599335,
                                    0.7754184196992829,
                                    0.00848593720671995,
                                ],
                                [
                                    0.21375636019323715,
                                    0.7754184196992829,
                                    0.0023392829007599335,
                                    0.00848593720671995,
                                ],
                                [
                                    0.0016360407213521812,
                                    0.03495662811095176,
                                    0.043073480982292654,
                                    0.9203338501854034,
                                ],
                                [
                                    0.0016360407213521812,
                                    0.043073480982292654,
                                    0.03495662811095176,
                                    0.9203338501854034,
                                ],
                                [
                                    0.011469458506374148,
                                    0.2450633351656084,
                                    0.03324006319727069,
                                    0.7102271431307468,
                                ],
                                [
                                    0.03651214463997502,
                                    0.9612873000330018,
                                    8.052419232892261e-05,
                                    0.002120031134694287,
                                ],
                                [
                                    0.03651214463997502,
                                    8.052419232892261e-05,
                                    0.9612873000330018,
                                    0.002120031134694287,
                                ],
                                [
                                    0.011469458506374148,
                                    0.03324006319727069,
                                    0.2450633351656084,
                                    0.7102271431307468,
                                ],
                                [
                                    0.25596827906631153,
                                    0.0005645146056710271,
                                    0.7418311656066653,
                                    0.0016360407213521825,
                                ],
                                [
                                    0.25596827906631153,
                                    0.7418311656066653,
                                    0.0005645146056710271,
                                    0.0016360407213521825,
                                ],
                                [
                                    0.03401981130662466,
                                    0.012382453814927549,
                                    0.6991299868230287,
                                    0.25446774805541905,
                                ],
                                [
                                    0.03401981130662466,
                                    0.6991299868230287,
                                    0.012382453814927549,
                                    0.25446774805541905,
                                ],
                                [
                                    0.0419563192431326,
                                    0.015271165985899492,
                                    0.6911934788865208,
                                    0.2515790358844471,
                                ],
                                [
                                    0.03619654513787415,
                                    0.7438633300224472,
                                    0.010205719983678056,
                                    0.2097344048560005,
                                ],
                                [
                                    0.03619654513787415,
                                    0.010205719983678056,
                                    0.7438633300224472,
                                    0.2097344048560005,
                                ],
                                [
                                    0.0419563192431326,
                                    0.6911934788865208,
                                    0.015271165985899492,
                                    0.2515790358844471,
                                ],
                                [
                                    0.04464086498349791,
                                    0.01258662024553418,
                                    0.7354190101768234,
                                    0.2073535045941444,
                                ],
                                [
                                    0.04464086498349791,
                                    0.7354190101768234,
                                    0.01258662024553418,
                                    0.2073535045941444,
                                ],
                                [
                                    0.02627955034320736,
                                    0.018132441035229183,
                                    0.5654424041910567,
                                    0.39014560443050667,
                                ],
                                [
                                    0.02627955034320736,
                                    0.5654424041910567,
                                    0.018132441035229183,
                                    0.39014560443050667,
                                ],
                                [
                                    0.05779030918860551,
                                    0.03987432661841205,
                                    0.5339316453456586,
                                    0.3684037188473238,
                                ],
                                [
                                    0.0365282988534425,
                                    0.7859590006279802,
                                    0.007883692524994048,
                                    0.16962900799358335,
                                ],
                                [
                                    0.0365282988534425,
                                    0.007883692524994048,
                                    0.7859590006279802,
                                    0.16962900799358335,
                                ],
                                [
                                    0.05779030918860551,
                                    0.5339316453456586,
                                    0.03987432661841205,
                                    0.3684037188473238,
                                ],
                                [
                                    0.08032792255975053,
                                    0.01733671324726704,
                                    0.7421593769216721,
                                    0.16017598727131035,
                                ],
                                [
                                    0.08032792255975053,
                                    0.7421593769216721,
                                    0.01733671324726704,
                                    0.16017598727131035,
                                ],
                                [
                                    0.015960644847781997,
                                    0.025536822129146135,
                                    0.36865668267863877,
                                    0.5898458503444332,
                                ],
                                [
                                    0.015960644847781997,
                                    0.36865668267863877,
                                    0.025536822129146135,
                                    0.5898458503444332,
                                ],
                                [
                                    0.06033881997742636,
                                    0.09654131947308102,
                                    0.3242785075489944,
                                    0.5188413530004983,
                                ],
                                [
                                    0.03670937833624606,
                                    0.8479079491901746,
                                    0.004788088640682068,
                                    0.11059458383289715,
                                ],
                                [
                                    0.03670937833624606,
                                    0.004788088640682068,
                                    0.8479079491901746,
                                    0.11059458383289715,
                                ],
                                [
                                    0.06033881997742636,
                                    0.3242785075489944,
                                    0.09654131947308102,
                                    0.5188413530004983,
                                ],
                                [
                                    0.13877888970268004,
                                    0.018101249747827328,
                                    0.7458384378237407,
                                    0.0972814227257519,
                                ],
                                [
                                    0.13877888970268004,
                                    0.7458384378237407,
                                    0.018101249747827328,
                                    0.0972814227257519,
                                ],
                                [
                                    0.006848962330515953,
                                    0.031733980244903766,
                                    0.17066373818806152,
                                    0.7907533192365187,
                                ],
                                [
                                    0.006848962330515953,
                                    0.17066373818806152,
                                    0.031733980244903766,
                                    0.7907533192365187,
                                ],
                                [
                                    0.03835972117591411,
                                    0.177735921918083,
                                    0.13915297934266338,
                                    0.6447513775633396,
                                ],
                                [
                                    0.03652829885344253,
                                    0.9102190567179764,
                                    0.0020546437219771873,
                                    0.05119800070660385,
                                ],
                                [
                                    0.03652829885344253,
                                    0.0020546437219771873,
                                    0.9102190567179764,
                                    0.05119800070660385,
                                ],
                                [
                                    0.03835972117591411,
                                    0.13915297934266338,
                                    0.177735921918083,
                                    0.6447513775633396,
                                ],
                                [
                                    0.20458797864974693,
                                    0.01150766444425018,
                                    0.7421593769216721,
                                    0.04174497998433086,
                                ],
                                [
                                    0.20458797864974693,
                                    0.7421593769216721,
                                    0.01150766444425018,
                                    0.04174497998433086,
                                ],
                                [
                                    0.0013204412192512956,
                                    0.03527222761305265,
                                    0.034764415703936895,
                                    0.9286429154637592,
                                ],
                                [
                                    0.0013204412192512956,
                                    0.034764415703936895,
                                    0.03527222761305265,
                                    0.9286429154637592,
                                ],
                                [
                                    0.009256949155759248,
                                    0.2472758445162233,
                                    0.026827907767428945,
                                    0.7166392985605885,
                                ],
                                [
                                    0.03619654513787413,
                                    0.9529782347546459,
                                    0.0003961236944298094,
                                    0.010429096413050084,
                                ],
                                [
                                    0.03619654513787413,
                                    0.0003961236944298094,
                                    0.9529782347546459,
                                    0.010429096413050084,
                                ],
                                [
                                    0.009256949155759248,
                                    0.026827907767428945,
                                    0.2472758445162233,
                                    0.7166392985605885,
                                ],
                                [
                                    0.25375576971569663,
                                    0.0027770239562859363,
                                    0.7354190101768235,
                                    0.008048196151193957,
                                ],
                                [
                                    0.25375576971569663,
                                    0.7354190101768235,
                                    0.0027770239562859363,
                                    0.008048196151193957,
                                ],
                                [
                                    0.022112765645151355,
                                    0.024289499476400855,
                                    0.4544321958395146,
                                    0.4991655390389332,
                                ],
                                [
                                    0.022112765645151355,
                                    0.4544321958395146,
                                    0.024289499476400855,
                                    0.4991655390389332,
                                ],
                                [
                                    0.02727146974433339,
                                    0.029956015484698704,
                                    0.4492734917403326,
                                    0.4934990230306353,
                                ],
                                [
                                    0.024289499476400855,
                                    0.4991655390389332,
                                    0.022112765645151355,
                                    0.4544321958395146,
                                ],
                                [
                                    0.024289499476400855,
                                    0.022112765645151355,
                                    0.4991655390389332,
                                    0.4544321958395146,
                                ],
                                [
                                    0.02727146974433339,
                                    0.4492734917403326,
                                    0.029956015484698704,
                                    0.4934990230306353,
                                ],
                                [
                                    0.029956015484698704,
                                    0.02727146974433339,
                                    0.4934990230306353,
                                    0.4492734917403326,
                                ],
                                [
                                    0.029956015484698704,
                                    0.4934990230306353,
                                    0.02727146974433339,
                                    0.4492734917403326,
                                ],
                                [
                                    0.01708162143410071,
                                    0.027330369944335835,
                                    0.36753570609232017,
                                    0.5880523025292433,
                                ],
                                [
                                    0.01708162143410071,
                                    0.36753570609232017,
                                    0.027330369944335835,
                                    0.5880523025292433,
                                ],
                                [
                                    0.03756351121793629,
                                    0.060101124589081276,
                                    0.3470538163084846,
                                    0.5552815478844979,
                                ],
                                [
                                    0.027330369944335842,
                                    0.5880523025292435,
                                    0.0170816214341007,
                                    0.36753570609232006,
                                ],
                                [
                                    0.027330369944335842,
                                    0.0170816214341007,
                                    0.5880523025292435,
                                    0.36753570609232006,
                                ],
                                [
                                    0.03756351121793629,
                                    0.3470538163084846,
                                    0.060101124589081276,
                                    0.5552815478844979,
                                ],
                                [
                                    0.06010112458908129,
                                    0.037563511217936274,
                                    0.5552815478844979,
                                    0.3470538163084845,
                                ],
                                [
                                    0.06010112458908129,
                                    0.5552815478844979,
                                    0.037563511217936274,
                                    0.3470538163084845,
                                ],
                                [
                                    0.010374366744232033,
                                    0.0311231002326961,
                                    0.23962563325576797,
                                    0.7188768997673038,
                                ],
                                [
                                    0.010374366744232033,
                                    0.23962563325576797,
                                    0.0311231002326961,
                                    0.7188768997673038,
                                ],
                                [
                                    0.039220034862626846,
                                    0.11766010458788054,
                                    0.21077996513737315,
                                    0.6323398954121194,
                                ],
                                [
                                    0.0311231002326961,
                                    0.7188768997673038,
                                    0.010374366744232033,
                                    0.23962563325576797,
                                ],
                                [
                                    0.0311231002326961,
                                    0.010374366744232033,
                                    0.7188768997673038,
                                    0.23962563325576797,
                                ],
                                [
                                    0.039220034862626846,
                                    0.21077996513737315,
                                    0.11766010458788054,
                                    0.6323398954121194,
                                ],
                                [
                                    0.11766010458788054,
                                    0.039220034862626846,
                                    0.6323398954121194,
                                    0.21077996513737315,
                                ],
                                [
                                    0.11766010458788054,
                                    0.6323398954121194,
                                    0.039220034862626846,
                                    0.21077996513737315,
                                ],
                                [
                                    0.00445180302624657,
                                    0.03413113954917315,
                                    0.11093086944733269,
                                    0.8504861879772476,
                                ],
                                [
                                    0.00445180302624657,
                                    0.11093086944733269,
                                    0.03413113954917315,
                                    0.8504861879772476,
                                ],
                                [
                                    0.024933692810082144,
                                    0.19116195028391494,
                                    0.0904489796634971,
                                    0.6934553772425058,
                                ],
                                [
                                    0.03413113954917315,
                                    0.8504861879772476,
                                    0.00445180302624657,
                                    0.11093086944733269,
                                ],
                                [
                                    0.03413113954917315,
                                    0.00445180302624657,
                                    0.8504861879772476,
                                    0.11093086944733269,
                                ],
                                [
                                    0.024933692810082144,
                                    0.0904489796634971,
                                    0.19116195028391494,
                                    0.6934553772425058,
                                ],
                                [
                                    0.19116195028391494,
                                    0.024933692810082144,
                                    0.6934553772425058,
                                    0.0904489796634971,
                                ],
                                [
                                    0.19116195028391494,
                                    0.6934553772425058,
                                    0.024933692810082144,
                                    0.0904489796634971,
                                ],
                                [
                                    0.0008582824568405524,
                                    0.03573438637546339,
                                    0.022596756058493483,
                                    0.9408105751092025,
                                ],
                                [
                                    0.0008582824568405524,
                                    0.022596756058493483,
                                    0.03573438637546339,
                                    0.9408105751092025,
                                ],
                                [
                                    0.006016986556022591,
                                    0.25051580711596,
                                    0.017438051959311446,
                                    0.726029154368706,
                                ],
                                [
                                    0.03573438637546339,
                                    0.9408105751092025,
                                    0.0008582824568405524,
                                    0.022596756058493483,
                                ],
                                [
                                    0.03573438637546339,
                                    0.0008582824568405524,
                                    0.9408105751092025,
                                    0.022596756058493483,
                                ],
                                [
                                    0.006016986556022591,
                                    0.017438051959311446,
                                    0.25051580711596,
                                    0.726029154368706,
                                ],
                                [
                                    0.25051580711596,
                                    0.006016986556022591,
                                    0.726029154368706,
                                    0.017438051959311446,
                                ],
                                [
                                    0.25051580711596,
                                    0.726029154368706,
                                    0.006016986556022591,
                                    0.017438051959311446,
                                ],
                                [
                                    0.010205719983678058,
                                    0.03619654513787415,
                                    0.20973440485600056,
                                    0.7438633300224472,
                                ],
                                [
                                    0.010205719983678058,
                                    0.20973440485600056,
                                    0.03619654513787415,
                                    0.7438633300224472,
                                ],
                                [
                                    0.012586620245534183,
                                    0.04464086498349791,
                                    0.20735350459414445,
                                    0.7354190101768234,
                                ],
                                [
                                    0.012382453814927554,
                                    0.25446774805541916,
                                    0.03401981130662465,
                                    0.6991299868230286,
                                ],
                                [
                                    0.012382453814927554,
                                    0.03401981130662465,
                                    0.25446774805541916,
                                    0.6991299868230286,
                                ],
                                [
                                    0.012586620245534183,
                                    0.20735350459414445,
                                    0.04464086498349791,
                                    0.7354190101768234,
                                ],
                                [
                                    0.015271165985899497,
                                    0.041956319243132596,
                                    0.2515790358844472,
                                    0.6911934788865207,
                                ],
                                [
                                    0.015271165985899497,
                                    0.2515790358844472,
                                    0.041956319243132596,
                                    0.6911934788865207,
                                ],
                                [
                                    0.007883692524994051,
                                    0.03652829885344249,
                                    0.16962900799358344,
                                    0.7859590006279801,
                                ],
                                [
                                    0.007883692524994051,
                                    0.16962900799358344,
                                    0.03652829885344249,
                                    0.7859590006279801,
                                ],
                                [
                                    0.017336713247267047,
                                    0.08032792255975052,
                                    0.16017598727131044,
                                    0.742159376921672,
                                ],
                                [
                                    0.01813244103522919,
                                    0.3901456044305068,
                                    0.026279550343207354,
                                    0.5654424041910566,
                                ],
                                [
                                    0.01813244103522919,
                                    0.026279550343207354,
                                    0.3901456044305068,
                                    0.5654424041910566,
                                ],
                                [
                                    0.017336713247267047,
                                    0.16017598727131044,
                                    0.08032792255975052,
                                    0.742159376921672,
                                ],
                                [
                                    0.039874326618412066,
                                    0.0577903091886055,
                                    0.3684037188473239,
                                    0.5339316453456585,
                                ],
                                [
                                    0.039874326618412066,
                                    0.3684037188473239,
                                    0.0577903091886055,
                                    0.5339316453456585,
                                ],
                                [
                                    0.004788088640682069,
                                    0.03670937833624606,
                                    0.11059458383289718,
                                    0.8479079491901746,
                                ],
                                [
                                    0.004788088640682069,
                                    0.11059458383289718,
                                    0.03670937833624606,
                                    0.8479079491901746,
                                ],
                                [
                                    0.01810124974782733,
                                    0.13877888970268004,
                                    0.09728142272575192,
                                    0.7458384378237407,
                                ],
                                [
                                    0.025536822129146135,
                                    0.5898458503444332,
                                    0.015960644847781997,
                                    0.36865668267863877,
                                ],
                                [
                                    0.025536822129146135,
                                    0.015960644847781997,
                                    0.5898458503444332,
                                    0.36865668267863877,
                                ],
                                [
                                    0.01810124974782733,
                                    0.09728142272575192,
                                    0.13877888970268004,
                                    0.7458384378237407,
                                ],
                                [
                                    0.09654131947308102,
                                    0.06033881997742636,
                                    0.5188413530004983,
                                    0.3242785075489944,
                                ],
                                [
                                    0.09654131947308102,
                                    0.5188413530004983,
                                    0.06033881997742636,
                                    0.3242785075489944,
                                ],
                                [
                                    0.0020546437219771865,
                                    0.03652829885344253,
                                    0.05119800070660383,
                                    0.9102190567179764,
                                ],
                                [
                                    0.0020546437219771865,
                                    0.05119800070660383,
                                    0.03652829885344253,
                                    0.9102190567179764,
                                ],
                                [
                                    0.011507664444250177,
                                    0.20458797864974693,
                                    0.04174497998433084,
                                    0.7421593769216721,
                                ],
                                [
                                    0.031733980244903766,
                                    0.7907533192365187,
                                    0.006848962330515952,
                                    0.1706637381880615,
                                ],
                                [
                                    0.031733980244903766,
                                    0.006848962330515952,
                                    0.7907533192365187,
                                    0.1706637381880615,
                                ],
                                [
                                    0.011507664444250177,
                                    0.04174497998433084,
                                    0.20458797864974693,
                                    0.7421593769216721,
                                ],
                                [
                                    0.177735921918083,
                                    0.03835972117591411,
                                    0.6447513775633396,
                                    0.13915297934266335,
                                ],
                                [
                                    0.177735921918083,
                                    0.6447513775633396,
                                    0.03835972117591411,
                                    0.13915297934266335,
                                ],
                                [
                                    0.00039612369442980903,
                                    0.03619654513787413,
                                    0.010429096413050074,
                                    0.9529782347546459,
                                ],
                                [
                                    0.00039612369442980903,
                                    0.010429096413050074,
                                    0.03619654513787413,
                                    0.9529782347546459,
                                ],
                                [
                                    0.0027770239562859337,
                                    0.25375576971569663,
                                    0.008048196151193949,
                                    0.7354190101768235,
                                ],
                                [
                                    0.03527222761305265,
                                    0.9286429154637592,
                                    0.0013204412192512952,
                                    0.03476441570393688,
                                ],
                                [
                                    0.03527222761305265,
                                    0.0013204412192512952,
                                    0.9286429154637592,
                                    0.03476441570393688,
                                ],
                                [
                                    0.0027770239562859337,
                                    0.008048196151193949,
                                    0.25375576971569663,
                                    0.7354190101768235,
                                ],
                                [
                                    0.2472758445162233,
                                    0.009256949155759244,
                                    0.7166392985605885,
                                    0.026827907767428934,
                                ],
                                [
                                    0.2472758445162233,
                                    0.7166392985605885,
                                    0.009256949155759244,
                                    0.026827907767428934,
                                ],
                                [
                                    0.0020746230795503206,
                                    0.04432764204200189,
                                    0.04263489862409452,
                                    0.9109628362543533,
                                ],
                                [
                                    0.0020746230795503206,
                                    0.04263489862409452,
                                    0.04432764204200189,
                                    0.9109628362543533,
                                ],
                                [
                                    0.0025586134928924247,
                                    0.05466887173613967,
                                    0.042150908210752416,
                                    0.9006216065602155,
                                ],
                                [
                                    0.004251356910799817,
                                    0.08736824182351309,
                                    0.042150908210752396,
                                    0.8662294930549347,
                                ],
                                [
                                    0.004251356910799817,
                                    0.042150908210752396,
                                    0.08736824182351309,
                                    0.8662294930549347,
                                ],
                                [
                                    0.0025586134928924247,
                                    0.042150908210752416,
                                    0.05466887173613967,
                                    0.9006216065602155,
                                ],
                                [
                                    0.005243159233257739,
                                    0.05198432599577436,
                                    0.08637643950105517,
                                    0.8563960752699127,
                                ],
                                [
                                    0.005243159233257739,
                                    0.08637643950105517,
                                    0.05198432599577436,
                                    0.8563960752699127,
                                ],
                                [
                                    0.0016026003545647502,
                                    0.042809391023871796,
                                    0.03448225656862344,
                                    0.92110575205294,
                                ],
                                [
                                    0.0016026003545647502,
                                    0.03448225656862344,
                                    0.042809391023871796,
                                    0.92110575205294,
                                ],
                                [
                                    0.003524214409551511,
                                    0.09414042139746605,
                                    0.03256064251363668,
                                    0.8697747216793458,
                                ],
                                [
                                    0.011851348864799889,
                                    0.2549988530055468,
                                    0.032560642513636655,
                                    0.7005891556160166,
                                ],
                                [
                                    0.011851348864799889,
                                    0.032560642513636655,
                                    0.2549988530055468,
                                    0.7005891556160166,
                                ],
                                [
                                    0.003524214409551511,
                                    0.03256064251363668,
                                    0.09414042139746605,
                                    0.8697747216793458,
                                ],
                                [
                                    0.026061827780696527,
                                    0.07160280802632103,
                                    0.24078837408965018,
                                    0.6615469901033323,
                                ],
                                [
                                    0.026061827780696527,
                                    0.24078837408965018,
                                    0.07160280802632103,
                                    0.6615469901033323,
                                ],
                                [
                                    0.0009733246862326517,
                                    0.04052414229069548,
                                    0.022481713829101385,
                                    0.9360208191939705,
                                ],
                                [
                                    0.0009733246862326517,
                                    0.022481713829101385,
                                    0.04052414229069548,
                                    0.9360208191939705,
                                ],
                                [
                                    0.0036796297131026254,
                                    0.15320050973740476,
                                    0.01977540880223141,
                                    0.8233444517472612,
                                ],
                                [
                                    0.021722058174696718,
                                    0.5017329803406373,
                                    0.019775408802231415,
                                    0.4567695526824345,
                                ],
                                [
                                    0.021722058174696718,
                                    0.019775408802231415,
                                    0.5017329803406373,
                                    0.4567695526824345,
                                ],
                                [
                                    0.0036796297131026254,
                                    0.01977540880223141,
                                    0.15320050973740476,
                                    0.8233444517472612,
                                ],
                                [
                                    0.08211969943835631,
                                    0.07476044001215107,
                                    0.4413353390769777,
                                    0.4017845214725149,
                                ],
                                [
                                    0.08211969943835631,
                                    0.4413353390769777,
                                    0.07476044001215107,
                                    0.4017845214725149,
                                ],
                                [
                                    0.0004176688457731752,
                                    0.038165273729646544,
                                    0.010407551261706708,
                                    0.9510095061628736,
                                ],
                                [
                                    0.0004176688457731752,
                                    0.010407551261706708,
                                    0.038165273729646544,
                                    0.9510095061628736,
                                ],
                                [
                                    0.0023392829007599335,
                                    0.21375636019323715,
                                    0.00848593720671995,
                                    0.7754184196992829,
                                ],
                                [
                                    0.030097005368699758,
                                    0.7499628697916216,
                                    0.008485937206719965,
                                    0.21145418763295865,
                                ],
                                [
                                    0.030097005368699758,
                                    0.008485937206719965,
                                    0.7499628697916216,
                                    0.21145418763295865,
                                ],
                                [
                                    0.0023392829007599335,
                                    0.00848593720671995,
                                    0.21375636019323715,
                                    0.7754184196992829,
                                ],
                                [
                                    0.16856754037459273,
                                    0.04752810271940436,
                                    0.6114923347857286,
                                    0.17241202212027426,
                                ],
                                [
                                    0.16856754037459273,
                                    0.6114923347857286,
                                    0.04752810271940436,
                                    0.17241202212027426,
                                ],
                                [
                                    8.052419232892353e-05,
                                    0.03651214463997502,
                                    0.0021200311346943113,
                                    0.9612873000330018,
                                ],
                                [
                                    8.052419232892353e-05,
                                    0.0021200311346943113,
                                    0.03651214463997502,
                                    0.9612873000330018,
                                ],
                                [
                                    0.0005645146056710336,
                                    0.25596827906631153,
                                    0.0016360407213522011,
                                    0.7418311656066653,
                                ],
                                [
                                    0.03495662811095176,
                                    0.9203338501854034,
                                    0.001636040721352182,
                                    0.043073480982292675,
                                ],
                                [
                                    0.03495662811095176,
                                    0.001636040721352182,
                                    0.9203338501854034,
                                    0.043073480982292675,
                                ],
                                [
                                    0.0005645146056710336,
                                    0.0016360407213522011,
                                    0.25596827906631153,
                                    0.7418311656066653,
                                ],
                                [
                                    0.2450633351656084,
                                    0.011469458506374153,
                                    0.7102271431307468,
                                    0.03324006319727071,
                                ],
                                [
                                    0.2450633351656084,
                                    0.7102271431307468,
                                    0.011469458506374153,
                                    0.03324006319727071,
                                ],
                                [
                                    0.8454615800363878,
                                    0.08527358208112183,
                                    0.06291882122929943,
                                    0.006346016653191003,
                                ],
                                [
                                    0.8454615800363878,
                                    0.06291882122929943,
                                    0.08527358208112183,
                                    0.006346016653191003,
                                ],
                                [
                                    0.866767677334649,
                                    0.08742252329819458,
                                    0.04161272393103817,
                                    0.004197075436118249,
                                ],
                                [
                                    0.8891224381864714,
                                    0.06616804010988378,
                                    0.04161272393103817,
                                    0.003096797772606645,
                                ],
                                [
                                    0.8891224381864714,
                                    0.04161272393103817,
                                    0.06616804010988378,
                                    0.003096797772606645,
                                ],
                                [
                                    0.866767677334649,
                                    0.04161272393103817,
                                    0.08742252329819458,
                                    0.004197075436118249,
                                ],
                                [
                                    0.9115288131482442,
                                    0.042661387484599314,
                                    0.04376166514811092,
                                    0.002048134219045494,
                                ],
                                [
                                    0.9115288131482442,
                                    0.04376166514811092,
                                    0.042661387484599314,
                                    0.002048134219045494,
                                ],
                                [
                                    0.6181331555609622,
                                    0.2249867049885306,
                                    0.1150166425686913,
                                    0.041863496881815995,
                                ],
                                [
                                    0.6181331555609622,
                                    0.1150166425686913,
                                    0.2249867049885306,
                                    0.041863496881815995,
                                ],
                                [
                                    0.7027259385926266,
                                    0.25577659443044526,
                                    0.030423859537026778,
                                    0.011073607439901299,
                                ],
                                [
                                    0.8126960010124659,
                                    0.15121914206434595,
                                    0.030423859537026778,
                                    0.005660997386161358,
                                ],
                                [
                                    0.8126960010124659,
                                    0.030423859537026778,
                                    0.15121914206434595,
                                    0.005660997386161358,
                                ],
                                [
                                    0.7027259385926266,
                                    0.030423859537026778,
                                    0.25577659443044526,
                                    0.011073607439901299,
                                ],
                                [
                                    0.9239151062584209,
                                    0.03458742676465096,
                                    0.0400000368183909,
                                    0.0014974301585371742,
                                ],
                                [
                                    0.9239151062584209,
                                    0.0400000368183909,
                                    0.03458742676465096,
                                    0.0014974301585371742,
                                ],
                                [
                                    0.3406426504746327,
                                    0.37417479175236634,
                                    0.13590231101003328,
                                    0.14928024676296772,
                                ],
                                [
                                    0.3406426504746327,
                                    0.13590231101003328,
                                    0.37417479175236634,
                                    0.14928024676296772,
                                ],
                                [
                                    0.45977889084579915,
                                    0.5050385513811998,
                                    0.016766070638866804,
                                    0.01841648713413421,
                                ],
                                [
                                    0.6980513715881322,
                                    0.2784935898965338,
                                    0.016766070638866804,
                                    0.006688967876467205,
                                ],
                                [
                                    0.6980513715881322,
                                    0.016766070638866804,
                                    0.2784935898965338,
                                    0.006688967876467205,
                                ],
                                [
                                    0.45977889084579915,
                                    0.016766070638866804,
                                    0.5050385513811998,
                                    0.01841648713413421,
                                ],
                                [
                                    0.9421876119592986,
                                    0.022629830267700306,
                                    0.03435734952536731,
                                    0.0008252082476337027,
                                ],
                                [
                                    0.9421876119592986,
                                    0.03435734952536731,
                                    0.022629830267700306,
                                    0.0008252082476337027,
                                ],
                                [
                                    0.128998187577904,
                                    0.4575168363266013,
                                    0.09094193726177464,
                                    0.3225430388337201,
                                ],
                                [
                                    0.128998187577904,
                                    0.09094193726177464,
                                    0.4575168363266013,
                                    0.3225430388337201,
                                ],
                                [
                                    0.21359097060956853,
                                    0.7575413808213575,
                                    0.006349154230110094,
                                    0.022518494338963857,
                                ],
                                [
                                    0.5801658696743952,
                                    0.40900891021812497,
                                    0.006349154230110094,
                                    0.004476065877369788,
                                ],
                                [
                                    0.5801658696743952,
                                    0.006349154230110094,
                                    0.40900891021812497,
                                    0.004476065877369788,
                                ],
                                [
                                    0.21359097060956853,
                                    0.006349154230110094,
                                    0.7575413808213575,
                                    0.022518494338963857,
                                ],
                                [
                                    0.9606196299731917,
                                    0.01051272145773428,
                                    0.028555149919328348,
                                    0.0003124986497456022,
                                ],
                                [
                                    0.9606196299731917,
                                    0.028555149919328348,
                                    0.01051272145773428,
                                    0.0003124986497456022,
                                ],
                                [
                                    0.02230556796374561,
                                    0.4765941543727428,
                                    0.02240395373989923,
                                    0.4786963239236124,
                                ],
                                [
                                    0.02230556796374561,
                                    0.02240395373989923,
                                    0.4765941543727428,
                                    0.4786963239236124,
                                ],
                                [
                                    0.043611665262006875,
                                    0.9318330185591475,
                                    0.0010978564416379592,
                                    0.023457459737207653,
                                ],
                                [
                                    0.4978018658948504,
                                    0.49999757877812634,
                                    0.0010978564416379596,
                                    0.00110269888538525,
                                ],
                                [
                                    0.4978018658948504,
                                    0.0010978564416379596,
                                    0.49999757877812634,
                                    0.00110269888538525,
                                ],
                                [
                                    0.043611665262006875,
                                    0.0010978564416379592,
                                    0.9318330185591475,
                                    0.023457459737207653,
                                ],
                                [
                                    0.9732981638259552,
                                    0.0021465199951991114,
                                    0.024501280847021516,
                                    5.4035331824097916e-05,
                                ],
                                [
                                    0.9732981638259552,
                                    0.024501280847021516,
                                    0.0021465199951991114,
                                    5.4035331824097916e-05,
                                ],
                                [
                                    0.6823682962186224,
                                    0.2483668658988872,
                                    0.05078150191103103,
                                    0.0184833359714594,
                                ],
                                [
                                    0.6823682962186224,
                                    0.05078150191103103,
                                    0.2483668658988872,
                                    0.0184833359714594,
                                ],
                                [
                                    0.6995643529712627,
                                    0.2546258476615808,
                                    0.03358544515839065,
                                    0.012224354208765765,
                                ],
                                [
                                    0.7260291543687061,
                                    0.05403072079161538,
                                    0.20470600774880354,
                                    0.01523411709087504,
                                ],
                                [
                                    0.7260291543687061,
                                    0.20470600774880354,
                                    0.05403072079161538,
                                    0.01523411709087504,
                                ],
                                [
                                    0.6995643529712627,
                                    0.03358544515839065,
                                    0.2546258476615808,
                                    0.012224354208765765,
                                ],
                                [
                                    0.7443254887848579,
                                    0.20986471184798555,
                                    0.0357343863754634,
                                    0.01007541299169301,
                                ],
                                [
                                    0.7443254887848579,
                                    0.0357343863754634,
                                    0.20986471184798555,
                                    0.01007541299169301,
                                ],
                                [
                                    0.49889253179100207,
                                    0.34422732875849066,
                                    0.0928294227432621,
                                    0.0640507167072452,
                                ],
                                [
                                    0.49889253179100207,
                                    0.0928294227432621,
                                    0.34422732875849066,
                                    0.0640507167072452,
                                ],
                                [
                                    0.5671669922664552,
                                    0.39133554075661675,
                                    0.024554962267808962,
                                    0.016942504709119115,
                                ],
                                [
                                    0.6934553772425059,
                                    0.12903192223891674,
                                    0.14966448330698684,
                                    0.027848217211590563,
                                ],
                                [
                                    0.6934553772425059,
                                    0.14966448330698684,
                                    0.12903192223891674,
                                    0.027848217211590563,
                                ],
                                [
                                    0.5671669922664552,
                                    0.024554962267808962,
                                    0.39133554075661675,
                                    0.016942504709119115,
                                ],
                                [
                                    0.7883561599322495,
                                    0.1701463730908224,
                                    0.03413113954917309,
                                    0.007366327427754989,
                                ],
                                [
                                    0.7883561599322495,
                                    0.03413113954917309,
                                    0.1701463730908224,
                                    0.007366327427754989,
                                ],
                                [
                                    0.27493117429862,
                                    0.43988626792837904,
                                    0.10968615322780073,
                                    0.17549640454520027,
                                ],
                                [
                                    0.27493117429862,
                                    0.10968615322780073,
                                    0.43988626792837904,
                                    0.17549640454520027,
                                ],
                                [
                                    0.3710855061802252,
                                    0.5937319360467738,
                                    0.01353182134619555,
                                    0.021650736426805463,
                                ],
                                [
                                    0.6323398954121195,
                                    0.25227743211430126,
                                    0.08247754681487947,
                                    0.03290512565869976,
                                ],
                                [
                                    0.6323398954121195,
                                    0.08247754681487947,
                                    0.25227743211430126,
                                    0.03290512565869976,
                                ],
                                [
                                    0.3710855061802252,
                                    0.01353182134619555,
                                    0.5937319360467738,
                                    0.021650736426805463,
                                ],
                                [
                                    0.8534942272937247,
                                    0.11132321493327427,
                                    0.031123100232696058,
                                    0.004059457540304955,
                                ],
                                [
                                    0.8534942272937247,
                                    0.031123100232696058,
                                    0.11132321493327427,
                                    0.004059457540304955,
                                ],
                                [
                                    0.10411386578800676,
                                    0.48240115811649853,
                                    0.07339883473057073,
                                    0.340086141364924,
                                ],
                                [
                                    0.10411386578800676,
                                    0.07339883473057073,
                                    0.48240115811649853,
                                    0.340086141364924,
                                ],
                                [
                                    0.1723883262634599,
                                    0.7987440251674661,
                                    0.005124374255117566,
                                    0.023743274313956383,
                                ],
                                [
                                    0.5552815478844979,
                                    0.391465807686921,
                                    0.03123347602000733,
                                    0.022019168408573712,
                                ],
                                [
                                    0.5552815478844979,
                                    0.03123347602000733,
                                    0.391465807686921,
                                    0.022019168408573712,
                                ],
                                [
                                    0.1723883262634599,
                                    0.005124374255117566,
                                    0.7987440251674661,
                                    0.023743274313956383,
                                ],
                                [
                                    0.9194169856270832,
                                    0.05171536580384291,
                                    0.027330369944335818,
                                    0.0015372786247381314,
                                ],
                                [
                                    0.9194169856270832,
                                    0.027330369944335818,
                                    0.05171536580384291,
                                    0.0015372786247381314,
                                ],
                                [
                                    0.0180027250995305,
                                    0.4808969972369579,
                                    0.018082131823657692,
                                    0.4830181458398539,
                                ],
                                [
                                    0.0180027250995305,
                                    0.018082131823657692,
                                    0.4808969972369579,
                                    0.4830181458398539,
                                ],
                                [
                                    0.035198781852170895,
                                    0.9402459019689835,
                                    0.0008860750710172921,
                                    0.02366924110782832,
                                ],
                                [
                                    0.4934990230306353,
                                    0.4956757568618848,
                                    0.0054006993058530895,
                                    0.0054245208016268035,
                                ],
                                [
                                    0.4934990230306353,
                                    0.0054006993058530895,
                                    0.4956757568618848,
                                    0.0054245208016268035,
                                ],
                                [
                                    0.035198781852170895,
                                    0.0008860750710172921,
                                    0.9402459019689835,
                                    0.02366924110782832,
                                ],
                                [
                                    0.9648852804161192,
                                    0.010559403405035127,
                                    0.02428949947640085,
                                    0.00026581670244476586,
                                ],
                                [
                                    0.9648852804161192,
                                    0.02428949947640085,
                                    0.010559403405035127,
                                    0.00026581670244476586,
                                ],
                                [
                                    0.44353715198371296,
                                    0.48719801013379666,
                                    0.03300780950095303,
                                    0.036257028381537396,
                                ],
                                [
                                    0.44353715198371296,
                                    0.03300780950095303,
                                    0.48719801013379666,
                                    0.036257028381537396,
                                ],
                                [
                                    0.4547145324096241,
                                    0.4994756682232194,
                                    0.02183042907504183,
                                    0.023979370292114586,
                                ],
                                [
                                    0.48719801013379666,
                                    0.036257028381537396,
                                    0.44353715198371296,
                                    0.03300780950095303,
                                ],
                                [
                                    0.48719801013379666,
                                    0.44353715198371296,
                                    0.036257028381537396,
                                    0.03300780950095303,
                                ],
                                [
                                    0.4547145324096241,
                                    0.02183042907504183,
                                    0.4994756682232194,
                                    0.023979370292114586,
                                ],
                                [
                                    0.4994756682232194,
                                    0.4547145324096241,
                                    0.023979370292114586,
                                    0.02183042907504183,
                                ],
                                [
                                    0.4994756682232194,
                                    0.023979370292114586,
                                    0.4547145324096241,
                                    0.02183042907504183,
                                ],
                                [
                                    0.3242785075489945,
                                    0.5188413530004982,
                                    0.06033881997742634,
                                    0.09654131947308095,
                                ],
                                [
                                    0.3242785075489945,
                                    0.06033881997742634,
                                    0.5188413530004982,
                                    0.09654131947308095,
                                ],
                                [
                                    0.3686566826786389,
                                    0.589845850344433,
                                    0.01596064484778198,
                                    0.025536822129146097,
                                ],
                                [
                                    0.5188413530004983,
                                    0.09654131947308098,
                                    0.32427850754899445,
                                    0.06033881997742633,
                                ],
                                [
                                    0.5188413530004983,
                                    0.32427850754899445,
                                    0.09654131947308098,
                                    0.06033881997742633,
                                ],
                                [
                                    0.3686566826786389,
                                    0.01596064484778198,
                                    0.589845850344433,
                                    0.025536822129146097,
                                ],
                                [
                                    0.5898458503444332,
                                    0.36865668267863877,
                                    0.0255368221291461,
                                    0.015960644847781976,
                                ],
                                [
                                    0.5898458503444332,
                                    0.0255368221291461,
                                    0.36865668267863877,
                                    0.015960644847781976,
                                ],
                                [
                                    0.17870436055674976,
                                    0.5361130816702493,
                                    0.07129563944325025,
                                    0.21388691832975076,
                                ],
                                [
                                    0.17870436055674976,
                                    0.07129563944325025,
                                    0.5361130816702493,
                                    0.21388691832975076,
                                ],
                                [
                                    0.24120436055674974,
                                    0.7236130816702492,
                                    0.008795639443250253,
                                    0.02638691832975076,
                                ],
                                [
                                    0.5361130816702493,
                                    0.21388691832975076,
                                    0.17870436055674976,
                                    0.07129563944325025,
                                ],
                                [
                                    0.5361130816702493,
                                    0.17870436055674976,
                                    0.21388691832975076,
                                    0.07129563944325025,
                                ],
                                [
                                    0.24120436055674974,
                                    0.008795639443250253,
                                    0.7236130816702492,
                                    0.02638691832975076,
                                ],
                                [
                                    0.7236130816702492,
                                    0.24120436055674974,
                                    0.02638691832975076,
                                    0.008795639443250253,
                                ],
                                [
                                    0.7236130816702492,
                                    0.02638691832975076,
                                    0.24120436055674974,
                                    0.008795639443250253,
                                ],
                                [
                                    0.06767367090400704,
                                    0.5188413530004983,
                                    0.04770900156957222,
                                    0.36577597452592253,
                                ],
                                [
                                    0.06767367090400704,
                                    0.04770900156957222,
                                    0.5188413530004983,
                                    0.36577597452592253,
                                ],
                                [
                                    0.1120518460336514,
                                    0.8590805053972747,
                                    0.0033308264399278483,
                                    0.0255368221291461,
                                ],
                                [
                                    0.5188413530004983,
                                    0.36577597452592253,
                                    0.06767367090400704,
                                    0.04770900156957222,
                                ],
                                [
                                    0.5188413530004983,
                                    0.06767367090400704,
                                    0.36577597452592253,
                                    0.04770900156957222,
                                ],
                                [
                                    0.1120518460336514,
                                    0.0033308264399278483,
                                    0.8590805053972747,
                                    0.0255368221291461,
                                ],
                                [
                                    0.8590805053972747,
                                    0.1120518460336514,
                                    0.0255368221291461,
                                    0.0033308264399278483,
                                ],
                                [
                                    0.8590805053972747,
                                    0.0255368221291461,
                                    0.1120518460336514,
                                    0.0033308264399278483,
                                ],
                                [
                                    0.011701712202691792,
                                    0.4871980101337966,
                                    0.011753326312642245,
                                    0.48934695135086936,
                                ],
                                [
                                    0.011701712202691792,
                                    0.011753326312642245,
                                    0.4871980101337966,
                                    0.48934695135086936,
                                ],
                                [
                                    0.022879092628603007,
                                    0.9525655911925514,
                                    0.0005759458867310289,
                                    0.023979370292114582,
                                ],
                                [
                                    0.4871980101337966,
                                    0.48934695135086936,
                                    0.011701712202691792,
                                    0.011753326312642245,
                                ],
                                [
                                    0.4871980101337966,
                                    0.011701712202691792,
                                    0.48934695135086936,
                                    0.011753326312642245,
                                ],
                                [
                                    0.022879092628603007,
                                    0.0005759458867310289,
                                    0.9525655911925514,
                                    0.023979370292114582,
                                ],
                                [
                                    0.9525655911925514,
                                    0.022879092628603007,
                                    0.023979370292114582,
                                    0.0005759458867310289,
                                ],
                                [
                                    0.9525655911925514,
                                    0.023979370292114582,
                                    0.022879092628603007,
                                    0.0005759458867310289,
                                ],
                                [
                                    0.20470600774880357,
                                    0.7260291543687061,
                                    0.015234117090875045,
                                    0.05403072079161538,
                                ],
                                [
                                    0.20470600774880357,
                                    0.015234117090875045,
                                    0.7260291543687061,
                                    0.05403072079161538,
                                ],
                                [
                                    0.2098647118479856,
                                    0.7443254887848579,
                                    0.010075412991693013,
                                    0.0357343863754634,
                                ],
                                [
                                    0.2483668658988873,
                                    0.018483335971459406,
                                    0.6823682962186223,
                                    0.050781501911031014,
                                ],
                                [
                                    0.2483668658988873,
                                    0.6823682962186223,
                                    0.018483335971459406,
                                    0.050781501911031014,
                                ],
                                [
                                    0.2098647118479856,
                                    0.010075412991693013,
                                    0.7443254887848579,
                                    0.0357343863754634,
                                ],
                                [
                                    0.2546258476615809,
                                    0.6995643529712626,
                                    0.01222435420876577,
                                    0.033585445158390646,
                                ],
                                [
                                    0.2546258476615809,
                                    0.01222435420876577,
                                    0.6995643529712626,
                                    0.033585445158390646,
                                ],
                                [
                                    0.14966448330698692,
                                    0.6934553772425058,
                                    0.027848217211590576,
                                    0.1290319222389167,
                                ],
                                [
                                    0.14966448330698692,
                                    0.027848217211590576,
                                    0.6934553772425058,
                                    0.1290319222389167,
                                ],
                                [
                                    0.17014637309082248,
                                    0.7883561599322494,
                                    0.007366327427754993,
                                    0.03413113954917309,
                                ],
                                [
                                    0.34422732875849077,
                                    0.06405071670724521,
                                    0.49889253179100196,
                                    0.09282942274326209,
                                ],
                                [
                                    0.34422732875849077,
                                    0.49889253179100196,
                                    0.06405071670724521,
                                    0.09282942274326209,
                                ],
                                [
                                    0.17014637309082248,
                                    0.007366327427754993,
                                    0.7883561599322494,
                                    0.03413113954917309,
                                ],
                                [
                                    0.39133554075661686,
                                    0.5671669922664551,
                                    0.016942504709119118,
                                    0.02455496226780896,
                                ],
                                [
                                    0.39133554075661686,
                                    0.016942504709119118,
                                    0.5671669922664551,
                                    0.02455496226780896,
                                ],
                                [
                                    0.0824775468148795,
                                    0.6323398954121195,
                                    0.03290512565869977,
                                    0.25227743211430126,
                                ],
                                [
                                    0.0824775468148795,
                                    0.03290512565869977,
                                    0.6323398954121195,
                                    0.25227743211430126,
                                ],
                                [
                                    0.1113232149332743,
                                    0.8534942272937247,
                                    0.004059457540304956,
                                    0.031123100232696058,
                                ],
                                [
                                    0.43988626792837904,
                                    0.17549640454520027,
                                    0.27493117429862,
                                    0.10968615322780073,
                                ],
                                [
                                    0.43988626792837904,
                                    0.27493117429862,
                                    0.17549640454520027,
                                    0.10968615322780073,
                                ],
                                [
                                    0.1113232149332743,
                                    0.004059457540304956,
                                    0.8534942272937247,
                                    0.031123100232696058,
                                ],
                                [
                                    0.5937319360467738,
                                    0.3710855061802252,
                                    0.021650736426805463,
                                    0.01353182134619555,
                                ],
                                [
                                    0.5937319360467738,
                                    0.021650736426805463,
                                    0.3710855061802252,
                                    0.01353182134619555,
                                ],
                                [
                                    0.031233476020007315,
                                    0.5552815478844979,
                                    0.022019168408573705,
                                    0.391465807686921,
                                ],
                                [
                                    0.031233476020007315,
                                    0.022019168408573705,
                                    0.5552815478844979,
                                    0.391465807686921,
                                ],
                                [
                                    0.05171536580384289,
                                    0.9194169856270832,
                                    0.0015372786247381308,
                                    0.027330369944335818,
                                ],
                                [
                                    0.48240115811649853,
                                    0.340086141364924,
                                    0.10411386578800674,
                                    0.07339883473057071,
                                ],
                                [
                                    0.48240115811649853,
                                    0.10411386578800674,
                                    0.340086141364924,
                                    0.07339883473057071,
                                ],
                                [
                                    0.05171536580384289,
                                    0.0015372786247381308,
                                    0.9194169856270832,
                                    0.027330369944335818,
                                ],
                                [
                                    0.7987440251674661,
                                    0.17238832626345987,
                                    0.023743274313956383,
                                    0.005124374255117565,
                                ],
                                [
                                    0.7987440251674661,
                                    0.023743274313956383,
                                    0.17238832626345987,
                                    0.005124374255117565,
                                ],
                                [
                                    0.005400699305853084,
                                    0.4934990230306353,
                                    0.005424520801626798,
                                    0.4956757568618848,
                                ],
                                [
                                    0.005400699305853084,
                                    0.005424520801626798,
                                    0.4934990230306353,
                                    0.4956757568618848,
                                ],
                                [
                                    0.010559403405035117,
                                    0.9648852804161192,
                                    0.0002658167024447656,
                                    0.02428949947640085,
                                ],
                                [
                                    0.4808969972369579,
                                    0.4830181458398539,
                                    0.018002725099530492,
                                    0.018082131823657685,
                                ],
                                [
                                    0.4808969972369579,
                                    0.018002725099530492,
                                    0.4830181458398539,
                                    0.018082131823657685,
                                ],
                                [
                                    0.010559403405035117,
                                    0.0002658167024447656,
                                    0.9648852804161192,
                                    0.02428949947640085,
                                ],
                                [
                                    0.9402459019689835,
                                    0.03519878185217088,
                                    0.02366924110782832,
                                    0.0008860750710172917,
                                ],
                                [
                                    0.9402459019689835,
                                    0.02366924110782832,
                                    0.03519878185217088,
                                    0.0008860750710172917,
                                ],
                                [
                                    0.041612723931038195,
                                    0.8891224381864714,
                                    0.0030967977726066467,
                                    0.06616804010988378,
                                ],
                                [
                                    0.041612723931038195,
                                    0.0030967977726066467,
                                    0.8891224381864714,
                                    0.06616804010988378,
                                ],
                                [
                                    0.04266138748459934,
                                    0.9115288131482442,
                                    0.0020481342190454953,
                                    0.04376166514811092,
                                ],
                                [
                                    0.0852735820811219,
                                    0.0063460166531910086,
                                    0.8454615800363877,
                                    0.06291882122929941,
                                ],
                                [
                                    0.0852735820811219,
                                    0.8454615800363877,
                                    0.0063460166531910086,
                                    0.06291882122929941,
                                ],
                                [
                                    0.04266138748459934,
                                    0.0020481342190454953,
                                    0.9115288131482442,
                                    0.04376166514811092,
                                ],
                                [
                                    0.08742252329819465,
                                    0.8667676773346489,
                                    0.004197075436118252,
                                    0.04161272393103816,
                                ],
                                [
                                    0.08742252329819465,
                                    0.004197075436118252,
                                    0.8667676773346489,
                                    0.04161272393103816,
                                ],
                                [
                                    0.030423859537026823,
                                    0.8126960010124659,
                                    0.005660997386161367,
                                    0.15121914206434595,
                                ],
                                [
                                    0.030423859537026823,
                                    0.005660997386161367,
                                    0.8126960010124659,
                                    0.15121914206434595,
                                ],
                                [
                                    0.034587426764651014,
                                    0.9239151062584209,
                                    0.0014974301585371763,
                                    0.0400000368183909,
                                ],
                                [
                                    0.22498670498853068,
                                    0.041863496881816016,
                                    0.618133155560962,
                                    0.11501664256869129,
                                ],
                                [
                                    0.22498670498853068,
                                    0.618133155560962,
                                    0.041863496881816016,
                                    0.11501664256869129,
                                ],
                                [
                                    0.034587426764651014,
                                    0.0014974301585371763,
                                    0.9239151062584209,
                                    0.0400000368183909,
                                ],
                                [
                                    0.25577659443044537,
                                    0.7027259385926264,
                                    0.011073607439901302,
                                    0.030423859537026775,
                                ],
                                [
                                    0.25577659443044537,
                                    0.011073607439901302,
                                    0.7027259385926264,
                                    0.030423859537026775,
                                ],
                                [
                                    0.016766070638866825,
                                    0.6980513715881322,
                                    0.006688967876467213,
                                    0.2784935898965338,
                                ],
                                [
                                    0.016766070638866825,
                                    0.006688967876467213,
                                    0.6980513715881322,
                                    0.2784935898965338,
                                ],
                                [
                                    0.02262983026770033,
                                    0.9421876119592986,
                                    0.0008252082476337037,
                                    0.03435734952536731,
                                ],
                                [
                                    0.37417479175236634,
                                    0.14928024676296772,
                                    0.3406426504746327,
                                    0.13590231101003328,
                                ],
                                [
                                    0.37417479175236634,
                                    0.3406426504746327,
                                    0.14928024676296772,
                                    0.13590231101003328,
                                ],
                                [
                                    0.02262983026770033,
                                    0.0008252082476337037,
                                    0.9421876119592986,
                                    0.03435734952536731,
                                ],
                                [
                                    0.5050385513811998,
                                    0.45977889084579915,
                                    0.01841648713413421,
                                    0.016766070638866804,
                                ],
                                [
                                    0.5050385513811998,
                                    0.01841648713413421,
                                    0.45977889084579915,
                                    0.016766070638866804,
                                ],
                                [
                                    0.006349154230110094,
                                    0.5801658696743952,
                                    0.004476065877369788,
                                    0.40900891021812497,
                                ],
                                [
                                    0.006349154230110094,
                                    0.004476065877369788,
                                    0.5801658696743952,
                                    0.40900891021812497,
                                ],
                                [
                                    0.01051272145773428,
                                    0.9606196299731917,
                                    0.0003124986497456022,
                                    0.028555149919328348,
                                ],
                                [
                                    0.4575168363266013,
                                    0.3225430388337201,
                                    0.128998187577904,
                                    0.09094193726177464,
                                ],
                                [
                                    0.4575168363266013,
                                    0.128998187577904,
                                    0.3225430388337201,
                                    0.09094193726177464,
                                ],
                                [
                                    0.01051272145773428,
                                    0.0003124986497456022,
                                    0.9606196299731917,
                                    0.028555149919328348,
                                ],
                                [
                                    0.7575413808213575,
                                    0.21359097060956853,
                                    0.022518494338963857,
                                    0.006349154230110094,
                                ],
                                [
                                    0.7575413808213575,
                                    0.022518494338963857,
                                    0.21359097060956853,
                                    0.006349154230110094,
                                ],
                                [
                                    0.0010978564416379722,
                                    0.4978018658948504,
                                    0.0011026988853852625,
                                    0.49999757877812634,
                                ],
                                [
                                    0.0010978564416379722,
                                    0.0011026988853852625,
                                    0.4978018658948504,
                                    0.49999757877812634,
                                ],
                                [
                                    0.002146519995199136,
                                    0.9732981638259552,
                                    5.403533182409853e-05,
                                    0.024501280847021516,
                                ],
                                [
                                    0.4765941543727428,
                                    0.4786963239236124,
                                    0.02230556796374562,
                                    0.02240395373989924,
                                ],
                                [
                                    0.4765941543727428,
                                    0.02230556796374562,
                                    0.4786963239236124,
                                    0.02240395373989924,
                                ],
                                [
                                    0.002146519995199136,
                                    5.403533182409853e-05,
                                    0.9732981638259552,
                                    0.024501280847021516,
                                ],
                                [
                                    0.9318330185591475,
                                    0.043611665262006896,
                                    0.023457459737207653,
                                    0.0010978564416379596,
                                ],
                                [
                                    0.9318330185591475,
                                    0.023457459737207653,
                                    0.043611665262006896,
                                    0.0010978564416379596,
                                ],
                                [
                                    0.6823682962186224,
                                    0.0688239303726251,
                                    0.2260121050470648,
                                    0.022795668361687733,
                                ],
                                [
                                    0.6823682962186224,
                                    0.2260121050470648,
                                    0.0688239303726251,
                                    0.022795668361687733,
                                ],
                                [
                                    0.7036743935168837,
                                    0.07097287158969784,
                                    0.20470600774880354,
                                    0.02064672714461498,
                                ],
                                [
                                    0.7176067814328568,
                                    0.23768369686349836,
                                    0.03358544515839065,
                                    0.011124076545254161,
                                ],
                                [
                                    0.7176067814328568,
                                    0.03358544515839065,
                                    0.23768369686349836,
                                    0.011124076545254161,
                                ],
                                [
                                    0.7036743935168837,
                                    0.20470600774880354,
                                    0.07097287158969784,
                                    0.02064672714461498,
                                ],
                                [
                                    0.7400131563946296,
                                    0.0346341087119518,
                                    0.2152773219017255,
                                    0.01007541299169301,
                                ],
                                [
                                    0.7400131563946296,
                                    0.2152773219017255,
                                    0.0346341087119518,
                                    0.01007541299169301,
                                ],
                                [
                                    0.49889253179100207,
                                    0.18158577300255083,
                                    0.23425726633865138,
                                    0.08526442886779577,
                                ],
                                [
                                    0.49889253179100207,
                                    0.23425726633865138,
                                    0.18158577300255083,
                                    0.08526442886779577,
                                ],
                                [
                                    0.5834853148226666,
                                    0.2123756624444655,
                                    0.14966448330698687,
                                    0.054474539425881076,
                                ],
                                [
                                    0.6559233425257439,
                                    0.30799180055106795,
                                    0.024554962267808962,
                                    0.011529894655379173,
                                ],
                                [
                                    0.6559233425257439,
                                    0.024554962267808962,
                                    0.30799180055106795,
                                    0.011529894655379173,
                                ],
                                [
                                    0.5834853148226666,
                                    0.14966448330698687,
                                    0.2123756624444655,
                                    0.054474539425881076,
                                ],
                                [
                                    0.7671424477716989,
                                    0.02871852949543315,
                                    0.19677269530511293,
                                    0.00736632742775499,
                                ],
                                [
                                    0.7671424477716989,
                                    0.19677269530511293,
                                    0.02871852949543315,
                                    0.00736632742775499,
                                ],
                                [
                                    0.27493117429862,
                                    0.30199481699101116,
                                    0.20161378718604595,
                                    0.22146022152432288,
                                ],
                                [
                                    0.27493117429862,
                                    0.20161378718604595,
                                    0.30199481699101116,
                                    0.22146022152432288,
                                ],
                                [
                                    0.3940674146697865,
                                    0.43285857661984467,
                                    0.08247754681487945,
                                    0.09059646189548937,
                                ],
                                [
                                    0.5633941699434356,
                                    0.41315079154123036,
                                    0.013531821346195553,
                                    0.009923217169138457,
                                ],
                                [
                                    0.5633941699434356,
                                    0.013531821346195553,
                                    0.41315079154123036,
                                    0.009923217169138457,
                                ],
                                [
                                    0.3940674146697865,
                                    0.08247754681487945,
                                    0.43285857661984467,
                                    0.09059646189548937,
                                ],
                                [
                                    0.8075304103146022,
                                    0.019395580975029053,
                                    0.16901455117006386,
                                    0.004059457540304954,
                                ],
                                [
                                    0.8075304103146022,
                                    0.16901455117006386,
                                    0.019395580975029053,
                                    0.004059457540304954,
                                ],
                                [
                                    0.10411386578800674,
                                    0.36925981199770275,
                                    0.11582625905167188,
                                    0.41080006316261863,
                                ],
                                [
                                    0.10411386578800674,
                                    0.11582625905167188,
                                    0.36925981199770275,
                                    0.41080006316261863,
                                ],
                                [
                                    0.18870664881967128,
                                    0.669284356492459,
                                    0.031233476020007325,
                                    0.11077551866786241,
                                ],
                                [
                                    0.4682493035305919,
                                    0.5209254763619282,
                                    0.005124374255117565,
                                    0.005700845852362317,
                                ],
                                [
                                    0.4682493035305919,
                                    0.005124374255117565,
                                    0.5209254763619282,
                                    0.005700845852362317,
                                ],
                                [
                                    0.18870664881967128,
                                    0.031233476020007325,
                                    0.669284356492459,
                                    0.11077551866786241,
                                ],
                                [
                                    0.8487030638293885,
                                    0.00928794148274175,
                                    0.1404717160631316,
                                    0.0015372786247381312,
                                ],
                                [
                                    0.8487030638293885,
                                    0.1404717160631316,
                                    0.00928794148274175,
                                    0.0015372786247381312,
                                ],
                                [
                                    0.018002725099530485,
                                    0.38465703088848435,
                                    0.026706796604114354,
                                    0.5706334474078708,
                                ],
                                [
                                    0.018002725099530485,
                                    0.026706796604114354,
                                    0.38465703088848435,
                                    0.5706334474078708,
                                ],
                                [
                                    0.03930882239779175,
                                    0.839895895074889,
                                    0.005400699305853086,
                                    0.11539458322146608,
                                ],
                                [
                                    0.40177368091699756,
                                    0.5960257637559793,
                                    0.0008860750710172918,
                                    0.0013144802560059179,
                                ],
                                [
                                    0.40177368091699756,
                                    0.0008860750710172918,
                                    0.5960257637559793,
                                    0.0013144802560059179,
                                ],
                                [
                                    0.03930882239779175,
                                    0.005400699305853086,
                                    0.839895895074889,
                                    0.11539458322146608,
                                ],
                                [
                                    0.8772699788481023,
                                    0.0019347386245784437,
                                    0.1205294658248744,
                                    0.0002658167024447658,
                                ],
                                [
                                    0.8772699788481023,
                                    0.1205294658248744,
                                    0.0019347386245784437,
                                    0.0002658167024447658,
                                ],
                                [
                                    0.550736429281938,
                                    0.20045579730930954,
                                    0.18241336884771545,
                                    0.06639440456103705,
                                ],
                                [
                                    0.550736429281938,
                                    0.18241336884771545,
                                    0.20045579730930954,
                                    0.06639440456103705,
                                ],
                                [
                                    0.5679324860345782,
                                    0.20671477907200314,
                                    0.1652173120950751,
                                    0.06013542279834343,
                                ],
                                [
                                    0.5859749144961723,
                                    0.19408496066414901,
                                    0.1652173120950751,
                                    0.054722812744603486,
                                ],
                                [
                                    0.5859749144961723,
                                    0.1652173120950751,
                                    0.19408496066414901,
                                    0.054722812744603486,
                                ],
                                [
                                    0.5679324860345782,
                                    0.1652173120950751,
                                    0.20671477907200314,
                                    0.06013542279834343,
                                ],
                                [
                                    0.6042712489123243,
                                    0.1703760161942571,
                                    0.17578862624799704,
                                    0.049564108645421455,
                                ],
                                [
                                    0.6042712489123243,
                                    0.17578862624799704,
                                    0.1703760161942571,
                                    0.049564108645421455,
                                ],
                                [
                                    0.4026539525306038,
                                    0.27782435226294905,
                                    0.1890680020036603,
                                    0.13045369320278682,
                                ],
                                [
                                    0.4026539525306038,
                                    0.1890680020036603,
                                    0.27782435226294905,
                                    0.13045369320278682,
                                ],
                                [
                                    0.470928413006057,
                                    0.32493256426107514,
                                    0.12079354152820719,
                                    0.08334548120466075,
                                ],
                                [
                                    0.5596847632653457,
                                    0.2628025362160769,
                                    0.12079354152820718,
                                    0.056719158990370215,
                                ],
                                [
                                    0.5596847632653457,
                                    0.12079354152820718,
                                    0.2628025362160769,
                                    0.056719158990370215,
                                ],
                                [
                                    0.470928413006057,
                                    0.12079354152820719,
                                    0.32493256426107514,
                                    0.08334548120466075,
                                ],
                                [
                                    0.6545855459550893,
                                    0.14127543131204276,
                                    0.1679017535263333,
                                    0.036237269206534646,
                                ],
                                [
                                    0.6545855459550893,
                                    0.1679017535263333,
                                    0.14127543131204276,
                                    0.036237269206534646,
                                ],
                                [
                                    0.22189573295034903,
                                    0.35503025833928215,
                                    0.16272159457607172,
                                    0.2603524141342971,
                                ],
                                [
                                    0.22189573295034903,
                                    0.16272159457607172,
                                    0.35503025833928215,
                                    0.2603524141342971,
                                ],
                                [
                                    0.31805006483195425,
                                    0.508875926457677,
                                    0.06656726269446653,
                                    0.10650674601590229,
                                ],
                                [
                                    0.5103587285951646,
                                    0.3742585989312561,
                                    0.06656726269446653,
                                    0.04881540977911269,
                                ],
                                [
                                    0.5103587285951646,
                                    0.06656726269446653,
                                    0.3742585989312561,
                                    0.04881540977911269,
                                ],
                                [
                                    0.31805006483195425,
                                    0.06656726269446653,
                                    0.508875926457677,
                                    0.10650674601590229,
                                ],
                                [
                                    0.7315130604767698,
                                    0.09541293081286134,
                                    0.15310426704965094,
                                    0.019969741660717882,
                                ],
                                [
                                    0.7315130604767698,
                                    0.15310426704965094,
                                    0.09541293081286134,
                                    0.019969741660717882,
                                ],
                                [
                                    0.08402983989815224,
                                    0.3893438378875572,
                                    0.09348286062042524,
                                    0.4331434615938653,
                                ],
                                [
                                    0.08402983989815224,
                                    0.09348286062042524,
                                    0.3893438378875572,
                                    0.4331434615938653,
                                ],
                                [
                                    0.1523043003736054,
                                    0.7056867049385248,
                                    0.025208400144972082,
                                    0.11680059454289765,
                                ],
                                [
                                    0.44816527764073744,
                                    0.49858207793068154,
                                    0.02520840014497208,
                                    0.028044244283608962,
                                ],
                                [
                                    0.44816527764073744,
                                    0.02520840014497208,
                                    0.49858207793068154,
                                    0.028044244283608962,
                                ],
                                [
                                    0.1523043003736054,
                                    0.025208400144972082,
                                    0.7056867049385248,
                                    0.11680059454289765,
                                ],
                                [
                                    0.8123007153833226,
                                    0.04569028992880766,
                                    0.13444664018809635,
                                    0.007562354499773381,
                                ],
                                [
                                    0.8123007153833226,
                                    0.13444664018809635,
                                    0.04569028992880766,
                                    0.007562354499773381,
                                ],
                                [
                                    0.014529919683553385,
                                    0.38812983630446146,
                                    0.021554937239634805,
                                    0.5757853067723504,
                                ],
                                [
                                    0.014529919683553385,
                                    0.021554937239634805,
                                    0.38812983630446146,
                                    0.5757853067723504,
                                ],
                                [
                                    0.031725976436193785,
                                    0.847478741036487,
                                    0.0043588804869944065,
                                    0.11643640204032475,
                                ],
                                [
                                    0.39830087550102045,
                                    0.5908739043914997,
                                    0.004358880486994406,
                                    0.006466339620485487,
                                ],
                                [
                                    0.39830087550102045,
                                    0.004358880486994406,
                                    0.5908739043914997,
                                    0.006466339620485487,
                                ],
                                [
                                    0.031725976436193785,
                                    0.0043588804869944065,
                                    0.847478741036487,
                                    0.11643640204032475,
                                ],
                                [
                                    0.8696871328865043,
                                    0.009517584586176443,
                                    0.11948764700601572,
                                    0.00130763552130345,
                                ],
                                [
                                    0.8696871328865043,
                                    0.11948764700601572,
                                    0.009517584586176443,
                                    0.00130763552130345,
                                ],
                                [
                                    0.35797687068850653,
                                    0.393215355902741,
                                    0.11856809079615946,
                                    0.13023968261259306,
                                ],
                                [
                                    0.35797687068850653,
                                    0.11856809079615946,
                                    0.393215355902741,
                                    0.13023968261259306,
                                ],
                                [
                                    0.3691542511144177,
                                    0.40549301399216375,
                                    0.10739071037024826,
                                    0.11796202452317024,
                                ],
                                [
                                    0.393215355902741,
                                    0.13023968261259306,
                                    0.35797687068850653,
                                    0.11856809079615946,
                                ],
                                [
                                    0.393215355902741,
                                    0.35797687068850653,
                                    0.13023968261259306,
                                    0.11856809079615946,
                                ],
                                [
                                    0.3691542511144177,
                                    0.10739071037024826,
                                    0.40549301399216375,
                                    0.11796202452317024,
                                ],
                                [
                                    0.40549301399216375,
                                    0.3691542511144177,
                                    0.11796202452317024,
                                    0.10739071037024826,
                                ],
                                [
                                    0.40549301399216375,
                                    0.11796202452317024,
                                    0.3691542511144177,
                                    0.10739071037024826,
                                ],
                                [
                                    0.26172374702940554,
                                    0.41875455776414733,
                                    0.12289358049701529,
                                    0.19662811470943184,
                                ],
                                [
                                    0.26172374702940554,
                                    0.12289358049701529,
                                    0.41875455776414733,
                                    0.19662811470943184,
                                ],
                                [
                                    0.30610192215904997,
                                    0.48975905510808215,
                                    0.07851540536737094,
                                    0.125623617365497,
                                ],
                                [
                                    0.4187545577641474,
                                    0.19662811470943187,
                                    0.2617237470294055,
                                    0.12289358049701526,
                                ],
                                [
                                    0.4187545577641474,
                                    0.2617237470294055,
                                    0.19662811470943187,
                                    0.12289358049701526,
                                ],
                                [
                                    0.30610192215904997,
                                    0.07851540536737094,
                                    0.48975905510808215,
                                    0.125623617365497,
                                ],
                                [
                                    0.48975905510808226,
                                    0.30610192215904986,
                                    0.12562361736549701,
                                    0.07851540536737092,
                                ],
                                [
                                    0.48975905510808226,
                                    0.12562361736549701,
                                    0.30610192215904986,
                                    0.07851540536737092,
                                ],
                                [
                                    0.1442314978224078,
                                    0.4326944934672234,
                                    0.1057685021775922,
                                    0.3173055065327766,
                                ],
                                [
                                    0.1442314978224078,
                                    0.1057685021775922,
                                    0.4326944934672234,
                                    0.3173055065327766,
                                ],
                                [
                                    0.2067314978224078,
                                    0.6201944934672234,
                                    0.043268502177592205,
                                    0.12980550653277662,
                                ],
                                [
                                    0.4326944934672234,
                                    0.3173055065327766,
                                    0.1442314978224078,
                                    0.1057685021775922,
                                ],
                                [
                                    0.4326944934672234,
                                    0.1442314978224078,
                                    0.3173055065327766,
                                    0.1057685021775922,
                                ],
                                [
                                    0.2067314978224078,
                                    0.043268502177592205,
                                    0.6201944934672234,
                                    0.12980550653277662,
                                ],
                                [
                                    0.6201944934672234,
                                    0.2067314978224078,
                                    0.12980550653277662,
                                    0.043268502177592205,
                                ],
                                [
                                    0.6201944934672234,
                                    0.12980550653277662,
                                    0.2067314978224078,
                                    0.043268502177592205,
                                ],
                                [
                                    0.054619120021562155,
                                    0.41875455776414733,
                                    0.060763552452017096,
                                    0.4658627697622734,
                                ],
                                [
                                    0.054619120021562155,
                                    0.060763552452017096,
                                    0.41875455776414733,
                                    0.4658627697622734,
                                ],
                                [
                                    0.09899729515120652,
                                    0.7589937101609238,
                                    0.01638537732237273,
                                    0.12562361736549701,
                                ],
                                [
                                    0.41875455776414733,
                                    0.4658627697622734,
                                    0.054619120021562155,
                                    0.060763552452017096,
                                ],
                                [
                                    0.41875455776414733,
                                    0.054619120021562155,
                                    0.4658627697622734,
                                    0.060763552452017096,
                                ],
                                [
                                    0.09899729515120652,
                                    0.01638537732237273,
                                    0.7589937101609238,
                                    0.12562361736549701,
                                ],
                                [
                                    0.7589937101609238,
                                    0.09899729515120652,
                                    0.12562361736549701,
                                    0.01638537732237273,
                                ],
                                [
                                    0.7589937101609238,
                                    0.12562361736549701,
                                    0.09899729515120652,
                                    0.01638537732237273,
                                ],
                                [
                                    0.009444400085273892,
                                    0.3932153559027409,
                                    0.014010638430060144,
                                    0.583329605581925,
                                ],
                                [
                                    0.009444400085273892,
                                    0.014010638430060144,
                                    0.3932153559027409,
                                    0.583329605581925,
                                ],
                                [
                                    0.020621780511185107,
                                    0.8585829369614957,
                                    0.0028332580041489277,
                                    0.11796202452317024,
                                ],
                                [
                                    0.3932153559027409,
                                    0.583329605581925,
                                    0.009444400085273892,
                                    0.014010638430060144,
                                ],
                                [
                                    0.3932153559027409,
                                    0.009444400085273892,
                                    0.583329605581925,
                                    0.014010638430060144,
                                ],
                                [
                                    0.020621780511185107,
                                    0.0028332580041489277,
                                    0.8585829369614957,
                                    0.11796202452317024,
                                ],
                                [
                                    0.8585829369614957,
                                    0.020621780511185107,
                                    0.11796202452317024,
                                    0.0028332580041489277,
                                ],
                                [
                                    0.8585829369614957,
                                    0.11796202452317024,
                                    0.020621780511185107,
                                    0.0028332580041489277,
                                ],
                                [
                                    0.16521731209507512,
                                    0.5859749144961723,
                                    0.0547228127446035,
                                    0.19408496066414901,
                                ],
                                [
                                    0.16521731209507512,
                                    0.0547228127446035,
                                    0.5859749144961723,
                                    0.19408496066414901,
                                ],
                                [
                                    0.17037601619425713,
                                    0.6042712489123243,
                                    0.04956410864542147,
                                    0.17578862624799704,
                                ],
                                [
                                    0.20045579730930962,
                                    0.06639440456103708,
                                    0.5507364292819379,
                                    0.18241336884771542,
                                ],
                                [
                                    0.20045579730930962,
                                    0.5507364292819379,
                                    0.06639440456103708,
                                    0.18241336884771542,
                                ],
                                [
                                    0.17037601619425713,
                                    0.04956410864542147,
                                    0.6042712489123243,
                                    0.17578862624799704,
                                ],
                                [
                                    0.20671477907200322,
                                    0.5679324860345782,
                                    0.06013542279834345,
                                    0.16521731209507506,
                                ],
                                [
                                    0.20671477907200322,
                                    0.06013542279834345,
                                    0.5679324860345782,
                                    0.16521731209507506,
                                ],
                                [
                                    0.12079354152820723,
                                    0.5596847632653457,
                                    0.05671915899037024,
                                    0.2628025362160769,
                                ],
                                [
                                    0.12079354152820723,
                                    0.05671915899037024,
                                    0.5596847632653457,
                                    0.2628025362160769,
                                ],
                                [
                                    0.14127543131204282,
                                    0.6545855459550893,
                                    0.03623726920653467,
                                    0.16790175352633327,
                                ],
                                [
                                    0.2778243522629491,
                                    0.13045369320278685,
                                    0.40265395253060376,
                                    0.18906800200366028,
                                ],
                                [
                                    0.2778243522629491,
                                    0.40265395253060376,
                                    0.13045369320278685,
                                    0.18906800200366028,
                                ],
                                [
                                    0.14127543131204282,
                                    0.03623726920653467,
                                    0.6545855459550893,
                                    0.16790175352633327,
                                ],
                                [
                                    0.32493256426107525,
                                    0.47092841300605687,
                                    0.08334548120466077,
                                    0.12079354152820716,
                                ],
                                [
                                    0.32493256426107525,
                                    0.08334548120466077,
                                    0.47092841300605687,
                                    0.12079354152820716,
                                ],
                                [
                                    0.06656726269446656,
                                    0.5103587285951646,
                                    0.0488154097791127,
                                    0.3742585989312561,
                                ],
                                [
                                    0.06656726269446656,
                                    0.0488154097791127,
                                    0.5103587285951646,
                                    0.3742585989312561,
                                ],
                                [
                                    0.09541293081286137,
                                    0.7315130604767698,
                                    0.01996974166071789,
                                    0.15310426704965094,
                                ],
                                [
                                    0.35503025833928215,
                                    0.2603524141342971,
                                    0.22189573295034903,
                                    0.16272159457607172,
                                ],
                                [
                                    0.35503025833928215,
                                    0.22189573295034903,
                                    0.2603524141342971,
                                    0.16272159457607172,
                                ],
                                [
                                    0.09541293081286137,
                                    0.01996974166071789,
                                    0.7315130604767698,
                                    0.15310426704965094,
                                ],
                                [
                                    0.508875926457677,
                                    0.31805006483195425,
                                    0.10650674601590229,
                                    0.06656726269446653,
                                ],
                                [
                                    0.508875926457677,
                                    0.10650674601590229,
                                    0.31805006483195425,
                                    0.06656726269446653,
                                ],
                                [
                                    0.025208400144972068,
                                    0.44816527764073744,
                                    0.02804424428360895,
                                    0.49858207793068154,
                                ],
                                [
                                    0.025208400144972068,
                                    0.02804424428360895,
                                    0.44816527764073744,
                                    0.49858207793068154,
                                ],
                                [
                                    0.045690289928807644,
                                    0.8123007153833226,
                                    0.0075623544997733775,
                                    0.13444664018809635,
                                ],
                                [
                                    0.3893438378875572,
                                    0.4331434615938653,
                                    0.08402983989815223,
                                    0.09348286062042523,
                                ],
                                [
                                    0.3893438378875572,
                                    0.08402983989815223,
                                    0.4331434615938653,
                                    0.09348286062042523,
                                ],
                                [
                                    0.045690289928807644,
                                    0.0075623544997733775,
                                    0.8123007153833226,
                                    0.13444664018809635,
                                ],
                                [
                                    0.7056867049385248,
                                    0.15230430037360537,
                                    0.11680059454289765,
                                    0.025208400144972075,
                                ],
                                [
                                    0.7056867049385248,
                                    0.11680059454289765,
                                    0.15230430037360537,
                                    0.025208400144972075,
                                ],
                                [
                                    0.004358880486994401,
                                    0.39830087550102045,
                                    0.006466339620485481,
                                    0.5908739043914997,
                                ],
                                [
                                    0.004358880486994401,
                                    0.006466339620485481,
                                    0.39830087550102045,
                                    0.5908739043914997,
                                ],
                                [
                                    0.009517584586176433,
                                    0.8696871328865043,
                                    0.0013076355213034487,
                                    0.11948764700601572,
                                ],
                                [
                                    0.38812983630446146,
                                    0.5757853067723504,
                                    0.01452991968355338,
                                    0.021554937239634798,
                                ],
                                [
                                    0.38812983630446146,
                                    0.01452991968355338,
                                    0.5757853067723504,
                                    0.021554937239634798,
                                ],
                                [
                                    0.009517584586176433,
                                    0.0013076355213034487,
                                    0.8696871328865043,
                                    0.11948764700601572,
                                ],
                                [
                                    0.847478741036487,
                                    0.03172597643619377,
                                    0.11643640204032475,
                                    0.004358880486994405,
                                ],
                                [
                                    0.847478741036487,
                                    0.11643640204032475,
                                    0.03172597643619377,
                                    0.004358880486994405,
                                ],
                                [
                                    0.033585445158390674,
                                    0.7176067814328568,
                                    0.011124076545254168,
                                    0.23768369686349836,
                                ],
                                [
                                    0.033585445158390674,
                                    0.011124076545254168,
                                    0.7176067814328568,
                                    0.23768369686349836,
                                ],
                                [
                                    0.03463410871195182,
                                    0.7400131563946296,
                                    0.010075412991693017,
                                    0.2152773219017255,
                                ],
                                [
                                    0.06882393037262516,
                                    0.022795668361687754,
                                    0.6823682962186224,
                                    0.22601210504706476,
                                ],
                                [
                                    0.06882393037262516,
                                    0.6823682962186224,
                                    0.022795668361687754,
                                    0.22601210504706476,
                                ],
                                [
                                    0.03463410871195182,
                                    0.010075412991693017,
                                    0.7400131563946296,
                                    0.2152773219017255,
                                ],
                                [
                                    0.07097287158969791,
                                    0.7036743935168835,
                                    0.020646727144615,
                                    0.20470600774880351,
                                ],
                                [
                                    0.07097287158969791,
                                    0.020646727144615,
                                    0.7036743935168835,
                                    0.20470600774880351,
                                ],
                                [
                                    0.024554962267809,
                                    0.6559233425257439,
                                    0.01152989465537919,
                                    0.30799180055106795,
                                ],
                                [
                                    0.024554962267809,
                                    0.01152989465537919,
                                    0.6559233425257439,
                                    0.30799180055106795,
                                ],
                                [
                                    0.02871852949543319,
                                    0.7671424477716989,
                                    0.007366327427755001,
                                    0.19677269530511293,
                                ],
                                [
                                    0.18158577300255088,
                                    0.08526442886779581,
                                    0.49889253179100196,
                                    0.23425726633865132,
                                ],
                                [
                                    0.18158577300255088,
                                    0.49889253179100196,
                                    0.08526442886779581,
                                    0.23425726633865132,
                                ],
                                [
                                    0.02871852949543319,
                                    0.007366327427755001,
                                    0.7671424477716989,
                                    0.19677269530511293,
                                ],
                                [
                                    0.2123756624444656,
                                    0.5834853148226665,
                                    0.054474539425881104,
                                    0.14966448330698684,
                                ],
                                [
                                    0.2123756624444656,
                                    0.054474539425881104,
                                    0.5834853148226665,
                                    0.14966448330698684,
                                ],
                                [
                                    0.013531821346195568,
                                    0.5633941699434356,
                                    0.009923217169138469,
                                    0.41315079154123036,
                                ],
                                [
                                    0.013531821346195568,
                                    0.009923217169138469,
                                    0.5633941699434356,
                                    0.41315079154123036,
                                ],
                                [
                                    0.019395580975029077,
                                    0.8075304103146022,
                                    0.0040594575403049594,
                                    0.16901455117006386,
                                ],
                                [
                                    0.30199481699101116,
                                    0.22146022152432288,
                                    0.27493117429862,
                                    0.20161378718604595,
                                ],
                                [
                                    0.30199481699101116,
                                    0.27493117429862,
                                    0.22146022152432288,
                                    0.20161378718604595,
                                ],
                                [
                                    0.019395580975029077,
                                    0.0040594575403049594,
                                    0.8075304103146022,
                                    0.16901455117006386,
                                ],
                                [
                                    0.43285857661984467,
                                    0.3940674146697865,
                                    0.09059646189548937,
                                    0.08247754681487945,
                                ],
                                [
                                    0.43285857661984467,
                                    0.09059646189548937,
                                    0.3940674146697865,
                                    0.08247754681487945,
                                ],
                                [
                                    0.005124374255117565,
                                    0.4682493035305919,
                                    0.005700845852362317,
                                    0.5209254763619282,
                                ],
                                [
                                    0.005124374255117565,
                                    0.005700845852362317,
                                    0.4682493035305919,
                                    0.5209254763619282,
                                ],
                                [
                                    0.00928794148274175,
                                    0.8487030638293885,
                                    0.0015372786247381312,
                                    0.1404717160631316,
                                ],
                                [
                                    0.36925981199770275,
                                    0.41080006316261863,
                                    0.10411386578800674,
                                    0.11582625905167188,
                                ],
                                [
                                    0.36925981199770275,
                                    0.10411386578800674,
                                    0.41080006316261863,
                                    0.11582625905167188,
                                ],
                                [
                                    0.00928794148274175,
                                    0.0015372786247381312,
                                    0.8487030638293885,
                                    0.1404717160631316,
                                ],
                                [
                                    0.669284356492459,
                                    0.18870664881967128,
                                    0.11077551866786241,
                                    0.031233476020007325,
                                ],
                                [
                                    0.669284356492459,
                                    0.11077551866786241,
                                    0.18870664881967128,
                                    0.031233476020007325,
                                ],
                                [
                                    0.0008860750710173019,
                                    0.40177368091699756,
                                    0.0013144802560059328,
                                    0.5960257637559793,
                                ],
                                [
                                    0.0008860750710173019,
                                    0.0013144802560059328,
                                    0.40177368091699756,
                                    0.5960257637559793,
                                ],
                                [
                                    0.0019347386245784659,
                                    0.8772699788481023,
                                    0.00026581670244476885,
                                    0.1205294658248744,
                                ],
                                [
                                    0.38465703088848435,
                                    0.5706334474078708,
                                    0.018002725099530492,
                                    0.026706796604114368,
                                ],
                                [
                                    0.38465703088848435,
                                    0.018002725099530492,
                                    0.5706334474078708,
                                    0.026706796604114368,
                                ],
                                [
                                    0.0019347386245784659,
                                    0.00026581670244476885,
                                    0.8772699788481023,
                                    0.1205294658248744,
                                ],
                                [
                                    0.839895895074889,
                                    0.03930882239779177,
                                    0.11539458322146608,
                                    0.005400699305853089,
                                ],
                                [
                                    0.839895895074889,
                                    0.11539458322146608,
                                    0.03930882239779177,
                                    0.005400699305853089,
                                ],
                                [
                                    0.44353715198371296,
                                    0.04473532875862004,
                                    0.46484324928197424,
                                    0.04688426997569279,
                                ],
                                [
                                    0.44353715198371296,
                                    0.46484324928197424,
                                    0.04473532875862004,
                                    0.04688426997569279,
                                ],
                                [
                                    0.46484324928197424,
                                    0.04688426997569279,
                                    0.44353715198371296,
                                    0.04473532875862004,
                                ],
                                [
                                    0.46644205166729114,
                                    0.488848426629064,
                                    0.02183042907504183,
                                    0.022879092628602982,
                                ],
                                [
                                    0.46644205166729114,
                                    0.02183042907504183,
                                    0.488848426629064,
                                    0.022879092628602982,
                                ],
                                [
                                    0.46484324928197424,
                                    0.44353715198371296,
                                    0.04688426997569279,
                                    0.04473532875862004,
                                ],
                                [
                                    0.488848426629064,
                                    0.022879092628602982,
                                    0.46644205166729114,
                                    0.02183042907504183,
                                ],
                                [
                                    0.488848426629064,
                                    0.46644205166729114,
                                    0.022879092628602982,
                                    0.02183042907504183,
                                ],
                                [
                                    0.32427850754899445,
                                    0.11803015621421595,
                                    0.40887129058065896,
                                    0.14882004565613063,
                                ],
                                [
                                    0.32427850754899445,
                                    0.40887129058065896,
                                    0.11803015621421595,
                                    0.14882004565613063,
                                ],
                                [
                                    0.408871290580659,
                                    0.14882004565613066,
                                    0.32427850754899445,
                                    0.11803015621421593,
                                ],
                                [
                                    0.42634801891542845,
                                    0.5375671241613834,
                                    0.015960644847781976,
                                    0.02012421207540616,
                                ],
                                [
                                    0.42634801891542845,
                                    0.015960644847781976,
                                    0.5375671241613834,
                                    0.02012421207540616,
                                ],
                                [
                                    0.408871290580659,
                                    0.32427850754899445,
                                    0.14882004565613066,
                                    0.11803015621421593,
                                ],
                                [
                                    0.5375671241613835,
                                    0.020124212075406163,
                                    0.4263480189154284,
                                    0.015960644847781976,
                                ],
                                [
                                    0.5375671241613835,
                                    0.4263480189154284,
                                    0.020124212075406163,
                                    0.015960644847781976,
                                ],
                                [
                                    0.17870436055674974,
                                    0.19629563944325026,
                                    0.2978406009279162,
                                    0.3271593990720838,
                                ],
                                [
                                    0.17870436055674974,
                                    0.2978406009279162,
                                    0.19629563944325026,
                                    0.3271593990720838,
                                ],
                                [
                                    0.2978406009279162,
                                    0.3271593990720838,
                                    0.17870436055674974,
                                    0.19629563944325026,
                                ],
                                [
                                    0.36620436055674976,
                                    0.6103406009279162,
                                    0.008795639443250253,
                                    0.014659399072083756,
                                ],
                                [
                                    0.36620436055674976,
                                    0.008795639443250253,
                                    0.6103406009279162,
                                    0.014659399072083756,
                                ],
                                [
                                    0.2978406009279162,
                                    0.17870436055674974,
                                    0.3271593990720838,
                                    0.19629563944325026,
                                ],
                                [
                                    0.6103406009279162,
                                    0.014659399072083756,
                                    0.36620436055674976,
                                    0.008795639443250253,
                                ],
                                [
                                    0.6103406009279162,
                                    0.36620436055674976,
                                    0.014659399072083756,
                                    0.008795639443250253,
                                ],
                                [
                                    0.06767367090400705,
                                    0.24001766533278263,
                                    0.15226645393567156,
                                    0.5400422098275387,
                                ],
                                [
                                    0.06767367090400705,
                                    0.15226645393567156,
                                    0.24001766533278263,
                                    0.5400422098275387,
                                ],
                                [
                                    0.15226645393567156,
                                    0.5400422098275387,
                                    0.06767367090400704,
                                    0.2400176653327826,
                                ],
                                [
                                    0.30436050979686186,
                                    0.6848142700956583,
                                    0.003330826439927849,
                                    0.007494393667552034,
                                ],
                                [
                                    0.30436050979686186,
                                    0.003330826439927849,
                                    0.6848142700956583,
                                    0.007494393667552034,
                                ],
                                [
                                    0.15226645393567156,
                                    0.06767367090400704,
                                    0.5400422098275387,
                                    0.2400176653327826,
                                ],
                                [
                                    0.6848142700956583,
                                    0.007494393667552034,
                                    0.3043605097968618,
                                    0.0033308264399278483,
                                ],
                                [
                                    0.6848142700956583,
                                    0.3043605097968618,
                                    0.007494393667552034,
                                    0.0033308264399278483,
                                ],
                                [
                                    0.011701712202691786,
                                    0.25002580705497524,
                                    0.033007809500953056,
                                    0.7052646712413799,
                                ],
                                [
                                    0.011701712202691786,
                                    0.033007809500953056,
                                    0.25002580705497524,
                                    0.7052646712413799,
                                ],
                                [
                                    0.033007809500953056,
                                    0.7052646712413799,
                                    0.011701712202691786,
                                    0.25002580705497524,
                                ],
                                [
                                    0.261151573370936,
                                    0.7366478713020408,
                                    0.0005759458867310288,
                                    0.0016246094402921807,
                                ],
                                [
                                    0.261151573370936,
                                    0.0005759458867310288,
                                    0.7366478713020408,
                                    0.0016246094402921807,
                                ],
                                [
                                    0.033007809500953056,
                                    0.011701712202691786,
                                    0.7052646712413799,
                                    0.25002580705497524,
                                ],
                                [
                                    0.7366478713020408,
                                    0.0016246094402921807,
                                    0.261151573370936,
                                    0.0005759458867310288,
                                ],
                                [
                                    0.7366478713020408,
                                    0.261151573370936,
                                    0.0016246094402921807,
                                    0.0005759458867310288,
                                ],
                                [
                                    0.35797687068850653,
                                    0.13029561005382648,
                                    0.3751729274411469,
                                    0.1365545918165201,
                                ],
                                [
                                    0.35797687068850653,
                                    0.3751729274411469,
                                    0.13029561005382648,
                                    0.1365545918165201,
                                ],
                                [
                                    0.3751729274411469,
                                    0.1365545918165201,
                                    0.35797687068850653,
                                    0.13029561005382648,
                                ],
                                [
                                    0.3808817703720847,
                                    0.3991781047882367,
                                    0.10739071037024826,
                                    0.1125494144694303,
                                ],
                                [
                                    0.3808817703720847,
                                    0.10739071037024826,
                                    0.3991781047882367,
                                    0.1125494144694303,
                                ],
                                [
                                    0.3751729274411469,
                                    0.35797687068850653,
                                    0.1365545918165201,
                                    0.13029561005382648,
                                ],
                                [
                                    0.3991781047882367,
                                    0.1125494144694303,
                                    0.3808817703720847,
                                    0.10739071037024826,
                                ],
                                [
                                    0.3991781047882367,
                                    0.3808817703720847,
                                    0.1125494144694303,
                                    0.10739071037024826,
                                ],
                                [
                                    0.26172374702940554,
                                    0.18058491673380492,
                                    0.3299982075048586,
                                    0.22769312873193095,
                                ],
                                [
                                    0.26172374702940554,
                                    0.3299982075048586,
                                    0.18058491673380492,
                                    0.22769312873193095,
                                ],
                                [
                                    0.3299982075048587,
                                    0.227693128731931,
                                    0.2617237470294055,
                                    0.1805849167338049,
                                ],
                                [
                                    0.36379325839583954,
                                    0.4586940410855831,
                                    0.07851540536737092,
                                    0.09899729515120648,
                                ],
                                [
                                    0.36379325839583954,
                                    0.07851540536737092,
                                    0.4586940410855831,
                                    0.09899729515120648,
                                ],
                                [
                                    0.3299982075048587,
                                    0.2617237470294055,
                                    0.227693128731931,
                                    0.1805849167338049,
                                ],
                                [
                                    0.4586940410855832,
                                    0.0989972951512065,
                                    0.3637932583958395,
                                    0.07851540536737091,
                                ],
                                [
                                    0.4586940410855832,
                                    0.3637932583958395,
                                    0.0989972951512065,
                                    0.07851540536737091,
                                ],
                                [
                                    0.1442314978224078,
                                    0.2307685021775922,
                                    0.24038582970401295,
                                    0.38461417029598705,
                                ],
                                [
                                    0.1442314978224078,
                                    0.24038582970401295,
                                    0.2307685021775922,
                                    0.38461417029598705,
                                ],
                                [
                                    0.24038582970401295,
                                    0.38461417029598705,
                                    0.1442314978224078,
                                    0.2307685021775922,
                                ],
                                [
                                    0.3317314978224078,
                                    0.552885829704013,
                                    0.043268502177592205,
                                    0.07211417029598702,
                                ],
                                [
                                    0.3317314978224078,
                                    0.043268502177592205,
                                    0.552885829704013,
                                    0.07211417029598702,
                                ],
                                [
                                    0.24038582970401295,
                                    0.1442314978224078,
                                    0.38461417029598705,
                                    0.2307685021775922,
                                ],
                                [
                                    0.552885829704013,
                                    0.07211417029598702,
                                    0.3317314978224078,
                                    0.043268502177592205,
                                ],
                                [
                                    0.552885829704013,
                                    0.3317314978224078,
                                    0.07211417029598702,
                                    0.043268502177592205,
                                ],
                                [
                                    0.054619120021562176,
                                    0.2530722162152275,
                                    0.1228935804970153,
                                    0.569415083266195,
                                ],
                                [
                                    0.054619120021562176,
                                    0.1228935804970153,
                                    0.2530722162152275,
                                    0.569415083266195,
                                ],
                                [
                                    0.1228935804970153,
                                    0.569415083266195,
                                    0.05461912002156216,
                                    0.25307221621522746,
                                ],
                                [
                                    0.29130595891441696,
                                    0.6554413966570021,
                                    0.016385377322372732,
                                    0.03686726710620831,
                                ],
                                [
                                    0.29130595891441696,
                                    0.016385377322372732,
                                    0.6554413966570021,
                                    0.03686726710620831,
                                ],
                                [
                                    0.1228935804970153,
                                    0.05461912002156216,
                                    0.569415083266195,
                                    0.25307221621522746,
                                ],
                                [
                                    0.6554413966570021,
                                    0.03686726710620831,
                                    0.2913059589144169,
                                    0.016385377322372732,
                                ],
                                [
                                    0.6554413966570021,
                                    0.2913059589144169,
                                    0.03686726710620831,
                                    0.016385377322372732,
                                ],
                                [
                                    0.009444400085273896,
                                    0.2522831191723931,
                                    0.026640456837914293,
                                    0.7116320239044187,
                                ],
                                [
                                    0.009444400085273896,
                                    0.026640456837914293,
                                    0.2522831191723931,
                                    0.7116320239044187,
                                ],
                                [
                                    0.026640456837914293,
                                    0.7116320239044187,
                                    0.009444400085273896,
                                    0.2522831191723931,
                                ],
                                [
                                    0.2588942612535181,
                                    0.730280518639002,
                                    0.002833258004148928,
                                    0.007991962103330965,
                                ],
                                [
                                    0.2588942612535181,
                                    0.002833258004148928,
                                    0.730280518639002,
                                    0.007991962103330965,
                                ],
                                [
                                    0.026640456837914293,
                                    0.009444400085273896,
                                    0.7116320239044187,
                                    0.2522831191723931,
                                ],
                                [
                                    0.730280518639002,
                                    0.007991962103330965,
                                    0.2588942612535181,
                                    0.002833258004148928,
                                ],
                                [
                                    0.730280518639002,
                                    0.2588942612535181,
                                    0.007991962103330965,
                                    0.002833258004148928,
                                ],
                                [
                                    0.23268379052937738,
                                    0.2555886902129556,
                                    0.2438611709552886,
                                    0.26786634830237843,
                                ],
                                [
                                    0.23268379052937738,
                                    0.2438611709552886,
                                    0.2555886902129556,
                                    0.26786634830237843,
                                ],
                                [
                                    0.2438611709552886,
                                    0.26786634830237843,
                                    0.23268379052937738,
                                    0.2555886902129556,
                                ],
                                [
                                    0.2555886902129556,
                                    0.26786634830237843,
                                    0.23268379052937738,
                                    0.2438611709552886,
                                ],
                                [
                                    0.2555886902129556,
                                    0.23268379052937738,
                                    0.26786634830237843,
                                    0.2438611709552886,
                                ],
                                [
                                    0.2438611709552886,
                                    0.23268379052937738,
                                    0.26786634830237843,
                                    0.2555886902129556,
                                ],
                                [
                                    0.26786634830237843,
                                    0.2438611709552886,
                                    0.2555886902129556,
                                    0.23268379052937738,
                                ],
                                [
                                    0.26786634830237843,
                                    0.2555886902129556,
                                    0.2438611709552886,
                                    0.23268379052937738,
                                ],
                                [
                                    0.17011957619838827,
                                    0.2721890875648222,
                                    0.2144977513280326,
                                    0.34319358490875695,
                                ],
                                [
                                    0.17011957619838827,
                                    0.2144977513280326,
                                    0.2721890875648222,
                                    0.34319358490875695,
                                ],
                                [
                                    0.21449775132803264,
                                    0.34319358490875707,
                                    0.17011957619838824,
                                    0.27218908756482213,
                                ],
                                [
                                    0.27218908756482224,
                                    0.343193584908757,
                                    0.17011957619838822,
                                    0.21449775132803253,
                                ],
                                [
                                    0.27218908756482224,
                                    0.17011957619838822,
                                    0.343193584908757,
                                    0.21449775132803253,
                                ],
                                [
                                    0.21449775132803264,
                                    0.17011957619838824,
                                    0.34319358490875707,
                                    0.27218908756482213,
                                ],
                                [
                                    0.3431935849087571,
                                    0.2144977513280326,
                                    0.2721890875648222,
                                    0.1701195761983882,
                                ],
                                [
                                    0.3431935849087571,
                                    0.2721890875648222,
                                    0.2144977513280326,
                                    0.1701195761983882,
                                ],
                                [0.09375, 0.28125, 0.15625, 0.46875],
                                [0.09375, 0.15625, 0.28125, 0.46875],
                                [0.15625, 0.46875, 0.09375, 0.28125],
                                [0.28125, 0.46875, 0.09375, 0.15625],
                                [0.28125, 0.09375, 0.46875, 0.15625],
                                [0.15625, 0.09375, 0.46875, 0.28125],
                                [0.46875, 0.15625, 0.28125, 0.09375],
                                [0.46875, 0.28125, 0.15625, 0.09375],
                                [
                                    0.035502248671967454,
                                    0.27218908756482224,
                                    0.0798804238016118,
                                    0.6124282399615986,
                                ],
                                [
                                    0.035502248671967454,
                                    0.0798804238016118,
                                    0.27218908756482224,
                                    0.6124282399615986,
                                ],
                                [
                                    0.0798804238016118,
                                    0.6124282399615986,
                                    0.03550224867196745,
                                    0.2721890875648222,
                                ],
                                [
                                    0.27218908756482224,
                                    0.6124282399615986,
                                    0.035502248671967454,
                                    0.0798804238016118,
                                ],
                                [
                                    0.27218908756482224,
                                    0.035502248671967454,
                                    0.6124282399615986,
                                    0.0798804238016118,
                                ],
                                [
                                    0.0798804238016118,
                                    0.03550224867196745,
                                    0.6124282399615986,
                                    0.2721890875648222,
                                ],
                                [
                                    0.6124282399615986,
                                    0.0798804238016118,
                                    0.2721890875648222,
                                    0.03550224867196745,
                                ],
                                [
                                    0.6124282399615986,
                                    0.2721890875648222,
                                    0.0798804238016118,
                                    0.03550224867196745,
                                ],
                                [
                                    0.006138829044711411,
                                    0.2555886902129556,
                                    0.017316209470622627,
                                    0.7209562712717104,
                                ],
                                [
                                    0.006138829044711411,
                                    0.017316209470622627,
                                    0.2555886902129556,
                                    0.7209562712717104,
                                ],
                                [
                                    0.017316209470622627,
                                    0.7209562712717104,
                                    0.006138829044711411,
                                    0.2555886902129556,
                                ],
                                [
                                    0.2555886902129556,
                                    0.7209562712717104,
                                    0.006138829044711411,
                                    0.017316209470622627,
                                ],
                                [
                                    0.2555886902129556,
                                    0.006138829044711411,
                                    0.7209562712717104,
                                    0.017316209470622627,
                                ],
                                [
                                    0.017316209470622627,
                                    0.006138829044711411,
                                    0.7209562712717104,
                                    0.2555886902129556,
                                ],
                                [
                                    0.7209562712717104,
                                    0.017316209470622627,
                                    0.2555886902129556,
                                    0.006138829044711411,
                                ],
                                [
                                    0.7209562712717104,
                                    0.2555886902129556,
                                    0.017316209470622627,
                                    0.006138829044711411,
                                ],
                                [
                                    0.10739071037024829,
                                    0.3808817703720847,
                                    0.11254941446943033,
                                    0.3991781047882367,
                                ],
                                [
                                    0.10739071037024829,
                                    0.11254941446943033,
                                    0.3808817703720847,
                                    0.3991781047882367,
                                ],
                                [
                                    0.11254941446943033,
                                    0.3991781047882367,
                                    0.10739071037024829,
                                    0.3808817703720847,
                                ],
                                [
                                    0.13029561005382653,
                                    0.13655459181652016,
                                    0.3579768706885065,
                                    0.37517292744114683,
                                ],
                                [
                                    0.13029561005382653,
                                    0.3579768706885065,
                                    0.13655459181652016,
                                    0.37517292744114683,
                                ],
                                [
                                    0.11254941446943033,
                                    0.10739071037024829,
                                    0.3991781047882367,
                                    0.3808817703720847,
                                ],
                                [
                                    0.13655459181652016,
                                    0.37517292744114683,
                                    0.13029561005382653,
                                    0.3579768706885065,
                                ],
                                [
                                    0.13655459181652016,
                                    0.13029561005382653,
                                    0.37517292744114683,
                                    0.3579768706885065,
                                ],
                                [
                                    0.07851540536737096,
                                    0.3637932583958395,
                                    0.09899729515120652,
                                    0.45869404108558304,
                                ],
                                [
                                    0.07851540536737096,
                                    0.09899729515120652,
                                    0.3637932583958395,
                                    0.45869404108558304,
                                ],
                                [
                                    0.09899729515120655,
                                    0.45869404108558315,
                                    0.07851540536737095,
                                    0.3637932583958394,
                                ],
                                [
                                    0.18058491673380495,
                                    0.22769312873193104,
                                    0.2617237470294055,
                                    0.32999820750485853,
                                ],
                                [
                                    0.18058491673380495,
                                    0.2617237470294055,
                                    0.22769312873193104,
                                    0.32999820750485853,
                                ],
                                [
                                    0.09899729515120655,
                                    0.07851540536737095,
                                    0.45869404108558315,
                                    0.3637932583958394,
                                ],
                                [
                                    0.22769312873193107,
                                    0.3299982075048586,
                                    0.18058491673380495,
                                    0.26172374702940543,
                                ],
                                [
                                    0.22769312873193107,
                                    0.18058491673380495,
                                    0.3299982075048586,
                                    0.26172374702940543,
                                ],
                                [
                                    0.04326850217759222,
                                    0.3317314978224078,
                                    0.07211417029598703,
                                    0.552885829704013,
                                ],
                                [
                                    0.04326850217759222,
                                    0.07211417029598703,
                                    0.3317314978224078,
                                    0.552885829704013,
                                ],
                                [
                                    0.07211417029598703,
                                    0.552885829704013,
                                    0.04326850217759222,
                                    0.3317314978224078,
                                ],
                                [
                                    0.2307685021775922,
                                    0.38461417029598705,
                                    0.1442314978224078,
                                    0.24038582970401295,
                                ],
                                [
                                    0.2307685021775922,
                                    0.1442314978224078,
                                    0.38461417029598705,
                                    0.24038582970401295,
                                ],
                                [
                                    0.07211417029598703,
                                    0.04326850217759222,
                                    0.552885829704013,
                                    0.3317314978224078,
                                ],
                                [
                                    0.38461417029598705,
                                    0.24038582970401295,
                                    0.2307685021775922,
                                    0.1442314978224078,
                                ],
                                [
                                    0.38461417029598705,
                                    0.2307685021775922,
                                    0.24038582970401295,
                                    0.1442314978224078,
                                ],
                                [
                                    0.01638537732237273,
                                    0.29130595891441696,
                                    0.036867267106208294,
                                    0.6554413966570021,
                                ],
                                [
                                    0.01638537732237273,
                                    0.036867267106208294,
                                    0.29130595891441696,
                                    0.6554413966570021,
                                ],
                                [
                                    0.036867267106208294,
                                    0.6554413966570021,
                                    0.016385377322372725,
                                    0.2913059589144169,
                                ],
                                [
                                    0.2530722162152275,
                                    0.569415083266195,
                                    0.05461912002156217,
                                    0.12289358049701529,
                                ],
                                [
                                    0.2530722162152275,
                                    0.05461912002156217,
                                    0.569415083266195,
                                    0.12289358049701529,
                                ],
                                [
                                    0.036867267106208294,
                                    0.016385377322372725,
                                    0.6554413966570021,
                                    0.2913059589144169,
                                ],
                                [
                                    0.569415083266195,
                                    0.12289358049701529,
                                    0.25307221621522746,
                                    0.054619120021562155,
                                ],
                                [
                                    0.569415083266195,
                                    0.25307221621522746,
                                    0.12289358049701529,
                                    0.054619120021562155,
                                ],
                                [
                                    0.002833258004148925,
                                    0.2588942612535181,
                                    0.007991962103330957,
                                    0.730280518639002,
                                ],
                                [
                                    0.002833258004148925,
                                    0.007991962103330957,
                                    0.2588942612535181,
                                    0.730280518639002,
                                ],
                                [
                                    0.007991962103330957,
                                    0.730280518639002,
                                    0.002833258004148925,
                                    0.2588942612535181,
                                ],
                                [
                                    0.2522831191723931,
                                    0.7116320239044187,
                                    0.009444400085273892,
                                    0.026640456837914283,
                                ],
                                [
                                    0.2522831191723931,
                                    0.009444400085273892,
                                    0.7116320239044187,
                                    0.026640456837914283,
                                ],
                                [
                                    0.007991962103330957,
                                    0.002833258004148925,
                                    0.730280518639002,
                                    0.2588942612535181,
                                ],
                                [
                                    0.7116320239044187,
                                    0.026640456837914283,
                                    0.2522831191723931,
                                    0.009444400085273892,
                                ],
                                [
                                    0.7116320239044187,
                                    0.2522831191723931,
                                    0.026640456837914283,
                                    0.009444400085273892,
                                ],
                                [
                                    0.021830429075041843,
                                    0.46644205166729114,
                                    0.022879092628602996,
                                    0.488848426629064,
                                ],
                                [
                                    0.021830429075041843,
                                    0.022879092628602996,
                                    0.46644205166729114,
                                    0.488848426629064,
                                ],
                                [
                                    0.022879092628602996,
                                    0.488848426629064,
                                    0.021830429075041843,
                                    0.46644205166729114,
                                ],
                                [
                                    0.044735328758620074,
                                    0.04688426997569284,
                                    0.4435371519837129,
                                    0.4648432492819742,
                                ],
                                [
                                    0.044735328758620074,
                                    0.4435371519837129,
                                    0.04688426997569284,
                                    0.4648432492819742,
                                ],
                                [
                                    0.022879092628602996,
                                    0.021830429075041843,
                                    0.488848426629064,
                                    0.46644205166729114,
                                ],
                                [
                                    0.04688426997569284,
                                    0.4648432492819742,
                                    0.044735328758620074,
                                    0.4435371519837129,
                                ],
                                [
                                    0.04688426997569284,
                                    0.044735328758620074,
                                    0.4648432492819742,
                                    0.4435371519837129,
                                ],
                                [
                                    0.015960644847782,
                                    0.42634801891542845,
                                    0.02012421207540619,
                                    0.5375671241613834,
                                ],
                                [
                                    0.015960644847782,
                                    0.02012421207540619,
                                    0.42634801891542845,
                                    0.5375671241613834,
                                ],
                                [
                                    0.020124212075406194,
                                    0.5375671241613835,
                                    0.015960644847782,
                                    0.4263480189154284,
                                ],
                                [
                                    0.118030156214216,
                                    0.1488200456561307,
                                    0.32427850754899445,
                                    0.40887129058065885,
                                ],
                                [
                                    0.118030156214216,
                                    0.32427850754899445,
                                    0.1488200456561307,
                                    0.40887129058065885,
                                ],
                                [
                                    0.020124212075406194,
                                    0.015960644847782,
                                    0.5375671241613835,
                                    0.4263480189154284,
                                ],
                                [
                                    0.14882004565613072,
                                    0.40887129058065896,
                                    0.11803015621421599,
                                    0.3242785075489944,
                                ],
                                [
                                    0.14882004565613072,
                                    0.11803015621421599,
                                    0.40887129058065896,
                                    0.3242785075489944,
                                ],
                                [
                                    0.008795639443250264,
                                    0.36620436055674976,
                                    0.014659399072083773,
                                    0.6103406009279162,
                                ],
                                [
                                    0.008795639443250264,
                                    0.014659399072083773,
                                    0.36620436055674976,
                                    0.6103406009279162,
                                ],
                                [
                                    0.014659399072083773,
                                    0.6103406009279162,
                                    0.008795639443250264,
                                    0.36620436055674976,
                                ],
                                [
                                    0.19629563944325026,
                                    0.3271593990720838,
                                    0.17870436055674974,
                                    0.2978406009279162,
                                ],
                                [
                                    0.19629563944325026,
                                    0.17870436055674974,
                                    0.3271593990720838,
                                    0.2978406009279162,
                                ],
                                [
                                    0.014659399072083773,
                                    0.008795639443250264,
                                    0.6103406009279162,
                                    0.36620436055674976,
                                ],
                                [
                                    0.3271593990720838,
                                    0.2978406009279162,
                                    0.19629563944325026,
                                    0.17870436055674974,
                                ],
                                [
                                    0.3271593990720838,
                                    0.19629563944325026,
                                    0.2978406009279162,
                                    0.17870436055674974,
                                ],
                                [
                                    0.003330826439927849,
                                    0.30436050979686186,
                                    0.007494393667552034,
                                    0.6848142700956583,
                                ],
                                [
                                    0.003330826439927849,
                                    0.007494393667552034,
                                    0.30436050979686186,
                                    0.6848142700956583,
                                ],
                                [
                                    0.007494393667552034,
                                    0.6848142700956583,
                                    0.0033308264399278483,
                                    0.3043605097968618,
                                ],
                                [
                                    0.24001766533278263,
                                    0.5400422098275387,
                                    0.06767367090400705,
                                    0.15226645393567156,
                                ],
                                [
                                    0.24001766533278263,
                                    0.06767367090400705,
                                    0.5400422098275387,
                                    0.15226645393567156,
                                ],
                                [
                                    0.007494393667552034,
                                    0.0033308264399278483,
                                    0.6848142700956583,
                                    0.3043605097968618,
                                ],
                                [
                                    0.5400422098275387,
                                    0.15226645393567156,
                                    0.2400176653327826,
                                    0.06767367090400704,
                                ],
                                [
                                    0.5400422098275387,
                                    0.2400176653327826,
                                    0.15226645393567156,
                                    0.06767367090400704,
                                ],
                                [
                                    0.0005759458867310354,
                                    0.261151573370936,
                                    0.0016246094402921993,
                                    0.7366478713020408,
                                ],
                                [
                                    0.0005759458867310354,
                                    0.0016246094402921993,
                                    0.261151573370936,
                                    0.7366478713020408,
                                ],
                                [
                                    0.0016246094402921993,
                                    0.7366478713020408,
                                    0.0005759458867310354,
                                    0.261151573370936,
                                ],
                                [
                                    0.25002580705497524,
                                    0.7052646712413799,
                                    0.011701712202691792,
                                    0.03300780950095307,
                                ],
                                [
                                    0.25002580705497524,
                                    0.011701712202691792,
                                    0.7052646712413799,
                                    0.03300780950095307,
                                ],
                                [
                                    0.0016246094402921993,
                                    0.0005759458867310354,
                                    0.7366478713020408,
                                    0.261151573370936,
                                ],
                                [
                                    0.7052646712413799,
                                    0.03300780950095307,
                                    0.25002580705497524,
                                    0.011701712202691792,
                                ],
                                [
                                    0.7052646712413799,
                                    0.25002580705497524,
                                    0.03300780950095307,
                                    0.011701712202691792,
                                ],
                                [
                                    0.20470600774880357,
                                    0.020646727144614987,
                                    0.7036743935168837,
                                    0.07097287158969784,
                                ],
                                [
                                    0.20470600774880357,
                                    0.7036743935168837,
                                    0.020646727144614987,
                                    0.07097287158969784,
                                ],
                                [
                                    0.22601210504706487,
                                    0.022795668361687744,
                                    0.6823682962186224,
                                    0.06882393037262509,
                                ],
                                [
                                    0.21527732190172555,
                                    0.7400131563946296,
                                    0.010075412991693013,
                                    0.0346341087119518,
                                ],
                                [
                                    0.21527732190172555,
                                    0.010075412991693013,
                                    0.7400131563946296,
                                    0.0346341087119518,
                                ],
                                [
                                    0.22601210504706487,
                                    0.6823682962186224,
                                    0.022795668361687744,
                                    0.06882393037262509,
                                ],
                                [
                                    0.23768369686349844,
                                    0.011124076545254165,
                                    0.7176067814328567,
                                    0.033585445158390646,
                                ],
                                [
                                    0.23768369686349844,
                                    0.7176067814328567,
                                    0.011124076545254165,
                                    0.033585445158390646,
                                ],
                                [
                                    0.1496644833069869,
                                    0.0544745394258811,
                                    0.5834853148226665,
                                    0.21237566244446549,
                                ],
                                [
                                    0.1496644833069869,
                                    0.5834853148226665,
                                    0.0544745394258811,
                                    0.21237566244446549,
                                ],
                                [
                                    0.23425726633865143,
                                    0.0852644288677958,
                                    0.49889253179100196,
                                    0.18158577300255077,
                                ],
                                [
                                    0.196772695305113,
                                    0.7671424477716988,
                                    0.007366327427754992,
                                    0.028718529495433145,
                                ],
                                [
                                    0.196772695305113,
                                    0.007366327427754992,
                                    0.7671424477716988,
                                    0.028718529495433145,
                                ],
                                [
                                    0.23425726633865143,
                                    0.49889253179100196,
                                    0.0852644288677958,
                                    0.18158577300255077,
                                ],
                                [
                                    0.30799180055106806,
                                    0.011529894655379177,
                                    0.6559233425257438,
                                    0.02455496226780896,
                                ],
                                [
                                    0.30799180055106806,
                                    0.6559233425257438,
                                    0.011529894655379177,
                                    0.02455496226780896,
                                ],
                                [
                                    0.08247754681487945,
                                    0.09059646189548937,
                                    0.3940674146697865,
                                    0.43285857661984467,
                                ],
                                [
                                    0.08247754681487945,
                                    0.3940674146697865,
                                    0.09059646189548937,
                                    0.43285857661984467,
                                ],
                                [
                                    0.20161378718604595,
                                    0.22146022152432288,
                                    0.27493117429862,
                                    0.30199481699101116,
                                ],
                                [
                                    0.16901455117006386,
                                    0.8075304103146022,
                                    0.004059457540304954,
                                    0.019395580975029053,
                                ],
                                [
                                    0.16901455117006386,
                                    0.004059457540304954,
                                    0.8075304103146022,
                                    0.019395580975029053,
                                ],
                                [
                                    0.20161378718604595,
                                    0.27493117429862,
                                    0.22146022152432288,
                                    0.30199481699101116,
                                ],
                                [
                                    0.41315079154123036,
                                    0.009923217169138457,
                                    0.5633941699434356,
                                    0.013531821346195553,
                                ],
                                [
                                    0.41315079154123036,
                                    0.5633941699434356,
                                    0.009923217169138457,
                                    0.013531821346195553,
                                ],
                                [
                                    0.031233476020007332,
                                    0.11077551866786242,
                                    0.18870664881967128,
                                    0.669284356492459,
                                ],
                                [
                                    0.031233476020007332,
                                    0.18870664881967128,
                                    0.11077551866786242,
                                    0.669284356492459,
                                ],
                                [
                                    0.11582625905167188,
                                    0.41080006316261863,
                                    0.10411386578800674,
                                    0.36925981199770275,
                                ],
                                [
                                    0.14047171606313164,
                                    0.8487030638293885,
                                    0.0015372786247381317,
                                    0.00928794148274175,
                                ],
                                [
                                    0.14047171606313164,
                                    0.0015372786247381317,
                                    0.8487030638293885,
                                    0.00928794148274175,
                                ],
                                [
                                    0.11582625905167188,
                                    0.10411386578800674,
                                    0.41080006316261863,
                                    0.36925981199770275,
                                ],
                                [
                                    0.5209254763619282,
                                    0.005700845852362317,
                                    0.4682493035305919,
                                    0.005124374255117565,
                                ],
                                [
                                    0.5209254763619282,
                                    0.4682493035305919,
                                    0.005700845852362317,
                                    0.005124374255117565,
                                ],
                                [
                                    0.005400699305853088,
                                    0.1153945832214661,
                                    0.03930882239779175,
                                    0.839895895074889,
                                ],
                                [
                                    0.005400699305853088,
                                    0.03930882239779175,
                                    0.1153945832214661,
                                    0.839895895074889,
                                ],
                                [
                                    0.026706796604114354,
                                    0.5706334474078708,
                                    0.018002725099530485,
                                    0.38465703088848435,
                                ],
                                [
                                    0.12052946582487442,
                                    0.8772699788481023,
                                    0.00026581670244476586,
                                    0.0019347386245784437,
                                ],
                                [
                                    0.12052946582487442,
                                    0.00026581670244476586,
                                    0.8772699788481023,
                                    0.0019347386245784437,
                                ],
                                [
                                    0.026706796604114354,
                                    0.018002725099530485,
                                    0.5706334474078708,
                                    0.38465703088848435,
                                ],
                                [
                                    0.5960257637559793,
                                    0.0013144802560059179,
                                    0.40177368091699756,
                                    0.0008860750710172918,
                                ],
                                [
                                    0.5960257637559793,
                                    0.40177368091699756,
                                    0.0013144802560059179,
                                    0.0008860750710172918,
                                ],
                                [
                                    0.16521731209507512,
                                    0.06013542279834344,
                                    0.5679324860345782,
                                    0.20671477907200314,
                                ],
                                [
                                    0.16521731209507512,
                                    0.5679324860345782,
                                    0.06013542279834344,
                                    0.20671477907200314,
                                ],
                                [
                                    0.18241336884771553,
                                    0.06639440456103708,
                                    0.5507364292819379,
                                    0.2004557973093095,
                                ],
                                [
                                    0.17578862624799707,
                                    0.6042712489123243,
                                    0.04956410864542147,
                                    0.1703760161942571,
                                ],
                                [
                                    0.17578862624799707,
                                    0.04956410864542147,
                                    0.6042712489123243,
                                    0.1703760161942571,
                                ],
                                [
                                    0.18241336884771553,
                                    0.5507364292819379,
                                    0.06639440456103708,
                                    0.2004557973093095,
                                ],
                                [
                                    0.19408496066414907,
                                    0.0547228127446035,
                                    0.5859749144961723,
                                    0.16521731209507506,
                                ],
                                [
                                    0.19408496066414907,
                                    0.5859749144961723,
                                    0.0547228127446035,
                                    0.16521731209507506,
                                ],
                                [
                                    0.12079354152820722,
                                    0.08334548120466077,
                                    0.4709284130060569,
                                    0.3249325642610751,
                                ],
                                [
                                    0.12079354152820722,
                                    0.4709284130060569,
                                    0.08334548120466077,
                                    0.3249325642610751,
                                ],
                                [
                                    0.18906800200366036,
                                    0.13045369320278688,
                                    0.40265395253060376,
                                    0.277824352262949,
                                ],
                                [
                                    0.16790175352633332,
                                    0.6545855459550893,
                                    0.03623726920653466,
                                    0.14127543131204273,
                                ],
                                [
                                    0.16790175352633332,
                                    0.03623726920653466,
                                    0.6545855459550893,
                                    0.14127543131204273,
                                ],
                                [
                                    0.18906800200366036,
                                    0.40265395253060376,
                                    0.13045369320278688,
                                    0.277824352262949,
                                ],
                                [
                                    0.262802536216077,
                                    0.056719158990370236,
                                    0.5596847632653457,
                                    0.12079354152820716,
                                ],
                                [
                                    0.262802536216077,
                                    0.5596847632653457,
                                    0.056719158990370236,
                                    0.12079354152820716,
                                ],
                                [
                                    0.06656726269446653,
                                    0.10650674601590229,
                                    0.31805006483195425,
                                    0.508875926457677,
                                ],
                                [
                                    0.06656726269446653,
                                    0.31805006483195425,
                                    0.10650674601590229,
                                    0.508875926457677,
                                ],
                                [
                                    0.16272159457607172,
                                    0.2603524141342971,
                                    0.22189573295034903,
                                    0.35503025833928215,
                                ],
                                [
                                    0.15310426704965094,
                                    0.7315130604767698,
                                    0.019969741660717882,
                                    0.09541293081286134,
                                ],
                                [
                                    0.15310426704965094,
                                    0.019969741660717882,
                                    0.7315130604767698,
                                    0.09541293081286134,
                                ],
                                [
                                    0.16272159457607172,
                                    0.22189573295034903,
                                    0.2603524141342971,
                                    0.35503025833928215,
                                ],
                                [
                                    0.3742585989312561,
                                    0.04881540977911269,
                                    0.5103587285951646,
                                    0.06656726269446653,
                                ],
                                [
                                    0.3742585989312561,
                                    0.5103587285951646,
                                    0.04881540977911269,
                                    0.06656726269446653,
                                ],
                                [
                                    0.025208400144972085,
                                    0.11680059454289768,
                                    0.1523043003736054,
                                    0.7056867049385248,
                                ],
                                [
                                    0.025208400144972085,
                                    0.1523043003736054,
                                    0.11680059454289768,
                                    0.7056867049385248,
                                ],
                                [
                                    0.09348286062042524,
                                    0.4331434615938653,
                                    0.08402983989815224,
                                    0.3893438378875572,
                                ],
                                [
                                    0.13444664018809638,
                                    0.8123007153833226,
                                    0.007562354499773382,
                                    0.04569028992880766,
                                ],
                                [
                                    0.13444664018809638,
                                    0.007562354499773382,
                                    0.8123007153833226,
                                    0.04569028992880766,
                                ],
                                [
                                    0.09348286062042524,
                                    0.08402983989815224,
                                    0.4331434615938653,
                                    0.3893438378875572,
                                ],
                                [
                                    0.49858207793068154,
                                    0.028044244283608962,
                                    0.44816527764073744,
                                    0.02520840014497208,
                                ],
                                [
                                    0.49858207793068154,
                                    0.44816527764073744,
                                    0.028044244283608962,
                                    0.02520840014497208,
                                ],
                                [
                                    0.004358880486994407,
                                    0.11643640204032478,
                                    0.031725976436193785,
                                    0.847478741036487,
                                ],
                                [
                                    0.004358880486994407,
                                    0.031725976436193785,
                                    0.11643640204032478,
                                    0.847478741036487,
                                ],
                                [
                                    0.021554937239634805,
                                    0.5757853067723504,
                                    0.014529919683553385,
                                    0.38812983630446146,
                                ],
                                [
                                    0.11948764700601575,
                                    0.8696871328865043,
                                    0.0013076355213034504,
                                    0.009517584586176443,
                                ],
                                [
                                    0.11948764700601575,
                                    0.0013076355213034504,
                                    0.8696871328865043,
                                    0.009517584586176443,
                                ],
                                [
                                    0.021554937239634805,
                                    0.014529919683553385,
                                    0.5757853067723504,
                                    0.38812983630446146,
                                ],
                                [
                                    0.5908739043914997,
                                    0.006466339620485487,
                                    0.39830087550102045,
                                    0.004358880486994406,
                                ],
                                [
                                    0.5908739043914997,
                                    0.39830087550102045,
                                    0.006466339620485487,
                                    0.004358880486994406,
                                ],
                                [
                                    0.10739071037024829,
                                    0.11796202452317027,
                                    0.3691542511144177,
                                    0.40549301399216375,
                                ],
                                [
                                    0.10739071037024829,
                                    0.3691542511144177,
                                    0.11796202452317027,
                                    0.40549301399216375,
                                ],
                                [
                                    0.1185680907961595,
                                    0.13023968261259308,
                                    0.3579768706885065,
                                    0.3932153559027409,
                                ],
                                [
                                    0.11796202452317027,
                                    0.40549301399216375,
                                    0.10739071037024829,
                                    0.3691542511144177,
                                ],
                                [
                                    0.11796202452317027,
                                    0.10739071037024829,
                                    0.40549301399216375,
                                    0.3691542511144177,
                                ],
                                [
                                    0.1185680907961595,
                                    0.3579768706885065,
                                    0.13023968261259308,
                                    0.3932153559027409,
                                ],
                                [
                                    0.13023968261259308,
                                    0.1185680907961595,
                                    0.3932153559027409,
                                    0.3579768706885065,
                                ],
                                [
                                    0.13023968261259308,
                                    0.3932153559027409,
                                    0.1185680907961595,
                                    0.3579768706885065,
                                ],
                                [
                                    0.07851540536737096,
                                    0.12562361736549704,
                                    0.3061019221590499,
                                    0.4897590551080821,
                                ],
                                [
                                    0.07851540536737096,
                                    0.3061019221590499,
                                    0.12562361736549704,
                                    0.4897590551080821,
                                ],
                                [
                                    0.12289358049701533,
                                    0.1966281147094319,
                                    0.26172374702940554,
                                    0.4187545577641472,
                                ],
                                [
                                    0.12562361736549704,
                                    0.4897590551080822,
                                    0.07851540536737094,
                                    0.3061019221590498,
                                ],
                                [
                                    0.12562361736549704,
                                    0.07851540536737094,
                                    0.4897590551080822,
                                    0.3061019221590498,
                                ],
                                [
                                    0.12289358049701533,
                                    0.26172374702940554,
                                    0.1966281147094319,
                                    0.4187545577641472,
                                ],
                                [
                                    0.19662811470943195,
                                    0.1228935804970153,
                                    0.41875455776414733,
                                    0.26172374702940543,
                                ],
                                [
                                    0.19662811470943195,
                                    0.41875455776414733,
                                    0.1228935804970153,
                                    0.26172374702940543,
                                ],
                                [
                                    0.043268502177592205,
                                    0.12980550653277662,
                                    0.2067314978224078,
                                    0.6201944934672234,
                                ],
                                [
                                    0.043268502177592205,
                                    0.2067314978224078,
                                    0.12980550653277662,
                                    0.6201944934672234,
                                ],
                                [
                                    0.1057685021775922,
                                    0.3173055065327766,
                                    0.1442314978224078,
                                    0.4326944934672234,
                                ],
                                [
                                    0.12980550653277662,
                                    0.6201944934672234,
                                    0.043268502177592205,
                                    0.2067314978224078,
                                ],
                                [
                                    0.12980550653277662,
                                    0.043268502177592205,
                                    0.6201944934672234,
                                    0.2067314978224078,
                                ],
                                [
                                    0.1057685021775922,
                                    0.1442314978224078,
                                    0.3173055065327766,
                                    0.4326944934672234,
                                ],
                                [
                                    0.3173055065327766,
                                    0.1057685021775922,
                                    0.4326944934672234,
                                    0.1442314978224078,
                                ],
                                [
                                    0.3173055065327766,
                                    0.4326944934672234,
                                    0.1057685021775922,
                                    0.1442314978224078,
                                ],
                                [
                                    0.016385377322372732,
                                    0.12562361736549701,
                                    0.09899729515120652,
                                    0.7589937101609238,
                                ],
                                [
                                    0.016385377322372732,
                                    0.09899729515120652,
                                    0.12562361736549701,
                                    0.7589937101609238,
                                ],
                                [
                                    0.060763552452017096,
                                    0.4658627697622734,
                                    0.054619120021562155,
                                    0.41875455776414733,
                                ],
                                [
                                    0.12562361736549701,
                                    0.7589937101609238,
                                    0.016385377322372732,
                                    0.09899729515120652,
                                ],
                                [
                                    0.12562361736549701,
                                    0.016385377322372732,
                                    0.7589937101609238,
                                    0.09899729515120652,
                                ],
                                [
                                    0.060763552452017096,
                                    0.054619120021562155,
                                    0.4658627697622734,
                                    0.41875455776414733,
                                ],
                                [
                                    0.4658627697622734,
                                    0.060763552452017096,
                                    0.41875455776414733,
                                    0.054619120021562155,
                                ],
                                [
                                    0.4658627697622734,
                                    0.41875455776414733,
                                    0.060763552452017096,
                                    0.054619120021562155,
                                ],
                                [
                                    0.002833258004148928,
                                    0.11796202452317027,
                                    0.020621780511185107,
                                    0.8585829369614957,
                                ],
                                [
                                    0.002833258004148928,
                                    0.020621780511185107,
                                    0.11796202452317027,
                                    0.8585829369614957,
                                ],
                                [
                                    0.014010638430060144,
                                    0.583329605581925,
                                    0.009444400085273892,
                                    0.3932153559027409,
                                ],
                                [
                                    0.11796202452317027,
                                    0.8585829369614957,
                                    0.002833258004148928,
                                    0.020621780511185107,
                                ],
                                [
                                    0.11796202452317027,
                                    0.002833258004148928,
                                    0.8585829369614957,
                                    0.020621780511185107,
                                ],
                                [
                                    0.014010638430060144,
                                    0.009444400085273892,
                                    0.583329605581925,
                                    0.3932153559027409,
                                ],
                                [
                                    0.583329605581925,
                                    0.014010638430060144,
                                    0.3932153559027409,
                                    0.009444400085273892,
                                ],
                                [
                                    0.583329605581925,
                                    0.3932153559027409,
                                    0.014010638430060144,
                                    0.009444400085273892,
                                ],
                                [
                                    0.049564108645421476,
                                    0.17578862624799707,
                                    0.17037601619425713,
                                    0.6042712489123243,
                                ],
                                [
                                    0.049564108645421476,
                                    0.17037601619425713,
                                    0.17578862624799707,
                                    0.6042712489123243,
                                ],
                                [
                                    0.05472281274460351,
                                    0.19408496066414907,
                                    0.1652173120950751,
                                    0.5859749144961723,
                                ],
                                [
                                    0.06013542279834346,
                                    0.20671477907200322,
                                    0.1652173120950751,
                                    0.5679324860345782,
                                ],
                                [
                                    0.06013542279834346,
                                    0.1652173120950751,
                                    0.20671477907200322,
                                    0.5679324860345782,
                                ],
                                [
                                    0.05472281274460351,
                                    0.1652173120950751,
                                    0.19408496066414907,
                                    0.5859749144961723,
                                ],
                                [
                                    0.06639440456103711,
                                    0.1824133688477155,
                                    0.2004557973093096,
                                    0.5507364292819378,
                                ],
                                [
                                    0.06639440456103711,
                                    0.2004557973093096,
                                    0.1824133688477155,
                                    0.5507364292819378,
                                ],
                                [
                                    0.036237269206534674,
                                    0.16790175352633332,
                                    0.14127543131204282,
                                    0.6545855459550892,
                                ],
                                [
                                    0.036237269206534674,
                                    0.14127543131204282,
                                    0.16790175352633332,
                                    0.6545855459550892,
                                ],
                                [
                                    0.056719158990370264,
                                    0.26280253621607697,
                                    0.12079354152820722,
                                    0.5596847632653456,
                                ],
                                [
                                    0.08334548120466079,
                                    0.3249325642610752,
                                    0.1207935415282072,
                                    0.4709284130060568,
                                ],
                                [
                                    0.08334548120466079,
                                    0.1207935415282072,
                                    0.3249325642610752,
                                    0.4709284130060568,
                                ],
                                [
                                    0.056719158990370264,
                                    0.12079354152820722,
                                    0.26280253621607697,
                                    0.5596847632653456,
                                ],
                                [
                                    0.1304536932027869,
                                    0.18906800200366033,
                                    0.2778243522629491,
                                    0.40265395253060365,
                                ],
                                [
                                    0.1304536932027869,
                                    0.2778243522629491,
                                    0.18906800200366033,
                                    0.40265395253060365,
                                ],
                                [
                                    0.01996974166071789,
                                    0.15310426704965094,
                                    0.09541293081286137,
                                    0.7315130604767698,
                                ],
                                [
                                    0.01996974166071789,
                                    0.09541293081286137,
                                    0.15310426704965094,
                                    0.7315130604767698,
                                ],
                                [
                                    0.0488154097791127,
                                    0.3742585989312561,
                                    0.06656726269446656,
                                    0.5103587285951646,
                                ],
                                [
                                    0.10650674601590229,
                                    0.508875926457677,
                                    0.06656726269446653,
                                    0.31805006483195425,
                                ],
                                [
                                    0.10650674601590229,
                                    0.06656726269446653,
                                    0.508875926457677,
                                    0.31805006483195425,
                                ],
                                [
                                    0.0488154097791127,
                                    0.06656726269446656,
                                    0.3742585989312561,
                                    0.5103587285951646,
                                ],
                                [
                                    0.2603524141342971,
                                    0.16272159457607172,
                                    0.35503025833928215,
                                    0.22189573295034903,
                                ],
                                [
                                    0.2603524141342971,
                                    0.35503025833928215,
                                    0.16272159457607172,
                                    0.22189573295034903,
                                ],
                                [
                                    0.007562354499773379,
                                    0.13444664018809638,
                                    0.045690289928807644,
                                    0.8123007153833226,
                                ],
                                [
                                    0.007562354499773379,
                                    0.045690289928807644,
                                    0.13444664018809638,
                                    0.8123007153833226,
                                ],
                                [
                                    0.02804424428360895,
                                    0.49858207793068154,
                                    0.025208400144972068,
                                    0.44816527764073744,
                                ],
                                [
                                    0.11680059454289768,
                                    0.7056867049385248,
                                    0.025208400144972082,
                                    0.15230430037360537,
                                ],
                                [
                                    0.11680059454289768,
                                    0.025208400144972082,
                                    0.7056867049385248,
                                    0.15230430037360537,
                                ],
                                [
                                    0.02804424428360895,
                                    0.025208400144972068,
                                    0.49858207793068154,
                                    0.44816527764073744,
                                ],
                                [
                                    0.4331434615938653,
                                    0.09348286062042523,
                                    0.3893438378875572,
                                    0.08402983989815223,
                                ],
                                [
                                    0.4331434615938653,
                                    0.3893438378875572,
                                    0.09348286062042523,
                                    0.08402983989815223,
                                ],
                                [
                                    0.0013076355213034491,
                                    0.11948764700601575,
                                    0.009517584586176433,
                                    0.8696871328865043,
                                ],
                                [
                                    0.0013076355213034491,
                                    0.009517584586176433,
                                    0.11948764700601575,
                                    0.8696871328865043,
                                ],
                                [
                                    0.006466339620485481,
                                    0.5908739043914997,
                                    0.004358880486994401,
                                    0.39830087550102045,
                                ],
                                [
                                    0.11643640204032478,
                                    0.847478741036487,
                                    0.004358880486994406,
                                    0.03172597643619377,
                                ],
                                [
                                    0.11643640204032478,
                                    0.004358880486994406,
                                    0.847478741036487,
                                    0.03172597643619377,
                                ],
                                [
                                    0.006466339620485481,
                                    0.004358880486994401,
                                    0.5908739043914997,
                                    0.39830087550102045,
                                ],
                                [
                                    0.5757853067723504,
                                    0.021554937239634798,
                                    0.38812983630446146,
                                    0.01452991968355338,
                                ],
                                [
                                    0.5757853067723504,
                                    0.38812983630446146,
                                    0.021554937239634798,
                                    0.01452991968355338,
                                ],
                                [
                                    0.010075412991693018,
                                    0.21527732190172555,
                                    0.03463410871195182,
                                    0.7400131563946296,
                                ],
                                [
                                    0.010075412991693018,
                                    0.03463410871195182,
                                    0.21527732190172555,
                                    0.7400131563946296,
                                ],
                                [
                                    0.011124076545254172,
                                    0.23768369686349844,
                                    0.03358544515839067,
                                    0.7176067814328567,
                                ],
                                [
                                    0.020646727144615004,
                                    0.07097287158969791,
                                    0.20470600774880354,
                                    0.7036743935168835,
                                ],
                                [
                                    0.020646727144615004,
                                    0.20470600774880354,
                                    0.07097287158969791,
                                    0.7036743935168835,
                                ],
                                [
                                    0.011124076545254172,
                                    0.03358544515839067,
                                    0.23768369686349844,
                                    0.7176067814328567,
                                ],
                                [
                                    0.022795668361687765,
                                    0.22601210504706484,
                                    0.06882393037262514,
                                    0.6823682962186223,
                                ],
                                [
                                    0.022795668361687765,
                                    0.06882393037262514,
                                    0.22601210504706484,
                                    0.6823682962186223,
                                ],
                                [
                                    0.007366327427755003,
                                    0.196772695305113,
                                    0.028718529495433187,
                                    0.7671424477716988,
                                ],
                                [
                                    0.007366327427755003,
                                    0.028718529495433187,
                                    0.196772695305113,
                                    0.7671424477716988,
                                ],
                                [
                                    0.011529894655379194,
                                    0.30799180055106806,
                                    0.024554962267808997,
                                    0.6559233425257438,
                                ],
                                [
                                    0.05447453942588112,
                                    0.21237566244446557,
                                    0.14966448330698687,
                                    0.5834853148226664,
                                ],
                                [
                                    0.05447453942588112,
                                    0.14966448330698687,
                                    0.21237566244446557,
                                    0.5834853148226664,
                                ],
                                [
                                    0.011529894655379194,
                                    0.024554962267808997,
                                    0.30799180055106806,
                                    0.6559233425257438,
                                ],
                                [
                                    0.08526442886779584,
                                    0.2342572663386514,
                                    0.18158577300255085,
                                    0.4988925317910019,
                                ],
                                [
                                    0.08526442886779584,
                                    0.18158577300255085,
                                    0.2342572663386514,
                                    0.4988925317910019,
                                ],
                                [
                                    0.0040594575403049594,
                                    0.16901455117006386,
                                    0.019395580975029077,
                                    0.8075304103146022,
                                ],
                                [
                                    0.0040594575403049594,
                                    0.019395580975029077,
                                    0.16901455117006386,
                                    0.8075304103146022,
                                ],
                                [
                                    0.009923217169138469,
                                    0.41315079154123036,
                                    0.013531821346195568,
                                    0.5633941699434356,
                                ],
                                [
                                    0.09059646189548937,
                                    0.43285857661984467,
                                    0.08247754681487945,
                                    0.3940674146697865,
                                ],
                                [
                                    0.09059646189548937,
                                    0.08247754681487945,
                                    0.43285857661984467,
                                    0.3940674146697865,
                                ],
                                [
                                    0.009923217169138469,
                                    0.013531821346195568,
                                    0.41315079154123036,
                                    0.5633941699434356,
                                ],
                                [
                                    0.22146022152432288,
                                    0.20161378718604595,
                                    0.30199481699101116,
                                    0.27493117429862,
                                ],
                                [
                                    0.22146022152432288,
                                    0.30199481699101116,
                                    0.20161378718604595,
                                    0.27493117429862,
                                ],
                                [
                                    0.0015372786247381317,
                                    0.14047171606313164,
                                    0.00928794148274175,
                                    0.8487030638293885,
                                ],
                                [
                                    0.0015372786247381317,
                                    0.00928794148274175,
                                    0.14047171606313164,
                                    0.8487030638293885,
                                ],
                                [
                                    0.005700845852362317,
                                    0.5209254763619282,
                                    0.005124374255117565,
                                    0.4682493035305919,
                                ],
                                [
                                    0.11077551866786242,
                                    0.669284356492459,
                                    0.031233476020007332,
                                    0.18870664881967128,
                                ],
                                [
                                    0.11077551866786242,
                                    0.031233476020007332,
                                    0.669284356492459,
                                    0.18870664881967128,
                                ],
                                [
                                    0.005700845852362317,
                                    0.005124374255117565,
                                    0.5209254763619282,
                                    0.4682493035305919,
                                ],
                                [
                                    0.41080006316261863,
                                    0.11582625905167188,
                                    0.36925981199770275,
                                    0.10411386578800674,
                                ],
                                [
                                    0.41080006316261863,
                                    0.36925981199770275,
                                    0.11582625905167188,
                                    0.10411386578800674,
                                ],
                                [
                                    0.0002658167024447689,
                                    0.12052946582487442,
                                    0.0019347386245784659,
                                    0.8772699788481023,
                                ],
                                [
                                    0.0002658167024447689,
                                    0.0019347386245784659,
                                    0.12052946582487442,
                                    0.8772699788481023,
                                ],
                                [
                                    0.0013144802560059328,
                                    0.5960257637559793,
                                    0.0008860750710173019,
                                    0.40177368091699756,
                                ],
                                [
                                    0.1153945832214661,
                                    0.839895895074889,
                                    0.00540069930585309,
                                    0.03930882239779177,
                                ],
                                [
                                    0.1153945832214661,
                                    0.00540069930585309,
                                    0.839895895074889,
                                    0.03930882239779177,
                                ],
                                [
                                    0.0013144802560059328,
                                    0.0008860750710173019,
                                    0.5960257637559793,
                                    0.40177368091699756,
                                ],
                                [
                                    0.5706334474078708,
                                    0.026706796604114368,
                                    0.38465703088848435,
                                    0.018002725099530492,
                                ],
                                [
                                    0.5706334474078708,
                                    0.38465703088848435,
                                    0.026706796604114368,
                                    0.018002725099530492,
                                ],
                                [
                                    0.0416127239310382,
                                    0.004197075436118252,
                                    0.866767677334649,
                                    0.08742252329819458,
                                ],
                                [
                                    0.0416127239310382,
                                    0.866767677334649,
                                    0.004197075436118252,
                                    0.08742252329819458,
                                ],
                                [
                                    0.06291882122929948,
                                    0.006346016653191009,
                                    0.8454615800363877,
                                    0.08527358208112182,
                                ],
                                [
                                    0.04376166514811096,
                                    0.9115288131482442,
                                    0.0020481342190454958,
                                    0.042661387484599314,
                                ],
                                [
                                    0.04376166514811096,
                                    0.0020481342190454958,
                                    0.9115288131482442,
                                    0.042661387484599314,
                                ],
                                [
                                    0.06291882122929948,
                                    0.8454615800363877,
                                    0.006346016653191009,
                                    0.08527358208112182,
                                ],
                                [
                                    0.06616804010988385,
                                    0.003096797772606648,
                                    0.8891224381864713,
                                    0.04161272393103816,
                                ],
                                [
                                    0.06616804010988385,
                                    0.8891224381864713,
                                    0.003096797772606648,
                                    0.04161272393103816,
                                ],
                                [
                                    0.03042385953702682,
                                    0.011073607439901312,
                                    0.7027259385926266,
                                    0.25577659443044526,
                                ],
                                [
                                    0.03042385953702682,
                                    0.7027259385926266,
                                    0.011073607439901312,
                                    0.25577659443044526,
                                ],
                                [
                                    0.11501664256869136,
                                    0.041863496881816016,
                                    0.618133155560962,
                                    0.22498670498853057,
                                ],
                                [
                                    0.040000036818390955,
                                    0.9239151062584209,
                                    0.0014974301585371761,
                                    0.03458742676465096,
                                ],
                                [
                                    0.040000036818390955,
                                    0.0014974301585371761,
                                    0.9239151062584209,
                                    0.03458742676465096,
                                ],
                                [
                                    0.11501664256869136,
                                    0.618133155560962,
                                    0.041863496881816016,
                                    0.22498670498853057,
                                ],
                                [
                                    0.151219142064346,
                                    0.005660997386161362,
                                    0.8126960010124658,
                                    0.030423859537026775,
                                ],
                                [
                                    0.151219142064346,
                                    0.8126960010124658,
                                    0.005660997386161362,
                                    0.030423859537026775,
                                ],
                                [
                                    0.01676607063886682,
                                    0.018416487134134234,
                                    0.45977889084579915,
                                    0.5050385513811998,
                                ],
                                [
                                    0.01676607063886682,
                                    0.45977889084579915,
                                    0.018416487134134234,
                                    0.5050385513811998,
                                ],
                                [
                                    0.1359023110100333,
                                    0.14928024676296775,
                                    0.34064265047463266,
                                    0.3741747917523663,
                                ],
                                [
                                    0.03435734952536735,
                                    0.9421876119592986,
                                    0.0008252082476337037,
                                    0.022629830267700306,
                                ],
                                [
                                    0.03435734952536735,
                                    0.0008252082476337037,
                                    0.9421876119592986,
                                    0.022629830267700306,
                                ],
                                [
                                    0.1359023110100333,
                                    0.34064265047463266,
                                    0.14928024676296775,
                                    0.3741747917523663,
                                ],
                                [
                                    0.27849358989653383,
                                    0.006688967876467206,
                                    0.6980513715881321,
                                    0.016766070638866804,
                                ],
                                [
                                    0.27849358989653383,
                                    0.6980513715881321,
                                    0.006688967876467206,
                                    0.016766070638866804,
                                ],
                                [
                                    0.0063491542301101,
                                    0.022518494338963878,
                                    0.21359097060956853,
                                    0.7575413808213575,
                                ],
                                [
                                    0.0063491542301101,
                                    0.21359097060956853,
                                    0.022518494338963878,
                                    0.7575413808213575,
                                ],
                                [
                                    0.09094193726177464,
                                    0.3225430388337201,
                                    0.128998187577904,
                                    0.4575168363266013,
                                ],
                                [
                                    0.028555149919328376,
                                    0.9606196299731917,
                                    0.0003124986497456025,
                                    0.01051272145773428,
                                ],
                                [
                                    0.028555149919328376,
                                    0.0003124986497456025,
                                    0.9606196299731917,
                                    0.01051272145773428,
                                ],
                                [
                                    0.09094193726177464,
                                    0.128998187577904,
                                    0.3225430388337201,
                                    0.4575168363266013,
                                ],
                                [
                                    0.40900891021812497,
                                    0.004476065877369788,
                                    0.5801658696743952,
                                    0.006349154230110094,
                                ],
                                [
                                    0.40900891021812497,
                                    0.5801658696743952,
                                    0.004476065877369788,
                                    0.006349154230110094,
                                ],
                                [
                                    0.001097856441637961,
                                    0.023457459737207694,
                                    0.043611665262006875,
                                    0.9318330185591475,
                                ],
                                [
                                    0.001097856441637961,
                                    0.043611665262006875,
                                    0.023457459737207694,
                                    0.9318330185591475,
                                ],
                                [
                                    0.02240395373989923,
                                    0.4786963239236124,
                                    0.02230556796374561,
                                    0.4765941543727428,
                                ],
                                [
                                    0.024501280847021554,
                                    0.9732981638259552,
                                    5.403533182409801e-05,
                                    0.0021465199951991114,
                                ],
                                [
                                    0.024501280847021554,
                                    5.403533182409801e-05,
                                    0.9732981638259552,
                                    0.0021465199951991114,
                                ],
                                [
                                    0.02240395373989923,
                                    0.02230556796374561,
                                    0.4786963239236124,
                                    0.4765941543727428,
                                ],
                                [
                                    0.49999757877812634,
                                    0.00110269888538525,
                                    0.4978018658948504,
                                    0.0010978564416379596,
                                ],
                                [
                                    0.49999757877812634,
                                    0.4978018658948504,
                                    0.00110269888538525,
                                    0.0010978564416379596,
                                ],
                                [
                                    0.03358544515839068,
                                    0.012224354208765775,
                                    0.6995643529712627,
                                    0.2546258476615808,
                                ],
                                [
                                    0.03358544515839068,
                                    0.6995643529712627,
                                    0.012224354208765775,
                                    0.2546258476615808,
                                ],
                                [
                                    0.05078150191103108,
                                    0.018483335971459416,
                                    0.6823682962186224,
                                    0.24836686589888715,
                                ],
                                [
                                    0.03573438637546344,
                                    0.7443254887848579,
                                    0.010075412991693018,
                                    0.20986471184798555,
                                ],
                                [
                                    0.03573438637546344,
                                    0.010075412991693018,
                                    0.7443254887848579,
                                    0.20986471184798555,
                                ],
                                [
                                    0.05078150191103108,
                                    0.6823682962186224,
                                    0.018483335971459416,
                                    0.24836686589888715,
                                ],
                                [
                                    0.05403072079161543,
                                    0.015234117090875056,
                                    0.726029154368706,
                                    0.20470600774880351,
                                ],
                                [
                                    0.05403072079161543,
                                    0.726029154368706,
                                    0.015234117090875056,
                                    0.20470600774880351,
                                ],
                                [
                                    0.024554962267808997,
                                    0.016942504709119136,
                                    0.5671669922664552,
                                    0.39133554075661675,
                                ],
                                [
                                    0.024554962267808997,
                                    0.5671669922664552,
                                    0.016942504709119136,
                                    0.39133554075661675,
                                ],
                                [
                                    0.09282942274326214,
                                    0.06405071670724524,
                                    0.49889253179100196,
                                    0.34422732875849066,
                                ],
                                [
                                    0.034131139549173135,
                                    0.7883561599322495,
                                    0.007366327427754999,
                                    0.1701463730908224,
                                ],
                                [
                                    0.034131139549173135,
                                    0.007366327427754999,
                                    0.7883561599322495,
                                    0.1701463730908224,
                                ],
                                [
                                    0.09282942274326214,
                                    0.49889253179100196,
                                    0.06405071670724524,
                                    0.34422732875849066,
                                ],
                                [
                                    0.12903192223891682,
                                    0.027848217211590576,
                                    0.6934553772425058,
                                    0.1496644833069868,
                                ],
                                [
                                    0.12903192223891682,
                                    0.6934553772425058,
                                    0.027848217211590576,
                                    0.1496644833069868,
                                ],
                                [
                                    0.013531821346195566,
                                    0.021650736426805487,
                                    0.3710855061802252,
                                    0.5937319360467738,
                                ],
                                [
                                    0.013531821346195566,
                                    0.3710855061802252,
                                    0.021650736426805487,
                                    0.5937319360467738,
                                ],
                                [
                                    0.10968615322780076,
                                    0.1754964045452003,
                                    0.27493117429862,
                                    0.4398862679283789,
                                ],
                                [
                                    0.031123100232696096,
                                    0.8534942272937247,
                                    0.0040594575403049594,
                                    0.11132321493327427,
                                ],
                                [
                                    0.031123100232696096,
                                    0.0040594575403049594,
                                    0.8534942272937247,
                                    0.11132321493327427,
                                ],
                                [
                                    0.10968615322780076,
                                    0.27493117429862,
                                    0.1754964045452003,
                                    0.4398862679283789,
                                ],
                                [
                                    0.25227743211430126,
                                    0.03290512565869977,
                                    0.6323398954121194,
                                    0.08247754681487945,
                                ],
                                [
                                    0.25227743211430126,
                                    0.6323398954121194,
                                    0.03290512565869977,
                                    0.08247754681487945,
                                ],
                                [
                                    0.005124374255117571,
                                    0.023743274313956408,
                                    0.1723883262634599,
                                    0.7987440251674661,
                                ],
                                [
                                    0.005124374255117571,
                                    0.1723883262634599,
                                    0.023743274313956408,
                                    0.7987440251674661,
                                ],
                                [
                                    0.07339883473057073,
                                    0.340086141364924,
                                    0.10411386578800676,
                                    0.48240115811649853,
                                ],
                                [
                                    0.027330369944335846,
                                    0.9194169856270832,
                                    0.0015372786247381327,
                                    0.05171536580384291,
                                ],
                                [
                                    0.027330369944335846,
                                    0.0015372786247381327,
                                    0.9194169856270832,
                                    0.05171536580384291,
                                ],
                                [
                                    0.07339883473057073,
                                    0.10411386578800676,
                                    0.340086141364924,
                                    0.48240115811649853,
                                ],
                                [
                                    0.391465807686921,
                                    0.022019168408573712,
                                    0.5552815478844979,
                                    0.03123347602000733,
                                ],
                                [
                                    0.391465807686921,
                                    0.5552815478844979,
                                    0.022019168408573712,
                                    0.03123347602000733,
                                ],
                                [
                                    0.0008860750710172936,
                                    0.02366924110782836,
                                    0.035198781852170895,
                                    0.9402459019689835,
                                ],
                                [
                                    0.0008860750710172936,
                                    0.035198781852170895,
                                    0.02366924110782836,
                                    0.9402459019689835,
                                ],
                                [
                                    0.018082131823657692,
                                    0.4830181458398539,
                                    0.0180027250995305,
                                    0.4808969972369579,
                                ],
                                [
                                    0.024289499476400887,
                                    0.9648852804161192,
                                    0.0002658167024447663,
                                    0.010559403405035127,
                                ],
                                [
                                    0.024289499476400887,
                                    0.0002658167024447663,
                                    0.9648852804161192,
                                    0.010559403405035127,
                                ],
                                [
                                    0.018082131823657692,
                                    0.0180027250995305,
                                    0.4830181458398539,
                                    0.4808969972369579,
                                ],
                                [
                                    0.4956757568618848,
                                    0.0054245208016268035,
                                    0.4934990230306353,
                                    0.0054006993058530895,
                                ],
                                [
                                    0.4956757568618848,
                                    0.4934990230306353,
                                    0.0054245208016268035,
                                    0.0054006993058530895,
                                ],
                                [
                                    0.02183042907504185,
                                    0.023979370292114607,
                                    0.4547145324096241,
                                    0.4994756682232194,
                                ],
                                [
                                    0.02183042907504185,
                                    0.4547145324096241,
                                    0.023979370292114607,
                                    0.4994756682232194,
                                ],
                                [
                                    0.03300780950095306,
                                    0.03625702838153743,
                                    0.4435371519837129,
                                    0.4871980101337966,
                                ],
                                [
                                    0.023979370292114607,
                                    0.4994756682232194,
                                    0.02183042907504185,
                                    0.4547145324096241,
                                ],
                                [
                                    0.023979370292114607,
                                    0.02183042907504185,
                                    0.4994756682232194,
                                    0.4547145324096241,
                                ],
                                [
                                    0.03300780950095306,
                                    0.4435371519837129,
                                    0.03625702838153743,
                                    0.4871980101337966,
                                ],
                                [
                                    0.03625702838153743,
                                    0.03300780950095306,
                                    0.4871980101337966,
                                    0.4435371519837129,
                                ],
                                [
                                    0.03625702838153743,
                                    0.4871980101337966,
                                    0.03300780950095306,
                                    0.4435371519837129,
                                ],
                                [
                                    0.015960644847782,
                                    0.025536822129146132,
                                    0.3686566826786389,
                                    0.589845850344433,
                                ],
                                [
                                    0.015960644847782,
                                    0.3686566826786389,
                                    0.025536822129146132,
                                    0.589845850344433,
                                ],
                                [
                                    0.06033881997742638,
                                    0.096541319473081,
                                    0.3242785075489945,
                                    0.5188413530004982,
                                ],
                                [
                                    0.025536822129146135,
                                    0.5898458503444332,
                                    0.015960644847781997,
                                    0.36865668267863877,
                                ],
                                [
                                    0.025536822129146135,
                                    0.015960644847781997,
                                    0.5898458503444332,
                                    0.36865668267863877,
                                ],
                                [
                                    0.06033881997742638,
                                    0.3242785075489945,
                                    0.096541319473081,
                                    0.5188413530004982,
                                ],
                                [
                                    0.09654131947308102,
                                    0.06033881997742636,
                                    0.5188413530004983,
                                    0.3242785075489944,
                                ],
                                [
                                    0.09654131947308102,
                                    0.5188413530004983,
                                    0.06033881997742636,
                                    0.3242785075489944,
                                ],
                                [
                                    0.008795639443250264,
                                    0.02638691832975079,
                                    0.24120436055674974,
                                    0.7236130816702492,
                                ],
                                [
                                    0.008795639443250264,
                                    0.24120436055674974,
                                    0.02638691832975079,
                                    0.7236130816702492,
                                ],
                                [
                                    0.07129563944325026,
                                    0.2138869183297508,
                                    0.17870436055674974,
                                    0.5361130816702492,
                                ],
                                [
                                    0.02638691832975079,
                                    0.7236130816702492,
                                    0.008795639443250264,
                                    0.24120436055674974,
                                ],
                                [
                                    0.02638691832975079,
                                    0.008795639443250264,
                                    0.7236130816702492,
                                    0.24120436055674974,
                                ],
                                [
                                    0.07129563944325026,
                                    0.17870436055674974,
                                    0.2138869183297508,
                                    0.5361130816702492,
                                ],
                                [
                                    0.2138869183297508,
                                    0.07129563944325026,
                                    0.5361130816702492,
                                    0.17870436055674974,
                                ],
                                [
                                    0.2138869183297508,
                                    0.5361130816702492,
                                    0.07129563944325026,
                                    0.17870436055674974,
                                ],
                                [
                                    0.0033308264399278514,
                                    0.025536822129146125,
                                    0.1120518460336514,
                                    0.8590805053972747,
                                ],
                                [
                                    0.0033308264399278514,
                                    0.1120518460336514,
                                    0.025536822129146125,
                                    0.8590805053972747,
                                ],
                                [
                                    0.04770900156957222,
                                    0.36577597452592253,
                                    0.06767367090400704,
                                    0.5188413530004983,
                                ],
                                [
                                    0.025536822129146125,
                                    0.8590805053972747,
                                    0.0033308264399278514,
                                    0.1120518460336514,
                                ],
                                [
                                    0.025536822129146125,
                                    0.0033308264399278514,
                                    0.8590805053972747,
                                    0.1120518460336514,
                                ],
                                [
                                    0.04770900156957222,
                                    0.06767367090400704,
                                    0.36577597452592253,
                                    0.5188413530004983,
                                ],
                                [
                                    0.36577597452592253,
                                    0.04770900156957222,
                                    0.5188413530004983,
                                    0.06767367090400704,
                                ],
                                [
                                    0.36577597452592253,
                                    0.5188413530004983,
                                    0.04770900156957222,
                                    0.06767367090400704,
                                ],
                                [
                                    0.0005759458867310299,
                                    0.023979370292114624,
                                    0.022879092628603007,
                                    0.9525655911925514,
                                ],
                                [
                                    0.0005759458867310299,
                                    0.022879092628603007,
                                    0.023979370292114624,
                                    0.9525655911925514,
                                ],
                                [
                                    0.011753326312642245,
                                    0.48934695135086936,
                                    0.011701712202691792,
                                    0.4871980101337966,
                                ],
                                [
                                    0.023979370292114624,
                                    0.9525655911925514,
                                    0.0005759458867310299,
                                    0.022879092628603007,
                                ],
                                [
                                    0.023979370292114624,
                                    0.0005759458867310299,
                                    0.9525655911925514,
                                    0.022879092628603007,
                                ],
                                [
                                    0.011753326312642245,
                                    0.011701712202691792,
                                    0.48934695135086936,
                                    0.4871980101337966,
                                ],
                                [
                                    0.48934695135086936,
                                    0.011753326312642245,
                                    0.4871980101337966,
                                    0.011701712202691792,
                                ],
                                [
                                    0.48934695135086936,
                                    0.4871980101337966,
                                    0.011753326312642245,
                                    0.011701712202691792,
                                ],
                                [
                                    0.010075412991693022,
                                    0.03573438637546344,
                                    0.2098647118479856,
                                    0.7443254887848579,
                                ],
                                [
                                    0.010075412991693022,
                                    0.2098647118479856,
                                    0.03573438637546344,
                                    0.7443254887848579,
                                ],
                                [
                                    0.01523411709087506,
                                    0.05403072079161543,
                                    0.20470600774880357,
                                    0.726029154368706,
                                ],
                                [
                                    0.01222435420876578,
                                    0.2546258476615809,
                                    0.033585445158390674,
                                    0.6995643529712626,
                                ],
                                [
                                    0.01222435420876578,
                                    0.033585445158390674,
                                    0.2546258476615809,
                                    0.6995643529712626,
                                ],
                                [
                                    0.01523411709087506,
                                    0.20470600774880357,
                                    0.05403072079161543,
                                    0.726029154368706,
                                ],
                                [
                                    0.018483335971459423,
                                    0.05078150191103107,
                                    0.24836686589888726,
                                    0.6823682962186223,
                                ],
                                [
                                    0.018483335971459423,
                                    0.24836686589888726,
                                    0.05078150191103107,
                                    0.6823682962186223,
                                ],
                                [
                                    0.007366327427755002,
                                    0.03413113954917313,
                                    0.17014637309082248,
                                    0.7883561599322494,
                                ],
                                [
                                    0.007366327427755002,
                                    0.17014637309082248,
                                    0.03413113954917313,
                                    0.7883561599322494,
                                ],
                                [
                                    0.02784821721159059,
                                    0.1290319222389168,
                                    0.1496644833069869,
                                    0.6934553772425057,
                                ],
                                [
                                    0.016942504709119142,
                                    0.39133554075661686,
                                    0.02455496226780899,
                                    0.5671669922664551,
                                ],
                                [
                                    0.016942504709119142,
                                    0.02455496226780899,
                                    0.39133554075661686,
                                    0.5671669922664551,
                                ],
                                [
                                    0.02784821721159059,
                                    0.1496644833069869,
                                    0.1290319222389168,
                                    0.6934553772425057,
                                ],
                                [
                                    0.06405071670724526,
                                    0.09282942274326213,
                                    0.3442273287584907,
                                    0.4988925317910019,
                                ],
                                [
                                    0.06405071670724526,
                                    0.3442273287584907,
                                    0.09282942274326213,
                                    0.4988925317910019,
                                ],
                                [
                                    0.00405945754030496,
                                    0.031123100232696096,
                                    0.1113232149332743,
                                    0.8534942272937247,
                                ],
                                [
                                    0.00405945754030496,
                                    0.1113232149332743,
                                    0.031123100232696096,
                                    0.8534942272937247,
                                ],
                                [
                                    0.032905125658699776,
                                    0.25227743211430126,
                                    0.08247754681487948,
                                    0.6323398954121194,
                                ],
                                [
                                    0.021650736426805487,
                                    0.5937319360467738,
                                    0.013531821346195566,
                                    0.3710855061802252,
                                ],
                                [
                                    0.021650736426805487,
                                    0.013531821346195566,
                                    0.5937319360467738,
                                    0.3710855061802252,
                                ],
                                [
                                    0.032905125658699776,
                                    0.08247754681487948,
                                    0.25227743211430126,
                                    0.6323398954121194,
                                ],
                                [
                                    0.1754964045452003,
                                    0.10968615322780076,
                                    0.4398862679283789,
                                    0.27493117429862,
                                ],
                                [
                                    0.1754964045452003,
                                    0.4398862679283789,
                                    0.10968615322780076,
                                    0.27493117429862,
                                ],
                                [
                                    0.0015372786247381323,
                                    0.027330369944335846,
                                    0.05171536580384289,
                                    0.9194169856270832,
                                ],
                                [
                                    0.0015372786247381323,
                                    0.05171536580384289,
                                    0.027330369944335846,
                                    0.9194169856270832,
                                ],
                                [
                                    0.022019168408573705,
                                    0.391465807686921,
                                    0.031233476020007315,
                                    0.5552815478844979,
                                ],
                                [
                                    0.023743274313956408,
                                    0.7987440251674661,
                                    0.00512437425511757,
                                    0.17238832626345987,
                                ],
                                [
                                    0.023743274313956408,
                                    0.00512437425511757,
                                    0.7987440251674661,
                                    0.17238832626345987,
                                ],
                                [
                                    0.022019168408573705,
                                    0.031233476020007315,
                                    0.391465807686921,
                                    0.5552815478844979,
                                ],
                                [
                                    0.340086141364924,
                                    0.07339883473057071,
                                    0.48240115811649853,
                                    0.10411386578800674,
                                ],
                                [
                                    0.340086141364924,
                                    0.48240115811649853,
                                    0.07339883473057071,
                                    0.10411386578800674,
                                ],
                                [
                                    0.00026581670244476603,
                                    0.024289499476400887,
                                    0.010559403405035117,
                                    0.9648852804161192,
                                ],
                                [
                                    0.00026581670244476603,
                                    0.010559403405035117,
                                    0.024289499476400887,
                                    0.9648852804161192,
                                ],
                                [
                                    0.005424520801626798,
                                    0.4956757568618848,
                                    0.005400699305853084,
                                    0.4934990230306353,
                                ],
                                [
                                    0.02366924110782836,
                                    0.9402459019689835,
                                    0.0008860750710172932,
                                    0.03519878185217088,
                                ],
                                [
                                    0.02366924110782836,
                                    0.0008860750710172932,
                                    0.9402459019689835,
                                    0.03519878185217088,
                                ],
                                [
                                    0.005424520801626798,
                                    0.005400699305853084,
                                    0.4956757568618848,
                                    0.4934990230306353,
                                ],
                                [
                                    0.4830181458398539,
                                    0.018082131823657685,
                                    0.4808969972369579,
                                    0.018002725099530492,
                                ],
                                [
                                    0.4830181458398539,
                                    0.4808969972369579,
                                    0.018082131823657685,
                                    0.018002725099530492,
                                ],
                                [
                                    0.002048134219045497,
                                    0.04376166514811096,
                                    0.04266138748459934,
                                    0.9115288131482442,
                                ],
                                [
                                    0.002048134219045497,
                                    0.04266138748459934,
                                    0.04376166514811096,
                                    0.9115288131482442,
                                ],
                                [
                                    0.0030967977726066498,
                                    0.06616804010988385,
                                    0.04161272393103819,
                                    0.8891224381864713,
                                ],
                                [
                                    0.004197075436118256,
                                    0.08742252329819465,
                                    0.0416127239310382,
                                    0.8667676773346489,
                                ],
                                [
                                    0.004197075436118256,
                                    0.0416127239310382,
                                    0.08742252329819465,
                                    0.8667676773346489,
                                ],
                                [
                                    0.0030967977726066498,
                                    0.04161272393103819,
                                    0.06616804010988385,
                                    0.8891224381864713,
                                ],
                                [
                                    0.0063460166531910155,
                                    0.06291882122929948,
                                    0.0852735820811219,
                                    0.8454615800363876,
                                ],
                                [
                                    0.0063460166531910155,
                                    0.0852735820811219,
                                    0.06291882122929948,
                                    0.8454615800363876,
                                ],
                                [
                                    0.0014974301585371785,
                                    0.040000036818390955,
                                    0.034587426764651014,
                                    0.9239151062584209,
                                ],
                                [
                                    0.0014974301585371785,
                                    0.034587426764651014,
                                    0.040000036818390955,
                                    0.9239151062584209,
                                ],
                                [
                                    0.00566099738616137,
                                    0.151219142064346,
                                    0.03042385953702682,
                                    0.8126960010124658,
                                ],
                                [
                                    0.011073607439901318,
                                    0.25577659443044537,
                                    0.030423859537026816,
                                    0.7027259385926264,
                                ],
                                [
                                    0.011073607439901318,
                                    0.030423859537026816,
                                    0.25577659443044537,
                                    0.7027259385926264,
                                ],
                                [
                                    0.00566099738616137,
                                    0.03042385953702682,
                                    0.151219142064346,
                                    0.8126960010124658,
                                ],
                                [
                                    0.04186349688181604,
                                    0.11501664256869135,
                                    0.22498670498853066,
                                    0.6181331555609619,
                                ],
                                [
                                    0.04186349688181604,
                                    0.22498670498853066,
                                    0.11501664256869135,
                                    0.6181331555609619,
                                ],
                                [
                                    0.0008252082476337047,
                                    0.03435734952536735,
                                    0.02262983026770033,
                                    0.9421876119592986,
                                ],
                                [
                                    0.0008252082476337047,
                                    0.02262983026770033,
                                    0.03435734952536735,
                                    0.9421876119592986,
                                ],
                                [
                                    0.006688967876467214,
                                    0.27849358989653383,
                                    0.01676607063886682,
                                    0.6980513715881321,
                                ],
                                [
                                    0.018416487134134234,
                                    0.5050385513811998,
                                    0.01676607063886682,
                                    0.45977889084579915,
                                ],
                                [
                                    0.018416487134134234,
                                    0.01676607063886682,
                                    0.5050385513811998,
                                    0.45977889084579915,
                                ],
                                [
                                    0.006688967876467214,
                                    0.01676607063886682,
                                    0.27849358989653383,
                                    0.6980513715881321,
                                ],
                                [
                                    0.14928024676296775,
                                    0.1359023110100333,
                                    0.3741747917523663,
                                    0.34064265047463266,
                                ],
                                [
                                    0.14928024676296775,
                                    0.3741747917523663,
                                    0.1359023110100333,
                                    0.34064265047463266,
                                ],
                                [
                                    0.0003124986497456025,
                                    0.028555149919328376,
                                    0.01051272145773428,
                                    0.9606196299731917,
                                ],
                                [
                                    0.0003124986497456025,
                                    0.01051272145773428,
                                    0.028555149919328376,
                                    0.9606196299731917,
                                ],
                                [
                                    0.004476065877369788,
                                    0.40900891021812497,
                                    0.006349154230110094,
                                    0.5801658696743952,
                                ],
                                [
                                    0.022518494338963878,
                                    0.7575413808213575,
                                    0.0063491542301101,
                                    0.21359097060956853,
                                ],
                                [
                                    0.022518494338963878,
                                    0.0063491542301101,
                                    0.7575413808213575,
                                    0.21359097060956853,
                                ],
                                [
                                    0.004476065877369788,
                                    0.006349154230110094,
                                    0.40900891021812497,
                                    0.5801658696743952,
                                ],
                                [
                                    0.3225430388337201,
                                    0.09094193726177464,
                                    0.4575168363266013,
                                    0.128998187577904,
                                ],
                                [
                                    0.3225430388337201,
                                    0.4575168363266013,
                                    0.09094193726177464,
                                    0.128998187577904,
                                ],
                                [
                                    5.403533182409863e-05,
                                    0.024501280847021554,
                                    0.002146519995199136,
                                    0.9732981638259552,
                                ],
                                [
                                    5.403533182409863e-05,
                                    0.002146519995199136,
                                    0.024501280847021554,
                                    0.9732981638259552,
                                ],
                                [
                                    0.0011026988853852625,
                                    0.49999757877812634,
                                    0.0010978564416379722,
                                    0.4978018658948504,
                                ],
                                [
                                    0.023457459737207694,
                                    0.9318330185591475,
                                    0.0010978564416379616,
                                    0.043611665262006896,
                                ],
                                [
                                    0.023457459737207694,
                                    0.0010978564416379616,
                                    0.9318330185591475,
                                    0.043611665262006896,
                                ],
                                [
                                    0.0011026988853852625,
                                    0.0010978564416379722,
                                    0.49999757877812634,
                                    0.4978018658948504,
                                ],
                                [
                                    0.4786963239236124,
                                    0.02240395373989924,
                                    0.4765941543727428,
                                    0.02230556796374562,
                                ],
                                [
                                    0.4786963239236124,
                                    0.4765941543727428,
                                    0.02240395373989924,
                                    0.02230556796374562,
                                ],
                                [
                                    0.8345270848028626,
                                    0.08417072466118855,
                                    0.07385331646282449,
                                    0.007448874073124271,
                                ],
                                [
                                    0.8345270848028626,
                                    0.07385331646282449,
                                    0.08417072466118855,
                                    0.007448874073124271,
                                ],
                                [
                                    0.8673058616143633,
                                    0.08747680477287614,
                                    0.04107453965132394,
                                    0.004142793961436684,
                                ],
                                [
                                    0.8776232698127272,
                                    0.07766720848362789,
                                    0.041074539651323946,
                                    0.0036349820523208665,
                                ],
                                [
                                    0.8776232698127272,
                                    0.041074539651323946,
                                    0.07766720848362789,
                                    0.0036349820523208665,
                                ],
                                [
                                    0.8673058616143633,
                                    0.04107453965132394,
                                    0.08747680477287614,
                                    0.004142793961436684,
                                ],
                                [
                                    0.9120947900421352,
                                    0.042687876345104146,
                                    0.043195688254219954,
                                    0.0020216453585406692,
                                ],
                                [
                                    0.9120947900421352,
                                    0.043195688254219954,
                                    0.042687876345104146,
                                    0.0020216453585406692,
                                ],
                                [
                                    0.5747193210185918,
                                    0.20918503588741108,
                                    0.15843047711106156,
                                    0.05766516598293547,
                                ],
                                [
                                    0.5747193210185918,
                                    0.15843047711106156,
                                    0.20918503588741108,
                                    0.05766516598293547,
                                ],
                                [
                                    0.7048627215692366,
                                    0.2565543358553439,
                                    0.028287076560416926,
                                    0.010295866015002724,
                                ],
                                [
                                    0.755617280345586,
                                    0.2082978627312258,
                                    0.028287076560416922,
                                    0.007797780362771211,
                                ],
                                [
                                    0.755617280345586,
                                    0.028287076560416922,
                                    0.2082978627312258,
                                    0.007797780362771211,
                                ],
                                [
                                    0.7048627215692366,
                                    0.028287076560416926,
                                    0.2565543358553439,
                                    0.010295866015002724,
                                ],
                                [
                                    0.9267244604639018,
                                    0.034692596960678536,
                                    0.037190682612910045,
                                    0.001392259962509602,
                                ],
                                [
                                    0.9267244604639018,
                                    0.037190682612910045,
                                    0.034692596960678536,
                                    0.001392259962509602,
                                ],
                                [
                                    0.2795007794767504,
                                    0.3070142444277549,
                                    0.19704418200791557,
                                    0.21644079408757916,
                                ],
                                [
                                    0.2795007794767504,
                                    0.19704418200791557,
                                    0.3070142444277549,
                                    0.21644079408757916,
                                ],
                                [
                                    0.4627882290091637,
                                    0.5083441224217623,
                                    0.013756732475502218,
                                    0.015110916093571732,
                                ],
                                [
                                    0.572758291429003,
                                    0.40378667005566293,
                                    0.013756732475502218,
                                    0.009698306039831791,
                                ],
                                [
                                    0.572758291429003,
                                    0.013756732475502218,
                                    0.40378667005566293,
                                    0.009698306039831791,
                                ],
                                [
                                    0.4627882290091637,
                                    0.013756732475502218,
                                    0.5083441224217623,
                                    0.015110916093571732,
                                ],
                                [
                                    0.9483544047246267,
                                    0.022777946706299252,
                                    0.028190556760039193,
                                    0.0006770918090347562,
                                ],
                                [
                                    0.9483544047246267,
                                    0.028190556760039193,
                                    0.022777946706299252,
                                    0.0006770918090347562,
                                ],
                                [
                                    0.08558435303553372,
                                    0.303541337867474,
                                    0.1343557718041449,
                                    0.4765185372928474,
                                ],
                                [
                                    0.08558435303553372,
                                    0.1343557718041449,
                                    0.303541337867474,
                                    0.4765185372928474,
                                ],
                                [
                                    0.21572775358617838,
                                    0.7651198918510934,
                                    0.00421237125350024,
                                    0.014939983309228012,
                                ],
                                [
                                    0.3849133196495075,
                                    0.6042614602430126,
                                    0.004212371253500241,
                                    0.0066128488539796415,
                                ],
                                [
                                    0.3849133196495075,
                                    0.004212371253500241,
                                    0.6042614602430126,
                                    0.0066128488539796415,
                                ],
                                [
                                    0.21572775358617838,
                                    0.00421237125350024,
                                    0.7651198918510934,
                                    0.014939983309228012,
                                ],
                                [
                                    0.97022975378351,
                                    0.010617891653761853,
                                    0.01894502610901022,
                                    0.00020732845371802995,
                                ],
                                [
                                    0.97022975378351,
                                    0.01894502610901022,
                                    0.010617891653761853,
                                    0.00020732845371802995,
                                ],
                                [
                                    0.011371072730220536,
                                    0.2429611656147389,
                                    0.033338448973424306,
                                    0.7123293126816163,
                                ],
                                [
                                    0.011371072730220536,
                                    0.033338448973424306,
                                    0.2429611656147389,
                                    0.7123293126816163,
                                ],
                                [
                                    0.0441498495417211,
                                    0.9433321869328917,
                                    0.0005596721619237368,
                                    0.011958291363463536,
                                ],
                                [
                                    0.2537725661830357,
                                    0.7440268784899411,
                                    0.0005596721619237371,
                                    0.0016408831650994726,
                                ],
                                [
                                    0.2537725661830357,
                                    0.0005596721619237371,
                                    0.7440268784899411,
                                    0.0016408831650994726,
                                ],
                                [
                                    0.0441498495417211,
                                    0.0005596721619237368,
                                    0.9433321869328917,
                                    0.011958291363463536,
                                ],
                                [
                                    0.9853090276189088,
                                    0.0021730088557039362,
                                    0.012490417054068,
                                    2.75464713192732e-05,
                                ],
                                [
                                    0.9853090276189088,
                                    0.012490417054068,
                                    0.0021730088557039362,
                                    2.75464713192732e-05,
                                ],
                                [
                                    0.6735431135507239,
                                    0.24515469591332728,
                                    0.059606684578929446,
                                    0.021695505957019308,
                                ],
                                [
                                    0.6735431135507239,
                                    0.059606684578929446,
                                    0.24515469591332728,
                                    0.021695505957019308,
                                ],
                                [
                                    0.6999987191194968,
                                    0.2547839472677426,
                                    0.033151079010156646,
                                    0.01206625460260398,
                                ],
                                [
                                    0.7166392985605885,
                                    0.06342057659973285,
                                    0.20205851090346266,
                                    0.0178816139362159,
                                ],
                                [
                                    0.7166392985605885,
                                    0.20205851090346266,
                                    0.06342057659973285,
                                    0.0178816139362159,
                                ],
                                [
                                    0.6999987191194968,
                                    0.033151079010156646,
                                    0.2547839472677426,
                                    0.01206625460260398,
                                ],
                                [
                                    0.7447876475472688,
                                    0.2099950188399706,
                                    0.03527222761305266,
                                    0.009945105999707965,
                                ],
                                [
                                    0.7447876475472688,
                                    0.03527222761305266,
                                    0.2099950188399706,
                                    0.009945105999707965,
                                ],
                                [
                                    0.4638534182363454,
                                    0.3200509386696575,
                                    0.1278685362979187,
                                    0.08822710679607836,
                                ],
                                [
                                    0.4638534182363454,
                                    0.1278685362979187,
                                    0.3200509386696575,
                                    0.08822710679607836,
                                ],
                                [
                                    0.5688915803418536,
                                    0.39252547708272684,
                                    0.02283037419241059,
                                    0.01575256838300906,
                                ],
                                [
                                    0.6447513775633397,
                                    0.17773592191808296,
                                    0.1391529793426633,
                                    0.03835972117591408,
                                ],
                                [
                                    0.6447513775633397,
                                    0.1391529793426633,
                                    0.17773592191808296,
                                    0.03835972117591408,
                                ],
                                [
                                    0.5688915803418536,
                                    0.02283037419241059,
                                    0.39252547708272684,
                                    0.01575256838300906,
                                ],
                                [
                                    0.7907533192365189,
                                    0.17066373818806146,
                                    0.03173398024490372,
                                    0.006848962330515938,
                                ],
                                [
                                    0.7907533192365189,
                                    0.03173398024490372,
                                    0.17066373818806146,
                                    0.006848962330515938,
                                ],
                                [
                                    0.2255838410482456,
                                    0.3609311828562597,
                                    0.15903348647817514,
                                    0.25445148961731956,
                                ],
                                [
                                    0.2255838410482456,
                                    0.15903348647817514,
                                    0.3609311828562597,
                                    0.25445148961731956,
                                ],
                                [
                                    0.3735143296818116,
                                    0.5976180217491144,
                                    0.011102997844609127,
                                    0.017764650724464825,
                                ],
                                [
                                    0.5188413530004983,
                                    0.36577597452592253,
                                    0.06767367090400703,
                                    0.0477090015695722,
                                ],
                                [
                                    0.5188413530004983,
                                    0.06767367090400703,
                                    0.36577597452592253,
                                    0.0477090015695722,
                                ],
                                [
                                    0.3735143296818116,
                                    0.011102997844609127,
                                    0.5976180217491144,
                                    0.017764650724464825,
                                ],
                                [
                                    0.8590805053972747,
                                    0.11205184603365137,
                                    0.0255368221291461,
                                    0.0033308264399278475,
                                ],
                                [
                                    0.8590805053972747,
                                    0.0255368221291461,
                                    0.11205184603365137,
                                    0.0033308264399278475,
                                ],
                                [
                                    0.06907475223335016,
                                    0.32005093866965756,
                                    0.10843794828522732,
                                    0.5024363608117649,
                                ],
                                [
                                    0.06907475223335016,
                                    0.10843794828522732,
                                    0.32005093866965756,
                                    0.5024363608117649,
                                ],
                                [
                                    0.17411291433885828,
                                    0.8067347310984134,
                                    0.0033997861797191915,
                                    0.01575256838300906,
                                ],
                                [
                                    0.368403718847324,
                                    0.5783436367240951,
                                    0.020721972055683803,
                                    0.03253067237289724,
                                ],
                                [
                                    0.368403718847324,
                                    0.020721972055683803,
                                    0.5783436367240951,
                                    0.03253067237289724,
                                ],
                                [
                                    0.17411291433885828,
                                    0.0033997861797191915,
                                    0.8067347310984134,
                                    0.01575256838300906,
                                ],
                                [
                                    0.9286149145361898,
                                    0.052232730901081964,
                                    0.018132441035229173,
                                    0.0010199135274990793,
                                ],
                                [
                                    0.9286149145361898,
                                    0.018132441035229173,
                                    0.052232730901081964,
                                    0.0010199135274990793,
                                ],
                                [
                                    0.009177542431632059,
                                    0.2451546959133274,
                                    0.02690731449155613,
                                    0.7187604471634844,
                                ],
                                [
                                    0.009177542431632059,
                                    0.02690731449155613,
                                    0.2451546959133274,
                                    0.7187604471634844,
                                ],
                                [
                                    0.0356331480004049,
                                    0.9518488884742078,
                                    0.0004517089227832882,
                                    0.012066254602603986,
                                ],
                                [
                                    0.25157903588444724,
                                    0.7375957440080729,
                                    0.0027532024605122236,
                                    0.00807201764696767,
                                ],
                                [
                                    0.25157903588444724,
                                    0.0027532024605122236,
                                    0.7375957440080729,
                                    0.00807201764696767,
                                ],
                                [
                                    0.0356331480004049,
                                    0.0004517089227832882,
                                    0.9518488884742078,
                                    0.012066254602603986,
                                ],
                                [
                                    0.9767923260775926,
                                    0.010689710397020172,
                                    0.012382453814927552,
                                    0.00013550971045972221,
                                ],
                                [
                                    0.9767923260775926,
                                    0.012382453814927552,
                                    0.010689710397020172,
                                    0.00013550971045972221,
                                ],
                                [
                                    0.4378008122270933,
                                    0.48089699723695795,
                                    0.03874414925757267,
                                    0.042558041278376084,
                                ],
                                [
                                    0.4378008122270933,
                                    0.03874414925757267,
                                    0.48089699723695795,
                                    0.042558041278376084,
                                ],
                                [
                                    0.4549968689797337,
                                    0.4997857974075057,
                                    0.021548092504932302,
                                    0.023669241107828323,
                                ],
                                [
                                    0.48089699723695795,
                                    0.042558041278376084,
                                    0.4378008122270933,
                                    0.03874414925757267,
                                ],
                                [
                                    0.48089699723695795,
                                    0.4378008122270933,
                                    0.042558041278376084,
                                    0.03874414925757267,
                                ],
                                [
                                    0.4549968689797337,
                                    0.021548092504932302,
                                    0.4997857974075057,
                                    0.023669241107828323,
                                ],
                                [
                                    0.4997857974075057,
                                    0.4549968689797337,
                                    0.023669241107828323,
                                    0.021548092504932302,
                                ],
                                [
                                    0.4997857974075057,
                                    0.023669241107828323,
                                    0.4549968689797337,
                                    0.021548092504932302,
                                ],
                                [
                                    0.30150319878950443,
                                    0.4824011581164985,
                                    0.0831141287369164,
                                    0.13298151435708064,
                                ],
                                [
                                    0.30150319878950443,
                                    0.0831141287369164,
                                    0.4824011581164985,
                                    0.13298151435708064,
                                ],
                                [
                                    0.3697776592649576,
                                    0.5916393981596227,
                                    0.014839668261463268,
                                    0.023743274313956383,
                                ],
                                [
                                    0.4824011581164986,
                                    0.13298151435708067,
                                    0.3015031987895043,
                                    0.08311412873691638,
                                ],
                                [
                                    0.4824011581164986,
                                    0.3015031987895043,
                                    0.13298151435708067,
                                    0.08311412873691638,
                                ],
                                [
                                    0.3697776592649576,
                                    0.014839668261463268,
                                    0.5916393981596227,
                                    0.023743274313956383,
                                ],
                                [
                                    0.5916393981596229,
                                    0.3697776592649575,
                                    0.023743274313956387,
                                    0.014839668261463265,
                                ],
                                [
                                    0.5916393981596229,
                                    0.023743274313956387,
                                    0.3697776592649575,
                                    0.014839668261463265,
                                ],
                                [
                                    0.14662875597612632,
                                    0.4398862679283789,
                                    0.10337124402387368,
                                    0.3101137320716211,
                                ],
                                [
                                    0.14662875597612632,
                                    0.10337124402387368,
                                    0.4398862679283789,
                                    0.3101137320716211,
                                ],
                                [
                                    0.2427830878577315,
                                    0.7283492635731945,
                                    0.007216912142268488,
                                    0.021650736426805463,
                                ],
                                [
                                    0.4398862679283789,
                                    0.3101137320716211,
                                    0.14662875597612632,
                                    0.10337124402387368,
                                ],
                                [
                                    0.4398862679283789,
                                    0.14662875597612632,
                                    0.3101137320716211,
                                    0.10337124402387368,
                                ],
                                [
                                    0.2427830878577315,
                                    0.007216912142268488,
                                    0.7283492635731945,
                                    0.021650736426805463,
                                ],
                                [
                                    0.7283492635731945,
                                    0.2427830878577315,
                                    0.021650736426805463,
                                    0.007216912142268488,
                                ],
                                [
                                    0.7283492635731945,
                                    0.021650736426805463,
                                    0.2427830878577315,
                                    0.007216912142268488,
                                ],
                                [
                                    0.04489836214451698,
                                    0.34422732875849077,
                                    0.07048431032906227,
                                    0.54038999876793,
                                ],
                                [
                                    0.04489836214451698,
                                    0.07048431032906227,
                                    0.34422732875849077,
                                    0.54038999876793,
                                ],
                                [
                                    0.11317282261997012,
                                    0.8676748228173017,
                                    0.002209849853609135,
                                    0.016942504709119118,
                                ],
                                [
                                    0.34422732875849077,
                                    0.54038999876793,
                                    0.04489836214451698,
                                    0.07048431032906227,
                                ],
                                [
                                    0.34422732875849077,
                                    0.04489836214451698,
                                    0.54038999876793,
                                    0.07048431032906227,
                                ],
                                [
                                    0.11317282261997012,
                                    0.002209849853609135,
                                    0.8676748228173017,
                                    0.016942504709119118,
                                ],
                                [
                                    0.8676748228173017,
                                    0.11317282261997012,
                                    0.016942504709119118,
                                    0.002209849853609135,
                                ],
                                [
                                    0.8676748228173017,
                                    0.016942504709119118,
                                    0.11317282261997012,
                                    0.002209849853609135,
                                ],
                                [
                                    0.00596537244607214,
                                    0.2483668658988873,
                                    0.017489666069261896,
                                    0.7281780955857786,
                                ],
                                [
                                    0.00596537244607214,
                                    0.017489666069261896,
                                    0.2483668658988873,
                                    0.7281780955857786,
                                ],
                                [
                                    0.023161429198712533,
                                    0.9643206072759002,
                                    0.0002936093166215051,
                                    0.012224354208765768,
                                ],
                                [
                                    0.2483668658988873,
                                    0.7281780955857786,
                                    0.00596537244607214,
                                    0.017489666069261896,
                                ],
                                [
                                    0.2483668658988873,
                                    0.00596537244607214,
                                    0.7281780955857786,
                                    0.017489666069261896,
                                ],
                                [
                                    0.023161429198712533,
                                    0.0002936093166215051,
                                    0.9643206072759002,
                                    0.012224354208765768,
                                ],
                                [
                                    0.9643206072759002,
                                    0.023161429198712533,
                                    0.012224354208765768,
                                    0.0002936093166215051,
                                ],
                                [
                                    0.9643206072759002,
                                    0.012224354208765768,
                                    0.023161429198712533,
                                    0.0002936093166215051,
                                ],
                                [
                                    0.20205851090346272,
                                    0.7166392985605885,
                                    0.017881613936215908,
                                    0.06342057659973285,
                                ],
                                [
                                    0.20205851090346272,
                                    0.017881613936215908,
                                    0.7166392985605885,
                                    0.06342057659973285,
                                ],
                                [
                                    0.20999501883997065,
                                    0.7447876475472688,
                                    0.009945105999707968,
                                    0.03527222761305266,
                                ],
                                [
                                    0.24515469591332736,
                                    0.021695505957019315,
                                    0.6735431135507238,
                                    0.05960668457892944,
                                ],
                                [
                                    0.24515469591332736,
                                    0.6735431135507238,
                                    0.021695505957019315,
                                    0.05960668457892944,
                                ],
                                [
                                    0.20999501883997065,
                                    0.009945105999707968,
                                    0.7447876475472688,
                                    0.03527222761305266,
                                ],
                                [
                                    0.2547839472677427,
                                    0.6999987191194967,
                                    0.012066254602603986,
                                    0.03315107901015664,
                                ],
                                [
                                    0.2547839472677427,
                                    0.012066254602603986,
                                    0.6999987191194967,
                                    0.03315107901015664,
                                ],
                                [
                                    0.13915297934266338,
                                    0.6447513775633396,
                                    0.0383597211759141,
                                    0.17773592191808293,
                                ],
                                [
                                    0.13915297934266338,
                                    0.0383597211759141,
                                    0.6447513775633396,
                                    0.17773592191808293,
                                ],
                                [
                                    0.17066373818806155,
                                    0.7907533192365188,
                                    0.006848962330515941,
                                    0.03173398024490371,
                                ],
                                [
                                    0.32005093866965756,
                                    0.08822710679607838,
                                    0.46385341823634535,
                                    0.12786853629791867,
                                ],
                                [
                                    0.32005093866965756,
                                    0.46385341823634535,
                                    0.08822710679607838,
                                    0.12786853629791867,
                                ],
                                [
                                    0.17066373818806155,
                                    0.006848962330515941,
                                    0.7907533192365188,
                                    0.03173398024490371,
                                ],
                                [
                                    0.39252547708272695,
                                    0.5688915803418535,
                                    0.015752568383009063,
                                    0.022830374192410588,
                                ],
                                [
                                    0.39252547708272695,
                                    0.015752568383009063,
                                    0.5688915803418535,
                                    0.022830374192410588,
                                ],
                                [
                                    0.06767367090400704,
                                    0.5188413530004983,
                                    0.04770900156957222,
                                    0.36577597452592253,
                                ],
                                [
                                    0.06767367090400704,
                                    0.04770900156957222,
                                    0.5188413530004983,
                                    0.36577597452592253,
                                ],
                                [
                                    0.1120518460336514,
                                    0.8590805053972747,
                                    0.0033308264399278483,
                                    0.0255368221291461,
                                ],
                                [
                                    0.3609311828562597,
                                    0.25445148961731956,
                                    0.2255838410482456,
                                    0.15903348647817514,
                                ],
                                [
                                    0.3609311828562597,
                                    0.2255838410482456,
                                    0.25445148961731956,
                                    0.15903348647817514,
                                ],
                                [
                                    0.1120518460336514,
                                    0.0033308264399278483,
                                    0.8590805053972747,
                                    0.0255368221291461,
                                ],
                                [
                                    0.5976180217491144,
                                    0.3735143296818116,
                                    0.017764650724464825,
                                    0.011102997844609127,
                                ],
                                [
                                    0.5976180217491144,
                                    0.017764650724464825,
                                    0.3735143296818116,
                                    0.011102997844609127,
                                ],
                                [
                                    0.020721972055683796,
                                    0.368403718847324,
                                    0.032530672372897224,
                                    0.5783436367240951,
                                ],
                                [
                                    0.020721972055683796,
                                    0.032530672372897224,
                                    0.368403718847324,
                                    0.5783436367240951,
                                ],
                                [
                                    0.05223273090108194,
                                    0.9286149145361898,
                                    0.001019913527499079,
                                    0.018132441035229173,
                                ],
                                [
                                    0.32005093866965756,
                                    0.5024363608117649,
                                    0.06907475223335015,
                                    0.1084379482852273,
                                ],
                                [
                                    0.32005093866965756,
                                    0.06907475223335015,
                                    0.5024363608117649,
                                    0.1084379482852273,
                                ],
                                [
                                    0.05223273090108194,
                                    0.001019913527499079,
                                    0.9286149145361898,
                                    0.018132441035229173,
                                ],
                                [
                                    0.8067347310984134,
                                    0.17411291433885825,
                                    0.01575256838300906,
                                    0.0033997861797191906,
                                ],
                                [
                                    0.8067347310984134,
                                    0.01575256838300906,
                                    0.17411291433885825,
                                    0.0033997861797191906,
                                ],
                                [
                                    0.002753202460512221,
                                    0.25157903588444724,
                                    0.008072017646967663,
                                    0.7375957440080729,
                                ],
                                [
                                    0.002753202460512221,
                                    0.008072017646967663,
                                    0.25157903588444724,
                                    0.7375957440080729,
                                ],
                                [
                                    0.010689710397020161,
                                    0.9767923260775926,
                                    0.00013550971045972208,
                                    0.012382453814927552,
                                ],
                                [
                                    0.2451546959133274,
                                    0.7187604471634844,
                                    0.009177542431632055,
                                    0.02690731449155612,
                                ],
                                [
                                    0.2451546959133274,
                                    0.009177542431632055,
                                    0.7187604471634844,
                                    0.02690731449155612,
                                ],
                                [
                                    0.010689710397020161,
                                    0.00013550971045972208,
                                    0.9767923260775926,
                                    0.012382453814927552,
                                ],
                                [
                                    0.9518488884742078,
                                    0.03563314800040489,
                                    0.012066254602603986,
                                    0.00045170892278328803,
                                ],
                                [
                                    0.9518488884742078,
                                    0.012066254602603986,
                                    0.03563314800040489,
                                    0.00045170892278328803,
                                ],
                                [
                                    0.04107453965132397,
                                    0.8776232698127272,
                                    0.0036349820523208687,
                                    0.07766720848362789,
                                ],
                                [
                                    0.04107453965132397,
                                    0.0036349820523208687,
                                    0.8776232698127272,
                                    0.07766720848362789,
                                ],
                                [
                                    0.04268787634510417,
                                    0.9120947900421352,
                                    0.0020216453585406705,
                                    0.043195688254219954,
                                ],
                                [
                                    0.08417072466118863,
                                    0.007448874073124278,
                                    0.8345270848028626,
                                    0.07385331646282448,
                                ],
                                [
                                    0.08417072466118863,
                                    0.8345270848028626,
                                    0.007448874073124278,
                                    0.07385331646282448,
                                ],
                                [
                                    0.04268787634510417,
                                    0.0020216453585406705,
                                    0.9120947900421352,
                                    0.043195688254219954,
                                ],
                                [
                                    0.08747680477287623,
                                    0.8673058616143632,
                                    0.004142793961436688,
                                    0.04107453965132394,
                                ],
                                [
                                    0.08747680477287623,
                                    0.004142793961436688,
                                    0.8673058616143632,
                                    0.04107453965132394,
                                ],
                                [
                                    0.028287076560416964,
                                    0.755617280345586,
                                    0.0077977803627712235,
                                    0.2082978627312258,
                                ],
                                [
                                    0.028287076560416964,
                                    0.0077977803627712235,
                                    0.755617280345586,
                                    0.2082978627312258,
                                ],
                                [
                                    0.03469259696067859,
                                    0.9267244604639018,
                                    0.0013922599625096042,
                                    0.037190682612910045,
                                ],
                                [
                                    0.2091850358874112,
                                    0.0576651659829355,
                                    0.5747193210185917,
                                    0.15843047711106154,
                                ],
                                [
                                    0.2091850358874112,
                                    0.5747193210185917,
                                    0.0576651659829355,
                                    0.15843047711106154,
                                ],
                                [
                                    0.03469259696067859,
                                    0.0013922599625096042,
                                    0.9267244604639018,
                                    0.037190682612910045,
                                ],
                                [
                                    0.256554335855344,
                                    0.7048627215692365,
                                    0.010295866015002729,
                                    0.028287076560416922,
                                ],
                                [
                                    0.256554335855344,
                                    0.010295866015002729,
                                    0.7048627215692365,
                                    0.028287076560416922,
                                ],
                                [
                                    0.013756732475502234,
                                    0.572758291429003,
                                    0.009698306039831803,
                                    0.40378667005566293,
                                ],
                                [
                                    0.013756732475502234,
                                    0.009698306039831803,
                                    0.572758291429003,
                                    0.40378667005566293,
                                ],
                                [
                                    0.02277794670629928,
                                    0.9483544047246267,
                                    0.000677091809034757,
                                    0.028190556760039193,
                                ],
                                [
                                    0.3070142444277549,
                                    0.21644079408757916,
                                    0.2795007794767504,
                                    0.19704418200791557,
                                ],
                                [
                                    0.3070142444277549,
                                    0.2795007794767504,
                                    0.21644079408757916,
                                    0.19704418200791557,
                                ],
                                [
                                    0.02277794670629928,
                                    0.000677091809034757,
                                    0.9483544047246267,
                                    0.028190556760039193,
                                ],
                                [
                                    0.5083441224217623,
                                    0.4627882290091637,
                                    0.015110916093571732,
                                    0.013756732475502218,
                                ],
                                [
                                    0.5083441224217623,
                                    0.015110916093571732,
                                    0.4627882290091637,
                                    0.013756732475502218,
                                ],
                                [
                                    0.004212371253500241,
                                    0.3849133196495075,
                                    0.0066128488539796415,
                                    0.6042614602430126,
                                ],
                                [
                                    0.004212371253500241,
                                    0.0066128488539796415,
                                    0.3849133196495075,
                                    0.6042614602430126,
                                ],
                                [
                                    0.010617891653761853,
                                    0.97022975378351,
                                    0.00020732845371802995,
                                    0.01894502610901022,
                                ],
                                [
                                    0.303541337867474,
                                    0.4765185372928474,
                                    0.08558435303553372,
                                    0.1343557718041449,
                                ],
                                [
                                    0.303541337867474,
                                    0.08558435303553372,
                                    0.4765185372928474,
                                    0.1343557718041449,
                                ],
                                [
                                    0.010617891653761853,
                                    0.00020732845371802995,
                                    0.97022975378351,
                                    0.01894502610901022,
                                ],
                                [
                                    0.7651198918510934,
                                    0.21572775358617838,
                                    0.014939983309228012,
                                    0.00421237125350024,
                                ],
                                [
                                    0.7651198918510934,
                                    0.014939983309228012,
                                    0.21572775358617838,
                                    0.00421237125350024,
                                ],
                                [
                                    0.0005596721619237435,
                                    0.2537725661830357,
                                    0.0016408831650994913,
                                    0.7440268784899411,
                                ],
                                [
                                    0.0005596721619237435,
                                    0.0016408831650994913,
                                    0.2537725661830357,
                                    0.7440268784899411,
                                ],
                                [
                                    0.0021730088557039614,
                                    0.9853090276189088,
                                    2.7546471319273517e-05,
                                    0.012490417054068,
                                ],
                                [
                                    0.2429611656147389,
                                    0.7123293126816163,
                                    0.011371072730220541,
                                    0.03333844897342432,
                                ],
                                [
                                    0.2429611656147389,
                                    0.011371072730220541,
                                    0.7123293126816163,
                                    0.03333844897342432,
                                ],
                                [
                                    0.0021730088557039614,
                                    2.7546471319273517e-05,
                                    0.9853090276189088,
                                    0.012490417054068,
                                ],
                                [
                                    0.9433321869328917,
                                    0.044149849541721124,
                                    0.011958291363463536,
                                    0.000559672161923737,
                                ],
                                [
                                    0.9433321869328917,
                                    0.011958291363463536,
                                    0.044149849541721124,
                                    0.000559672161923737,
                                ],
                                [
                                    0.6735431135507239,
                                    0.06793381903417782,
                                    0.23483728771496323,
                                    0.023685779700135003,
                                ],
                                [
                                    0.6735431135507239,
                                    0.23483728771496323,
                                    0.06793381903417782,
                                    0.023685779700135003,
                                ],
                                [
                                    0.7063218903622246,
                                    0.07123989914586541,
                                    0.20205851090346266,
                                    0.020379699588447413,
                                ],
                                [
                                    0.7083258535747451,
                                    0.24696462472161004,
                                    0.033151079010156646,
                                    0.011558442693488165,
                                ],
                                [
                                    0.7083258535747451,
                                    0.033151079010156646,
                                    0.24696462472161004,
                                    0.011558442693488165,
                                ],
                                [
                                    0.7063218903622246,
                                    0.20205851090346266,
                                    0.07123989914586541,
                                    0.020379699588447413,
                                ],
                                [
                                    0.7427973738041531,
                                    0.034764415703936846,
                                    0.2124931044922021,
                                    0.009945105999707967,
                                ],
                                [
                                    0.7427973738041531,
                                    0.2124931044922021,
                                    0.034764415703936846,
                                    0.009945105999707967,
                                ],
                                [
                                    0.46385341823634546,
                                    0.16883231586558986,
                                    0.26929637989330796,
                                    0.09801788600475674,
                                ],
                                [
                                    0.46385341823634546,
                                    0.26929637989330796,
                                    0.16883231586558986,
                                    0.09801788600475674,
                                ],
                                [
                                    0.5939968187869901,
                                    0.2162016158335226,
                                    0.13915297934266332,
                                    0.05064858603682397,
                                ],
                                [
                                    0.6098553599095247,
                                    0.35405978316728715,
                                    0.022830374192410588,
                                    0.013254482730777548,
                                ],
                                [
                                    0.6098553599095247,
                                    0.022830374192410588,
                                    0.35405978316728715,
                                    0.013254482730777548,
                                ],
                                [
                                    0.5939968187869901,
                                    0.13915297934266332,
                                    0.2162016158335226,
                                    0.05064858603682397,
                                ],
                                [
                                    0.7809625400278404,
                                    0.029235894592672198,
                                    0.18295260304897135,
                                    0.0068489623305159385,
                                ],
                                [
                                    0.7809625400278404,
                                    0.18295260304897135,
                                    0.029235894592672198,
                                    0.0068489623305159385,
                                ],
                                [
                                    0.2255838410482456,
                                    0.24778983673746388,
                                    0.2509611204364204,
                                    0.27566520177787013,
                                ],
                                [
                                    0.2255838410482456,
                                    0.2509611204364204,
                                    0.24778983673746388,
                                    0.27566520177787013,
                                ],
                                [
                                    0.4088712905806589,
                                    0.44911971473147133,
                                    0.06767367090400701,
                                    0.07433532378386272,
                                ],
                                [
                                    0.4622706799411003,
                                    0.5142742815435656,
                                    0.011102997844609127,
                                    0.012352040670724882,
                                ],
                                [
                                    0.4622706799411003,
                                    0.011102997844609127,
                                    0.5142742815435656,
                                    0.012352040670724882,
                                ],
                                [
                                    0.4088712905806589,
                                    0.06767367090400701,
                                    0.44911971473147133,
                                    0.07433532378386272,
                                ],
                                [
                                    0.8378667932367241,
                                    0.02012421207540616,
                                    0.13867816824794188,
                                    0.0033308264399278475,
                                ],
                                [
                                    0.8378667932367241,
                                    0.13867816824794188,
                                    0.02012421207540616,
                                    0.0033308264399278475,
                                ],
                                [
                                    0.06907475223335016,
                                    0.24498686923613364,
                                    0.15086537260632846,
                                    0.5350730059241877,
                                ],
                                [
                                    0.06907475223335016,
                                    0.15086537260632846,
                                    0.24498686923613364,
                                    0.5350730059241877,
                                ],
                                [
                                    0.19921815278399482,
                                    0.706565423219753,
                                    0.0207219720556838,
                                    0.0734944519405684,
                                ],
                                [
                                    0.3106618352897646,
                                    0.6785129446027555,
                                    0.0033997861797191915,
                                    0.007425433927760691,
                                ],
                                [
                                    0.3106618352897646,
                                    0.0033997861797191915,
                                    0.6785129446027555,
                                    0.007425433927760691,
                                ],
                                [
                                    0.19921815278399482,
                                    0.0207219720556838,
                                    0.706565423219753,
                                    0.0734944519405684,
                                ],
                                [
                                    0.895978269423767,
                                    0.009805306579980803,
                                    0.09319651046875312,
                                    0.0010199135274990795,
                                ],
                                [
                                    0.895978269423767,
                                    0.09319651046875312,
                                    0.009805306579980803,
                                    0.0010199135274990795,
                                ],
                                [
                                    0.009177542431632053,
                                    0.19609288055488527,
                                    0.035531979272012786,
                                    0.7591975977414699,
                                ],
                                [
                                    0.009177542431632053,
                                    0.035531979272012786,
                                    0.19609288055488527,
                                    0.7591975977414699,
                                ],
                                [
                                    0.04195631924313262,
                                    0.896463901873038,
                                    0.002753202460512222,
                                    0.0588265764233172,
                                ],
                                [
                                    0.20481871406373403,
                                    0.7929807306092428,
                                    0.0004517089227832882,
                                    0.0017488464042399213,
                                ],
                                [
                                    0.20481871406373403,
                                    0.0004517089227832882,
                                    0.7929807306092428,
                                    0.0017488464042399213,
                                ],
                                [
                                    0.04195631924313262,
                                    0.002753202460512222,
                                    0.896463901873038,
                                    0.0588265764233172,
                                ],
                                [
                                    0.9363551754996071,
                                    0.0020650456165634875,
                                    0.061444269173369696,
                                    0.0001355097104597222,
                                ],
                                [
                                    0.9363551754996071,
                                    0.061444269173369696,
                                    0.0020650456165634875,
                                    0.0001355097104597222,
                                ],
                                [
                                    0.5436136634424154,
                                    0.1978632691424864,
                                    0.18953613468723804,
                                    0.06898693272786018,
                                ],
                                [
                                    0.5436136634424154,
                                    0.18953613468723804,
                                    0.1978632691424864,
                                    0.06898693272786018,
                                ],
                                [
                                    0.5700692690111883,
                                    0.20749252049690176,
                                    0.1630805291184652,
                                    0.05935768137344485,
                                ],
                                [
                                    0.5783964034664365,
                                    0.20166347169388488,
                                    0.1630805291184652,
                                    0.056859595721213345,
                                ],
                                [
                                    0.5783964034664365,
                                    0.1630805291184652,
                                    0.20166347169388488,
                                    0.056859595721213345,
                                ],
                                [
                                    0.5700692690111883,
                                    0.1630805291184652,
                                    0.20749252049690176,
                                    0.05935768137344485,
                                ],
                                [
                                    0.6065447524531168,
                                    0.17101703705497318,
                                    0.17351512270720465,
                                    0.048923087784705395,
                                ],
                                [
                                    0.6065447524531168,
                                    0.17351512270720465,
                                    0.17101703705497318,
                                    0.048923087784705395,
                                ],
                                [
                                    0.3743740391887429,
                                    0.2583116949131924,
                                    0.21734791534552125,
                                    0.14996635055254345,
                                ],
                                [
                                    0.3743740391887429,
                                    0.21734791534552125,
                                    0.2583116949131924,
                                    0.14996635055254345,
                                ],
                                [
                                    0.47941220129425094,
                                    0.3307862333262617,
                                    0.11230975324001315,
                                    0.07749181213947416,
                                ],
                                [
                                    0.5203759808619222,
                                    0.30211131861950047,
                                    0.11230975324001313,
                                    0.06520294727856427,
                                ],
                                [
                                    0.5203759808619222,
                                    0.11230975324001313,
                                    0.30211131861950047,
                                    0.06520294727856427,
                                ],
                                [
                                    0.47941220129425094,
                                    0.11230975324001315,
                                    0.3307862333262617,
                                    0.07749181213947416,
                                ],
                                [
                                    0.6663779225351014,
                                    0.14382051208541127,
                                    0.15610937694632118,
                                    0.03369218843316612,
                                ],
                                [
                                    0.6663779225351014,
                                    0.15610937694632118,
                                    0.14382051208541127,
                                    0.03369218843316612,
                                ],
                                [
                                    0.18206771887129258,
                                    0.2913059589144169,
                                    0.20254960865512817,
                                    0.32407671355916234,
                                ],
                                [
                                    0.18206771887129258,
                                    0.20254960865512817,
                                    0.2913059589144169,
                                    0.32407671355916234,
                                ],
                                [
                                    0.3299982075048586,
                                    0.5279927978072716,
                                    0.054619120021562134,
                                    0.0873898746663076,
                                ],
                                [
                                    0.41875455776414733,
                                    0.4658627697622734,
                                    0.05461912002156214,
                                    0.06076355245201708,
                                ],
                                [
                                    0.41875455776414733,
                                    0.05461912002156214,
                                    0.4658627697622734,
                                    0.06076355245201708,
                                ],
                                [
                                    0.3299982075048586,
                                    0.054619120021562134,
                                    0.5279927978072716,
                                    0.0873898746663076,
                                ],
                                [
                                    0.7589937101609238,
                                    0.09899729515120649,
                                    0.12562361736549701,
                                    0.016385377322372725,
                                ],
                                [
                                    0.7589937101609238,
                                    0.12562361736549701,
                                    0.09899729515120649,
                                    0.016385377322372725,
                                ],
                                [
                                    0.055749926556291324,
                                    0.2583116949131925,
                                    0.12176277396228616,
                                    0.56417560456823,
                                ],
                                [
                                    0.055749926556291324,
                                    0.12176277396228616,
                                    0.2583116949131925,
                                    0.56417560456823,
                                ],
                                [
                                    0.16078808866179944,
                                    0.7449954873419483,
                                    0.016724611856778034,
                                    0.07749181213947416,
                                ],
                                [
                                    0.29733700961270576,
                                    0.6494103459587132,
                                    0.016724611856778034,
                                    0.03652803257180301,
                                ],
                                [
                                    0.29733700961270576,
                                    0.016724611856778034,
                                    0.6494103459587132,
                                    0.03652803257180301,
                                ],
                                [
                                    0.16078808866179944,
                                    0.016724611856778034,
                                    0.7449954873419483,
                                    0.07749181213947416,
                                ],
                                [
                                    0.8575482053015716,
                                    0.04823537070217619,
                                    0.08919915026984736,
                                    0.005017273726404849,
                                ],
                                [
                                    0.8575482053015716,
                                    0.08919915026984736,
                                    0.04823537070217619,
                                    0.005017273726404849,
                                ],
                                [
                                    0.007407153844030798,
                                    0.19786326914248653,
                                    0.028677703079157395,
                                    0.7660518739343253,
                                ],
                                [
                                    0.007407153844030798,
                                    0.028677703079157395,
                                    0.19786326914248653,
                                    0.7660518739343253,
                                ],
                                [
                                    0.033862759412803645,
                                    0.904557461703367,
                                    0.00222209751038455,
                                    0.05935768137344487,
                                ],
                                [
                                    0.20304832547613277,
                                    0.7861264544163874,
                                    0.0022220975103845503,
                                    0.008603122597095343,
                                ],
                                [
                                    0.20304832547613277,
                                    0.0022220975103845503,
                                    0.7861264544163874,
                                    0.008603122597095343,
                                ],
                                [
                                    0.033862759412803645,
                                    0.00222209751038455,
                                    0.904557461703367,
                                    0.05935768137344487,
                                ],
                                [
                                    0.9282616156692781,
                                    0.010158605446892498,
                                    0.06091316422324203,
                                    0.0006666146605873959,
                                ],
                                [
                                    0.9282616156692781,
                                    0.06091316422324203,
                                    0.010158605446892498,
                                    0.0006666146605873959,
                                ],
                                [
                                    0.35334709628044025,
                                    0.3881298363044615,
                                    0.12319786520422568,
                                    0.13532520221087255,
                                ],
                                [
                                    0.35334709628044025,
                                    0.12319786520422568,
                                    0.3881298363044615,
                                    0.13532520221087255,
                                ],
                                [
                                    0.37054315303308066,
                                    0.4070186364750093,
                                    0.1060018084515853,
                                    0.11643640204032477,
                                ],
                                [
                                    0.3881298363044615,
                                    0.13532520221087255,
                                    0.35334709628044025,
                                    0.12319786520422568,
                                ],
                                [
                                    0.3881298363044615,
                                    0.35334709628044025,
                                    0.13532520221087255,
                                    0.12319786520422568,
                                ],
                                [
                                    0.37054315303308066,
                                    0.1060018084515853,
                                    0.4070186364750093,
                                    0.11643640204032477,
                                ],
                                [
                                    0.4070186364750093,
                                    0.37054315303308066,
                                    0.11643640204032477,
                                    0.1060018084515853,
                                ],
                                [
                                    0.4070186364750093,
                                    0.11643640204032477,
                                    0.37054315303308066,
                                    0.1060018084515853,
                                ],
                                [
                                    0.24334189621437807,
                                    0.3893438378875572,
                                    0.1412754313120428,
                                    0.22603883458602192,
                                ],
                                [
                                    0.24334189621437807,
                                    0.1412754313120428,
                                    0.3893438378875572,
                                    0.22603883458602192,
                                ],
                                [
                                    0.3116163566898312,
                                    0.4985820779306815,
                                    0.07300097083658966,
                                    0.11680059454289765,
                                ],
                                [
                                    0.3893438378875573,
                                    0.22603883458602195,
                                    0.243341896214378,
                                    0.14127543131204276,
                                ],
                                [
                                    0.3893438378875573,
                                    0.243341896214378,
                                    0.22603883458602195,
                                    0.14127543131204276,
                                ],
                                [
                                    0.3116163566898312,
                                    0.07300097083658966,
                                    0.4985820779306815,
                                    0.11680059454289765,
                                ],
                                [
                                    0.49858207793068154,
                                    0.3116163566898311,
                                    0.11680059454289768,
                                    0.07300097083658963,
                                ],
                                [
                                    0.49858207793068154,
                                    0.11680059454289768,
                                    0.3116163566898311,
                                    0.07300097083658963,
                                ],
                                [
                                    0.11834341944642737,
                                    0.35503025833928215,
                                    0.13165658055357263,
                                    0.39496974166071785,
                                ],
                                [
                                    0.11834341944642737,
                                    0.13165658055357263,
                                    0.35503025833928215,
                                    0.39496974166071785,
                                ],
                                [
                                    0.21449775132803256,
                                    0.6434932539840976,
                                    0.03550224867196743,
                                    0.10650674601590229,
                                ],
                                [
                                    0.35503025833928215,
                                    0.39496974166071785,
                                    0.11834341944642737,
                                    0.13165658055357263,
                                ],
                                [
                                    0.35503025833928215,
                                    0.11834341944642737,
                                    0.39496974166071785,
                                    0.13165658055357263,
                                ],
                                [
                                    0.21449775132803256,
                                    0.03550224867196743,
                                    0.6434932539840976,
                                    0.10650674601590229,
                                ],
                                [
                                    0.6434932539840976,
                                    0.21449775132803256,
                                    0.10650674601590229,
                                    0.03550224867196743,
                                ],
                                [
                                    0.6434932539840976,
                                    0.10650674601590229,
                                    0.21449775132803256,
                                    0.03550224867196743,
                                ],
                                [
                                    0.036237269206534674,
                                    0.2778243522629491,
                                    0.07914540326704457,
                                    0.6067929752634716,
                                ],
                                [
                                    0.036237269206534674,
                                    0.07914540326704457,
                                    0.2778243522629491,
                                    0.6067929752634716,
                                ],
                                [
                                    0.10451172968198781,
                                    0.80127184632176,
                                    0.01087094279159144,
                                    0.08334548120466076,
                                ],
                                [
                                    0.2778243522629491,
                                    0.6067929752634716,
                                    0.036237269206534674,
                                    0.07914540326704457,
                                ],
                                [
                                    0.2778243522629491,
                                    0.036237269206534674,
                                    0.6067929752634716,
                                    0.07914540326704457,
                                ],
                                [
                                    0.10451172968198781,
                                    0.01087094279159144,
                                    0.80127184632176,
                                    0.08334548120466076,
                                ],
                                [
                                    0.80127184632176,
                                    0.10451172968198781,
                                    0.08334548120466076,
                                    0.01087094279159144,
                                ],
                                [
                                    0.80127184632176,
                                    0.08334548120466076,
                                    0.10451172968198781,
                                    0.01087094279159144,
                                ],
                                [
                                    0.004814625677207673,
                                    0.20045579730930965,
                                    0.018640412838126365,
                                    0.7760891641753563,
                                ],
                                [
                                    0.004814625677207673,
                                    0.018640412838126365,
                                    0.20045579730930965,
                                    0.7760891641753563,
                                ],
                                [
                                    0.022010682429848064,
                                    0.9164095386863226,
                                    0.0014443560854859726,
                                    0.06013542279834345,
                                ],
                                [
                                    0.20045579730930965,
                                    0.7760891641753563,
                                    0.004814625677207673,
                                    0.018640412838126365,
                                ],
                                [
                                    0.20045579730930965,
                                    0.004814625677207673,
                                    0.7760891641753563,
                                    0.018640412838126365,
                                ],
                                [
                                    0.022010682429848064,
                                    0.0014443560854859726,
                                    0.9164095386863226,
                                    0.06013542279834345,
                                ],
                                [
                                    0.9164095386863226,
                                    0.022010682429848064,
                                    0.06013542279834345,
                                    0.0014443560854859726,
                                ],
                                [
                                    0.9164095386863226,
                                    0.06013542279834345,
                                    0.022010682429848064,
                                    0.0014443560854859726,
                                ],
                                [
                                    0.16308052911846527,
                                    0.5783964034664365,
                                    0.05685959572121336,
                                    0.20166347169388488,
                                ],
                                [
                                    0.16308052911846527,
                                    0.05685959572121336,
                                    0.5783964034664365,
                                    0.20166347169388488,
                                ],
                                [
                                    0.1710170370549732,
                                    0.6065447524531168,
                                    0.04892308778470541,
                                    0.17351512270720465,
                                ],
                                [
                                    0.19786326914248648,
                                    0.0689869327278602,
                                    0.5436136634424152,
                                    0.189536134687238,
                                ],
                                [
                                    0.19786326914248648,
                                    0.5436136634424152,
                                    0.0689869327278602,
                                    0.189536134687238,
                                ],
                                [
                                    0.1710170370549732,
                                    0.04892308778470541,
                                    0.6065447524531168,
                                    0.17351512270720465,
                                ],
                                [
                                    0.20749252049690184,
                                    0.5700692690111882,
                                    0.05935768137344487,
                                    0.16308052911846518,
                                ],
                                [
                                    0.20749252049690184,
                                    0.05935768137344487,
                                    0.5700692690111882,
                                    0.16308052911846518,
                                ],
                                [
                                    0.11230975324001319,
                                    0.5203759808619222,
                                    0.0652029472785643,
                                    0.3021113186195004,
                                ],
                                [
                                    0.11230975324001319,
                                    0.0652029472785643,
                                    0.5203759808619222,
                                    0.3021113186195004,
                                ],
                                [
                                    0.14382051208541136,
                                    0.6663779225351013,
                                    0.03369218843316613,
                                    0.15610937694632118,
                                ],
                                [
                                    0.2583116949131925,
                                    0.1499663505525435,
                                    0.3743740391887428,
                                    0.2173479153455212,
                                ],
                                [
                                    0.2583116949131925,
                                    0.3743740391887428,
                                    0.1499663505525435,
                                    0.2173479153455212,
                                ],
                                [
                                    0.14382051208541136,
                                    0.03369218843316613,
                                    0.6663779225351013,
                                    0.15610937694632118,
                                ],
                                [
                                    0.3307862333262618,
                                    0.4794122012942509,
                                    0.07749181213947418,
                                    0.11230975324001313,
                                ],
                                [
                                    0.3307862333262618,
                                    0.07749181213947418,
                                    0.4794122012942509,
                                    0.11230975324001313,
                                ],
                                [
                                    0.054619120021562155,
                                    0.41875455776414733,
                                    0.060763552452017096,
                                    0.4658627697622734,
                                ],
                                [
                                    0.054619120021562155,
                                    0.060763552452017096,
                                    0.41875455776414733,
                                    0.4658627697622734,
                                ],
                                [
                                    0.09899729515120652,
                                    0.7589937101609238,
                                    0.01638537732237273,
                                    0.12562361736549701,
                                ],
                                [
                                    0.2913059589144169,
                                    0.32407671355916234,
                                    0.18206771887129258,
                                    0.20254960865512817,
                                ],
                                [
                                    0.2913059589144169,
                                    0.18206771887129258,
                                    0.32407671355916234,
                                    0.20254960865512817,
                                ],
                                [
                                    0.09899729515120652,
                                    0.01638537732237273,
                                    0.7589937101609238,
                                    0.12562361736549701,
                                ],
                                [
                                    0.5279927978072716,
                                    0.3299982075048586,
                                    0.0873898746663076,
                                    0.054619120021562134,
                                ],
                                [
                                    0.5279927978072716,
                                    0.0873898746663076,
                                    0.3299982075048586,
                                    0.054619120021562134,
                                ],
                                [
                                    0.016724611856778027,
                                    0.29733700961270576,
                                    0.03652803257180299,
                                    0.6494103459587132,
                                ],
                                [
                                    0.016724611856778027,
                                    0.03652803257180299,
                                    0.29733700961270576,
                                    0.6494103459587132,
                                ],
                                [
                                    0.04823537070217617,
                                    0.8575482053015716,
                                    0.005017273726404847,
                                    0.08919915026984736,
                                ],
                                [
                                    0.2583116949131925,
                                    0.56417560456823,
                                    0.05574992655629131,
                                    0.12176277396228614,
                                ],
                                [
                                    0.2583116949131925,
                                    0.05574992655629131,
                                    0.56417560456823,
                                    0.12176277396228614,
                                ],
                                [
                                    0.04823537070217617,
                                    0.005017273726404847,
                                    0.8575482053015716,
                                    0.08919915026984736,
                                ],
                                [
                                    0.7449954873419483,
                                    0.16078808866179942,
                                    0.07749181213947416,
                                    0.01672461185677803,
                                ],
                                [
                                    0.7449954873419483,
                                    0.07749181213947416,
                                    0.16078808866179942,
                                    0.01672461185677803,
                                ],
                                [
                                    0.002222097510384548,
                                    0.20304832547613277,
                                    0.008603122597095334,
                                    0.7861264544163874,
                                ],
                                [
                                    0.002222097510384548,
                                    0.008603122597095334,
                                    0.20304832547613277,
                                    0.7861264544163874,
                                ],
                                [
                                    0.010158605446892488,
                                    0.9282616156692781,
                                    0.0006666146605873954,
                                    0.06091316422324203,
                                ],
                                [
                                    0.19786326914248653,
                                    0.7660518739343253,
                                    0.007407153844030795,
                                    0.02867770307915738,
                                ],
                                [
                                    0.19786326914248653,
                                    0.007407153844030795,
                                    0.7660518739343253,
                                    0.02867770307915738,
                                ],
                                [
                                    0.010158605446892488,
                                    0.0006666146605873954,
                                    0.9282616156692781,
                                    0.06091316422324203,
                                ],
                                [
                                    0.904557461703367,
                                    0.03386275941280363,
                                    0.05935768137344487,
                                    0.002222097510384549,
                                ],
                                [
                                    0.904557461703367,
                                    0.05935768137344487,
                                    0.03386275941280363,
                                    0.002222097510384549,
                                ],
                                [
                                    0.03315107901015667,
                                    0.7083258535747451,
                                    0.011558442693488172,
                                    0.24696462472161004,
                                ],
                                [
                                    0.03315107901015667,
                                    0.011558442693488172,
                                    0.7083258535747451,
                                    0.24696462472161004,
                                ],
                                [
                                    0.03476441570393687,
                                    0.7427973738041531,
                                    0.009945105999707972,
                                    0.2124931044922021,
                                ],
                                [
                                    0.06793381903417789,
                                    0.023685779700135027,
                                    0.6735431135507239,
                                    0.2348372877149632,
                                ],
                                [
                                    0.06793381903417789,
                                    0.6735431135507239,
                                    0.023685779700135027,
                                    0.2348372877149632,
                                ],
                                [
                                    0.03476441570393687,
                                    0.009945105999707972,
                                    0.7427973738041531,
                                    0.2124931044922021,
                                ],
                                [
                                    0.07123989914586548,
                                    0.7063218903622245,
                                    0.020379699588447434,
                                    0.20205851090346263,
                                ],
                                [
                                    0.07123989914586548,
                                    0.020379699588447434,
                                    0.7063218903622245,
                                    0.20205851090346263,
                                ],
                                [
                                    0.022830374192410623,
                                    0.6098553599095247,
                                    0.013254482730777568,
                                    0.35405978316728715,
                                ],
                                [
                                    0.022830374192410623,
                                    0.013254482730777568,
                                    0.6098553599095247,
                                    0.35405978316728715,
                                ],
                                [
                                    0.029235894592672243,
                                    0.7809625400278404,
                                    0.006848962330515949,
                                    0.18295260304897135,
                                ],
                                [
                                    0.16883231586558992,
                                    0.09801788600475676,
                                    0.46385341823634535,
                                    0.26929637989330796,
                                ],
                                [
                                    0.16883231586558992,
                                    0.46385341823634535,
                                    0.09801788600475676,
                                    0.26929637989330796,
                                ],
                                [
                                    0.029235894592672243,
                                    0.006848962330515949,
                                    0.7809625400278404,
                                    0.18295260304897135,
                                ],
                                [
                                    0.21620161583352268,
                                    0.59399681878699,
                                    0.05064858603682399,
                                    0.13915297934266332,
                                ],
                                [
                                    0.21620161583352268,
                                    0.05064858603682399,
                                    0.59399681878699,
                                    0.13915297934266332,
                                ],
                                [
                                    0.01110299784460914,
                                    0.4622706799411003,
                                    0.012352040670724897,
                                    0.5142742815435656,
                                ],
                                [
                                    0.01110299784460914,
                                    0.012352040670724897,
                                    0.4622706799411003,
                                    0.5142742815435656,
                                ],
                                [
                                    0.020124212075406184,
                                    0.8378667932367241,
                                    0.0033308264399278514,
                                    0.13867816824794188,
                                ],
                                [
                                    0.24778983673746388,
                                    0.27566520177787013,
                                    0.2255838410482456,
                                    0.2509611204364204,
                                ],
                                [
                                    0.24778983673746388,
                                    0.2255838410482456,
                                    0.27566520177787013,
                                    0.2509611204364204,
                                ],
                                [
                                    0.020124212075406184,
                                    0.0033308264399278514,
                                    0.8378667932367241,
                                    0.13867816824794188,
                                ],
                                [
                                    0.44911971473147133,
                                    0.4088712905806589,
                                    0.07433532378386272,
                                    0.06767367090400701,
                                ],
                                [
                                    0.44911971473147133,
                                    0.07433532378386272,
                                    0.4088712905806589,
                                    0.06767367090400701,
                                ],
                                [
                                    0.0033997861797191915,
                                    0.3106618352897646,
                                    0.007425433927760691,
                                    0.6785129446027555,
                                ],
                                [
                                    0.0033997861797191915,
                                    0.007425433927760691,
                                    0.3106618352897646,
                                    0.6785129446027555,
                                ],
                                [
                                    0.009805306579980803,
                                    0.895978269423767,
                                    0.0010199135274990795,
                                    0.09319651046875312,
                                ],
                                [
                                    0.24498686923613364,
                                    0.5350730059241877,
                                    0.06907475223335016,
                                    0.15086537260632846,
                                ],
                                [
                                    0.24498686923613364,
                                    0.06907475223335016,
                                    0.5350730059241877,
                                    0.15086537260632846,
                                ],
                                [
                                    0.009805306579980803,
                                    0.0010199135274990795,
                                    0.895978269423767,
                                    0.09319651046875312,
                                ],
                                [
                                    0.706565423219753,
                                    0.19921815278399482,
                                    0.0734944519405684,
                                    0.0207219720556838,
                                ],
                                [
                                    0.706565423219753,
                                    0.0734944519405684,
                                    0.19921815278399482,
                                    0.0207219720556838,
                                ],
                                [
                                    0.00045170892278329335,
                                    0.20481871406373403,
                                    0.0017488464042399415,
                                    0.7929807306092428,
                                ],
                                [
                                    0.00045170892278329335,
                                    0.0017488464042399415,
                                    0.20481871406373403,
                                    0.7929807306092428,
                                ],
                                [
                                    0.002065045616563511,
                                    0.9363551754996071,
                                    0.00013550971045972373,
                                    0.061444269173369696,
                                ],
                                [
                                    0.19609288055488527,
                                    0.7591975977414699,
                                    0.009177542431632057,
                                    0.0355319792720128,
                                ],
                                [
                                    0.19609288055488527,
                                    0.009177542431632057,
                                    0.7591975977414699,
                                    0.0355319792720128,
                                ],
                                [
                                    0.002065045616563511,
                                    0.00013550971045972373,
                                    0.9363551754996071,
                                    0.061444269173369696,
                                ],
                                [
                                    0.896463901873038,
                                    0.04195631924313264,
                                    0.0588265764233172,
                                    0.002753202460512223,
                                ],
                                [
                                    0.896463901873038,
                                    0.0588265764233172,
                                    0.04195631924313264,
                                    0.002753202460512223,
                                ],
                                [
                                    0.4378008122270933,
                                    0.04415675931131262,
                                    0.4705795890385939,
                                    0.04746283942300021,
                                ],
                                [
                                    0.4378008122270933,
                                    0.4705795890385939,
                                    0.04415675931131262,
                                    0.04746283942300021,
                                ],
                                [
                                    0.4705795890385939,
                                    0.04746283942300021,
                                    0.4378008122270933,
                                    0.04415675931131262,
                                ],
                                [
                                    0.46040947903347357,
                                    0.4948809992628816,
                                    0.021548092504932306,
                                    0.023161429198712506,
                                ],
                                [
                                    0.46040947903347357,
                                    0.021548092504932306,
                                    0.4948809992628816,
                                    0.023161429198712506,
                                ],
                                [
                                    0.4705795890385939,
                                    0.4378008122270933,
                                    0.04746283942300021,
                                    0.04415675931131262,
                                ],
                                [
                                    0.4948809992628816,
                                    0.023161429198712506,
                                    0.46040947903347357,
                                    0.021548092504932306,
                                ],
                                [
                                    0.4948809992628816,
                                    0.46040947903347357,
                                    0.023161429198712506,
                                    0.021548092504932306,
                                ],
                                [
                                    0.3015031987895044,
                                    0.10974045095120691,
                                    0.43164659934014904,
                                    0.15710975091913967,
                                ],
                                [
                                    0.3015031987895044,
                                    0.43164659934014904,
                                    0.10974045095120691,
                                    0.15710975091913967,
                                ],
                                [
                                    0.43164659934014904,
                                    0.15710975091913967,
                                    0.3015031987895044,
                                    0.10974045095120692,
                                ],
                                [
                                    0.396403981479248,
                                    0.5675111615975639,
                                    0.014839668261463261,
                                    0.021245188661724874,
                                ],
                                [
                                    0.396403981479248,
                                    0.014839668261463261,
                                    0.5675111615975639,
                                    0.021245188661724874,
                                ],
                                [
                                    0.43164659934014904,
                                    0.3015031987895044,
                                    0.15710975091913967,
                                    0.10974045095120692,
                                ],
                                [
                                    0.5675111615975639,
                                    0.021245188661724874,
                                    0.39640398147924805,
                                    0.014839668261463263,
                                ],
                                [
                                    0.5675111615975639,
                                    0.39640398147924805,
                                    0.021245188661724874,
                                    0.014839668261463263,
                                ],
                                [
                                    0.14662875597612635,
                                    0.16106258026066333,
                                    0.3299162055085396,
                                    0.3623924582546707,
                                ],
                                [
                                    0.14662875597612635,
                                    0.3299162055085396,
                                    0.16106258026066333,
                                    0.3623924582546707,
                                ],
                                [
                                    0.3299162055085396,
                                    0.3623924582546707,
                                    0.14662875597612632,
                                    0.1610625802606633,
                                ],
                                [
                                    0.3004744240945212,
                                    0.6760705373901448,
                                    0.0072169121422684885,
                                    0.01623812637306552,
                                ],
                                [
                                    0.3004744240945212,
                                    0.0072169121422684885,
                                    0.6760705373901448,
                                    0.01623812637306552,
                                ],
                                [
                                    0.3299162055085396,
                                    0.14662875597612632,
                                    0.3623924582546707,
                                    0.1610625802606633,
                                ],
                                [
                                    0.6760705373901448,
                                    0.01623812637306552,
                                    0.30047442409452113,
                                    0.007216912142268488,
                                ],
                                [
                                    0.6760705373901448,
                                    0.30047442409452113,
                                    0.01623812637306552,
                                    0.007216912142268488,
                                ],
                                [
                                    0.04489836214451698,
                                    0.159240660588351,
                                    0.17504176269516164,
                                    0.6208192145719703,
                                ],
                                [
                                    0.04489836214451698,
                                    0.17504176269516164,
                                    0.159240660588351,
                                    0.6208192145719703,
                                ],
                                [
                                    0.17504176269516164,
                                    0.6208192145719703,
                                    0.04489836214451698,
                                    0.159240660588351,
                                ],
                                [
                                    0.20192917287925885,
                                    0.7872456070132613,
                                    0.0022098498536091355,
                                    0.008615370253870748,
                                ],
                                [
                                    0.20192917287925885,
                                    0.0022098498536091355,
                                    0.7872456070132613,
                                    0.008615370253870748,
                                ],
                                [
                                    0.17504176269516164,
                                    0.04489836214451698,
                                    0.6208192145719703,
                                    0.159240660588351,
                                ],
                                [
                                    0.7872456070132613,
                                    0.008615370253870748,
                                    0.20192917287925885,
                                    0.0022098498536091355,
                                ],
                                [
                                    0.7872456070132613,
                                    0.20192917287925885,
                                    0.008615370253870748,
                                    0.0022098498536091355,
                                ],
                                [
                                    0.005965372446072136,
                                    0.1274597284891012,
                                    0.038744149257572705,
                                    0.8278307498072539,
                                ],
                                [
                                    0.005965372446072136,
                                    0.038744149257572705,
                                    0.1274597284891012,
                                    0.8278307498072539,
                                ],
                                [
                                    0.038744149257572705,
                                    0.8278307498072539,
                                    0.005965372446072136,
                                    0.1274597284891012,
                                ],
                                [
                                    0.13313149161855184,
                                    0.8646679530544249,
                                    0.0002936093166215051,
                                    0.0019069460104017045,
                                ],
                                [
                                    0.13313149161855184,
                                    0.0002936093166215051,
                                    0.8646679530544249,
                                    0.0019069460104017045,
                                ],
                                [
                                    0.038744149257572705,
                                    0.005965372446072136,
                                    0.8278307498072539,
                                    0.1274597284891012,
                                ],
                                [
                                    0.8646679530544249,
                                    0.0019069460104017045,
                                    0.13313149161855184,
                                    0.0002936093166215051,
                                ],
                                [
                                    0.8646679530544249,
                                    0.13313149161855184,
                                    0.0019069460104017045,
                                    0.0002936093166215051,
                                ],
                                [
                                    0.3533470962804403,
                                    0.12861047525796562,
                                    0.3798027018492131,
                                    0.13823972661238096,
                                ],
                                [
                                    0.3533470962804403,
                                    0.3798027018492131,
                                    0.12861047525796562,
                                    0.13823972661238096,
                                ],
                                [
                                    0.3798027018492131,
                                    0.13823972661238096,
                                    0.3533470962804403,
                                    0.12861047525796562,
                                ],
                                [
                                    0.37595576308682055,
                                    0.40410411207350083,
                                    0.1060018084515853,
                                    0.11393831638809326,
                                ],
                                [
                                    0.37595576308682055,
                                    0.1060018084515853,
                                    0.40410411207350083,
                                    0.11393831638809326,
                                ],
                                [
                                    0.3798027018492131,
                                    0.3533470962804403,
                                    0.13823972661238096,
                                    0.12861047525796562,
                                ],
                                [
                                    0.40410411207350083,
                                    0.11393831638809326,
                                    0.37595576308682055,
                                    0.1060018084515853,
                                ],
                                [
                                    0.40410411207350083,
                                    0.37595576308682055,
                                    0.11393831638809326,
                                    0.1060018084515853,
                                ],
                                [
                                    0.243341896214378,
                                    0.16790175352633327,
                                    0.34838005831988617,
                                    0.2403762919394026,
                                ],
                                [
                                    0.243341896214378,
                                    0.34838005831988617,
                                    0.16790175352633327,
                                    0.2403762919394026,
                                ],
                                [
                                    0.34838005831988617,
                                    0.2403762919394026,
                                    0.24334189621437802,
                                    0.1679017535263333,
                                ],
                                [
                                    0.33824267890412163,
                                    0.484244620577301,
                                    0.07300097083658962,
                                    0.10451172968198778,
                                ],
                                [
                                    0.33824267890412163,
                                    0.07300097083658962,
                                    0.484244620577301,
                                    0.10451172968198778,
                                ],
                                [
                                    0.34838005831988617,
                                    0.24334189621437802,
                                    0.2403762919394026,
                                    0.1679017535263333,
                                ],
                                [
                                    0.484244620577301,
                                    0.10451172968198778,
                                    0.3382426789041217,
                                    0.07300097083658963,
                                ],
                                [
                                    0.484244620577301,
                                    0.3382426789041217,
                                    0.10451172968198778,
                                    0.07300097083658963,
                                ],
                                [
                                    0.11834341944642739,
                                    0.18934791679036228,
                                    0.26627390807999335,
                                    0.42603475568321697,
                                ],
                                [
                                    0.11834341944642739,
                                    0.26627390807999335,
                                    0.18934791679036228,
                                    0.42603475568321697,
                                ],
                                [
                                    0.26627390807999335,
                                    0.42603475568321697,
                                    0.11834341944642737,
                                    0.18934791679036225,
                                ],
                                [
                                    0.27218908756482224,
                                    0.6124282399615986,
                                    0.03550224867196744,
                                    0.07988042380161178,
                                ],
                                [
                                    0.27218908756482224,
                                    0.03550224867196744,
                                    0.6124282399615986,
                                    0.07988042380161178,
                                ],
                                [
                                    0.26627390807999335,
                                    0.11834341944642737,
                                    0.42603475568321697,
                                    0.18934791679036225,
                                ],
                                [
                                    0.6124282399615986,
                                    0.07988042380161178,
                                    0.2721890875648222,
                                    0.03550224867196743,
                                ],
                                [
                                    0.6124282399615986,
                                    0.2721890875648222,
                                    0.07988042380161178,
                                    0.03550224867196743,
                                ],
                                [
                                    0.036237269206534674,
                                    0.16790175352633332,
                                    0.14127543131204282,
                                    0.6545855459550892,
                                ],
                                [
                                    0.036237269206534674,
                                    0.14127543131204282,
                                    0.16790175352633332,
                                    0.6545855459550892,
                                ],
                                [
                                    0.14127543131204282,
                                    0.6545855459550892,
                                    0.036237269206534674,
                                    0.16790175352633332,
                                ],
                                [
                                    0.19326807994127657,
                                    0.7534792756301424,
                                    0.010870942791591441,
                                    0.0423817016369896,
                                ],
                                [
                                    0.19326807994127657,
                                    0.010870942791591441,
                                    0.7534792756301424,
                                    0.0423817016369896,
                                ],
                                [
                                    0.14127543131204282,
                                    0.036237269206534674,
                                    0.6545855459550892,
                                    0.16790175352633332,
                                ],
                                [
                                    0.7534792756301424,
                                    0.0423817016369896,
                                    0.19326807994127657,
                                    0.010870942791591441,
                                ],
                                [
                                    0.7534792756301424,
                                    0.19326807994127657,
                                    0.0423817016369896,
                                    0.010870942791591441,
                                ],
                                [
                                    0.004814625677207673,
                                    0.12861047525796568,
                                    0.031270231245980516,
                                    0.8353046678188462,
                                ],
                                [
                                    0.004814625677207673,
                                    0.031270231245980516,
                                    0.12861047525796568,
                                    0.8353046678188462,
                                ],
                                [
                                    0.031270231245980516,
                                    0.8353046678188462,
                                    0.004814625677207673,
                                    0.12861047525796568,
                                ],
                                [
                                    0.1319807448496874,
                                    0.8571940350428328,
                                    0.0014443560854859728,
                                    0.00938086402199392,
                                ],
                                [
                                    0.1319807448496874,
                                    0.0014443560854859728,
                                    0.8571940350428328,
                                    0.00938086402199392,
                                ],
                                [
                                    0.031270231245980516,
                                    0.004814625677207673,
                                    0.8353046678188462,
                                    0.12861047525796568,
                                ],
                                [
                                    0.8571940350428328,
                                    0.00938086402199392,
                                    0.1319807448496874,
                                    0.0014443560854859728,
                                ],
                                [
                                    0.8571940350428328,
                                    0.1319807448496874,
                                    0.00938086402199392,
                                    0.0014443560854859728,
                                ],
                                [
                                    0.22967445236601278,
                                    0.2522831191723931,
                                    0.2468705091186532,
                                    0.27117191934294094,
                                ],
                                [
                                    0.22967445236601278,
                                    0.2468705091186532,
                                    0.2522831191723931,
                                    0.27117191934294094,
                                ],
                                [
                                    0.2468705091186532,
                                    0.27117191934294094,
                                    0.22967445236601278,
                                    0.2522831191723931,
                                ],
                                [
                                    0.2522831191723931,
                                    0.27117191934294094,
                                    0.22967445236601278,
                                    0.2468705091186532,
                                ],
                                [
                                    0.2522831191723931,
                                    0.22967445236601278,
                                    0.27117191934294094,
                                    0.2468705091186532,
                                ],
                                [
                                    0.2468705091186532,
                                    0.22967445236601278,
                                    0.27117191934294094,
                                    0.2522831191723931,
                                ],
                                [
                                    0.27117191934294094,
                                    0.2468705091186532,
                                    0.2522831191723931,
                                    0.22967445236601278,
                                ],
                                [
                                    0.27117191934294094,
                                    0.2522831191723931,
                                    0.2468705091186532,
                                    0.22967445236601278,
                                ],
                                [
                                    0.15817143352548385,
                                    0.2530722162152274,
                                    0.226445894000937,
                                    0.36231045625835173,
                                ],
                                [
                                    0.15817143352548385,
                                    0.226445894000937,
                                    0.2530722162152274,
                                    0.36231045625835173,
                                ],
                                [
                                    0.226445894000937,
                                    0.36231045625835173,
                                    0.15817143352548385,
                                    0.25307221621522746,
                                ],
                                [
                                    0.25307221621522746,
                                    0.3623104562583518,
                                    0.1581714335254838,
                                    0.22644589400093695,
                                ],
                                [
                                    0.25307221621522746,
                                    0.1581714335254838,
                                    0.3623104562583518,
                                    0.22644589400093695,
                                ],
                                [
                                    0.226445894000937,
                                    0.15817143352548385,
                                    0.36231045625835173,
                                    0.25307221621522746,
                                ],
                                [
                                    0.3623104562583518,
                                    0.22644589400093695,
                                    0.2530722162152275,
                                    0.15817143352548382,
                                ],
                                [
                                    0.3623104562583518,
                                    0.2530722162152275,
                                    0.22644589400093695,
                                    0.15817143352548382,
                                ],
                                [
                                    0.07692283405919742,
                                    0.23076850217759226,
                                    0.17307716594080258,
                                    0.5192314978224077,
                                ],
                                [
                                    0.07692283405919742,
                                    0.17307716594080258,
                                    0.23076850217759226,
                                    0.5192314978224077,
                                ],
                                [
                                    0.17307716594080258,
                                    0.5192314978224077,
                                    0.0769228340591974,
                                    0.2307685021775922,
                                ],
                                [
                                    0.23076850217759226,
                                    0.5192314978224077,
                                    0.07692283405919742,
                                    0.17307716594080258,
                                ],
                                [
                                    0.23076850217759226,
                                    0.07692283405919742,
                                    0.5192314978224077,
                                    0.17307716594080258,
                                ],
                                [
                                    0.17307716594080258,
                                    0.0769228340591974,
                                    0.5192314978224077,
                                    0.2307685021775922,
                                ],
                                [
                                    0.5192314978224077,
                                    0.17307716594080258,
                                    0.2307685021775922,
                                    0.0769228340591974,
                                ],
                                [
                                    0.5192314978224077,
                                    0.2307685021775922,
                                    0.17307716594080258,
                                    0.0769228340591974,
                                ],
                                [
                                    0.023554105999063057,
                                    0.18058491673380495,
                                    0.09182856647451619,
                                    0.7040324107926158,
                                ],
                                [
                                    0.023554105999063057,
                                    0.09182856647451619,
                                    0.18058491673380495,
                                    0.7040324107926158,
                                ],
                                [
                                    0.09182856647451619,
                                    0.7040324107926158,
                                    0.023554105999063057,
                                    0.18058491673380495,
                                ],
                                [
                                    0.18058491673380495,
                                    0.7040324107926158,
                                    0.023554105999063057,
                                    0.09182856647451619,
                                ],
                                [
                                    0.18058491673380495,
                                    0.023554105999063057,
                                    0.7040324107926158,
                                    0.09182856647451619,
                                ],
                                [
                                    0.09182856647451619,
                                    0.023554105999063057,
                                    0.7040324107926158,
                                    0.18058491673380495,
                                ],
                                [
                                    0.7040324107926158,
                                    0.09182856647451619,
                                    0.18058491673380495,
                                    0.023554105999063057,
                                ],
                                [
                                    0.7040324107926158,
                                    0.18058491673380495,
                                    0.09182856647451619,
                                    0.023554105999063057,
                                ],
                                [
                                    0.0031294908813468223,
                                    0.13029561005382653,
                                    0.020325547633987216,
                                    0.8462493514308395,
                                ],
                                [
                                    0.0031294908813468223,
                                    0.020325547633987216,
                                    0.13029561005382653,
                                    0.8462493514308395,
                                ],
                                [
                                    0.020325547633987216,
                                    0.8462493514308395,
                                    0.0031294908813468223,
                                    0.13029561005382653,
                                ],
                                [
                                    0.13029561005382653,
                                    0.8462493514308395,
                                    0.0031294908813468223,
                                    0.020325547633987216,
                                ],
                                [
                                    0.13029561005382653,
                                    0.0031294908813468223,
                                    0.8462493514308395,
                                    0.020325547633987216,
                                ],
                                [
                                    0.020325547633987216,
                                    0.0031294908813468223,
                                    0.8462493514308395,
                                    0.13029561005382653,
                                ],
                                [
                                    0.8462493514308395,
                                    0.020325547633987216,
                                    0.13029561005382653,
                                    0.0031294908813468223,
                                ],
                                [
                                    0.8462493514308395,
                                    0.13029561005382653,
                                    0.020325547633987216,
                                    0.0031294908813468223,
                                ],
                                [
                                    0.10600180845158533,
                                    0.37595576308682055,
                                    0.11393831638809329,
                                    0.40410411207350083,
                                ],
                                [
                                    0.10600180845158533,
                                    0.11393831638809329,
                                    0.37595576308682055,
                                    0.40410411207350083,
                                ],
                                [
                                    0.11393831638809329,
                                    0.40410411207350083,
                                    0.10600180845158533,
                                    0.37595576308682055,
                                ],
                                [
                                    0.12861047525796568,
                                    0.13823972661238101,
                                    0.35334709628044025,
                                    0.37980270184921305,
                                ],
                                [
                                    0.12861047525796568,
                                    0.35334709628044025,
                                    0.13823972661238101,
                                    0.37980270184921305,
                                ],
                                [
                                    0.11393831638809329,
                                    0.10600180845158533,
                                    0.40410411207350083,
                                    0.37595576308682055,
                                ],
                                [
                                    0.13823972661238101,
                                    0.37980270184921305,
                                    0.12861047525796568,
                                    0.35334709628044025,
                                ],
                                [
                                    0.13823972661238101,
                                    0.12861047525796568,
                                    0.37980270184921305,
                                    0.35334709628044025,
                                ],
                                [
                                    0.07300097083658966,
                                    0.33824267890412163,
                                    0.10451172968198782,
                                    0.4842446205773009,
                                ],
                                [
                                    0.07300097083658966,
                                    0.10451172968198782,
                                    0.33824267890412163,
                                    0.4842446205773009,
                                ],
                                [
                                    0.10451172968198782,
                                    0.4842446205773009,
                                    0.07300097083658966,
                                    0.33824267890412163,
                                ],
                                [
                                    0.16790175352633332,
                                    0.24037629193940266,
                                    0.24334189621437793,
                                    0.34838005831988605,
                                ],
                                [
                                    0.16790175352633332,
                                    0.24334189621437793,
                                    0.24037629193940266,
                                    0.34838005831988605,
                                ],
                                [
                                    0.10451172968198782,
                                    0.07300097083658966,
                                    0.4842446205773009,
                                    0.33824267890412163,
                                ],
                                [
                                    0.24037629193940266,
                                    0.34838005831988605,
                                    0.16790175352633332,
                                    0.243341896214378,
                                ],
                                [
                                    0.24037629193940266,
                                    0.16790175352633332,
                                    0.34838005831988605,
                                    0.243341896214378,
                                ],
                                [
                                    0.035502248671967454,
                                    0.27218908756482224,
                                    0.0798804238016118,
                                    0.6124282399615986,
                                ],
                                [
                                    0.035502248671967454,
                                    0.0798804238016118,
                                    0.27218908756482224,
                                    0.6124282399615986,
                                ],
                                [
                                    0.0798804238016118,
                                    0.6124282399615986,
                                    0.03550224867196745,
                                    0.2721890875648222,
                                ],
                                [
                                    0.18934791679036228,
                                    0.42603475568321697,
                                    0.11834341944642739,
                                    0.26627390807999335,
                                ],
                                [
                                    0.18934791679036228,
                                    0.11834341944642739,
                                    0.42603475568321697,
                                    0.26627390807999335,
                                ],
                                [
                                    0.0798804238016118,
                                    0.03550224867196745,
                                    0.6124282399615986,
                                    0.2721890875648222,
                                ],
                                [
                                    0.42603475568321697,
                                    0.26627390807999335,
                                    0.18934791679036225,
                                    0.11834341944642737,
                                ],
                                [
                                    0.42603475568321697,
                                    0.18934791679036225,
                                    0.26627390807999335,
                                    0.11834341944642737,
                                ],
                                [
                                    0.010870942791591436,
                                    0.19326807994127657,
                                    0.04238170163698958,
                                    0.7534792756301424,
                                ],
                                [
                                    0.010870942791591436,
                                    0.04238170163698958,
                                    0.19326807994127657,
                                    0.7534792756301424,
                                ],
                                [
                                    0.04238170163698958,
                                    0.7534792756301424,
                                    0.010870942791591436,
                                    0.19326807994127657,
                                ],
                                [
                                    0.16790175352633332,
                                    0.6545855459550892,
                                    0.036237269206534674,
                                    0.1412754313120428,
                                ],
                                [
                                    0.16790175352633332,
                                    0.036237269206534674,
                                    0.6545855459550892,
                                    0.1412754313120428,
                                ],
                                [
                                    0.04238170163698958,
                                    0.010870942791591436,
                                    0.7534792756301424,
                                    0.19326807994127657,
                                ],
                                [
                                    0.6545855459550892,
                                    0.1412754313120428,
                                    0.16790175352633332,
                                    0.036237269206534674,
                                ],
                                [
                                    0.6545855459550892,
                                    0.16790175352633332,
                                    0.1412754313120428,
                                    0.036237269206534674,
                                ],
                                [
                                    0.0014443560854859713,
                                    0.1319807448496874,
                                    0.009380864021993911,
                                    0.8571940350428328,
                                ],
                                [
                                    0.0014443560854859713,
                                    0.009380864021993911,
                                    0.1319807448496874,
                                    0.8571940350428328,
                                ],
                                [
                                    0.009380864021993911,
                                    0.8571940350428328,
                                    0.0014443560854859713,
                                    0.1319807448496874,
                                ],
                                [
                                    0.12861047525796568,
                                    0.8353046678188462,
                                    0.004814625677207671,
                                    0.03127023124598051,
                                ],
                                [
                                    0.12861047525796568,
                                    0.004814625677207671,
                                    0.8353046678188462,
                                    0.03127023124598051,
                                ],
                                [
                                    0.009380864021993911,
                                    0.0014443560854859713,
                                    0.8571940350428328,
                                    0.1319807448496874,
                                ],
                                [
                                    0.8353046678188462,
                                    0.03127023124598051,
                                    0.12861047525796568,
                                    0.004814625677207671,
                                ],
                                [
                                    0.8353046678188462,
                                    0.12861047525796568,
                                    0.03127023124598051,
                                    0.004814625677207671,
                                ],
                                [
                                    0.02154809250493232,
                                    0.46040947903347357,
                                    0.02316142919871252,
                                    0.4948809992628816,
                                ],
                                [
                                    0.02154809250493232,
                                    0.02316142919871252,
                                    0.46040947903347357,
                                    0.4948809992628816,
                                ],
                                [
                                    0.02316142919871252,
                                    0.4948809992628816,
                                    0.02154809250493232,
                                    0.46040947903347357,
                                ],
                                [
                                    0.04415675931131266,
                                    0.04746283942300025,
                                    0.4378008122270933,
                                    0.4705795890385938,
                                ],
                                [
                                    0.04415675931131266,
                                    0.4378008122270933,
                                    0.04746283942300025,
                                    0.4705795890385938,
                                ],
                                [
                                    0.02316142919871252,
                                    0.02154809250493232,
                                    0.4948809992628816,
                                    0.46040947903347357,
                                ],
                                [
                                    0.04746283942300025,
                                    0.4705795890385938,
                                    0.04415675931131266,
                                    0.4378008122270933,
                                ],
                                [
                                    0.04746283942300025,
                                    0.04415675931131266,
                                    0.4705795890385938,
                                    0.4378008122270933,
                                ],
                                [
                                    0.014839668261463284,
                                    0.396403981479248,
                                    0.021245188661724906,
                                    0.5675111615975639,
                                ],
                                [
                                    0.014839668261463284,
                                    0.021245188661724906,
                                    0.396403981479248,
                                    0.5675111615975639,
                                ],
                                [
                                    0.021245188661724906,
                                    0.5675111615975639,
                                    0.014839668261463285,
                                    0.39640398147924805,
                                ],
                                [
                                    0.10974045095120695,
                                    0.15710975091913976,
                                    0.3015031987895043,
                                    0.431646599340149,
                                ],
                                [
                                    0.10974045095120695,
                                    0.3015031987895043,
                                    0.15710975091913976,
                                    0.431646599340149,
                                ],
                                [
                                    0.021245188661724906,
                                    0.014839668261463285,
                                    0.5675111615975639,
                                    0.39640398147924805,
                                ],
                                [
                                    0.15710975091913976,
                                    0.431646599340149,
                                    0.10974045095120696,
                                    0.3015031987895044,
                                ],
                                [
                                    0.15710975091913976,
                                    0.10974045095120696,
                                    0.431646599340149,
                                    0.3015031987895044,
                                ],
                                [
                                    0.007216912142268497,
                                    0.3004744240945212,
                                    0.01623812637306554,
                                    0.6760705373901448,
                                ],
                                [
                                    0.007216912142268497,
                                    0.01623812637306554,
                                    0.3004744240945212,
                                    0.6760705373901448,
                                ],
                                [
                                    0.01623812637306554,
                                    0.6760705373901448,
                                    0.007216912142268496,
                                    0.30047442409452113,
                                ],
                                [
                                    0.16106258026066333,
                                    0.3623924582546707,
                                    0.14662875597612635,
                                    0.3299162055085396,
                                ],
                                [
                                    0.16106258026066333,
                                    0.14662875597612635,
                                    0.3623924582546707,
                                    0.3299162055085396,
                                ],
                                [
                                    0.01623812637306554,
                                    0.007216912142268496,
                                    0.6760705373901448,
                                    0.30047442409452113,
                                ],
                                [
                                    0.3623924582546707,
                                    0.3299162055085396,
                                    0.1610625802606633,
                                    0.14662875597612632,
                                ],
                                [
                                    0.3623924582546707,
                                    0.1610625802606633,
                                    0.3299162055085396,
                                    0.14662875597612632,
                                ],
                                [
                                    0.0022098498536091355,
                                    0.20192917287925885,
                                    0.008615370253870748,
                                    0.7872456070132613,
                                ],
                                [
                                    0.0022098498536091355,
                                    0.008615370253870748,
                                    0.20192917287925885,
                                    0.7872456070132613,
                                ],
                                [
                                    0.008615370253870748,
                                    0.7872456070132613,
                                    0.0022098498536091355,
                                    0.20192917287925885,
                                ],
                                [
                                    0.159240660588351,
                                    0.6208192145719703,
                                    0.04489836214451698,
                                    0.17504176269516164,
                                ],
                                [
                                    0.159240660588351,
                                    0.04489836214451698,
                                    0.6208192145719703,
                                    0.17504176269516164,
                                ],
                                [
                                    0.008615370253870748,
                                    0.0022098498536091355,
                                    0.7872456070132613,
                                    0.20192917287925885,
                                ],
                                [
                                    0.6208192145719703,
                                    0.17504176269516164,
                                    0.159240660588351,
                                    0.04489836214451698,
                                ],
                                [
                                    0.6208192145719703,
                                    0.159240660588351,
                                    0.17504176269516164,
                                    0.04489836214451698,
                                ],
                                [
                                    0.0002936093166215085,
                                    0.13313149161855184,
                                    0.0019069460104017262,
                                    0.8646679530544249,
                                ],
                                [
                                    0.0002936093166215085,
                                    0.0019069460104017262,
                                    0.13313149161855184,
                                    0.8646679530544249,
                                ],
                                [
                                    0.0019069460104017262,
                                    0.8646679530544249,
                                    0.0002936093166215085,
                                    0.13313149161855184,
                                ],
                                [
                                    0.1274597284891012,
                                    0.8278307498072539,
                                    0.0059653724460721385,
                                    0.03874414925757272,
                                ],
                                [
                                    0.1274597284891012,
                                    0.0059653724460721385,
                                    0.8278307498072539,
                                    0.03874414925757272,
                                ],
                                [
                                    0.0019069460104017262,
                                    0.0002936093166215085,
                                    0.8646679530544249,
                                    0.13313149161855184,
                                ],
                                [
                                    0.8278307498072539,
                                    0.03874414925757272,
                                    0.1274597284891012,
                                    0.0059653724460721385,
                                ],
                                [
                                    0.8278307498072539,
                                    0.1274597284891012,
                                    0.03874414925757272,
                                    0.0059653724460721385,
                                ],
                                [
                                    0.20205851090346283,
                                    0.02037969958844743,
                                    0.7063218903622244,
                                    0.0712398991458654,
                                ],
                                [
                                    0.20205851090346283,
                                    0.7063218903622244,
                                    0.02037969958844743,
                                    0.0712398991458654,
                                ],
                                [
                                    0.23483728771496334,
                                    0.023685779700135013,
                                    0.6735431135507238,
                                    0.06793381903417782,
                                ],
                                [
                                    0.21249310449220227,
                                    0.7427973738041529,
                                    0.009945105999707975,
                                    0.03476441570393684,
                                ],
                                [
                                    0.21249310449220227,
                                    0.009945105999707975,
                                    0.7427973738041529,
                                    0.03476441570393684,
                                ],
                                [
                                    0.23483728771496334,
                                    0.6735431135507238,
                                    0.023685779700135013,
                                    0.06793381903417782,
                                ],
                                [
                                    0.24696462472161015,
                                    0.01155844269348817,
                                    0.708325853574745,
                                    0.03315107901015664,
                                ],
                                [
                                    0.24696462472161015,
                                    0.708325853574745,
                                    0.01155844269348817,
                                    0.03315107901015664,
                                ],
                                [
                                    0.13915297934266335,
                                    0.050648586036823984,
                                    0.5939968187869901,
                                    0.2162016158335226,
                                ],
                                [
                                    0.13915297934266335,
                                    0.5939968187869901,
                                    0.050648586036823984,
                                    0.2162016158335226,
                                ],
                                [
                                    0.26929637989330796,
                                    0.09801788600475674,
                                    0.46385341823634546,
                                    0.16883231586558986,
                                ],
                                [
                                    0.18295260304897137,
                                    0.7809625400278404,
                                    0.006848962330515939,
                                    0.029235894592672198,
                                ],
                                [
                                    0.18295260304897137,
                                    0.006848962330515939,
                                    0.7809625400278404,
                                    0.029235894592672198,
                                ],
                                [
                                    0.26929637989330796,
                                    0.46385341823634546,
                                    0.09801788600475674,
                                    0.16883231586558986,
                                ],
                                [
                                    0.35405978316728715,
                                    0.013254482730777548,
                                    0.6098553599095247,
                                    0.022830374192410588,
                                ],
                                [
                                    0.35405978316728715,
                                    0.6098553599095247,
                                    0.013254482730777548,
                                    0.022830374192410588,
                                ],
                                [
                                    0.06767367090400703,
                                    0.07433532378386273,
                                    0.4088712905806589,
                                    0.44911971473147133,
                                ],
                                [
                                    0.06767367090400703,
                                    0.4088712905806589,
                                    0.07433532378386273,
                                    0.44911971473147133,
                                ],
                                [
                                    0.2509611204364204,
                                    0.27566520177787013,
                                    0.2255838410482456,
                                    0.24778983673746388,
                                ],
                                [
                                    0.1386781682479419,
                                    0.8378667932367241,
                                    0.003330826439927848,
                                    0.02012421207540616,
                                ],
                                [
                                    0.1386781682479419,
                                    0.003330826439927848,
                                    0.8378667932367241,
                                    0.02012421207540616,
                                ],
                                [
                                    0.2509611204364204,
                                    0.2255838410482456,
                                    0.27566520177787013,
                                    0.24778983673746388,
                                ],
                                [
                                    0.5142742815435656,
                                    0.012352040670724882,
                                    0.4622706799411003,
                                    0.011102997844609127,
                                ],
                                [
                                    0.5142742815435656,
                                    0.4622706799411003,
                                    0.012352040670724882,
                                    0.011102997844609127,
                                ],
                                [
                                    0.0207219720556838,
                                    0.07349445194056839,
                                    0.19921815278399482,
                                    0.706565423219753,
                                ],
                                [
                                    0.0207219720556838,
                                    0.19921815278399482,
                                    0.07349445194056839,
                                    0.706565423219753,
                                ],
                                [
                                    0.15086537260632846,
                                    0.5350730059241877,
                                    0.06907475223335015,
                                    0.2449868692361336,
                                ],
                                [
                                    0.0931965104687531,
                                    0.895978269423767,
                                    0.0010199135274990793,
                                    0.009805306579980803,
                                ],
                                [
                                    0.0931965104687531,
                                    0.0010199135274990793,
                                    0.895978269423767,
                                    0.009805306579980803,
                                ],
                                [
                                    0.15086537260632846,
                                    0.06907475223335015,
                                    0.5350730059241877,
                                    0.2449868692361336,
                                ],
                                [
                                    0.6785129446027555,
                                    0.007425433927760691,
                                    0.31066183528976454,
                                    0.003399786179719191,
                                ],
                                [
                                    0.6785129446027555,
                                    0.31066183528976454,
                                    0.007425433927760691,
                                    0.003399786179719191,
                                ],
                                [
                                    0.0027532024605122244,
                                    0.05882657642331726,
                                    0.04195631924313262,
                                    0.8964639018730379,
                                ],
                                [
                                    0.0027532024605122244,
                                    0.04195631924313262,
                                    0.05882657642331726,
                                    0.8964639018730379,
                                ],
                                [
                                    0.03553197927201279,
                                    0.75919759774147,
                                    0.00917754243163205,
                                    0.19609288055488522,
                                ],
                                [
                                    0.06144426917336976,
                                    0.936355175499607,
                                    0.00013550971045972232,
                                    0.002065045616563487,
                                ],
                                [
                                    0.06144426917336976,
                                    0.00013550971045972232,
                                    0.936355175499607,
                                    0.002065045616563487,
                                ],
                                [
                                    0.03553197927201279,
                                    0.00917754243163205,
                                    0.75919759774147,
                                    0.19609288055488522,
                                ],
                                [
                                    0.7929807306092429,
                                    0.0017488464042399216,
                                    0.20481871406373398,
                                    0.00045170892278328803,
                                ],
                                [
                                    0.7929807306092429,
                                    0.20481871406373398,
                                    0.0017488464042399216,
                                    0.00045170892278328803,
                                ],
                                [
                                    0.16308052911846535,
                                    0.059357681373444895,
                                    0.570069269011188,
                                    0.20749252049690167,
                                ],
                                [
                                    0.16308052911846535,
                                    0.570069269011188,
                                    0.059357681373444895,
                                    0.20749252049690167,
                                ],
                                [
                                    0.18953613468723812,
                                    0.06898693272786022,
                                    0.5436136634424152,
                                    0.19786326914248636,
                                ],
                                [
                                    0.17351512270720482,
                                    0.6065447524531166,
                                    0.048923087784705444,
                                    0.17101703705497312,
                                ],
                                [
                                    0.17351512270720482,
                                    0.048923087784705444,
                                    0.6065447524531166,
                                    0.17101703705497312,
                                ],
                                [
                                    0.18953613468723812,
                                    0.5436136634424152,
                                    0.06898693272786022,
                                    0.19786326914248636,
                                ],
                                [
                                    0.20166347169388496,
                                    0.056859595721213366,
                                    0.5783964034664364,
                                    0.16308052911846518,
                                ],
                                [
                                    0.20166347169388496,
                                    0.5783964034664364,
                                    0.056859595721213366,
                                    0.16308052911846518,
                                ],
                                [
                                    0.11230975324001316,
                                    0.07749181213947418,
                                    0.47941220129425094,
                                    0.3307862333262617,
                                ],
                                [
                                    0.11230975324001316,
                                    0.47941220129425094,
                                    0.07749181213947418,
                                    0.3307862333262617,
                                ],
                                [
                                    0.21734791534552125,
                                    0.14996635055254345,
                                    0.3743740391887429,
                                    0.2583116949131924,
                                ],
                                [
                                    0.1561093769463212,
                                    0.6663779225351014,
                                    0.033692188433166126,
                                    0.14382051208541127,
                                ],
                                [
                                    0.1561093769463212,
                                    0.033692188433166126,
                                    0.6663779225351014,
                                    0.14382051208541127,
                                ],
                                [
                                    0.21734791534552125,
                                    0.3743740391887429,
                                    0.14996635055254345,
                                    0.2583116949131924,
                                ],
                                [
                                    0.30211131861950047,
                                    0.06520294727856427,
                                    0.5203759808619222,
                                    0.11230975324001313,
                                ],
                                [
                                    0.30211131861950047,
                                    0.5203759808619222,
                                    0.06520294727856427,
                                    0.11230975324001313,
                                ],
                                [
                                    0.05461912002156215,
                                    0.08738987466630761,
                                    0.3299982075048586,
                                    0.5279927978072716,
                                ],
                                [
                                    0.05461912002156215,
                                    0.3299982075048586,
                                    0.08738987466630761,
                                    0.5279927978072716,
                                ],
                                [
                                    0.20254960865512817,
                                    0.32407671355916234,
                                    0.18206771887129258,
                                    0.2913059589144169,
                                ],
                                [
                                    0.12562361736549701,
                                    0.7589937101609238,
                                    0.01638537732237273,
                                    0.09899729515120649,
                                ],
                                [
                                    0.12562361736549701,
                                    0.01638537732237273,
                                    0.7589937101609238,
                                    0.09899729515120649,
                                ],
                                [
                                    0.20254960865512817,
                                    0.18206771887129258,
                                    0.32407671355916234,
                                    0.2913059589144169,
                                ],
                                [
                                    0.4658627697622734,
                                    0.06076355245201708,
                                    0.41875455776414733,
                                    0.05461912002156214,
                                ],
                                [
                                    0.4658627697622734,
                                    0.41875455776414733,
                                    0.06076355245201708,
                                    0.05461912002156214,
                                ],
                                [
                                    0.01672461185677803,
                                    0.07749181213947415,
                                    0.16078808866179944,
                                    0.7449954873419483,
                                ],
                                [
                                    0.01672461185677803,
                                    0.16078808866179944,
                                    0.07749181213947415,
                                    0.7449954873419483,
                                ],
                                [
                                    0.12176277396228616,
                                    0.56417560456823,
                                    0.05574992655629131,
                                    0.25831169491319245,
                                ],
                                [
                                    0.08919915026984734,
                                    0.8575482053015716,
                                    0.005017273726404848,
                                    0.04823537070217619,
                                ],
                                [
                                    0.08919915026984734,
                                    0.005017273726404848,
                                    0.8575482053015716,
                                    0.04823537070217619,
                                ],
                                [
                                    0.12176277396228616,
                                    0.05574992655629131,
                                    0.56417560456823,
                                    0.25831169491319245,
                                ],
                                [
                                    0.6494103459587132,
                                    0.03652803257180301,
                                    0.2973370096127057,
                                    0.01672461185677803,
                                ],
                                [
                                    0.6494103459587132,
                                    0.2973370096127057,
                                    0.03652803257180301,
                                    0.01672461185677803,
                                ],
                                [
                                    0.0022220975103845525,
                                    0.05935768137344493,
                                    0.03386275941280364,
                                    0.9045574617033669,
                                ],
                                [
                                    0.0022220975103845525,
                                    0.03386275941280364,
                                    0.05935768137344493,
                                    0.9045574617033669,
                                ],
                                [
                                    0.028677703079157398,
                                    0.7660518739343254,
                                    0.007407153844030796,
                                    0.19786326914248648,
                                ],
                                [
                                    0.06091316422324209,
                                    0.928261615669278,
                                    0.0006666146605873967,
                                    0.010158605446892496,
                                ],
                                [
                                    0.06091316422324209,
                                    0.0006666146605873967,
                                    0.928261615669278,
                                    0.010158605446892496,
                                ],
                                [
                                    0.028677703079157398,
                                    0.007407153844030796,
                                    0.7660518739343254,
                                    0.19786326914248648,
                                ],
                                [
                                    0.7861264544163875,
                                    0.008603122597095345,
                                    0.20304832547613272,
                                    0.0022220975103845494,
                                ],
                                [
                                    0.7861264544163875,
                                    0.20304832547613272,
                                    0.008603122597095345,
                                    0.0022220975103845494,
                                ],
                                [
                                    0.1060018084515854,
                                    0.11643640204032486,
                                    0.37054315303308055,
                                    0.4070186364750092,
                                ],
                                [
                                    0.1060018084515854,
                                    0.37054315303308055,
                                    0.11643640204032486,
                                    0.4070186364750092,
                                ],
                                [
                                    0.12319786520422574,
                                    0.1353252022108726,
                                    0.3533470962804402,
                                    0.38812983630446146,
                                ],
                                [
                                    0.11643640204032486,
                                    0.4070186364750092,
                                    0.1060018084515854,
                                    0.37054315303308055,
                                ],
                                [
                                    0.11643640204032486,
                                    0.1060018084515854,
                                    0.4070186364750092,
                                    0.37054315303308055,
                                ],
                                [
                                    0.12319786520422574,
                                    0.3533470962804402,
                                    0.1353252022108726,
                                    0.38812983630446146,
                                ],
                                [
                                    0.1353252022108726,
                                    0.12319786520422574,
                                    0.38812983630446146,
                                    0.3533470962804402,
                                ],
                                [
                                    0.1353252022108726,
                                    0.38812983630446146,
                                    0.12319786520422574,
                                    0.3533470962804402,
                                ],
                                [
                                    0.07300097083658966,
                                    0.11680059454289768,
                                    0.3116163566898312,
                                    0.4985820779306815,
                                ],
                                [
                                    0.07300097083658966,
                                    0.3116163566898312,
                                    0.11680059454289768,
                                    0.4985820779306815,
                                ],
                                [
                                    0.1412754313120428,
                                    0.22603883458602192,
                                    0.24334189621437807,
                                    0.3893438378875572,
                                ],
                                [
                                    0.11680059454289769,
                                    0.49858207793068154,
                                    0.07300097083658964,
                                    0.3116163566898311,
                                ],
                                [
                                    0.11680059454289769,
                                    0.07300097083658964,
                                    0.49858207793068154,
                                    0.3116163566898311,
                                ],
                                [
                                    0.1412754313120428,
                                    0.24334189621437807,
                                    0.22603883458602192,
                                    0.3893438378875572,
                                ],
                                [
                                    0.22603883458602195,
                                    0.14127543131204276,
                                    0.3893438378875573,
                                    0.243341896214378,
                                ],
                                [
                                    0.22603883458602195,
                                    0.3893438378875573,
                                    0.14127543131204276,
                                    0.243341896214378,
                                ],
                                [
                                    0.03550224867196744,
                                    0.10650674601590232,
                                    0.21449775132803256,
                                    0.6434932539840976,
                                ],
                                [
                                    0.03550224867196744,
                                    0.21449775132803256,
                                    0.10650674601590232,
                                    0.6434932539840976,
                                ],
                                [
                                    0.13165658055357263,
                                    0.39496974166071785,
                                    0.11834341944642737,
                                    0.35503025833928215,
                                ],
                                [
                                    0.10650674601590232,
                                    0.6434932539840976,
                                    0.03550224867196744,
                                    0.21449775132803256,
                                ],
                                [
                                    0.10650674601590232,
                                    0.03550224867196744,
                                    0.6434932539840976,
                                    0.21449775132803256,
                                ],
                                [
                                    0.13165658055357263,
                                    0.11834341944642737,
                                    0.39496974166071785,
                                    0.35503025833928215,
                                ],
                                [
                                    0.39496974166071785,
                                    0.13165658055357263,
                                    0.35503025833928215,
                                    0.11834341944642737,
                                ],
                                [
                                    0.39496974166071785,
                                    0.35503025833928215,
                                    0.13165658055357263,
                                    0.11834341944642737,
                                ],
                                [
                                    0.010870942791591438,
                                    0.08334548120466075,
                                    0.10451172968198781,
                                    0.80127184632176,
                                ],
                                [
                                    0.010870942791591438,
                                    0.10451172968198781,
                                    0.08334548120466075,
                                    0.80127184632176,
                                ],
                                [
                                    0.07914540326704457,
                                    0.6067929752634716,
                                    0.03623726920653467,
                                    0.27782435226294905,
                                ],
                                [
                                    0.08334548120466075,
                                    0.80127184632176,
                                    0.010870942791591438,
                                    0.10451172968198781,
                                ],
                                [
                                    0.08334548120466075,
                                    0.010870942791591438,
                                    0.80127184632176,
                                    0.10451172968198781,
                                ],
                                [
                                    0.07914540326704457,
                                    0.03623726920653467,
                                    0.6067929752634716,
                                    0.27782435226294905,
                                ],
                                [
                                    0.6067929752634716,
                                    0.07914540326704457,
                                    0.27782435226294905,
                                    0.03623726920653467,
                                ],
                                [
                                    0.6067929752634716,
                                    0.27782435226294905,
                                    0.07914540326704457,
                                    0.03623726920653467,
                                ],
                                [
                                    0.0014443560854859741,
                                    0.06013542279834351,
                                    0.022010682429848064,
                                    0.9164095386863225,
                                ],
                                [
                                    0.0014443560854859741,
                                    0.022010682429848064,
                                    0.06013542279834351,
                                    0.9164095386863225,
                                ],
                                [
                                    0.018640412838126365,
                                    0.7760891641753564,
                                    0.004814625677207671,
                                    0.2004557973093096,
                                ],
                                [
                                    0.06013542279834351,
                                    0.9164095386863225,
                                    0.0014443560854859741,
                                    0.022010682429848064,
                                ],
                                [
                                    0.06013542279834351,
                                    0.0014443560854859741,
                                    0.9164095386863225,
                                    0.022010682429848064,
                                ],
                                [
                                    0.018640412838126365,
                                    0.004814625677207671,
                                    0.7760891641753564,
                                    0.2004557973093096,
                                ],
                                [
                                    0.7760891641753564,
                                    0.018640412838126365,
                                    0.2004557973093096,
                                    0.004814625677207671,
                                ],
                                [
                                    0.7760891641753564,
                                    0.2004557973093096,
                                    0.018640412838126365,
                                    0.004814625677207671,
                                ],
                                [
                                    0.04892308778470545,
                                    0.17351512270720482,
                                    0.17101703705497318,
                                    0.6065447524531166,
                                ],
                                [
                                    0.04892308778470545,
                                    0.17101703705497318,
                                    0.17351512270720482,
                                    0.6065447524531166,
                                ],
                                [
                                    0.05685959572121338,
                                    0.20166347169388496,
                                    0.16308052911846524,
                                    0.5783964034664364,
                                ],
                                [
                                    0.05935768137344492,
                                    0.20749252049690178,
                                    0.16308052911846535,
                                    0.5700692690111879,
                                ],
                                [
                                    0.05935768137344492,
                                    0.16308052911846535,
                                    0.20749252049690178,
                                    0.5700692690111879,
                                ],
                                [
                                    0.05685959572121338,
                                    0.16308052911846524,
                                    0.20166347169388496,
                                    0.5783964034664364,
                                ],
                                [
                                    0.06898693272786025,
                                    0.1895361346872381,
                                    0.19786326914248645,
                                    0.5436136634424152,
                                ],
                                [
                                    0.06898693272786025,
                                    0.19786326914248645,
                                    0.1895361346872381,
                                    0.5436136634424152,
                                ],
                                [
                                    0.03369218843316614,
                                    0.1561093769463212,
                                    0.14382051208541136,
                                    0.6663779225351013,
                                ],
                                [
                                    0.03369218843316614,
                                    0.14382051208541136,
                                    0.1561093769463212,
                                    0.6663779225351013,
                                ],
                                [
                                    0.0652029472785643,
                                    0.3021113186195004,
                                    0.11230975324001319,
                                    0.5203759808619222,
                                ],
                                [
                                    0.07749181213947419,
                                    0.3307862333262618,
                                    0.11230975324001315,
                                    0.4794122012942509,
                                ],
                                [
                                    0.07749181213947419,
                                    0.11230975324001315,
                                    0.3307862333262618,
                                    0.4794122012942509,
                                ],
                                [
                                    0.0652029472785643,
                                    0.11230975324001319,
                                    0.3021113186195004,
                                    0.5203759808619222,
                                ],
                                [
                                    0.1499663505525435,
                                    0.2173479153455212,
                                    0.2583116949131925,
                                    0.3743740391887428,
                                ],
                                [
                                    0.1499663505525435,
                                    0.2583116949131925,
                                    0.2173479153455212,
                                    0.3743740391887428,
                                ],
                                [
                                    0.016385377322372732,
                                    0.12562361736549701,
                                    0.09899729515120652,
                                    0.7589937101609238,
                                ],
                                [
                                    0.016385377322372732,
                                    0.09899729515120652,
                                    0.12562361736549701,
                                    0.7589937101609238,
                                ],
                                [
                                    0.060763552452017096,
                                    0.4658627697622734,
                                    0.054619120021562155,
                                    0.41875455776414733,
                                ],
                                [
                                    0.08738987466630761,
                                    0.5279927978072716,
                                    0.05461912002156215,
                                    0.3299982075048586,
                                ],
                                [
                                    0.08738987466630761,
                                    0.05461912002156215,
                                    0.5279927978072716,
                                    0.3299982075048586,
                                ],
                                [
                                    0.060763552452017096,
                                    0.054619120021562155,
                                    0.4658627697622734,
                                    0.41875455776414733,
                                ],
                                [
                                    0.32407671355916234,
                                    0.20254960865512817,
                                    0.2913059589144169,
                                    0.18206771887129258,
                                ],
                                [
                                    0.32407671355916234,
                                    0.2913059589144169,
                                    0.20254960865512817,
                                    0.18206771887129258,
                                ],
                                [
                                    0.005017273726404846,
                                    0.08919915026984734,
                                    0.04823537070217617,
                                    0.8575482053015716,
                                ],
                                [
                                    0.005017273726404846,
                                    0.04823537070217617,
                                    0.08919915026984734,
                                    0.8575482053015716,
                                ],
                                [
                                    0.03652803257180299,
                                    0.6494103459587132,
                                    0.016724611856778024,
                                    0.2973370096127057,
                                ],
                                [
                                    0.07749181213947415,
                                    0.7449954873419483,
                                    0.016724611856778027,
                                    0.16078808866179942,
                                ],
                                [
                                    0.07749181213947415,
                                    0.016724611856778027,
                                    0.7449954873419483,
                                    0.16078808866179942,
                                ],
                                [
                                    0.03652803257180299,
                                    0.016724611856778024,
                                    0.6494103459587132,
                                    0.2973370096127057,
                                ],
                                [
                                    0.56417560456823,
                                    0.12176277396228614,
                                    0.25831169491319245,
                                    0.0557499265562913,
                                ],
                                [
                                    0.56417560456823,
                                    0.25831169491319245,
                                    0.12176277396228614,
                                    0.0557499265562913,
                                ],
                                [
                                    0.000666614660587396,
                                    0.06091316422324209,
                                    0.010158605446892486,
                                    0.928261615669278,
                                ],
                                [
                                    0.000666614660587396,
                                    0.010158605446892486,
                                    0.06091316422324209,
                                    0.928261615669278,
                                ],
                                [
                                    0.008603122597095336,
                                    0.7861264544163875,
                                    0.0022220975103845473,
                                    0.20304832547613272,
                                ],
                                [
                                    0.05935768137344493,
                                    0.9045574617033669,
                                    0.0022220975103845516,
                                    0.033862759412803624,
                                ],
                                [
                                    0.05935768137344493,
                                    0.0022220975103845516,
                                    0.9045574617033669,
                                    0.033862759412803624,
                                ],
                                [
                                    0.008603122597095336,
                                    0.0022220975103845473,
                                    0.7861264544163875,
                                    0.20304832547613272,
                                ],
                                [
                                    0.7660518739343254,
                                    0.028677703079157388,
                                    0.19786326914248648,
                                    0.007407153844030793,
                                ],
                                [
                                    0.7660518739343254,
                                    0.19786326914248648,
                                    0.028677703079157388,
                                    0.007407153844030793,
                                ],
                                [
                                    0.00994510599970798,
                                    0.21249310449220227,
                                    0.03476441570393686,
                                    0.7427973738041529,
                                ],
                                [
                                    0.00994510599970798,
                                    0.03476441570393686,
                                    0.21249310449220227,
                                    0.7427973738041529,
                                ],
                                [
                                    0.011558442693488177,
                                    0.24696462472161015,
                                    0.03315107901015666,
                                    0.708325853574745,
                                ],
                                [
                                    0.02037969958844745,
                                    0.07123989914586547,
                                    0.2020585109034628,
                                    0.7063218903622243,
                                ],
                                [
                                    0.02037969958844745,
                                    0.2020585109034628,
                                    0.07123989914586547,
                                    0.7063218903622243,
                                ],
                                [
                                    0.011558442693488177,
                                    0.03315107901015666,
                                    0.24696462472161015,
                                    0.708325853574745,
                                ],
                                [
                                    0.023685779700135037,
                                    0.23483728771496332,
                                    0.06793381903417788,
                                    0.6735431135507238,
                                ],
                                [
                                    0.023685779700135037,
                                    0.06793381903417788,
                                    0.23483728771496332,
                                    0.6735431135507238,
                                ],
                                [
                                    0.00684896233051595,
                                    0.18295260304897137,
                                    0.029235894592672243,
                                    0.7809625400278404,
                                ],
                                [
                                    0.00684896233051595,
                                    0.029235894592672243,
                                    0.18295260304897137,
                                    0.7809625400278404,
                                ],
                                [
                                    0.013254482730777568,
                                    0.35405978316728715,
                                    0.022830374192410623,
                                    0.6098553599095247,
                                ],
                                [
                                    0.050648586036824005,
                                    0.21620161583352268,
                                    0.13915297934266332,
                                    0.59399681878699,
                                ],
                                [
                                    0.050648586036824005,
                                    0.13915297934266332,
                                    0.21620161583352268,
                                    0.59399681878699,
                                ],
                                [
                                    0.013254482730777568,
                                    0.022830374192410623,
                                    0.35405978316728715,
                                    0.6098553599095247,
                                ],
                                [
                                    0.09801788600475676,
                                    0.26929637989330796,
                                    0.16883231586558992,
                                    0.46385341823634535,
                                ],
                                [
                                    0.09801788600475676,
                                    0.16883231586558992,
                                    0.26929637989330796,
                                    0.46385341823634535,
                                ],
                                [
                                    0.003330826439927852,
                                    0.1386781682479419,
                                    0.020124212075406184,
                                    0.8378667932367241,
                                ],
                                [
                                    0.003330826439927852,
                                    0.020124212075406184,
                                    0.1386781682479419,
                                    0.8378667932367241,
                                ],
                                [
                                    0.012352040670724897,
                                    0.5142742815435656,
                                    0.01110299784460914,
                                    0.4622706799411003,
                                ],
                                [
                                    0.07433532378386273,
                                    0.44911971473147133,
                                    0.06767367090400703,
                                    0.4088712905806589,
                                ],
                                [
                                    0.07433532378386273,
                                    0.06767367090400703,
                                    0.44911971473147133,
                                    0.4088712905806589,
                                ],
                                [
                                    0.012352040670724897,
                                    0.01110299784460914,
                                    0.5142742815435656,
                                    0.4622706799411003,
                                ],
                                [
                                    0.27566520177787013,
                                    0.2509611204364204,
                                    0.24778983673746388,
                                    0.2255838410482456,
                                ],
                                [
                                    0.27566520177787013,
                                    0.24778983673746388,
                                    0.2509611204364204,
                                    0.2255838410482456,
                                ],
                                [
                                    0.0010199135274990793,
                                    0.0931965104687531,
                                    0.009805306579980803,
                                    0.895978269423767,
                                ],
                                [
                                    0.0010199135274990793,
                                    0.009805306579980803,
                                    0.0931965104687531,
                                    0.895978269423767,
                                ],
                                [
                                    0.007425433927760691,
                                    0.6785129446027555,
                                    0.003399786179719191,
                                    0.31066183528976454,
                                ],
                                [
                                    0.07349445194056839,
                                    0.706565423219753,
                                    0.0207219720556838,
                                    0.19921815278399482,
                                ],
                                [
                                    0.07349445194056839,
                                    0.0207219720556838,
                                    0.706565423219753,
                                    0.19921815278399482,
                                ],
                                [
                                    0.007425433927760691,
                                    0.003399786179719191,
                                    0.6785129446027555,
                                    0.31066183528976454,
                                ],
                                [
                                    0.5350730059241877,
                                    0.15086537260632846,
                                    0.2449868692361336,
                                    0.06907475223335015,
                                ],
                                [
                                    0.5350730059241877,
                                    0.2449868692361336,
                                    0.15086537260632846,
                                    0.06907475223335015,
                                ],
                                [
                                    0.00013550971045972387,
                                    0.06144426917336976,
                                    0.002065045616563511,
                                    0.936355175499607,
                                ],
                                [
                                    0.00013550971045972387,
                                    0.002065045616563511,
                                    0.06144426917336976,
                                    0.936355175499607,
                                ],
                                [
                                    0.0017488464042399417,
                                    0.7929807306092429,
                                    0.00045170892278329324,
                                    0.20481871406373398,
                                ],
                                [
                                    0.05882657642331726,
                                    0.8964639018730379,
                                    0.0027532024605122257,
                                    0.04195631924313263,
                                ],
                                [
                                    0.05882657642331726,
                                    0.0027532024605122257,
                                    0.8964639018730379,
                                    0.04195631924313263,
                                ],
                                [
                                    0.0017488464042399417,
                                    0.00045170892278329324,
                                    0.7929807306092429,
                                    0.20481871406373398,
                                ],
                                [
                                    0.75919759774147,
                                    0.035531979272012806,
                                    0.19609288055488522,
                                    0.009177542431632055,
                                ],
                                [
                                    0.75919759774147,
                                    0.19609288055488522,
                                    0.035531979272012806,
                                    0.009177542431632055,
                                ],
                                [
                                    0.04107453965132411,
                                    0.004142793961436702,
                                    0.8673058616143631,
                                    0.08747680477287613,
                                ],
                                [
                                    0.04107453965132411,
                                    0.8673058616143631,
                                    0.004142793961436702,
                                    0.08747680477287613,
                                ],
                                [
                                    0.07385331646282461,
                                    0.007448874073124284,
                                    0.8345270848028626,
                                    0.08417072466118855,
                                ],
                                [
                                    0.043195688254220134,
                                    0.912094790042135,
                                    0.0020216453585406775,
                                    0.04268787634510413,
                                ],
                                [
                                    0.043195688254220134,
                                    0.0020216453585406775,
                                    0.912094790042135,
                                    0.04268787634510413,
                                ],
                                [
                                    0.07385331646282461,
                                    0.8345270848028626,
                                    0.007448874073124284,
                                    0.08417072466118855,
                                ],
                                [
                                    0.07766720848362801,
                                    0.0036349820523208726,
                                    0.8776232698127271,
                                    0.04107453965132394,
                                ],
                                [
                                    0.07766720848362801,
                                    0.8776232698127271,
                                    0.0036349820523208726,
                                    0.04107453965132394,
                                ],
                                [
                                    0.028287076560416978,
                                    0.010295866015002743,
                                    0.7048627215692365,
                                    0.2565543358553438,
                                ],
                                [
                                    0.028287076560416978,
                                    0.7048627215692365,
                                    0.010295866015002743,
                                    0.2565543358553438,
                                ],
                                [
                                    0.1584304771110616,
                                    0.05766516598293549,
                                    0.5747193210185918,
                                    0.20918503588741108,
                                ],
                                [
                                    0.037190682612910114,
                                    0.9267244604639017,
                                    0.0013922599625096046,
                                    0.03469259696067853,
                                ],
                                [
                                    0.037190682612910114,
                                    0.0013922599625096046,
                                    0.9267244604639017,
                                    0.03469259696067853,
                                ],
                                [
                                    0.1584304771110616,
                                    0.5747193210185918,
                                    0.05766516598293549,
                                    0.20918503588741108,
                                ],
                                [
                                    0.20829786273122586,
                                    0.007797780362771213,
                                    0.755617280345586,
                                    0.028287076560416922,
                                ],
                                [
                                    0.20829786273122586,
                                    0.755617280345586,
                                    0.007797780362771213,
                                    0.028287076560416922,
                                ],
                                [
                                    0.013756732475502232,
                                    0.015110916093571746,
                                    0.4627882290091637,
                                    0.5083441224217623,
                                ],
                                [
                                    0.013756732475502232,
                                    0.4627882290091637,
                                    0.015110916093571746,
                                    0.5083441224217623,
                                ],
                                [
                                    0.19704418200791557,
                                    0.21644079408757916,
                                    0.2795007794767504,
                                    0.3070142444277549,
                                ],
                                [
                                    0.02819055676003922,
                                    0.9483544047246267,
                                    0.0006770918090347568,
                                    0.022777946706299252,
                                ],
                                [
                                    0.02819055676003922,
                                    0.0006770918090347568,
                                    0.9483544047246267,
                                    0.022777946706299252,
                                ],
                                [
                                    0.19704418200791557,
                                    0.2795007794767504,
                                    0.21644079408757916,
                                    0.3070142444277549,
                                ],
                                [
                                    0.40378667005566293,
                                    0.009698306039831791,
                                    0.572758291429003,
                                    0.013756732475502218,
                                ],
                                [
                                    0.40378667005566293,
                                    0.572758291429003,
                                    0.009698306039831791,
                                    0.013756732475502218,
                                ],
                                [
                                    0.004212371253500261,
                                    0.014939983309228086,
                                    0.21572775358617835,
                                    0.7651198918510933,
                                ],
                                [
                                    0.004212371253500261,
                                    0.21572775358617835,
                                    0.014939983309228086,
                                    0.7651198918510933,
                                ],
                                [
                                    0.13435577180414493,
                                    0.47651853729284743,
                                    0.0855843530355337,
                                    0.303541337867474,
                                ],
                                [
                                    0.018945026109010315,
                                    0.9702297537835098,
                                    0.00020732845371803098,
                                    0.010617891653761851,
                                ],
                                [
                                    0.018945026109010315,
                                    0.00020732845371803098,
                                    0.9702297537835098,
                                    0.010617891653761851,
                                ],
                                [
                                    0.13435577180414493,
                                    0.0855843530355337,
                                    0.47651853729284743,
                                    0.303541337867474,
                                ],
                                [
                                    0.6042614602430127,
                                    0.006612848853979642,
                                    0.3849133196495075,
                                    0.00421237125350024,
                                ],
                                [
                                    0.6042614602430127,
                                    0.3849133196495075,
                                    0.006612848853979642,
                                    0.00421237125350024,
                                ],
                                [
                                    0.0005596721619237409,
                                    0.011958291363463625,
                                    0.044149849541721096,
                                    0.9433321869328916,
                                ],
                                [
                                    0.0005596721619237409,
                                    0.044149849541721096,
                                    0.011958291363463625,
                                    0.9433321869328916,
                                ],
                                [
                                    0.033338448973424306,
                                    0.7123293126816164,
                                    0.011371072730220533,
                                    0.24296116561473885,
                                ],
                                [
                                    0.012490417054068092,
                                    0.9853090276189087,
                                    2.7546471319273405e-05,
                                    0.0021730088557039362,
                                ],
                                [
                                    0.012490417054068092,
                                    2.7546471319273405e-05,
                                    0.9853090276189087,
                                    0.0021730088557039362,
                                ],
                                [
                                    0.033338448973424306,
                                    0.011371072730220533,
                                    0.7123293126816164,
                                    0.24296116561473885,
                                ],
                                [
                                    0.7440268784899412,
                                    0.0016408831650994728,
                                    0.2537725661830356,
                                    0.000559672161923737,
                                ],
                                [
                                    0.7440268784899412,
                                    0.2537725661830356,
                                    0.0016408831650994728,
                                    0.000559672161923737,
                                ],
                                [
                                    0.033151079010156785,
                                    0.012066254602604031,
                                    0.6999987191194966,
                                    0.25478394726774256,
                                ],
                                [
                                    0.033151079010156785,
                                    0.6999987191194966,
                                    0.012066254602604031,
                                    0.25478394726774256,
                                ],
                                [
                                    0.05960668457892955,
                                    0.021695505957019343,
                                    0.6735431135507238,
                                    0.24515469591332723,
                                ],
                                [
                                    0.035272227613052806,
                                    0.7447876475472686,
                                    0.009945105999708007,
                                    0.20999501883997054,
                                ],
                                [
                                    0.035272227613052806,
                                    0.009945105999708007,
                                    0.7447876475472686,
                                    0.20999501883997054,
                                ],
                                [
                                    0.05960668457892955,
                                    0.6735431135507238,
                                    0.021695505957019343,
                                    0.24515469591332723,
                                ],
                                [
                                    0.06342057659973295,
                                    0.017881613936215932,
                                    0.7166392985605884,
                                    0.20205851090346263,
                                ],
                                [
                                    0.06342057659973295,
                                    0.7166392985605884,
                                    0.017881613936215932,
                                    0.20205851090346263,
                                ],
                                [
                                    0.022830374192410633,
                                    0.015752568383009088,
                                    0.5688915803418535,
                                    0.3925254770827268,
                                ],
                                [
                                    0.022830374192410633,
                                    0.5688915803418535,
                                    0.015752568383009088,
                                    0.3925254770827268,
                                ],
                                [
                                    0.12786853629791872,
                                    0.08822710679607838,
                                    0.4638534182363454,
                                    0.3200509386696575,
                                ],
                                [
                                    0.03173398024490377,
                                    0.7907533192365188,
                                    0.006848962330515951,
                                    0.17066373818806144,
                                ],
                                [
                                    0.03173398024490377,
                                    0.006848962330515951,
                                    0.7907533192365188,
                                    0.17066373818806144,
                                ],
                                [
                                    0.12786853629791872,
                                    0.4638534182363454,
                                    0.08822710679607838,
                                    0.3200509386696575,
                                ],
                                [
                                    0.17773592191808302,
                                    0.038359721175914095,
                                    0.6447513775633397,
                                    0.1391529793426633,
                                ],
                                [
                                    0.17773592191808302,
                                    0.6447513775633397,
                                    0.038359721175914095,
                                    0.1391529793426633,
                                ],
                                [
                                    0.011102997844609138,
                                    0.017764650724464842,
                                    0.3735143296818116,
                                    0.5976180217491144,
                                ],
                                [
                                    0.011102997844609138,
                                    0.3735143296818116,
                                    0.017764650724464842,
                                    0.5976180217491144,
                                ],
                                [
                                    0.15903348647817514,
                                    0.25445148961731956,
                                    0.2255838410482456,
                                    0.3609311828562597,
                                ],
                                [
                                    0.025536822129146125,
                                    0.8590805053972747,
                                    0.003330826439927851,
                                    0.11205184603365137,
                                ],
                                [
                                    0.025536822129146125,
                                    0.003330826439927851,
                                    0.8590805053972747,
                                    0.11205184603365137,
                                ],
                                [
                                    0.15903348647817514,
                                    0.2255838410482456,
                                    0.25445148961731956,
                                    0.3609311828562597,
                                ],
                                [
                                    0.36577597452592253,
                                    0.0477090015695722,
                                    0.5188413530004983,
                                    0.06767367090400703,
                                ],
                                [
                                    0.36577597452592253,
                                    0.5188413530004983,
                                    0.0477090015695722,
                                    0.06767367090400703,
                                ],
                                [
                                    0.003399786179719208,
                                    0.01575256838300914,
                                    0.17411291433885828,
                                    0.8067347310984134,
                                ],
                                [
                                    0.003399786179719208,
                                    0.17411291433885828,
                                    0.01575256838300914,
                                    0.8067347310984134,
                                ],
                                [
                                    0.10843794828522733,
                                    0.502436360811765,
                                    0.06907475223335015,
                                    0.32005093866965756,
                                ],
                                [
                                    0.018132441035229263,
                                    0.9286149145361897,
                                    0.0010199135274990845,
                                    0.05223273090108196,
                                ],
                                [
                                    0.018132441035229263,
                                    0.0010199135274990845,
                                    0.9286149145361897,
                                    0.05223273090108196,
                                ],
                                [
                                    0.10843794828522733,
                                    0.06907475223335015,
                                    0.502436360811765,
                                    0.32005093866965756,
                                ],
                                [
                                    0.5783436367240952,
                                    0.032530672372897244,
                                    0.3684037188473239,
                                    0.0207219720556838,
                                ],
                                [
                                    0.5783436367240952,
                                    0.3684037188473239,
                                    0.032530672372897244,
                                    0.0207219720556838,
                                ],
                                [
                                    0.00045170892278329156,
                                    0.012066254602604074,
                                    0.0356331480004049,
                                    0.9518488884742078,
                                ],
                                [
                                    0.00045170892278329156,
                                    0.0356331480004049,
                                    0.012066254602604074,
                                    0.9518488884742078,
                                ],
                                [
                                    0.026907314491556138,
                                    0.7187604471634845,
                                    0.009177542431632057,
                                    0.24515469591332734,
                                ],
                                [
                                    0.012382453814927643,
                                    0.9767923260775925,
                                    0.0001355097104597232,
                                    0.01068971039702017,
                                ],
                                [
                                    0.012382453814927643,
                                    0.0001355097104597232,
                                    0.9767923260775925,
                                    0.01068971039702017,
                                ],
                                [
                                    0.026907314491556138,
                                    0.009177542431632057,
                                    0.7187604471634845,
                                    0.24515469591332734,
                                ],
                                [
                                    0.737595744008073,
                                    0.008072017646967671,
                                    0.2515790358844472,
                                    0.002753202460512223,
                                ],
                                [
                                    0.737595744008073,
                                    0.2515790358844472,
                                    0.008072017646967671,
                                    0.002753202460512223,
                                ],
                                [
                                    0.021548092504932392,
                                    0.02366924110782842,
                                    0.45499686897973357,
                                    0.4997857974075056,
                                ],
                                [
                                    0.021548092504932392,
                                    0.45499686897973357,
                                    0.02366924110782842,
                                    0.4997857974075056,
                                ],
                                [
                                    0.03874414925757274,
                                    0.04255804127837615,
                                    0.4378008122270932,
                                    0.4808969972369579,
                                ],
                                [
                                    0.02366924110782842,
                                    0.4997857974075056,
                                    0.021548092504932392,
                                    0.45499686897973357,
                                ],
                                [
                                    0.02366924110782842,
                                    0.021548092504932392,
                                    0.4997857974075056,
                                    0.45499686897973357,
                                ],
                                [
                                    0.03874414925757274,
                                    0.4378008122270932,
                                    0.04255804127837615,
                                    0.4808969972369579,
                                ],
                                [
                                    0.04255804127837615,
                                    0.03874414925757274,
                                    0.4808969972369579,
                                    0.4378008122270932,
                                ],
                                [
                                    0.04255804127837615,
                                    0.4808969972369579,
                                    0.03874414925757274,
                                    0.4378008122270932,
                                ],
                                [
                                    0.014839668261463294,
                                    0.023743274313956425,
                                    0.3697776592649576,
                                    0.5916393981596227,
                                ],
                                [
                                    0.014839668261463294,
                                    0.3697776592649576,
                                    0.023743274313956425,
                                    0.5916393981596227,
                                ],
                                [
                                    0.08311412873691643,
                                    0.13298151435708067,
                                    0.30150319878950443,
                                    0.4824011581164985,
                                ],
                                [
                                    0.023743274313956432,
                                    0.5916393981596229,
                                    0.01483966826146329,
                                    0.3697776592649575,
                                ],
                                [
                                    0.023743274313956432,
                                    0.01483966826146329,
                                    0.5916393981596229,
                                    0.3697776592649575,
                                ],
                                [
                                    0.08311412873691643,
                                    0.30150319878950443,
                                    0.13298151435708067,
                                    0.4824011581164985,
                                ],
                                [
                                    0.1329815143570807,
                                    0.0831141287369164,
                                    0.4824011581164986,
                                    0.3015031987895043,
                                ],
                                [
                                    0.1329815143570807,
                                    0.4824011581164986,
                                    0.0831141287369164,
                                    0.3015031987895043,
                                ],
                                [
                                    0.0072169121422684945,
                                    0.021650736426805484,
                                    0.2427830878577315,
                                    0.7283492635731945,
                                ],
                                [
                                    0.0072169121422684945,
                                    0.2427830878577315,
                                    0.021650736426805484,
                                    0.7283492635731945,
                                ],
                                [
                                    0.10337124402387368,
                                    0.3101137320716211,
                                    0.14662875597612632,
                                    0.4398862679283789,
                                ],
                                [
                                    0.021650736426805484,
                                    0.7283492635731945,
                                    0.0072169121422684945,
                                    0.2427830878577315,
                                ],
                                [
                                    0.021650736426805484,
                                    0.0072169121422684945,
                                    0.7283492635731945,
                                    0.2427830878577315,
                                ],
                                [
                                    0.10337124402387368,
                                    0.14662875597612632,
                                    0.3101137320716211,
                                    0.4398862679283789,
                                ],
                                [
                                    0.3101137320716211,
                                    0.10337124402387368,
                                    0.4398862679283789,
                                    0.14662875597612632,
                                ],
                                [
                                    0.3101137320716211,
                                    0.4398862679283789,
                                    0.10337124402387368,
                                    0.14662875597612632,
                                ],
                                [
                                    0.002209849853609146,
                                    0.0169425047091192,
                                    0.11317282261997011,
                                    0.8676748228173016,
                                ],
                                [
                                    0.002209849853609146,
                                    0.11317282261997011,
                                    0.0169425047091192,
                                    0.8676748228173016,
                                ],
                                [
                                    0.07048431032906229,
                                    0.54038999876793,
                                    0.04489836214451697,
                                    0.3442273287584907,
                                ],
                                [
                                    0.0169425047091192,
                                    0.8676748228173016,
                                    0.002209849853609146,
                                    0.11317282261997011,
                                ],
                                [
                                    0.0169425047091192,
                                    0.002209849853609146,
                                    0.8676748228173016,
                                    0.11317282261997011,
                                ],
                                [
                                    0.07048431032906229,
                                    0.04489836214451697,
                                    0.54038999876793,
                                    0.3442273287584907,
                                ],
                                [
                                    0.54038999876793,
                                    0.07048431032906229,
                                    0.3442273287584907,
                                    0.04489836214451697,
                                ],
                                [
                                    0.54038999876793,
                                    0.3442273287584907,
                                    0.07048431032906229,
                                    0.04489836214451697,
                                ],
                                [
                                    0.0002936093166215073,
                                    0.012224354208765859,
                                    0.02316142919871253,
                                    0.9643206072759001,
                                ],
                                [
                                    0.0002936093166215073,
                                    0.02316142919871253,
                                    0.012224354208765859,
                                    0.9643206072759001,
                                ],
                                [
                                    0.0174896660692619,
                                    0.7281780955857787,
                                    0.0059653724460721385,
                                    0.24836686589888723,
                                ],
                                [
                                    0.012224354208765859,
                                    0.9643206072759001,
                                    0.0002936093166215073,
                                    0.02316142919871253,
                                ],
                                [
                                    0.012224354208765859,
                                    0.0002936093166215073,
                                    0.9643206072759001,
                                    0.02316142919871253,
                                ],
                                [
                                    0.0174896660692619,
                                    0.0059653724460721385,
                                    0.7281780955857787,
                                    0.24836686589888723,
                                ],
                                [
                                    0.7281780955857787,
                                    0.0174896660692619,
                                    0.24836686589888723,
                                    0.0059653724460721385,
                                ],
                                [
                                    0.7281780955857787,
                                    0.24836686589888723,
                                    0.0174896660692619,
                                    0.0059653724460721385,
                                ],
                                [
                                    0.00994510599970801,
                                    0.035272227613052806,
                                    0.2099950188399706,
                                    0.7447876475472686,
                                ],
                                [
                                    0.00994510599970801,
                                    0.2099950188399706,
                                    0.035272227613052806,
                                    0.7447876475472686,
                                ],
                                [
                                    0.017881613936215936,
                                    0.06342057659973295,
                                    0.2020585109034627,
                                    0.7166392985605884,
                                ],
                                [
                                    0.012066254602604036,
                                    0.25478394726774267,
                                    0.03315107901015678,
                                    0.6999987191194965,
                                ],
                                [
                                    0.012066254602604036,
                                    0.03315107901015678,
                                    0.25478394726774267,
                                    0.6999987191194965,
                                ],
                                [
                                    0.017881613936215936,
                                    0.2020585109034627,
                                    0.06342057659973295,
                                    0.7166392985605884,
                                ],
                                [
                                    0.021695505957019353,
                                    0.05960668457892954,
                                    0.24515469591332734,
                                    0.6735431135507237,
                                ],
                                [
                                    0.021695505957019353,
                                    0.24515469591332734,
                                    0.05960668457892954,
                                    0.6735431135507237,
                                ],
                                [
                                    0.006848962330515953,
                                    0.031733980244903766,
                                    0.17066373818806152,
                                    0.7907533192365187,
                                ],
                                [
                                    0.006848962330515953,
                                    0.17066373818806152,
                                    0.031733980244903766,
                                    0.7907533192365187,
                                ],
                                [
                                    0.03835972117591411,
                                    0.177735921918083,
                                    0.13915297934266338,
                                    0.6447513775633396,
                                ],
                                [
                                    0.015752568383009095,
                                    0.3925254770827269,
                                    0.022830374192410626,
                                    0.5688915803418534,
                                ],
                                [
                                    0.015752568383009095,
                                    0.022830374192410626,
                                    0.3925254770827269,
                                    0.5688915803418534,
                                ],
                                [
                                    0.03835972117591411,
                                    0.13915297934266338,
                                    0.177735921918083,
                                    0.6447513775633396,
                                ],
                                [
                                    0.0882271067960784,
                                    0.1278685362979187,
                                    0.32005093866965756,
                                    0.46385341823634535,
                                ],
                                [
                                    0.0882271067960784,
                                    0.32005093866965756,
                                    0.1278685362979187,
                                    0.46385341823634535,
                                ],
                                [
                                    0.0033308264399278514,
                                    0.025536822129146125,
                                    0.1120518460336514,
                                    0.8590805053972747,
                                ],
                                [
                                    0.0033308264399278514,
                                    0.1120518460336514,
                                    0.025536822129146125,
                                    0.8590805053972747,
                                ],
                                [
                                    0.04770900156957222,
                                    0.36577597452592253,
                                    0.06767367090400704,
                                    0.5188413530004983,
                                ],
                                [
                                    0.017764650724464842,
                                    0.5976180217491144,
                                    0.011102997844609138,
                                    0.3735143296818116,
                                ],
                                [
                                    0.017764650724464842,
                                    0.011102997844609138,
                                    0.5976180217491144,
                                    0.3735143296818116,
                                ],
                                [
                                    0.04770900156957222,
                                    0.06767367090400704,
                                    0.36577597452592253,
                                    0.5188413530004983,
                                ],
                                [
                                    0.25445148961731956,
                                    0.15903348647817514,
                                    0.3609311828562597,
                                    0.2255838410482456,
                                ],
                                [
                                    0.25445148961731956,
                                    0.3609311828562597,
                                    0.15903348647817514,
                                    0.2255838410482456,
                                ],
                                [
                                    0.001019913527499084,
                                    0.018132441035229263,
                                    0.052232730901081936,
                                    0.9286149145361897,
                                ],
                                [
                                    0.001019913527499084,
                                    0.052232730901081936,
                                    0.018132441035229263,
                                    0.9286149145361897,
                                ],
                                [
                                    0.03253067237289723,
                                    0.5783436367240952,
                                    0.020721972055683793,
                                    0.3684037188473239,
                                ],
                                [
                                    0.01575256838300914,
                                    0.8067347310984134,
                                    0.0033997861797192075,
                                    0.17411291433885825,
                                ],
                                [
                                    0.01575256838300914,
                                    0.0033997861797192075,
                                    0.8067347310984134,
                                    0.17411291433885825,
                                ],
                                [
                                    0.03253067237289723,
                                    0.020721972055683793,
                                    0.5783436367240952,
                                    0.3684037188473239,
                                ],
                                [
                                    0.502436360811765,
                                    0.10843794828522732,
                                    0.32005093866965756,
                                    0.06907475223335015,
                                ],
                                [
                                    0.502436360811765,
                                    0.32005093866965756,
                                    0.10843794828522732,
                                    0.06907475223335015,
                                ],
                                [
                                    0.00013550971045972305,
                                    0.012382453814927643,
                                    0.01068971039702016,
                                    0.9767923260775925,
                                ],
                                [
                                    0.00013550971045972305,
                                    0.01068971039702016,
                                    0.012382453814927643,
                                    0.9767923260775925,
                                ],
                                [
                                    0.008072017646967663,
                                    0.737595744008073,
                                    0.0027532024605122205,
                                    0.2515790358844472,
                                ],
                                [
                                    0.012066254602604074,
                                    0.9518488884742078,
                                    0.00045170892278329134,
                                    0.03563314800040489,
                                ],
                                [
                                    0.012066254602604074,
                                    0.00045170892278329134,
                                    0.9518488884742078,
                                    0.03563314800040489,
                                ],
                                [
                                    0.008072017646967663,
                                    0.0027532024605122205,
                                    0.737595744008073,
                                    0.2515790358844472,
                                ],
                                [
                                    0.7187604471634845,
                                    0.026907314491556127,
                                    0.24515469591332734,
                                    0.009177542431632053,
                                ],
                                [
                                    0.7187604471634845,
                                    0.24515469591332734,
                                    0.026907314491556127,
                                    0.009177542431632053,
                                ],
                                [
                                    0.0020216453585406788,
                                    0.043195688254220134,
                                    0.04268787634510416,
                                    0.912094790042135,
                                ],
                                [
                                    0.0020216453585406788,
                                    0.04268787634510416,
                                    0.043195688254220134,
                                    0.912094790042135,
                                ],
                                [
                                    0.003634982052320875,
                                    0.07766720848362801,
                                    0.04107453965132397,
                                    0.8776232698127271,
                                ],
                                [
                                    0.004142793961436705,
                                    0.08747680477287621,
                                    0.041074539651324106,
                                    0.867305861614363,
                                ],
                                [
                                    0.004142793961436705,
                                    0.041074539651324106,
                                    0.08747680477287621,
                                    0.867305861614363,
                                ],
                                [
                                    0.003634982052320875,
                                    0.04107453965132397,
                                    0.07766720848362801,
                                    0.8776232698127271,
                                ],
                                [
                                    0.007448874073124291,
                                    0.0738533164628246,
                                    0.08417072466118862,
                                    0.8345270848028625,
                                ],
                                [
                                    0.007448874073124291,
                                    0.08417072466118862,
                                    0.0738533164628246,
                                    0.8345270848028625,
                                ],
                                [
                                    0.0013922599625096068,
                                    0.037190682612910114,
                                    0.034692596960678584,
                                    0.9267244604639017,
                                ],
                                [
                                    0.0013922599625096068,
                                    0.034692596960678584,
                                    0.037190682612910114,
                                    0.9267244604639017,
                                ],
                                [
                                    0.007797780362771225,
                                    0.20829786273122586,
                                    0.028287076560416964,
                                    0.755617280345586,
                                ],
                                [
                                    0.010295866015002746,
                                    0.25655433585534393,
                                    0.028287076560416975,
                                    0.7048627215692364,
                                ],
                                [
                                    0.010295866015002746,
                                    0.028287076560416975,
                                    0.25655433585534393,
                                    0.7048627215692364,
                                ],
                                [
                                    0.007797780362771225,
                                    0.028287076560416964,
                                    0.20829786273122586,
                                    0.755617280345586,
                                ],
                                [
                                    0.057665165982935515,
                                    0.1584304771110616,
                                    0.2091850358874112,
                                    0.5747193210185917,
                                ],
                                [
                                    0.057665165982935515,
                                    0.2091850358874112,
                                    0.1584304771110616,
                                    0.5747193210185917,
                                ],
                                [
                                    0.0006770918090347577,
                                    0.02819055676003922,
                                    0.02277794670629928,
                                    0.9483544047246267,
                                ],
                                [
                                    0.0006770918090347577,
                                    0.02277794670629928,
                                    0.02819055676003922,
                                    0.9483544047246267,
                                ],
                                [
                                    0.009698306039831803,
                                    0.40378667005566293,
                                    0.013756732475502234,
                                    0.572758291429003,
                                ],
                                [
                                    0.015110916093571746,
                                    0.5083441224217623,
                                    0.013756732475502232,
                                    0.4627882290091637,
                                ],
                                [
                                    0.015110916093571746,
                                    0.013756732475502232,
                                    0.5083441224217623,
                                    0.4627882290091637,
                                ],
                                [
                                    0.009698306039831803,
                                    0.013756732475502234,
                                    0.40378667005566293,
                                    0.572758291429003,
                                ],
                                [
                                    0.21644079408757916,
                                    0.19704418200791557,
                                    0.3070142444277549,
                                    0.2795007794767504,
                                ],
                                [
                                    0.21644079408757916,
                                    0.3070142444277549,
                                    0.19704418200791557,
                                    0.2795007794767504,
                                ],
                                [
                                    0.00020732845371803098,
                                    0.018945026109010315,
                                    0.010617891653761851,
                                    0.9702297537835098,
                                ],
                                [
                                    0.00020732845371803098,
                                    0.010617891653761851,
                                    0.018945026109010315,
                                    0.9702297537835098,
                                ],
                                [
                                    0.006612848853979642,
                                    0.6042614602430127,
                                    0.00421237125350024,
                                    0.3849133196495075,
                                ],
                                [
                                    0.014939983309228086,
                                    0.7651198918510933,
                                    0.004212371253500261,
                                    0.21572775358617835,
                                ],
                                [
                                    0.014939983309228086,
                                    0.004212371253500261,
                                    0.7651198918510933,
                                    0.21572775358617835,
                                ],
                                [
                                    0.006612848853979642,
                                    0.00421237125350024,
                                    0.6042614602430127,
                                    0.3849133196495075,
                                ],
                                [
                                    0.47651853729284743,
                                    0.13435577180414493,
                                    0.303541337867474,
                                    0.0855843530355337,
                                ],
                                [
                                    0.47651853729284743,
                                    0.303541337867474,
                                    0.13435577180414493,
                                    0.0855843530355337,
                                ],
                                [
                                    2.754647131927372e-05,
                                    0.012490417054068092,
                                    0.002173008855703961,
                                    0.9853090276189087,
                                ],
                                [
                                    2.754647131927372e-05,
                                    0.002173008855703961,
                                    0.012490417054068092,
                                    0.9853090276189087,
                                ],
                                [
                                    0.0016408831650994915,
                                    0.7440268784899412,
                                    0.0005596721619237434,
                                    0.2537725661830356,
                                ],
                                [
                                    0.011958291363463625,
                                    0.9433321869328916,
                                    0.0005596721619237411,
                                    0.04414984954172112,
                                ],
                                [
                                    0.011958291363463625,
                                    0.0005596721619237411,
                                    0.9433321869328916,
                                    0.04414984954172112,
                                ],
                                [
                                    0.0016408831650994915,
                                    0.0005596721619237434,
                                    0.7440268784899412,
                                    0.2537725661830356,
                                ],
                                [
                                    0.7123293126816164,
                                    0.03333844897342432,
                                    0.24296116561473885,
                                    0.01137107273022054,
                                ],
                                [
                                    0.7123293126816164,
                                    0.24296116561473885,
                                    0.03333844897342432,
                                    0.01137107273022054,
                                ],
                                [
                                    0.8270601242427641,
                                    0.08341760413004548,
                                    0.08132027702292319,
                                    0.008201994604267356,
                                ],
                                [
                                    0.8270601242427641,
                                    0.08132027702292319,
                                    0.08341760413004548,
                                    0.008201994604267356,
                                ],
                                [
                                    0.8676733775083179,
                                    0.08751387256813646,
                                    0.04070702375736935,
                                    0.004105726166176367,
                                ],
                                [
                                    0.8697707046154401,
                                    0.08551977368091507,
                                    0.04070702375736935,
                                    0.0040024979462754615,
                                ],
                                [
                                    0.8697707046154401,
                                    0.04070702375736935,
                                    0.08551977368091507,
                                    0.0040024979462754615,
                                ],
                                [
                                    0.8676733775083179,
                                    0.04070702375736935,
                                    0.08751387256813646,
                                    0.004105726166176367,
                                ],
                                [
                                    0.9124812849881163,
                                    0.04270596508833804,
                                    0.042809193308238944,
                                    0.002003556615306775,
                                ],
                                [
                                    0.9124812849881163,
                                    0.042809193308238944,
                                    0.04270596508833804,
                                    0.002003556615306775,
                                ],
                                [
                                    0.5450728322354034,
                                    0.19839437409261407,
                                    0.18807696589425002,
                                    0.0684558277777325,
                                ],
                                [
                                    0.5450728322354034,
                                    0.18807696589425002,
                                    0.19839437409261407,
                                    0.0684558277777325,
                                ],
                                [
                                    0.7063218903622245,
                                    0.2570854408054715,
                                    0.026827907767428907,
                                    0.00976476106487505,
                                ],
                                [
                                    0.7166392985605885,
                                    0.24727584451622325,
                                    0.026827907767428903,
                                    0.009256949155759232,
                                ],
                                [
                                    0.7166392985605885,
                                    0.026827907767428903,
                                    0.24727584451622325,
                                    0.009256949155759232,
                                ],
                                [
                                    0.7063218903622245,
                                    0.026827907767428907,
                                    0.2570854408054715,
                                    0.00976476106487505,
                                ],
                                [
                                    0.9286429154637592,
                                    0.03476441570393684,
                                    0.03527222761305266,
                                    0.001320441219251294,
                                ],
                                [
                                    0.9286429154637592,
                                    0.03527222761305266,
                                    0.03476441570393684,
                                    0.001320441219251294,
                                ],
                                [
                                    0.2377481489655524,
                                    0.261151573370936,
                                    0.23879681251911355,
                                    0.26230346514439806,
                                ],
                                [
                                    0.2377481489655524,
                                    0.23879681251911355,
                                    0.261151573370936,
                                    0.26230346514439806,
                                ],
                                [
                                    0.4648432492819742,
                                    0.5106014345391802,
                                    0.011701712202691778,
                                    0.012853603976153835,
                                ],
                                [
                                    0.4871980101337966,
                                    0.48934695135086936,
                                    0.011701712202691778,
                                    0.011753326312642231,
                                ],
                                [
                                    0.4871980101337966,
                                    0.011701712202691778,
                                    0.48934695135086936,
                                    0.011753326312642231,
                                ],
                                [
                                    0.4648432492819742,
                                    0.011701712202691778,
                                    0.5106014345391802,
                                    0.012853603976153835,
                                ],
                                [
                                    0.9525655911925514,
                                    0.02287909262860298,
                                    0.023979370292114582,
                                    0.0005759458867310281,
                                ],
                                [
                                    0.9525655911925514,
                                    0.023979370292114582,
                                    0.02287909262860298,
                                    0.0005759458867310281,
                                ],
                                [
                                    0.055937864252345273,
                                    0.19839437409261415,
                                    0.16400226058733333,
                                    0.5816655010677072,
                                ],
                                [
                                    0.055937864252345273,
                                    0.16400226058733333,
                                    0.19839437409261415,
                                    0.5816655010677072,
                                ],
                                [
                                    0.2171869223791664,
                                    0.7702951140954464,
                                    0.0027532024605122205,
                                    0.009764761064875054,
                                ],
                                [
                                    0.25157903588444724,
                                    0.7375957440080729,
                                    0.002753202460512221,
                                    0.008072017646967663,
                                ],
                                [
                                    0.25157903588444724,
                                    0.002753202460512221,
                                    0.7375957440080729,
                                    0.008072017646967663,
                                ],
                                [
                                    0.2171869223791664,
                                    0.0027532024605122205,
                                    0.7702951140954464,
                                    0.009764761064875054,
                                ],
                                [
                                    0.9767923260775926,
                                    0.010689710397020161,
                                    0.012382453814927552,
                                    0.00013550971045972208,
                                ],
                                [
                                    0.9767923260775926,
                                    0.012382453814927552,
                                    0.010689710397020161,
                                    0.00013550971045972208,
                                ],
                                [
                                    0.003904112170121851,
                                    0.08341760413004554,
                                    0.04080540953352299,
                                    0.8718728741663097,
                                ],
                                [
                                    0.003904112170121851,
                                    0.04080540953352299,
                                    0.08341760413004554,
                                    0.8718728741663097,
                                ],
                                [
                                    0.04451736543567569,
                                    0.9511847521301787,
                                    0.00019215626796914272,
                                    0.00410572616617637,
                                ],
                                [
                                    0.08712956003219824,
                                    0.9106698846407785,
                                    0.00019215626796914277,
                                    0.002008399059054067,
                                ],
                                [
                                    0.08712956003219824,
                                    0.00019215626796914277,
                                    0.9106698846407785,
                                    0.002008399059054067,
                                ],
                                [
                                    0.04451736543567569,
                                    0.00019215626796914272,
                                    0.9511847521301787,
                                    0.00410572616617637,
                                ],
                                [
                                    0.9935110199669166,
                                    0.002191097598937831,
                                    0.004288424706060135,
                                    9.457728085378388e-06,
                                ],
                                [
                                    0.9935110199669166,
                                    0.004288424706060135,
                                    0.002191097598937831,
                                    9.457728085378388e-06,
                                ],
                                [
                                    0.6675165627580707,
                                    0.2429611656147388,
                                    0.06563323537158273,
                                    0.023889036255607794,
                                ],
                                [
                                    0.6675165627580707,
                                    0.06563323537158273,
                                    0.2429611656147388,
                                    0.023889036255607794,
                                ],
                                [
                                    0.7002953395695712,
                                    0.25489191050688303,
                                    0.032854458560082185,
                                    0.011958291363463533,
                                ],
                                [
                                    0.7102271431307468,
                                    0.06983273202957463,
                                    0.20025058524206266,
                                    0.0196895395976159,
                                ],
                                [
                                    0.7102271431307468,
                                    0.20025058524206266,
                                    0.06983273202957463,
                                    0.0196895395976159,
                                ],
                                [
                                    0.7002953395695712,
                                    0.032854458560082185,
                                    0.25489191050688303,
                                    0.011958291363463533,
                                ],
                                [
                                    0.7451032470493697,
                                    0.21008400302708463,
                                    0.03495662811095177,
                                    0.00985612181259394,
                                ],
                                [
                                    0.7451032470493697,
                                    0.03495662811095177,
                                    0.21008400302708463,
                                    0.00985612181259394,
                                ],
                                [
                                    0.4399258684605435,
                                    0.30354133786747395,
                                    0.15179608607372058,
                                    0.10473670759826191,
                                ],
                                [
                                    0.4399258684605435,
                                    0.15179608607372058,
                                    0.30354133786747395,
                                    0.10473670759826191,
                                ],
                                [
                                    0.5700692690111882,
                                    0.39333806215650785,
                                    0.021652685523075945,
                                    0.014939983309228012,
                                ],
                                [
                                    0.6114923347857287,
                                    0.21099496469569387,
                                    0.13197487154228876,
                                    0.045537828976288636,
                                ],
                                [
                                    0.6114923347857287,
                                    0.13197487154228876,
                                    0.21099496469569387,
                                    0.045537828976288636,
                                ],
                                [
                                    0.5700692690111882,
                                    0.021652685523075945,
                                    0.39333806215650785,
                                    0.014939983309228012,
                                ],
                                [
                                    0.7923902941127229,
                                    0.17101703705497315,
                                    0.030097005368699706,
                                    0.0064956634636042536,
                                ],
                                [
                                    0.7923902941127229,
                                    0.030097005368699706,
                                    0.17101703705497315,
                                    0.0064956634636042536,
                                ],
                                [
                                    0.19188547790873353,
                                    0.3070142444277549,
                                    0.19273184961768722,
                                    0.30836842804582437,
                                ],
                                [
                                    0.19188547790873353,
                                    0.19273184961768722,
                                    0.3070142444277549,
                                    0.30836842804582437,
                                ],
                                [
                                    0.37517292744114683,
                                    0.6002717563800075,
                                    0.009444400085273882,
                                    0.01511091609357173,
                                ],
                                [
                                    0.4413353390769777,
                                    0.44328198844944305,
                                    0.05756438325951065,
                                    0.05781828921406857,
                                ],
                                [
                                    0.4413353390769777,
                                    0.05756438325951065,
                                    0.44328198844944305,
                                    0.05781828921406857,
                                ],
                                [
                                    0.37517292744114683,
                                    0.009444400085273882,
                                    0.6002717563800075,
                                    0.01511091609357173,
                                ],
                                [
                                    0.862895269351724,
                                    0.1125494144694303,
                                    0.021722058174696687,
                                    0.002833258004148924,
                                ],
                                [
                                    0.862895269351724,
                                    0.021722058174696687,
                                    0.1125494144694303,
                                    0.002833258004148924,
                                ],
                                [
                                    0.045147202457548254,
                                    0.2091850358874112,
                                    0.13236549806102924,
                                    0.6133022635940113,
                                ],
                                [
                                    0.045147202457548254,
                                    0.13236549806102924,
                                    0.2091850358874112,
                                    0.6133022635940113,
                                ],
                                [
                                    0.17529060300819294,
                                    0.8121914334664198,
                                    0.0022220975103845477,
                                    0.010295866015002725,
                                ],
                                [
                                    0.2407883740896502,
                                    0.7059589814817688,
                                    0.013543864255309249,
                                    0.03970878017327179,
                                ],
                                [
                                    0.2407883740896502,
                                    0.013543864255309249,
                                    0.7059589814817688,
                                    0.03970878017327179,
                                ],
                                [
                                    0.17529060300819294,
                                    0.0022220975103845477,
                                    0.8121914334664198,
                                    0.010295866015002725,
                                ],
                                [
                                    0.9348960067066191,
                                    0.05258602976799365,
                                    0.011851348864799879,
                                    0.0006666146605873953,
                                ],
                                [
                                    0.9348960067066191,
                                    0.011851348864799879,
                                    0.05258602976799365,
                                    0.0006666146605873953,
                                ],
                                [
                                    0.00315099163897877,
                                    0.08417072466118862,
                                    0.03293386528420942,
                                    0.8797444184156232,
                                ],
                                [
                                    0.00315099163897877,
                                    0.03293386528420942,
                                    0.08417072466118862,
                                    0.8797444184156232,
                                ],
                                [
                                    0.03592976845047936,
                                    0.9597723491153751,
                                    0.00015508847270882464,
                                    0.004142793961436689,
                                ],
                                [
                                    0.08637643950105516,
                                    0.902798340391465,
                                    0.0009452767991122267,
                                    0.009879943308367667,
                                ],
                                [
                                    0.08637643950105516,
                                    0.0009452767991122267,
                                    0.902798340391465,
                                    0.009879943308367667,
                                ],
                                [
                                    0.03592976845047936,
                                    0.00015508847270882464,
                                    0.9597723491153751,
                                    0.004142793961436689,
                                ],
                                [
                                    0.9849234229817203,
                                    0.010778694584134196,
                                    0.004251356910799817,
                                    4.652552334569664e-05,
                                ],
                                [
                                    0.9849234229817203,
                                    0.004251356910799817,
                                    0.010778694584134196,
                                    4.652552334569664e-05,
                                ],
                                [
                                    0.43388357400006666,
                                    0.47659415437274283,
                                    0.04266138748459932,
                                    0.046860884142591215,
                                ],
                                [
                                    0.43388357400006666,
                                    0.04266138748459932,
                                    0.47659415437274283,
                                    0.046860884142591215,
                                ],
                                [
                                    0.45518967129832794,
                                    0.4999975787781264,
                                    0.021355290186338062,
                                    0.023457459737207656,
                                ],
                                [
                                    0.47659415437274283,
                                    0.046860884142591215,
                                    0.43388357400006666,
                                    0.04266138748459932,
                                ],
                                [
                                    0.47659415437274283,
                                    0.43388357400006666,
                                    0.046860884142591215,
                                    0.04266138748459932,
                                ],
                                [
                                    0.45518967129832794,
                                    0.021355290186338062,
                                    0.4999975787781264,
                                    0.023457459737207656,
                                ],
                                [
                                    0.4999975787781264,
                                    0.45518967129832794,
                                    0.023457459737207656,
                                    0.021355290186338062,
                                ],
                                [
                                    0.4999975787781264,
                                    0.023457459737207656,
                                    0.45518967129832794,
                                    0.021355290186338062,
                                ],
                                [
                                    0.2859503700014162,
                                    0.45751683632660123,
                                    0.09866695752500464,
                                    0.15786583614697786,
                                ],
                                [
                                    0.2859503700014162,
                                    0.09866695752500464,
                                    0.45751683632660123,
                                    0.15786583614697786,
                                ],
                                [
                                    0.3705431530330808,
                                    0.5928641781346153,
                                    0.014074174493340103,
                                    0.022518494338963854,
                                ],
                                [
                                    0.45751683632660134,
                                    0.15786583614697788,
                                    0.2859503700014161,
                                    0.09866695752500461,
                                ],
                                [
                                    0.45751683632660134,
                                    0.2859503700014161,
                                    0.15786583614697788,
                                    0.09866695752500461,
                                ],
                                [
                                    0.3705431530330808,
                                    0.014074174493340103,
                                    0.5928641781346153,
                                    0.022518494338963854,
                                ],
                                [
                                    0.5928641781346154,
                                    0.37054315303308066,
                                    0.022518494338963857,
                                    0.0140741744933401,
                                ],
                                [
                                    0.5928641781346154,
                                    0.022518494338963857,
                                    0.37054315303308066,
                                    0.0140741744933401,
                                ],
                                [
                                    0.1247249305841221,
                                    0.3741747917523663,
                                    0.1252750694158779,
                                    0.3758252082476337,
                                ],
                                [
                                    0.1247249305841221,
                                    0.1252750694158779,
                                    0.3741747917523663,
                                    0.3758252082476337,
                                ],
                                [
                                    0.2438611709552886,
                                    0.7315835128658658,
                                    0.006138829044711403,
                                    0.01841648713413421,
                                ],
                                [
                                    0.3741747917523663,
                                    0.3758252082476337,
                                    0.1247249305841221,
                                    0.1252750694158779,
                                ],
                                [
                                    0.3741747917523663,
                                    0.1247249305841221,
                                    0.3758252082476337,
                                    0.1252750694158779,
                                ],
                                [
                                    0.2438611709552886,
                                    0.006138829044711403,
                                    0.7315835128658658,
                                    0.01841648713413421,
                                ],
                                [
                                    0.7315835128658658,
                                    0.2438611709552886,
                                    0.01841648713413421,
                                    0.006138829044711403,
                                ],
                                [
                                    0.7315835128658658,
                                    0.01841648713413421,
                                    0.2438611709552886,
                                    0.006138829044711403,
                                ],
                                [
                                    0.029345533356428748,
                                    0.22498670498853068,
                                    0.0860371391171505,
                                    0.6596306225378901,
                                ],
                                [
                                    0.029345533356428748,
                                    0.0860371391171505,
                                    0.22498670498853068,
                                    0.6596306225378901,
                                ],
                                [
                                    0.11393831638809328,
                                    0.8735437200865195,
                                    0.0014443560854859713,
                                    0.011073607439901302,
                                ],
                                [
                                    0.22498670498853068,
                                    0.6596306225378901,
                                    0.029345533356428748,
                                    0.0860371391171505,
                                ],
                                [
                                    0.22498670498853068,
                                    0.029345533356428748,
                                    0.6596306225378901,
                                    0.0860371391171505,
                                ],
                                [
                                    0.11393831638809328,
                                    0.0014443560854859713,
                                    0.8735437200865195,
                                    0.011073607439901302,
                                ],
                                [
                                    0.8735437200865195,
                                    0.11393831638809328,
                                    0.011073607439901302,
                                    0.0014443560854859713,
                                ],
                                [
                                    0.8735437200865195,
                                    0.011073607439901302,
                                    0.11393831638809328,
                                    0.0014443560854859713,
                                ],
                                [
                                    0.002048134219045498,
                                    0.08527358208112189,
                                    0.02140690429628854,
                                    0.8912713794035441,
                                ],
                                [
                                    0.002048134219045498,
                                    0.02140690429628854,
                                    0.08527358208112189,
                                    0.8912713794035441,
                                ],
                                [
                                    0.023354231517306777,
                                    0.9723478860485477,
                                    0.00010080699802726062,
                                    0.004197075436118252,
                                ],
                                [
                                    0.08527358208112189,
                                    0.8912713794035441,
                                    0.002048134219045498,
                                    0.02140690429628854,
                                ],
                                [
                                    0.08527358208112189,
                                    0.002048134219045498,
                                    0.8912713794035441,
                                    0.02140690429628854,
                                ],
                                [
                                    0.023354231517306777,
                                    0.00010080699802726062,
                                    0.9723478860485477,
                                    0.004197075436118252,
                                ],
                                [
                                    0.9723478860485477,
                                    0.023354231517306777,
                                    0.004197075436118252,
                                    0.00010080699802726062,
                                ],
                                [
                                    0.9723478860485477,
                                    0.004197075436118252,
                                    0.023354231517306777,
                                    0.00010080699802726062,
                                ],
                                [
                                    0.2002505852420627,
                                    0.7102271431307468,
                                    0.019689539597615907,
                                    0.06983273202957463,
                                ],
                                [
                                    0.2002505852420627,
                                    0.019689539597615907,
                                    0.7102271431307468,
                                    0.06983273202957463,
                                ],
                                [
                                    0.2100840030270847,
                                    0.7451032470493697,
                                    0.009856121812593944,
                                    0.03495662811095177,
                                ],
                                [
                                    0.2429611656147389,
                                    0.023889036255607805,
                                    0.6675165627580706,
                                    0.06563323537158273,
                                ],
                                [
                                    0.2429611656147389,
                                    0.6675165627580706,
                                    0.023889036255607805,
                                    0.06563323537158273,
                                ],
                                [
                                    0.2100840030270847,
                                    0.009856121812593944,
                                    0.7451032470493697,
                                    0.03495662811095177,
                                ],
                                [
                                    0.25489191050688315,
                                    0.7002953395695711,
                                    0.011958291363463538,
                                    0.03285445856008218,
                                ],
                                [
                                    0.25489191050688315,
                                    0.011958291363463538,
                                    0.7002953395695711,
                                    0.03285445856008218,
                                ],
                                [
                                    0.13197487154228882,
                                    0.6114923347857286,
                                    0.045537828976288657,
                                    0.21099496469569384,
                                ],
                                [
                                    0.13197487154228882,
                                    0.045537828976288657,
                                    0.6114923347857286,
                                    0.21099496469569384,
                                ],
                                [
                                    0.17101703705497323,
                                    0.7923902941127229,
                                    0.006495663463604257,
                                    0.0300970053686997,
                                ],
                                [
                                    0.303541337867474,
                                    0.10473670759826194,
                                    0.43992586846054343,
                                    0.15179608607372055,
                                ],
                                [
                                    0.303541337867474,
                                    0.43992586846054343,
                                    0.10473670759826194,
                                    0.15179608607372055,
                                ],
                                [
                                    0.17101703705497323,
                                    0.006495663463604257,
                                    0.7923902941127229,
                                    0.0300970053686997,
                                ],
                                [
                                    0.39333806215650796,
                                    0.570069269011188,
                                    0.014939983309228015,
                                    0.02165268552307594,
                                ],
                                [
                                    0.39333806215650796,
                                    0.014939983309228015,
                                    0.570069269011188,
                                    0.02165268552307594,
                                ],
                                [
                                    0.05756438325951067,
                                    0.4413353390769777,
                                    0.057818289214068584,
                                    0.44328198844944305,
                                ],
                                [
                                    0.05756438325951067,
                                    0.057818289214068584,
                                    0.4413353390769777,
                                    0.44328198844944305,
                                ],
                                [
                                    0.11254941446943031,
                                    0.862895269351724,
                                    0.002833258004148925,
                                    0.021722058174696687,
                                ],
                                [
                                    0.3070142444277549,
                                    0.30836842804582437,
                                    0.19188547790873353,
                                    0.19273184961768722,
                                ],
                                [
                                    0.3070142444277549,
                                    0.19188547790873353,
                                    0.30836842804582437,
                                    0.19273184961768722,
                                ],
                                [
                                    0.11254941446943031,
                                    0.002833258004148925,
                                    0.862895269351724,
                                    0.021722058174696687,
                                ],
                                [
                                    0.6002717563800075,
                                    0.37517292744114683,
                                    0.01511091609357173,
                                    0.009444400085273882,
                                ],
                                [
                                    0.6002717563800075,
                                    0.01511091609357173,
                                    0.37517292744114683,
                                    0.009444400085273882,
                                ],
                                [
                                    0.013543864255309243,
                                    0.2407883740896502,
                                    0.03970878017327178,
                                    0.7059589814817688,
                                ],
                                [
                                    0.013543864255309243,
                                    0.03970878017327178,
                                    0.2407883740896502,
                                    0.7059589814817688,
                                ],
                                [
                                    0.052586029767993626,
                                    0.9348960067066191,
                                    0.0006666146605873951,
                                    0.011851348864799879,
                                ],
                                [
                                    0.2091850358874112,
                                    0.6133022635940113,
                                    0.04514720245754825,
                                    0.1323654980610292,
                                ],
                                [
                                    0.2091850358874112,
                                    0.04514720245754825,
                                    0.6133022635940113,
                                    0.1323654980610292,
                                ],
                                [
                                    0.052586029767993626,
                                    0.0006666146605873951,
                                    0.9348960067066191,
                                    0.011851348864799879,
                                ],
                                [
                                    0.8121914334664198,
                                    0.1752906030081929,
                                    0.010295866015002725,
                                    0.0022220975103845473,
                                ],
                                [
                                    0.8121914334664198,
                                    0.010295866015002725,
                                    0.1752906030081929,
                                    0.0022220975103845473,
                                ],
                                [
                                    0.0009452767991122258,
                                    0.08637643950105516,
                                    0.009879943308367656,
                                    0.902798340391465,
                                ],
                                [
                                    0.0009452767991122258,
                                    0.009879943308367656,
                                    0.08637643950105516,
                                    0.902798340391465,
                                ],
                                [
                                    0.010778694584134186,
                                    0.9849234229817203,
                                    4.652552334569659e-05,
                                    0.004251356910799817,
                                ],
                                [
                                    0.08417072466118862,
                                    0.8797444184156232,
                                    0.003150991638978769,
                                    0.032933865284209406,
                                ],
                                [
                                    0.08417072466118862,
                                    0.003150991638978769,
                                    0.8797444184156232,
                                    0.032933865284209406,
                                ],
                                [
                                    0.010778694584134186,
                                    4.652552334569659e-05,
                                    0.9849234229817203,
                                    0.004251356910799817,
                                ],
                                [
                                    0.9597723491153751,
                                    0.03592976845047935,
                                    0.004142793961436689,
                                    0.0001550884727088246,
                                ],
                                [
                                    0.9597723491153751,
                                    0.004142793961436689,
                                    0.03592976845047935,
                                    0.0001550884727088246,
                                ],
                                [
                                    0.04070702375736938,
                                    0.8697707046154401,
                                    0.004002497946275464,
                                    0.08551977368091507,
                                ],
                                [
                                    0.04070702375736938,
                                    0.004002497946275464,
                                    0.8697707046154401,
                                    0.08551977368091507,
                                ],
                                [
                                    0.042705965088338065,
                                    0.9124812849881163,
                                    0.0020035566153067757,
                                    0.042809193308238944,
                                ],
                                [
                                    0.08341760413004555,
                                    0.008201994604267362,
                                    0.827060124242764,
                                    0.08132027702292317,
                                ],
                                [
                                    0.08341760413004555,
                                    0.827060124242764,
                                    0.008201994604267362,
                                    0.08132027702292317,
                                ],
                                [
                                    0.042705965088338065,
                                    0.0020035566153067757,
                                    0.9124812849881163,
                                    0.042809193308238944,
                                ],
                                [
                                    0.08751387256813654,
                                    0.8676733775083177,
                                    0.00410572616617637,
                                    0.04070702375736935,
                                ],
                                [
                                    0.08751387256813654,
                                    0.00410572616617637,
                                    0.8676733775083177,
                                    0.04070702375736935,
                                ],
                                [
                                    0.026827907767428945,
                                    0.7166392985605885,
                                    0.009256949155759246,
                                    0.24727584451622325,
                                ],
                                [
                                    0.026827907767428945,
                                    0.009256949155759246,
                                    0.7166392985605885,
                                    0.24727584451622325,
                                ],
                                [
                                    0.034764415703936895,
                                    0.9286429154637592,
                                    0.0013204412192512963,
                                    0.03527222761305266,
                                ],
                                [
                                    0.19839437409261415,
                                    0.06845582777773253,
                                    0.5450728322354033,
                                    0.18807696589424996,
                                ],
                                [
                                    0.19839437409261415,
                                    0.5450728322354033,
                                    0.06845582777773253,
                                    0.18807696589424996,
                                ],
                                [
                                    0.034764415703936895,
                                    0.0013204412192512963,
                                    0.9286429154637592,
                                    0.03527222761305266,
                                ],
                                [
                                    0.25708544080547163,
                                    0.7063218903622244,
                                    0.009764761064875055,
                                    0.026827907767428903,
                                ],
                                [
                                    0.25708544080547163,
                                    0.009764761064875055,
                                    0.7063218903622244,
                                    0.026827907767428903,
                                ],
                                [
                                    0.011701712202691792,
                                    0.4871980101337966,
                                    0.011753326312642245,
                                    0.48934695135086936,
                                ],
                                [
                                    0.011701712202691792,
                                    0.011753326312642245,
                                    0.4871980101337966,
                                    0.48934695135086936,
                                ],
                                [
                                    0.022879092628603007,
                                    0.9525655911925514,
                                    0.0005759458867310289,
                                    0.023979370292114582,
                                ],
                                [
                                    0.261151573370936,
                                    0.26230346514439806,
                                    0.2377481489655524,
                                    0.23879681251911355,
                                ],
                                [
                                    0.261151573370936,
                                    0.2377481489655524,
                                    0.26230346514439806,
                                    0.23879681251911355,
                                ],
                                [
                                    0.022879092628603007,
                                    0.0005759458867310289,
                                    0.9525655911925514,
                                    0.023979370292114582,
                                ],
                                [
                                    0.5106014345391802,
                                    0.4648432492819742,
                                    0.012853603976153835,
                                    0.011701712202691778,
                                ],
                                [
                                    0.5106014345391802,
                                    0.012853603976153835,
                                    0.4648432492819742,
                                    0.011701712202691778,
                                ],
                                [
                                    0.002753202460512221,
                                    0.25157903588444724,
                                    0.008072017646967663,
                                    0.7375957440080729,
                                ],
                                [
                                    0.002753202460512221,
                                    0.008072017646967663,
                                    0.25157903588444724,
                                    0.7375957440080729,
                                ],
                                [
                                    0.010689710397020161,
                                    0.9767923260775926,
                                    0.00013550971045972208,
                                    0.012382453814927552,
                                ],
                                [
                                    0.19839437409261415,
                                    0.5816655010677072,
                                    0.055937864252345273,
                                    0.16400226058733333,
                                ],
                                [
                                    0.19839437409261415,
                                    0.055937864252345273,
                                    0.5816655010677072,
                                    0.16400226058733333,
                                ],
                                [
                                    0.010689710397020161,
                                    0.00013550971045972208,
                                    0.9767923260775926,
                                    0.012382453814927552,
                                ],
                                [
                                    0.7702951140954464,
                                    0.2171869223791664,
                                    0.009764761064875054,
                                    0.0027532024605122205,
                                ],
                                [
                                    0.7702951140954464,
                                    0.009764761064875054,
                                    0.2171869223791664,
                                    0.0027532024605122205,
                                ],
                                [
                                    0.00019215626796914497,
                                    0.08712956003219824,
                                    0.00200839905905409,
                                    0.9106698846407785,
                                ],
                                [
                                    0.00019215626796914497,
                                    0.00200839905905409,
                                    0.08712956003219824,
                                    0.9106698846407785,
                                ],
                                [
                                    0.0021910975989378563,
                                    0.9935110199669166,
                                    9.457728085378496e-06,
                                    0.004288424706060135,
                                ],
                                [
                                    0.08341760413004554,
                                    0.8718728741663097,
                                    0.0039041121701218527,
                                    0.040805409533523004,
                                ],
                                [
                                    0.08341760413004554,
                                    0.0039041121701218527,
                                    0.8718728741663097,
                                    0.040805409533523004,
                                ],
                                [
                                    0.0021910975989378563,
                                    9.457728085378496e-06,
                                    0.9935110199669166,
                                    0.004288424706060135,
                                ],
                                [
                                    0.9511847521301787,
                                    0.044517365435675714,
                                    0.00410572616617637,
                                    0.00019215626796914283,
                                ],
                                [
                                    0.9511847521301787,
                                    0.00410572616617637,
                                    0.044517365435675714,
                                    0.00019215626796914283,
                                ],
                                [
                                    0.6675165627580707,
                                    0.06732597878949012,
                                    0.2408638385076165,
                                    0.024293619944822705,
                                ],
                                [
                                    0.6675165627580707,
                                    0.2408638385076165,
                                    0.06732597878949012,
                                    0.024293619944822705,
                                ],
                                [
                                    0.7081298160236246,
                                    0.07142224722758111,
                                    0.20025058524206266,
                                    0.020197351506731714,
                                ],
                                [
                                    0.7019880829874786,
                                    0.25330239530887655,
                                    0.032854458560082185,
                                    0.011855063143562628,
                                ],
                                [
                                    0.7019880829874786,
                                    0.032854458560082185,
                                    0.25330239530887655,
                                    0.011855063143562628,
                                ],
                                [
                                    0.7081298160236246,
                                    0.20025058524206266,
                                    0.07142224722758111,
                                    0.020197351506731714,
                                ],
                                [
                                    0.7446986633601548,
                                    0.03485339989105087,
                                    0.2105918149362004,
                                    0.00985612181259394,
                                ],
                                [
                                    0.7446986633601548,
                                    0.2105918149362004,
                                    0.03485339989105087,
                                    0.00985612181259394,
                                ],
                                [
                                    0.4399258684605435,
                                    0.16012322052896896,
                                    0.29322392966910993,
                                    0.10672698134137762,
                                ],
                                [
                                    0.4399258684605435,
                                    0.29322392966910993,
                                    0.16012322052896896,
                                    0.10672698134137762,
                                ],
                                [
                                    0.6011749265873647,
                                    0.21881428724182644,
                                    0.13197487154228876,
                                    0.04803591462852016,
                                ],
                                [
                                    0.5783964034664365,
                                    0.3855187396103753,
                                    0.02165268552307594,
                                    0.014432171400112192,
                                ],
                                [
                                    0.5783964034664365,
                                    0.02165268552307594,
                                    0.3855187396103753,
                                    0.014432171400112192,
                                ],
                                [
                                    0.6011749265873647,
                                    0.13197487154228876,
                                    0.21881428724182644,
                                    0.04803591462852016,
                                ],
                                [
                                    0.7904000203696072,
                                    0.029589193459583885,
                                    0.17351512270720468,
                                    0.0064956634636042536,
                                ],
                                [
                                    0.7904000203696072,
                                    0.17351512270720468,
                                    0.029589193459583885,
                                    0.0064956634636042536,
                                ],
                                [
                                    0.19188547790873353,
                                    0.2107742780792813,
                                    0.28465948357593246,
                                    0.3126807604360527,
                                ],
                                [
                                    0.19188547790873353,
                                    0.28465948357593246,
                                    0.2107742780792813,
                                    0.3126807604360527,
                                ],
                                [
                                    0.4189805782251553,
                                    0.46022413924752553,
                                    0.05756438325951065,
                                    0.0632308992678085,
                                ],
                                [
                                    0.3932153559027409,
                                    0.583329605581925,
                                    0.009444400085273882,
                                    0.014010638430060127,
                                ],
                                [
                                    0.3932153559027409,
                                    0.009444400085273882,
                                    0.583329605581925,
                                    0.014010638430060127,
                                ],
                                [
                                    0.4189805782251553,
                                    0.05756438325951065,
                                    0.46022413924752553,
                                    0.0632308992678085,
                                ],
                                [
                                    0.8585829369614957,
                                    0.020621780511185083,
                                    0.11796202452317024,
                                    0.002833258004148924,
                                ],
                                [
                                    0.8585829369614957,
                                    0.11796202452317024,
                                    0.020621780511185083,
                                    0.002833258004148924,
                                ],
                                [
                                    0.045147202457548254,
                                    0.16012322052896907,
                                    0.17479292238213037,
                                    0.6199366546313523,
                                ],
                                [
                                    0.045147202457548254,
                                    0.17479292238213037,
                                    0.16012322052896907,
                                    0.6199366546313523,
                                ],
                                [
                                    0.20639626058436938,
                                    0.7320239605318013,
                                    0.013543864255309249,
                                    0.04803591462852017,
                                ],
                                [
                                    0.20304832547613277,
                                    0.7861264544163874,
                                    0.002222097510384548,
                                    0.008603122597095334,
                                ],
                                [
                                    0.20304832547613277,
                                    0.002222097510384548,
                                    0.7861264544163874,
                                    0.008603122597095334,
                                ],
                                [
                                    0.20639626058436938,
                                    0.013543864255309249,
                                    0.7320239605318013,
                                    0.04803591462852017,
                                ],
                                [
                                    0.9282616156692781,
                                    0.010158605446892488,
                                    0.06091316422324203,
                                    0.0006666146605873954,
                                ],
                                [
                                    0.9282616156692781,
                                    0.06091316422324203,
                                    0.010158605446892488,
                                    0.0006666146605873954,
                                ],
                                [
                                    0.003150991638978766,
                                    0.06732597878949013,
                                    0.041558530064666074,
                                    0.8879644995068651,
                                ],
                                [
                                    0.003150991638978766,
                                    0.041558530064666074,
                                    0.06732597878949013,
                                    0.8879644995068651,
                                ],
                                [
                                    0.04376424490453261,
                                    0.9350931267896234,
                                    0.0009452767991122263,
                                    0.020197351506731735,
                                ],
                                [
                                    0.07032188195576007,
                                    0.9274775627172167,
                                    0.00015508847270882445,
                                    0.002045466854314385,
                                ],
                                [
                                    0.07032188195576007,
                                    0.00015508847270882445,
                                    0.9274775627172167,
                                    0.002045466854314385,
                                ],
                                [
                                    0.04376424490453261,
                                    0.0009452767991122263,
                                    0.9350931267896234,
                                    0.020197351506731735,
                                ],
                                [
                                    0.9767033418904785,
                                    0.002154029803677513,
                                    0.021096102782498263,
                                    4.6525523345696626e-05,
                                ],
                                [
                                    0.9767033418904785,
                                    0.021096102782498263,
                                    0.002154029803677513,
                                    4.6525523345696626e-05,
                                ],
                                [
                                    0.5387496609926756,
                                    0.19609288055488514,
                                    0.19440013713697776,
                                    0.07075732131546143,
                                ],
                                [
                                    0.5387496609926756,
                                    0.19440013713697776,
                                    0.19609288055488514,
                                    0.07075732131546143,
                                ],
                                [
                                    0.5715284378041762,
                                    0.2080236254470294,
                                    0.1616213603254772,
                                    0.05882657642331717,
                                ],
                                [
                                    0.5732211812220835,
                                    0.20683869393823784,
                                    0.1616213603254772,
                                    0.058318764514201364,
                                ],
                                [
                                    0.5732211812220835,
                                    0.1616213603254772,
                                    0.20683869393823784,
                                    0.058318764514201364,
                                ],
                                [
                                    0.5715284378041762,
                                    0.1616213603254772,
                                    0.2080236254470294,
                                    0.05882657642331717,
                                ],
                                [
                                    0.6080972851407064,
                                    0.17145477811049917,
                                    0.17196259001961497,
                                    0.048485346729179396,
                                ],
                                [
                                    0.6080972851407064,
                                    0.17196259001961497,
                                    0.17145477811049917,
                                    0.048485346729179396,
                                ],
                                [
                                    0.3550622197533789,
                                    0.24498686923613355,
                                    0.2366597347808852,
                                    0.16329117622960232,
                                ],
                                [
                                    0.3550622197533789,
                                    0.2366597347808852,
                                    0.24498686923613355,
                                    0.16329117622960232,
                                ],
                                [
                                    0.4852056203040236,
                                    0.3347835935251675,
                                    0.10651633423024054,
                                    0.07349445194056839,
                                ],
                                [
                                    0.493532754759272,
                                    0.32895454472215063,
                                    0.10651633423024053,
                                    0.07099636628833687,
                                ],
                                [
                                    0.493532754759272,
                                    0.10651633423024053,
                                    0.32895454472215063,
                                    0.07099636628833687,
                                ],
                                [
                                    0.4852056203040236,
                                    0.10651633423024054,
                                    0.3347835935251675,
                                    0.07349445194056839,
                                ],
                                [
                                    0.6744307140862662,
                                    0.14555849974292492,
                                    0.14805658539515645,
                                    0.03195420077565248,
                                ],
                                [
                                    0.6744307140862662,
                                    0.14805658539515645,
                                    0.14555849974292492,
                                    0.03195420077565248,
                                ],
                                [
                                    0.15486991925055096,
                                    0.24778983673746388,
                                    0.22974740827586979,
                                    0.3675928357361154,
                                ],
                                [
                                    0.15486991925055096,
                                    0.22974740827586979,
                                    0.24778983673746388,
                                    0.3675928357361154,
                                ],
                                [
                                    0.3381573687829643,
                                    0.5410473486897165,
                                    0.046459958743456445,
                                    0.07433532378386272,
                                ],
                                [
                                    0.3561997972445584,
                                    0.5284175302818623,
                                    0.046459958743456445,
                                    0.06892271373012278,
                                ],
                                [
                                    0.3561997972445584,
                                    0.046459958743456445,
                                    0.5284175302818623,
                                    0.06892271373012278,
                                ],
                                [
                                    0.3381573687829643,
                                    0.046459958743456445,
                                    0.5410473486897165,
                                    0.07433532378386272,
                                ],
                                [
                                    0.7777597275193047,
                                    0.10144498995337609,
                                    0.10685760000711603,
                                    0.013937682520203134,
                                ],
                                [
                                    0.7777597275193047,
                                    0.10685760000711603,
                                    0.10144498995337609,
                                    0.013937682520203134,
                                ],
                                [
                                    0.03643810712092737,
                                    0.16883231586558994,
                                    0.1410745933976501,
                                    0.6536549836158325,
                                ],
                                [
                                    0.03643810712092737,
                                    0.1410745933976501,
                                    0.16883231586558994,
                                    0.6536549836158325,
                                ],
                                [
                                    0.16658150767157207,
                                    0.7718387134445985,
                                    0.010931192847005434,
                                    0.05064858603682399,
                                ],
                                [
                                    0.19433923013951188,
                                    0.752408125431907,
                                    0.010931192847005436,
                                    0.0423214515815756,
                                ],
                                [
                                    0.19433923013951188,
                                    0.010931192847005436,
                                    0.752408125431907,
                                    0.0423214515815756,
                                ],
                                [
                                    0.16658150767157207,
                                    0.010931192847005434,
                                    0.7718387134445985,
                                    0.05064858603682399,
                                ],
                                [
                                    0.8884468627564808,
                                    0.04997335835968983,
                                    0.05830049281493821,
                                    0.003279286068891211,
                                ],
                                [
                                    0.8884468627564808,
                                    0.05830049281493821,
                                    0.04997335835968983,
                                    0.003279286068891211,
                                ],
                                [
                                    0.0025431513942910655,
                                    0.06793381903417783,
                                    0.033541705528897126,
                                    0.895981324042634,
                                ],
                                [
                                    0.0025431513942910655,
                                    0.033541705528897126,
                                    0.06793381903417783,
                                    0.895981324042634,
                                ],
                                [
                                    0.035321928205791664,
                                    0.9435354434883644,
                                    0.0007629287173965281,
                                    0.020379699588447434,
                                ],
                                [
                                    0.06971404171107237,
                                    0.9194607381814477,
                                    0.0007629287173965273,
                                    0.010062291390083366,
                                ],
                                [
                                    0.06971404171107237,
                                    0.0007629287173965273,
                                    0.9194607381814477,
                                    0.010062291390083366,
                                ],
                                [
                                    0.035321928205791664,
                                    0.0007629287173965281,
                                    0.9435354434883644,
                                    0.020379699588447434,
                                ],
                                [
                                    0.9682610251917375,
                                    0.010596346502418497,
                                    0.020913754700782567,
                                    0.0002288736050613956,
                                ],
                                [
                                    0.9682610251917375,
                                    0.020913754700782567,
                                    0.010596346502418497,
                                    0.0002288736050613956,
                                ],
                                [
                                    0.3501855106590764,
                                    0.3846570308884844,
                                    0.12635945082558955,
                                    0.13879800762684966,
                                ],
                                [
                                    0.3501855106590764,
                                    0.12635945082558955,
                                    0.3846570308884844,
                                    0.13879800762684966,
                                ],
                                [
                                    0.37149160795733766,
                                    0.408060455293868,
                                    0.1050533535273283,
                                    0.11539458322146608,
                                ],
                                [
                                    0.3846570308884844,
                                    0.13879800762684966,
                                    0.3501855106590764,
                                    0.12635945082558955,
                                ],
                                [
                                    0.3846570308884844,
                                    0.3501855106590764,
                                    0.13879800762684966,
                                    0.12635945082558955,
                                ],
                                [
                                    0.37149160795733766,
                                    0.1050533535273283,
                                    0.408060455293868,
                                    0.11539458322146608,
                                ],
                                [
                                    0.408060455293868,
                                    0.37149160795733766,
                                    0.11539458322146608,
                                    0.1050533535273283,
                                ],
                                [
                                    0.408060455293868,
                                    0.11539458322146608,
                                    0.37149160795733766,
                                    0.1050533535273283,
                                ],
                                [
                                    0.2307892769918098,
                                    0.3692598119977027,
                                    0.15382805053461107,
                                    0.24612286047587645,
                                ],
                                [
                                    0.2307892769918098,
                                    0.15382805053461107,
                                    0.3692598119977027,
                                    0.24612286047587645,
                                ],
                                [
                                    0.31538206002347435,
                                    0.5046071538057167,
                                    0.06923526750294653,
                                    0.1107755186678624,
                                ],
                                [
                                    0.36925981199770275,
                                    0.24612286047587648,
                                    0.2307892769918097,
                                    0.15382805053461104,
                                ],
                                [
                                    0.36925981199770275,
                                    0.2307892769918097,
                                    0.24612286047587648,
                                    0.15382805053461104,
                                ],
                                [
                                    0.31538206002347435,
                                    0.06923526750294653,
                                    0.5046071538057167,
                                    0.1107755186678624,
                                ],
                                [
                                    0.5046071538057169,
                                    0.31538206002347424,
                                    0.11077551866786242,
                                    0.06923526750294651,
                                ],
                                [
                                    0.5046071538057169,
                                    0.11077551866786242,
                                    0.31538206002347424,
                                    0.06923526750294651,
                                ],
                                [
                                    0.10066493899700371,
                                    0.30199481699101116,
                                    0.1493350610029963,
                                    0.44800518300898884,
                                ],
                                [
                                    0.10066493899700371,
                                    0.1493350610029963,
                                    0.30199481699101116,
                                    0.44800518300898884,
                                ],
                                [
                                    0.2198011793681702,
                                    0.6594035381045106,
                                    0.03019882063182979,
                                    0.09059646189548937,
                                ],
                                [
                                    0.30199481699101116,
                                    0.44800518300898884,
                                    0.10066493899700371,
                                    0.1493350610029963,
                                ],
                                [
                                    0.30199481699101116,
                                    0.10066493899700371,
                                    0.44800518300898884,
                                    0.1493350610029963,
                                ],
                                [
                                    0.2198011793681702,
                                    0.03019882063182979,
                                    0.6594035381045106,
                                    0.09059646189548937,
                                ],
                                [
                                    0.6594035381045106,
                                    0.2198011793681702,
                                    0.09059646189548937,
                                    0.03019882063182979,
                                ],
                                [
                                    0.6594035381045106,
                                    0.09059646189548937,
                                    0.2198011793681702,
                                    0.03019882063182979,
                                ],
                                [
                                    0.0236846499839664,
                                    0.1815857730025509,
                                    0.09169802248961285,
                                    0.7030315545238698,
                                ],
                                [
                                    0.0236846499839664,
                                    0.09169802248961285,
                                    0.1815857730025509,
                                    0.7030315545238698,
                                ],
                                [
                                    0.10827743301563093,
                                    0.8301427881005397,
                                    0.007105239457948322,
                                    0.0544745394258811,
                                ],
                                [
                                    0.1815857730025509,
                                    0.7030315545238698,
                                    0.0236846499839664,
                                    0.09169802248961285,
                                ],
                                [
                                    0.1815857730025509,
                                    0.0236846499839664,
                                    0.7030315545238698,
                                    0.09169802248961285,
                                ],
                                [
                                    0.10827743301563093,
                                    0.007105239457948322,
                                    0.8301427881005397,
                                    0.0544745394258811,
                                ],
                                [
                                    0.8301427881005397,
                                    0.10827743301563093,
                                    0.0544745394258811,
                                    0.007105239457948322,
                                ],
                                [
                                    0.8301427881005397,
                                    0.0544745394258811,
                                    0.10827743301563093,
                                    0.007105239457948322,
                                ],
                                [
                                    0.0016530400558437959,
                                    0.0688239303726251,
                                    0.02180199845949024,
                                    0.9077210311120408,
                                ],
                                [
                                    0.0016530400558437959,
                                    0.02180199845949024,
                                    0.0688239303726251,
                                    0.9077210311120408,
                                ],
                                [
                                    0.022959137354105073,
                                    0.955898234340051,
                                    0.0004959011612289617,
                                    0.020646727144615,
                                ],
                                [
                                    0.0688239303726251,
                                    0.9077210311120408,
                                    0.0016530400558437959,
                                    0.02180199845949024,
                                ],
                                [
                                    0.0688239303726251,
                                    0.0016530400558437959,
                                    0.9077210311120408,
                                    0.02180199845949024,
                                ],
                                [
                                    0.022959137354105073,
                                    0.0004959011612289617,
                                    0.955898234340051,
                                    0.020646727144615,
                                ],
                                [
                                    0.955898234340051,
                                    0.022959137354105073,
                                    0.020646727144615,
                                    0.0004959011612289617,
                                ],
                                [
                                    0.955898234340051,
                                    0.020646727144615,
                                    0.022959137354105073,
                                    0.0004959011612289617,
                                ],
                                [
                                    0.16162136032547725,
                                    0.5732211812220835,
                                    0.05831876451420138,
                                    0.20683869393823784,
                                ],
                                [
                                    0.16162136032547725,
                                    0.05831876451420138,
                                    0.5732211812220835,
                                    0.20683869393823784,
                                ],
                                [
                                    0.17145477811049922,
                                    0.6080972851407064,
                                    0.04848534672917941,
                                    0.17196259001961497,
                                ],
                                [
                                    0.19609288055488522,
                                    0.07075732131546147,
                                    0.5387496609926755,
                                    0.19440013713697774,
                                ],
                                [
                                    0.19609288055488522,
                                    0.5387496609926755,
                                    0.07075732131546147,
                                    0.19440013713697774,
                                ],
                                [
                                    0.17145477811049922,
                                    0.04848534672917941,
                                    0.6080972851407064,
                                    0.17196259001961497,
                                ],
                                [
                                    0.2080236254470295,
                                    0.5715284378041762,
                                    0.0588265764233172,
                                    0.16162136032547716,
                                ],
                                [
                                    0.2080236254470295,
                                    0.0588265764233172,
                                    0.5715284378041762,
                                    0.16162136032547716,
                                ],
                                [
                                    0.10651633423024058,
                                    0.4935327547592719,
                                    0.0709963662883369,
                                    0.32895454472215063,
                                ],
                                [
                                    0.10651633423024058,
                                    0.0709963662883369,
                                    0.4935327547592719,
                                    0.32895454472215063,
                                ],
                                [
                                    0.14555849974292498,
                                    0.6744307140862661,
                                    0.031954200775652496,
                                    0.14805658539515643,
                                ],
                                [
                                    0.24498686923613364,
                                    0.16329117622960235,
                                    0.35506221975337887,
                                    0.23665973478088517,
                                ],
                                [
                                    0.24498686923613364,
                                    0.35506221975337887,
                                    0.16329117622960235,
                                    0.23665973478088517,
                                ],
                                [
                                    0.14555849974292498,
                                    0.031954200775652496,
                                    0.6744307140862661,
                                    0.14805658539515643,
                                ],
                                [
                                    0.33478359352516757,
                                    0.48520562030402353,
                                    0.0734944519405684,
                                    0.10651633423024053,
                                ],
                                [
                                    0.33478359352516757,
                                    0.0734944519405684,
                                    0.48520562030402353,
                                    0.10651633423024053,
                                ],
                                [
                                    0.04645995874345646,
                                    0.3561997972445584,
                                    0.06892271373012279,
                                    0.5284175302818623,
                                ],
                                [
                                    0.04645995874345646,
                                    0.06892271373012279,
                                    0.3561997972445584,
                                    0.5284175302818623,
                                ],
                                [
                                    0.10144498995337611,
                                    0.7777597275193047,
                                    0.013937682520203137,
                                    0.10685760000711603,
                                ],
                                [
                                    0.24778983673746388,
                                    0.3675928357361154,
                                    0.15486991925055096,
                                    0.22974740827586979,
                                ],
                                [
                                    0.24778983673746388,
                                    0.15486991925055096,
                                    0.3675928357361154,
                                    0.22974740827586979,
                                ],
                                [
                                    0.10144498995337611,
                                    0.013937682520203137,
                                    0.7777597275193047,
                                    0.10685760000711603,
                                ],
                                [
                                    0.5410473486897165,
                                    0.3381573687829643,
                                    0.07433532378386272,
                                    0.046459958743456445,
                                ],
                                [
                                    0.5410473486897165,
                                    0.07433532378386272,
                                    0.3381573687829643,
                                    0.046459958743456445,
                                ],
                                [
                                    0.01093119284700543,
                                    0.19433923013951188,
                                    0.04232145158157559,
                                    0.752408125431907,
                                ],
                                [
                                    0.01093119284700543,
                                    0.04232145158157559,
                                    0.19433923013951188,
                                    0.752408125431907,
                                ],
                                [
                                    0.049973358359689815,
                                    0.8884468627564808,
                                    0.0032792860688912098,
                                    0.05830049281493821,
                                ],
                                [
                                    0.16883231586558994,
                                    0.6536549836158325,
                                    0.03643810712092737,
                                    0.14107459339765008,
                                ],
                                [
                                    0.16883231586558994,
                                    0.03643810712092737,
                                    0.6536549836158325,
                                    0.14107459339765008,
                                ],
                                [
                                    0.049973358359689815,
                                    0.0032792860688912098,
                                    0.8884468627564808,
                                    0.05830049281493821,
                                ],
                                [
                                    0.7718387134445985,
                                    0.16658150767157204,
                                    0.05064858603682399,
                                    0.010931192847005432,
                                ],
                                [
                                    0.7718387134445985,
                                    0.05064858603682399,
                                    0.16658150767157204,
                                    0.010931192847005432,
                                ],
                                [
                                    0.0007629287173965266,
                                    0.06971404171107237,
                                    0.010062291390083355,
                                    0.9194607381814477,
                                ],
                                [
                                    0.0007629287173965266,
                                    0.010062291390083355,
                                    0.06971404171107237,
                                    0.9194607381814477,
                                ],
                                [
                                    0.010596346502418487,
                                    0.9682610251917375,
                                    0.00022887360506139537,
                                    0.020913754700782567,
                                ],
                                [
                                    0.06793381903417783,
                                    0.895981324042634,
                                    0.002543151394291064,
                                    0.03354170552889711,
                                ],
                                [
                                    0.06793381903417783,
                                    0.002543151394291064,
                                    0.895981324042634,
                                    0.03354170552889711,
                                ],
                                [
                                    0.010596346502418487,
                                    0.00022887360506139537,
                                    0.9682610251917375,
                                    0.020913754700782567,
                                ],
                                [
                                    0.9435354434883644,
                                    0.03532192820579165,
                                    0.020379699588447434,
                                    0.0007629287173965278,
                                ],
                                [
                                    0.9435354434883644,
                                    0.020379699588447434,
                                    0.03532192820579165,
                                    0.0007629287173965278,
                                ],
                                [
                                    0.032854458560082206,
                                    0.7019880829874786,
                                    0.011855063143562635,
                                    0.25330239530887655,
                                ],
                                [
                                    0.032854458560082206,
                                    0.011855063143562635,
                                    0.7019880829874786,
                                    0.25330239530887655,
                                ],
                                [
                                    0.03485339989105089,
                                    0.7446986633601548,
                                    0.009856121812593946,
                                    0.2105918149362004,
                                ],
                                [
                                    0.06732597878949019,
                                    0.02429361994482273,
                                    0.6675165627580706,
                                    0.24086383850761647,
                                ],
                                [
                                    0.06732597878949019,
                                    0.6675165627580706,
                                    0.02429361994482273,
                                    0.24086383850761647,
                                ],
                                [
                                    0.03485339989105089,
                                    0.009856121812593946,
                                    0.7446986633601548,
                                    0.2105918149362004,
                                ],
                                [
                                    0.07142224722758118,
                                    0.7081298160236245,
                                    0.020197351506731735,
                                    0.20025058524206263,
                                ],
                                [
                                    0.07142224722758118,
                                    0.020197351506731735,
                                    0.7081298160236245,
                                    0.20025058524206263,
                                ],
                                [
                                    0.021652685523075976,
                                    0.5783964034664365,
                                    0.014432171400112215,
                                    0.3855187396103753,
                                ],
                                [
                                    0.021652685523075976,
                                    0.014432171400112215,
                                    0.5783964034664365,
                                    0.3855187396103753,
                                ],
                                [
                                    0.02958919345958393,
                                    0.7904000203696072,
                                    0.006495663463604264,
                                    0.17351512270720468,
                                ],
                                [
                                    0.16012322052896905,
                                    0.10672698134137766,
                                    0.43992586846054343,
                                    0.2932239296691099,
                                ],
                                [
                                    0.16012322052896905,
                                    0.43992586846054343,
                                    0.10672698134137766,
                                    0.2932239296691099,
                                ],
                                [
                                    0.02958919345958393,
                                    0.006495663463604264,
                                    0.7904000203696072,
                                    0.17351512270720468,
                                ],
                                [
                                    0.21881428724182653,
                                    0.6011749265873646,
                                    0.04803591462852017,
                                    0.13197487154228876,
                                ],
                                [
                                    0.21881428724182653,
                                    0.04803591462852017,
                                    0.6011749265873646,
                                    0.13197487154228876,
                                ],
                                [
                                    0.009444400085273892,
                                    0.3932153559027409,
                                    0.014010638430060144,
                                    0.583329605581925,
                                ],
                                [
                                    0.009444400085273892,
                                    0.014010638430060144,
                                    0.3932153559027409,
                                    0.583329605581925,
                                ],
                                [
                                    0.020621780511185107,
                                    0.8585829369614957,
                                    0.0028332580041489277,
                                    0.11796202452317024,
                                ],
                                [
                                    0.2107742780792813,
                                    0.3126807604360527,
                                    0.19188547790873353,
                                    0.28465948357593246,
                                ],
                                [
                                    0.2107742780792813,
                                    0.19188547790873353,
                                    0.3126807604360527,
                                    0.28465948357593246,
                                ],
                                [
                                    0.020621780511185107,
                                    0.0028332580041489277,
                                    0.8585829369614957,
                                    0.11796202452317024,
                                ],
                                [
                                    0.46022413924752553,
                                    0.4189805782251553,
                                    0.0632308992678085,
                                    0.05756438325951065,
                                ],
                                [
                                    0.46022413924752553,
                                    0.0632308992678085,
                                    0.4189805782251553,
                                    0.05756438325951065,
                                ],
                                [
                                    0.002222097510384548,
                                    0.20304832547613277,
                                    0.008603122597095334,
                                    0.7861264544163874,
                                ],
                                [
                                    0.002222097510384548,
                                    0.008603122597095334,
                                    0.20304832547613277,
                                    0.7861264544163874,
                                ],
                                [
                                    0.010158605446892488,
                                    0.9282616156692781,
                                    0.0006666146605873954,
                                    0.06091316422324203,
                                ],
                                [
                                    0.16012322052896907,
                                    0.6199366546313523,
                                    0.045147202457548254,
                                    0.17479292238213037,
                                ],
                                [
                                    0.16012322052896907,
                                    0.045147202457548254,
                                    0.6199366546313523,
                                    0.17479292238213037,
                                ],
                                [
                                    0.010158605446892488,
                                    0.0006666146605873954,
                                    0.9282616156692781,
                                    0.06091316422324203,
                                ],
                                [
                                    0.7320239605318013,
                                    0.20639626058436938,
                                    0.04803591462852017,
                                    0.013543864255309249,
                                ],
                                [
                                    0.7320239605318013,
                                    0.04803591462852017,
                                    0.20639626058436938,
                                    0.013543864255309249,
                                ],
                                [
                                    0.00015508847270882621,
                                    0.07032188195576007,
                                    0.0020454668543144084,
                                    0.9274775627172167,
                                ],
                                [
                                    0.00015508847270882621,
                                    0.0020454668543144084,
                                    0.07032188195576007,
                                    0.9274775627172167,
                                ],
                                [
                                    0.0021540298036775373,
                                    0.9767033418904785,
                                    4.652552334569716e-05,
                                    0.021096102782498263,
                                ],
                                [
                                    0.06732597878949013,
                                    0.8879644995068651,
                                    0.003150991638978767,
                                    0.041558530064666095,
                                ],
                                [
                                    0.06732597878949013,
                                    0.003150991638978767,
                                    0.8879644995068651,
                                    0.041558530064666095,
                                ],
                                [
                                    0.0021540298036775373,
                                    4.652552334569716e-05,
                                    0.9767033418904785,
                                    0.021096102782498263,
                                ],
                                [
                                    0.9350931267896234,
                                    0.04376424490453263,
                                    0.020197351506731735,
                                    0.0009452767991122268,
                                ],
                                [
                                    0.9350931267896234,
                                    0.020197351506731735,
                                    0.04376424490453263,
                                    0.0009452767991122268,
                                ],
                                [
                                    0.43388357400006666,
                                    0.04376166514811092,
                                    0.47449682726562054,
                                    0.04785793358620191,
                                ],
                                [
                                    0.43388357400006666,
                                    0.47449682726562054,
                                    0.04376166514811092,
                                    0.04785793358620191,
                                ],
                                [
                                    0.47449682726562054,
                                    0.04785793358620191,
                                    0.43388357400006666,
                                    0.04376166514811092,
                                ],
                                [
                                    0.4562899489618395,
                                    0.49900052933451566,
                                    0.021355290186338062,
                                    0.02335423151730675,
                                ],
                                [
                                    0.4562899489618395,
                                    0.021355290186338062,
                                    0.49900052933451566,
                                    0.02335423151730675,
                                ],
                                [
                                    0.47449682726562054,
                                    0.43388357400006666,
                                    0.04785793358620191,
                                    0.04376166514811092,
                                ],
                                [
                                    0.49900052933451566,
                                    0.02335423151730675,
                                    0.4562899489618395,
                                    0.021355290186338062,
                                ],
                                [
                                    0.49900052933451566,
                                    0.4562899489618395,
                                    0.02335423151730675,
                                    0.021355290186338062,
                                ],
                                [
                                    0.2859503700014162,
                                    0.10407956757874459,
                                    0.4471994281282372,
                                    0.162770634291602,
                                ],
                                [
                                    0.2859503700014162,
                                    0.4471994281282372,
                                    0.10407956757874459,
                                    0.162770634291602,
                                ],
                                [
                                    0.44719942812823726,
                                    0.16277063429160202,
                                    0.28595037000141615,
                                    0.10407956757874455,
                                ],
                                [
                                    0.37595576308682066,
                                    0.5879593799899911,
                                    0.014074174493340101,
                                    0.022010682429848032,
                                ],
                                [
                                    0.37595576308682066,
                                    0.014074174493340101,
                                    0.5879593799899911,
                                    0.022010682429848032,
                                ],
                                [
                                    0.44719942812823726,
                                    0.28595037000141615,
                                    0.16277063429160202,
                                    0.10407956757874455,
                                ],
                                [
                                    0.5879593799899913,
                                    0.02201068242984804,
                                    0.37595576308682055,
                                    0.014074174493340098,
                                ],
                                [
                                    0.5879593799899913,
                                    0.37595576308682055,
                                    0.02201068242984804,
                                    0.014074174493340098,
                                ],
                                [
                                    0.1247249305841221,
                                    0.13700258867354492,
                                    0.35182003090054387,
                                    0.3864524498417891,
                                ],
                                [
                                    0.1247249305841221,
                                    0.35182003090054387,
                                    0.13700258867354492,
                                    0.3864524498417891,
                                ],
                                [
                                    0.35182003090054387,
                                    0.3864524498417891,
                                    0.1247249305841221,
                                    0.13700258867354492,
                                ],
                                [
                                    0.2555886902129556,
                                    0.7209562712717104,
                                    0.006138829044711403,
                                    0.017316209470622606,
                                ],
                                [
                                    0.2555886902129556,
                                    0.006138829044711403,
                                    0.7209562712717104,
                                    0.017316209470622606,
                                ],
                                [
                                    0.35182003090054387,
                                    0.1247249305841221,
                                    0.3864524498417891,
                                    0.13700258867354492,
                                ],
                                [
                                    0.7209562712717104,
                                    0.017316209470622606,
                                    0.2555886902129556,
                                    0.006138829044711403,
                                ],
                                [
                                    0.7209562712717104,
                                    0.2555886902129556,
                                    0.017316209470622606,
                                    0.006138829044711403,
                                ],
                                [
                                    0.029345533356428748,
                                    0.1040795675787446,
                                    0.19059459148324986,
                                    0.6759803075815768,
                                ],
                                [
                                    0.029345533356428748,
                                    0.19059459148324986,
                                    0.1040795675787446,
                                    0.6759803075815768,
                                ],
                                [
                                    0.19059459148324986,
                                    0.6759803075815768,
                                    0.029345533356428748,
                                    0.1040795675787446,
                                ],
                                [
                                    0.1319807448496874,
                                    0.8571940350428328,
                                    0.0014443560854859713,
                                    0.009380864021993911,
                                ],
                                [
                                    0.1319807448496874,
                                    0.0014443560854859713,
                                    0.8571940350428328,
                                    0.009380864021993911,
                                ],
                                [
                                    0.19059459148324986,
                                    0.029345533356428748,
                                    0.6759803075815768,
                                    0.1040795675787446,
                                ],
                                [
                                    0.8571940350428328,
                                    0.009380864021993911,
                                    0.1319807448496874,
                                    0.0014443560854859713,
                                ],
                                [
                                    0.8571940350428328,
                                    0.1319807448496874,
                                    0.009380864021993911,
                                    0.0014443560854859713,
                                ],
                                [
                                    0.002048134219045497,
                                    0.04376166514811096,
                                    0.04266138748459934,
                                    0.9115288131482442,
                                ],
                                [
                                    0.002048134219045497,
                                    0.04266138748459934,
                                    0.04376166514811096,
                                    0.9115288131482442,
                                ],
                                [
                                    0.04266138748459934,
                                    0.9115288131482442,
                                    0.002048134219045497,
                                    0.04376166514811096,
                                ],
                                [
                                    0.045708992369129196,
                                    0.9520904523038476,
                                    0.00010080699802726059,
                                    0.002099748328995949,
                                ],
                                [
                                    0.045708992369129196,
                                    0.00010080699802726059,
                                    0.9520904523038476,
                                    0.002099748328995949,
                                ],
                                [
                                    0.04266138748459934,
                                    0.002048134219045497,
                                    0.9115288131482442,
                                    0.04376166514811096,
                                ],
                                [
                                    0.9520904523038476,
                                    0.002099748328995949,
                                    0.045708992369129196,
                                    0.00010080699802726059,
                                ],
                                [
                                    0.9520904523038476,
                                    0.045708992369129196,
                                    0.002099748328995949,
                                    0.00010080699802726059,
                                ],
                                [
                                    0.35018551065907644,
                                    0.12745972848910117,
                                    0.382964287470577,
                                    0.1393904733812454,
                                ],
                                [
                                    0.35018551065907644,
                                    0.382964287470577,
                                    0.12745972848910117,
                                    0.1393904733812454,
                                ],
                                [
                                    0.382964287470577,
                                    0.1393904733812454,
                                    0.35018551065907644,
                                    0.12745972848910117,
                                ],
                                [
                                    0.3725918856208493,
                                    0.4074679895394721,
                                    0.1050533535273283,
                                    0.11488677131235027,
                                ],
                                [
                                    0.3725918856208493,
                                    0.1050533535273283,
                                    0.4074679895394721,
                                    0.11488677131235027,
                                ],
                                [
                                    0.382964287470577,
                                    0.35018551065907644,
                                    0.1393904733812454,
                                    0.12745972848910117,
                                ],
                                [
                                    0.4074679895394721,
                                    0.11488677131235027,
                                    0.3725918856208493,
                                    0.1050533535273283,
                                ],
                                [
                                    0.4074679895394721,
                                    0.3725918856208493,
                                    0.11488677131235027,
                                    0.1050533535273283,
                                ],
                                [
                                    0.2307892769918098,
                                    0.159240660588351,
                                    0.36093267754245434,
                                    0.24903738487738486,
                                ],
                                [
                                    0.2307892769918098,
                                    0.36093267754245434,
                                    0.159240660588351,
                                    0.24903738487738486,
                                ],
                                [
                                    0.3609326775424544,
                                    0.24903738487738492,
                                    0.23078927699180973,
                                    0.15924066058835096,
                                ],
                                [
                                    0.3207946700772143,
                                    0.5016926294042083,
                                    0.06923526750294652,
                                    0.10827743301563088,
                                ],
                                [
                                    0.3207946700772143,
                                    0.06923526750294652,
                                    0.5016926294042083,
                                    0.10827743301563088,
                                ],
                                [
                                    0.3609326775424544,
                                    0.23078927699180973,
                                    0.24903738487738492,
                                    0.15924066058835096,
                                ],
                                [
                                    0.5016926294042084,
                                    0.10827743301563089,
                                    0.3207946700772142,
                                    0.06923526750294651,
                                ],
                                [
                                    0.5016926294042084,
                                    0.3207946700772142,
                                    0.10827743301563089,
                                    0.06923526750294651,
                                ],
                                [
                                    0.10066493899700371,
                                    0.1610625802606633,
                                    0.28395238852941707,
                                    0.4543200922129159,
                                ],
                                [
                                    0.10066493899700371,
                                    0.28395238852941707,
                                    0.1610625802606633,
                                    0.4543200922129159,
                                ],
                                [
                                    0.28395238852941707,
                                    0.4543200922129159,
                                    0.10066493899700371,
                                    0.1610625802606633,
                                ],
                                [
                                    0.23152869862583722,
                                    0.6530886289005835,
                                    0.03019882063182979,
                                    0.08518385184174943,
                                ],
                                [
                                    0.23152869862583722,
                                    0.03019882063182979,
                                    0.6530886289005835,
                                    0.08518385184174943,
                                ],
                                [
                                    0.28395238852941707,
                                    0.10066493899700371,
                                    0.4543200922129159,
                                    0.1610625802606633,
                                ],
                                [
                                    0.6530886289005835,
                                    0.08518385184174943,
                                    0.23152869862583722,
                                    0.03019882063182979,
                                ],
                                [
                                    0.6530886289005835,
                                    0.23152869862583722,
                                    0.08518385184174943,
                                    0.03019882063182979,
                                ],
                                [
                                    0.0236846499839664,
                                    0.10974045095120695,
                                    0.15382805053461107,
                                    0.7127468485302155,
                                ],
                                [
                                    0.0236846499839664,
                                    0.15382805053461107,
                                    0.10974045095120695,
                                    0.7127468485302155,
                                ],
                                [
                                    0.15382805053461107,
                                    0.7127468485302155,
                                    0.0236846499839664,
                                    0.10974045095120695,
                                ],
                                [
                                    0.12631986147722502,
                                    0.8204274940941939,
                                    0.007105239457948322,
                                    0.046147404970632716,
                                ],
                                [
                                    0.12631986147722502,
                                    0.007105239457948322,
                                    0.8204274940941939,
                                    0.046147404970632716,
                                ],
                                [
                                    0.15382805053461107,
                                    0.0236846499839664,
                                    0.7127468485302155,
                                    0.10974045095120695,
                                ],
                                [
                                    0.8204274940941939,
                                    0.046147404970632716,
                                    0.12631986147722502,
                                    0.007105239457948322,
                                ],
                                [
                                    0.8204274940941939,
                                    0.12631986147722502,
                                    0.046147404970632716,
                                    0.007105239457948322,
                                ],
                                [
                                    0.0016530400558437976,
                                    0.04415675931131266,
                                    0.034431816867344395,
                                    0.9197583837654991,
                                ],
                                [
                                    0.0016530400558437976,
                                    0.034431816867344395,
                                    0.04415675931131266,
                                    0.9197583837654991,
                                ],
                                [
                                    0.034431816867344395,
                                    0.9197583837654991,
                                    0.0016530400558437976,
                                    0.04415675931131266,
                                ],
                                [
                                    0.045313898205927496,
                                    0.9438608816865927,
                                    0.0004959011612289618,
                                    0.01032931894625093,
                                ],
                                [
                                    0.045313898205927496,
                                    0.0004959011612289618,
                                    0.9438608816865927,
                                    0.01032931894625093,
                                ],
                                [
                                    0.034431816867344395,
                                    0.0016530400558437976,
                                    0.9197583837654991,
                                    0.04415675931131266,
                                ],
                                [
                                    0.9438608816865927,
                                    0.01032931894625093,
                                    0.045313898205927496,
                                    0.0004959011612289618,
                                ],
                                [
                                    0.9438608816865927,
                                    0.045313898205927496,
                                    0.01032931894625093,
                                    0.0004959011612289618,
                                ],
                                [
                                    0.22761943209320235,
                                    0.25002580705497524,
                                    0.24892552939146362,
                                    0.2734292314603588,
                                ],
                                [
                                    0.22761943209320235,
                                    0.24892552939146362,
                                    0.25002580705497524,
                                    0.2734292314603588,
                                ],
                                [
                                    0.24892552939146362,
                                    0.2734292314603588,
                                    0.22761943209320235,
                                    0.25002580705497524,
                                ],
                                [
                                    0.25002580705497524,
                                    0.2734292314603588,
                                    0.22761943209320235,
                                    0.24892552939146362,
                                ],
                                [
                                    0.25002580705497524,
                                    0.22761943209320235,
                                    0.2734292314603588,
                                    0.24892552939146362,
                                ],
                                [
                                    0.24892552939146362,
                                    0.22761943209320235,
                                    0.2734292314603588,
                                    0.25002580705497524,
                                ],
                                [
                                    0.2734292314603588,
                                    0.24892552939146362,
                                    0.25002580705497524,
                                    0.22761943209320235,
                                ],
                                [
                                    0.2734292314603588,
                                    0.25002580705497524,
                                    0.24892552939146362,
                                    0.22761943209320235,
                                ],
                                [
                                    0.1500122722473782,
                                    0.2400176653327826,
                                    0.23460505527904266,
                                    0.3753650071407965,
                                ],
                                [
                                    0.1500122722473782,
                                    0.23460505527904266,
                                    0.2400176653327826,
                                    0.3753650071407965,
                                ],
                                [
                                    0.2346050552790427,
                                    0.3753650071407966,
                                    0.15001227224737815,
                                    0.24001766533278254,
                                ],
                                [
                                    0.24001766533278265,
                                    0.37536500714079657,
                                    0.15001227224737815,
                                    0.2346050552790426,
                                ],
                                [
                                    0.24001766533278265,
                                    0.15001227224737815,
                                    0.37536500714079657,
                                    0.2346050552790426,
                                ],
                                [
                                    0.2346050552790427,
                                    0.15001227224737815,
                                    0.3753650071407966,
                                    0.24001766533278254,
                                ],
                                [
                                    0.3753650071407967,
                                    0.23460505527904266,
                                    0.2400176653327826,
                                    0.1500122722473781,
                                ],
                                [
                                    0.3753650071407967,
                                    0.2400176653327826,
                                    0.23460505527904266,
                                    0.1500122722473781,
                                ],
                                [
                                    0.06543187981441675,
                                    0.19629563944325026,
                                    0.18456812018558325,
                                    0.5537043605567498,
                                ],
                                [
                                    0.06543187981441675,
                                    0.18456812018558325,
                                    0.19629563944325026,
                                    0.5537043605567498,
                                ],
                                [
                                    0.18456812018558325,
                                    0.5537043605567498,
                                    0.06543187981441675,
                                    0.19629563944325026,
                                ],
                                [
                                    0.19629563944325026,
                                    0.5537043605567498,
                                    0.06543187981441675,
                                    0.18456812018558325,
                                ],
                                [
                                    0.19629563944325026,
                                    0.06543187981441675,
                                    0.5537043605567498,
                                    0.18456812018558325,
                                ],
                                [
                                    0.18456812018558325,
                                    0.06543187981441675,
                                    0.5537043605567498,
                                    0.19629563944325026,
                                ],
                                [
                                    0.5537043605567498,
                                    0.18456812018558325,
                                    0.19629563944325026,
                                    0.06543187981441675,
                                ],
                                [
                                    0.5537043605567498,
                                    0.19629563944325026,
                                    0.18456812018558325,
                                    0.06543187981441675,
                                ],
                                [
                                    0.015394944720957359,
                                    0.11803015621421599,
                                    0.0999877277526219,
                                    0.7665871713122048,
                                ],
                                [
                                    0.015394944720957359,
                                    0.0999877277526219,
                                    0.11803015621421599,
                                    0.7665871713122048,
                                ],
                                [
                                    0.0999877277526219,
                                    0.7665871713122048,
                                    0.015394944720957359,
                                    0.11803015621421599,
                                ],
                                [
                                    0.11803015621421599,
                                    0.7665871713122048,
                                    0.015394944720957359,
                                    0.0999877277526219,
                                ],
                                [
                                    0.11803015621421599,
                                    0.015394944720957359,
                                    0.7665871713122048,
                                    0.0999877277526219,
                                ],
                                [
                                    0.0999877277526219,
                                    0.015394944720957359,
                                    0.7665871713122048,
                                    0.11803015621421599,
                                ],
                                [
                                    0.7665871713122048,
                                    0.0999877277526219,
                                    0.11803015621421599,
                                    0.015394944720957359,
                                ],
                                [
                                    0.7665871713122048,
                                    0.11803015621421599,
                                    0.0999877277526219,
                                    0.015394944720957359,
                                ],
                                [
                                    0.0010744706085363794,
                                    0.044735328758620074,
                                    0.02238056790679766,
                                    0.9318096327260459,
                                ],
                                [
                                    0.0010744706085363794,
                                    0.02238056790679766,
                                    0.044735328758620074,
                                    0.9318096327260459,
                                ],
                                [
                                    0.02238056790679766,
                                    0.9318096327260459,
                                    0.0010744706085363794,
                                    0.044735328758620074,
                                ],
                                [
                                    0.044735328758620074,
                                    0.9318096327260459,
                                    0.0010744706085363794,
                                    0.02238056790679766,
                                ],
                                [
                                    0.044735328758620074,
                                    0.0010744706085363794,
                                    0.9318096327260459,
                                    0.02238056790679766,
                                ],
                                [
                                    0.02238056790679766,
                                    0.0010744706085363794,
                                    0.9318096327260459,
                                    0.044735328758620074,
                                ],
                                [
                                    0.9318096327260459,
                                    0.02238056790679766,
                                    0.044735328758620074,
                                    0.0010744706085363794,
                                ],
                                [
                                    0.9318096327260459,
                                    0.044735328758620074,
                                    0.02238056790679766,
                                    0.0010744706085363794,
                                ],
                                [
                                    0.10505335352732832,
                                    0.3725918856208493,
                                    0.1148867713123503,
                                    0.4074679895394721,
                                ],
                                [
                                    0.10505335352732832,
                                    0.1148867713123503,
                                    0.3725918856208493,
                                    0.4074679895394721,
                                ],
                                [
                                    0.1148867713123503,
                                    0.4074679895394721,
                                    0.10505335352732832,
                                    0.3725918856208493,
                                ],
                                [
                                    0.1274597284891012,
                                    0.1393904733812455,
                                    0.3501855106590764,
                                    0.3829642874705769,
                                ],
                                [
                                    0.1274597284891012,
                                    0.3501855106590764,
                                    0.1393904733812455,
                                    0.3829642874705769,
                                ],
                                [
                                    0.1148867713123503,
                                    0.10505335352732832,
                                    0.4074679895394721,
                                    0.3725918856208493,
                                ],
                                [
                                    0.1393904733812455,
                                    0.3829642874705769,
                                    0.1274597284891012,
                                    0.3501855106590764,
                                ],
                                [
                                    0.1393904733812455,
                                    0.1274597284891012,
                                    0.3829642874705769,
                                    0.3501855106590764,
                                ],
                                [
                                    0.06923526750294655,
                                    0.32079467007721424,
                                    0.10827743301563093,
                                    0.5016926294042082,
                                ],
                                [
                                    0.06923526750294655,
                                    0.10827743301563093,
                                    0.32079467007721424,
                                    0.5016926294042082,
                                ],
                                [
                                    0.10827743301563095,
                                    0.5016926294042083,
                                    0.06923526750294653,
                                    0.3207946700772142,
                                ],
                                [
                                    0.15924066058835107,
                                    0.24903738487738492,
                                    0.23078927699180973,
                                    0.3609326775424543,
                                ],
                                [
                                    0.15924066058835107,
                                    0.23078927699180973,
                                    0.24903738487738492,
                                    0.3609326775424543,
                                ],
                                [
                                    0.10827743301563095,
                                    0.06923526750294653,
                                    0.5016926294042083,
                                    0.3207946700772142,
                                ],
                                [
                                    0.24903738487738497,
                                    0.36093267754245434,
                                    0.159240660588351,
                                    0.23078927699180968,
                                ],
                                [
                                    0.24903738487738497,
                                    0.159240660588351,
                                    0.36093267754245434,
                                    0.23078927699180968,
                                ],
                                [
                                    0.030198820631829798,
                                    0.23152869862583722,
                                    0.08518385184174945,
                                    0.6530886289005835,
                                ],
                                [
                                    0.030198820631829798,
                                    0.08518385184174945,
                                    0.23152869862583722,
                                    0.6530886289005835,
                                ],
                                [
                                    0.08518385184174945,
                                    0.6530886289005835,
                                    0.030198820631829798,
                                    0.23152869862583722,
                                ],
                                [
                                    0.1610625802606633,
                                    0.4543200922129159,
                                    0.10066493899700371,
                                    0.28395238852941707,
                                ],
                                [
                                    0.1610625802606633,
                                    0.10066493899700371,
                                    0.4543200922129159,
                                    0.28395238852941707,
                                ],
                                [
                                    0.08518385184174945,
                                    0.030198820631829798,
                                    0.6530886289005835,
                                    0.23152869862583722,
                                ],
                                [
                                    0.4543200922129159,
                                    0.28395238852941707,
                                    0.1610625802606633,
                                    0.10066493899700371,
                                ],
                                [
                                    0.4543200922129159,
                                    0.1610625802606633,
                                    0.28395238852941707,
                                    0.10066493899700371,
                                ],
                                [
                                    0.007105239457948319,
                                    0.12631986147722502,
                                    0.0461474049706327,
                                    0.8204274940941939,
                                ],
                                [
                                    0.007105239457948319,
                                    0.0461474049706327,
                                    0.12631986147722502,
                                    0.8204274940941939,
                                ],
                                [
                                    0.0461474049706327,
                                    0.8204274940941939,
                                    0.007105239457948319,
                                    0.12631986147722502,
                                ],
                                [
                                    0.10974045095120695,
                                    0.7127468485302155,
                                    0.023684649983966397,
                                    0.15382805053461107,
                                ],
                                [
                                    0.10974045095120695,
                                    0.023684649983966397,
                                    0.7127468485302155,
                                    0.15382805053461107,
                                ],
                                [
                                    0.0461474049706327,
                                    0.007105239457948319,
                                    0.8204274940941939,
                                    0.12631986147722502,
                                ],
                                [
                                    0.7127468485302155,
                                    0.15382805053461107,
                                    0.10974045095120695,
                                    0.023684649983966397,
                                ],
                                [
                                    0.7127468485302155,
                                    0.10974045095120695,
                                    0.15382805053461107,
                                    0.023684649983966397,
                                ],
                                [
                                    0.0004959011612289613,
                                    0.045313898205927496,
                                    0.010329318946250922,
                                    0.9438608816865927,
                                ],
                                [
                                    0.0004959011612289613,
                                    0.010329318946250922,
                                    0.045313898205927496,
                                    0.9438608816865927,
                                ],
                                [
                                    0.010329318946250922,
                                    0.9438608816865927,
                                    0.0004959011612289613,
                                    0.045313898205927496,
                                ],
                                [
                                    0.04415675931131266,
                                    0.9197583837654991,
                                    0.001653040055843797,
                                    0.03443181686734438,
                                ],
                                [
                                    0.04415675931131266,
                                    0.001653040055843797,
                                    0.9197583837654991,
                                    0.03443181686734438,
                                ],
                                [
                                    0.010329318946250922,
                                    0.0004959011612289613,
                                    0.9438608816865927,
                                    0.045313898205927496,
                                ],
                                [
                                    0.9197583837654991,
                                    0.03443181686734438,
                                    0.04415675931131266,
                                    0.001653040055843797,
                                ],
                                [
                                    0.9197583837654991,
                                    0.04415675931131266,
                                    0.03443181686734438,
                                    0.001653040055843797,
                                ],
                                [
                                    0.021355290186338076,
                                    0.4562899489618395,
                                    0.023354231517306763,
                                    0.49900052933451566,
                                ],
                                [
                                    0.021355290186338076,
                                    0.023354231517306763,
                                    0.4562899489618395,
                                    0.49900052933451566,
                                ],
                                [
                                    0.023354231517306763,
                                    0.49900052933451566,
                                    0.021355290186338076,
                                    0.4562899489618395,
                                ],
                                [
                                    0.04376166514811096,
                                    0.04785793358620195,
                                    0.4338835740000666,
                                    0.4744968272656205,
                                ],
                                [
                                    0.04376166514811096,
                                    0.4338835740000666,
                                    0.04785793358620195,
                                    0.4744968272656205,
                                ],
                                [
                                    0.023354231517306763,
                                    0.021355290186338076,
                                    0.49900052933451566,
                                    0.4562899489618395,
                                ],
                                [
                                    0.04785793358620195,
                                    0.4744968272656205,
                                    0.04376166514811096,
                                    0.4338835740000666,
                                ],
                                [
                                    0.04785793358620195,
                                    0.04376166514811096,
                                    0.4744968272656205,
                                    0.4338835740000666,
                                ],
                                [
                                    0.014074174493340124,
                                    0.37595576308682066,
                                    0.022010682429848067,
                                    0.5879593799899911,
                                ],
                                [
                                    0.014074174493340124,
                                    0.022010682429848067,
                                    0.37595576308682066,
                                    0.5879593799899911,
                                ],
                                [
                                    0.02201068242984807,
                                    0.5879593799899913,
                                    0.014074174493340119,
                                    0.37595576308682055,
                                ],
                                [
                                    0.10407956757874463,
                                    0.16277063429160207,
                                    0.28595037000141615,
                                    0.44719942812823715,
                                ],
                                [
                                    0.10407956757874463,
                                    0.28595037000141615,
                                    0.16277063429160207,
                                    0.44719942812823715,
                                ],
                                [
                                    0.02201068242984807,
                                    0.014074174493340119,
                                    0.5879593799899913,
                                    0.37595576308682055,
                                ],
                                [
                                    0.1627706342916021,
                                    0.4471994281282372,
                                    0.1040795675787446,
                                    0.2859503700014161,
                                ],
                                [
                                    0.1627706342916021,
                                    0.1040795675787446,
                                    0.4471994281282372,
                                    0.2859503700014161,
                                ],
                                [
                                    0.006138829044711411,
                                    0.2555886902129556,
                                    0.017316209470622627,
                                    0.7209562712717104,
                                ],
                                [
                                    0.006138829044711411,
                                    0.017316209470622627,
                                    0.2555886902129556,
                                    0.7209562712717104,
                                ],
                                [
                                    0.017316209470622627,
                                    0.7209562712717104,
                                    0.006138829044711411,
                                    0.2555886902129556,
                                ],
                                [
                                    0.13700258867354492,
                                    0.3864524498417891,
                                    0.1247249305841221,
                                    0.35182003090054387,
                                ],
                                [
                                    0.13700258867354492,
                                    0.1247249305841221,
                                    0.3864524498417891,
                                    0.35182003090054387,
                                ],
                                [
                                    0.017316209470622627,
                                    0.006138829044711411,
                                    0.7209562712717104,
                                    0.2555886902129556,
                                ],
                                [
                                    0.3864524498417891,
                                    0.35182003090054387,
                                    0.13700258867354492,
                                    0.1247249305841221,
                                ],
                                [
                                    0.3864524498417891,
                                    0.13700258867354492,
                                    0.35182003090054387,
                                    0.1247249305841221,
                                ],
                                [
                                    0.0014443560854859713,
                                    0.1319807448496874,
                                    0.009380864021993911,
                                    0.8571940350428328,
                                ],
                                [
                                    0.0014443560854859713,
                                    0.009380864021993911,
                                    0.1319807448496874,
                                    0.8571940350428328,
                                ],
                                [
                                    0.009380864021993911,
                                    0.8571940350428328,
                                    0.0014443560854859713,
                                    0.1319807448496874,
                                ],
                                [
                                    0.1040795675787446,
                                    0.6759803075815768,
                                    0.029345533356428748,
                                    0.19059459148324986,
                                ],
                                [
                                    0.1040795675787446,
                                    0.029345533356428748,
                                    0.6759803075815768,
                                    0.19059459148324986,
                                ],
                                [
                                    0.009380864021993911,
                                    0.0014443560854859713,
                                    0.8571940350428328,
                                    0.1319807448496874,
                                ],
                                [
                                    0.6759803075815768,
                                    0.19059459148324986,
                                    0.1040795675787446,
                                    0.029345533356428748,
                                ],
                                [
                                    0.6759803075815768,
                                    0.1040795675787446,
                                    0.19059459148324986,
                                    0.029345533356428748,
                                ],
                                [
                                    0.00010080699802726174,
                                    0.045708992369129196,
                                    0.002099748328995973,
                                    0.9520904523038476,
                                ],
                                [
                                    0.00010080699802726174,
                                    0.002099748328995973,
                                    0.045708992369129196,
                                    0.9520904523038476,
                                ],
                                [
                                    0.002099748328995973,
                                    0.9520904523038476,
                                    0.00010080699802726174,
                                    0.045708992369129196,
                                ],
                                [
                                    0.04376166514811096,
                                    0.9115288131482442,
                                    0.002048134219045498,
                                    0.04266138748459936,
                                ],
                                [
                                    0.04376166514811096,
                                    0.002048134219045498,
                                    0.9115288131482442,
                                    0.04266138748459936,
                                ],
                                [
                                    0.002099748328995973,
                                    0.00010080699802726174,
                                    0.9520904523038476,
                                    0.045708992369129196,
                                ],
                                [
                                    0.9115288131482442,
                                    0.04266138748459936,
                                    0.04376166514811096,
                                    0.002048134219045498,
                                ],
                                [
                                    0.9115288131482442,
                                    0.04376166514811096,
                                    0.04266138748459936,
                                    0.002048134219045498,
                                ],
                                [
                                    0.20025058524206277,
                                    0.020197351506731725,
                                    0.7081298160236245,
                                    0.0714222472275811,
                                ],
                                [
                                    0.20025058524206277,
                                    0.7081298160236245,
                                    0.020197351506731725,
                                    0.0714222472275811,
                                ],
                                [
                                    0.2408638385076166,
                                    0.024293619944822716,
                                    0.6675165627580706,
                                    0.0673259787894901,
                                ],
                                [
                                    0.21059181493620052,
                                    0.7446986633601547,
                                    0.009856121812593946,
                                    0.034853399891050865,
                                ],
                                [
                                    0.21059181493620052,
                                    0.009856121812593946,
                                    0.7446986633601547,
                                    0.034853399891050865,
                                ],
                                [
                                    0.2408638385076166,
                                    0.6675165627580706,
                                    0.024293619944822716,
                                    0.0673259787894901,
                                ],
                                [
                                    0.25330239530887666,
                                    0.011855063143562633,
                                    0.7019880829874785,
                                    0.03285445856008218,
                                ],
                                [
                                    0.25330239530887666,
                                    0.7019880829874785,
                                    0.011855063143562633,
                                    0.03285445856008218,
                                ],
                                [
                                    0.1319748715422889,
                                    0.04803591462852021,
                                    0.6011749265873645,
                                    0.21881428724182636,
                                ],
                                [
                                    0.1319748715422889,
                                    0.6011749265873645,
                                    0.04803591462852021,
                                    0.21881428724182636,
                                ],
                                [
                                    0.29322392966911,
                                    0.10672698134137765,
                                    0.43992586846054343,
                                    0.16012322052896893,
                                ],
                                [
                                    0.17351512270720484,
                                    0.790400020369607,
                                    0.0064956634636042605,
                                    0.029589193459583874,
                                ],
                                [
                                    0.17351512270720484,
                                    0.0064956634636042605,
                                    0.790400020369607,
                                    0.029589193459583874,
                                ],
                                [
                                    0.29322392966911,
                                    0.43992586846054343,
                                    0.10672698134137765,
                                    0.16012322052896893,
                                ],
                                [
                                    0.3855187396103754,
                                    0.014432171400112196,
                                    0.5783964034664364,
                                    0.021652685523075938,
                                ],
                                [
                                    0.3855187396103754,
                                    0.5783964034664364,
                                    0.014432171400112196,
                                    0.021652685523075938,
                                ],
                                [
                                    0.05756438325951067,
                                    0.06323089926780852,
                                    0.4189805782251553,
                                    0.46022413924752553,
                                ],
                                [
                                    0.05756438325951067,
                                    0.4189805782251553,
                                    0.06323089926780852,
                                    0.46022413924752553,
                                ],
                                [
                                    0.28465948357593246,
                                    0.3126807604360527,
                                    0.19188547790873353,
                                    0.2107742780792813,
                                ],
                                [
                                    0.11796202452317027,
                                    0.8585829369614957,
                                    0.002833258004148925,
                                    0.020621780511185083,
                                ],
                                [
                                    0.11796202452317027,
                                    0.002833258004148925,
                                    0.8585829369614957,
                                    0.020621780511185083,
                                ],
                                [
                                    0.28465948357593246,
                                    0.19188547790873353,
                                    0.3126807604360527,
                                    0.2107742780792813,
                                ],
                                [
                                    0.583329605581925,
                                    0.014010638430060127,
                                    0.3932153559027409,
                                    0.009444400085273882,
                                ],
                                [
                                    0.583329605581925,
                                    0.3932153559027409,
                                    0.014010638430060127,
                                    0.009444400085273882,
                                ],
                                [
                                    0.013543864255309263,
                                    0.04803591462852022,
                                    0.20639626058436936,
                                    0.7320239605318012,
                                ],
                                [
                                    0.013543864255309263,
                                    0.20639626058436936,
                                    0.04803591462852022,
                                    0.7320239605318012,
                                ],
                                [
                                    0.1747929223821304,
                                    0.6199366546313524,
                                    0.04514720245754824,
                                    0.16012322052896902,
                                ],
                                [
                                    0.06091316422324209,
                                    0.928261615669278,
                                    0.000666614660587396,
                                    0.010158605446892486,
                                ],
                                [
                                    0.06091316422324209,
                                    0.000666614660587396,
                                    0.928261615669278,
                                    0.010158605446892486,
                                ],
                                [
                                    0.1747929223821304,
                                    0.04514720245754824,
                                    0.6199366546313524,
                                    0.16012322052896902,
                                ],
                                [
                                    0.7861264544163875,
                                    0.008603122597095336,
                                    0.20304832547613272,
                                    0.0022220975103845473,
                                ],
                                [
                                    0.7861264544163875,
                                    0.20304832547613272,
                                    0.008603122597095336,
                                    0.0022220975103845473,
                                ],
                                [
                                    0.0009452767991122286,
                                    0.020197351506731784,
                                    0.04376424490453261,
                                    0.9350931267896234,
                                ],
                                [
                                    0.0009452767991122286,
                                    0.04376424490453261,
                                    0.020197351506731784,
                                    0.9350931267896234,
                                ],
                                [
                                    0.041558530064666074,
                                    0.8879644995068651,
                                    0.0031509916389787676,
                                    0.06732597878949018,
                                ],
                                [
                                    0.021096102782498315,
                                    0.9767033418904785,
                                    4.652552334569674e-05,
                                    0.002154029803677513,
                                ],
                                [
                                    0.021096102782498315,
                                    4.652552334569674e-05,
                                    0.9767033418904785,
                                    0.002154029803677513,
                                ],
                                [
                                    0.041558530064666074,
                                    0.0031509916389787676,
                                    0.8879644995068651,
                                    0.06732597878949018,
                                ],
                                [
                                    0.9274775627172167,
                                    0.002045466854314385,
                                    0.07032188195576011,
                                    0.00015508847270882453,
                                ],
                                [
                                    0.9274775627172167,
                                    0.07032188195576011,
                                    0.002045466854314385,
                                    0.00015508847270882453,
                                ],
                                [
                                    0.16162136032547728,
                                    0.0588265764233172,
                                    0.5715284378041762,
                                    0.20802362544702938,
                                ],
                                [
                                    0.16162136032547728,
                                    0.5715284378041762,
                                    0.0588265764233172,
                                    0.20802362544702938,
                                ],
                                [
                                    0.19440013713697785,
                                    0.07075732131546147,
                                    0.5387496609926755,
                                    0.1960928805548851,
                                ],
                                [
                                    0.17196259001961506,
                                    0.6080972851407064,
                                    0.048485346729179424,
                                    0.17145477811049914,
                                ],
                                [
                                    0.17196259001961506,
                                    0.048485346729179424,
                                    0.6080972851407064,
                                    0.17145477811049914,
                                ],
                                [
                                    0.19440013713697785,
                                    0.5387496609926755,
                                    0.07075732131546147,
                                    0.1960928805548851,
                                ],
                                [
                                    0.20683869393823792,
                                    0.058318764514201385,
                                    0.5732211812220834,
                                    0.16162136032547716,
                                ],
                                [
                                    0.20683869393823792,
                                    0.5732211812220834,
                                    0.058318764514201385,
                                    0.16162136032547716,
                                ],
                                [
                                    0.10651633423024066,
                                    0.07349445194056846,
                                    0.4852056203040235,
                                    0.3347835935251674,
                                ],
                                [
                                    0.10651633423024066,
                                    0.4852056203040235,
                                    0.07349445194056846,
                                    0.3347835935251674,
                                ],
                                [
                                    0.23665973478088528,
                                    0.16329117622960235,
                                    0.35506221975337887,
                                    0.24498686923613353,
                                ],
                                [
                                    0.14805658539515662,
                                    0.674430714086266,
                                    0.031954200775652516,
                                    0.1455584997429249,
                                ],
                                [
                                    0.14805658539515662,
                                    0.031954200775652516,
                                    0.674430714086266,
                                    0.1455584997429249,
                                ],
                                [
                                    0.23665973478088528,
                                    0.35506221975337887,
                                    0.16329117622960235,
                                    0.24498686923613353,
                                ],
                                [
                                    0.32895454472215074,
                                    0.07099636628833689,
                                    0.4935327547592719,
                                    0.10651633423024051,
                                ],
                                [
                                    0.32895454472215074,
                                    0.4935327547592719,
                                    0.07099636628833689,
                                    0.10651633423024051,
                                ],
                                [
                                    0.04645995874345646,
                                    0.07433532378386273,
                                    0.3381573687829643,
                                    0.5410473486897165,
                                ],
                                [
                                    0.04645995874345646,
                                    0.3381573687829643,
                                    0.07433532378386273,
                                    0.5410473486897165,
                                ],
                                [
                                    0.22974740827586979,
                                    0.3675928357361154,
                                    0.15486991925055096,
                                    0.24778983673746388,
                                ],
                                [
                                    0.10685760000711605,
                                    0.7777597275193047,
                                    0.013937682520203137,
                                    0.10144498995337609,
                                ],
                                [
                                    0.10685760000711605,
                                    0.013937682520203137,
                                    0.7777597275193047,
                                    0.10144498995337609,
                                ],
                                [
                                    0.22974740827586979,
                                    0.15486991925055096,
                                    0.3675928357361154,
                                    0.24778983673746388,
                                ],
                                [
                                    0.5284175302818623,
                                    0.06892271373012278,
                                    0.3561997972445584,
                                    0.046459958743456445,
                                ],
                                [
                                    0.5284175302818623,
                                    0.3561997972445584,
                                    0.06892271373012278,
                                    0.046459958743456445,
                                ],
                                [
                                    0.010931192847005444,
                                    0.05064858603682404,
                                    0.16658150767157204,
                                    0.7718387134445985,
                                ],
                                [
                                    0.010931192847005444,
                                    0.16658150767157204,
                                    0.05064858603682404,
                                    0.7718387134445985,
                                ],
                                [
                                    0.14107459339765013,
                                    0.6536549836158326,
                                    0.03643810712092736,
                                    0.16883231586558992,
                                ],
                                [
                                    0.05830049281493827,
                                    0.8884468627564807,
                                    0.0032792860688912145,
                                    0.04997335835968983,
                                ],
                                [
                                    0.05830049281493827,
                                    0.0032792860688912145,
                                    0.8884468627564807,
                                    0.04997335835968983,
                                ],
                                [
                                    0.14107459339765013,
                                    0.03643810712092736,
                                    0.6536549836158326,
                                    0.16883231586558992,
                                ],
                                [
                                    0.7524081254319072,
                                    0.04232145158157561,
                                    0.19433923013951185,
                                    0.010931192847005432,
                                ],
                                [
                                    0.7524081254319072,
                                    0.19433923013951185,
                                    0.04232145158157561,
                                    0.010931192847005432,
                                ],
                                [
                                    0.0007629287173965299,
                                    0.020379699588447483,
                                    0.035321928205791664,
                                    0.9435354434883644,
                                ],
                                [
                                    0.0007629287173965299,
                                    0.035321928205791664,
                                    0.020379699588447483,
                                    0.9435354434883644,
                                ],
                                [
                                    0.033541705528897126,
                                    0.895981324042634,
                                    0.002543151394291067,
                                    0.06793381903417788,
                                ],
                                [
                                    0.02091375470078262,
                                    0.9682610251917375,
                                    0.00022887360506139616,
                                    0.010596346502418497,
                                ],
                                [
                                    0.02091375470078262,
                                    0.00022887360506139616,
                                    0.9682610251917375,
                                    0.010596346502418497,
                                ],
                                [
                                    0.033541705528897126,
                                    0.002543151394291067,
                                    0.895981324042634,
                                    0.06793381903417788,
                                ],
                                [
                                    0.9194607381814477,
                                    0.010062291390083366,
                                    0.06971404171107241,
                                    0.0007629287173965278,
                                ],
                                [
                                    0.9194607381814477,
                                    0.06971404171107241,
                                    0.010062291390083366,
                                    0.0007629287173965278,
                                ],
                                [
                                    0.10505335352732835,
                                    0.11539458322146613,
                                    0.3714916079573376,
                                    0.4080604552938679,
                                ],
                                [
                                    0.10505335352732835,
                                    0.3714916079573376,
                                    0.11539458322146613,
                                    0.4080604552938679,
                                ],
                                [
                                    0.1263594508255896,
                                    0.1387980076268497,
                                    0.3501855106590763,
                                    0.38465703088848435,
                                ],
                                [
                                    0.11539458322146613,
                                    0.4080604552938679,
                                    0.10505335352732835,
                                    0.3714916079573376,
                                ],
                                [
                                    0.11539458322146613,
                                    0.10505335352732835,
                                    0.4080604552938679,
                                    0.3714916079573376,
                                ],
                                [
                                    0.1263594508255896,
                                    0.3501855106590763,
                                    0.1387980076268497,
                                    0.38465703088848435,
                                ],
                                [
                                    0.1387980076268497,
                                    0.1263594508255896,
                                    0.38465703088848435,
                                    0.3501855106590763,
                                ],
                                [
                                    0.1387980076268497,
                                    0.38465703088848435,
                                    0.1263594508255896,
                                    0.3501855106590763,
                                ],
                                [
                                    0.0692352675029466,
                                    0.11077551866786252,
                                    0.31538206002347424,
                                    0.5046071538057166,
                                ],
                                [
                                    0.0692352675029466,
                                    0.31538206002347424,
                                    0.11077551866786252,
                                    0.5046071538057166,
                                ],
                                [
                                    0.15382805053461113,
                                    0.2461228604758765,
                                    0.23078927699180973,
                                    0.36925981199770264,
                                ],
                                [
                                    0.11077551866786255,
                                    0.5046071538057167,
                                    0.06923526750294658,
                                    0.3153820600234742,
                                ],
                                [
                                    0.11077551866786255,
                                    0.06923526750294658,
                                    0.5046071538057167,
                                    0.3153820600234742,
                                ],
                                [
                                    0.15382805053461113,
                                    0.23078927699180973,
                                    0.2461228604758765,
                                    0.36925981199770264,
                                ],
                                [
                                    0.24612286047587656,
                                    0.15382805053461107,
                                    0.3692598119977027,
                                    0.23078927699180968,
                                ],
                                [
                                    0.24612286047587656,
                                    0.3692598119977027,
                                    0.15382805053461107,
                                    0.23078927699180968,
                                ],
                                [
                                    0.030198820631829798,
                                    0.0905964618954894,
                                    0.2198011793681702,
                                    0.6594035381045106,
                                ],
                                [
                                    0.030198820631829798,
                                    0.2198011793681702,
                                    0.0905964618954894,
                                    0.6594035381045106,
                                ],
                                [
                                    0.1493350610029963,
                                    0.44800518300898884,
                                    0.10066493899700371,
                                    0.30199481699101116,
                                ],
                                [
                                    0.0905964618954894,
                                    0.6594035381045106,
                                    0.030198820631829798,
                                    0.2198011793681702,
                                ],
                                [
                                    0.0905964618954894,
                                    0.030198820631829798,
                                    0.6594035381045106,
                                    0.2198011793681702,
                                ],
                                [
                                    0.1493350610029963,
                                    0.10066493899700371,
                                    0.44800518300898884,
                                    0.30199481699101116,
                                ],
                                [
                                    0.44800518300898884,
                                    0.1493350610029963,
                                    0.30199481699101116,
                                    0.10066493899700371,
                                ],
                                [
                                    0.44800518300898884,
                                    0.30199481699101116,
                                    0.1493350610029963,
                                    0.10066493899700371,
                                ],
                                [
                                    0.007105239457948329,
                                    0.05447453942588115,
                                    0.10827743301563092,
                                    0.8301427881005395,
                                ],
                                [
                                    0.007105239457948329,
                                    0.10827743301563092,
                                    0.05447453942588115,
                                    0.8301427881005395,
                                ],
                                [
                                    0.09169802248961287,
                                    0.7030315545238699,
                                    0.023684649983966397,
                                    0.18158577300255088,
                                ],
                                [
                                    0.05447453942588115,
                                    0.8301427881005395,
                                    0.007105239457948329,
                                    0.10827743301563092,
                                ],
                                [
                                    0.05447453942588115,
                                    0.007105239457948329,
                                    0.8301427881005395,
                                    0.10827743301563092,
                                ],
                                [
                                    0.09169802248961287,
                                    0.023684649983966397,
                                    0.7030315545238699,
                                    0.18158577300255088,
                                ],
                                [
                                    0.7030315545238699,
                                    0.09169802248961287,
                                    0.18158577300255088,
                                    0.023684649983966397,
                                ],
                                [
                                    0.7030315545238699,
                                    0.18158577300255088,
                                    0.09169802248961287,
                                    0.023684649983966397,
                                ],
                                [
                                    0.000495901161228963,
                                    0.02064672714461505,
                                    0.022959137354105073,
                                    0.955898234340051,
                                ],
                                [
                                    0.000495901161228963,
                                    0.022959137354105073,
                                    0.02064672714461505,
                                    0.955898234340051,
                                ],
                                [
                                    0.02180199845949024,
                                    0.9077210311120408,
                                    0.001653040055843797,
                                    0.06882393037262514,
                                ],
                                [
                                    0.02064672714461505,
                                    0.955898234340051,
                                    0.000495901161228963,
                                    0.022959137354105073,
                                ],
                                [
                                    0.02064672714461505,
                                    0.000495901161228963,
                                    0.955898234340051,
                                    0.022959137354105073,
                                ],
                                [
                                    0.02180199845949024,
                                    0.001653040055843797,
                                    0.9077210311120408,
                                    0.06882393037262514,
                                ],
                                [
                                    0.9077210311120408,
                                    0.02180199845949024,
                                    0.06882393037262514,
                                    0.001653040055843797,
                                ],
                                [
                                    0.9077210311120408,
                                    0.06882393037262514,
                                    0.02180199845949024,
                                    0.001653040055843797,
                                ],
                                [
                                    0.04848534672917944,
                                    0.17196259001961506,
                                    0.1714547781104992,
                                    0.6080972851407064,
                                ],
                                [
                                    0.04848534672917944,
                                    0.1714547781104992,
                                    0.17196259001961506,
                                    0.6080972851407064,
                                ],
                                [
                                    0.0583187645142014,
                                    0.20683869393823792,
                                    0.16162136032547722,
                                    0.5732211812220834,
                                ],
                                [
                                    0.05882657642331723,
                                    0.20802362544702946,
                                    0.16162136032547725,
                                    0.5715284378041761,
                                ],
                                [
                                    0.05882657642331723,
                                    0.16162136032547725,
                                    0.20802362544702946,
                                    0.5715284378041761,
                                ],
                                [
                                    0.0583187645142014,
                                    0.16162136032547722,
                                    0.20683869393823792,
                                    0.5732211812220834,
                                ],
                                [
                                    0.0707573213154615,
                                    0.19440013713697782,
                                    0.1960928805548852,
                                    0.5387496609926755,
                                ],
                                [
                                    0.0707573213154615,
                                    0.1960928805548852,
                                    0.19440013713697782,
                                    0.5387496609926755,
                                ],
                                [
                                    0.03195420077565253,
                                    0.1480565853951566,
                                    0.14555849974292495,
                                    0.6744307140862659,
                                ],
                                [
                                    0.03195420077565253,
                                    0.14555849974292495,
                                    0.1480565853951566,
                                    0.6744307140862659,
                                ],
                                [
                                    0.07099636628833693,
                                    0.3289545447221507,
                                    0.10651633423024055,
                                    0.49353275475927183,
                                ],
                                [
                                    0.07349445194056849,
                                    0.3347835935251675,
                                    0.10651633423024064,
                                    0.48520562030402337,
                                ],
                                [
                                    0.07349445194056849,
                                    0.10651633423024064,
                                    0.3347835935251675,
                                    0.48520562030402337,
                                ],
                                [
                                    0.07099636628833693,
                                    0.10651633423024055,
                                    0.3289545447221507,
                                    0.49353275475927183,
                                ],
                                [
                                    0.1632911762296024,
                                    0.23665973478088523,
                                    0.24498686923613358,
                                    0.35506221975337876,
                                ],
                                [
                                    0.1632911762296024,
                                    0.24498686923613358,
                                    0.23665973478088523,
                                    0.35506221975337876,
                                ],
                                [
                                    0.01393768252020314,
                                    0.10685760000711605,
                                    0.10144498995337611,
                                    0.7777597275193047,
                                ],
                                [
                                    0.01393768252020314,
                                    0.10144498995337611,
                                    0.10685760000711605,
                                    0.7777597275193047,
                                ],
                                [
                                    0.06892271373012279,
                                    0.5284175302818623,
                                    0.04645995874345646,
                                    0.3561997972445584,
                                ],
                                [
                                    0.07433532378386273,
                                    0.5410473486897165,
                                    0.04645995874345646,
                                    0.3381573687829643,
                                ],
                                [
                                    0.07433532378386273,
                                    0.04645995874345646,
                                    0.5410473486897165,
                                    0.3381573687829643,
                                ],
                                [
                                    0.06892271373012279,
                                    0.04645995874345646,
                                    0.5284175302818623,
                                    0.3561997972445584,
                                ],
                                [
                                    0.3675928357361154,
                                    0.22974740827586979,
                                    0.24778983673746388,
                                    0.15486991925055096,
                                ],
                                [
                                    0.3675928357361154,
                                    0.24778983673746388,
                                    0.22974740827586979,
                                    0.15486991925055096,
                                ],
                                [
                                    0.0032792860688912132,
                                    0.05830049281493827,
                                    0.04997335835968981,
                                    0.8884468627564807,
                                ],
                                [
                                    0.0032792860688912132,
                                    0.04997335835968981,
                                    0.05830049281493827,
                                    0.8884468627564807,
                                ],
                                [
                                    0.042321451581575596,
                                    0.7524081254319072,
                                    0.010931192847005429,
                                    0.19433923013951185,
                                ],
                                [
                                    0.05064858603682404,
                                    0.7718387134445985,
                                    0.010931192847005443,
                                    0.166581507671572,
                                ],
                                [
                                    0.05064858603682404,
                                    0.010931192847005443,
                                    0.7718387134445985,
                                    0.166581507671572,
                                ],
                                [
                                    0.042321451581575596,
                                    0.010931192847005429,
                                    0.7524081254319072,
                                    0.19433923013951185,
                                ],
                                [
                                    0.6536549836158326,
                                    0.1410745933976501,
                                    0.16883231586558992,
                                    0.036438107120927356,
                                ],
                                [
                                    0.6536549836158326,
                                    0.16883231586558992,
                                    0.1410745933976501,
                                    0.036438107120927356,
                                ],
                                [
                                    0.00022887360506139594,
                                    0.02091375470078262,
                                    0.010596346502418487,
                                    0.9682610251917375,
                                ],
                                [
                                    0.00022887360506139594,
                                    0.010596346502418487,
                                    0.02091375470078262,
                                    0.9682610251917375,
                                ],
                                [
                                    0.010062291390083355,
                                    0.9194607381814477,
                                    0.000762928717396527,
                                    0.06971404171107241,
                                ],
                                [
                                    0.020379699588447483,
                                    0.9435354434883644,
                                    0.0007629287173965296,
                                    0.03532192820579165,
                                ],
                                [
                                    0.020379699588447483,
                                    0.0007629287173965296,
                                    0.9435354434883644,
                                    0.03532192820579165,
                                ],
                                [
                                    0.010062291390083355,
                                    0.000762928717396527,
                                    0.9194607381814477,
                                    0.06971404171107241,
                                ],
                                [
                                    0.895981324042634,
                                    0.03354170552889711,
                                    0.06793381903417788,
                                    0.002543151394291066,
                                ],
                                [
                                    0.895981324042634,
                                    0.06793381903417788,
                                    0.03354170552889711,
                                    0.002543151394291066,
                                ],
                                [
                                    0.009856121812593951,
                                    0.21059181493620052,
                                    0.034853399891050886,
                                    0.7446986633601547,
                                ],
                                [
                                    0.009856121812593951,
                                    0.034853399891050886,
                                    0.21059181493620052,
                                    0.7446986633601547,
                                ],
                                [
                                    0.01185506314356264,
                                    0.25330239530887666,
                                    0.0328544585600822,
                                    0.7019880829874785,
                                ],
                                [
                                    0.020197351506731746,
                                    0.07142224722758117,
                                    0.20025058524206274,
                                    0.7081298160236243,
                                ],
                                [
                                    0.020197351506731746,
                                    0.20025058524206274,
                                    0.07142224722758117,
                                    0.7081298160236243,
                                ],
                                [
                                    0.01185506314356264,
                                    0.0328544585600822,
                                    0.25330239530887666,
                                    0.7019880829874785,
                                ],
                                [
                                    0.02429361994482274,
                                    0.24086383850761658,
                                    0.06732597878949018,
                                    0.6675165627580705,
                                ],
                                [
                                    0.02429361994482274,
                                    0.06732597878949018,
                                    0.24086383850761658,
                                    0.6675165627580705,
                                ],
                                [
                                    0.006495663463604271,
                                    0.17351512270720484,
                                    0.02958919345958392,
                                    0.790400020369607,
                                ],
                                [
                                    0.006495663463604271,
                                    0.02958919345958392,
                                    0.17351512270720484,
                                    0.790400020369607,
                                ],
                                [
                                    0.014432171400112218,
                                    0.3855187396103754,
                                    0.021652685523075973,
                                    0.5783964034664364,
                                ],
                                [
                                    0.04803591462852023,
                                    0.21881428724182647,
                                    0.1319748715422889,
                                    0.6011749265873644,
                                ],
                                [
                                    0.04803591462852023,
                                    0.1319748715422889,
                                    0.21881428724182647,
                                    0.6011749265873644,
                                ],
                                [
                                    0.014432171400112218,
                                    0.021652685523075973,
                                    0.3855187396103754,
                                    0.5783964034664364,
                                ],
                                [
                                    0.10672698134137769,
                                    0.29322392966910993,
                                    0.160123220528969,
                                    0.4399258684605434,
                                ],
                                [
                                    0.10672698134137769,
                                    0.160123220528969,
                                    0.29322392966910993,
                                    0.4399258684605434,
                                ],
                                [
                                    0.002833258004148928,
                                    0.11796202452317027,
                                    0.020621780511185107,
                                    0.8585829369614957,
                                ],
                                [
                                    0.002833258004148928,
                                    0.020621780511185107,
                                    0.11796202452317027,
                                    0.8585829369614957,
                                ],
                                [
                                    0.014010638430060144,
                                    0.583329605581925,
                                    0.009444400085273892,
                                    0.3932153559027409,
                                ],
                                [
                                    0.06323089926780852,
                                    0.46022413924752553,
                                    0.05756438325951067,
                                    0.4189805782251553,
                                ],
                                [
                                    0.06323089926780852,
                                    0.05756438325951067,
                                    0.46022413924752553,
                                    0.4189805782251553,
                                ],
                                [
                                    0.014010638430060144,
                                    0.009444400085273892,
                                    0.583329605581925,
                                    0.3932153559027409,
                                ],
                                [
                                    0.3126807604360527,
                                    0.28465948357593246,
                                    0.2107742780792813,
                                    0.19188547790873353,
                                ],
                                [
                                    0.3126807604360527,
                                    0.2107742780792813,
                                    0.28465948357593246,
                                    0.19188547790873353,
                                ],
                                [
                                    0.000666614660587396,
                                    0.06091316422324209,
                                    0.010158605446892486,
                                    0.928261615669278,
                                ],
                                [
                                    0.000666614660587396,
                                    0.010158605446892486,
                                    0.06091316422324209,
                                    0.928261615669278,
                                ],
                                [
                                    0.008603122597095336,
                                    0.7861264544163875,
                                    0.0022220975103845473,
                                    0.20304832547613272,
                                ],
                                [
                                    0.04803591462852022,
                                    0.7320239605318012,
                                    0.013543864255309263,
                                    0.20639626058436936,
                                ],
                                [
                                    0.04803591462852022,
                                    0.013543864255309263,
                                    0.7320239605318012,
                                    0.20639626058436936,
                                ],
                                [
                                    0.008603122597095336,
                                    0.0022220975103845473,
                                    0.7861264544163875,
                                    0.20304832547613272,
                                ],
                                [
                                    0.6199366546313524,
                                    0.1747929223821304,
                                    0.16012322052896902,
                                    0.04514720245754824,
                                ],
                                [
                                    0.6199366546313524,
                                    0.16012322052896902,
                                    0.1747929223821304,
                                    0.04514720245754824,
                                ],
                                [
                                    4.652552334569727e-05,
                                    0.021096102782498315,
                                    0.0021540298036775373,
                                    0.9767033418904785,
                                ],
                                [
                                    4.652552334569727e-05,
                                    0.0021540298036775373,
                                    0.021096102782498315,
                                    0.9767033418904785,
                                ],
                                [
                                    0.0020454668543144084,
                                    0.9274775627172167,
                                    0.00015508847270882632,
                                    0.07032188195576011,
                                ],
                                [
                                    0.020197351506731784,
                                    0.9350931267896234,
                                    0.0009452767991122291,
                                    0.04376424490453263,
                                ],
                                [
                                    0.020197351506731784,
                                    0.0009452767991122291,
                                    0.9350931267896234,
                                    0.04376424490453263,
                                ],
                                [
                                    0.0020454668543144084,
                                    0.00015508847270882632,
                                    0.9274775627172167,
                                    0.07032188195576011,
                                ],
                                [
                                    0.8879644995068651,
                                    0.041558530064666095,
                                    0.06732597878949018,
                                    0.003150991638978769,
                                ],
                                [
                                    0.8879644995068651,
                                    0.06732597878949018,
                                    0.041558530064666095,
                                    0.003150991638978769,
                                ],
                                [
                                    0.04070702375736941,
                                    0.004105726166176373,
                                    0.8676733775083177,
                                    0.08751387256813646,
                                ],
                                [
                                    0.04070702375736941,
                                    0.8676733775083177,
                                    0.004105726166176373,
                                    0.08751387256813646,
                                ],
                                [
                                    0.08132027702292326,
                                    0.008201994604267362,
                                    0.827060124242764,
                                    0.08341760413004547,
                                ],
                                [
                                    0.042809193308239,
                                    0.9124812849881162,
                                    0.0020035566153067774,
                                    0.04270596508833804,
                                ],
                                [
                                    0.042809193308239,
                                    0.0020035566153067774,
                                    0.9124812849881162,
                                    0.04270596508833804,
                                ],
                                [
                                    0.08132027702292326,
                                    0.827060124242764,
                                    0.008201994604267362,
                                    0.08341760413004547,
                                ],
                                [
                                    0.08551977368091515,
                                    0.004002497946275465,
                                    0.86977070461544,
                                    0.04070702375736934,
                                ],
                                [
                                    0.08551977368091515,
                                    0.86977070461544,
                                    0.004002497946275465,
                                    0.04070702375736934,
                                ],
                                [
                                    0.026827907767428896,
                                    0.009764761064875047,
                                    0.7063218903622245,
                                    0.2570854408054715,
                                ],
                                [
                                    0.026827907767428896,
                                    0.7063218903622245,
                                    0.009764761064875047,
                                    0.2570854408054715,
                                ],
                                [
                                    0.18807696589425005,
                                    0.06845582777773251,
                                    0.5450728322354034,
                                    0.19839437409261407,
                                ],
                                [
                                    0.03527222761305265,
                                    0.9286429154637592,
                                    0.0013204412192512937,
                                    0.03476441570393684,
                                ],
                                [
                                    0.03527222761305265,
                                    0.0013204412192512937,
                                    0.9286429154637592,
                                    0.03476441570393684,
                                ],
                                [
                                    0.18807696589425005,
                                    0.5450728322354034,
                                    0.06845582777773251,
                                    0.19839437409261407,
                                ],
                                [
                                    0.2472758445162233,
                                    0.009256949155759234,
                                    0.7166392985605885,
                                    0.026827907767428903,
                                ],
                                [
                                    0.2472758445162233,
                                    0.7166392985605885,
                                    0.009256949155759234,
                                    0.026827907767428903,
                                ],
                                [
                                    0.011701712202691797,
                                    0.012853603976153857,
                                    0.4648432492819742,
                                    0.5106014345391802,
                                ],
                                [
                                    0.011701712202691797,
                                    0.4648432492819742,
                                    0.012853603976153857,
                                    0.5106014345391802,
                                ],
                                [
                                    0.23879681251911355,
                                    0.26230346514439806,
                                    0.2377481489655524,
                                    0.261151573370936,
                                ],
                                [
                                    0.023979370292114624,
                                    0.9525655911925514,
                                    0.0005759458867310291,
                                    0.02287909262860298,
                                ],
                                [
                                    0.023979370292114624,
                                    0.0005759458867310291,
                                    0.9525655911925514,
                                    0.02287909262860298,
                                ],
                                [
                                    0.23879681251911355,
                                    0.2377481489655524,
                                    0.26230346514439806,
                                    0.261151573370936,
                                ],
                                [
                                    0.48934695135086936,
                                    0.011753326312642231,
                                    0.4871980101337966,
                                    0.011701712202691778,
                                ],
                                [
                                    0.48934695135086936,
                                    0.4871980101337966,
                                    0.011753326312642231,
                                    0.011701712202691778,
                                ],
                                [
                                    0.0027532024605122405,
                                    0.009764761064875125,
                                    0.21718692237916637,
                                    0.7702951140954463,
                                ],
                                [
                                    0.0027532024605122405,
                                    0.21718692237916637,
                                    0.009764761064875125,
                                    0.7702951140954463,
                                ],
                                [
                                    0.16400226058733336,
                                    0.5816655010677073,
                                    0.05593786425234527,
                                    0.19839437409261412,
                                ],
                                [
                                    0.012382453814927643,
                                    0.9767923260775925,
                                    0.00013550971045972305,
                                    0.01068971039702016,
                                ],
                                [
                                    0.012382453814927643,
                                    0.00013550971045972305,
                                    0.9767923260775925,
                                    0.01068971039702016,
                                ],
                                [
                                    0.16400226058733336,
                                    0.05593786425234527,
                                    0.5816655010677073,
                                    0.19839437409261412,
                                ],
                                [
                                    0.737595744008073,
                                    0.008072017646967663,
                                    0.2515790358844472,
                                    0.0027532024605122205,
                                ],
                                [
                                    0.737595744008073,
                                    0.2515790358844472,
                                    0.008072017646967663,
                                    0.0027532024605122205,
                                ],
                                [
                                    0.0001921562679691434,
                                    0.004105726166176385,
                                    0.04451736543567569,
                                    0.9511847521301787,
                                ],
                                [
                                    0.0001921562679691434,
                                    0.04451736543567569,
                                    0.004105726166176385,
                                    0.9511847521301787,
                                ],
                                [
                                    0.04080540953352299,
                                    0.8718728741663097,
                                    0.0039041121701218514,
                                    0.08341760413004555,
                                ],
                                [
                                    0.0042884247060601495,
                                    0.9935110199669166,
                                    9.45772808537842e-06,
                                    0.002191097598937831,
                                ],
                                [
                                    0.0042884247060601495,
                                    9.45772808537842e-06,
                                    0.9935110199669166,
                                    0.002191097598937831,
                                ],
                                [
                                    0.04080540953352299,
                                    0.0039041121701218514,
                                    0.8718728741663097,
                                    0.08341760413004555,
                                ],
                                [
                                    0.9106698846407785,
                                    0.002008399059054067,
                                    0.08712956003219825,
                                    0.0001921562679691428,
                                ],
                                [
                                    0.9106698846407785,
                                    0.08712956003219825,
                                    0.002008399059054067,
                                    0.0001921562679691428,
                                ],
                                [
                                    0.032854458560082234,
                                    0.01195829136346355,
                                    0.7002953395695712,
                                    0.25489191050688303,
                                ],
                                [
                                    0.032854458560082234,
                                    0.7002953395695712,
                                    0.01195829136346355,
                                    0.25489191050688303,
                                ],
                                [
                                    0.0656332353715828,
                                    0.02388903625560782,
                                    0.6675165627580706,
                                    0.24296116561473877,
                                ],
                                [
                                    0.03495662811095182,
                                    0.7451032470493696,
                                    0.009856121812593955,
                                    0.2100840030270846,
                                ],
                                [
                                    0.03495662811095182,
                                    0.009856121812593955,
                                    0.7451032470493696,
                                    0.2100840030270846,
                                ],
                                [
                                    0.0656332353715828,
                                    0.6675165627580706,
                                    0.02388903625560782,
                                    0.24296116561473877,
                                ],
                                [
                                    0.0698327320295747,
                                    0.019689539597615918,
                                    0.7102271431307466,
                                    0.20025058524206266,
                                ],
                                [
                                    0.0698327320295747,
                                    0.7102271431307466,
                                    0.019689539597615918,
                                    0.20025058524206266,
                                ],
                                [
                                    0.021652685523075938,
                                    0.014939983309228005,
                                    0.5700692690111882,
                                    0.39333806215650785,
                                ],
                                [
                                    0.021652685523075938,
                                    0.5700692690111882,
                                    0.014939983309228005,
                                    0.39333806215650785,
                                ],
                                [
                                    0.15179608607372064,
                                    0.10473670759826194,
                                    0.4399258684605435,
                                    0.30354133786747395,
                                ],
                                [
                                    0.030097005368699692,
                                    0.7923902941127229,
                                    0.006495663463604251,
                                    0.17101703705497315,
                                ],
                                [
                                    0.030097005368699692,
                                    0.006495663463604251,
                                    0.7923902941127229,
                                    0.17101703705497315,
                                ],
                                [
                                    0.15179608607372064,
                                    0.4399258684605435,
                                    0.10473670759826194,
                                    0.30354133786747395,
                                ],
                                [
                                    0.21099496469569393,
                                    0.04553782897628865,
                                    0.6114923347857287,
                                    0.13197487154228876,
                                ],
                                [
                                    0.21099496469569393,
                                    0.6114923347857287,
                                    0.04553782897628865,
                                    0.13197487154228876,
                                ],
                                [
                                    0.009444400085273898,
                                    0.015110916093571757,
                                    0.37517292744114683,
                                    0.6002717563800075,
                                ],
                                [
                                    0.009444400085273898,
                                    0.37517292744114683,
                                    0.015110916093571757,
                                    0.6002717563800075,
                                ],
                                [
                                    0.19273184961768722,
                                    0.30836842804582437,
                                    0.19188547790873353,
                                    0.3070142444277549,
                                ],
                                [
                                    0.021722058174696725,
                                    0.862895269351724,
                                    0.002833258004148929,
                                    0.1125494144694303,
                                ],
                                [
                                    0.021722058174696725,
                                    0.002833258004148929,
                                    0.862895269351724,
                                    0.1125494144694303,
                                ],
                                [
                                    0.19273184961768722,
                                    0.19188547790873353,
                                    0.30836842804582437,
                                    0.3070142444277549,
                                ],
                                [
                                    0.44328198844944305,
                                    0.05781828921406857,
                                    0.4413353390769777,
                                    0.05756438325951065,
                                ],
                                [
                                    0.44328198844944305,
                                    0.4413353390769777,
                                    0.05781828921406857,
                                    0.05756438325951065,
                                ],
                                [
                                    0.0022220975103845637,
                                    0.010295866015002802,
                                    0.1752906030081929,
                                    0.8121914334664198,
                                ],
                                [
                                    0.0022220975103845637,
                                    0.1752906030081929,
                                    0.010295866015002802,
                                    0.8121914334664198,
                                ],
                                [
                                    0.13236549806102924,
                                    0.6133022635940114,
                                    0.04514720245754824,
                                    0.20918503588741114,
                                ],
                                [
                                    0.011851348864799965,
                                    0.934896006706619,
                                    0.0006666146605874002,
                                    0.05258602976799364,
                                ],
                                [
                                    0.011851348864799965,
                                    0.0006666146605874002,
                                    0.934896006706619,
                                    0.05258602976799364,
                                ],
                                [
                                    0.13236549806102924,
                                    0.04514720245754824,
                                    0.6133022635940114,
                                    0.20918503588741114,
                                ],
                                [
                                    0.7059589814817689,
                                    0.0397087801732718,
                                    0.24078837408965015,
                                    0.013543864255309247,
                                ],
                                [
                                    0.7059589814817689,
                                    0.24078837408965015,
                                    0.0397087801732718,
                                    0.013543864255309247,
                                ],
                                [
                                    0.00015508847270882516,
                                    0.0041427939614367025,
                                    0.03592976845047936,
                                    0.9597723491153751,
                                ],
                                [
                                    0.00015508847270882516,
                                    0.03592976845047936,
                                    0.0041427939614367025,
                                    0.9597723491153751,
                                ],
                                [
                                    0.03293386528420942,
                                    0.8797444184156232,
                                    0.0031509916389787706,
                                    0.08417072466118863,
                                ],
                                [
                                    0.004251356910799831,
                                    0.9849234229817203,
                                    4.6525523345696795e-05,
                                    0.010778694584134196,
                                ],
                                [
                                    0.004251356910799831,
                                    4.6525523345696795e-05,
                                    0.9849234229817203,
                                    0.010778694584134196,
                                ],
                                [
                                    0.03293386528420942,
                                    0.0031509916389787706,
                                    0.8797444184156232,
                                    0.08417072466118863,
                                ],
                                [
                                    0.902798340391465,
                                    0.009879943308367667,
                                    0.08637643950105517,
                                    0.0009452767991122269,
                                ],
                                [
                                    0.902798340391465,
                                    0.08637643950105517,
                                    0.009879943308367667,
                                    0.0009452767991122269,
                                ],
                                [
                                    0.021355290186338093,
                                    0.023457459737207687,
                                    0.4551896712983279,
                                    0.49999757877812634,
                                ],
                                [
                                    0.021355290186338093,
                                    0.4551896712983279,
                                    0.023457459737207687,
                                    0.49999757877812634,
                                ],
                                [
                                    0.042661387484599356,
                                    0.046860884142591264,
                                    0.4338835740000666,
                                    0.4765941543727428,
                                ],
                                [
                                    0.023457459737207687,
                                    0.49999757877812634,
                                    0.021355290186338093,
                                    0.4551896712983279,
                                ],
                                [
                                    0.023457459737207687,
                                    0.021355290186338093,
                                    0.49999757877812634,
                                    0.4551896712983279,
                                ],
                                [
                                    0.042661387484599356,
                                    0.4338835740000666,
                                    0.046860884142591264,
                                    0.4765941543727428,
                                ],
                                [
                                    0.046860884142591264,
                                    0.042661387484599356,
                                    0.4765941543727428,
                                    0.4338835740000666,
                                ],
                                [
                                    0.046860884142591264,
                                    0.4765941543727428,
                                    0.042661387484599356,
                                    0.4338835740000666,
                                ],
                                [
                                    0.014074174493340098,
                                    0.022518494338963847,
                                    0.3705431530330808,
                                    0.5928641781346153,
                                ],
                                [
                                    0.014074174493340098,
                                    0.3705431530330808,
                                    0.022518494338963847,
                                    0.5928641781346153,
                                ],
                                [
                                    0.09866695752500466,
                                    0.1578658361469779,
                                    0.2859503700014162,
                                    0.45751683632660123,
                                ],
                                [
                                    0.02251849433896385,
                                    0.5928641781346154,
                                    0.014074174493340095,
                                    0.37054315303308066,
                                ],
                                [
                                    0.02251849433896385,
                                    0.014074174493340095,
                                    0.5928641781346154,
                                    0.37054315303308066,
                                ],
                                [
                                    0.09866695752500466,
                                    0.2859503700014162,
                                    0.1578658361469779,
                                    0.45751683632660123,
                                ],
                                [
                                    0.15786583614697794,
                                    0.09866695752500464,
                                    0.45751683632660134,
                                    0.2859503700014161,
                                ],
                                [
                                    0.15786583614697794,
                                    0.45751683632660134,
                                    0.09866695752500464,
                                    0.2859503700014161,
                                ],
                                [
                                    0.0061388290447114136,
                                    0.01841648713413424,
                                    0.2438611709552886,
                                    0.7315835128658658,
                                ],
                                [
                                    0.0061388290447114136,
                                    0.2438611709552886,
                                    0.01841648713413424,
                                    0.7315835128658658,
                                ],
                                [
                                    0.1252750694158779,
                                    0.3758252082476337,
                                    0.1247249305841221,
                                    0.3741747917523663,
                                ],
                                [
                                    0.01841648713413424,
                                    0.7315835128658658,
                                    0.0061388290447114136,
                                    0.2438611709552886,
                                ],
                                [
                                    0.01841648713413424,
                                    0.0061388290447114136,
                                    0.7315835128658658,
                                    0.2438611709552886,
                                ],
                                [
                                    0.1252750694158779,
                                    0.1247249305841221,
                                    0.3758252082476337,
                                    0.3741747917523663,
                                ],
                                [
                                    0.3758252082476337,
                                    0.1252750694158779,
                                    0.3741747917523663,
                                    0.1247249305841221,
                                ],
                                [
                                    0.3758252082476337,
                                    0.3741747917523663,
                                    0.1252750694158779,
                                    0.1247249305841221,
                                ],
                                [
                                    0.001444356085485982,
                                    0.011073607439901384,
                                    0.11393831638809326,
                                    0.8735437200865194,
                                ],
                                [
                                    0.001444356085485982,
                                    0.11393831638809326,
                                    0.011073607439901384,
                                    0.8735437200865194,
                                ],
                                [
                                    0.08603713911715051,
                                    0.6596306225378902,
                                    0.02934553335642874,
                                    0.22498670498853063,
                                ],
                                [
                                    0.011073607439901384,
                                    0.8735437200865194,
                                    0.001444356085485982,
                                    0.11393831638809326,
                                ],
                                [
                                    0.011073607439901384,
                                    0.001444356085485982,
                                    0.8735437200865194,
                                    0.11393831638809326,
                                ],
                                [
                                    0.08603713911715051,
                                    0.02934553335642874,
                                    0.6596306225378902,
                                    0.22498670498853063,
                                ],
                                [
                                    0.6596306225378902,
                                    0.08603713911715051,
                                    0.22498670498853063,
                                    0.02934553335642874,
                                ],
                                [
                                    0.6596306225378902,
                                    0.22498670498853063,
                                    0.08603713911715051,
                                    0.02934553335642874,
                                ],
                                [
                                    0.00010080699802726096,
                                    0.004197075436118267,
                                    0.023354231517306777,
                                    0.9723478860485477,
                                ],
                                [
                                    0.00010080699802726096,
                                    0.023354231517306777,
                                    0.004197075436118267,
                                    0.9723478860485477,
                                ],
                                [
                                    0.02140690429628854,
                                    0.8912713794035441,
                                    0.0020481342190454984,
                                    0.0852735820811219,
                                ],
                                [
                                    0.004197075436118267,
                                    0.9723478860485477,
                                    0.00010080699802726096,
                                    0.023354231517306777,
                                ],
                                [
                                    0.004197075436118267,
                                    0.00010080699802726096,
                                    0.9723478860485477,
                                    0.023354231517306777,
                                ],
                                [
                                    0.02140690429628854,
                                    0.0020481342190454984,
                                    0.8912713794035441,
                                    0.0852735820811219,
                                ],
                                [
                                    0.8912713794035441,
                                    0.02140690429628854,
                                    0.0852735820811219,
                                    0.0020481342190454984,
                                ],
                                [
                                    0.8912713794035441,
                                    0.0852735820811219,
                                    0.02140690429628854,
                                    0.0020481342190454984,
                                ],
                                [
                                    0.009856121812593958,
                                    0.03495662811095182,
                                    0.21008400302708466,
                                    0.7451032470493696,
                                ],
                                [
                                    0.009856121812593958,
                                    0.21008400302708466,
                                    0.03495662811095182,
                                    0.7451032470493696,
                                ],
                                [
                                    0.019689539597615924,
                                    0.0698327320295747,
                                    0.20025058524206268,
                                    0.7102271431307466,
                                ],
                                [
                                    0.011958291363463555,
                                    0.25489191050688315,
                                    0.03285445856008223,
                                    0.7002953395695711,
                                ],
                                [
                                    0.011958291363463555,
                                    0.03285445856008223,
                                    0.25489191050688315,
                                    0.7002953395695711,
                                ],
                                [
                                    0.019689539597615924,
                                    0.20025058524206268,
                                    0.0698327320295747,
                                    0.7102271431307466,
                                ],
                                [
                                    0.023889036255607825,
                                    0.06563323537158279,
                                    0.24296116561473888,
                                    0.6675165627580705,
                                ],
                                [
                                    0.023889036255607825,
                                    0.24296116561473888,
                                    0.06563323537158279,
                                    0.6675165627580705,
                                ],
                                [
                                    0.006495663463604254,
                                    0.03009700536869969,
                                    0.17101703705497323,
                                    0.7923902941127229,
                                ],
                                [
                                    0.006495663463604254,
                                    0.17101703705497323,
                                    0.03009700536869969,
                                    0.7923902941127229,
                                ],
                                [
                                    0.04553782897628867,
                                    0.2109949646956939,
                                    0.13197487154228882,
                                    0.6114923347857286,
                                ],
                                [
                                    0.01493998330922801,
                                    0.39333806215650796,
                                    0.021652685523075935,
                                    0.570069269011188,
                                ],
                                [
                                    0.01493998330922801,
                                    0.021652685523075935,
                                    0.39333806215650796,
                                    0.570069269011188,
                                ],
                                [
                                    0.04553782897628867,
                                    0.13197487154228882,
                                    0.2109949646956939,
                                    0.6114923347857286,
                                ],
                                [
                                    0.10473670759826197,
                                    0.1517960860737206,
                                    0.303541337867474,
                                    0.43992586846054343,
                                ],
                                [
                                    0.10473670759826197,
                                    0.303541337867474,
                                    0.1517960860737206,
                                    0.43992586846054343,
                                ],
                                [
                                    0.00283325800414893,
                                    0.021722058174696725,
                                    0.11254941446943031,
                                    0.862895269351724,
                                ],
                                [
                                    0.00283325800414893,
                                    0.11254941446943031,
                                    0.021722058174696725,
                                    0.862895269351724,
                                ],
                                [
                                    0.057818289214068584,
                                    0.44328198844944305,
                                    0.05756438325951067,
                                    0.4413353390769777,
                                ],
                                [
                                    0.015110916093571757,
                                    0.6002717563800075,
                                    0.009444400085273898,
                                    0.37517292744114683,
                                ],
                                [
                                    0.015110916093571757,
                                    0.009444400085273898,
                                    0.6002717563800075,
                                    0.37517292744114683,
                                ],
                                [
                                    0.057818289214068584,
                                    0.05756438325951067,
                                    0.44328198844944305,
                                    0.4413353390769777,
                                ],
                                [
                                    0.30836842804582437,
                                    0.19273184961768722,
                                    0.3070142444277549,
                                    0.19188547790873353,
                                ],
                                [
                                    0.30836842804582437,
                                    0.3070142444277549,
                                    0.19273184961768722,
                                    0.19188547790873353,
                                ],
                                [
                                    0.0006666146605873999,
                                    0.011851348864799965,
                                    0.05258602976799362,
                                    0.934896006706619,
                                ],
                                [
                                    0.0006666146605873999,
                                    0.05258602976799362,
                                    0.011851348864799965,
                                    0.934896006706619,
                                ],
                                [
                                    0.03970878017327178,
                                    0.7059589814817689,
                                    0.013543864255309242,
                                    0.24078837408965015,
                                ],
                                [
                                    0.010295866015002802,
                                    0.8121914334664198,
                                    0.0022220975103845633,
                                    0.17529060300819288,
                                ],
                                [
                                    0.010295866015002802,
                                    0.0022220975103845633,
                                    0.8121914334664198,
                                    0.17529060300819288,
                                ],
                                [
                                    0.03970878017327178,
                                    0.013543864255309242,
                                    0.7059589814817689,
                                    0.24078837408965015,
                                ],
                                [
                                    0.6133022635940114,
                                    0.13236549806102924,
                                    0.20918503588741114,
                                    0.04514720245754823,
                                ],
                                [
                                    0.6133022635940114,
                                    0.20918503588741114,
                                    0.13236549806102924,
                                    0.04514720245754823,
                                ],
                                [
                                    4.6525523345696755e-05,
                                    0.004251356910799831,
                                    0.010778694584134186,
                                    0.9849234229817203,
                                ],
                                [
                                    4.6525523345696755e-05,
                                    0.010778694584134186,
                                    0.004251356910799831,
                                    0.9849234229817203,
                                ],
                                [
                                    0.009879943308367656,
                                    0.902798340391465,
                                    0.0009452767991122259,
                                    0.08637643950105517,
                                ],
                                [
                                    0.0041427939614367025,
                                    0.9597723491153751,
                                    0.0001550884727088251,
                                    0.03592976845047935,
                                ],
                                [
                                    0.0041427939614367025,
                                    0.0001550884727088251,
                                    0.9597723491153751,
                                    0.03592976845047935,
                                ],
                                [
                                    0.009879943308367656,
                                    0.0009452767991122259,
                                    0.902798340391465,
                                    0.08637643950105517,
                                ],
                                [
                                    0.8797444184156232,
                                    0.032933865284209406,
                                    0.08417072466118863,
                                    0.0031509916389787693,
                                ],
                                [
                                    0.8797444184156232,
                                    0.08417072466118863,
                                    0.032933865284209406,
                                    0.0031509916389787693,
                                ],
                                [
                                    0.0020035566153067787,
                                    0.042809193308239,
                                    0.04270596508833806,
                                    0.9124812849881162,
                                ],
                                [
                                    0.0020035566153067787,
                                    0.04270596508833806,
                                    0.042809193308239,
                                    0.9124812849881162,
                                ],
                                [
                                    0.0040024979462754675,
                                    0.08551977368091515,
                                    0.04070702375736937,
                                    0.86977070461544,
                                ],
                                [
                                    0.004105726166176376,
                                    0.08751387256813653,
                                    0.040707023757369405,
                                    0.8676733775083176,
                                ],
                                [
                                    0.004105726166176376,
                                    0.040707023757369405,
                                    0.08751387256813653,
                                    0.8676733775083176,
                                ],
                                [
                                    0.0040024979462754675,
                                    0.04070702375736937,
                                    0.08551977368091515,
                                    0.86977070461544,
                                ],
                                [
                                    0.008201994604267371,
                                    0.08132027702292324,
                                    0.08341760413004554,
                                    0.8270601242427639,
                                ],
                                [
                                    0.008201994604267371,
                                    0.08341760413004554,
                                    0.08132027702292324,
                                    0.8270601242427639,
                                ],
                                [
                                    0.0013204412192512956,
                                    0.03527222761305265,
                                    0.034764415703936895,
                                    0.9286429154637592,
                                ],
                                [
                                    0.0013204412192512956,
                                    0.034764415703936895,
                                    0.03527222761305265,
                                    0.9286429154637592,
                                ],
                                [
                                    0.009256949155759248,
                                    0.2472758445162233,
                                    0.026827907767428945,
                                    0.7166392985605885,
                                ],
                                [
                                    0.00976476106487505,
                                    0.25708544080547163,
                                    0.026827907767428893,
                                    0.7063218903622244,
                                ],
                                [
                                    0.00976476106487505,
                                    0.026827907767428893,
                                    0.25708544080547163,
                                    0.7063218903622244,
                                ],
                                [
                                    0.009256949155759248,
                                    0.026827907767428945,
                                    0.2472758445162233,
                                    0.7166392985605885,
                                ],
                                [
                                    0.06845582777773254,
                                    0.18807696589425002,
                                    0.19839437409261415,
                                    0.5450728322354033,
                                ],
                                [
                                    0.06845582777773254,
                                    0.19839437409261415,
                                    0.18807696589425002,
                                    0.5450728322354033,
                                ],
                                [
                                    0.0005759458867310299,
                                    0.023979370292114624,
                                    0.022879092628603007,
                                    0.9525655911925514,
                                ],
                                [
                                    0.0005759458867310299,
                                    0.022879092628603007,
                                    0.023979370292114624,
                                    0.9525655911925514,
                                ],
                                [
                                    0.011753326312642245,
                                    0.48934695135086936,
                                    0.011701712202691792,
                                    0.4871980101337966,
                                ],
                                [
                                    0.012853603976153857,
                                    0.5106014345391802,
                                    0.011701712202691797,
                                    0.4648432492819742,
                                ],
                                [
                                    0.012853603976153857,
                                    0.011701712202691797,
                                    0.5106014345391802,
                                    0.4648432492819742,
                                ],
                                [
                                    0.011753326312642245,
                                    0.011701712202691792,
                                    0.48934695135086936,
                                    0.4871980101337966,
                                ],
                                [
                                    0.26230346514439806,
                                    0.23879681251911355,
                                    0.261151573370936,
                                    0.2377481489655524,
                                ],
                                [
                                    0.26230346514439806,
                                    0.261151573370936,
                                    0.23879681251911355,
                                    0.2377481489655524,
                                ],
                                [
                                    0.00013550971045972305,
                                    0.012382453814927643,
                                    0.01068971039702016,
                                    0.9767923260775925,
                                ],
                                [
                                    0.00013550971045972305,
                                    0.01068971039702016,
                                    0.012382453814927643,
                                    0.9767923260775925,
                                ],
                                [
                                    0.008072017646967663,
                                    0.737595744008073,
                                    0.0027532024605122205,
                                    0.2515790358844472,
                                ],
                                [
                                    0.009764761064875125,
                                    0.7702951140954463,
                                    0.0027532024605122405,
                                    0.21718692237916637,
                                ],
                                [
                                    0.009764761064875125,
                                    0.0027532024605122405,
                                    0.7702951140954463,
                                    0.21718692237916637,
                                ],
                                [
                                    0.008072017646967663,
                                    0.0027532024605122205,
                                    0.737595744008073,
                                    0.2515790358844472,
                                ],
                                [
                                    0.5816655010677073,
                                    0.16400226058733336,
                                    0.19839437409261412,
                                    0.05593786425234527,
                                ],
                                [
                                    0.5816655010677073,
                                    0.19839437409261412,
                                    0.16400226058733336,
                                    0.05593786425234527,
                                ],
                                [
                                    9.457728085378528e-06,
                                    0.0042884247060601495,
                                    0.0021910975989378563,
                                    0.9935110199669166,
                                ],
                                [
                                    9.457728085378528e-06,
                                    0.0021910975989378563,
                                    0.0042884247060601495,
                                    0.9935110199669166,
                                ],
                                [
                                    0.00200839905905409,
                                    0.9106698846407785,
                                    0.000192156267969145,
                                    0.08712956003219825,
                                ],
                                [
                                    0.004105726166176385,
                                    0.9511847521301787,
                                    0.00019215626796914348,
                                    0.044517365435675714,
                                ],
                                [
                                    0.004105726166176385,
                                    0.00019215626796914348,
                                    0.9511847521301787,
                                    0.044517365435675714,
                                ],
                                [
                                    0.00200839905905409,
                                    0.000192156267969145,
                                    0.9106698846407785,
                                    0.08712956003219825,
                                ],
                                [
                                    0.8718728741663097,
                                    0.040805409533523004,
                                    0.08341760413004555,
                                    0.0039041121701218536,
                                ],
                                [
                                    0.8718728741663097,
                                    0.08341760413004555,
                                    0.040805409533523004,
                                    0.0039041121701218536,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                5.0653200531719395e-05,
                                5.0653200531719395e-05,
                                5.0653200531719395e-05,
                                5.0653200531719395e-05,
                                5.0653200531719395e-05,
                                5.0653200531719395e-05,
                                5.0653200531719395e-05,
                                5.0653200531719395e-05,
                                0.0004027638104867261,
                                0.0004027638104867261,
                                0.0004027638104867261,
                                0.0004027638104867261,
                                0.0004027638104867261,
                                0.0004027638104867261,
                                0.0004027638104867261,
                                0.0004027638104867261,
                                0.000665593341842671,
                                0.000665593341842671,
                                0.000665593341842671,
                                0.000665593341842671,
                                0.000665593341842671,
                                0.000665593341842671,
                                0.000665593341842671,
                                0.000665593341842671,
                                0.00039247880546818854,
                                0.00039247880546818854,
                                0.00039247880546818854,
                                0.00039247880546818854,
                                0.00039247880546818854,
                                0.00039247880546818854,
                                0.00039247880546818854,
                                0.00039247880546818854,
                                4.849523661445467e-05,
                                4.849523661445467e-05,
                                4.849523661445467e-05,
                                4.849523661445467e-05,
                                4.849523661445467e-05,
                                4.849523661445467e-05,
                                4.849523661445467e-05,
                                4.849523661445467e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                4.2616536375646826e-05,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0003388610867669303,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                0.0003302079061999542,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                4.080095617909327e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                2.1095692418156473e-05,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.0001677402686109048,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                0.00016345684130300158,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                4.261653637564684e-05,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.00033886108676693037,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                0.00033020790619995433,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                4.0800956179093276e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                3.5854973695483094e-05,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.0002850972037087961,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                0.00027781694144448667,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                3.4327454433578284e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                2.1095692418156476e-05,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.00016774026861090486,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                0.00016345684130300163,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                2.0196958625025485e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                1.774863846451018e-05,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00014112650699023348,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                0.00013752269057264332,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                1.6992498260437476e-05,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                8.78578715520226e-06,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                6.985929962192025e-05,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                6.807536762878837e-05,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                8.411488760102387e-06,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                0.00010144275465244485,
                                0.00010144275465244485,
                                0.00010144275465244485,
                                0.00010144275465244485,
                                0.00010144275465244485,
                                0.00010144275465244485,
                                0.00010144275465244485,
                                0.00010144275465244485,
                                0.0007787460770806568,
                                0.0007787460770806568,
                                0.0007787460770806568,
                                0.0007787460770806568,
                                0.0007787460770806568,
                                0.0007787460770806568,
                                0.0007787460770806568,
                                0.0007787460770806568,
                                0.001218025925829118,
                                0.001218025925829118,
                                0.001218025925829118,
                                0.001218025925829118,
                                0.001218025925829118,
                                0.001218025925829118,
                                0.001218025925829118,
                                0.001218025925829118,
                                0.0006765360939753942,
                                0.0006765360939753942,
                                0.0006765360939753942,
                                0.0006765360939753942,
                                0.0006765360939753942,
                                0.0006765360939753942,
                                0.0006765360939753942,
                                0.0006765360939753942,
                                7.999741212438053e-05,
                                7.999741212438053e-05,
                                7.999741212438053e-05,
                                7.999741212438053e-05,
                                7.999741212438053e-05,
                                7.999741212438053e-05,
                                7.999741212438053e-05,
                                7.999741212438053e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                4.224817243005999e-05,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0003243267462171923,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.331676543059989e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                8.534779240621829e-05,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.0006551898038608214,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                0.0005691965118825185,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                6.730497950709748e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                7.180646556347605e-05,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0005512370356874626,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                0.00047888748586266764,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                5.662633510453561e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                3.554505457247037e-05,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                0.00023705500173956255,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                2.8030709431735428e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                4.224817243006e-05,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.00032432674621719237,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                0.0002817590438209071,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.3316765430599895e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                3.5545054572470376e-05,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.0002728688894812267,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                0.00023705500173956258,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                2.8030709431735435e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                1.759522481221446e-05,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.00013507334599508551,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                0.00011734504556642205,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                1.3875534586440995e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                0.00011903343985166553,
                                0.00011903343985166553,
                                0.00011903343985166553,
                                0.00011903343985166553,
                                0.00011903343985166553,
                                0.00011903343985166553,
                                0.00011903343985166553,
                                0.00011903343985166553,
                                0.0008648602855822686,
                                0.0008648602855822686,
                                0.0008648602855822686,
                                0.0008648602855822686,
                                0.0008648602855822686,
                                0.0008648602855822686,
                                0.0008648602855822686,
                                0.0008648602855822686,
                                0.0012274140649291276,
                                0.0012274140649291276,
                                0.0012274140649291276,
                                0.0012274140649291276,
                                0.0012274140649291276,
                                0.0012274140649291276,
                                0.0012274140649291276,
                                0.0012274140649291276,
                                0.0006016387168744261,
                                0.0006016387168744261,
                                0.0006016387168744261,
                                0.0006016387168744261,
                                0.0006016387168744261,
                                0.0006016387168744261,
                                0.0006016387168744261,
                                0.0006016387168744261,
                                6.380520744015403e-05,
                                6.380520744015403e-05,
                                6.380520744015403e-05,
                                6.380520744015403e-05,
                                6.380520744015403e-05,
                                6.380520744015403e-05,
                                6.380520744015403e-05,
                                6.380520744015403e-05,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                4.9574218573087015e-05,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                0.00025056630548131714,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                2.6573148719226026e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.000100147529990336,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0007276410855280253,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                0.0005061823930872967,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                5.368183876409271e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                8.425806878859947e-05,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0006121931578716699,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                0.0004258712211918054,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.51646492301897e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                4.9574218573087e-05,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0003601909924309218,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                0.0002505663054813171,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                2.6573148719226022e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                4.170874627737002e-05,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00030304289501904965,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                0.00021081132011331003,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.2357038590270658e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                2.0646325521590964e-05,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.00015000983764796916,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                0.00010435411099990905,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.1067000033130824e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                9.885230532822716e-05,
                                9.885230532822716e-05,
                                9.885230532822716e-05,
                                9.885230532822716e-05,
                                9.885230532822716e-05,
                                9.885230532822716e-05,
                                9.885230532822716e-05,
                                9.885230532822716e-05,
                                0.000676536093975394,
                                0.000676536093975394,
                                0.000676536093975394,
                                0.000676536093975394,
                                0.000676536093975394,
                                0.000676536093975394,
                                0.000676536093975394,
                                0.000676536093975394,
                                0.0008473178470002798,
                                0.0008473178470002798,
                                0.0008473178470002798,
                                0.0008473178470002798,
                                0.0008473178470002798,
                                0.0008473178470002798,
                                0.0008473178470002798,
                                0.0008473178470002798,
                                0.0003358286921991994,
                                0.0003358286921991994,
                                0.0003358286921991994,
                                0.0003358286921991994,
                                0.0003358286921991994,
                                0.0003358286921991994,
                                0.0003358286921991994,
                                0.0003358286921991994,
                                2.7366265403804892e-05,
                                2.7366265403804892e-05,
                                2.7366265403804892e-05,
                                2.7366265403804892e-05,
                                2.7366265403804892e-05,
                                2.7366265403804892e-05,
                                2.7366265403804892e-05,
                                2.7366265403804892e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                4.116932012468006e-05,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00028175904382090694,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                0.0001398635964057131,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                1.1397311749941422e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                8.316834517098065e-05,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0005691965118825184,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                0.0002825459305010924,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                2.3024318953281912e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                6.997281060378313e-05,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0004788874858626674,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                0.00023771704055404247,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                1.9371268071848456e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                3.4637373556590955e-05,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                0.00011767276265436278,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                9.589008111576444e-06,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                4.1169320124680065e-05,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.000281759043820907,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                0.00013986359640571314,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                1.1397311749941423e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                3.463737355659096e-05,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.0002370550017395625,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                0.00011767276265436279,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                9.589008111576446e-06,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                1.714591191273317e-05,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00011734504556642202,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                5.824941719969822e-05,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                4.7466730738967485e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                4.84952366144546e-05,
                                4.84952366144546e-05,
                                4.84952366144546e-05,
                                4.84952366144546e-05,
                                4.84952366144546e-05,
                                4.84952366144546e-05,
                                4.84952366144546e-05,
                                4.84952366144546e-05,
                                0.00031761817437511746,
                                0.00031761817437511746,
                                0.00031761817437511746,
                                0.00031761817437511746,
                                0.00031761817437511746,
                                0.00031761817437511746,
                                0.00031761817437511746,
                                0.00031761817437511746,
                                0.0003567763924152672,
                                0.0003567763924152672,
                                0.0003567763924152672,
                                0.0003567763924152672,
                                0.0003567763924152672,
                                0.0003567763924152672,
                                0.0003567763924152672,
                                0.0003567763924152672,
                                0.00010865380549444563,
                                0.00010865380549444563,
                                0.00010865380549444563,
                                0.00010865380549444563,
                                0.00010865380549444563,
                                0.00010865380549444563,
                                0.00010865380549444563,
                                0.00010865380549444563,
                                4.651060823997379e-06,
                                4.651060823997379e-06,
                                4.651060823997379e-06,
                                4.651060823997379e-06,
                                4.651060823997379e-06,
                                4.651060823997379e-06,
                                4.651060823997379e-06,
                                4.651060823997379e-06,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                4.080095617909322e-05,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                9.141473402666583e-05,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                3.91312100144804e-06,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                2.0196958625025458e-05,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001322794066850335,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                4.525138069681654e-05,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                4.0800956179093235e-05,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00026722470327116894,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                9.141473402666585e-05,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.913121001448041e-06,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                3.4327454433578236e-05,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.0002248266875119931,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                7.69108229494387e-05,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                3.2922631097335967e-06,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                2.019695862502546e-05,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00013227940668503356,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                4.525138069681655e-05,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.9370414412361627e-06,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                1.6992498260437456e-05,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.00011129188457127403,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                3.807177219347692e-05,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                1.6297093999002668e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                8.41148876010238e-06,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                5.50908066497447e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                1.884598008923764e-05,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                                8.067255379045941e-07,
                            ]
                        ),
                    )
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.EdgeAdjacentQuadrilaterals:
            match order:
                case 1:
                    return (
                        np.array(
                            [
                                [0.0625, 0.1875, 0.1875, 0.5625],
                                [0.1875, 0.5625, 0.0625, 0.1875],
                                [0.09375, 0.28125, 0.15625, 0.46875],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.15625, 0.46875, 0.09375, 0.28125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                            ]
                        ),
                        np.array(
                            [
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [0.46875, 0.15625, 0.28125, 0.09375],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.28125, 0.09375, 0.46875, 0.15625],
                            ]
                        ),
                        np.array([0.125, 0.125, 0.1875, 0.1875, 0.1875, 0.1875]),
                    )
                case 2:
                    return (
                        np.array(
                            [
                                [
                                    0.027777777777777807,
                                    0.5942306901503683,
                                    0.016880420960742694,
                                    0.3611111111111111,
                                ],
                                [
                                    0.037215165615433754,
                                    0.7961181677178996,
                                    0.007443033123086752,
                                    0.15922363354357993,
                                ],
                                [
                                    0.03364791292792191,
                                    0.7198064107660265,
                                    0.0110102858105986,
                                    0.23553539049545305,
                                ],
                                [
                                    0.15922363354357993,
                                    0.5942306901503684,
                                    0.0521012318616072,
                                    0.19444444444444445,
                                ],
                                [
                                    0.03564226764249109,
                                    0.7624702547899777,
                                    0.009015931096029408,
                                    0.1928715464715018,
                                ],
                                [
                                    0.16866102138123587,
                                    0.6294515010512329,
                                    0.042663844023951264,
                                    0.15922363354357993,
                                ],
                                [
                                    0.027777777777777783,
                                    0.13888888888888884,
                                    0.13888888888888895,
                                    0.6944444444444444,
                                ],
                                [
                                    0.15922363354358,
                                    0.7961181677178996,
                                    0.007443033123086746,
                                    0.03721516561543371,
                                ],
                                [
                                    0.1095382131381685,
                                    0.5476910656908422,
                                    0.05712845352849824,
                                    0.28564226764249107,
                                ],
                                [
                                    0.5183403899401218,
                                    0.1388888888888889,
                                    0.27033474465469104,
                                    0.07243597651629824,
                                ],
                                [
                                    0.1373159909159463,
                                    0.6865799545797311,
                                    0.029350675750720444,
                                    0.14675337875360214,
                                ],
                                [
                                    0.6497862457059239,
                                    0.1741096997897534,
                                    0.1388888888888889,
                                    0.03721516561543371,
                                ],
                                [
                                    0.007443033123086749,
                                    0.15922363354357988,
                                    0.037215165615433754,
                                    0.7961181677178996,
                                ],
                                [
                                    0.016880420960742694,
                                    0.36111111111111105,
                                    0.02777777777777781,
                                    0.5942306901503684,
                                ],
                                [
                                    0.00901593109602941,
                                    0.19287154647150181,
                                    0.03564226764249109,
                                    0.7624702547899777,
                                ],
                                [
                                    0.04266384402395127,
                                    0.15922363354357996,
                                    0.16866102138123587,
                                    0.6294515010512329,
                                ],
                                [
                                    0.011010285810598604,
                                    0.23553539049545313,
                                    0.0336479129279219,
                                    0.7198064107660264,
                                ],
                                [
                                    0.052101231861607214,
                                    0.1944444444444445,
                                    0.1592236335435799,
                                    0.5942306901503683,
                                ],
                                [
                                    0.007443033123086735,
                                    0.03721516561543366,
                                    0.15922363354358002,
                                    0.7961181677178996,
                                ],
                                [
                                    0.13888888888888895,
                                    0.6944444444444443,
                                    0.027777777777777794,
                                    0.1388888888888889,
                                ],
                                [
                                    0.029350675750720454,
                                    0.1467533787536022,
                                    0.1373159909159463,
                                    0.6865799545797311,
                                ],
                                [
                                    0.13888888888888892,
                                    0.037215165615433726,
                                    0.6497862457059239,
                                    0.1741096997897534,
                                ],
                                [
                                    0.057128453528498255,
                                    0.2856422676424911,
                                    0.10953821313816849,
                                    0.5476910656908421,
                                ],
                                [
                                    0.27033474465469115,
                                    0.07243597651629827,
                                    0.5183403899401218,
                                    0.13888888888888887,
                                ],
                                [
                                    0.1036680779880244,
                                    0.5183403899401218,
                                    0.06299858867864233,
                                    0.3149929433932115,
                                ],
                                [
                                    0.13888888888888895,
                                    0.6944444444444443,
                                    0.027777777777777794,
                                    0.1388888888888889,
                                ],
                                [
                                    0.1255757206156581,
                                    0.6278786030782902,
                                    0.041090946051008624,
                                    0.20545473025504302,
                                ],
                                [
                                    0.15922363354357993,
                                    0.5942306901503684,
                                    0.0521012318616072,
                                    0.19444444444444445,
                                ],
                                [
                                    0.13301875373874486,
                                    0.6650937686937239,
                                    0.03364791292792188,
                                    0.16823956463960932,
                                ],
                                [
                                    0.16866102138123587,
                                    0.6294515010512329,
                                    0.042663844023951264,
                                    0.15922363354357993,
                                ],
                                [
                                    0.10366807798802435,
                                    0.06299858867864228,
                                    0.5183403899401219,
                                    0.3149929433932115,
                                ],
                                [
                                    0.5942306901503684,
                                    0.36111111111111105,
                                    0.027777777777777783,
                                    0.016880420960742673,
                                ],
                                [
                                    0.4088021768019534,
                                    0.24842710202705734,
                                    0.21320629112619285,
                                    0.12956443004479642,
                                ],
                                [
                                    0.5183403899401218,
                                    0.1388888888888889,
                                    0.27033474465469104,
                                    0.07243597651629824,
                                ],
                                [
                                    0.5124702547899778,
                                    0.3114256907056996,
                                    0.10953821313816846,
                                    0.06656584136615414,
                                ],
                                [
                                    0.6497862457059239,
                                    0.1741096997897534,
                                    0.1388888888888889,
                                    0.03721516561543371,
                                ],
                                [
                                    0.027777777777777783,
                                    0.13888888888888884,
                                    0.13888888888888895,
                                    0.6944444444444444,
                                ],
                                [
                                    0.06299858867864232,
                                    0.31499294339321143,
                                    0.10366807798802442,
                                    0.5183403899401218,
                                ],
                                [
                                    0.03364791292792189,
                                    0.16823956463960935,
                                    0.13301875373874486,
                                    0.6650937686937239,
                                ],
                                [
                                    0.04266384402395127,
                                    0.15922363354357996,
                                    0.16866102138123587,
                                    0.6294515010512329,
                                ],
                                [
                                    0.04109094605100864,
                                    0.2054547302550431,
                                    0.1255757206156581,
                                    0.6278786030782901,
                                ],
                                [
                                    0.052101231861607214,
                                    0.1944444444444445,
                                    0.1592236335435799,
                                    0.5942306901503683,
                                ],
                                [
                                    0.02777777777777774,
                                    0.016880420960742652,
                                    0.5942306901503684,
                                    0.3611111111111111,
                                ],
                                [
                                    0.5183403899401218,
                                    0.31499294339321143,
                                    0.10366807798802438,
                                    0.0629985886786423,
                                ],
                                [
                                    0.10953821313816849,
                                    0.06656584136615416,
                                    0.5124702547899778,
                                    0.3114256907056996,
                                ],
                                [
                                    0.13888888888888892,
                                    0.037215165615433726,
                                    0.6497862457059239,
                                    0.1741096997897534,
                                ],
                                [
                                    0.2132062911261929,
                                    0.12956443004479648,
                                    0.4088021768019533,
                                    0.24842710202705728,
                                ],
                                [
                                    0.27033474465469115,
                                    0.07243597651629827,
                                    0.5183403899401218,
                                    0.13888888888888887,
                                ],
                                [
                                    0.027777777777777807,
                                    0.5942306901503683,
                                    0.016880420960742694,
                                    0.3611111111111111,
                                ],
                                [
                                    0.037215165615433754,
                                    0.7961181677178996,
                                    0.007443033123086752,
                                    0.15922363354357993,
                                ],
                                [
                                    0.029350675750720468,
                                    0.6278786030782902,
                                    0.015307522987800037,
                                    0.32746319818318925,
                                ],
                                [
                                    0.1388888888888889,
                                    0.5183403899401218,
                                    0.07243597651629824,
                                    0.27033474465469104,
                                ],
                                [
                                    0.036793708873807215,
                                    0.7871022366218702,
                                    0.007864489864713286,
                                    0.16823956463960932,
                                ],
                                [
                                    0.1741096997897534,
                                    0.6497862457059239,
                                    0.03721516561543371,
                                    0.1388888888888889,
                                ],
                                [
                                    0.027777777777777783,
                                    0.13888888888888884,
                                    0.13888888888888895,
                                    0.6944444444444444,
                                ],
                                [
                                    0.15922363354358,
                                    0.7961181677178996,
                                    0.007443033123086746,
                                    0.03721516561543371,
                                ],
                                [
                                    0.04968542040541148,
                                    0.24842710202705728,
                                    0.11698124626125525,
                                    0.584906231306276,
                                ],
                                [
                                    0.23511393375382647,
                                    0.06299858867864229,
                                    0.5535612008409864,
                                    0.14832627672654483,
                                ],
                                [
                                    0.1533534983934359,
                                    0.7667674919671791,
                                    0.013313168273230836,
                                    0.06656584136615414,
                                ],
                                [
                                    0.7256765459161706,
                                    0.19444444444444445,
                                    0.0629985886786423,
                                    0.016880420960742677,
                                ],
                                [
                                    0.007443033123086749,
                                    0.15922363354357988,
                                    0.037215165615433754,
                                    0.7961181677178996,
                                ],
                                [
                                    0.016880420960742694,
                                    0.36111111111111105,
                                    0.02777777777777781,
                                    0.5942306901503684,
                                ],
                                [
                                    0.007864489864713288,
                                    0.16823956463960937,
                                    0.036793708873807215,
                                    0.7871022366218702,
                                ],
                                [
                                    0.037215165615433726,
                                    0.13888888888888892,
                                    0.1741096997897534,
                                    0.6497862457059239,
                                ],
                                [
                                    0.015307522987800042,
                                    0.32746319818318936,
                                    0.02935067575072046,
                                    0.6278786030782901,
                                ],
                                [
                                    0.07243597651629827,
                                    0.27033474465469115,
                                    0.13888888888888887,
                                    0.5183403899401218,
                                ],
                                [
                                    0.007443033123086735,
                                    0.03721516561543366,
                                    0.15922363354358002,
                                    0.7961181677178996,
                                ],
                                [
                                    0.13888888888888895,
                                    0.6944444444444443,
                                    0.027777777777777794,
                                    0.1388888888888889,
                                ],
                                [
                                    0.013313168273230837,
                                    0.06656584136615415,
                                    0.1533534983934359,
                                    0.7667674919671791,
                                ],
                                [
                                    0.06299858867864232,
                                    0.01688042096074268,
                                    0.7256765459161706,
                                    0.19444444444444445,
                                ],
                                [
                                    0.11698124626125525,
                                    0.584906231306276,
                                    0.04968542040541148,
                                    0.24842710202705728,
                                ],
                                [
                                    0.5535612008409864,
                                    0.14832627672654483,
                                    0.23511393375382647,
                                    0.06299858867864229,
                                ],
                                [
                                    0.1036680779880244,
                                    0.5183403899401218,
                                    0.06299858867864233,
                                    0.3149929433932115,
                                ],
                                [
                                    0.13888888888888895,
                                    0.6944444444444443,
                                    0.027777777777777794,
                                    0.1388888888888889,
                                ],
                                [
                                    0.1095382131381685,
                                    0.5476910656908422,
                                    0.05712845352849824,
                                    0.28564226764249107,
                                ],
                                [
                                    0.1388888888888889,
                                    0.5183403899401218,
                                    0.07243597651629824,
                                    0.27033474465469104,
                                ],
                                [
                                    0.1373159909159463,
                                    0.6865799545797311,
                                    0.029350675750720444,
                                    0.14675337875360214,
                                ],
                                [
                                    0.1741096997897534,
                                    0.6497862457059239,
                                    0.03721516561543371,
                                    0.1388888888888889,
                                ],
                                [
                                    0.10366807798802435,
                                    0.06299858867864228,
                                    0.5183403899401219,
                                    0.3149929433932115,
                                ],
                                [
                                    0.5942306901503684,
                                    0.36111111111111105,
                                    0.027777777777777783,
                                    0.016880420960742673,
                                ],
                                [
                                    0.18542851334841504,
                                    0.11268400908405375,
                                    0.4365799545797312,
                                    0.2653075229878,
                                ],
                                [
                                    0.23511393375382647,
                                    0.06299858867864229,
                                    0.5535612008409864,
                                    0.14832627672654483,
                                ],
                                [
                                    0.5723230475227348,
                                    0.34779794283788024,
                                    0.049685420405411476,
                                    0.030193589233973504,
                                ],
                                [
                                    0.7256765459161706,
                                    0.19444444444444445,
                                    0.0629985886786423,
                                    0.016880420960742677,
                                ],
                                [
                                    0.027777777777777783,
                                    0.13888888888888884,
                                    0.13888888888888895,
                                    0.6944444444444444,
                                ],
                                [
                                    0.06299858867864232,
                                    0.31499294339321143,
                                    0.10366807798802442,
                                    0.5183403899401218,
                                ],
                                [
                                    0.029350675750720454,
                                    0.1467533787536022,
                                    0.1373159909159463,
                                    0.6865799545797311,
                                ],
                                [
                                    0.037215165615433726,
                                    0.13888888888888892,
                                    0.1741096997897534,
                                    0.6497862457059239,
                                ],
                                [
                                    0.057128453528498255,
                                    0.2856422676424911,
                                    0.10953821313816849,
                                    0.5476910656908421,
                                ],
                                [
                                    0.07243597651629827,
                                    0.27033474465469115,
                                    0.13888888888888887,
                                    0.5183403899401218,
                                ],
                                [
                                    0.02777777777777774,
                                    0.016880420960742652,
                                    0.5942306901503684,
                                    0.3611111111111111,
                                ],
                                [
                                    0.5183403899401218,
                                    0.31499294339321143,
                                    0.10366807798802438,
                                    0.0629985886786423,
                                ],
                                [
                                    0.04968542040541148,
                                    0.030193589233973507,
                                    0.5723230475227348,
                                    0.34779794283788024,
                                ],
                                [
                                    0.06299858867864232,
                                    0.01688042096074268,
                                    0.7256765459161706,
                                    0.19444444444444445,
                                ],
                                [
                                    0.4365799545797312,
                                    0.2653075229878,
                                    0.18542851334841504,
                                    0.11268400908405375,
                                ],
                                [
                                    0.5535612008409864,
                                    0.14832627672654483,
                                    0.23511393375382647,
                                    0.06299858867864229,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.5942306901503683,
                                    0.027777777777777776,
                                    0.3611111111111111,
                                    0.016880420960742677,
                                ],
                                [
                                    0.6294515010512329,
                                    0.16866102138123587,
                                    0.15922363354357993,
                                    0.042663844023951264,
                                ],
                                [
                                    0.7624702547899777,
                                    0.03564226764249106,
                                    0.1928715464715018,
                                    0.0090159310960294,
                                ],
                                [
                                    0.5942306901503684,
                                    0.15922363354357993,
                                    0.19444444444444445,
                                    0.0521012318616072,
                                ],
                                [
                                    0.7198064107660265,
                                    0.033647912927921866,
                                    0.23553539049545305,
                                    0.011010285810598588,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.13888888888888884,
                                    0.027777777777777776,
                                    0.6944444444444444,
                                    0.13888888888888892,
                                ],
                                [
                                    0.1741096997897534,
                                    0.6497862457059239,
                                    0.03721516561543371,
                                    0.1388888888888889,
                                ],
                                [
                                    0.6865799545797311,
                                    0.13731599091594623,
                                    0.14675337875360214,
                                    0.029350675750720437,
                                ],
                                [
                                    0.1388888888888889,
                                    0.5183403899401218,
                                    0.07243597651629824,
                                    0.27033474465469104,
                                ],
                                [
                                    0.5476910656908422,
                                    0.10953821313816847,
                                    0.28564226764249107,
                                    0.05712845352849822,
                                ],
                                [
                                    0.36111111111111105,
                                    0.016880420960742673,
                                    0.5942306901503684,
                                    0.027777777777777783,
                                ],
                                [
                                    0.15922363354357988,
                                    0.007443033123086741,
                                    0.7961181677178996,
                                    0.03721516561543371,
                                ],
                                [
                                    0.1944444444444445,
                                    0.052101231861607214,
                                    0.5942306901503683,
                                    0.1592236335435799,
                                ],
                                [
                                    0.23553539049545313,
                                    0.011010285810598592,
                                    0.7198064107660264,
                                    0.033647912927921866,
                                ],
                                [
                                    0.15922363354357996,
                                    0.04266384402395127,
                                    0.6294515010512329,
                                    0.16866102138123587,
                                ],
                                [
                                    0.19287154647150181,
                                    0.0090159310960294,
                                    0.7624702547899777,
                                    0.03564226764249106,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.03721516561543366,
                                    0.0074430331230867335,
                                    0.7961181677178996,
                                    0.15922363354357996,
                                ],
                                [
                                    0.07243597651629827,
                                    0.27033474465469115,
                                    0.13888888888888887,
                                    0.5183403899401218,
                                ],
                                [
                                    0.2856422676424911,
                                    0.05712845352849824,
                                    0.5476910656908421,
                                    0.10953821313816844,
                                ],
                                [
                                    0.037215165615433726,
                                    0.13888888888888892,
                                    0.1741096997897534,
                                    0.6497862457059239,
                                ],
                                [
                                    0.1467533787536022,
                                    0.029350675750720444,
                                    0.6865799545797311,
                                    0.13731599091594623,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.5942306901503683,
                                    0.027777777777777776,
                                    0.3611111111111111,
                                    0.016880420960742677,
                                ],
                                [
                                    0.6294515010512329,
                                    0.16866102138123587,
                                    0.15922363354357993,
                                    0.042663844023951264,
                                ],
                                [
                                    0.6650937686937239,
                                    0.1330187537387448,
                                    0.16823956463960932,
                                    0.03364791292792187,
                                ],
                                [
                                    0.5942306901503684,
                                    0.15922363354357993,
                                    0.19444444444444445,
                                    0.0521012318616072,
                                ],
                                [
                                    0.6278786030782902,
                                    0.12557572061565808,
                                    0.20545473025504302,
                                    0.04109094605100861,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.13888888888888884,
                                    0.027777777777777776,
                                    0.6944444444444444,
                                    0.13888888888888892,
                                ],
                                [
                                    0.1741096997897534,
                                    0.6497862457059239,
                                    0.03721516561543371,
                                    0.1388888888888889,
                                ],
                                [
                                    0.3114256907056996,
                                    0.5124702547899778,
                                    0.06656584136615414,
                                    0.10953821313816846,
                                ],
                                [
                                    0.1388888888888889,
                                    0.5183403899401218,
                                    0.07243597651629824,
                                    0.27033474465469104,
                                ],
                                [
                                    0.24842710202705734,
                                    0.4088021768019534,
                                    0.12956443004479642,
                                    0.21320629112619285,
                                ],
                                [
                                    0.36111111111111105,
                                    0.016880420960742673,
                                    0.5942306901503684,
                                    0.027777777777777783,
                                ],
                                [
                                    0.15922363354357988,
                                    0.007443033123086741,
                                    0.7961181677178996,
                                    0.03721516561543371,
                                ],
                                [
                                    0.1944444444444445,
                                    0.052101231861607214,
                                    0.5942306901503683,
                                    0.1592236335435799,
                                ],
                                [
                                    0.2054547302550431,
                                    0.041090946051008624,
                                    0.6278786030782901,
                                    0.12557572061565805,
                                ],
                                [
                                    0.15922363354357996,
                                    0.04266384402395127,
                                    0.6294515010512329,
                                    0.16866102138123587,
                                ],
                                [
                                    0.16823956463960935,
                                    0.03364791292792187,
                                    0.6650937686937239,
                                    0.1330187537387448,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.03721516561543366,
                                    0.0074430331230867335,
                                    0.7961181677178996,
                                    0.15922363354357996,
                                ],
                                [
                                    0.07243597651629827,
                                    0.27033474465469115,
                                    0.13888888888888887,
                                    0.5183403899401218,
                                ],
                                [
                                    0.12956443004479648,
                                    0.2132062911261929,
                                    0.24842710202705728,
                                    0.4088021768019533,
                                ],
                                [
                                    0.037215165615433726,
                                    0.13888888888888892,
                                    0.1741096997897534,
                                    0.6497862457059239,
                                ],
                                [
                                    0.06656584136615416,
                                    0.10953821313816849,
                                    0.3114256907056996,
                                    0.5124702547899778,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.5183403899401218,
                                    0.10366807798802437,
                                    0.3149929433932115,
                                    0.06299858867864232,
                                ],
                                [
                                    0.6497862457059239,
                                    0.1741096997897534,
                                    0.1388888888888889,
                                    0.03721516561543371,
                                ],
                                [
                                    0.7871022366218702,
                                    0.036793708873807174,
                                    0.16823956463960932,
                                    0.007864489864713277,
                                ],
                                [
                                    0.5183403899401218,
                                    0.1388888888888889,
                                    0.27033474465469104,
                                    0.07243597651629824,
                                ],
                                [
                                    0.6278786030782902,
                                    0.029350675750720437,
                                    0.32746319818318925,
                                    0.015307522987800021,
                                ],
                                [
                                    0.36111111111111105,
                                    0.5942306901503684,
                                    0.016880420960742673,
                                    0.027777777777777783,
                                ],
                                [
                                    0.06299858867864228,
                                    0.10366807798802435,
                                    0.3149929433932115,
                                    0.5183403899401219,
                                ],
                                [
                                    0.19444444444444445,
                                    0.7256765459161706,
                                    0.016880420960742677,
                                    0.0629985886786423,
                                ],
                                [
                                    0.7667674919671791,
                                    0.15335349839343584,
                                    0.06656584136615414,
                                    0.01331316827323083,
                                ],
                                [
                                    0.06299858867864229,
                                    0.23511393375382647,
                                    0.14832627672654483,
                                    0.5535612008409864,
                                ],
                                [
                                    0.24842710202705728,
                                    0.04968542040541147,
                                    0.584906231306276,
                                    0.11698124626125522,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.13888888888888884,
                                    0.027777777777777776,
                                    0.6944444444444444,
                                    0.13888888888888892,
                                ],
                                [
                                    0.27033474465469115,
                                    0.07243597651629827,
                                    0.5183403899401218,
                                    0.13888888888888887,
                                ],
                                [
                                    0.32746319818318936,
                                    0.015307522987800025,
                                    0.6278786030782901,
                                    0.02935067575072043,
                                ],
                                [
                                    0.13888888888888892,
                                    0.037215165615433726,
                                    0.6497862457059239,
                                    0.1741096997897534,
                                ],
                                [
                                    0.16823956463960937,
                                    0.007864489864713279,
                                    0.7871022366218702,
                                    0.036793708873807174,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.016880420960742652,
                                    0.02777777777777774,
                                    0.3611111111111111,
                                    0.5942306901503684,
                                ],
                                [
                                    0.14832627672654483,
                                    0.5535612008409864,
                                    0.06299858867864229,
                                    0.23511393375382647,
                                ],
                                [
                                    0.584906231306276,
                                    0.11698124626125522,
                                    0.24842710202705728,
                                    0.04968542040541147,
                                ],
                                [
                                    0.01688042096074268,
                                    0.06299858867864232,
                                    0.19444444444444445,
                                    0.7256765459161706,
                                ],
                                [
                                    0.06656584136615415,
                                    0.013313168273230834,
                                    0.7667674919671791,
                                    0.15335349839343584,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.5183403899401218,
                                    0.10366807798802437,
                                    0.3149929433932115,
                                    0.06299858867864232,
                                ],
                                [
                                    0.6497862457059239,
                                    0.1741096997897534,
                                    0.1388888888888889,
                                    0.03721516561543371,
                                ],
                                [
                                    0.6865799545797311,
                                    0.13731599091594623,
                                    0.14675337875360214,
                                    0.029350675750720437,
                                ],
                                [
                                    0.5183403899401218,
                                    0.1388888888888889,
                                    0.27033474465469104,
                                    0.07243597651629824,
                                ],
                                [
                                    0.5476910656908422,
                                    0.10953821313816847,
                                    0.28564226764249107,
                                    0.05712845352849822,
                                ],
                                [
                                    0.36111111111111105,
                                    0.5942306901503684,
                                    0.016880420960742673,
                                    0.027777777777777783,
                                ],
                                [
                                    0.06299858867864228,
                                    0.10366807798802435,
                                    0.3149929433932115,
                                    0.5183403899401219,
                                ],
                                [
                                    0.19444444444444445,
                                    0.7256765459161706,
                                    0.016880420960742677,
                                    0.0629985886786423,
                                ],
                                [
                                    0.34779794283788024,
                                    0.5723230475227348,
                                    0.030193589233973504,
                                    0.049685420405411476,
                                ],
                                [
                                    0.06299858867864229,
                                    0.23511393375382647,
                                    0.14832627672654483,
                                    0.5535612008409864,
                                ],
                                [
                                    0.11268400908405375,
                                    0.18542851334841504,
                                    0.2653075229878,
                                    0.4365799545797312,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.13888888888888884,
                                    0.027777777777777776,
                                    0.6944444444444444,
                                    0.13888888888888892,
                                ],
                                [
                                    0.27033474465469115,
                                    0.07243597651629827,
                                    0.5183403899401218,
                                    0.13888888888888887,
                                ],
                                [
                                    0.2856422676424911,
                                    0.05712845352849824,
                                    0.5476910656908421,
                                    0.10953821313816844,
                                ],
                                [
                                    0.13888888888888892,
                                    0.037215165615433726,
                                    0.6497862457059239,
                                    0.1741096997897534,
                                ],
                                [
                                    0.1467533787536022,
                                    0.029350675750720444,
                                    0.6865799545797311,
                                    0.13731599091594623,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.016880420960742652,
                                    0.02777777777777774,
                                    0.3611111111111111,
                                    0.5942306901503684,
                                ],
                                [
                                    0.14832627672654483,
                                    0.5535612008409864,
                                    0.06299858867864229,
                                    0.23511393375382647,
                                ],
                                [
                                    0.2653075229878,
                                    0.4365799545797312,
                                    0.11268400908405375,
                                    0.18542851334841504,
                                ],
                                [
                                    0.01688042096074268,
                                    0.06299858867864232,
                                    0.19444444444444445,
                                    0.7256765459161706,
                                ],
                                [
                                    0.030193589233973507,
                                    0.04968542040541148,
                                    0.34779794283788024,
                                    0.5723230475227348,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.002666490251496954,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.03239627437125761,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.014694620859614156,
                                0.014694620859614156,
                                0.014694620859614156,
                                0.014694620859614156,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.014694620859614156,
                                0.014694620859614156,
                                0.014694620859614156,
                                0.014694620859614156,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.014694620859614156,
                                0.014694620859614156,
                                0.014694620859614156,
                                0.014694620859614156,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.002325947850964607,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.014694620859614156,
                                0.014694620859614156,
                                0.014694620859614156,
                                0.014694620859614156,
                            ]
                        ),
                    )
                case 3:
                    return (
                        np.array(
                            [
                                [
                                    0.010000000000000007,
                                    0.7772983346207417,
                                    0.002701665379258313,
                                    0.20999999999999996,
                                ],
                                [
                                    0.011431498841332488,
                                    0.8885685011586675,
                                    0.001270166537925832,
                                    0.09872983346207416,
                                ],
                                [
                                    0.011127016653792591,
                                    0.8649011514290234,
                                    0.0015746487254657293,
                                    0.1223971831917184,
                                ],
                                [
                                    0.09872983346207416,
                                    0.7772983346207417,
                                    0.013971831917184138,
                                    0.10999999999999999,
                                ],
                                [
                                    0.01128834895719924,
                                    0.8774414845048749,
                                    0.00141331642205908,
                                    0.10985685011586674,
                                ],
                                [
                                    0.10016133230340664,
                                    0.7885685011586675,
                                    0.012540333075851659,
                                    0.09872983346207416,
                                ],
                                [
                                    0.024999999999999998,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.525,
                                ],
                                [
                                    0.05317541634481457,
                                    0.8904737509655563,
                                    0.003175416344814577,
                                    0.05317541634481457,
                                ],
                                [
                                    0.047182458365518536,
                                    0.7901158762552232,
                                    0.009168374324110612,
                                    0.15353329105514768,
                                ],
                                [
                                    0.41864916731037083,
                                    0.41864916731037083,
                                    0.08135083268962914,
                                    0.08135083268962914,
                                ],
                                [
                                    0.05035787471033311,
                                    0.8432912926000377,
                                    0.005992957979296034,
                                    0.1003578747103331,
                                ],
                                [
                                    0.4468245836551854,
                                    0.4468245836551854,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                ],
                                [
                                    0.009999999999999995,
                                    0.08999999999999998,
                                    0.08999999999999998,
                                    0.81,
                                ],
                                [
                                    0.09872983346207415,
                                    0.8885685011586675,
                                    0.0012701665379258305,
                                    0.011431498841332478,
                                ],
                                [
                                    0.07985685011586674,
                                    0.7187116510428008,
                                    0.02014314988413324,
                                    0.18128834895719922,
                                ],
                                [
                                    0.7085685011586675,
                                    0.08999999999999998,
                                    0.17872983346207416,
                                    0.022701665379258308,
                                ],
                                [
                                    0.08985685011586673,
                                    0.8087116510428007,
                                    0.010143149884133245,
                                    0.09128834895719923,
                                ],
                                [
                                    0.7972983346207416,
                                    0.10127016653792581,
                                    0.09,
                                    0.011431498841332478,
                                ],
                                [
                                    0.00563508326896292,
                                    0.43801408404140796,
                                    0.0070665821102954005,
                                    0.5492842505793337,
                                ],
                                [
                                    0.0070665821102954005,
                                    0.5492842505793337,
                                    0.00563508326896292,
                                    0.43801408404140796,
                                ],
                                [
                                    0.0062701665379258364,
                                    0.48737900077244506,
                                    0.006431498841332484,
                                    0.4999193338482966,
                                ],
                                [
                                    0.055635083268962916,
                                    0.43801408404140796,
                                    0.05706658211029538,
                                    0.44928425057933374,
                                ],
                                [
                                    0.006431498841332484,
                                    0.4999193338482966,
                                    0.006270166537925836,
                                    0.487379000772445,
                                ],
                                [
                                    0.05706658211029538,
                                    0.44928425057933374,
                                    0.05563508326896291,
                                    0.43801408404140796,
                                ],
                                [
                                    0.014087708172407287,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.7077368754827782,
                                ],
                                [
                                    0.04226312451722186,
                                    0.7077368754827782,
                                    0.014087708172407287,
                                    0.2359122918275927,
                                ],
                                [
                                    0.026587708172407284,
                                    0.4452368754827781,
                                    0.029763124517221864,
                                    0.4984122918275927,
                                ],
                                [
                                    0.2359122918275927,
                                    0.2359122918275927,
                                    0.2640877081724073,
                                    0.2640877081724073,
                                ],
                                [
                                    0.029763124517221864,
                                    0.4984122918275927,
                                    0.026587708172407284,
                                    0.4452368754827781,
                                ],
                                [
                                    0.2640877081724073,
                                    0.2640877081724073,
                                    0.2359122918275927,
                                    0.2359122918275927,
                                ],
                                [
                                    0.0056350832689629135,
                                    0.050715749420666235,
                                    0.09436491673103706,
                                    0.8492842505793338,
                                ],
                                [
                                    0.09436491673103706,
                                    0.8492842505793338,
                                    0.0056350832689629135,
                                    0.050715749420666235,
                                ],
                                [
                                    0.044999999999999984,
                                    0.40499999999999997,
                                    0.05499999999999999,
                                    0.49500000000000005,
                                ],
                                [
                                    0.3992842505793337,
                                    0.05071574942066623,
                                    0.488014084041408,
                                    0.06198591595859207,
                                ],
                                [
                                    0.05499999999999999,
                                    0.49500000000000005,
                                    0.04499999999999999,
                                    0.405,
                                ],
                                [
                                    0.488014084041408,
                                    0.06198591595859207,
                                    0.39928425057933375,
                                    0.050715749420666235,
                                ],
                                [
                                    0.0012701665379258318,
                                    0.09872983346207415,
                                    0.011431498841332488,
                                    0.8885685011586675,
                                ],
                                [
                                    0.002701665379258313,
                                    0.20999999999999996,
                                    0.010000000000000007,
                                    0.7772983346207417,
                                ],
                                [
                                    0.0014133164220590793,
                                    0.10985685011586668,
                                    0.01128834895719924,
                                    0.877441484504875,
                                ],
                                [
                                    0.012540333075851654,
                                    0.0987298334620741,
                                    0.10016133230340664,
                                    0.7885685011586676,
                                ],
                                [
                                    0.0015746487254657286,
                                    0.12239718319171836,
                                    0.011127016653792591,
                                    0.8649011514290234,
                                ],
                                [
                                    0.013971831917184135,
                                    0.10999999999999995,
                                    0.09872983346207416,
                                    0.7772983346207417,
                                ],
                                [
                                    0.003175416344814577,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.8904737509655563,
                                ],
                                [
                                    0.031350832689629154,
                                    0.525,
                                    0.024999999999999998,
                                    0.41864916731037083,
                                ],
                                [
                                    0.005992957979296037,
                                    0.10035787471033315,
                                    0.05035787471033311,
                                    0.8432912926000377,
                                ],
                                [
                                    0.0531754163448146,
                                    0.0531754163448146,
                                    0.4468245836551854,
                                    0.4468245836551854,
                                ],
                                [
                                    0.009168374324110613,
                                    0.15353329105514774,
                                    0.047182458365518536,
                                    0.7901158762552232,
                                ],
                                [
                                    0.08135083268962917,
                                    0.08135083268962917,
                                    0.41864916731037083,
                                    0.41864916731037083,
                                ],
                                [
                                    0.0012701665379258318,
                                    0.011431498841332488,
                                    0.09872983346207415,
                                    0.8885685011586675,
                                ],
                                [0.08999999999999998, 0.81, 0.009999999999999997, 0.09],
                                [
                                    0.01014314988413325,
                                    0.09128834895719927,
                                    0.08985685011586673,
                                    0.8087116510428007,
                                ],
                                [
                                    0.09000000000000002,
                                    0.011431498841332483,
                                    0.7972983346207416,
                                    0.10127016653792581,
                                ],
                                [
                                    0.020143149884133245,
                                    0.18128834895719925,
                                    0.07985685011586674,
                                    0.7187116510428008,
                                ],
                                [
                                    0.1787298334620742,
                                    0.022701665379258308,
                                    0.7085685011586675,
                                    0.08999999999999998,
                                ],
                                [
                                    0.04436491673103708,
                                    0.7429334178897047,
                                    0.011985915958592068,
                                    0.2007157494206662,
                                ],
                                [
                                    0.050715749420666235,
                                    0.8492842505793338,
                                    0.005635083268962914,
                                    0.09436491673103707,
                                ],
                                [
                                    0.04936491673103708,
                                    0.8266632513517789,
                                    0.006985915958592069,
                                    0.11698591595859205,
                                ],
                                [
                                    0.09872983346207416,
                                    0.7772983346207417,
                                    0.013971831917184138,
                                    0.10999999999999999,
                                ],
                                [
                                    0.05008066615170332,
                                    0.8386491673103708,
                                    0.0062701665379258295,
                                    0.10499999999999998,
                                ],
                                [
                                    0.10016133230340664,
                                    0.7885685011586675,
                                    0.012540333075851659,
                                    0.09872983346207416,
                                ],
                                [
                                    0.11091229182759271,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.41726312451722186,
                                ],
                                [
                                    0.2359122918275927,
                                    0.7077368754827782,
                                    0.014087708172407287,
                                    0.04226312451722186,
                                ],
                                [
                                    0.20932458365518541,
                                    0.6279737509655563,
                                    0.04067541634481457,
                                    0.12202624903444372,
                                ],
                                [
                                    0.41864916731037083,
                                    0.41864916731037083,
                                    0.08135083268962914,
                                    0.08135083268962914,
                                ],
                                [
                                    0.2234122918275927,
                                    0.6702368754827781,
                                    0.026587708172407284,
                                    0.07976312451722185,
                                ],
                                [
                                    0.4468245836551854,
                                    0.4468245836551854,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                ],
                                [
                                    0.044364916731037075,
                                    0.0556350832689629,
                                    0.39928425057933375,
                                    0.5007157494206662,
                                ],
                                [
                                    0.43801408404140796,
                                    0.5492842505793337,
                                    0.005635083268962914,
                                    0.0070665821102953935,
                                ],
                                [
                                    0.35428425057933377,
                                    0.44428425057933374,
                                    0.08936491673103708,
                                    0.11206658211029538,
                                ],
                                [
                                    0.7085685011586675,
                                    0.08999999999999998,
                                    0.17872983346207416,
                                    0.022701665379258308,
                                ],
                                [
                                    0.3986491673103708,
                                    0.4999193338482967,
                                    0.045,
                                    0.05643149884133247,
                                ],
                                [
                                    0.7972983346207416,
                                    0.10127016653792581,
                                    0.09,
                                    0.011431498841332478,
                                ],
                                [
                                    0.024999999999999998,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.525,
                                ],
                                [
                                    0.031350832689629154,
                                    0.525,
                                    0.024999999999999998,
                                    0.41864916731037083,
                                ],
                                [
                                    0.027817541634481458,
                                    0.4658316256758894,
                                    0.02853329105514769,
                                    0.4778175416344814,
                                ],
                                [
                                    0.055635083268962916,
                                    0.43801408404140796,
                                    0.05706658211029538,
                                    0.44928425057933374,
                                ],
                                [
                                    0.02853329105514769,
                                    0.4778175416344814,
                                    0.027817541634481455,
                                    0.46583162567588937,
                                ],
                                [
                                    0.05706658211029538,
                                    0.44928425057933374,
                                    0.05563508326896291,
                                    0.43801408404140796,
                                ],
                                [0.0625, 0.1875, 0.1875, 0.5625],
                                [0.1875, 0.5625, 0.0625, 0.1875],
                                [
                                    0.11795614591379636,
                                    0.3538684377413891,
                                    0.13204385408620364,
                                    0.3961315622586109,
                                ],
                                [
                                    0.2359122918275927,
                                    0.2359122918275927,
                                    0.2640877081724073,
                                    0.2640877081724073,
                                ],
                                [
                                    0.13204385408620364,
                                    0.3961315622586109,
                                    0.11795614591379636,
                                    0.3538684377413891,
                                ],
                                [
                                    0.2640877081724073,
                                    0.2640877081724073,
                                    0.2359122918275927,
                                    0.2359122918275927,
                                ],
                                [
                                    0.024999999999999998,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.525,
                                ],
                                [
                                    0.41864916731037083,
                                    0.525,
                                    0.024999999999999998,
                                    0.031350832689629154,
                                ],
                                [
                                    0.19964212528966685,
                                    0.2503578747103331,
                                    0.244007042020704,
                                    0.30599295797929604,
                                ],
                                [
                                    0.3992842505793337,
                                    0.05071574942066623,
                                    0.488014084041408,
                                    0.06198591595859207,
                                ],
                                [
                                    0.244007042020704,
                                    0.30599295797929604,
                                    0.19964212528966688,
                                    0.2503578747103331,
                                ],
                                [
                                    0.488014084041408,
                                    0.06198591595859207,
                                    0.39928425057933375,
                                    0.050715749420666235,
                                ],
                                [
                                    0.0056350832689629135,
                                    0.09436491673103706,
                                    0.050715749420666235,
                                    0.8492842505793338,
                                ],
                                [
                                    0.011985915958592068,
                                    0.2007157494206662,
                                    0.04436491673103708,
                                    0.7429334178897047,
                                ],
                                [
                                    0.006270166537925827,
                                    0.10499999999999994,
                                    0.05008066615170332,
                                    0.8386491673103709,
                                ],
                                [
                                    0.012540333075851654,
                                    0.0987298334620741,
                                    0.10016133230340664,
                                    0.7885685011586676,
                                ],
                                [
                                    0.006985915958592067,
                                    0.11698591595859202,
                                    0.04936491673103708,
                                    0.8266632513517789,
                                ],
                                [
                                    0.013971831917184135,
                                    0.10999999999999995,
                                    0.09872983346207416,
                                    0.7772983346207417,
                                ],
                                [
                                    0.014087708172407287,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.7077368754827782,
                                ],
                                [
                                    0.1390877081724073,
                                    0.41726312451722186,
                                    0.11091229182759271,
                                    0.33273687548277814,
                                ],
                                [
                                    0.0265877081724073,
                                    0.0797631245172219,
                                    0.2234122918275927,
                                    0.6702368754827781,
                                ],
                                [
                                    0.0531754163448146,
                                    0.0531754163448146,
                                    0.4468245836551854,
                                    0.4468245836551854,
                                ],
                                [
                                    0.040675416344814586,
                                    0.12202624903444376,
                                    0.20932458365518541,
                                    0.6279737509655563,
                                ],
                                [
                                    0.08135083268962917,
                                    0.08135083268962917,
                                    0.41864916731037083,
                                    0.41864916731037083,
                                ],
                                [
                                    0.00563508326896292,
                                    0.0070665821102954005,
                                    0.43801408404140796,
                                    0.5492842505793337,
                                ],
                                [
                                    0.39928425057933375,
                                    0.5007157494206662,
                                    0.04436491673103708,
                                    0.05563508326896291,
                                ],
                                [
                                    0.04500000000000001,
                                    0.0564314988413325,
                                    0.3986491673103708,
                                    0.4999193338482967,
                                ],
                                [
                                    0.09000000000000002,
                                    0.011431498841332483,
                                    0.7972983346207416,
                                    0.10127016653792581,
                                ],
                                [
                                    0.0893649167310371,
                                    0.1120665821102954,
                                    0.35428425057933377,
                                    0.44428425057933374,
                                ],
                                [
                                    0.1787298334620742,
                                    0.022701665379258308,
                                    0.7085685011586675,
                                    0.08999999999999998,
                                ],
                                [
                                    0.07872983346207416,
                                    0.7085685011586675,
                                    0.021270166537925822,
                                    0.19143149884133245,
                                ],
                                [0.08999999999999998, 0.81, 0.009999999999999997, 0.09],
                                [
                                    0.08760281680828157,
                                    0.7884253512745344,
                                    0.01239718319171841,
                                    0.11157464872546571,
                                ],
                                [
                                    0.09872983346207416,
                                    0.7772983346207417,
                                    0.013971831917184138,
                                    0.10999999999999999,
                                ],
                                [
                                    0.0888729833462074,
                                    0.7998568501158667,
                                    0.011127016653792579,
                                    0.10014314988413324,
                                ],
                                [
                                    0.10016133230340664,
                                    0.7885685011586675,
                                    0.012540333075851659,
                                    0.09872983346207416,
                                ],
                                [
                                    0.19682458365518543,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.3095262490344437,
                                ],
                                [
                                    0.41864916731037083,
                                    0.525,
                                    0.024999999999999998,
                                    0.031350832689629154,
                                ],
                                [
                                    0.3714667089448523,
                                    0.46583162567588937,
                                    0.07218245836551854,
                                    0.09051920701373975,
                                ],
                                [
                                    0.41864916731037083,
                                    0.41864916731037083,
                                    0.08135083268962914,
                                    0.08135083268962914,
                                ],
                                [
                                    0.3964667089448523,
                                    0.4971824583655185,
                                    0.047182458365518536,
                                    0.0591683743241106,
                                ],
                                [
                                    0.4468245836551854,
                                    0.4468245836551854,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                ],
                                [
                                    0.07872983346207416,
                                    0.021270166537925822,
                                    0.7085685011586675,
                                    0.19143149884133245,
                                ],
                                [
                                    0.7772983346207417,
                                    0.20999999999999996,
                                    0.009999999999999998,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.6287116510428008,
                                    0.1698568501158667,
                                    0.15858668357794092,
                                    0.042844815263391546,
                                ],
                                [
                                    0.7085685011586675,
                                    0.08999999999999998,
                                    0.17872983346207416,
                                    0.022701665379258308,
                                ],
                                [
                                    0.707441484504875,
                                    0.19112701665379253,
                                    0.07985685011586675,
                                    0.021574648725465724,
                                ],
                                [
                                    0.7972983346207416,
                                    0.10127016653792581,
                                    0.09,
                                    0.011431498841332478,
                                ],
                                [
                                    0.044364916731037075,
                                    0.39928425057933375,
                                    0.0556350832689629,
                                    0.5007157494206662,
                                ],
                                [
                                    0.0556350832689629,
                                    0.5007157494206662,
                                    0.044364916731037075,
                                    0.39928425057933375,
                                ],
                                [
                                    0.04936491673103708,
                                    0.4442842505793338,
                                    0.0506350832689629,
                                    0.4557157494206662,
                                ],
                                [
                                    0.055635083268962916,
                                    0.43801408404140796,
                                    0.05706658211029538,
                                    0.44928425057933374,
                                ],
                                [
                                    0.0506350832689629,
                                    0.4557157494206662,
                                    0.04936491673103707,
                                    0.44428425057933374,
                                ],
                                [
                                    0.05706658211029538,
                                    0.44928425057933374,
                                    0.05563508326896291,
                                    0.43801408404140796,
                                ],
                                [
                                    0.11091229182759271,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.41726312451722186,
                                ],
                                [
                                    0.33273687548277814,
                                    0.41726312451722186,
                                    0.11091229182759271,
                                    0.1390877081724073,
                                ],
                                [
                                    0.20932458365518541,
                                    0.2625,
                                    0.23432458365518544,
                                    0.29385083268962914,
                                ],
                                [
                                    0.2359122918275927,
                                    0.2359122918275927,
                                    0.2640877081724073,
                                    0.2640877081724073,
                                ],
                                [
                                    0.23432458365518544,
                                    0.29385083268962914,
                                    0.20932458365518541,
                                    0.2625,
                                ],
                                [
                                    0.2640877081724073,
                                    0.2640877081724073,
                                    0.2359122918275927,
                                    0.2359122918275927,
                                ],
                                [
                                    0.04436491673103708,
                                    0.011985915958592068,
                                    0.7429334178897047,
                                    0.2007157494206662,
                                ],
                                [
                                    0.7429334178897047,
                                    0.2007157494206662,
                                    0.04436491673103708,
                                    0.011985915958592068,
                                ],
                                [
                                    0.3542842505793337,
                                    0.09571574942066621,
                                    0.433014084041408,
                                    0.11698591595859206,
                                ],
                                [
                                    0.3992842505793337,
                                    0.05071574942066623,
                                    0.488014084041408,
                                    0.06198591595859207,
                                ],
                                [
                                    0.433014084041408,
                                    0.11698591595859206,
                                    0.35428425057933377,
                                    0.09571574942066623,
                                ],
                                [
                                    0.488014084041408,
                                    0.06198591595859207,
                                    0.39928425057933375,
                                    0.050715749420666235,
                                ],
                                [
                                    0.009999999999999995,
                                    0.08999999999999998,
                                    0.08999999999999998,
                                    0.81,
                                ],
                                [
                                    0.021270166537925822,
                                    0.19143149884133245,
                                    0.07872983346207416,
                                    0.7085685011586675,
                                ],
                                [
                                    0.011127016653792574,
                                    0.10014314988413318,
                                    0.0888729833462074,
                                    0.7998568501158668,
                                ],
                                [
                                    0.012540333075851654,
                                    0.0987298334620741,
                                    0.10016133230340664,
                                    0.7885685011586676,
                                ],
                                [
                                    0.012397183191718406,
                                    0.11157464872546567,
                                    0.08760281680828157,
                                    0.7884253512745344,
                                ],
                                [
                                    0.013971831917184135,
                                    0.10999999999999995,
                                    0.09872983346207416,
                                    0.7772983346207417,
                                ],
                                [
                                    0.024999999999999998,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.525,
                                ],
                                [
                                    0.24682458365518542,
                                    0.3095262490344437,
                                    0.19682458365518543,
                                    0.24682458365518542,
                                ],
                                [
                                    0.047182458365518556,
                                    0.05916837432411064,
                                    0.3964667089448523,
                                    0.4971824583655185,
                                ],
                                [
                                    0.0531754163448146,
                                    0.0531754163448146,
                                    0.4468245836551854,
                                    0.4468245836551854,
                                ],
                                [
                                    0.07218245836551855,
                                    0.09051920701373979,
                                    0.3714667089448523,
                                    0.46583162567588937,
                                ],
                                [
                                    0.08135083268962917,
                                    0.08135083268962917,
                                    0.41864916731037083,
                                    0.41864916731037083,
                                ],
                                [
                                    0.010000000000000007,
                                    0.002701665379258313,
                                    0.7772983346207417,
                                    0.20999999999999996,
                                ],
                                [
                                    0.7085685011586675,
                                    0.19143149884133245,
                                    0.07872983346207417,
                                    0.021270166537925825,
                                ],
                                [
                                    0.07985685011586678,
                                    0.02157464872546573,
                                    0.707441484504875,
                                    0.19112701665379253,
                                ],
                                [
                                    0.09000000000000002,
                                    0.011431498841332483,
                                    0.7972983346207416,
                                    0.10127016653792581,
                                ],
                                [
                                    0.15858668357794092,
                                    0.04284481526339155,
                                    0.6287116510428008,
                                    0.1698568501158667,
                                ],
                                [
                                    0.1787298334620742,
                                    0.022701665379258308,
                                    0.7085685011586675,
                                    0.08999999999999998,
                                ],
                                [
                                    0.010000000000000007,
                                    0.7772983346207417,
                                    0.002701665379258313,
                                    0.20999999999999996,
                                ],
                                [
                                    0.011431498841332488,
                                    0.8885685011586675,
                                    0.001270166537925832,
                                    0.09872983346207416,
                                ],
                                [
                                    0.010635083268962923,
                                    0.8266632513517788,
                                    0.002066582110295397,
                                    0.1606350832689629,
                                ],
                                [
                                    0.09436491673103707,
                                    0.7429334178897046,
                                    0.018336748648221223,
                                    0.14436491673103707,
                                ],
                                [
                                    0.011350832689629163,
                                    0.8822983346207417,
                                    0.0013508326896291565,
                                    0.10499999999999998,
                                ],
                                [
                                    0.10071574942066622,
                                    0.7929334178897046,
                                    0.011985915958592068,
                                    0.09436491673103707,
                                ],
                                [
                                    0.024999999999999998,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.525,
                                ],
                                [
                                    0.05317541634481457,
                                    0.8904737509655563,
                                    0.003175416344814577,
                                    0.05317541634481457,
                                ],
                                [
                                    0.0375,
                                    0.6279737509655563,
                                    0.018850832689629154,
                                    0.31567541634481455,
                                ],
                                [
                                    0.33273687548277814,
                                    0.33273687548277814,
                                    0.16726312451722186,
                                    0.16726312451722186,
                                ],
                                [
                                    0.051587708172407286,
                                    0.863886042793149,
                                    0.004763124517221866,
                                    0.07976312451722185,
                                ],
                                [
                                    0.45773687548277814,
                                    0.45773687548277814,
                                    0.04226312451722186,
                                    0.04226312451722186,
                                ],
                                [
                                    0.009999999999999995,
                                    0.08999999999999998,
                                    0.08999999999999998,
                                    0.81,
                                ],
                                [
                                    0.09872983346207415,
                                    0.8885685011586675,
                                    0.0012701665379258305,
                                    0.011431498841332478,
                                ],
                                [
                                    0.04936491673103708,
                                    0.4442842505793338,
                                    0.0506350832689629,
                                    0.4557157494206662,
                                ],
                                [
                                    0.43801408404140796,
                                    0.055635083268962916,
                                    0.44928425057933374,
                                    0.05706658211029538,
                                ],
                                [
                                    0.09372983346207416,
                                    0.8435685011586675,
                                    0.0062701665379258295,
                                    0.05643149884133248,
                                ],
                                [
                                    0.8316632513517789,
                                    0.10563508326896291,
                                    0.055635083268962916,
                                    0.007066582110295394,
                                ],
                                [
                                    0.00563508326896292,
                                    0.43801408404140796,
                                    0.0070665821102954005,
                                    0.5492842505793337,
                                ],
                                [
                                    0.0070665821102954005,
                                    0.5492842505793337,
                                    0.00563508326896292,
                                    0.43801408404140796,
                                ],
                                [
                                    0.005992957979296039,
                                    0.46583162567588937,
                                    0.006708707399962281,
                                    0.5214667089448523,
                                ],
                                [
                                    0.05317541634481457,
                                    0.41864916731037083,
                                    0.05952624903444373,
                                    0.4686491673103709,
                                ],
                                [
                                    0.006708707399962281,
                                    0.5214667089448523,
                                    0.005992957979296039,
                                    0.46583162567588937,
                                ],
                                [
                                    0.05952624903444373,
                                    0.4686491673103709,
                                    0.05317541634481457,
                                    0.41864916731037083,
                                ],
                                [
                                    0.014087708172407287,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.7077368754827782,
                                ],
                                [
                                    0.04226312451722186,
                                    0.7077368754827782,
                                    0.014087708172407287,
                                    0.2359122918275927,
                                ],
                                [
                                    0.02113156225861093,
                                    0.3538684377413891,
                                    0.03521927043101822,
                                    0.5897807295689818,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.03521927043101822,
                                    0.5897807295689818,
                                    0.02113156225861093,
                                    0.3538684377413891,
                                ],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.0056350832689629135,
                                    0.050715749420666235,
                                    0.09436491673103706,
                                    0.8492842505793338,
                                ],
                                [
                                    0.09436491673103706,
                                    0.8492842505793338,
                                    0.0056350832689629135,
                                    0.050715749420666235,
                                ],
                                [
                                    0.02781754163448145,
                                    0.2503578747103331,
                                    0.07218245836551852,
                                    0.6496421252896669,
                                ],
                                [
                                    0.24682458365518542,
                                    0.031350832689629154,
                                    0.6404737509655563,
                                    0.08135083268962914,
                                ],
                                [
                                    0.07218245836551852,
                                    0.6496421252896669,
                                    0.02781754163448145,
                                    0.2503578747103331,
                                ],
                                [
                                    0.6404737509655563,
                                    0.08135083268962914,
                                    0.24682458365518542,
                                    0.031350832689629154,
                                ],
                                [
                                    0.0012701665379258318,
                                    0.09872983346207415,
                                    0.011431498841332488,
                                    0.8885685011586675,
                                ],
                                [
                                    0.002701665379258313,
                                    0.20999999999999996,
                                    0.010000000000000007,
                                    0.7772983346207417,
                                ],
                                [
                                    0.0013508326896291571,
                                    0.10500000000000004,
                                    0.011350832689629163,
                                    0.8822983346207417,
                                ],
                                [
                                    0.011985915958592074,
                                    0.09436491673103711,
                                    0.10071574942066622,
                                    0.7929334178897046,
                                ],
                                [
                                    0.0020665821102953978,
                                    0.16063508326896295,
                                    0.010635083268962923,
                                    0.8266632513517788,
                                ],
                                [
                                    0.018336748648221227,
                                    0.1443649167310371,
                                    0.09436491673103707,
                                    0.7429334178897046,
                                ],
                                [
                                    0.003175416344814577,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.8904737509655563,
                                ],
                                [
                                    0.031350832689629154,
                                    0.525,
                                    0.024999999999999998,
                                    0.41864916731037083,
                                ],
                                [
                                    0.004763124517221866,
                                    0.07976312451722185,
                                    0.051587708172407286,
                                    0.863886042793149,
                                ],
                                [
                                    0.04226312451722186,
                                    0.04226312451722186,
                                    0.45773687548277814,
                                    0.45773687548277814,
                                ],
                                [
                                    0.018850832689629154,
                                    0.31567541634481455,
                                    0.0375,
                                    0.6279737509655563,
                                ],
                                [
                                    0.16726312451722186,
                                    0.16726312451722186,
                                    0.33273687548277814,
                                    0.33273687548277814,
                                ],
                                [
                                    0.0012701665379258318,
                                    0.011431498841332488,
                                    0.09872983346207415,
                                    0.8885685011586675,
                                ],
                                [0.08999999999999998, 0.81, 0.009999999999999997, 0.09],
                                [
                                    0.006270166537925824,
                                    0.05643149884133243,
                                    0.09372983346207416,
                                    0.8435685011586675,
                                ],
                                [
                                    0.05563508326896287,
                                    0.007066582110295388,
                                    0.8316632513517789,
                                    0.10563508326896291,
                                ],
                                [
                                    0.0506350832689629,
                                    0.4557157494206662,
                                    0.04936491673103707,
                                    0.44428425057933374,
                                ],
                                [
                                    0.44928425057933374,
                                    0.05706658211029538,
                                    0.43801408404140796,
                                    0.05563508326896291,
                                ],
                                [
                                    0.04436491673103708,
                                    0.7429334178897047,
                                    0.011985915958592068,
                                    0.2007157494206662,
                                ],
                                [
                                    0.050715749420666235,
                                    0.8492842505793338,
                                    0.005635083268962914,
                                    0.09436491673103707,
                                ],
                                [
                                    0.047182458365518536,
                                    0.7901158762552232,
                                    0.009168374324110612,
                                    0.15353329105514768,
                                ],
                                [
                                    0.09436491673103707,
                                    0.7429334178897046,
                                    0.018336748648221223,
                                    0.14436491673103707,
                                ],
                                [
                                    0.05035787471033311,
                                    0.8432912926000377,
                                    0.005992957979296034,
                                    0.1003578747103331,
                                ],
                                [
                                    0.10071574942066622,
                                    0.7929334178897046,
                                    0.011985915958592068,
                                    0.09436491673103707,
                                ],
                                [
                                    0.11091229182759271,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.41726312451722186,
                                ],
                                [
                                    0.2359122918275927,
                                    0.7077368754827782,
                                    0.014087708172407287,
                                    0.04226312451722186,
                                ],
                                [
                                    0.16636843774138907,
                                    0.4991053132241672,
                                    0.08363156225861093,
                                    0.2508946867758328,
                                ],
                                [
                                    0.33273687548277814,
                                    0.33273687548277814,
                                    0.16726312451722186,
                                    0.16726312451722186,
                                ],
                                [
                                    0.22886843774138907,
                                    0.6866053132241672,
                                    0.02113156225861093,
                                    0.06339468677583279,
                                ],
                                [
                                    0.45773687548277814,
                                    0.45773687548277814,
                                    0.04226312451722186,
                                    0.04226312451722186,
                                ],
                                [
                                    0.044364916731037075,
                                    0.0556350832689629,
                                    0.39928425057933375,
                                    0.5007157494206662,
                                ],
                                [
                                    0.43801408404140796,
                                    0.5492842505793337,
                                    0.005635083268962914,
                                    0.0070665821102953935,
                                ],
                                [
                                    0.21900704202070398,
                                    0.2746421252896669,
                                    0.22464212528966687,
                                    0.28170870739996223,
                                ],
                                [
                                    0.43801408404140796,
                                    0.055635083268962916,
                                    0.44928425057933374,
                                    0.05706658211029538,
                                ],
                                [
                                    0.41583162567588944,
                                    0.5214667089448524,
                                    0.027817541634481458,
                                    0.034884123744776854,
                                ],
                                [
                                    0.8316632513517789,
                                    0.10563508326896291,
                                    0.055635083268962916,
                                    0.007066582110295394,
                                ],
                                [
                                    0.024999999999999998,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.525,
                                ],
                                [
                                    0.031350832689629154,
                                    0.525,
                                    0.024999999999999998,
                                    0.41864916731037083,
                                ],
                                [
                                    0.026587708172407284,
                                    0.4452368754827781,
                                    0.029763124517221864,
                                    0.4984122918275927,
                                ],
                                [
                                    0.05317541634481457,
                                    0.41864916731037083,
                                    0.05952624903444373,
                                    0.4686491673103709,
                                ],
                                [
                                    0.029763124517221864,
                                    0.4984122918275927,
                                    0.026587708172407284,
                                    0.4452368754827781,
                                ],
                                [
                                    0.05952624903444373,
                                    0.4686491673103709,
                                    0.05317541634481457,
                                    0.41864916731037083,
                                ],
                                [0.0625, 0.1875, 0.1875, 0.5625],
                                [0.1875, 0.5625, 0.0625, 0.1875],
                                [0.09375, 0.28125, 0.15625, 0.46875],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.15625, 0.46875, 0.09375, 0.28125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.024999999999999998,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.525,
                                ],
                                [
                                    0.41864916731037083,
                                    0.525,
                                    0.024999999999999998,
                                    0.031350832689629154,
                                ],
                                [
                                    0.12341229182759271,
                                    0.15476312451722185,
                                    0.3202368754827781,
                                    0.4015877081724073,
                                ],
                                [
                                    0.24682458365518542,
                                    0.031350832689629154,
                                    0.6404737509655563,
                                    0.08135083268962914,
                                ],
                                [
                                    0.3202368754827781,
                                    0.4015877081724073,
                                    0.12341229182759271,
                                    0.15476312451722185,
                                ],
                                [
                                    0.6404737509655563,
                                    0.08135083268962914,
                                    0.24682458365518542,
                                    0.031350832689629154,
                                ],
                                [
                                    0.0056350832689629135,
                                    0.09436491673103706,
                                    0.050715749420666235,
                                    0.8492842505793338,
                                ],
                                [
                                    0.011985915958592068,
                                    0.2007157494206662,
                                    0.04436491673103708,
                                    0.7429334178897047,
                                ],
                                [
                                    0.005992957979296037,
                                    0.10035787471033315,
                                    0.05035787471033311,
                                    0.8432912926000377,
                                ],
                                [
                                    0.011985915958592074,
                                    0.09436491673103711,
                                    0.10071574942066622,
                                    0.7929334178897046,
                                ],
                                [
                                    0.009168374324110613,
                                    0.15353329105514774,
                                    0.047182458365518536,
                                    0.7901158762552232,
                                ],
                                [
                                    0.018336748648221227,
                                    0.1443649167310371,
                                    0.09436491673103707,
                                    0.7429334178897046,
                                ],
                                [
                                    0.014087708172407287,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.7077368754827782,
                                ],
                                [
                                    0.1390877081724073,
                                    0.41726312451722186,
                                    0.11091229182759271,
                                    0.33273687548277814,
                                ],
                                [
                                    0.02113156225861093,
                                    0.06339468677583279,
                                    0.22886843774138907,
                                    0.6866053132241672,
                                ],
                                [
                                    0.04226312451722186,
                                    0.04226312451722186,
                                    0.45773687548277814,
                                    0.45773687548277814,
                                ],
                                [
                                    0.08363156225861093,
                                    0.2508946867758328,
                                    0.16636843774138907,
                                    0.4991053132241672,
                                ],
                                [
                                    0.16726312451722186,
                                    0.16726312451722186,
                                    0.33273687548277814,
                                    0.33273687548277814,
                                ],
                                [
                                    0.00563508326896292,
                                    0.0070665821102954005,
                                    0.43801408404140796,
                                    0.5492842505793337,
                                ],
                                [
                                    0.39928425057933375,
                                    0.5007157494206662,
                                    0.04436491673103708,
                                    0.05563508326896291,
                                ],
                                [
                                    0.027817541634481434,
                                    0.03488412374477682,
                                    0.41583162567588944,
                                    0.5214667089448524,
                                ],
                                [
                                    0.05563508326896287,
                                    0.007066582110295388,
                                    0.8316632513517789,
                                    0.10563508326896291,
                                ],
                                [
                                    0.22464212528966687,
                                    0.28170870739996223,
                                    0.21900704202070398,
                                    0.27464212528966686,
                                ],
                                [
                                    0.44928425057933374,
                                    0.05706658211029538,
                                    0.43801408404140796,
                                    0.05563508326896291,
                                ],
                                [
                                    0.07872983346207416,
                                    0.7085685011586675,
                                    0.021270166537925822,
                                    0.19143149884133245,
                                ],
                                [0.08999999999999998, 0.81, 0.009999999999999997, 0.09],
                                [
                                    0.08372983346207415,
                                    0.7535685011586675,
                                    0.016270166537925825,
                                    0.14643149884133247,
                                ],
                                [
                                    0.09436491673103707,
                                    0.7429334178897046,
                                    0.018336748648221223,
                                    0.14436491673103707,
                                ],
                                [
                                    0.08936491673103707,
                                    0.8042842505793337,
                                    0.010635083268962911,
                                    0.09571574942066623,
                                ],
                                [
                                    0.10071574942066622,
                                    0.7929334178897046,
                                    0.011985915958592068,
                                    0.09436491673103707,
                                ],
                                [
                                    0.19682458365518543,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.3095262490344437,
                                ],
                                [
                                    0.41864916731037083,
                                    0.525,
                                    0.024999999999999998,
                                    0.031350832689629154,
                                ],
                                [
                                    0.29523687548277816,
                                    0.3702368754827781,
                                    0.14841229182759272,
                                    0.186113957206851,
                                ],
                                [
                                    0.33273687548277814,
                                    0.33273687548277814,
                                    0.16726312451722186,
                                    0.16726312451722186,
                                ],
                                [
                                    0.4061491673103709,
                                    0.5093245836551854,
                                    0.0375,
                                    0.047026249034443725,
                                ],
                                [
                                    0.45773687548277814,
                                    0.45773687548277814,
                                    0.04226312451722186,
                                    0.04226312451722186,
                                ],
                                [
                                    0.07872983346207416,
                                    0.021270166537925822,
                                    0.7085685011586675,
                                    0.19143149884133245,
                                ],
                                [
                                    0.7772983346207417,
                                    0.20999999999999996,
                                    0.009999999999999998,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.3886491673103709,
                                    0.105,
                                    0.3986491673103708,
                                    0.10770166537925828,
                                ],
                                [
                                    0.43801408404140796,
                                    0.055635083268962916,
                                    0.44928425057933374,
                                    0.05706658211029538,
                                ],
                                [
                                    0.7379334178897047,
                                    0.19936491673103707,
                                    0.04936491673103709,
                                    0.013336748648221224,
                                ],
                                [
                                    0.8316632513517789,
                                    0.10563508326896291,
                                    0.055635083268962916,
                                    0.007066582110295394,
                                ],
                                [
                                    0.044364916731037075,
                                    0.39928425057933375,
                                    0.0556350832689629,
                                    0.5007157494206662,
                                ],
                                [
                                    0.0556350832689629,
                                    0.5007157494206662,
                                    0.044364916731037075,
                                    0.39928425057933375,
                                ],
                                [
                                    0.04718245836551853,
                                    0.4246421252896669,
                                    0.05281754163448145,
                                    0.47535787471033314,
                                ],
                                [
                                    0.05317541634481457,
                                    0.41864916731037083,
                                    0.05952624903444373,
                                    0.4686491673103709,
                                ],
                                [
                                    0.05281754163448145,
                                    0.47535787471033314,
                                    0.04718245836551853,
                                    0.4246421252896669,
                                ],
                                [
                                    0.05952624903444373,
                                    0.4686491673103709,
                                    0.05317541634481457,
                                    0.41864916731037083,
                                ],
                                [
                                    0.11091229182759271,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.41726312451722186,
                                ],
                                [
                                    0.33273687548277814,
                                    0.41726312451722186,
                                    0.11091229182759271,
                                    0.1390877081724073,
                                ],
                                [
                                    0.16636843774138907,
                                    0.20863156225861093,
                                    0.27728072956898175,
                                    0.34771927043101825,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.27728072956898175,
                                    0.34771927043101825,
                                    0.16636843774138907,
                                    0.20863156225861093,
                                ],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.04436491673103708,
                                    0.011985915958592068,
                                    0.7429334178897047,
                                    0.2007157494206662,
                                ],
                                [
                                    0.7429334178897047,
                                    0.2007157494206662,
                                    0.04436491673103708,
                                    0.011985915958592068,
                                ],
                                [
                                    0.21900704202070398,
                                    0.0591683743241106,
                                    0.5682912926000377,
                                    0.15353329105514768,
                                ],
                                [
                                    0.24682458365518542,
                                    0.031350832689629154,
                                    0.6404737509655563,
                                    0.08135083268962914,
                                ],
                                [
                                    0.5682912926000377,
                                    0.15353329105514768,
                                    0.21900704202070398,
                                    0.0591683743241106,
                                ],
                                [
                                    0.6404737509655563,
                                    0.08135083268962914,
                                    0.24682458365518542,
                                    0.031350832689629154,
                                ],
                                [
                                    0.009999999999999995,
                                    0.08999999999999998,
                                    0.08999999999999998,
                                    0.81,
                                ],
                                [
                                    0.021270166537925822,
                                    0.19143149884133245,
                                    0.07872983346207416,
                                    0.7085685011586675,
                                ],
                                [
                                    0.010635083268962916,
                                    0.09571574942066628,
                                    0.08936491673103707,
                                    0.8042842505793337,
                                ],
                                [
                                    0.011985915958592074,
                                    0.09436491673103711,
                                    0.10071574942066622,
                                    0.7929334178897046,
                                ],
                                [
                                    0.01627016653792583,
                                    0.14643149884133252,
                                    0.08372983346207415,
                                    0.7535685011586675,
                                ],
                                [
                                    0.018336748648221227,
                                    0.1443649167310371,
                                    0.09436491673103707,
                                    0.7429334178897046,
                                ],
                                [
                                    0.024999999999999998,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.525,
                                ],
                                [
                                    0.24682458365518542,
                                    0.3095262490344437,
                                    0.19682458365518543,
                                    0.24682458365518542,
                                ],
                                [
                                    0.0375,
                                    0.047026249034443725,
                                    0.4061491673103709,
                                    0.5093245836551854,
                                ],
                                [
                                    0.04226312451722186,
                                    0.04226312451722186,
                                    0.45773687548277814,
                                    0.45773687548277814,
                                ],
                                [
                                    0.14841229182759272,
                                    0.186113957206851,
                                    0.29523687548277816,
                                    0.3702368754827781,
                                ],
                                [
                                    0.16726312451722186,
                                    0.16726312451722186,
                                    0.33273687548277814,
                                    0.33273687548277814,
                                ],
                                [
                                    0.010000000000000007,
                                    0.002701665379258313,
                                    0.7772983346207417,
                                    0.20999999999999996,
                                ],
                                [
                                    0.7085685011586675,
                                    0.19143149884133245,
                                    0.07872983346207417,
                                    0.021270166537925825,
                                ],
                                [
                                    0.04936491673103704,
                                    0.013336748648221212,
                                    0.7379334178897047,
                                    0.19936491673103707,
                                ],
                                [
                                    0.05563508326896287,
                                    0.007066582110295388,
                                    0.8316632513517789,
                                    0.10563508326896291,
                                ],
                                [
                                    0.3986491673103708,
                                    0.10770166537925828,
                                    0.38864916731037086,
                                    0.10499999999999998,
                                ],
                                [
                                    0.44928425057933374,
                                    0.05706658211029538,
                                    0.43801408404140796,
                                    0.05563508326896291,
                                ],
                                [
                                    0.010000000000000007,
                                    0.7772983346207417,
                                    0.002701665379258313,
                                    0.20999999999999996,
                                ],
                                [
                                    0.011431498841332488,
                                    0.8885685011586675,
                                    0.001270166537925832,
                                    0.09872983346207416,
                                ],
                                [
                                    0.010143149884133255,
                                    0.7884253512745343,
                                    0.002558515495125065,
                                    0.1988729833462074,
                                ],
                                [
                                    0.08999999999999998,
                                    0.7085685011586675,
                                    0.022701665379258308,
                                    0.17872983346207416,
                                ],
                                [
                                    0.011413316422059087,
                                    0.8871551847366084,
                                    0.001288348957199233,
                                    0.10014314988413324,
                                ],
                                [
                                    0.10127016653792581,
                                    0.7972983346207416,
                                    0.011431498841332478,
                                    0.09,
                                ],
                                [
                                    0.024999999999999998,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.525,
                                ],
                                [
                                    0.05317541634481457,
                                    0.8904737509655563,
                                    0.003175416344814577,
                                    0.05317541634481457,
                                ],
                                [
                                    0.027817541634481458,
                                    0.4658316256758894,
                                    0.02853329105514769,
                                    0.4778175416344814,
                                ],
                                [
                                    0.24682458365518545,
                                    0.24682458365518545,
                                    0.25317541634481455,
                                    0.25317541634481455,
                                ],
                                [
                                    0.052817541634481456,
                                    0.8844807929862603,
                                    0.003533291055147697,
                                    0.05916837432411061,
                                ],
                                [
                                    0.4686491673103709,
                                    0.4686491673103709,
                                    0.031350832689629154,
                                    0.031350832689629154,
                                ],
                                [
                                    0.009999999999999995,
                                    0.08999999999999998,
                                    0.08999999999999998,
                                    0.81,
                                ],
                                [
                                    0.09872983346207415,
                                    0.8885685011586675,
                                    0.0012701665379258305,
                                    0.011431498841332478,
                                ],
                                [
                                    0.018872983346207413,
                                    0.16985685011586676,
                                    0.08112701665379257,
                                    0.7301431498841333,
                                ],
                                [
                                    0.16745966692414835,
                                    0.02127016653792583,
                                    0.7198386676965933,
                                    0.09143149884133248,
                                ],
                                [
                                    0.09760281680828156,
                                    0.8784253512745344,
                                    0.002397183191718413,
                                    0.021574648725465724,
                                ],
                                [
                                    0.8660281680828159,
                                    0.10999999999999999,
                                    0.021270166537925825,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.00563508326896292,
                                    0.43801408404140796,
                                    0.0070665821102954005,
                                    0.5492842505793337,
                                ],
                                [
                                    0.0070665821102954005,
                                    0.5492842505793337,
                                    0.00563508326896292,
                                    0.43801408404140796,
                                ],
                                [
                                    0.005715749420666243,
                                    0.44428425057933374,
                                    0.006985915958592077,
                                    0.5430140840414079,
                                ],
                                [
                                    0.05071574942066623,
                                    0.3992842505793337,
                                    0.06198591595859207,
                                    0.488014084041408,
                                ],
                                [
                                    0.006985915958592077,
                                    0.5430140840414079,
                                    0.005715749420666244,
                                    0.44428425057933374,
                                ],
                                [
                                    0.06198591595859207,
                                    0.488014084041408,
                                    0.050715749420666235,
                                    0.39928425057933375,
                                ],
                                [
                                    0.014087708172407287,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.7077368754827782,
                                ],
                                [
                                    0.04226312451722186,
                                    0.7077368754827782,
                                    0.014087708172407287,
                                    0.2359122918275927,
                                ],
                                [
                                    0.015675416344814577,
                                    0.2625,
                                    0.04067541634481457,
                                    0.6811491673103709,
                                ],
                                [
                                    0.1390877081724073,
                                    0.1390877081724073,
                                    0.3609122918275927,
                                    0.3609122918275927,
                                ],
                                [
                                    0.04067541634481457,
                                    0.6811491673103709,
                                    0.015675416344814577,
                                    0.2625,
                                ],
                                [
                                    0.3609122918275927,
                                    0.3609122918275927,
                                    0.1390877081724073,
                                    0.1390877081724073,
                                ],
                                [
                                    0.0056350832689629135,
                                    0.050715749420666235,
                                    0.09436491673103706,
                                    0.8492842505793338,
                                ],
                                [
                                    0.09436491673103706,
                                    0.8492842505793338,
                                    0.0056350832689629135,
                                    0.050715749420666235,
                                ],
                                [
                                    0.010635083268962916,
                                    0.09571574942066628,
                                    0.08936491673103707,
                                    0.8042842505793337,
                                ],
                                [
                                    0.09436491673103711,
                                    0.011985915958592074,
                                    0.7929334178897046,
                                    0.10071574942066622,
                                ],
                                [
                                    0.08936491673103707,
                                    0.8042842505793337,
                                    0.010635083268962911,
                                    0.09571574942066623,
                                ],
                                [
                                    0.7929334178897046,
                                    0.10071574942066622,
                                    0.09436491673103707,
                                    0.011985915958592068,
                                ],
                                [
                                    0.0012701665379258318,
                                    0.09872983346207415,
                                    0.011431498841332488,
                                    0.8885685011586675,
                                ],
                                [
                                    0.002701665379258313,
                                    0.20999999999999996,
                                    0.010000000000000007,
                                    0.7772983346207417,
                                ],
                                [
                                    0.0012883489571992336,
                                    0.10014314988413328,
                                    0.011413316422059087,
                                    0.8871551847366084,
                                ],
                                [
                                    0.011431498841332483,
                                    0.09000000000000002,
                                    0.10127016653792581,
                                    0.7972983346207416,
                                ],
                                [
                                    0.0025585154951250654,
                                    0.19887298334620743,
                                    0.010143149884133255,
                                    0.7884253512745343,
                                ],
                                [
                                    0.022701665379258308,
                                    0.1787298334620742,
                                    0.08999999999999998,
                                    0.7085685011586675,
                                ],
                                [
                                    0.003175416344814577,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.8904737509655563,
                                ],
                                [
                                    0.031350832689629154,
                                    0.525,
                                    0.024999999999999998,
                                    0.41864916731037083,
                                ],
                                [
                                    0.003533291055147694,
                                    0.05916837432411056,
                                    0.052817541634481456,
                                    0.8844807929862603,
                                ],
                                [
                                    0.03135083268962913,
                                    0.03135083268962913,
                                    0.4686491673103709,
                                    0.4686491673103709,
                                ],
                                [
                                    0.02853329105514769,
                                    0.4778175416344814,
                                    0.027817541634481455,
                                    0.46583162567588937,
                                ],
                                [
                                    0.25317541634481455,
                                    0.25317541634481455,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                ],
                                [
                                    0.0012701665379258318,
                                    0.011431498841332488,
                                    0.09872983346207415,
                                    0.8885685011586675,
                                ],
                                [0.08999999999999998, 0.81, 0.009999999999999997, 0.09],
                                [
                                    0.00239718319171841,
                                    0.021574648725465696,
                                    0.09760281680828156,
                                    0.8784253512745344,
                                ],
                                [
                                    0.021270166537925798,
                                    0.002701665379258307,
                                    0.8660281680828159,
                                    0.10999999999999999,
                                ],
                                [
                                    0.08112701665379257,
                                    0.7301431498841333,
                                    0.01887298334620741,
                                    0.16985685011586674,
                                ],
                                [
                                    0.7198386676965933,
                                    0.09143149884133248,
                                    0.16745966692414832,
                                    0.021270166537925825,
                                ],
                                [
                                    0.04436491673103708,
                                    0.7429334178897047,
                                    0.011985915958592068,
                                    0.2007157494206662,
                                ],
                                [
                                    0.050715749420666235,
                                    0.8492842505793338,
                                    0.005635083268962914,
                                    0.09436491673103707,
                                ],
                                [
                                    0.04499999999999999,
                                    0.7535685011586675,
                                    0.011350832689629154,
                                    0.1900806661517033,
                                ],
                                [
                                    0.08999999999999998,
                                    0.7085685011586675,
                                    0.022701665379258308,
                                    0.17872983346207416,
                                ],
                                [
                                    0.050635083268962905,
                                    0.8479334178897046,
                                    0.005715749420666239,
                                    0.09571574942066623,
                                ],
                                [
                                    0.10127016653792581,
                                    0.7972983346207416,
                                    0.011431498841332478,
                                    0.09,
                                ],
                                [
                                    0.11091229182759271,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.41726312451722186,
                                ],
                                [
                                    0.2359122918275927,
                                    0.7077368754827782,
                                    0.014087708172407287,
                                    0.04226312451722186,
                                ],
                                [
                                    0.12341229182759272,
                                    0.37023687548277817,
                                    0.12658770817240728,
                                    0.37976312451722183,
                                ],
                                [
                                    0.24682458365518545,
                                    0.24682458365518545,
                                    0.25317541634481455,
                                    0.25317541634481455,
                                ],
                                [
                                    0.23432458365518544,
                                    0.7029737509655563,
                                    0.015675416344814577,
                                    0.04702624903444373,
                                ],
                                [
                                    0.4686491673103709,
                                    0.4686491673103709,
                                    0.031350832689629154,
                                    0.031350832689629154,
                                ],
                                [
                                    0.044364916731037075,
                                    0.0556350832689629,
                                    0.39928425057933375,
                                    0.5007157494206662,
                                ],
                                [
                                    0.43801408404140796,
                                    0.5492842505793337,
                                    0.005635083268962914,
                                    0.0070665821102953935,
                                ],
                                [
                                    0.08372983346207417,
                                    0.105,
                                    0.35991933384829666,
                                    0.45135083268962917,
                                ],
                                [
                                    0.16745966692414835,
                                    0.02127016653792583,
                                    0.7198386676965933,
                                    0.09143149884133248,
                                ],
                                [
                                    0.43301408404140795,
                                    0.5430140840414079,
                                    0.010635083268962913,
                                    0.013336748648221224,
                                ],
                                [
                                    0.8660281680828159,
                                    0.10999999999999999,
                                    0.021270166537925825,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.024999999999999998,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.525,
                                ],
                                [
                                    0.031350832689629154,
                                    0.525,
                                    0.024999999999999998,
                                    0.41864916731037083,
                                ],
                                [
                                    0.025357874710333114,
                                    0.4246421252896668,
                                    0.030992957979296035,
                                    0.519007042020704,
                                ],
                                [
                                    0.05071574942066623,
                                    0.3992842505793337,
                                    0.06198591595859207,
                                    0.488014084041408,
                                ],
                                [
                                    0.030992957979296035,
                                    0.519007042020704,
                                    0.025357874710333118,
                                    0.4246421252896669,
                                ],
                                [
                                    0.06198591595859207,
                                    0.488014084041408,
                                    0.050715749420666235,
                                    0.39928425057933375,
                                ],
                                [0.0625, 0.1875, 0.1875, 0.5625],
                                [0.1875, 0.5625, 0.0625, 0.1875],
                                [
                                    0.06954385408620364,
                                    0.20863156225861093,
                                    0.18045614591379636,
                                    0.5413684377413891,
                                ],
                                [
                                    0.1390877081724073,
                                    0.1390877081724073,
                                    0.3609122918275927,
                                    0.3609122918275927,
                                ],
                                [
                                    0.18045614591379636,
                                    0.5413684377413891,
                                    0.06954385408620364,
                                    0.20863156225861093,
                                ],
                                [
                                    0.3609122918275927,
                                    0.3609122918275927,
                                    0.1390877081724073,
                                    0.1390877081724073,
                                ],
                                [
                                    0.024999999999999998,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.525,
                                ],
                                [
                                    0.41864916731037083,
                                    0.525,
                                    0.024999999999999998,
                                    0.031350832689629154,
                                ],
                                [
                                    0.047182458365518556,
                                    0.05916837432411064,
                                    0.3964667089448523,
                                    0.4971824583655185,
                                ],
                                [
                                    0.09436491673103711,
                                    0.011985915958592074,
                                    0.7929334178897046,
                                    0.10071574942066622,
                                ],
                                [
                                    0.3964667089448523,
                                    0.4971824583655185,
                                    0.047182458365518536,
                                    0.0591683743241106,
                                ],
                                [
                                    0.7929334178897046,
                                    0.10071574942066622,
                                    0.09436491673103707,
                                    0.011985915958592068,
                                ],
                                [
                                    0.0056350832689629135,
                                    0.09436491673103706,
                                    0.050715749420666235,
                                    0.8492842505793338,
                                ],
                                [
                                    0.011985915958592068,
                                    0.2007157494206662,
                                    0.04436491673103708,
                                    0.7429334178897047,
                                ],
                                [
                                    0.005715749420666241,
                                    0.09571574942066627,
                                    0.050635083268962905,
                                    0.8479334178897046,
                                ],
                                [
                                    0.011431498841332483,
                                    0.09000000000000002,
                                    0.10127016653792581,
                                    0.7972983346207416,
                                ],
                                [
                                    0.011350832689629154,
                                    0.19008066615170333,
                                    0.04499999999999999,
                                    0.7535685011586675,
                                ],
                                [
                                    0.022701665379258308,
                                    0.1787298334620742,
                                    0.08999999999999998,
                                    0.7085685011586675,
                                ],
                                [
                                    0.014087708172407287,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.7077368754827782,
                                ],
                                [
                                    0.1390877081724073,
                                    0.41726312451722186,
                                    0.11091229182759271,
                                    0.33273687548277814,
                                ],
                                [
                                    0.015675416344814563,
                                    0.04702624903444369,
                                    0.23432458365518544,
                                    0.7029737509655563,
                                ],
                                [
                                    0.03135083268962913,
                                    0.03135083268962913,
                                    0.4686491673103709,
                                    0.4686491673103709,
                                ],
                                [
                                    0.12658770817240728,
                                    0.37976312451722183,
                                    0.12341229182759271,
                                    0.3702368754827781,
                                ],
                                [
                                    0.25317541634481455,
                                    0.25317541634481455,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                ],
                                [
                                    0.00563508326896292,
                                    0.0070665821102954005,
                                    0.43801408404140796,
                                    0.5492842505793337,
                                ],
                                [
                                    0.39928425057933375,
                                    0.5007157494206662,
                                    0.04436491673103708,
                                    0.05563508326896291,
                                ],
                                [
                                    0.010635083268962899,
                                    0.013336748648221207,
                                    0.43301408404140795,
                                    0.5430140840414079,
                                ],
                                [
                                    0.021270166537925798,
                                    0.002701665379258307,
                                    0.8660281680828159,
                                    0.10999999999999999,
                                ],
                                [
                                    0.35991933384829666,
                                    0.45135083268962917,
                                    0.08372983346207416,
                                    0.10499999999999998,
                                ],
                                [
                                    0.7198386676965933,
                                    0.09143149884133248,
                                    0.16745966692414832,
                                    0.021270166537925825,
                                ],
                                [
                                    0.07872983346207416,
                                    0.7085685011586675,
                                    0.021270166537925822,
                                    0.19143149884133245,
                                ],
                                [0.08999999999999998, 0.81, 0.009999999999999997, 0.09],
                                [
                                    0.07985685011586674,
                                    0.7187116510428008,
                                    0.02014314988413324,
                                    0.18128834895719922,
                                ],
                                [
                                    0.08999999999999998,
                                    0.7085685011586675,
                                    0.022701665379258308,
                                    0.17872983346207416,
                                ],
                                [
                                    0.08985685011586673,
                                    0.8087116510428007,
                                    0.010143149884133245,
                                    0.09128834895719923,
                                ],
                                [
                                    0.10127016653792581,
                                    0.7972983346207416,
                                    0.011431498841332478,
                                    0.09,
                                ],
                                [
                                    0.19682458365518543,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.3095262490344437,
                                ],
                                [
                                    0.41864916731037083,
                                    0.525,
                                    0.024999999999999998,
                                    0.031350832689629154,
                                ],
                                [
                                    0.21900704202070398,
                                    0.2746421252896669,
                                    0.22464212528966687,
                                    0.28170870739996223,
                                ],
                                [
                                    0.24682458365518545,
                                    0.24682458365518545,
                                    0.25317541634481455,
                                    0.25317541634481455,
                                ],
                                [
                                    0.41583162567588944,
                                    0.5214667089448524,
                                    0.027817541634481458,
                                    0.034884123744776854,
                                ],
                                [
                                    0.4686491673103709,
                                    0.4686491673103709,
                                    0.031350832689629154,
                                    0.031350832689629154,
                                ],
                                [
                                    0.07872983346207416,
                                    0.021270166537925822,
                                    0.7085685011586675,
                                    0.19143149884133245,
                                ],
                                [
                                    0.7772983346207417,
                                    0.20999999999999996,
                                    0.009999999999999998,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.14858668357794094,
                                    0.04014314988413324,
                                    0.6387116510428008,
                                    0.17255851549512505,
                                ],
                                [
                                    0.16745966692414835,
                                    0.02127016653792583,
                                    0.7198386676965933,
                                    0.09143149884133248,
                                ],
                                [
                                    0.7684253512745344,
                                    0.20760281680828155,
                                    0.018872983346207413,
                                    0.005098848570976724,
                                ],
                                [
                                    0.8660281680828159,
                                    0.10999999999999999,
                                    0.021270166537925825,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.044364916731037075,
                                    0.39928425057933375,
                                    0.0556350832689629,
                                    0.5007157494206662,
                                ],
                                [
                                    0.0556350832689629,
                                    0.5007157494206662,
                                    0.044364916731037075,
                                    0.39928425057933375,
                                ],
                                [
                                    0.044999999999999984,
                                    0.40499999999999997,
                                    0.05499999999999999,
                                    0.49500000000000005,
                                ],
                                [
                                    0.05071574942066623,
                                    0.3992842505793337,
                                    0.06198591595859207,
                                    0.488014084041408,
                                ],
                                [
                                    0.05499999999999999,
                                    0.49500000000000005,
                                    0.04499999999999999,
                                    0.405,
                                ],
                                [
                                    0.06198591595859207,
                                    0.488014084041408,
                                    0.050715749420666235,
                                    0.39928425057933375,
                                ],
                                [
                                    0.11091229182759271,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.41726312451722186,
                                ],
                                [
                                    0.33273687548277814,
                                    0.41726312451722186,
                                    0.11091229182759271,
                                    0.1390877081724073,
                                ],
                                [
                                    0.12341229182759271,
                                    0.15476312451722185,
                                    0.3202368754827781,
                                    0.4015877081724073,
                                ],
                                [
                                    0.1390877081724073,
                                    0.1390877081724073,
                                    0.3609122918275927,
                                    0.3609122918275927,
                                ],
                                [
                                    0.3202368754827781,
                                    0.4015877081724073,
                                    0.12341229182759271,
                                    0.15476312451722185,
                                ],
                                [
                                    0.3609122918275927,
                                    0.3609122918275927,
                                    0.1390877081724073,
                                    0.1390877081724073,
                                ],
                                [
                                    0.04436491673103708,
                                    0.011985915958592068,
                                    0.7429334178897047,
                                    0.2007157494206662,
                                ],
                                [
                                    0.7429334178897047,
                                    0.2007157494206662,
                                    0.04436491673103708,
                                    0.011985915958592068,
                                ],
                                [
                                    0.0837298334620742,
                                    0.02262099922755499,
                                    0.7035685011586675,
                                    0.1900806661517033,
                                ],
                                [
                                    0.09436491673103711,
                                    0.011985915958592074,
                                    0.7929334178897046,
                                    0.10071574942066622,
                                ],
                                [
                                    0.7035685011586675,
                                    0.1900806661517033,
                                    0.08372983346207416,
                                    0.022620999227554978,
                                ],
                                [
                                    0.7929334178897046,
                                    0.10071574942066622,
                                    0.09436491673103707,
                                    0.011985915958592068,
                                ],
                                [
                                    0.009999999999999995,
                                    0.08999999999999998,
                                    0.08999999999999998,
                                    0.81,
                                ],
                                [
                                    0.021270166537925822,
                                    0.19143149884133245,
                                    0.07872983346207416,
                                    0.7085685011586675,
                                ],
                                [
                                    0.01014314988413325,
                                    0.09128834895719927,
                                    0.08985685011586673,
                                    0.8087116510428007,
                                ],
                                [
                                    0.011431498841332483,
                                    0.09000000000000002,
                                    0.10127016653792581,
                                    0.7972983346207416,
                                ],
                                [
                                    0.020143149884133245,
                                    0.18128834895719925,
                                    0.07985685011586674,
                                    0.7187116510428008,
                                ],
                                [
                                    0.022701665379258308,
                                    0.1787298334620742,
                                    0.08999999999999998,
                                    0.7085685011586675,
                                ],
                                [
                                    0.024999999999999998,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.525,
                                ],
                                [
                                    0.24682458365518542,
                                    0.3095262490344437,
                                    0.19682458365518543,
                                    0.24682458365518542,
                                ],
                                [
                                    0.027817541634481434,
                                    0.03488412374477682,
                                    0.41583162567588944,
                                    0.5214667089448524,
                                ],
                                [
                                    0.03135083268962913,
                                    0.03135083268962913,
                                    0.4686491673103709,
                                    0.4686491673103709,
                                ],
                                [
                                    0.22464212528966687,
                                    0.28170870739996223,
                                    0.21900704202070398,
                                    0.27464212528966686,
                                ],
                                [
                                    0.25317541634481455,
                                    0.25317541634481455,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                ],
                                [
                                    0.010000000000000007,
                                    0.002701665379258313,
                                    0.7772983346207417,
                                    0.20999999999999996,
                                ],
                                [
                                    0.7085685011586675,
                                    0.19143149884133245,
                                    0.07872983346207417,
                                    0.021270166537925825,
                                ],
                                [
                                    0.01887298334620739,
                                    0.005098848570976717,
                                    0.7684253512745344,
                                    0.20760281680828155,
                                ],
                                [
                                    0.021270166537925798,
                                    0.002701665379258307,
                                    0.8660281680828159,
                                    0.10999999999999999,
                                ],
                                [
                                    0.6387116510428008,
                                    0.17255851549512505,
                                    0.14858668357794091,
                                    0.040143149884133235,
                                ],
                                [
                                    0.7198386676965933,
                                    0.09143149884133248,
                                    0.16745966692414832,
                                    0.021270166537925825,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7772983346207417,
                                    0.009999999999999998,
                                    0.20999999999999996,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.7885685011586675,
                                    0.10016133230340664,
                                    0.09872983346207416,
                                    0.012540333075851659,
                                ],
                                [
                                    0.8774414845048749,
                                    0.011288348957199228,
                                    0.10985685011586674,
                                    0.0014133164220590786,
                                ],
                                [
                                    0.7772983346207417,
                                    0.09872983346207416,
                                    0.10999999999999999,
                                    0.013971831917184138,
                                ],
                                [
                                    0.8649011514290234,
                                    0.01112701665379258,
                                    0.1223971831917184,
                                    0.0015746487254657277,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.4468245836551854,
                                    0.4468245836551854,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                ],
                                [
                                    0.8432912926000377,
                                    0.05035787471033311,
                                    0.1003578747103331,
                                    0.005992957979296034,
                                ],
                                [
                                    0.41864916731037083,
                                    0.41864916731037083,
                                    0.08135083268962914,
                                    0.08135083268962914,
                                ],
                                [
                                    0.7901158762552232,
                                    0.047182458365518536,
                                    0.15353329105514768,
                                    0.009168374324110612,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.10127016653792581,
                                    0.7972983346207416,
                                    0.011431498841332478,
                                    0.09,
                                ],
                                [
                                    0.8087116510428007,
                                    0.08985685011586673,
                                    0.09128834895719923,
                                    0.010143149884133246,
                                ],
                                [
                                    0.08999999999999998,
                                    0.7085685011586675,
                                    0.022701665379258308,
                                    0.17872983346207416,
                                ],
                                [
                                    0.7187116510428008,
                                    0.07985685011586674,
                                    0.18128834895719922,
                                    0.020143149884133245,
                                ],
                                [
                                    0.5492842505793337,
                                    0.0070665821102953935,
                                    0.43801408404140796,
                                    0.005635083268962914,
                                ],
                                [
                                    0.43801408404140796,
                                    0.005635083268962914,
                                    0.5492842505793337,
                                    0.0070665821102953935,
                                ],
                                [
                                    0.44928425057933374,
                                    0.05706658211029538,
                                    0.43801408404140796,
                                    0.05563508326896291,
                                ],
                                [
                                    0.4999193338482966,
                                    0.0064314988413324775,
                                    0.487379000772445,
                                    0.0062701665379258295,
                                ],
                                [
                                    0.43801408404140796,
                                    0.055635083268962916,
                                    0.44928425057933374,
                                    0.05706658211029538,
                                ],
                                [
                                    0.48737900077244506,
                                    0.00627016653792583,
                                    0.4999193338482966,
                                    0.0064314988413324775,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.2359122918275927,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.04226312451722186,
                                ],
                                [
                                    0.2640877081724073,
                                    0.2640877081724073,
                                    0.2359122918275927,
                                    0.2359122918275927,
                                ],
                                [
                                    0.4984122918275927,
                                    0.029763124517221864,
                                    0.4452368754827781,
                                    0.026587708172407284,
                                ],
                                [
                                    0.2359122918275927,
                                    0.2359122918275927,
                                    0.2640877081724073,
                                    0.2640877081724073,
                                ],
                                [
                                    0.4452368754827781,
                                    0.026587708172407284,
                                    0.4984122918275927,
                                    0.029763124517221864,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.050715749420666235,
                                    0.005635083268962914,
                                    0.8492842505793338,
                                    0.09436491673103707,
                                ],
                                [
                                    0.06198591595859207,
                                    0.488014084041408,
                                    0.050715749420666235,
                                    0.39928425057933375,
                                ],
                                [0.49500000000000005, 0.055, 0.405, 0.045],
                                [
                                    0.05071574942066623,
                                    0.3992842505793337,
                                    0.06198591595859207,
                                    0.488014084041408,
                                ],
                                [
                                    0.40499999999999997,
                                    0.04499999999999999,
                                    0.49500000000000005,
                                    0.055,
                                ],
                                [
                                    0.20999999999999996,
                                    0.0027016653792583103,
                                    0.7772983346207417,
                                    0.009999999999999998,
                                ],
                                [
                                    0.09872983346207415,
                                    0.0012701665379258305,
                                    0.8885685011586675,
                                    0.011431498841332478,
                                ],
                                [
                                    0.10999999999999995,
                                    0.013971831917184135,
                                    0.7772983346207417,
                                    0.09872983346207416,
                                ],
                                [
                                    0.12239718319171836,
                                    0.001574648725465727,
                                    0.8649011514290234,
                                    0.01112701665379258,
                                ],
                                [
                                    0.0987298334620741,
                                    0.012540333075851654,
                                    0.7885685011586676,
                                    0.10016133230340664,
                                ],
                                [
                                    0.10985685011586668,
                                    0.001413316422059078,
                                    0.877441484504875,
                                    0.01128834895719923,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.05317541634481457,
                                    0.003175416344814577,
                                    0.8904737509655563,
                                    0.05317541634481457,
                                ],
                                [
                                    0.08135083268962917,
                                    0.08135083268962917,
                                    0.41864916731037083,
                                    0.41864916731037083,
                                ],
                                [
                                    0.15353329105514774,
                                    0.009168374324110613,
                                    0.7901158762552232,
                                    0.047182458365518536,
                                ],
                                [
                                    0.0531754163448146,
                                    0.0531754163448146,
                                    0.4468245836551854,
                                    0.4468245836551854,
                                ],
                                [
                                    0.10035787471033315,
                                    0.005992957979296037,
                                    0.8432912926000377,
                                    0.05035787471033311,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.011431498841332488,
                                    0.001270166537925832,
                                    0.8885685011586675,
                                    0.09872983346207416,
                                ],
                                [
                                    0.022701665379258308,
                                    0.1787298334620742,
                                    0.08999999999999998,
                                    0.7085685011586675,
                                ],
                                [
                                    0.18128834895719925,
                                    0.02014314988413325,
                                    0.7187116510428008,
                                    0.07985685011586674,
                                ],
                                [
                                    0.011431498841332483,
                                    0.09000000000000002,
                                    0.10127016653792581,
                                    0.7972983346207416,
                                ],
                                [
                                    0.09128834895719927,
                                    0.01014314988413325,
                                    0.8087116510428007,
                                    0.08985685011586673,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7772983346207417,
                                    0.009999999999999998,
                                    0.20999999999999996,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.7885685011586675,
                                    0.10016133230340664,
                                    0.09872983346207416,
                                    0.012540333075851659,
                                ],
                                [
                                    0.8386491673103708,
                                    0.05008066615170332,
                                    0.10499999999999998,
                                    0.0062701665379258295,
                                ],
                                [
                                    0.7772983346207417,
                                    0.09872983346207416,
                                    0.10999999999999999,
                                    0.013971831917184138,
                                ],
                                [
                                    0.8266632513517789,
                                    0.04936491673103708,
                                    0.11698591595859205,
                                    0.006985915958592069,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.4468245836551854,
                                    0.4468245836551854,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                ],
                                [
                                    0.6702368754827781,
                                    0.2234122918275927,
                                    0.07976312451722185,
                                    0.026587708172407284,
                                ],
                                [
                                    0.41864916731037083,
                                    0.41864916731037083,
                                    0.08135083268962914,
                                    0.08135083268962914,
                                ],
                                [
                                    0.6279737509655563,
                                    0.20932458365518541,
                                    0.12202624903444372,
                                    0.04067541634481457,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.10127016653792581,
                                    0.7972983346207416,
                                    0.011431498841332478,
                                    0.09,
                                ],
                                [
                                    0.4999193338482967,
                                    0.3986491673103708,
                                    0.05643149884133247,
                                    0.045,
                                ],
                                [
                                    0.08999999999999998,
                                    0.7085685011586675,
                                    0.022701665379258308,
                                    0.17872983346207416,
                                ],
                                [
                                    0.44428425057933374,
                                    0.35428425057933377,
                                    0.11206658211029538,
                                    0.08936491673103708,
                                ],
                                [
                                    0.5492842505793337,
                                    0.0070665821102953935,
                                    0.43801408404140796,
                                    0.005635083268962914,
                                ],
                                [
                                    0.43801408404140796,
                                    0.005635083268962914,
                                    0.5492842505793337,
                                    0.0070665821102953935,
                                ],
                                [
                                    0.44928425057933374,
                                    0.05706658211029538,
                                    0.43801408404140796,
                                    0.05563508326896291,
                                ],
                                [
                                    0.4778175416344814,
                                    0.02853329105514769,
                                    0.46583162567588937,
                                    0.027817541634481455,
                                ],
                                [
                                    0.43801408404140796,
                                    0.055635083268962916,
                                    0.44928425057933374,
                                    0.05706658211029538,
                                ],
                                [
                                    0.4658316256758894,
                                    0.027817541634481458,
                                    0.4778175416344814,
                                    0.02853329105514769,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.2359122918275927,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.04226312451722186,
                                ],
                                [
                                    0.2640877081724073,
                                    0.2640877081724073,
                                    0.2359122918275927,
                                    0.2359122918275927,
                                ],
                                [
                                    0.3961315622586109,
                                    0.13204385408620364,
                                    0.3538684377413891,
                                    0.11795614591379636,
                                ],
                                [
                                    0.2359122918275927,
                                    0.2359122918275927,
                                    0.2640877081724073,
                                    0.2640877081724073,
                                ],
                                [
                                    0.3538684377413891,
                                    0.11795614591379636,
                                    0.3961315622586109,
                                    0.13204385408620364,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.050715749420666235,
                                    0.005635083268962914,
                                    0.8492842505793338,
                                    0.09436491673103707,
                                ],
                                [
                                    0.06198591595859207,
                                    0.488014084041408,
                                    0.050715749420666235,
                                    0.39928425057933375,
                                ],
                                [
                                    0.30599295797929604,
                                    0.244007042020704,
                                    0.2503578747103331,
                                    0.19964212528966688,
                                ],
                                [
                                    0.05071574942066623,
                                    0.3992842505793337,
                                    0.06198591595859207,
                                    0.488014084041408,
                                ],
                                [
                                    0.2503578747103331,
                                    0.19964212528966685,
                                    0.30599295797929604,
                                    0.244007042020704,
                                ],
                                [
                                    0.20999999999999996,
                                    0.0027016653792583103,
                                    0.7772983346207417,
                                    0.009999999999999998,
                                ],
                                [
                                    0.09872983346207415,
                                    0.0012701665379258305,
                                    0.8885685011586675,
                                    0.011431498841332478,
                                ],
                                [
                                    0.10999999999999995,
                                    0.013971831917184135,
                                    0.7772983346207417,
                                    0.09872983346207416,
                                ],
                                [
                                    0.11698591595859202,
                                    0.006985915958592067,
                                    0.8266632513517789,
                                    0.04936491673103708,
                                ],
                                [
                                    0.0987298334620741,
                                    0.012540333075851654,
                                    0.7885685011586676,
                                    0.10016133230340664,
                                ],
                                [
                                    0.10499999999999994,
                                    0.006270166537925827,
                                    0.8386491673103709,
                                    0.05008066615170332,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.05317541634481457,
                                    0.003175416344814577,
                                    0.8904737509655563,
                                    0.05317541634481457,
                                ],
                                [
                                    0.08135083268962917,
                                    0.08135083268962917,
                                    0.41864916731037083,
                                    0.41864916731037083,
                                ],
                                [
                                    0.12202624903444376,
                                    0.040675416344814586,
                                    0.6279737509655563,
                                    0.20932458365518541,
                                ],
                                [
                                    0.0531754163448146,
                                    0.0531754163448146,
                                    0.4468245836551854,
                                    0.4468245836551854,
                                ],
                                [
                                    0.0797631245172219,
                                    0.0265877081724073,
                                    0.6702368754827781,
                                    0.2234122918275927,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.011431498841332488,
                                    0.001270166537925832,
                                    0.8885685011586675,
                                    0.09872983346207416,
                                ],
                                [
                                    0.022701665379258308,
                                    0.1787298334620742,
                                    0.08999999999999998,
                                    0.7085685011586675,
                                ],
                                [
                                    0.1120665821102954,
                                    0.0893649167310371,
                                    0.44428425057933374,
                                    0.35428425057933377,
                                ],
                                [
                                    0.011431498841332483,
                                    0.09000000000000002,
                                    0.10127016653792581,
                                    0.7972983346207416,
                                ],
                                [
                                    0.0564314988413325,
                                    0.04500000000000001,
                                    0.4999193338482967,
                                    0.3986491673103708,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7772983346207417,
                                    0.009999999999999998,
                                    0.20999999999999996,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.7885685011586675,
                                    0.10016133230340664,
                                    0.09872983346207416,
                                    0.012540333075851659,
                                ],
                                [
                                    0.7998568501158667,
                                    0.0888729833462074,
                                    0.10014314988413324,
                                    0.01112701665379258,
                                ],
                                [
                                    0.7772983346207417,
                                    0.09872983346207416,
                                    0.10999999999999999,
                                    0.013971831917184138,
                                ],
                                [
                                    0.7884253512745344,
                                    0.08760281680828158,
                                    0.11157464872546571,
                                    0.012397183191718411,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.4468245836551854,
                                    0.4468245836551854,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                ],
                                [
                                    0.4971824583655185,
                                    0.3964667089448523,
                                    0.0591683743241106,
                                    0.047182458365518536,
                                ],
                                [
                                    0.41864916731037083,
                                    0.41864916731037083,
                                    0.08135083268962914,
                                    0.08135083268962914,
                                ],
                                [
                                    0.46583162567588937,
                                    0.3714667089448523,
                                    0.09051920701373975,
                                    0.07218245836551854,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.10127016653792581,
                                    0.7972983346207416,
                                    0.011431498841332478,
                                    0.09,
                                ],
                                [
                                    0.19112701665379253,
                                    0.707441484504875,
                                    0.021574648725465724,
                                    0.07985685011586675,
                                ],
                                [
                                    0.08999999999999998,
                                    0.7085685011586675,
                                    0.022701665379258308,
                                    0.17872983346207416,
                                ],
                                [
                                    0.1698568501158667,
                                    0.6287116510428008,
                                    0.042844815263391546,
                                    0.15858668357794092,
                                ],
                                [
                                    0.5492842505793337,
                                    0.0070665821102953935,
                                    0.43801408404140796,
                                    0.005635083268962914,
                                ],
                                [
                                    0.43801408404140796,
                                    0.005635083268962914,
                                    0.5492842505793337,
                                    0.0070665821102953935,
                                ],
                                [
                                    0.44928425057933374,
                                    0.05706658211029538,
                                    0.43801408404140796,
                                    0.05563508326896291,
                                ],
                                [
                                    0.4557157494206662,
                                    0.050635083268962905,
                                    0.44428425057933374,
                                    0.04936491673103708,
                                ],
                                [
                                    0.43801408404140796,
                                    0.055635083268962916,
                                    0.44928425057933374,
                                    0.05706658211029538,
                                ],
                                [
                                    0.4442842505793338,
                                    0.04936491673103709,
                                    0.4557157494206662,
                                    0.050635083268962905,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.2359122918275927,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.04226312451722186,
                                ],
                                [
                                    0.2640877081724073,
                                    0.2640877081724073,
                                    0.2359122918275927,
                                    0.2359122918275927,
                                ],
                                [
                                    0.29385083268962914,
                                    0.23432458365518544,
                                    0.2625,
                                    0.20932458365518541,
                                ],
                                [
                                    0.2359122918275927,
                                    0.2359122918275927,
                                    0.2640877081724073,
                                    0.2640877081724073,
                                ],
                                [
                                    0.2625,
                                    0.20932458365518541,
                                    0.29385083268962914,
                                    0.23432458365518544,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.050715749420666235,
                                    0.005635083268962914,
                                    0.8492842505793338,
                                    0.09436491673103707,
                                ],
                                [
                                    0.06198591595859207,
                                    0.488014084041408,
                                    0.050715749420666235,
                                    0.39928425057933375,
                                ],
                                [
                                    0.11698591595859206,
                                    0.433014084041408,
                                    0.09571574942066623,
                                    0.35428425057933377,
                                ],
                                [
                                    0.05071574942066623,
                                    0.3992842505793337,
                                    0.06198591595859207,
                                    0.488014084041408,
                                ],
                                [
                                    0.09571574942066621,
                                    0.3542842505793337,
                                    0.11698591595859206,
                                    0.433014084041408,
                                ],
                                [
                                    0.20999999999999996,
                                    0.0027016653792583103,
                                    0.7772983346207417,
                                    0.009999999999999998,
                                ],
                                [
                                    0.09872983346207415,
                                    0.0012701665379258305,
                                    0.8885685011586675,
                                    0.011431498841332478,
                                ],
                                [
                                    0.10999999999999995,
                                    0.013971831917184135,
                                    0.7772983346207417,
                                    0.09872983346207416,
                                ],
                                [
                                    0.11157464872546567,
                                    0.012397183191718408,
                                    0.7884253512745344,
                                    0.08760281680828158,
                                ],
                                [
                                    0.0987298334620741,
                                    0.012540333075851654,
                                    0.7885685011586676,
                                    0.10016133230340664,
                                ],
                                [
                                    0.10014314988413318,
                                    0.011127016653792576,
                                    0.7998568501158668,
                                    0.08887298334620741,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.05317541634481457,
                                    0.003175416344814577,
                                    0.8904737509655563,
                                    0.05317541634481457,
                                ],
                                [
                                    0.08135083268962917,
                                    0.08135083268962917,
                                    0.41864916731037083,
                                    0.41864916731037083,
                                ],
                                [
                                    0.09051920701373979,
                                    0.07218245836551855,
                                    0.46583162567588937,
                                    0.3714667089448523,
                                ],
                                [
                                    0.0531754163448146,
                                    0.0531754163448146,
                                    0.4468245836551854,
                                    0.4468245836551854,
                                ],
                                [
                                    0.05916837432411064,
                                    0.047182458365518556,
                                    0.4971824583655185,
                                    0.3964667089448523,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.011431498841332488,
                                    0.001270166537925832,
                                    0.8885685011586675,
                                    0.09872983346207416,
                                ],
                                [
                                    0.022701665379258308,
                                    0.1787298334620742,
                                    0.08999999999999998,
                                    0.7085685011586675,
                                ],
                                [
                                    0.04284481526339155,
                                    0.15858668357794092,
                                    0.1698568501158667,
                                    0.6287116510428008,
                                ],
                                [
                                    0.011431498841332483,
                                    0.09000000000000002,
                                    0.10127016653792581,
                                    0.7972983346207416,
                                ],
                                [
                                    0.02157464872546573,
                                    0.07985685011586678,
                                    0.19112701665379253,
                                    0.707441484504875,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.7429334178897047,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.011985915958592068,
                                ],
                                [
                                    0.7929334178897046,
                                    0.10071574942066622,
                                    0.09436491673103707,
                                    0.011985915958592068,
                                ],
                                [
                                    0.8822983346207417,
                                    0.011350832689629152,
                                    0.10499999999999998,
                                    0.0013508326896291552,
                                ],
                                [
                                    0.7429334178897046,
                                    0.09436491673103707,
                                    0.14436491673103707,
                                    0.018336748648221223,
                                ],
                                [
                                    0.8266632513517788,
                                    0.010635083268962913,
                                    0.1606350832689629,
                                    0.002066582110295395,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.33273687548277814,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.1390877081724073,
                                ],
                                [
                                    0.45773687548277814,
                                    0.45773687548277814,
                                    0.04226312451722186,
                                    0.04226312451722186,
                                ],
                                [
                                    0.863886042793149,
                                    0.051587708172407286,
                                    0.07976312451722185,
                                    0.004763124517221866,
                                ],
                                [
                                    0.33273687548277814,
                                    0.33273687548277814,
                                    0.16726312451722186,
                                    0.16726312451722186,
                                ],
                                [
                                    0.6279737509655563,
                                    0.0375,
                                    0.31567541634481455,
                                    0.018850832689629154,
                                ],
                                [
                                    0.5492842505793337,
                                    0.43801408404140796,
                                    0.0070665821102953935,
                                    0.005635083268962914,
                                ],
                                [
                                    0.0556350832689629,
                                    0.044364916731037075,
                                    0.5007157494206662,
                                    0.39928425057933375,
                                ],
                                [
                                    0.10563508326896291,
                                    0.8316632513517789,
                                    0.007066582110295394,
                                    0.055635083268962916,
                                ],
                                [
                                    0.8435685011586675,
                                    0.09372983346207417,
                                    0.05643149884133248,
                                    0.00627016653792583,
                                ],
                                [
                                    0.055635083268962916,
                                    0.43801408404140796,
                                    0.05706658211029538,
                                    0.44928425057933374,
                                ],
                                [
                                    0.4442842505793338,
                                    0.04936491673103709,
                                    0.4557157494206662,
                                    0.050635083268962905,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.4686491673103709,
                                    0.05952624903444373,
                                    0.41864916731037083,
                                    0.05317541634481457,
                                ],
                                [
                                    0.5214667089448523,
                                    0.006708707399962274,
                                    0.46583162567588937,
                                    0.005992957979296034,
                                ],
                                [
                                    0.41864916731037083,
                                    0.05317541634481457,
                                    0.4686491673103709,
                                    0.05952624903444373,
                                ],
                                [
                                    0.46583162567588937,
                                    0.005992957979296034,
                                    0.5214667089448523,
                                    0.006708707399962274,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.5897807295689818,
                                    0.03521927043101822,
                                    0.3538684377413891,
                                    0.02113156225861093,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.3538684377413891,
                                    0.02113156225861093,
                                    0.5897807295689818,
                                    0.03521927043101822,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.08135083268962914,
                                    0.6404737509655563,
                                    0.031350832689629154,
                                    0.24682458365518542,
                                ],
                                [
                                    0.6496421252896669,
                                    0.07218245836551854,
                                    0.2503578747103331,
                                    0.027817541634481455,
                                ],
                                [
                                    0.031350832689629154,
                                    0.24682458365518542,
                                    0.08135083268962914,
                                    0.6404737509655563,
                                ],
                                [
                                    0.2503578747103331,
                                    0.027817541634481455,
                                    0.6496421252896669,
                                    0.07218245836551854,
                                ],
                                [
                                    0.2007157494206662,
                                    0.011985915958592068,
                                    0.7429334178897047,
                                    0.04436491673103708,
                                ],
                                [
                                    0.09436491673103706,
                                    0.0056350832689629135,
                                    0.8492842505793338,
                                    0.050715749420666235,
                                ],
                                [
                                    0.1443649167310371,
                                    0.018336748648221227,
                                    0.7429334178897046,
                                    0.09436491673103707,
                                ],
                                [
                                    0.16063508326896295,
                                    0.0020665821102953956,
                                    0.8266632513517788,
                                    0.010635083268962913,
                                ],
                                [
                                    0.09436491673103711,
                                    0.011985915958592074,
                                    0.7929334178897046,
                                    0.10071574942066622,
                                ],
                                [
                                    0.10500000000000004,
                                    0.0013508326896291558,
                                    0.8822983346207417,
                                    0.011350832689629152,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.04226312451722186,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.2359122918275927,
                                ],
                                [
                                    0.16726312451722186,
                                    0.16726312451722186,
                                    0.33273687548277814,
                                    0.33273687548277814,
                                ],
                                [
                                    0.31567541634481455,
                                    0.018850832689629154,
                                    0.6279737509655563,
                                    0.0375,
                                ],
                                [
                                    0.04226312451722186,
                                    0.04226312451722186,
                                    0.45773687548277814,
                                    0.45773687548277814,
                                ],
                                [
                                    0.07976312451722185,
                                    0.004763124517221866,
                                    0.863886042793149,
                                    0.051587708172407286,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.0070665821102954005,
                                    0.00563508326896292,
                                    0.5492842505793337,
                                    0.43801408404140796,
                                ],
                                [
                                    0.05706658211029538,
                                    0.44928425057933374,
                                    0.05563508326896291,
                                    0.43801408404140796,
                                ],
                                [
                                    0.4557157494206662,
                                    0.050635083268962905,
                                    0.44428425057933374,
                                    0.04936491673103708,
                                ],
                                [
                                    0.007066582110295388,
                                    0.05563508326896287,
                                    0.10563508326896291,
                                    0.8316632513517789,
                                ],
                                [
                                    0.05643149884133243,
                                    0.006270166537925825,
                                    0.8435685011586675,
                                    0.09372983346207417,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.7429334178897047,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.011985915958592068,
                                ],
                                [
                                    0.7929334178897046,
                                    0.10071574942066622,
                                    0.09436491673103707,
                                    0.011985915958592068,
                                ],
                                [
                                    0.8432912926000377,
                                    0.05035787471033311,
                                    0.1003578747103331,
                                    0.005992957979296034,
                                ],
                                [
                                    0.7429334178897046,
                                    0.09436491673103707,
                                    0.14436491673103707,
                                    0.018336748648221223,
                                ],
                                [
                                    0.7901158762552232,
                                    0.047182458365518536,
                                    0.15353329105514768,
                                    0.009168374324110612,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.33273687548277814,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.1390877081724073,
                                ],
                                [
                                    0.45773687548277814,
                                    0.45773687548277814,
                                    0.04226312451722186,
                                    0.04226312451722186,
                                ],
                                [
                                    0.6866053132241672,
                                    0.22886843774138907,
                                    0.06339468677583279,
                                    0.02113156225861093,
                                ],
                                [
                                    0.33273687548277814,
                                    0.33273687548277814,
                                    0.16726312451722186,
                                    0.16726312451722186,
                                ],
                                [
                                    0.4991053132241672,
                                    0.16636843774138907,
                                    0.2508946867758328,
                                    0.08363156225861093,
                                ],
                                [
                                    0.5492842505793337,
                                    0.43801408404140796,
                                    0.0070665821102953935,
                                    0.005635083268962914,
                                ],
                                [
                                    0.0556350832689629,
                                    0.044364916731037075,
                                    0.5007157494206662,
                                    0.39928425057933375,
                                ],
                                [
                                    0.10563508326896291,
                                    0.8316632513517789,
                                    0.007066582110295394,
                                    0.055635083268962916,
                                ],
                                [
                                    0.5214667089448524,
                                    0.41583162567588944,
                                    0.034884123744776854,
                                    0.027817541634481458,
                                ],
                                [
                                    0.055635083268962916,
                                    0.43801408404140796,
                                    0.05706658211029538,
                                    0.44928425057933374,
                                ],
                                [
                                    0.2746421252896669,
                                    0.21900704202070398,
                                    0.28170870739996223,
                                    0.22464212528966687,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.4686491673103709,
                                    0.05952624903444373,
                                    0.41864916731037083,
                                    0.05317541634481457,
                                ],
                                [
                                    0.4984122918275927,
                                    0.029763124517221864,
                                    0.4452368754827781,
                                    0.026587708172407284,
                                ],
                                [
                                    0.41864916731037083,
                                    0.05317541634481457,
                                    0.4686491673103709,
                                    0.05952624903444373,
                                ],
                                [
                                    0.4452368754827781,
                                    0.026587708172407284,
                                    0.4984122918275927,
                                    0.029763124517221864,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [0.46875, 0.15625, 0.28125, 0.09375],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.28125, 0.09375, 0.46875, 0.15625],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.08135083268962914,
                                    0.6404737509655563,
                                    0.031350832689629154,
                                    0.24682458365518542,
                                ],
                                [
                                    0.4015877081724073,
                                    0.3202368754827781,
                                    0.15476312451722185,
                                    0.12341229182759271,
                                ],
                                [
                                    0.031350832689629154,
                                    0.24682458365518542,
                                    0.08135083268962914,
                                    0.6404737509655563,
                                ],
                                [
                                    0.15476312451722185,
                                    0.12341229182759271,
                                    0.4015877081724073,
                                    0.3202368754827781,
                                ],
                                [
                                    0.2007157494206662,
                                    0.011985915958592068,
                                    0.7429334178897047,
                                    0.04436491673103708,
                                ],
                                [
                                    0.09436491673103706,
                                    0.0056350832689629135,
                                    0.8492842505793338,
                                    0.050715749420666235,
                                ],
                                [
                                    0.1443649167310371,
                                    0.018336748648221227,
                                    0.7429334178897046,
                                    0.09436491673103707,
                                ],
                                [
                                    0.15353329105514774,
                                    0.009168374324110613,
                                    0.7901158762552232,
                                    0.047182458365518536,
                                ],
                                [
                                    0.09436491673103711,
                                    0.011985915958592074,
                                    0.7929334178897046,
                                    0.10071574942066622,
                                ],
                                [
                                    0.10035787471033315,
                                    0.005992957979296037,
                                    0.8432912926000377,
                                    0.05035787471033311,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.04226312451722186,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.2359122918275927,
                                ],
                                [
                                    0.16726312451722186,
                                    0.16726312451722186,
                                    0.33273687548277814,
                                    0.33273687548277814,
                                ],
                                [
                                    0.2508946867758328,
                                    0.08363156225861093,
                                    0.4991053132241672,
                                    0.16636843774138907,
                                ],
                                [
                                    0.04226312451722186,
                                    0.04226312451722186,
                                    0.45773687548277814,
                                    0.45773687548277814,
                                ],
                                [
                                    0.06339468677583279,
                                    0.02113156225861093,
                                    0.6866053132241672,
                                    0.22886843774138907,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.0070665821102954005,
                                    0.00563508326896292,
                                    0.5492842505793337,
                                    0.43801408404140796,
                                ],
                                [
                                    0.05706658211029538,
                                    0.44928425057933374,
                                    0.05563508326896291,
                                    0.43801408404140796,
                                ],
                                [
                                    0.28170870739996223,
                                    0.22464212528966687,
                                    0.27464212528966686,
                                    0.21900704202070398,
                                ],
                                [
                                    0.007066582110295388,
                                    0.05563508326896287,
                                    0.10563508326896291,
                                    0.8316632513517789,
                                ],
                                [
                                    0.03488412374477682,
                                    0.027817541634481434,
                                    0.5214667089448524,
                                    0.41583162567588944,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.7429334178897047,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.011985915958592068,
                                ],
                                [
                                    0.7929334178897046,
                                    0.10071574942066622,
                                    0.09436491673103707,
                                    0.011985915958592068,
                                ],
                                [
                                    0.8042842505793337,
                                    0.08936491673103707,
                                    0.09571574942066623,
                                    0.010635083268962913,
                                ],
                                [
                                    0.7429334178897046,
                                    0.09436491673103707,
                                    0.14436491673103707,
                                    0.018336748648221223,
                                ],
                                [
                                    0.7535685011586675,
                                    0.08372983346207416,
                                    0.14643149884133247,
                                    0.016270166537925828,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.33273687548277814,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.1390877081724073,
                                ],
                                [
                                    0.45773687548277814,
                                    0.45773687548277814,
                                    0.04226312451722186,
                                    0.04226312451722186,
                                ],
                                [
                                    0.5093245836551854,
                                    0.4061491673103709,
                                    0.047026249034443725,
                                    0.0375,
                                ],
                                [
                                    0.33273687548277814,
                                    0.33273687548277814,
                                    0.16726312451722186,
                                    0.16726312451722186,
                                ],
                                [
                                    0.3702368754827781,
                                    0.29523687548277816,
                                    0.186113957206851,
                                    0.14841229182759272,
                                ],
                                [
                                    0.5492842505793337,
                                    0.43801408404140796,
                                    0.0070665821102953935,
                                    0.005635083268962914,
                                ],
                                [
                                    0.0556350832689629,
                                    0.044364916731037075,
                                    0.5007157494206662,
                                    0.39928425057933375,
                                ],
                                [
                                    0.10563508326896291,
                                    0.8316632513517789,
                                    0.007066582110295394,
                                    0.055635083268962916,
                                ],
                                [
                                    0.19936491673103707,
                                    0.7379334178897047,
                                    0.013336748648221224,
                                    0.04936491673103709,
                                ],
                                [
                                    0.055635083268962916,
                                    0.43801408404140796,
                                    0.05706658211029538,
                                    0.44928425057933374,
                                ],
                                [
                                    0.105,
                                    0.3886491673103709,
                                    0.10770166537925828,
                                    0.3986491673103708,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.4686491673103709,
                                    0.05952624903444373,
                                    0.41864916731037083,
                                    0.05317541634481457,
                                ],
                                [
                                    0.47535787471033314,
                                    0.052817541634481456,
                                    0.4246421252896669,
                                    0.047182458365518536,
                                ],
                                [
                                    0.41864916731037083,
                                    0.05317541634481457,
                                    0.4686491673103709,
                                    0.05952624903444373,
                                ],
                                [
                                    0.4246421252896669,
                                    0.047182458365518536,
                                    0.47535787471033314,
                                    0.052817541634481456,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.34771927043101825,
                                    0.27728072956898175,
                                    0.20863156225861093,
                                    0.16636843774138907,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.20863156225861093,
                                    0.16636843774138907,
                                    0.34771927043101825,
                                    0.27728072956898175,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.08135083268962914,
                                    0.6404737509655563,
                                    0.031350832689629154,
                                    0.24682458365518542,
                                ],
                                [
                                    0.15353329105514768,
                                    0.5682912926000377,
                                    0.0591683743241106,
                                    0.21900704202070398,
                                ],
                                [
                                    0.031350832689629154,
                                    0.24682458365518542,
                                    0.08135083268962914,
                                    0.6404737509655563,
                                ],
                                [
                                    0.0591683743241106,
                                    0.21900704202070398,
                                    0.15353329105514768,
                                    0.5682912926000377,
                                ],
                                [
                                    0.2007157494206662,
                                    0.011985915958592068,
                                    0.7429334178897047,
                                    0.04436491673103708,
                                ],
                                [
                                    0.09436491673103706,
                                    0.0056350832689629135,
                                    0.8492842505793338,
                                    0.050715749420666235,
                                ],
                                [
                                    0.1443649167310371,
                                    0.018336748648221227,
                                    0.7429334178897046,
                                    0.09436491673103707,
                                ],
                                [
                                    0.14643149884133252,
                                    0.01627016653792583,
                                    0.7535685011586675,
                                    0.08372983346207416,
                                ],
                                [
                                    0.09436491673103711,
                                    0.011985915958592074,
                                    0.7929334178897046,
                                    0.10071574942066622,
                                ],
                                [
                                    0.09571574942066628,
                                    0.010635083268962918,
                                    0.8042842505793337,
                                    0.08936491673103707,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.04226312451722186,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.2359122918275927,
                                ],
                                [
                                    0.16726312451722186,
                                    0.16726312451722186,
                                    0.33273687548277814,
                                    0.33273687548277814,
                                ],
                                [
                                    0.186113957206851,
                                    0.14841229182759272,
                                    0.3702368754827781,
                                    0.29523687548277816,
                                ],
                                [
                                    0.04226312451722186,
                                    0.04226312451722186,
                                    0.45773687548277814,
                                    0.45773687548277814,
                                ],
                                [
                                    0.047026249034443725,
                                    0.0375,
                                    0.5093245836551854,
                                    0.4061491673103709,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.0070665821102954005,
                                    0.00563508326896292,
                                    0.5492842505793337,
                                    0.43801408404140796,
                                ],
                                [
                                    0.05706658211029538,
                                    0.44928425057933374,
                                    0.05563508326896291,
                                    0.43801408404140796,
                                ],
                                [
                                    0.10770166537925828,
                                    0.3986491673103708,
                                    0.10499999999999998,
                                    0.38864916731037086,
                                ],
                                [
                                    0.007066582110295388,
                                    0.05563508326896287,
                                    0.10563508326896291,
                                    0.8316632513517789,
                                ],
                                [
                                    0.013336748648221212,
                                    0.04936491673103704,
                                    0.19936491673103707,
                                    0.7379334178897047,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.7085685011586675,
                                    0.07872983346207417,
                                    0.19143149884133245,
                                    0.021270166537925825,
                                ],
                                [
                                    0.7972983346207416,
                                    0.10127016653792581,
                                    0.09,
                                    0.011431498841332478,
                                ],
                                [
                                    0.8871551847366084,
                                    0.011413316422059075,
                                    0.10014314988413324,
                                    0.001288348957199232,
                                ],
                                [
                                    0.7085685011586675,
                                    0.08999999999999998,
                                    0.17872983346207416,
                                    0.022701665379258308,
                                ],
                                [
                                    0.7884253512745343,
                                    0.010143149884133245,
                                    0.1988729833462074,
                                    0.0025585154951250624,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.24682458365518542,
                                    0.19682458365518543,
                                    0.3095262490344437,
                                    0.24682458365518542,
                                ],
                                [
                                    0.4686491673103709,
                                    0.4686491673103709,
                                    0.031350832689629154,
                                    0.031350832689629154,
                                ],
                                [
                                    0.8844807929862603,
                                    0.052817541634481456,
                                    0.05916837432411061,
                                    0.003533291055147697,
                                ],
                                [
                                    0.24682458365518545,
                                    0.24682458365518545,
                                    0.25317541634481455,
                                    0.25317541634481455,
                                ],
                                [
                                    0.4658316256758894,
                                    0.027817541634481458,
                                    0.4778175416344814,
                                    0.02853329105514769,
                                ],
                                [
                                    0.20999999999999996,
                                    0.7772983346207417,
                                    0.0027016653792583103,
                                    0.009999999999999998,
                                ],
                                [
                                    0.021270166537925822,
                                    0.07872983346207416,
                                    0.19143149884133245,
                                    0.7085685011586675,
                                ],
                                [
                                    0.10999999999999999,
                                    0.8660281680828159,
                                    0.0027016653792583103,
                                    0.021270166537925825,
                                ],
                                [
                                    0.8784253512745344,
                                    0.09760281680828158,
                                    0.021574648725465724,
                                    0.0023971831917184135,
                                ],
                                [
                                    0.02127016653792583,
                                    0.16745966692414835,
                                    0.09143149884133248,
                                    0.7198386676965933,
                                ],
                                [
                                    0.16985685011586676,
                                    0.018872983346207416,
                                    0.7301431498841333,
                                    0.08112701665379257,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.39928425057933375,
                                    0.04436491673103708,
                                    0.5007157494206662,
                                    0.05563508326896291,
                                ],
                                [
                                    0.488014084041408,
                                    0.06198591595859207,
                                    0.39928425057933375,
                                    0.050715749420666235,
                                ],
                                [
                                    0.5430140840414079,
                                    0.00698591595859207,
                                    0.44428425057933374,
                                    0.005715749420666239,
                                ],
                                [
                                    0.3992842505793337,
                                    0.05071574942066623,
                                    0.488014084041408,
                                    0.06198591595859207,
                                ],
                                [
                                    0.44428425057933374,
                                    0.005715749420666238,
                                    0.5430140840414079,
                                    0.00698591595859207,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.1390877081724073,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.33273687548277814,
                                ],
                                [
                                    0.3609122918275927,
                                    0.3609122918275927,
                                    0.1390877081724073,
                                    0.1390877081724073,
                                ],
                                [
                                    0.6811491673103709,
                                    0.04067541634481457,
                                    0.2625,
                                    0.015675416344814577,
                                ],
                                [
                                    0.1390877081724073,
                                    0.1390877081724073,
                                    0.3609122918275927,
                                    0.3609122918275927,
                                ],
                                [
                                    0.2625,
                                    0.015675416344814577,
                                    0.6811491673103709,
                                    0.04067541634481457,
                                ],
                                [
                                    0.2007157494206662,
                                    0.7429334178897047,
                                    0.011985915958592068,
                                    0.04436491673103708,
                                ],
                                [
                                    0.011985915958592068,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.7429334178897047,
                                ],
                                [
                                    0.10071574942066622,
                                    0.7929334178897046,
                                    0.011985915958592068,
                                    0.09436491673103707,
                                ],
                                [
                                    0.8042842505793337,
                                    0.08936491673103707,
                                    0.09571574942066623,
                                    0.010635083268962913,
                                ],
                                [
                                    0.011985915958592074,
                                    0.09436491673103711,
                                    0.10071574942066622,
                                    0.7929334178897046,
                                ],
                                [
                                    0.09571574942066628,
                                    0.010635083268962918,
                                    0.8042842505793337,
                                    0.08936491673103707,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.1787298334620742,
                                    0.022701665379258308,
                                    0.7085685011586675,
                                    0.08999999999999998,
                                ],
                                [
                                    0.19887298334620743,
                                    0.002558515495125063,
                                    0.7884253512745343,
                                    0.010143149884133245,
                                ],
                                [
                                    0.09000000000000002,
                                    0.011431498841332483,
                                    0.7972983346207416,
                                    0.10127016653792581,
                                ],
                                [
                                    0.10014314988413328,
                                    0.0012883489571992323,
                                    0.8871551847366084,
                                    0.011413316422059075,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.25317541634481455,
                                    0.25317541634481455,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                ],
                                [
                                    0.4778175416344814,
                                    0.02853329105514769,
                                    0.46583162567588937,
                                    0.027817541634481455,
                                ],
                                [
                                    0.03135083268962913,
                                    0.03135083268962913,
                                    0.4686491673103709,
                                    0.4686491673103709,
                                ],
                                [
                                    0.05916837432411056,
                                    0.003533291055147694,
                                    0.8844807929862603,
                                    0.052817541634481456,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.002701665379258313,
                                    0.010000000000000007,
                                    0.20999999999999996,
                                    0.7772983346207417,
                                ],
                                [
                                    0.09143149884133248,
                                    0.7198386676965933,
                                    0.021270166537925825,
                                    0.16745966692414832,
                                ],
                                [
                                    0.7301431498841333,
                                    0.08112701665379257,
                                    0.16985685011586674,
                                    0.018872983346207413,
                                ],
                                [
                                    0.002701665379258307,
                                    0.021270166537925798,
                                    0.10999999999999999,
                                    0.8660281680828159,
                                ],
                                [
                                    0.021574648725465696,
                                    0.0023971831917184105,
                                    0.8784253512745344,
                                    0.09760281680828158,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.7085685011586675,
                                    0.07872983346207417,
                                    0.19143149884133245,
                                    0.021270166537925825,
                                ],
                                [
                                    0.7972983346207416,
                                    0.10127016653792581,
                                    0.09,
                                    0.011431498841332478,
                                ],
                                [
                                    0.8479334178897046,
                                    0.050635083268962905,
                                    0.09571574942066623,
                                    0.005715749420666239,
                                ],
                                [
                                    0.7085685011586675,
                                    0.08999999999999998,
                                    0.17872983346207416,
                                    0.022701665379258308,
                                ],
                                [
                                    0.7535685011586675,
                                    0.04499999999999999,
                                    0.1900806661517033,
                                    0.011350832689629154,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.24682458365518542,
                                    0.19682458365518543,
                                    0.3095262490344437,
                                    0.24682458365518542,
                                ],
                                [
                                    0.4686491673103709,
                                    0.4686491673103709,
                                    0.031350832689629154,
                                    0.031350832689629154,
                                ],
                                [
                                    0.7029737509655563,
                                    0.23432458365518544,
                                    0.04702624903444373,
                                    0.015675416344814577,
                                ],
                                [
                                    0.24682458365518545,
                                    0.24682458365518545,
                                    0.25317541634481455,
                                    0.25317541634481455,
                                ],
                                [
                                    0.37023687548277817,
                                    0.12341229182759272,
                                    0.37976312451722183,
                                    0.12658770817240728,
                                ],
                                [
                                    0.20999999999999996,
                                    0.7772983346207417,
                                    0.0027016653792583103,
                                    0.009999999999999998,
                                ],
                                [
                                    0.021270166537925822,
                                    0.07872983346207416,
                                    0.19143149884133245,
                                    0.7085685011586675,
                                ],
                                [
                                    0.10999999999999999,
                                    0.8660281680828159,
                                    0.0027016653792583103,
                                    0.021270166537925825,
                                ],
                                [
                                    0.5430140840414079,
                                    0.43301408404140795,
                                    0.013336748648221224,
                                    0.010635083268962913,
                                ],
                                [
                                    0.02127016653792583,
                                    0.16745966692414835,
                                    0.09143149884133248,
                                    0.7198386676965933,
                                ],
                                [
                                    0.105,
                                    0.08372983346207417,
                                    0.45135083268962917,
                                    0.35991933384829666,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.39928425057933375,
                                    0.04436491673103708,
                                    0.5007157494206662,
                                    0.05563508326896291,
                                ],
                                [
                                    0.488014084041408,
                                    0.06198591595859207,
                                    0.39928425057933375,
                                    0.050715749420666235,
                                ],
                                [
                                    0.519007042020704,
                                    0.030992957979296035,
                                    0.4246421252896669,
                                    0.025357874710333118,
                                ],
                                [
                                    0.3992842505793337,
                                    0.05071574942066623,
                                    0.488014084041408,
                                    0.06198591595859207,
                                ],
                                [
                                    0.4246421252896668,
                                    0.025357874710333114,
                                    0.519007042020704,
                                    0.030992957979296035,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.1390877081724073,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.33273687548277814,
                                ],
                                [
                                    0.3609122918275927,
                                    0.3609122918275927,
                                    0.1390877081724073,
                                    0.1390877081724073,
                                ],
                                [
                                    0.5413684377413891,
                                    0.18045614591379636,
                                    0.20863156225861093,
                                    0.06954385408620364,
                                ],
                                [
                                    0.1390877081724073,
                                    0.1390877081724073,
                                    0.3609122918275927,
                                    0.3609122918275927,
                                ],
                                [
                                    0.20863156225861093,
                                    0.06954385408620364,
                                    0.5413684377413891,
                                    0.18045614591379636,
                                ],
                                [
                                    0.2007157494206662,
                                    0.7429334178897047,
                                    0.011985915958592068,
                                    0.04436491673103708,
                                ],
                                [
                                    0.011985915958592068,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.7429334178897047,
                                ],
                                [
                                    0.10071574942066622,
                                    0.7929334178897046,
                                    0.011985915958592068,
                                    0.09436491673103707,
                                ],
                                [
                                    0.4971824583655185,
                                    0.3964667089448523,
                                    0.0591683743241106,
                                    0.047182458365518536,
                                ],
                                [
                                    0.011985915958592074,
                                    0.09436491673103711,
                                    0.10071574942066622,
                                    0.7929334178897046,
                                ],
                                [
                                    0.05916837432411064,
                                    0.047182458365518556,
                                    0.4971824583655185,
                                    0.3964667089448523,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.1787298334620742,
                                    0.022701665379258308,
                                    0.7085685011586675,
                                    0.08999999999999998,
                                ],
                                [
                                    0.19008066615170333,
                                    0.011350832689629154,
                                    0.7535685011586675,
                                    0.04499999999999999,
                                ],
                                [
                                    0.09000000000000002,
                                    0.011431498841332483,
                                    0.7972983346207416,
                                    0.10127016653792581,
                                ],
                                [
                                    0.09571574942066627,
                                    0.005715749420666241,
                                    0.8479334178897046,
                                    0.050635083268962905,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.25317541634481455,
                                    0.25317541634481455,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                ],
                                [
                                    0.37976312451722183,
                                    0.12658770817240728,
                                    0.3702368754827781,
                                    0.12341229182759271,
                                ],
                                [
                                    0.03135083268962913,
                                    0.03135083268962913,
                                    0.4686491673103709,
                                    0.4686491673103709,
                                ],
                                [
                                    0.04702624903444369,
                                    0.015675416344814563,
                                    0.7029737509655563,
                                    0.23432458365518544,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.002701665379258313,
                                    0.010000000000000007,
                                    0.20999999999999996,
                                    0.7772983346207417,
                                ],
                                [
                                    0.09143149884133248,
                                    0.7198386676965933,
                                    0.021270166537925825,
                                    0.16745966692414832,
                                ],
                                [
                                    0.45135083268962917,
                                    0.35991933384829666,
                                    0.10499999999999998,
                                    0.08372983346207416,
                                ],
                                [
                                    0.002701665379258307,
                                    0.021270166537925798,
                                    0.10999999999999999,
                                    0.8660281680828159,
                                ],
                                [
                                    0.013336748648221207,
                                    0.010635083268962899,
                                    0.5430140840414079,
                                    0.43301408404140795,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.7085685011586675,
                                    0.07872983346207417,
                                    0.19143149884133245,
                                    0.021270166537925825,
                                ],
                                [
                                    0.7972983346207416,
                                    0.10127016653792581,
                                    0.09,
                                    0.011431498841332478,
                                ],
                                [
                                    0.8087116510428007,
                                    0.08985685011586673,
                                    0.09128834895719923,
                                    0.010143149884133246,
                                ],
                                [
                                    0.7085685011586675,
                                    0.08999999999999998,
                                    0.17872983346207416,
                                    0.022701665379258308,
                                ],
                                [
                                    0.7187116510428008,
                                    0.07985685011586674,
                                    0.18128834895719922,
                                    0.020143149884133245,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.24682458365518542,
                                    0.19682458365518543,
                                    0.3095262490344437,
                                    0.24682458365518542,
                                ],
                                [
                                    0.4686491673103709,
                                    0.4686491673103709,
                                    0.031350832689629154,
                                    0.031350832689629154,
                                ],
                                [
                                    0.5214667089448524,
                                    0.41583162567588944,
                                    0.034884123744776854,
                                    0.027817541634481458,
                                ],
                                [
                                    0.24682458365518545,
                                    0.24682458365518545,
                                    0.25317541634481455,
                                    0.25317541634481455,
                                ],
                                [
                                    0.2746421252896669,
                                    0.21900704202070398,
                                    0.28170870739996223,
                                    0.22464212528966687,
                                ],
                                [
                                    0.20999999999999996,
                                    0.7772983346207417,
                                    0.0027016653792583103,
                                    0.009999999999999998,
                                ],
                                [
                                    0.021270166537925822,
                                    0.07872983346207416,
                                    0.19143149884133245,
                                    0.7085685011586675,
                                ],
                                [
                                    0.10999999999999999,
                                    0.8660281680828159,
                                    0.0027016653792583103,
                                    0.021270166537925825,
                                ],
                                [
                                    0.20760281680828155,
                                    0.7684253512745344,
                                    0.005098848570976724,
                                    0.018872983346207413,
                                ],
                                [
                                    0.02127016653792583,
                                    0.16745966692414835,
                                    0.09143149884133248,
                                    0.7198386676965933,
                                ],
                                [
                                    0.04014314988413324,
                                    0.14858668357794094,
                                    0.17255851549512505,
                                    0.6387116510428008,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.39928425057933375,
                                    0.04436491673103708,
                                    0.5007157494206662,
                                    0.05563508326896291,
                                ],
                                [
                                    0.488014084041408,
                                    0.06198591595859207,
                                    0.39928425057933375,
                                    0.050715749420666235,
                                ],
                                [0.49500000000000005, 0.055, 0.405, 0.045],
                                [
                                    0.3992842505793337,
                                    0.05071574942066623,
                                    0.488014084041408,
                                    0.06198591595859207,
                                ],
                                [
                                    0.40499999999999997,
                                    0.04499999999999999,
                                    0.49500000000000005,
                                    0.055,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.1390877081724073,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.33273687548277814,
                                ],
                                [
                                    0.3609122918275927,
                                    0.3609122918275927,
                                    0.1390877081724073,
                                    0.1390877081724073,
                                ],
                                [
                                    0.4015877081724073,
                                    0.3202368754827781,
                                    0.15476312451722185,
                                    0.12341229182759271,
                                ],
                                [
                                    0.1390877081724073,
                                    0.1390877081724073,
                                    0.3609122918275927,
                                    0.3609122918275927,
                                ],
                                [
                                    0.15476312451722185,
                                    0.12341229182759271,
                                    0.4015877081724073,
                                    0.3202368754827781,
                                ],
                                [
                                    0.2007157494206662,
                                    0.7429334178897047,
                                    0.011985915958592068,
                                    0.04436491673103708,
                                ],
                                [
                                    0.011985915958592068,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.7429334178897047,
                                ],
                                [
                                    0.10071574942066622,
                                    0.7929334178897046,
                                    0.011985915958592068,
                                    0.09436491673103707,
                                ],
                                [
                                    0.1900806661517033,
                                    0.7035685011586675,
                                    0.022620999227554978,
                                    0.08372983346207416,
                                ],
                                [
                                    0.011985915958592074,
                                    0.09436491673103711,
                                    0.10071574942066622,
                                    0.7929334178897046,
                                ],
                                [
                                    0.02262099922755499,
                                    0.0837298334620742,
                                    0.1900806661517033,
                                    0.7035685011586675,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.1787298334620742,
                                    0.022701665379258308,
                                    0.7085685011586675,
                                    0.08999999999999998,
                                ],
                                [
                                    0.18128834895719925,
                                    0.02014314988413325,
                                    0.7187116510428008,
                                    0.07985685011586674,
                                ],
                                [
                                    0.09000000000000002,
                                    0.011431498841332483,
                                    0.7972983346207416,
                                    0.10127016653792581,
                                ],
                                [
                                    0.09128834895719927,
                                    0.01014314988413325,
                                    0.8087116510428007,
                                    0.08985685011586673,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.25317541634481455,
                                    0.25317541634481455,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                ],
                                [
                                    0.28170870739996223,
                                    0.22464212528966687,
                                    0.27464212528966686,
                                    0.21900704202070398,
                                ],
                                [
                                    0.03135083268962913,
                                    0.03135083268962913,
                                    0.4686491673103709,
                                    0.4686491673103709,
                                ],
                                [
                                    0.03488412374477682,
                                    0.027817541634481434,
                                    0.5214667089448524,
                                    0.41583162567588944,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.002701665379258313,
                                    0.010000000000000007,
                                    0.20999999999999996,
                                    0.7772983346207417,
                                ],
                                [
                                    0.09143149884133248,
                                    0.7198386676965933,
                                    0.021270166537925825,
                                    0.16745966692414832,
                                ],
                                [
                                    0.17255851549512505,
                                    0.6387116510428008,
                                    0.040143149884133235,
                                    0.14858668357794091,
                                ],
                                [
                                    0.002701665379258307,
                                    0.021270166537925798,
                                    0.10999999999999999,
                                    0.8660281680828159,
                                ],
                                [
                                    0.005098848570976717,
                                    0.01887298334620739,
                                    0.20760281680828155,
                                    0.7684253512745344,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.006749814254293058,
                                0.006749814254293058,
                                0.006749814254293058,
                                0.006749814254293058,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.006749814254293058,
                                0.006749814254293058,
                                0.006749814254293058,
                                0.006749814254293058,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                0.00019113447760785951,
                                0.00019113447760785951,
                                0.00019113447760785951,
                                0.00019113447760785951,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.005753081343151171,
                                0.005753081343151171,
                                0.005753081343151171,
                                0.005753081343151171,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.010799702806868889,
                                0.010799702806868889,
                                0.010799702806868889,
                                0.010799702806868889,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.006749814254293058,
                                0.006749814254293058,
                                0.006749814254293058,
                                0.006749814254293058,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.00011945904850491224,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0035956758394694835,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.006749814254293058,
                                0.006749814254293058,
                                0.006749814254293058,
                                0.006749814254293058,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                7.466190531557017e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.002247297399668428,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.0042186339089331625,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.004172516423195856,
                                0.004172516423195856,
                                0.004172516423195856,
                                0.004172516423195856,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                0.00018268428530090035,
                                0.00018268428530090035,
                                0.00018268428530090035,
                                0.00018268428530090035,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.004172516423195856,
                                0.004172516423195856,
                                0.004172516423195856,
                                0.004172516423195856,
                                0.00017177513394186608,
                                0.00017177513394186608,
                                0.00018268428530090038,
                                0.00018268428530090038,
                                0.00018268428530090038,
                                0.00018268428530090038,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.00027484021430698567,
                                0.00027484021430698567,
                                0.00029229485648144053,
                                0.00029229485648144053,
                                0.00029229485648144053,
                                0.00029229485648144053,
                                0.004877305288827922,
                                0.004877305288827922,
                                0.007315957933241883,
                                0.007315957933241883,
                                0.007315957933241883,
                                0.007315957933241883,
                                0.002163812430106976,
                                0.002163812430106976,
                                0.010681642043381387,
                                0.010681642043381387,
                                0.010681642043381387,
                                0.010681642043381387,
                                0.00017177513394186608,
                                0.00017177513394186608,
                                0.00018268428530090038,
                                0.00018268428530090038,
                                0.00018268428530090038,
                                0.00018268428530090038,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.004172516423195856,
                                0.004172516423195856,
                                0.004172516423195856,
                                0.004172516423195856,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                0.00018268428530090035,
                                0.00018268428530090035,
                                0.00018268428530090035,
                                0.00018268428530090035,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.004572473708276178,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.0066760262771133685,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.00011417767831306276,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.002857796067672612,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.004172516423195856,
                                0.004172516423195856,
                                0.004172516423195856,
                                0.004172516423195856,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0009970116200616597,
                                0.0009970116200616597,
                                0.0009970116200616597,
                                0.0009970116200616597,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0009970116200616597,
                                0.0009970116200616597,
                                0.0009970116200616597,
                                0.0009970116200616597,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                0.0001742340929939412,
                                0.0001742340929939412,
                                0.0001742340929939412,
                                0.0001742340929939412,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0033918660734011835,
                                0.0033918660734011835,
                                0.0033918660734011835,
                                0.0033918660734011835,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0025523497473578477,
                                0.0025523497473578477,
                                0.0025523497473578477,
                                0.0025523497473578477,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0009970116200616597,
                                0.0009970116200616597,
                                0.0009970116200616597,
                                0.0009970116200616597,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.00010889630812121327,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0021199162958757405,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                0.0015952185920986553,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                6.806019257575831e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0013249476849223382,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0009970116200616597,
                                0.0009970116200616597,
                                0.0009970116200616597,
                                0.0009970116200616597,
                            ]
                        ),
                    )
                case 4:
                    return (
                        np.array(
                            [
                                [
                                    0.004174589489585101,
                                    0.8617825030938935,
                                    0.0006461914998409646,
                                    0.13339671591668045,
                                ],
                                [
                                    0.004509305204179589,
                                    0.9308796315822727,
                                    0.0003114757852464765,
                                    0.06429958742830122,
                                ],
                                [
                                    0.004464438936637345,
                                    0.9216176515855574,
                                    0.0003563420527887202,
                                    0.07356156742501652,
                                ],
                                [
                                    0.06429958742830127,
                                    0.8617825030938935,
                                    0.005132256774672491,
                                    0.06878565270313274,
                                ],
                                [
                                    0.0044876788659853565,
                                    0.9264151926456354,
                                    0.00033310212344070877,
                                    0.06876402636493852,
                                ],
                                [
                                    0.06463430314289577,
                                    0.866268568368725,
                                    0.004797541060078007,
                                    0.06429958742830122,
                                ],
                                [
                                    0.014285714285714264,
                                    0.609186129980153,
                                    0.00862745239069848,
                                    0.36790070334343433,
                                ],
                                [
                                    0.02184727646468036,
                                    0.9316340460087588,
                                    0.0010658902117323865,
                                    0.04545278731482855,
                                ],
                                [
                                    0.020833702685600936,
                                    0.888412189853886,
                                    0.0020794639908118086,
                                    0.08867464346970123,
                                ],
                                [
                                    0.30005976255933403,
                                    0.6091861299801529,
                                    0.029949715648237816,
                                    0.06080439181227523,
                                ],
                                [
                                    0.021358715892742006,
                                    0.9108003433231577,
                                    0.0015544507836707363,
                                    0.06628649000042952,
                                ],
                                [
                                    0.3076213247383002,
                                    0.6245377344775995,
                                    0.02238815346927171,
                                    0.045452787314828554,
                                ],
                                [
                                    0.014285714285714282,
                                    0.29281059724544484,
                                    0.03223296324084663,
                                    0.6606707252279942,
                                ],
                                [
                                    0.045452787314828526,
                                    0.9316340460087588,
                                    0.0010658902117323876,
                                    0.02184727646468039,
                                ],
                                [
                                    0.041275062230343,
                                    0.8460042936106749,
                                    0.00524361529621791,
                                    0.10747702886276418,
                                ],
                                [
                                    0.5944687585955731,
                                    0.2928105972454448,
                                    0.07552176319685502,
                                    0.03719888096212706,
                                ],
                                [
                                    0.04343904958916317,
                                    0.8903589837784157,
                                    0.0030796279373977455,
                                    0.06312233869502341,
                                ],
                                [
                                    0.6256358316246874,
                                    0.3081622017428915,
                                    0.04435469016774077,
                                    0.02184727646468039,
                                ],
                                [
                                    0.004174589489585058,
                                    0.060436473723962644,
                                    0.060436473723962644,
                                    0.8749524630624896,
                                ],
                                [
                                    0.06429958742830123,
                                    0.9308796315822727,
                                    0.00031147578524647355,
                                    0.004509305204179546,
                                ],
                                [
                                    0.05624025789618335,
                                    0.8142028999621267,
                                    0.008370805317364347,
                                    0.12118603682432554,
                                ],
                                [
                                    0.8100066841343474,
                                    0.060436473723962686,
                                    0.1205614716626788,
                                    0.008995370479011078,
                                ],
                                [
                                    0.06041484738576841,
                                    0.8746393736860893,
                                    0.004196215827779289,
                                    0.0607495631003629,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879422,
                                    0.06043647372396264,
                                    0.004509305204179545,
                                ],
                                [
                                    0.0030056212142793013,
                                    0.6204662230515879,
                                    0.0018151597751467643,
                                    0.374712995958986,
                                ],
                                [
                                    0.003340336928873789,
                                    0.6895633515399671,
                                    0.0014804440605522763,
                                    0.3056158674706068,
                                ],
                                [
                                    0.0032143070381622945,
                                    0.6635463371837134,
                                    0.0016064739512637713,
                                    0.3316328818268606,
                                ],
                                [
                                    0.04629442117028769,
                                    0.6204662230515879,
                                    0.02313742303268608,
                                    0.31010193274543835,
                                ],
                                [
                                    0.003237546967510306,
                                    0.6683438782437913,
                                    0.0015832340219157598,
                                    0.32683534076678267,
                                ],
                                [
                                    0.046629136884882176,
                                    0.6249522883264195,
                                    0.022802707318091597,
                                    0.3056158674706068,
                                ],
                                [
                                    0.010285429507595268,
                                    0.4386018697840949,
                                    0.012627737168817476,
                                    0.5384849635394924,
                                ],
                                [
                                    0.017846991686561363,
                                    0.7610497858127007,
                                    0.005066174989851383,
                                    0.21603704751088665,
                                ],
                                [
                                    0.014999850624846284,
                                    0.639639066670135,
                                    0.007913316051566458,
                                    0.3374477666534521,
                                ],
                                [
                                    0.2160370475108866,
                                    0.43860186978409477,
                                    0.11397243069668525,
                                    0.23138865200833333,
                                ],
                                [
                                    0.015524863831987359,
                                    0.6620272201394068,
                                    0.007388302844425385,
                                    0.3150596131841804,
                                ],
                                [
                                    0.22359860968985273,
                                    0.4539534742815415,
                                    0.10641086851771915,
                                    0.21603704751088665,
                                ],
                                [
                                    0.010285429507595279,
                                    0.2108177929931427,
                                    0.03623324801896564,
                                    0.7426635294802963,
                                ],
                                [
                                    0.041452502536709526,
                                    0.8496412417564566,
                                    0.005066174989851388,
                                    0.10384008071698246,
                                ],
                                [
                                    0.029717222009426107,
                                    0.6091062267538878,
                                    0.016801455517134807,
                                    0.3443750957195513,
                                ],
                                [
                                    0.42800565577017113,
                                    0.21081779299314274,
                                    0.241984866022257,
                                    0.11919168521442913,
                                ],
                                [
                                    0.03188120936824627,
                                    0.6534609169216286,
                                    0.014637468158314643,
                                    0.3000204055518106,
                                ],
                                [
                                    0.4591727287992854,
                                    0.2261693974905894,
                                    0.21081779299314274,
                                    0.10384008071698247,
                                ],
                                [
                                    0.0030056212142792753,
                                    0.04351305631228175,
                                    0.06160544199926843,
                                    0.8918758804741705,
                                ],
                                [
                                    0.06313061915299545,
                                    0.9139562141705918,
                                    0.0014804440605522618,
                                    0.021432722615860534,
                                ],
                                [
                                    0.0404918645656121,
                                    0.5862098572708075,
                                    0.0241191986479356,
                                    0.34917907951564464,
                                ],
                                [
                                    0.583188665524138,
                                    0.043513056312281695,
                                    0.34737949027288817,
                                    0.025918787890692067,
                                ],
                                [
                                    0.04466645405519716,
                                    0.6466463309947702,
                                    0.01994460915835054,
                                    0.288742605791682,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711323,
                                    0.287254492334172,
                                    0.021432722615860534,
                                ],
                                [
                                    0.0014804440605522765,
                                    0.3056158674706069,
                                    0.003340336928873789,
                                    0.6895633515399671,
                                ],
                                [
                                    0.001815159775146765,
                                    0.3747129959589861,
                                    0.003005621214279301,
                                    0.6204662230515878,
                                ],
                                [
                                    0.0015832340219157598,
                                    0.32683534076678267,
                                    0.003237546967510306,
                                    0.6683438782437913,
                                ],
                                [
                                    0.022802707318091597,
                                    0.3056158674706068,
                                    0.046629136884882176,
                                    0.6249522883264195,
                                ],
                                [
                                    0.0016064739512637715,
                                    0.3316328818268607,
                                    0.003214307038162294,
                                    0.6635463371837133,
                                ],
                                [
                                    0.023137423032686084,
                                    0.3101019327454384,
                                    0.04629442117028768,
                                    0.6204662230515878,
                                ],
                                [
                                    0.005066174989851382,
                                    0.21603704751088662,
                                    0.017846991686561363,
                                    0.7610497858127007,
                                ],
                                [
                                    0.012627737168817476,
                                    0.5384849635394924,
                                    0.010285429507595268,
                                    0.4386018697840949,
                                ],
                                [
                                    0.007388302844425385,
                                    0.3150596131841804,
                                    0.015524863831987359,
                                    0.6620272201394068,
                                ],
                                [
                                    0.10641086851771915,
                                    0.21603704751088665,
                                    0.22359860968985273,
                                    0.4539534742815415,
                                ],
                                [
                                    0.007913316051566456,
                                    0.33744776665345205,
                                    0.014999850624846288,
                                    0.6396390666701351,
                                ],
                                [
                                    0.11397243069668524,
                                    0.23138865200833328,
                                    0.21603704751088662,
                                    0.4386018697840948,
                                ],
                                [
                                    0.00506617498985139,
                                    0.10384008071698249,
                                    0.041452502536709526,
                                    0.8496412417564566,
                                ],
                                [
                                    0.03623324801896564,
                                    0.7426635294802963,
                                    0.010285429507595279,
                                    0.21081779299314274,
                                ],
                                [
                                    0.014637468158314643,
                                    0.3000204055518106,
                                    0.03188120936824627,
                                    0.6534609169216286,
                                ],
                                [
                                    0.21081779299314274,
                                    0.10384008071698247,
                                    0.4591727287992854,
                                    0.2261693974905894,
                                ],
                                [
                                    0.016801455517134807,
                                    0.3443750957195513,
                                    0.029717222009426107,
                                    0.6091062267538878,
                                ],
                                [
                                    0.241984866022257,
                                    0.11919168521442913,
                                    0.42800565577017113,
                                    0.21081779299314274,
                                ],
                                [
                                    0.0014804440605522657,
                                    0.02143272261586059,
                                    0.06313061915299543,
                                    0.9139562141705917,
                                ],
                                [
                                    0.061605441999268436,
                                    0.8918758804741707,
                                    0.003005621214279272,
                                    0.043513056312281695,
                                ],
                                [
                                    0.019944609158350543,
                                    0.28874260579168204,
                                    0.04466645405519716,
                                    0.6466463309947702,
                                ],
                                [
                                    0.28725449233417205,
                                    0.021432722615860537,
                                    0.6433136634628541,
                                    0.04799912158711323,
                                ],
                                [
                                    0.024119198647935602,
                                    0.3491790795156447,
                                    0.0404918645656121,
                                    0.5862098572708075,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069207,
                                    0.583188665524138,
                                    0.043513056312281695,
                                ],
                                [
                                    0.0003114757852464766,
                                    0.06429958742830123,
                                    0.004509305204179589,
                                    0.9308796315822727,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.1333967159166805,
                                    0.004174589489585101,
                                    0.8617825030938935,
                                ],
                                [
                                    0.0003331021234407088,
                                    0.06876402636493853,
                                    0.0044876788659853565,
                                    0.9264151926456354,
                                ],
                                [
                                    0.0047975410600780075,
                                    0.06429958742830123,
                                    0.06463430314289577,
                                    0.866268568368725,
                                ],
                                [
                                    0.0003563420527887206,
                                    0.07356156742501657,
                                    0.004464438936637345,
                                    0.9216176515855573,
                                ],
                                [
                                    0.005132256774672495,
                                    0.0687856527031328,
                                    0.06429958742830127,
                                    0.8617825030938935,
                                ],
                                [
                                    0.0010658902117323885,
                                    0.04545278731482864,
                                    0.021847276464680356,
                                    0.9316340460087587,
                                ],
                                [
                                    0.008627452390698481,
                                    0.3679007033434344,
                                    0.014285714285714263,
                                    0.6091861299801529,
                                ],
                                [
                                    0.0015544507836707372,
                                    0.06628649000042956,
                                    0.021358715892742006,
                                    0.9108003433231577,
                                ],
                                [
                                    0.022388153469271723,
                                    0.04545278731482858,
                                    0.3076213247383002,
                                    0.6245377344775995,
                                ],
                                [
                                    0.0020794639908118086,
                                    0.08867464346970123,
                                    0.020833702685600936,
                                    0.888412189853886,
                                ],
                                [
                                    0.029949715648237816,
                                    0.06080439181227523,
                                    0.30005976255933403,
                                    0.6091861299801529,
                                ],
                                [
                                    0.001065890211732391,
                                    0.021847276464680463,
                                    0.045452787314828526,
                                    0.9316340460087587,
                                ],
                                [
                                    0.03223296324084663,
                                    0.6606707252279942,
                                    0.014285714285714278,
                                    0.2928105972454448,
                                ],
                                [
                                    0.0030796279373977464,
                                    0.06312233869502343,
                                    0.04343904958916317,
                                    0.8903589837784157,
                                ],
                                [
                                    0.044354690167740775,
                                    0.021847276464680394,
                                    0.6256358316246874,
                                    0.3081622017428915,
                                ],
                                [
                                    0.00524361529621791,
                                    0.10747702886276418,
                                    0.041275062230343,
                                    0.8460042936106749,
                                ],
                                [
                                    0.07552176319685502,
                                    0.03719888096212706,
                                    0.5944687585955731,
                                    0.2928105972454448,
                                ],
                                [
                                    0.0003114757852464766,
                                    0.004509305204179589,
                                    0.06429958742830123,
                                    0.9308796315822727,
                                ],
                                [
                                    0.060436473723962644,
                                    0.8749524630624896,
                                    0.00417458948958506,
                                    0.060436473723962686,
                                ],
                                [
                                    0.004196215827779293,
                                    0.06074956310036295,
                                    0.06041484738576841,
                                    0.8746393736860893,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179549,
                                    0.8701316820730636,
                                    0.06492253899879422,
                                ],
                                [
                                    0.00837080531736435,
                                    0.12118603682432559,
                                    0.05624025789618335,
                                    0.8142028999621267,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011083,
                                    0.8100066841343474,
                                    0.060436473723962686,
                                ],
                                [
                                    0.019841819196987024,
                                    0.8461152733864915,
                                    0.0030713474794257173,
                                    0.1309715599370957,
                                ],
                                [
                                    0.021432722615860485,
                                    0.9139562141705918,
                                    0.0014804440605522581,
                                    0.06313061915299543,
                                ],
                                [
                                    0.021219473296175805,
                                    0.904862617226019,
                                    0.0016936933802369405,
                                    0.0722242160975683,
                                ],
                                [
                                    0.06429958742830127,
                                    0.8617825030938935,
                                    0.005132256774672491,
                                    0.06878565270313274,
                                ],
                                [
                                    0.021329932654497005,
                                    0.9095729388571238,
                                    0.0015832340219157405,
                                    0.06751389446646348,
                                ],
                                [
                                    0.06463430314289577,
                                    0.866268568368725,
                                    0.004797541060078007,
                                    0.06429958742830122,
                                ],
                                [
                                    0.06789998409762985,
                                    0.5555718601682373,
                                    0.04100627160920403,
                                    0.3355218841249287,
                                ],
                                [
                                    0.10384008071698249,
                                    0.8496412417564566,
                                    0.0050661749898513915,
                                    0.04145250253670954,
                                ],
                                [
                                    0.09902256567329376,
                                    0.8102233268661931,
                                    0.009883690033540114,
                                    0.08087041742697293,
                                ],
                                [
                                    0.30005976255933403,
                                    0.6091861299801529,
                                    0.029949715648237816,
                                    0.06080439181227523,
                                ],
                                [
                                    0.10151795286240847,
                                    0.8306411063534912,
                                    0.007388302844425398,
                                    0.06045263793967486,
                                ],
                                [
                                    0.3076213247383002,
                                    0.6245377344775995,
                                    0.02238815346927171,
                                    0.045452787314828554,
                                ],
                                [
                                    0.06789998409762983,
                                    0.2391963274335293,
                                    0.15320323840310818,
                                    0.5397004500657328,
                                ],
                                [
                                    0.21603704751088662,
                                    0.7610497858127007,
                                    0.00506617498985139,
                                    0.017846991686561387,
                                ],
                                [
                                    0.19618032483482806,
                                    0.6910990310061899,
                                    0.024922897665909927,
                                    0.08779774649307216,
                                ],
                                [
                                    0.5944687585955731,
                                    0.2928105972454448,
                                    0.07552176319685502,
                                    0.03719888096212706,
                                ],
                                [
                                    0.20646575434242334,
                                    0.7273322790251555,
                                    0.014637468158314649,
                                    0.05156449847410651,
                                ],
                                [
                                    0.6256358316246874,
                                    0.3081622017428915,
                                    0.04435469016774077,
                                    0.02184727646468039,
                                ],
                                [
                                    0.019841819196987062,
                                    0.04476924401656064,
                                    0.28725449233417205,
                                    0.6481344444522802,
                                ],
                                [
                                    0.3056158674706069,
                                    0.6895633515399671,
                                    0.0014804440605522622,
                                    0.0033403369288737567,
                                ],
                                [
                                    0.2673098831758215,
                                    0.6031332746824886,
                                    0.039786428355337605,
                                    0.08977041378635228,
                                ],
                                [
                                    0.8100066841343474,
                                    0.060436473723962686,
                                    0.1205614716626788,
                                    0.008995370479011078,
                                ],
                                [
                                    0.28715170237280857,
                                    0.6479025186990492,
                                    0.019944609158350543,
                                    0.04500116976979164,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879422,
                                    0.06043647372396264,
                                    0.004509305204179545,
                                ],
                                [
                                    0.014285714285714264,
                                    0.609186129980153,
                                    0.00862745239069848,
                                    0.36790070334343433,
                                ],
                                [
                                    0.01587661770458772,
                                    0.6770270707642532,
                                    0.007036548971825021,
                                    0.30005976255933403,
                                ],
                                [
                                    0.015277597774328175,
                                    0.6514830464475475,
                                    0.007635568902084571,
                                    0.32560378687603986,
                                ],
                                [
                                    0.04629442117028769,
                                    0.6204662230515879,
                                    0.02313742303268608,
                                    0.31010193274543835,
                                ],
                                [
                                    0.015388057132649373,
                                    0.6561933680786523,
                                    0.007525109543763371,
                                    0.320893465244935,
                                ],
                                [
                                    0.046629136884882176,
                                    0.6249522883264195,
                                    0.022802707318091597,
                                    0.3056158674706068,
                                ],
                                [
                                    0.04888663500021088,
                                    0.40000066429147924,
                                    0.060019620706623,
                                    0.4910930800016869,
                                ],
                                [
                                    0.08482673161956351,
                                    0.6940700458796984,
                                    0.02407952408727036,
                                    0.19702369841346767,
                                ],
                                [
                                    0.07129427332257211,
                                    0.5833446439724093,
                                    0.037611982384261756,
                                    0.3077491003207568,
                                ],
                                [
                                    0.2160370475108866,
                                    0.43860186978409477,
                                    0.11397243069668525,
                                    0.23138865200833333,
                                ],
                                [
                                    0.07378966051168684,
                                    0.6037624234597074,
                                    0.03511659519514704,
                                    0.28733132083345875,
                                ],
                                [
                                    0.22359860968985273,
                                    0.4539534742815415,
                                    0.10641086851771915,
                                    0.21603704751088665,
                                ],
                                [
                                    0.04888663500021085,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.6066801899987349,
                                ],
                                [
                                    0.19702369841346765,
                                    0.6940700458796984,
                                    0.024079524087270352,
                                    0.0848267316195635,
                                ],
                                [
                                    0.14124592313060377,
                                    0.49757752563271007,
                                    0.07985729937013421,
                                    0.28131925186655193,
                                ],
                                [
                                    0.42800565577017113,
                                    0.21081779299314274,
                                    0.241984866022257,
                                    0.11919168521442913,
                                ],
                                [
                                    0.15153135263819906,
                                    0.5338107736516757,
                                    0.06957186986253894,
                                    0.24508600384758628,
                                ],
                                [
                                    0.4591727287992854,
                                    0.2261693974905894,
                                    0.21081779299314274,
                                    0.10384008071698247,
                                ],
                                [
                                    0.014285714285714315,
                                    0.03223296324084671,
                                    0.29281059724544484,
                                    0.6606707252279942,
                                ],
                                [
                                    0.3000597625593341,
                                    0.6770270707642532,
                                    0.007036548971825038,
                                    0.01587661770458776,
                                ],
                                [
                                    0.19245778720619097,
                                    0.4342439346302287,
                                    0.11463852432496814,
                                    0.2586597538386121,
                                ],
                                [
                                    0.583188665524138,
                                    0.043513056312281695,
                                    0.34737949027288817,
                                    0.025918787890692067,
                                ],
                                [
                                    0.21229960640317805,
                                    0.4790131786467894,
                                    0.09479670512798108,
                                    0.21389050982205146,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711323,
                                    0.287254492334172,
                                    0.021432722615860534,
                                ],
                                [
                                    0.007036548971825022,
                                    0.3000597625593341,
                                    0.01587661770458772,
                                    0.6770270707642532,
                                ],
                                [
                                    0.008627452390698481,
                                    0.3679007033434344,
                                    0.014285714285714263,
                                    0.6091861299801529,
                                ],
                                [
                                    0.007525109543763371,
                                    0.320893465244935,
                                    0.015388057132649373,
                                    0.6561933680786523,
                                ],
                                [
                                    0.022802707318091597,
                                    0.3056158674706068,
                                    0.046629136884882176,
                                    0.6249522883264195,
                                ],
                                [
                                    0.0076355689020845725,
                                    0.3256037868760399,
                                    0.015277597774328171,
                                    0.6514830464475474,
                                ],
                                [
                                    0.023137423032686084,
                                    0.3101019327454384,
                                    0.04629442117028768,
                                    0.6204662230515878,
                                ],
                                [
                                    0.02407952408727036,
                                    0.19702369841346765,
                                    0.08482673161956351,
                                    0.6940700458796984,
                                ],
                                [
                                    0.060019620706623,
                                    0.4910930800016869,
                                    0.04888663500021088,
                                    0.40000066429147924,
                                ],
                                [
                                    0.03511659519514704,
                                    0.28733132083345875,
                                    0.07378966051168684,
                                    0.6037624234597074,
                                ],
                                [
                                    0.10641086851771915,
                                    0.21603704751088665,
                                    0.22359860968985273,
                                    0.4539534742815415,
                                ],
                                [
                                    0.03761198238426175,
                                    0.30774910032075675,
                                    0.07129427332257213,
                                    0.5833446439724094,
                                ],
                                [
                                    0.11397243069668524,
                                    0.23138865200833328,
                                    0.21603704751088662,
                                    0.4386018697840948,
                                ],
                                [
                                    0.02407952408727036,
                                    0.08482673161956351,
                                    0.19702369841346765,
                                    0.6940700458796984,
                                ],
                                [
                                    0.17221658750052715,
                                    0.6066801899987349,
                                    0.04888663500021086,
                                    0.17221658750052715,
                                ],
                                [
                                    0.06957186986253894,
                                    0.24508600384758628,
                                    0.15153135263819906,
                                    0.5338107736516757,
                                ],
                                [
                                    0.21081779299314274,
                                    0.10384008071698247,
                                    0.4591727287992854,
                                    0.2261693974905894,
                                ],
                                [
                                    0.07985729937013421,
                                    0.28131925186655193,
                                    0.14124592313060377,
                                    0.49757752563271007,
                                ],
                                [
                                    0.241984866022257,
                                    0.11919168521442913,
                                    0.42800565577017113,
                                    0.21081779299314274,
                                ],
                                [
                                    0.007036548971825056,
                                    0.0158766177045878,
                                    0.3000597625593341,
                                    0.6770270707642531,
                                ],
                                [
                                    0.29281059724544484,
                                    0.6606707252279942,
                                    0.0142857142857143,
                                    0.03223296324084667,
                                ],
                                [
                                    0.09479670512798109,
                                    0.21389050982205152,
                                    0.21229960640317805,
                                    0.4790131786467894,
                                ],
                                [
                                    0.28725449233417205,
                                    0.021432722615860537,
                                    0.6433136634628541,
                                    0.04799912158711323,
                                ],
                                [
                                    0.11463852432496816,
                                    0.25865975383861217,
                                    0.19245778720619097,
                                    0.4342439346302287,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069207,
                                    0.583188665524138,
                                    0.043513056312281695,
                                ],
                                [
                                    0.0014804440605522586,
                                    0.06313061915299545,
                                    0.021432722615860485,
                                    0.9139562141705918,
                                ],
                                [
                                    0.0030713474794257186,
                                    0.13097155993709575,
                                    0.019841819196987024,
                                    0.8461152733864915,
                                ],
                                [
                                    0.0015832340219157407,
                                    0.0675138944664635,
                                    0.021329932654497005,
                                    0.9095729388571238,
                                ],
                                [
                                    0.0047975410600780075,
                                    0.06429958742830123,
                                    0.06463430314289577,
                                    0.866268568368725,
                                ],
                                [
                                    0.0016936933802369422,
                                    0.07222421609756836,
                                    0.021219473296175802,
                                    0.9048626172260189,
                                ],
                                [
                                    0.005132256774672495,
                                    0.0687856527031328,
                                    0.06429958742830127,
                                    0.8617825030938935,
                                ],
                                [
                                    0.005066174989851401,
                                    0.04145250253670962,
                                    0.10384008071698247,
                                    0.8496412417564565,
                                ],
                                [
                                    0.041006271609204045,
                                    0.33552188412492884,
                                    0.06789998409762983,
                                    0.5555718601682372,
                                ],
                                [
                                    0.007388302844425402,
                                    0.0604526379396749,
                                    0.10151795286240847,
                                    0.8306411063534912,
                                ],
                                [
                                    0.022388153469271723,
                                    0.04545278731482858,
                                    0.3076213247383002,
                                    0.6245377344775995,
                                ],
                                [
                                    0.009883690033540114,
                                    0.08087041742697293,
                                    0.09902256567329376,
                                    0.8102233268661931,
                                ],
                                [
                                    0.029949715648237816,
                                    0.06080439181227523,
                                    0.30005976255933403,
                                    0.6091861299801529,
                                ],
                                [
                                    0.005066174989851407,
                                    0.01784699168656145,
                                    0.2160370475108866,
                                    0.7610497858127006,
                                ],
                                [
                                    0.15320323840310818,
                                    0.5397004500657328,
                                    0.06789998409762982,
                                    0.23919632743352925,
                                ],
                                [
                                    0.01463746815831465,
                                    0.05156449847410652,
                                    0.20646575434242334,
                                    0.7273322790251555,
                                ],
                                [
                                    0.044354690167740775,
                                    0.021847276464680394,
                                    0.6256358316246874,
                                    0.3081622017428915,
                                ],
                                [
                                    0.024922897665909927,
                                    0.08779774649307216,
                                    0.19618032483482806,
                                    0.6910990310061899,
                                ],
                                [
                                    0.07552176319685502,
                                    0.03719888096212706,
                                    0.5944687585955731,
                                    0.2928105972454448,
                                ],
                                [
                                    0.0014804440605522765,
                                    0.003340336928873789,
                                    0.3056158674706069,
                                    0.6895633515399671,
                                ],
                                [
                                    0.28725449233417205,
                                    0.6481344444522802,
                                    0.019841819196987073,
                                    0.04476924401656067,
                                ],
                                [
                                    0.01994460915835056,
                                    0.04500116976979168,
                                    0.28715170237280857,
                                    0.6479025186990492,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179549,
                                    0.8701316820730636,
                                    0.06492253899879422,
                                ],
                                [
                                    0.03978642835533762,
                                    0.08977041378635232,
                                    0.2673098831758215,
                                    0.6031332746824886,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011083,
                                    0.8100066841343474,
                                    0.060436473723962686,
                                ],
                                [
                                    0.04028317874172909,
                                    0.8256739138417495,
                                    0.00623549878483182,
                                    0.1278074086316896,
                                ],
                                [
                                    0.043513056312281646,
                                    0.8918758804741707,
                                    0.0030056212142792675,
                                    0.06160544199926842,
                                ],
                                [
                                    0.043080114132125376,
                                    0.8830019763900694,
                                    0.0034385633944355423,
                                    0.07047934608336968,
                                ],
                                [
                                    0.06429958742830127,
                                    0.8617825030938935,
                                    0.005132256774672491,
                                    0.06878565270313274,
                                ],
                                [
                                    0.04330437048839866,
                                    0.8875985010232221,
                                    0.0032143070381622585,
                                    0.06588282145021696,
                                ],
                                [
                                    0.06463430314289577,
                                    0.866268568368725,
                                    0.004797541060078007,
                                    0.06429958742830122,
                                ],
                                [
                                    0.13785163390566152,
                                    0.4856202103602057,
                                    0.08325158859507649,
                                    0.2932765671390563,
                                ],
                                [
                                    0.2108177929931427,
                                    0.7426635294802963,
                                    0.010285429507595282,
                                    0.03623324801896565,
                                ],
                                [
                                    0.2010371968860403,
                                    0.7082086956534467,
                                    0.0200660256146977,
                                    0.07068808184581535,
                                ],
                                [
                                    0.30005976255933403,
                                    0.6091861299801529,
                                    0.029949715648237816,
                                    0.06080439181227523,
                                ],
                                [
                                    0.20610337187589167,
                                    0.726055687340008,
                                    0.01499985062484631,
                                    0.05284109015925395,
                                ],
                                [
                                    0.3076213247383002,
                                    0.6245377344775995,
                                    0.02238815346927171,
                                    0.045452787314828554,
                                ],
                                [
                                    0.13785163390566155,
                                    0.16924467762549758,
                                    0.3110356653860286,
                                    0.38186802308281226,
                                ],
                                [
                                    0.4386018697840949,
                                    0.5384849635394924,
                                    0.010285429507595284,
                                    0.012627737168817495,
                                ],
                                [
                                    0.398288433760745,
                                    0.4889909220802729,
                                    0.05059886553094509,
                                    0.06212177862803699,
                                ],
                                [
                                    0.5944687585955731,
                                    0.2928105972454448,
                                    0.07552176319685502,
                                    0.03719888096212706,
                                ],
                                [
                                    0.419170077282264,
                                    0.5146279560853149,
                                    0.02971722200942612,
                                    0.03648474462299504,
                                ],
                                [
                                    0.6256358316246874,
                                    0.3081622017428915,
                                    0.04435469016774077,
                                    0.02184727646468039,
                                ],
                                [
                                    0.04028317874172911,
                                    0.024327884471818596,
                                    0.583188665524138,
                                    0.3522002712623143,
                                ],
                                [
                                    0.6204662230515878,
                                    0.3747129959589861,
                                    0.0030056212142792714,
                                    0.0018151597751467474,
                                ],
                                [
                                    0.5426968009585259,
                                    0.3277463568997842,
                                    0.0807750433073412,
                                    0.04878179883434868,
                                ],
                                [
                                    0.8100066841343474,
                                    0.060436473723962686,
                                    0.1205614716626788,
                                    0.008995370479011078,
                                ],
                                [
                                    0.582979979700255,
                                    0.3520742413716028,
                                    0.040491864565612094,
                                    0.024453914362530086,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879422,
                                    0.06043647372396264,
                                    0.004509305204179545,
                                ],
                                [
                                    0.029003085670294082,
                                    0.5944687585955731,
                                    0.017515591856266832,
                                    0.35901256387786595,
                                ],
                                [
                                    0.03223296324084663,
                                    0.6606707252279942,
                                    0.014285714285714278,
                                    0.2928105972454448,
                                ],
                                [
                                    0.031016823395959445,
                                    0.6357438208259162,
                                    0.015501854130601473,
                                    0.31773750164752296,
                                ],
                                [
                                    0.04629442117028769,
                                    0.6204662230515879,
                                    0.02313742303268608,
                                    0.31010193274543835,
                                ],
                                [
                                    0.031241079752232725,
                                    0.6403403454590689,
                                    0.015277597774328189,
                                    0.3131409770143702,
                                ],
                                [
                                    0.046629136884882176,
                                    0.6249522883264195,
                                    0.022802707318091597,
                                    0.3056158674706068,
                                ],
                                [
                                    0.09925042841304593,
                                    0.3496368708786442,
                                    0.12185279408769206,
                                    0.4292599066206178,
                                ],
                                [
                                    0.17221658750052715,
                                    0.6066801899987349,
                                    0.04888663500021086,
                                    0.17221658750052715,
                                ],
                                [
                                    0.1447427741883145,
                                    0.5098961431066669,
                                    0.0763604483124235,
                                    0.2690006343925951,
                                ],
                                [
                                    0.2160370475108866,
                                    0.43860186978409477,
                                    0.11397243069668525,
                                    0.23138865200833333,
                                ],
                                [
                                    0.1498089491781659,
                                    0.5277431347932283,
                                    0.07129427332257211,
                                    0.2511536427060337,
                                ],
                                [
                                    0.22359860968985273,
                                    0.4539534742815415,
                                    0.10641086851771915,
                                    0.21603704751088665,
                                ],
                                [
                                    0.09925042841304593,
                                    0.12185279408769206,
                                    0.3496368708786442,
                                    0.4292599066206178,
                                ],
                                [
                                    0.40000066429147924,
                                    0.4910930800016869,
                                    0.048886635000210864,
                                    0.060019620706622985,
                                ],
                                [
                                    0.28675973263956733,
                                    0.35206371612374654,
                                    0.16212756665212277,
                                    0.19904898458456335,
                                ],
                                [
                                    0.42800565577017113,
                                    0.21081779299314274,
                                    0.241984866022257,
                                    0.11919168521442913,
                                ],
                                [
                                    0.30764137616108633,
                                    0.37770075012878845,
                                    0.1412459231306038,
                                    0.1734119505795214,
                                ],
                                [
                                    0.4591727287992854,
                                    0.2261693974905894,
                                    0.21081779299314274,
                                    0.10384008071698247,
                                ],
                                [
                                    0.029003085670294148,
                                    0.017515591856266877,
                                    0.5944687585955729,
                                    0.359012563877866,
                                ],
                                [
                                    0.6091861299801529,
                                    0.3679007033434344,
                                    0.014285714285714294,
                                    0.008627452390698502,
                                ],
                                [
                                    0.390730878317947,
                                    0.23597084351847267,
                                    0.23274096594792004,
                                    0.1405573122156602,
                                ],
                                [
                                    0.583188665524138,
                                    0.043513056312281695,
                                    0.34737949027288817,
                                    0.025918787890692067,
                                ],
                                [
                                    0.43101405705967616,
                                    0.26029872799029125,
                                    0.19245778720619094,
                                    0.11622942774384161,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711323,
                                    0.287254492334172,
                                    0.021432722615860534,
                                ],
                                [
                                    0.014285714285714282,
                                    0.29281059724544484,
                                    0.03223296324084663,
                                    0.6606707252279942,
                                ],
                                [
                                    0.017515591856266836,
                                    0.35901256387786606,
                                    0.02900308567029408,
                                    0.594468758595573,
                                ],
                                [
                                    0.015277597774328189,
                                    0.3131409770143702,
                                    0.031241079752232725,
                                    0.6403403454590689,
                                ],
                                [
                                    0.022802707318091597,
                                    0.3056158674706068,
                                    0.046629136884882176,
                                    0.6249522883264195,
                                ],
                                [
                                    0.015501854130601476,
                                    0.317737501647523,
                                    0.031016823395959438,
                                    0.6357438208259161,
                                ],
                                [
                                    0.023137423032686084,
                                    0.3101019327454384,
                                    0.04629442117028768,
                                    0.6204662230515878,
                                ],
                                [
                                    0.04888663500021085,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.6066801899987349,
                                ],
                                [
                                    0.12185279408769206,
                                    0.4292599066206178,
                                    0.09925042841304593,
                                    0.3496368708786442,
                                ],
                                [
                                    0.07129427332257211,
                                    0.2511536427060337,
                                    0.1498089491781659,
                                    0.5277431347932283,
                                ],
                                [
                                    0.10641086851771915,
                                    0.21603704751088665,
                                    0.22359860968985273,
                                    0.4539534742815415,
                                ],
                                [
                                    0.07636044831242349,
                                    0.26900063439259503,
                                    0.1447427741883145,
                                    0.509896143106667,
                                ],
                                [
                                    0.11397243069668524,
                                    0.23138865200833328,
                                    0.21603704751088662,
                                    0.4386018697840948,
                                ],
                                [
                                    0.04888663500021088,
                                    0.060019620706623,
                                    0.40000066429147924,
                                    0.4910930800016869,
                                ],
                                [
                                    0.3496368708786442,
                                    0.4292599066206178,
                                    0.09925042841304595,
                                    0.12185279408769208,
                                ],
                                [
                                    0.1412459231306038,
                                    0.1734119505795214,
                                    0.30764137616108633,
                                    0.37770075012878845,
                                ],
                                [
                                    0.21081779299314274,
                                    0.10384008071698247,
                                    0.4591727287992854,
                                    0.2261693974905894,
                                ],
                                [
                                    0.16212756665212277,
                                    0.19904898458456335,
                                    0.28675973263956733,
                                    0.35206371612374654,
                                ],
                                [
                                    0.241984866022257,
                                    0.11919168521442913,
                                    0.42800565577017113,
                                    0.21081779299314274,
                                ],
                                [
                                    0.014285714285714332,
                                    0.008627452390698523,
                                    0.6091861299801528,
                                    0.3679007033434344,
                                ],
                                [
                                    0.594468758595573,
                                    0.35901256387786606,
                                    0.029003085670294113,
                                    0.017515591856266857,
                                ],
                                [
                                    0.19245778720619097,
                                    0.11622942774384162,
                                    0.43101405705967616,
                                    0.26029872799029125,
                                ],
                                [
                                    0.28725449233417205,
                                    0.021432722615860537,
                                    0.6433136634628541,
                                    0.04799912158711323,
                                ],
                                [
                                    0.23274096594792007,
                                    0.14055731221566023,
                                    0.390730878317947,
                                    0.23597084351847267,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069207,
                                    0.583188665524138,
                                    0.043513056312281695,
                                ],
                                [
                                    0.0030056212142792684,
                                    0.061605441999268436,
                                    0.043513056312281646,
                                    0.8918758804741707,
                                ],
                                [
                                    0.006235498784831823,
                                    0.12780740863168966,
                                    0.04028317874172909,
                                    0.8256739138417495,
                                ],
                                [
                                    0.003214307038162259,
                                    0.06588282145021697,
                                    0.04330437048839866,
                                    0.8875985010232221,
                                ],
                                [
                                    0.0047975410600780075,
                                    0.06429958742830123,
                                    0.06463430314289577,
                                    0.866268568368725,
                                ],
                                [
                                    0.0034385633944355454,
                                    0.07047934608336975,
                                    0.04308011413212537,
                                    0.8830019763900694,
                                ],
                                [
                                    0.005132256774672495,
                                    0.0687856527031328,
                                    0.06429958742830127,
                                    0.8617825030938935,
                                ],
                                [
                                    0.010285429507595303,
                                    0.03623324801896572,
                                    0.21081779299314268,
                                    0.7426635294802962,
                                ],
                                [
                                    0.08325158859507652,
                                    0.29327656713905637,
                                    0.1378516339056615,
                                    0.48562021036020564,
                                ],
                                [
                                    0.014999850624846319,
                                    0.05284109015925398,
                                    0.20610337187589167,
                                    0.726055687340008,
                                ],
                                [
                                    0.022388153469271723,
                                    0.04545278731482858,
                                    0.3076213247383002,
                                    0.6245377344775995,
                                ],
                                [
                                    0.0200660256146977,
                                    0.07068808184581535,
                                    0.2010371968860403,
                                    0.7082086956534467,
                                ],
                                [
                                    0.029949715648237816,
                                    0.06080439181227523,
                                    0.30005976255933403,
                                    0.6091861299801529,
                                ],
                                [
                                    0.010285429507595319,
                                    0.012627737168817536,
                                    0.4386018697840948,
                                    0.5384849635394924,
                                ],
                                [
                                    0.3110356653860286,
                                    0.38186802308281226,
                                    0.13785163390566152,
                                    0.16924467762549755,
                                ],
                                [
                                    0.029717222009426125,
                                    0.036484744622995044,
                                    0.419170077282264,
                                    0.5146279560853149,
                                ],
                                [
                                    0.044354690167740775,
                                    0.021847276464680394,
                                    0.6256358316246874,
                                    0.3081622017428915,
                                ],
                                [
                                    0.05059886553094509,
                                    0.06212177862803699,
                                    0.398288433760745,
                                    0.4889909220802729,
                                ],
                                [
                                    0.07552176319685502,
                                    0.03719888096212706,
                                    0.5944687585955731,
                                    0.2928105972454448,
                                ],
                                [
                                    0.003005621214279301,
                                    0.001815159775146765,
                                    0.6204662230515878,
                                    0.3747129959589861,
                                ],
                                [
                                    0.583188665524138,
                                    0.3522002712623143,
                                    0.04028317874172913,
                                    0.02432788447181861,
                                ],
                                [
                                    0.04049186456561213,
                                    0.024453914362530107,
                                    0.582979979700255,
                                    0.3520742413716028,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179549,
                                    0.8701316820730636,
                                    0.06492253899879422,
                                ],
                                [
                                    0.08077504330734124,
                                    0.0487817988343487,
                                    0.5426968009585259,
                                    0.3277463568997842,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011083,
                                    0.8100066841343474,
                                    0.060436473723962686,
                                ],
                                [
                                    0.055950408449131114,
                                    0.8100066841343474,
                                    0.008660654764416588,
                                    0.12538225265210484,
                                ],
                                [
                                    0.060436473723962644,
                                    0.8749524630624896,
                                    0.004174589489585057,
                                    0.06043647372396263,
                                ],
                                [
                                    0.059835148491663936,
                                    0.8662469420305309,
                                    0.004775914721883771,
                                    0.06914199475592146,
                                ],
                                [
                                    0.06429958742830127,
                                    0.8617825030938935,
                                    0.005132256774672491,
                                    0.06878565270313274,
                                ],
                                [
                                    0.06014662427691041,
                                    0.8707562472347103,
                                    0.0044644389366372975,
                                    0.06463268955174192,
                                ],
                                [
                                    0.06463430314289577,
                                    0.866268568368725,
                                    0.004797541060078007,
                                    0.06429958742830122,
                                ],
                                [
                                    0.19146590371757707,
                                    0.4320059405482901,
                                    0.11563040781358204,
                                    0.26089774792055076,
                                ],
                                [
                                    0.29281059724544484,
                                    0.6606707252279942,
                                    0.014285714285714287,
                                    0.032232963240846645,
                                ],
                                [
                                    0.2792260598737331,
                                    0.6300198326657538,
                                    0.027870251657426008,
                                    0.06288385580308704,
                                ],
                                [
                                    0.30005976255933403,
                                    0.6091861299801529,
                                    0.029949715648237816,
                                    0.06080439181227523,
                                ],
                                [
                                    0.28626260884555815,
                                    0.6458964503703416,
                                    0.02083370268560097,
                                    0.047007238098499285,
                                ],
                                [
                                    0.3076213247383002,
                                    0.6245377344775995,
                                    0.02238815346927171,
                                    0.045452787314828554,
                                ],
                                [
                                    0.19146590371757705,
                                    0.11563040781358208,
                                    0.43200594054829006,
                                    0.2608977479205508,
                                ],
                                [
                                    0.6091861299801529,
                                    0.3679007033434344,
                                    0.014285714285714284,
                                    0.008627452390698495,
                                ],
                                [
                                    0.55319369636523,
                                    0.3340856594757879,
                                    0.0702781479006371,
                                    0.04244249625834499,
                                ],
                                [
                                    0.5944687585955731,
                                    0.2928105972454448,
                                    0.07552176319685502,
                                    0.03719888096212706,
                                ],
                                [
                                    0.582196782035524,
                                    0.3516012513320547,
                                    0.04127506223034302,
                                    0.024926904402078145,
                                ],
                                [
                                    0.6256358316246874,
                                    0.3081622017428915,
                                    0.04435469016774077,
                                    0.02184727646468039,
                                ],
                                [
                                    0.055950408449131114,
                                    0.008660654764416591,
                                    0.8100066841343474,
                                    0.12538225265210487,
                                ],
                                [
                                    0.8617825030938935,
                                    0.1333967159166805,
                                    0.00417458948958506,
                                    0.0006461914998409586,
                                ],
                                [
                                    0.753766426238164,
                                    0.11667673162014604,
                                    0.11219066634531447,
                                    0.017366175796375425,
                                ],
                                [
                                    0.8100066841343474,
                                    0.060436473723962686,
                                    0.1205614716626788,
                                    0.008995370479011078,
                                ],
                                [
                                    0.8097168346872952,
                                    0.12533738638456263,
                                    0.05624025789618335,
                                    0.008705521031958834,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879422,
                                    0.06043647372396264,
                                    0.004509305204179545,
                                ],
                                [
                                    0.04028317874172912,
                                    0.5831886655241381,
                                    0.02432788447181859,
                                    0.3522002712623142,
                                ],
                                [
                                    0.04476924401656064,
                                    0.6481344444522802,
                                    0.01984181919698706,
                                    0.287254492334172,
                                ],
                                [
                                    0.0430801141321254,
                                    0.6236805300897502,
                                    0.02153094908142231,
                                    0.3117084066967021,
                                ],
                                [
                                    0.04629442117028769,
                                    0.6204662230515879,
                                    0.02313742303268608,
                                    0.31010193274543835,
                                ],
                                [
                                    0.04339158991737187,
                                    0.6281898352939297,
                                    0.021219473296175836,
                                    0.30719910149252255,
                                ],
                                [
                                    0.046629136884882176,
                                    0.6249522883264195,
                                    0.022802707318091597,
                                    0.3056158674706068,
                                ],
                                [
                                    0.13785163390566155,
                                    0.3110356653860286,
                                    0.16924467762549758,
                                    0.38186802308281226,
                                ],
                                [
                                    0.2391963274335293,
                                    0.5397004500657328,
                                    0.06789998409762983,
                                    0.15320323840310818,
                                ],
                                [
                                    0.2010371968860403,
                                    0.45360172040894103,
                                    0.1060591146451188,
                                    0.23930196805989978,
                                ],
                                [
                                    0.2160370475108866,
                                    0.43860186978409477,
                                    0.11397243069668525,
                                    0.23138865200833333,
                                ],
                                [
                                    0.20807374585786537,
                                    0.46947833811352885,
                                    0.09902256567329376,
                                    0.22342535035531202,
                                ],
                                [
                                    0.22359860968985273,
                                    0.4539534742815415,
                                    0.10641086851771915,
                                    0.21603704751088665,
                                ],
                                [
                                    0.1378516339056615,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.29327656713905637,
                                ],
                                [
                                    0.5555718601682372,
                                    0.33552188412492884,
                                    0.06789998409762982,
                                    0.04100627160920404,
                                ],
                                [
                                    0.39828843376074496,
                                    0.2405350150025689,
                                    0.22518341050512214,
                                    0.135993140731564,
                                ],
                                [
                                    0.42800565577017113,
                                    0.21081779299314274,
                                    0.241984866022257,
                                    0.11919168521442913,
                                ],
                                [
                                    0.42729151943103905,
                                    0.25805060685883574,
                                    0.19618032483482806,
                                    0.11847754887529714,
                                ],
                                [
                                    0.4591727287992854,
                                    0.2261693974905894,
                                    0.21081779299314274,
                                    0.10384008071698247,
                                ],
                                [
                                    0.04028317874172919,
                                    0.0062354987848318374,
                                    0.8256739138417494,
                                    0.12780740863168963,
                                ],
                                [
                                    0.8461152733864915,
                                    0.13097155993709575,
                                    0.01984181919698707,
                                    0.0030713474794257256,
                                ],
                                [
                                    0.5426968009585259,
                                    0.0840049208778938,
                                    0.32326029162495257,
                                    0.05003798653862766,
                                ],
                                [
                                    0.583188665524138,
                                    0.043513056312281695,
                                    0.34737949027288817,
                                    0.025918787890692067,
                                ],
                                [
                                    0.598647209407657,
                                    0.09266557564231039,
                                    0.26730988317582144,
                                    0.041377331774211074,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711323,
                                    0.287254492334172,
                                    0.021432722615860534,
                                ],
                                [
                                    0.019841819196987062,
                                    0.28725449233417205,
                                    0.04476924401656064,
                                    0.6481344444522802,
                                ],
                                [
                                    0.024327884471818596,
                                    0.3522002712623143,
                                    0.04028317874172911,
                                    0.583188665524138,
                                ],
                                [
                                    0.021219473296175836,
                                    0.30719910149252255,
                                    0.04339158991737187,
                                    0.6281898352939297,
                                ],
                                [
                                    0.022802707318091597,
                                    0.3056158674706068,
                                    0.046629136884882176,
                                    0.6249522883264195,
                                ],
                                [
                                    0.021530949081422314,
                                    0.31170840669670213,
                                    0.04308011413212539,
                                    0.6236805300897501,
                                ],
                                [
                                    0.023137423032686084,
                                    0.3101019327454384,
                                    0.04629442117028768,
                                    0.6204662230515878,
                                ],
                                [
                                    0.06789998409762983,
                                    0.15320323840310818,
                                    0.2391963274335293,
                                    0.5397004500657328,
                                ],
                                [
                                    0.16924467762549758,
                                    0.38186802308281226,
                                    0.13785163390566155,
                                    0.3110356653860286,
                                ],
                                [
                                    0.09902256567329376,
                                    0.22342535035531202,
                                    0.20807374585786537,
                                    0.46947833811352885,
                                ],
                                [
                                    0.10641086851771915,
                                    0.21603704751088665,
                                    0.22359860968985273,
                                    0.4539534742815415,
                                ],
                                [
                                    0.10605911464511879,
                                    0.23930196805989976,
                                    0.20103719688604035,
                                    0.45360172040894114,
                                ],
                                [
                                    0.11397243069668524,
                                    0.23138865200833328,
                                    0.21603704751088662,
                                    0.4386018697840948,
                                ],
                                [
                                    0.06789998409762983,
                                    0.041006271609204045,
                                    0.5555718601682372,
                                    0.33552188412492884,
                                ],
                                [
                                    0.48562021036020564,
                                    0.29327656713905637,
                                    0.1378516339056615,
                                    0.08325158859507652,
                                ],
                                [
                                    0.19618032483482806,
                                    0.11847754887529714,
                                    0.42729151943103905,
                                    0.25805060685883574,
                                ],
                                [
                                    0.21081779299314274,
                                    0.10384008071698247,
                                    0.4591727287992854,
                                    0.2261693974905894,
                                ],
                                [
                                    0.22518341050512214,
                                    0.135993140731564,
                                    0.39828843376074496,
                                    0.2405350150025689,
                                ],
                                [
                                    0.241984866022257,
                                    0.11919168521442913,
                                    0.42800565577017113,
                                    0.21081779299314274,
                                ],
                                [
                                    0.01984181919698712,
                                    0.0030713474794257334,
                                    0.8461152733864914,
                                    0.13097155993709575,
                                ],
                                [
                                    0.8256739138417495,
                                    0.12780740863168966,
                                    0.04028317874172914,
                                    0.0062354987848318305,
                                ],
                                [
                                    0.2673098831758215,
                                    0.04137733177421108,
                                    0.598647209407657,
                                    0.09266557564231039,
                                ],
                                [
                                    0.28725449233417205,
                                    0.021432722615860537,
                                    0.6433136634628541,
                                    0.04799912158711323,
                                ],
                                [
                                    0.3232602916249526,
                                    0.05003798653862768,
                                    0.5426968009585259,
                                    0.0840049208778938,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069207,
                                    0.583188665524138,
                                    0.043513056312281695,
                                ],
                                [
                                    0.004174589489585058,
                                    0.060436473723962644,
                                    0.060436473723962644,
                                    0.8749524630624896,
                                ],
                                [
                                    0.008660654764416591,
                                    0.12538225265210487,
                                    0.055950408449131114,
                                    0.8100066841343474,
                                ],
                                [
                                    0.004464438936637298,
                                    0.06463268955174194,
                                    0.06014662427691041,
                                    0.8707562472347103,
                                ],
                                [
                                    0.0047975410600780075,
                                    0.06429958742830123,
                                    0.06463430314289577,
                                    0.866268568368725,
                                ],
                                [
                                    0.004775914721883775,
                                    0.06914199475592152,
                                    0.05983514849166393,
                                    0.8662469420305308,
                                ],
                                [
                                    0.005132256774672495,
                                    0.0687856527031328,
                                    0.06429958742830127,
                                    0.8617825030938935,
                                ],
                                [
                                    0.014285714285714315,
                                    0.03223296324084671,
                                    0.29281059724544484,
                                    0.6606707252279942,
                                ],
                                [
                                    0.11563040781358208,
                                    0.2608977479205508,
                                    0.19146590371757705,
                                    0.43200594054829006,
                                ],
                                [
                                    0.020833702685600985,
                                    0.04700723809849932,
                                    0.28626260884555815,
                                    0.6458964503703416,
                                ],
                                [
                                    0.022388153469271723,
                                    0.04545278731482858,
                                    0.3076213247383002,
                                    0.6245377344775995,
                                ],
                                [
                                    0.027870251657426008,
                                    0.06288385580308704,
                                    0.2792260598737331,
                                    0.6300198326657538,
                                ],
                                [
                                    0.029949715648237816,
                                    0.06080439181227523,
                                    0.30005976255933403,
                                    0.6091861299801529,
                                ],
                                [
                                    0.014285714285714332,
                                    0.008627452390698523,
                                    0.6091861299801528,
                                    0.3679007033434344,
                                ],
                                [
                                    0.43200594054829006,
                                    0.2608977479205508,
                                    0.19146590371757702,
                                    0.11563040781358205,
                                ],
                                [
                                    0.041275062230343024,
                                    0.02492690440207815,
                                    0.582196782035524,
                                    0.3516012513320547,
                                ],
                                [
                                    0.044354690167740775,
                                    0.021847276464680394,
                                    0.6256358316246874,
                                    0.3081622017428915,
                                ],
                                [
                                    0.0702781479006371,
                                    0.04244249625834499,
                                    0.55319369636523,
                                    0.3340856594757879,
                                ],
                                [
                                    0.07552176319685502,
                                    0.03719888096212706,
                                    0.5944687585955731,
                                    0.2928105972454448,
                                ],
                                [
                                    0.004174589489585101,
                                    0.0006461914998409649,
                                    0.8617825030938935,
                                    0.1333967159166805,
                                ],
                                [
                                    0.8100066841343474,
                                    0.12538225265210487,
                                    0.05595040844913115,
                                    0.008660654764416596,
                                ],
                                [
                                    0.0562402578961834,
                                    0.008705521031958841,
                                    0.8097168346872952,
                                    0.12533738638456263,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179549,
                                    0.8701316820730636,
                                    0.06492253899879422,
                                ],
                                [
                                    0.11219066634531451,
                                    0.017366175796375432,
                                    0.753766426238164,
                                    0.11667673162014604,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011083,
                                    0.8100066841343474,
                                    0.060436473723962686,
                                ],
                                [
                                    0.004174589489585101,
                                    0.8617825030938935,
                                    0.0006461914998409646,
                                    0.13339671591668045,
                                ],
                                [
                                    0.004509305204179589,
                                    0.9308796315822727,
                                    0.0003114757852464765,
                                    0.06429958742830122,
                                ],
                                [
                                    0.004383275313468094,
                                    0.9048626172260189,
                                    0.00043750567595797154,
                                    0.09031660178455507,
                                ],
                                [
                                    0.06313061915299549,
                                    0.8461152733864915,
                                    0.006301225049978281,
                                    0.08445288241053477,
                                ],
                                [
                                    0.004493734671789295,
                                    0.9276653245441104,
                                    0.00032704631763676997,
                                    0.06751389446646348,
                                ],
                                [
                                    0.06472152257186894,
                                    0.8674375366440308,
                                    0.0047103216311048185,
                                    0.06313061915299543,
                                ],
                                [
                                    0.014285714285714264,
                                    0.609186129980153,
                                    0.00862745239069848,
                                    0.36790070334343433,
                                ],
                                [
                                    0.02184727646468036,
                                    0.9316340460087588,
                                    0.0010658902117323865,
                                    0.04545278731482855,
                                ],
                                [
                                    0.019000135402965284,
                                    0.8102233268661932,
                                    0.00391303127344746,
                                    0.16686350645739398,
                                ],
                                [
                                    0.27365160210092115,
                                    0.5555718601682373,
                                    0.056357876106650696,
                                    0.11441866162419075,
                                ],
                                [
                                    0.021495522592079996,
                                    0.9166341953839124,
                                    0.0014176440843327496,
                                    0.060452637939674855,
                                ],
                                [
                                    0.3095916987202738,
                                    0.6285380192557186,
                                    0.020417779487298063,
                                    0.04145250253670954,
                                ],
                                [
                                    0.014285714285714282,
                                    0.29281059724544484,
                                    0.03223296324084663,
                                    0.6606707252279942,
                                ],
                                [
                                    0.045452787314828526,
                                    0.9316340460087588,
                                    0.0010658902117323876,
                                    0.02184727646468039,
                                ],
                                [
                                    0.03371750678754511,
                                    0.6910990310061899,
                                    0.012801170739015807,
                                    0.26238229146724923,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.04400293629514039,
                                    0.9019168239993326,
                                    0.002515741231420528,
                                    0.05156449847410651,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.004174589489585058,
                                    0.060436473723962644,
                                    0.060436473723962644,
                                    0.8749524630624896,
                                ],
                                [
                                    0.06429958742830123,
                                    0.9308796315822727,
                                    0.00031147578524647355,
                                    0.004509305204179546,
                                ],
                                [
                                    0.04166083284091789,
                                    0.6031332746824886,
                                    0.022950230372629808,
                                    0.3322556621039636,
                                ],
                                [
                                    0.6000248635068458,
                                    0.044769244016560676,
                                    0.33054329229018037,
                                    0.02466260018641309,
                                ],
                                [
                                    0.061502652037904955,
                                    0.8903877670166607,
                                    0.003108411175642752,
                                    0.04500116976979165,
                                ],
                                [
                                    0.8857989117804657,
                                    0.06609150727410001,
                                    0.04476924401656064,
                                    0.0033403369288737563,
                                ],
                                [
                                    0.0030056212142793013,
                                    0.6204662230515879,
                                    0.0018151597751467643,
                                    0.374712995958986,
                                ],
                                [
                                    0.003340336928873789,
                                    0.6895633515399671,
                                    0.0014804440605522763,
                                    0.3056158674706068,
                                ],
                                [
                                    0.0031558708474341084,
                                    0.6514830464475473,
                                    0.0016649101419919567,
                                    0.34369617256302665,
                                ],
                                [
                                    0.045452787314828574,
                                    0.6091861299801528,
                                    0.023979056888145188,
                                    0.3213820258168734,
                                ],
                                [
                                    0.0032663302057553104,
                                    0.6742857537656389,
                                    0.0015544507836707552,
                                    0.320893465244935,
                                ],
                                [
                                    0.04704369073370204,
                                    0.6305083932376921,
                                    0.022388153469271727,
                                    0.3000597625593341,
                                ],
                                [
                                    0.010285429507595268,
                                    0.4386018697840949,
                                    0.012627737168817476,
                                    0.5384849635394924,
                                ],
                                [
                                    0.017846991686561363,
                                    0.7610497858127007,
                                    0.005066174989851383,
                                    0.21603704751088665,
                                ],
                                [
                                    0.013679718732537547,
                                    0.5833446439724094,
                                    0.009233447943875197,
                                    0.39374218935117783,
                                ],
                                [
                                    0.19702369841346767,
                                    0.4000006642914793,
                                    0.1329857797941042,
                                    0.26998985750094884,
                                ],
                                [
                                    0.016175105921652257,
                                    0.6897555124901286,
                                    0.006738060754760488,
                                    0.28733132083345875,
                                ],
                                [
                                    0.23296379503282033,
                                    0.4729668233789605,
                                    0.09704568317475157,
                                    0.19702369841346765,
                                ],
                                [
                                    0.010285429507595279,
                                    0.2108177929931427,
                                    0.03623324801896564,
                                    0.7426635294802963,
                                ],
                                [
                                    0.041452502536709526,
                                    0.8496412417564566,
                                    0.005066174989851388,
                                    0.10384008071698246,
                                ],
                                [
                                    0.024275932746461247,
                                    0.49757752563271007,
                                    0.022242744780099667,
                                    0.455903796840729,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.034561362254056524,
                                    0.7083953186258528,
                                    0.011957315272504387,
                                    0.24508600384758628,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.0030056212142792753,
                                    0.04351305631228175,
                                    0.06160544199926843,
                                    0.8918758804741705,
                                ],
                                [
                                    0.06313061915299545,
                                    0.9139562141705918,
                                    0.0014804440605522618,
                                    0.021432722615860534,
                                ],
                                [
                                    0.029994969158908008,
                                    0.4342439346302288,
                                    0.034616094054639696,
                                    0.5011450021562235,
                                ],
                                [
                                    0.4320059405482901,
                                    0.03223296324084667,
                                    0.4985622152487361,
                                    0.0371988809621271,
                                ],
                                [
                                    0.04983678835589507,
                                    0.7214984269644008,
                                    0.014774274857652637,
                                    0.21389050982205146,
                                ],
                                [
                                    0.7177799888219099,
                                    0.05355522649838601,
                                    0.21278816697511635,
                                    0.01587661770458776,
                                ],
                                [
                                    0.0014804440605522765,
                                    0.3056158674706069,
                                    0.003340336928873789,
                                    0.6895633515399671,
                                ],
                                [
                                    0.001815159775146765,
                                    0.3747129959589861,
                                    0.003005621214279301,
                                    0.6204662230515878,
                                ],
                                [
                                    0.0015544507836707552,
                                    0.320893465244935,
                                    0.0032663302057553104,
                                    0.6742857537656389,
                                ],
                                [
                                    0.022388153469271727,
                                    0.3000597625593341,
                                    0.04704369073370204,
                                    0.6305083932376921,
                                ],
                                [
                                    0.0016649101419919565,
                                    0.3436961725630266,
                                    0.0031558708474341093,
                                    0.6514830464475474,
                                ],
                                [
                                    0.023979056888145184,
                                    0.32138202581687336,
                                    0.04545278731482858,
                                    0.6091861299801529,
                                ],
                                [
                                    0.005066174989851382,
                                    0.21603704751088662,
                                    0.017846991686561363,
                                    0.7610497858127007,
                                ],
                                [
                                    0.012627737168817476,
                                    0.5384849635394924,
                                    0.010285429507595268,
                                    0.4386018697840949,
                                ],
                                [
                                    0.006738060754760489,
                                    0.2873313208334588,
                                    0.016175105921652253,
                                    0.6897555124901285,
                                ],
                                [
                                    0.09704568317475158,
                                    0.19702369841346767,
                                    0.23296379503282028,
                                    0.47296682337896045,
                                ],
                                [
                                    0.0092334479438752,
                                    0.39374218935117794,
                                    0.013679718732537543,
                                    0.5833446439724093,
                                ],
                                [
                                    0.13298577979410423,
                                    0.2699898575009489,
                                    0.19702369841346765,
                                    0.40000066429147924,
                                ],
                                [
                                    0.00506617498985139,
                                    0.10384008071698249,
                                    0.041452502536709526,
                                    0.8496412417564566,
                                ],
                                [
                                    0.03623324801896564,
                                    0.7426635294802963,
                                    0.010285429507595279,
                                    0.21081779299314274,
                                ],
                                [
                                    0.011957315272504388,
                                    0.24508600384758633,
                                    0.034561362254056524,
                                    0.7083953186258528,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.022242744780099667,
                                    0.455903796840729,
                                    0.024275932746461247,
                                    0.49757752563271007,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.0014804440605522657,
                                    0.02143272261586059,
                                    0.06313061915299543,
                                    0.9139562141705917,
                                ],
                                [
                                    0.061605441999268436,
                                    0.8918758804741707,
                                    0.003005621214279272,
                                    0.043513056312281695,
                                ],
                                [
                                    0.014774274857652642,
                                    0.21389050982205154,
                                    0.04983678835589506,
                                    0.7214984269644007,
                                ],
                                [
                                    0.21278816697511643,
                                    0.015876617704587766,
                                    0.7177799888219099,
                                    0.053555226498386004,
                                ],
                                [
                                    0.034616094054639696,
                                    0.5011450021562235,
                                    0.029994969158908005,
                                    0.43424393463022876,
                                ],
                                [
                                    0.4985622152487361,
                                    0.0371988809621271,
                                    0.43200594054829006,
                                    0.03223296324084667,
                                ],
                                [
                                    0.0003114757852464766,
                                    0.06429958742830123,
                                    0.004509305204179589,
                                    0.9308796315822727,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.1333967159166805,
                                    0.004174589489585101,
                                    0.8617825030938935,
                                ],
                                [
                                    0.0003270463176367702,
                                    0.06751389446646353,
                                    0.004493734671789295,
                                    0.9276653245441104,
                                ],
                                [
                                    0.004710321631104821,
                                    0.06313061915299548,
                                    0.06472152257186894,
                                    0.8674375366440308,
                                ],
                                [
                                    0.00043750567595797154,
                                    0.09031660178455507,
                                    0.004383275313468094,
                                    0.9048626172260189,
                                ],
                                [
                                    0.006301225049978281,
                                    0.08445288241053477,
                                    0.06313061915299549,
                                    0.8461152733864915,
                                ],
                                [
                                    0.0010658902117323885,
                                    0.04545278731482864,
                                    0.021847276464680356,
                                    0.9316340460087587,
                                ],
                                [
                                    0.008627452390698481,
                                    0.3679007033434344,
                                    0.014285714285714263,
                                    0.6091861299801529,
                                ],
                                [
                                    0.0014176440843327513,
                                    0.06045263793967493,
                                    0.021495522592079992,
                                    0.9166341953839123,
                                ],
                                [
                                    0.020417779487298088,
                                    0.041452502536709596,
                                    0.30959169872027376,
                                    0.6285380192557185,
                                ],
                                [
                                    0.0039130312734474626,
                                    0.1668635064573941,
                                    0.01900013540296528,
                                    0.8102233268661931,
                                ],
                                [
                                    0.05635787610665073,
                                    0.11441866162419083,
                                    0.27365160210092115,
                                    0.5555718601682373,
                                ],
                                [
                                    0.001065890211732391,
                                    0.021847276464680463,
                                    0.045452787314828526,
                                    0.9316340460087587,
                                ],
                                [
                                    0.03223296324084663,
                                    0.6606707252279942,
                                    0.014285714285714278,
                                    0.2928105972454448,
                                ],
                                [
                                    0.0025157412314205313,
                                    0.05156449847410658,
                                    0.044002936295140384,
                                    0.9019168239993325,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.01280117073901581,
                                    0.2623822914672493,
                                    0.03371750678754511,
                                    0.6910990310061897,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.0003114757852464766,
                                    0.004509305204179589,
                                    0.06429958742830123,
                                    0.9308796315822727,
                                ],
                                [
                                    0.060436473723962644,
                                    0.8749524630624896,
                                    0.00417458948958506,
                                    0.060436473723962686,
                                ],
                                [
                                    0.003108411175642751,
                                    0.045001169769791634,
                                    0.061502652037904955,
                                    0.8903877670166607,
                                ],
                                [
                                    0.04476924401656063,
                                    0.0033403369288737554,
                                    0.8857989117804657,
                                    0.06609150727410001,
                                ],
                                [
                                    0.02295023037262981,
                                    0.3322556621039637,
                                    0.04166083284091789,
                                    0.6031332746824886,
                                ],
                                [
                                    0.3305432922901804,
                                    0.024662600186413093,
                                    0.6000248635068458,
                                    0.044769244016560676,
                                ],
                                [
                                    0.019841819196987024,
                                    0.8461152733864915,
                                    0.0030713474794257173,
                                    0.1309715599370957,
                                ],
                                [
                                    0.021432722615860485,
                                    0.9139562141705918,
                                    0.0014804440605522581,
                                    0.06313061915299543,
                                ],
                                [
                                    0.020833702685600936,
                                    0.888412189853886,
                                    0.0020794639908118086,
                                    0.08867464346970123,
                                ],
                                [
                                    0.06313061915299549,
                                    0.8461152733864915,
                                    0.006301225049978281,
                                    0.08445288241053477,
                                ],
                                [
                                    0.021358715892742006,
                                    0.9108003433231577,
                                    0.0015544507836707363,
                                    0.06628649000042952,
                                ],
                                [
                                    0.06472152257186894,
                                    0.8674375366440308,
                                    0.0047103216311048185,
                                    0.06313061915299543,
                                ],
                                [
                                    0.06789998409762985,
                                    0.5555718601682373,
                                    0.04100627160920403,
                                    0.3355218841249287,
                                ],
                                [
                                    0.10384008071698249,
                                    0.8496412417564566,
                                    0.0050661749898513915,
                                    0.04145250253670954,
                                ],
                                [
                                    0.09030762241999109,
                                    0.7389158398491674,
                                    0.018598633286842782,
                                    0.15217790444399867,
                                ],
                                [
                                    0.27365160210092115,
                                    0.5555718601682373,
                                    0.056357876106650696,
                                    0.11441866162419075,
                                ],
                                [
                                    0.10216819495207338,
                                    0.835961523023919,
                                    0.0067380607547604995,
                                    0.055132221269247106,
                                ],
                                [
                                    0.3095916987202738,
                                    0.6285380192557186,
                                    0.020417779487298063,
                                    0.04145250253670954,
                                ],
                                [
                                    0.06789998409762983,
                                    0.2391963274335293,
                                    0.15320323840310818,
                                    0.5397004500657328,
                                ],
                                [
                                    0.21603704751088662,
                                    0.7610497858127007,
                                    0.00506617498985139,
                                    0.017846991686561387,
                                ],
                                [
                                    0.16025927222802275,
                                    0.5645572655657123,
                                    0.06084395027271525,
                                    0.2143395119335498,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.20914590722823362,
                                    0.7367738530662394,
                                    0.01195731527250439,
                                    0.04212292443302265,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.019841819196987062,
                                    0.04476924401656064,
                                    0.28725449233417205,
                                    0.6481344444522802,
                                ],
                                [
                                    0.3056158674706069,
                                    0.6895633515399671,
                                    0.0014804440605522622,
                                    0.0033403369288737567,
                                ],
                                [
                                    0.19801389211746376,
                                    0.44678021540594276,
                                    0.10908241941369536,
                                    0.2461234730628981,
                                ],
                                [
                                    0.6000248635068458,
                                    0.044769244016560676,
                                    0.33054329229018037,
                                    0.02466260018641309,
                                ],
                                [
                                    0.2923220366735065,
                                    0.6595683823810591,
                                    0.014774274857652639,
                                    0.033335306087781756,
                                ],
                                [
                                    0.8857989117804657,
                                    0.06609150727410001,
                                    0.04476924401656064,
                                    0.0033403369288737563,
                                ],
                                [
                                    0.014285714285714264,
                                    0.609186129980153,
                                    0.00862745239069848,
                                    0.36790070334343433,
                                ],
                                [
                                    0.01587661770458772,
                                    0.6770270707642532,
                                    0.007036548971825021,
                                    0.30005976255933403,
                                ],
                                [
                                    0.014999850624846284,
                                    0.639639066670135,
                                    0.007913316051566458,
                                    0.3374477666534521,
                                ],
                                [
                                    0.045452787314828574,
                                    0.6091861299801528,
                                    0.023979056888145188,
                                    0.3213820258168734,
                                ],
                                [
                                    0.015524863831987359,
                                    0.6620272201394068,
                                    0.007388302844425385,
                                    0.3150596131841804,
                                ],
                                [
                                    0.04704369073370204,
                                    0.6305083932376921,
                                    0.022388153469271727,
                                    0.3000597625593341,
                                ],
                                [
                                    0.04888663500021088,
                                    0.40000066429147924,
                                    0.060019620706623,
                                    0.4910930800016869,
                                ],
                                [
                                    0.08482673161956351,
                                    0.6940700458796984,
                                    0.02407952408727036,
                                    0.19702369841346767,
                                ],
                                [
                                    0.06501968790795448,
                                    0.5320046747969924,
                                    0.04388656779887939,
                                    0.35908906949617364,
                                ],
                                [
                                    0.19702369841346767,
                                    0.4000006642914793,
                                    0.1329857797941042,
                                    0.26998985750094884,
                                ],
                                [
                                    0.07688026044003678,
                                    0.629050357971744,
                                    0.03202599526679711,
                                    0.2620433863214221,
                                ],
                                [
                                    0.23296379503282033,
                                    0.4729668233789605,
                                    0.09704568317475157,
                                    0.19702369841346765,
                                ],
                                [
                                    0.04888663500021085,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.6066801899987349,
                                ],
                                [
                                    0.19702369841346765,
                                    0.6940700458796984,
                                    0.024079524087270352,
                                    0.0848267316195635,
                                ],
                                [
                                    0.11538348132078953,
                                    0.4064699770583818,
                                    0.10571974117994846,
                                    0.3724268004408802,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.1642701163210004,
                                    0.5786865645589089,
                                    0.0568331061797376,
                                    0.20021021294035304,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.014285714285714315,
                                    0.03223296324084671,
                                    0.29281059724544484,
                                    0.6606707252279942,
                                ],
                                [
                                    0.3000597625593341,
                                    0.6770270707642532,
                                    0.007036548971825038,
                                    0.01587661770458776,
                                ],
                                [
                                    0.14256605502291256,
                                    0.3216728487662242,
                                    0.16453025650824657,
                                    0.37123083970261667,
                                ],
                                [
                                    0.4320059405482901,
                                    0.03223296324084667,
                                    0.4985622152487361,
                                    0.0371988809621271,
                                ],
                                [
                                    0.2368741995789553,
                                    0.5344610157413406,
                                    0.07022211195220383,
                                    0.15844267272750026,
                                ],
                                [
                                    0.7177799888219099,
                                    0.05355522649838601,
                                    0.21278816697511635,
                                    0.01587661770458776,
                                ],
                                [
                                    0.007036548971825022,
                                    0.3000597625593341,
                                    0.01587661770458772,
                                    0.6770270707642532,
                                ],
                                [
                                    0.008627452390698481,
                                    0.3679007033434344,
                                    0.014285714285714263,
                                    0.6091861299801529,
                                ],
                                [
                                    0.007388302844425385,
                                    0.3150596131841804,
                                    0.015524863831987359,
                                    0.6620272201394068,
                                ],
                                [
                                    0.022388153469271727,
                                    0.3000597625593341,
                                    0.04704369073370204,
                                    0.6305083932376921,
                                ],
                                [
                                    0.007913316051566456,
                                    0.33744776665345205,
                                    0.014999850624846288,
                                    0.6396390666701351,
                                ],
                                [
                                    0.023979056888145184,
                                    0.32138202581687336,
                                    0.04545278731482858,
                                    0.6091861299801529,
                                ],
                                [
                                    0.02407952408727036,
                                    0.19702369841346765,
                                    0.08482673161956351,
                                    0.6940700458796984,
                                ],
                                [
                                    0.060019620706623,
                                    0.4910930800016869,
                                    0.04888663500021088,
                                    0.40000066429147924,
                                ],
                                [
                                    0.032025995266797114,
                                    0.26204338632142216,
                                    0.07688026044003676,
                                    0.629050357971744,
                                ],
                                [
                                    0.09704568317475158,
                                    0.19702369841346767,
                                    0.23296379503282028,
                                    0.47296682337896045,
                                ],
                                [
                                    0.0438865677988794,
                                    0.35908906949617375,
                                    0.06501968790795448,
                                    0.5320046747969924,
                                ],
                                [
                                    0.13298577979410423,
                                    0.2699898575009489,
                                    0.19702369841346765,
                                    0.40000066429147924,
                                ],
                                [
                                    0.02407952408727036,
                                    0.08482673161956351,
                                    0.19702369841346765,
                                    0.6940700458796984,
                                ],
                                [
                                    0.17221658750052715,
                                    0.6066801899987349,
                                    0.04888663500021086,
                                    0.17221658750052715,
                                ],
                                [
                                    0.056833106179737615,
                                    0.2002102129403531,
                                    0.1642701163210004,
                                    0.5786865645589089,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.10571974117994846,
                                    0.3724268004408802,
                                    0.11538348132078953,
                                    0.4064699770583818,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.007036548971825056,
                                    0.0158766177045878,
                                    0.3000597625593341,
                                    0.6770270707642531,
                                ],
                                [
                                    0.29281059724544484,
                                    0.6606707252279942,
                                    0.0142857142857143,
                                    0.03223296324084667,
                                ],
                                [
                                    0.07022211195220386,
                                    0.15844267272750032,
                                    0.23687419957895525,
                                    0.5344610157413405,
                                ],
                                [
                                    0.21278816697511643,
                                    0.015876617704587766,
                                    0.7177799888219099,
                                    0.053555226498386004,
                                ],
                                [
                                    0.16453025650824657,
                                    0.37123083970261667,
                                    0.14256605502291256,
                                    0.3216728487662242,
                                ],
                                [
                                    0.4985622152487361,
                                    0.0371988809621271,
                                    0.43200594054829006,
                                    0.03223296324084667,
                                ],
                                [
                                    0.0014804440605522586,
                                    0.06313061915299545,
                                    0.021432722615860485,
                                    0.9139562141705918,
                                ],
                                [
                                    0.0030713474794257186,
                                    0.13097155993709575,
                                    0.019841819196987024,
                                    0.8461152733864915,
                                ],
                                [
                                    0.0015544507836707372,
                                    0.06628649000042956,
                                    0.021358715892742006,
                                    0.9108003433231577,
                                ],
                                [
                                    0.004710321631104821,
                                    0.06313061915299548,
                                    0.06472152257186894,
                                    0.8674375366440308,
                                ],
                                [
                                    0.0020794639908118086,
                                    0.08867464346970123,
                                    0.020833702685600936,
                                    0.888412189853886,
                                ],
                                [
                                    0.006301225049978281,
                                    0.08445288241053477,
                                    0.06313061915299549,
                                    0.8461152733864915,
                                ],
                                [
                                    0.005066174989851401,
                                    0.04145250253670962,
                                    0.10384008071698247,
                                    0.8496412417564565,
                                ],
                                [
                                    0.041006271609204045,
                                    0.33552188412492884,
                                    0.06789998409762983,
                                    0.5555718601682372,
                                ],
                                [
                                    0.006738060754760508,
                                    0.055132221269247175,
                                    0.10216819495207337,
                                    0.8359615230239189,
                                ],
                                [
                                    0.020417779487298088,
                                    0.041452502536709596,
                                    0.30959169872027376,
                                    0.6285380192557185,
                                ],
                                [
                                    0.018598633286842796,
                                    0.15217790444399876,
                                    0.09030762241999109,
                                    0.7389158398491673,
                                ],
                                [
                                    0.05635787610665073,
                                    0.11441866162419083,
                                    0.27365160210092115,
                                    0.5555718601682373,
                                ],
                                [
                                    0.005066174989851407,
                                    0.01784699168656145,
                                    0.2160370475108866,
                                    0.7610497858127006,
                                ],
                                [
                                    0.15320323840310818,
                                    0.5397004500657328,
                                    0.06789998409762982,
                                    0.23919632743352925,
                                ],
                                [
                                    0.011957315272504406,
                                    0.04212292443302271,
                                    0.2091459072282336,
                                    0.7367738530662393,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.06084395027271526,
                                    0.21433951193354986,
                                    0.16025927222802275,
                                    0.5645572655657122,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.0014804440605522765,
                                    0.003340336928873789,
                                    0.3056158674706069,
                                    0.6895633515399671,
                                ],
                                [
                                    0.28725449233417205,
                                    0.6481344444522802,
                                    0.019841819196987073,
                                    0.04476924401656067,
                                ],
                                [
                                    0.014774274857652633,
                                    0.03333530608778175,
                                    0.2923220366735065,
                                    0.6595683823810591,
                                ],
                                [
                                    0.04476924401656063,
                                    0.0033403369288737554,
                                    0.8857989117804657,
                                    0.06609150727410001,
                                ],
                                [
                                    0.10908241941369537,
                                    0.24612347306289814,
                                    0.19801389211746376,
                                    0.44678021540594276,
                                ],
                                [
                                    0.3305432922901804,
                                    0.024662600186413093,
                                    0.6000248635068458,
                                    0.044769244016560676,
                                ],
                                [
                                    0.04028317874172909,
                                    0.8256739138417495,
                                    0.00623549878483182,
                                    0.1278074086316896,
                                ],
                                [
                                    0.043513056312281646,
                                    0.8918758804741707,
                                    0.0030056212142792675,
                                    0.06160544199926842,
                                ],
                                [
                                    0.04229691646739445,
                                    0.8669489760720925,
                                    0.004221761059166463,
                                    0.08653234640134658,
                                ],
                                [
                                    0.06313061915299549,
                                    0.8461152733864915,
                                    0.006301225049978281,
                                    0.08445288241053477,
                                ],
                                [
                                    0.043362806679126835,
                                    0.8887962525367729,
                                    0.0031558708474340746,
                                    0.06468506993666619,
                                ],
                                [
                                    0.06472152257186894,
                                    0.8674375366440308,
                                    0.0047103216311048185,
                                    0.06313061915299543,
                                ],
                                [
                                    0.13785163390566152,
                                    0.4856202103602057,
                                    0.08325158859507649,
                                    0.2932765671390563,
                                ],
                                [
                                    0.2108177929931427,
                                    0.7426635294802963,
                                    0.010285429507595282,
                                    0.03623324801896565,
                                ],
                                [
                                    0.18334397968093008,
                                    0.6458794825882285,
                                    0.037759242819807914,
                                    0.13301729491103353,
                                ],
                                [
                                    0.27365160210092115,
                                    0.5555718601682373,
                                    0.056357876106650696,
                                    0.11441866162419075,
                                ],
                                [
                                    0.20742350376820043,
                                    0.730706214207792,
                                    0.013679718732537564,
                                    0.04819056329147004,
                                ],
                                [
                                    0.3095916987202738,
                                    0.6285380192557186,
                                    0.020417779487298063,
                                    0.04145250253670954,
                                ],
                                [
                                    0.13785163390566155,
                                    0.16924467762549758,
                                    0.3110356653860286,
                                    0.38186802308281226,
                                ],
                                [
                                    0.4386018697840949,
                                    0.5384849635394924,
                                    0.010285429507595284,
                                    0.012627737168817495,
                                ],
                                [
                                    0.325360938132183,
                                    0.39945559966155203,
                                    0.1235263611595072,
                                    0.15165710104675786,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.4246113665452289,
                                    0.5213083937492441,
                                    0.02427593274646126,
                                    0.02980430695906578,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.04028317874172911,
                                    0.024327884471818596,
                                    0.583188665524138,
                                    0.3522002712623143,
                                ],
                                [
                                    0.6204662230515878,
                                    0.3747129959589861,
                                    0.0030056212142792714,
                                    0.0018151597751467474,
                                ],
                                [
                                    0.4020109713893821,
                                    0.24278313613402444,
                                    0.221460872876485,
                                    0.13374501960010846,
                                ],
                                [
                                    0.6000248635068458,
                                    0.044769244016560676,
                                    0.33054329229018037,
                                    0.02466260018641309,
                                ],
                                [
                                    0.5934768751069591,
                                    0.3584135439476065,
                                    0.029994969158908,
                                    0.018114611786526395,
                                ],
                                [
                                    0.8857989117804657,
                                    0.06609150727410001,
                                    0.04476924401656064,
                                    0.0033403369288737563,
                                ],
                                [
                                    0.029003085670294082,
                                    0.5944687585955731,
                                    0.017515591856266832,
                                    0.35901256387786595,
                                ],
                                [
                                    0.03223296324084663,
                                    0.6606707252279942,
                                    0.014285714285714278,
                                    0.2928105972454448,
                                ],
                                [
                                    0.030452936689982217,
                                    0.6241859806049992,
                                    0.016065740836578694,
                                    0.3292953418684399,
                                ],
                                [
                                    0.045452787314828574,
                                    0.6091861299801528,
                                    0.023979056888145188,
                                    0.3213820258168734,
                                ],
                                [
                                    0.03151882690171461,
                                    0.6460332570696796,
                                    0.014999850624846305,
                                    0.30744806540375946,
                                ],
                                [
                                    0.04704369073370204,
                                    0.6305083932376921,
                                    0.022388153469271727,
                                    0.3000597625593341,
                                ],
                                [
                                    0.09925042841304593,
                                    0.3496368708786442,
                                    0.12185279408769206,
                                    0.4292599066206178,
                                ],
                                [
                                    0.17221658750052715,
                                    0.6066801899987349,
                                    0.04888663500021086,
                                    0.17221658750052715,
                                ],
                                [
                                    0.1320040105055132,
                                    0.4650203521994338,
                                    0.0890992119952248,
                                    0.31387642529982823,
                                ],
                                [
                                    0.19702369841346767,
                                    0.4000006642914793,
                                    0.1329857797941042,
                                    0.26998985750094884,
                                ],
                                [
                                    0.15608353459278354,
                                    0.5498470838189973,
                                    0.06501968790795445,
                                    0.22904969368026476,
                                ],
                                [
                                    0.23296379503282033,
                                    0.4729668233789605,
                                    0.09704568317475157,
                                    0.19702369841346765,
                                ],
                                [
                                    0.09925042841304593,
                                    0.12185279408769206,
                                    0.3496368708786442,
                                    0.4292599066206178,
                                ],
                                [
                                    0.40000066429147924,
                                    0.4910930800016869,
                                    0.048886635000210864,
                                    0.060019620706622985,
                                ],
                                [
                                    0.23425338955785463,
                                    0.28760006882131667,
                                    0.2146339097338355,
                                    0.2635126318869932,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.33350381797090056,
                                    0.40945286290900873,
                                    0.11538348132078954,
                                    0.1416598377993011,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.029003085670294148,
                                    0.017515591856266877,
                                    0.5944687585955729,
                                    0.359012563877866,
                                ],
                                [
                                    0.6091861299801529,
                                    0.3679007033434344,
                                    0.014285714285714294,
                                    0.008627452390698502,
                                ],
                                [
                                    0.2894398855253776,
                                    0.17479901826375924,
                                    0.3340319587404895,
                                    0.20172913747037366,
                                ],
                                [
                                    0.4320059405482901,
                                    0.03223296324084667,
                                    0.4985622152487361,
                                    0.0371988809621271,
                                ],
                                [
                                    0.48090578924295463,
                                    0.2904294260773413,
                                    0.1425660550229125,
                                    0.08609872965679159,
                                ],
                                [
                                    0.7177799888219099,
                                    0.05355522649838601,
                                    0.21278816697511635,
                                    0.01587661770458776,
                                ],
                                [
                                    0.014285714285714282,
                                    0.29281059724544484,
                                    0.03223296324084663,
                                    0.6606707252279942,
                                ],
                                [
                                    0.017515591856266836,
                                    0.35901256387786606,
                                    0.02900308567029408,
                                    0.594468758595573,
                                ],
                                [
                                    0.014999850624846305,
                                    0.30744806540375946,
                                    0.03151882690171461,
                                    0.6460332570696796,
                                ],
                                [
                                    0.022388153469271727,
                                    0.3000597625593341,
                                    0.04704369073370204,
                                    0.6305083932376921,
                                ],
                                [
                                    0.01606574083657869,
                                    0.32929534186843984,
                                    0.030452936689982224,
                                    0.6241859806049993,
                                ],
                                [
                                    0.023979056888145184,
                                    0.32138202581687336,
                                    0.04545278731482858,
                                    0.6091861299801529,
                                ],
                                [
                                    0.04888663500021085,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.6066801899987349,
                                ],
                                [
                                    0.12185279408769206,
                                    0.4292599066206178,
                                    0.09925042841304593,
                                    0.3496368708786442,
                                ],
                                [
                                    0.06501968790795447,
                                    0.2290496936802648,
                                    0.1560835345927835,
                                    0.5498470838189972,
                                ],
                                [
                                    0.09704568317475158,
                                    0.19702369841346767,
                                    0.23296379503282028,
                                    0.47296682337896045,
                                ],
                                [
                                    0.08909921199522483,
                                    0.31387642529982834,
                                    0.13200401050551316,
                                    0.46502035219943366,
                                ],
                                [
                                    0.13298577979410423,
                                    0.2699898575009489,
                                    0.19702369841346765,
                                    0.40000066429147924,
                                ],
                                [
                                    0.04888663500021088,
                                    0.060019620706623,
                                    0.40000066429147924,
                                    0.4910930800016869,
                                ],
                                [
                                    0.3496368708786442,
                                    0.4292599066206178,
                                    0.09925042841304595,
                                    0.12185279408769208,
                                ],
                                [
                                    0.11538348132078957,
                                    0.14165983779930114,
                                    0.33350381797090056,
                                    0.40945286290900873,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.2146339097338355,
                                    0.2635126318869932,
                                    0.23425338955785463,
                                    0.28760006882131667,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.014285714285714332,
                                    0.008627452390698523,
                                    0.6091861299801528,
                                    0.3679007033434344,
                                ],
                                [
                                    0.594468758595573,
                                    0.35901256387786606,
                                    0.029003085670294113,
                                    0.017515591856266857,
                                ],
                                [
                                    0.14256605502291256,
                                    0.08609872965679162,
                                    0.4809057892429545,
                                    0.2904294260773413,
                                ],
                                [
                                    0.21278816697511643,
                                    0.015876617704587766,
                                    0.7177799888219099,
                                    0.053555226498386004,
                                ],
                                [
                                    0.3340319587404895,
                                    0.20172913747037366,
                                    0.2894398855253775,
                                    0.1747990182637592,
                                ],
                                [
                                    0.4985622152487361,
                                    0.0371988809621271,
                                    0.43200594054829006,
                                    0.03223296324084667,
                                ],
                                [
                                    0.0030056212142792684,
                                    0.061605441999268436,
                                    0.043513056312281646,
                                    0.8918758804741707,
                                ],
                                [
                                    0.006235498784831823,
                                    0.12780740863168966,
                                    0.04028317874172909,
                                    0.8256739138417495,
                                ],
                                [
                                    0.0031558708474340763,
                                    0.06468506993666623,
                                    0.043362806679126835,
                                    0.8887962525367729,
                                ],
                                [
                                    0.004710321631104821,
                                    0.06313061915299548,
                                    0.06472152257186894,
                                    0.8674375366440308,
                                ],
                                [
                                    0.004221761059166463,
                                    0.08653234640134658,
                                    0.04229691646739445,
                                    0.8669489760720925,
                                ],
                                [
                                    0.006301225049978281,
                                    0.08445288241053477,
                                    0.06313061915299549,
                                    0.8461152733864915,
                                ],
                                [
                                    0.010285429507595303,
                                    0.03623324801896572,
                                    0.21081779299314268,
                                    0.7426635294802962,
                                ],
                                [
                                    0.08325158859507652,
                                    0.29327656713905637,
                                    0.1378516339056615,
                                    0.48562021036020564,
                                ],
                                [
                                    0.013679718732537581,
                                    0.048190563291470104,
                                    0.2074235037682004,
                                    0.7307062142077919,
                                ],
                                [
                                    0.020417779487298088,
                                    0.041452502536709596,
                                    0.30959169872027376,
                                    0.6285380192557185,
                                ],
                                [
                                    0.03775924281980794,
                                    0.13301729491103362,
                                    0.18334397968093005,
                                    0.6458794825882284,
                                ],
                                [
                                    0.05635787610665073,
                                    0.11441866162419083,
                                    0.27365160210092115,
                                    0.5555718601682373,
                                ],
                                [
                                    0.010285429507595319,
                                    0.012627737168817536,
                                    0.4386018697840948,
                                    0.5384849635394924,
                                ],
                                [
                                    0.3110356653860286,
                                    0.38186802308281226,
                                    0.13785163390566152,
                                    0.16924467762549755,
                                ],
                                [
                                    0.024275932746461292,
                                    0.02980430695906582,
                                    0.42461136654522885,
                                    0.5213083937492441,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.12352636115950723,
                                    0.1516571010467579,
                                    0.3253609381321829,
                                    0.399455599661552,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.003005621214279301,
                                    0.001815159775146765,
                                    0.6204662230515878,
                                    0.3747129959589861,
                                ],
                                [
                                    0.583188665524138,
                                    0.3522002712623143,
                                    0.04028317874172913,
                                    0.02432788447181861,
                                ],
                                [
                                    0.029994969158907994,
                                    0.01811461178652639,
                                    0.5934768751069591,
                                    0.3584135439476065,
                                ],
                                [
                                    0.04476924401656063,
                                    0.0033403369288737554,
                                    0.8857989117804657,
                                    0.06609150727410001,
                                ],
                                [
                                    0.22146087287648505,
                                    0.13374501960010846,
                                    0.4020109713893821,
                                    0.24278313613402444,
                                ],
                                [
                                    0.3305432922901804,
                                    0.024662600186413093,
                                    0.6000248635068458,
                                    0.044769244016560676,
                                ],
                                [
                                    0.055950408449131114,
                                    0.8100066841343474,
                                    0.008660654764416588,
                                    0.12538225265210484,
                                ],
                                [
                                    0.060436473723962644,
                                    0.8749524630624896,
                                    0.004174589489585057,
                                    0.06043647372396263,
                                ],
                                [
                                    0.05874734383952739,
                                    0.8504985486999596,
                                    0.005863719374020309,
                                    0.08489038808649274,
                                ],
                                [
                                    0.06313061915299549,
                                    0.8461152733864915,
                                    0.006301225049978281,
                                    0.08445288241053477,
                                ],
                                [
                                    0.060227787900079655,
                                    0.87193127131582,
                                    0.004383275313468048,
                                    0.06345766547063221,
                                ],
                                [
                                    0.06472152257186894,
                                    0.8674375366440308,
                                    0.0047103216311048185,
                                    0.06313061915299543,
                                ],
                                [
                                    0.19146590371757707,
                                    0.4320059405482901,
                                    0.11563040781358204,
                                    0.26089774792055076,
                                ],
                                [
                                    0.29281059724544484,
                                    0.6606707252279942,
                                    0.014285714285714287,
                                    0.032232963240846645,
                                ],
                                [
                                    0.2546514666979559,
                                    0.5745719955712026,
                                    0.05244484483320324,
                                    0.11833169289763822,
                                ],
                                [
                                    0.27365160210092115,
                                    0.5555718601682373,
                                    0.056357876106650696,
                                    0.11441866162419075,
                                ],
                                [
                                    0.2880961761281938,
                                    0.6500335418477986,
                                    0.019000135402965315,
                                    0.04287014662104229,
                                ],
                                [
                                    0.3095916987202738,
                                    0.6285380192557186,
                                    0.020417779487298063,
                                    0.04145250253670954,
                                ],
                                [
                                    0.19146590371757705,
                                    0.11563040781358208,
                                    0.43200594054829006,
                                    0.2608977479205508,
                                ],
                                [
                                    0.6091861299801529,
                                    0.3679007033434344,
                                    0.014285714285714284,
                                    0.008627452390698495,
                                ],
                                [
                                    0.45190270357266055,
                                    0.27291383422107446,
                                    0.1715691406932066,
                                    0.10361432151305844,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.5897543374783221,
                                    0.356165422816151,
                                    0.03371750678754512,
                                    0.020362732917981925,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.055950408449131114,
                                    0.008660654764416591,
                                    0.8100066841343474,
                                    0.12538225265210487,
                                ],
                                [
                                    0.8617825030938935,
                                    0.1333967159166805,
                                    0.00417458948958506,
                                    0.0006461914998409586,
                                ],
                                [
                                    0.5583640306659279,
                                    0.08643007685747857,
                                    0.30759306191755054,
                                    0.0476128305590429,
                                ],
                                [
                                    0.6000248635068458,
                                    0.044769244016560676,
                                    0.33054329229018037,
                                    0.02466260018641309,
                                ],
                                [
                                    0.8242962597425606,
                                    0.12759415931200496,
                                    0.041660832840917886,
                                    0.006448748104516508,
                                ],
                                [
                                    0.8857989117804657,
                                    0.06609150727410001,
                                    0.04476924401656064,
                                    0.0033403369288737563,
                                ],
                                [
                                    0.04028317874172912,
                                    0.5831886655241381,
                                    0.02432788447181859,
                                    0.3522002712623142,
                                ],
                                [
                                    0.04476924401656064,
                                    0.6481344444522802,
                                    0.01984181919698706,
                                    0.287254492334172,
                                ],
                                [
                                    0.04229691646739447,
                                    0.6123420008275869,
                                    0.022314146746153233,
                                    0.32304693595886536,
                                ],
                                [
                                    0.045452787314828574,
                                    0.6091861299801528,
                                    0.023979056888145188,
                                    0.3213820258168734,
                                ],
                                [
                                    0.043777360527946736,
                                    0.6337747234434474,
                                    0.02083370268560097,
                                    0.3016142133430048,
                                ],
                                [
                                    0.04704369073370204,
                                    0.6305083932376921,
                                    0.022388153469271727,
                                    0.3000597625593341,
                                ],
                                [
                                    0.13785163390566155,
                                    0.3110356653860286,
                                    0.16924467762549758,
                                    0.38186802308281226,
                                ],
                                [
                                    0.2391963274335293,
                                    0.5397004500657328,
                                    0.06789998409762983,
                                    0.15320323840310818,
                                ],
                                [
                                    0.18334397968093014,
                                    0.41368038302401683,
                                    0.12375233185022899,
                                    0.27922330544482404,
                                ],
                                [
                                    0.19702369841346767,
                                    0.4000006642914793,
                                    0.1329857797941042,
                                    0.26998985750094884,
                                ],
                                [
                                    0.21678868911116805,
                                    0.4891419293006128,
                                    0.09030762241999107,
                                    0.20376175916822814,
                                ],
                                [
                                    0.23296379503282033,
                                    0.4729668233789605,
                                    0.09704568317475157,
                                    0.19702369841346765,
                                ],
                                [
                                    0.1378516339056615,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.29327656713905637,
                                ],
                                [
                                    0.5555718601682372,
                                    0.33552188412492884,
                                    0.06789998409762982,
                                    0.04100627160920404,
                                ],
                                [
                                    0.32536093813218286,
                                    0.19649252024698846,
                                    0.29811090613368424,
                                    0.18003563548714444,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.46321257203784433,
                                    0.27974410884206496,
                                    0.16025927222802275,
                                    0.09678404689206792,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.04028317874172919,
                                    0.0062354987848318374,
                                    0.8256739138417494,
                                    0.12780740863168963,
                                ],
                                [
                                    0.8461152733864915,
                                    0.13097155993709575,
                                    0.01984181919698707,
                                    0.0030713474794257256,
                                ],
                                [
                                    0.40201097138938213,
                                    0.06222793239975468,
                                    0.4639461211940964,
                                    0.07181497501676679,
                                ],
                                [
                                    0.4320059405482901,
                                    0.03223296324084667,
                                    0.4985622152487361,
                                    0.0371988809621271,
                                ],
                                [
                                    0.6679432004660149,
                                    0.10339201485428108,
                                    0.1980138921174637,
                                    0.030650892562240396,
                                ],
                                [
                                    0.7177799888219099,
                                    0.05355522649838601,
                                    0.21278816697511635,
                                    0.01587661770458776,
                                ],
                                [
                                    0.019841819196987062,
                                    0.28725449233417205,
                                    0.04476924401656064,
                                    0.6481344444522802,
                                ],
                                [
                                    0.024327884471818596,
                                    0.3522002712623143,
                                    0.04028317874172911,
                                    0.583188665524138,
                                ],
                                [
                                    0.02083370268560097,
                                    0.3016142133430048,
                                    0.043777360527946736,
                                    0.6337747234434474,
                                ],
                                [
                                    0.022388153469271727,
                                    0.3000597625593341,
                                    0.04704369073370204,
                                    0.6305083932376921,
                                ],
                                [
                                    0.02231414674615323,
                                    0.3230469359588653,
                                    0.042296916467394474,
                                    0.6123420008275869,
                                ],
                                [
                                    0.023979056888145184,
                                    0.32138202581687336,
                                    0.04545278731482858,
                                    0.6091861299801529,
                                ],
                                [
                                    0.06789998409762983,
                                    0.15320323840310818,
                                    0.2391963274335293,
                                    0.5397004500657328,
                                ],
                                [
                                    0.16924467762549758,
                                    0.38186802308281226,
                                    0.13785163390566155,
                                    0.3110356653860286,
                                ],
                                [
                                    0.0903076224199911,
                                    0.20376175916822817,
                                    0.21678868911116803,
                                    0.4891419293006127,
                                ],
                                [
                                    0.09704568317475158,
                                    0.19702369841346767,
                                    0.23296379503282028,
                                    0.47296682337896045,
                                ],
                                [
                                    0.12375233185022903,
                                    0.2792233054448241,
                                    0.1833439796809301,
                                    0.4136803830240168,
                                ],
                                [
                                    0.13298577979410423,
                                    0.2699898575009489,
                                    0.19702369841346765,
                                    0.40000066429147924,
                                ],
                                [
                                    0.06789998409762983,
                                    0.041006271609204045,
                                    0.5555718601682372,
                                    0.33552188412492884,
                                ],
                                [
                                    0.48562021036020564,
                                    0.29327656713905637,
                                    0.1378516339056615,
                                    0.08325158859507652,
                                ],
                                [
                                    0.16025927222802278,
                                    0.09678404689206793,
                                    0.46321257203784433,
                                    0.27974410884206496,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.29811090613368424,
                                    0.18003563548714444,
                                    0.32536093813218286,
                                    0.19649252024698846,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.01984181919698712,
                                    0.0030713474794257334,
                                    0.8461152733864914,
                                    0.13097155993709575,
                                ],
                                [
                                    0.8256739138417495,
                                    0.12780740863168966,
                                    0.04028317874172914,
                                    0.0062354987848318305,
                                ],
                                [
                                    0.19801389211746379,
                                    0.030650892562240406,
                                    0.6679432004660147,
                                    0.10339201485428107,
                                ],
                                [
                                    0.21278816697511643,
                                    0.015876617704587766,
                                    0.7177799888219099,
                                    0.053555226498386004,
                                ],
                                [
                                    0.4639461211940964,
                                    0.07181497501676679,
                                    0.4020109713893821,
                                    0.062227932399754673,
                                ],
                                [
                                    0.4985622152487361,
                                    0.0371988809621271,
                                    0.43200594054829006,
                                    0.03223296324084667,
                                ],
                                [
                                    0.004174589489585058,
                                    0.060436473723962644,
                                    0.060436473723962644,
                                    0.8749524630624896,
                                ],
                                [
                                    0.008660654764416591,
                                    0.12538225265210487,
                                    0.055950408449131114,
                                    0.8100066841343474,
                                ],
                                [
                                    0.004383275313468051,
                                    0.06345766547063225,
                                    0.060227787900079655,
                                    0.87193127131582,
                                ],
                                [
                                    0.004710321631104821,
                                    0.06313061915299548,
                                    0.06472152257186894,
                                    0.8674375366440308,
                                ],
                                [
                                    0.005863719374020309,
                                    0.08489038808649274,
                                    0.05874734383952739,
                                    0.8504985486999596,
                                ],
                                [
                                    0.006301225049978281,
                                    0.08445288241053477,
                                    0.06313061915299549,
                                    0.8461152733864915,
                                ],
                                [
                                    0.014285714285714315,
                                    0.03223296324084671,
                                    0.29281059724544484,
                                    0.6606707252279942,
                                ],
                                [
                                    0.11563040781358208,
                                    0.2608977479205508,
                                    0.19146590371757705,
                                    0.43200594054829006,
                                ],
                                [
                                    0.01900013540296534,
                                    0.04287014662104235,
                                    0.28809617612819377,
                                    0.6500335418477985,
                                ],
                                [
                                    0.020417779487298088,
                                    0.041452502536709596,
                                    0.30959169872027376,
                                    0.6285380192557185,
                                ],
                                [
                                    0.05244484483320327,
                                    0.11833169289763829,
                                    0.25465146669795585,
                                    0.5745719955712025,
                                ],
                                [
                                    0.05635787610665073,
                                    0.11441866162419083,
                                    0.27365160210092115,
                                    0.5555718601682373,
                                ],
                                [
                                    0.014285714285714332,
                                    0.008627452390698523,
                                    0.6091861299801528,
                                    0.3679007033434344,
                                ],
                                [
                                    0.43200594054829006,
                                    0.2608977479205508,
                                    0.19146590371757702,
                                    0.11563040781358205,
                                ],
                                [
                                    0.03371750678754516,
                                    0.02036273291798195,
                                    0.589754337478322,
                                    0.35616542281615093,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.17156914069320664,
                                    0.10361432151305847,
                                    0.45190270357266044,
                                    0.27291383422107446,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.004174589489585101,
                                    0.0006461914998409649,
                                    0.8617825030938935,
                                    0.1333967159166805,
                                ],
                                [
                                    0.8100066841343474,
                                    0.12538225265210487,
                                    0.05595040844913115,
                                    0.008660654764416596,
                                ],
                                [
                                    0.04166083284091788,
                                    0.006448748104516506,
                                    0.8242962597425606,
                                    0.12759415931200496,
                                ],
                                [
                                    0.04476924401656063,
                                    0.0033403369288737554,
                                    0.8857989117804657,
                                    0.06609150727410001,
                                ],
                                [
                                    0.3075930619175506,
                                    0.047612830559042904,
                                    0.5583640306659279,
                                    0.08643007685747857,
                                ],
                                [
                                    0.3305432922901804,
                                    0.024662600186413093,
                                    0.6000248635068458,
                                    0.044769244016560676,
                                ],
                                [
                                    0.004174589489585101,
                                    0.8617825030938935,
                                    0.0006461914998409646,
                                    0.13339671591668045,
                                ],
                                [
                                    0.004509305204179589,
                                    0.9308796315822727,
                                    0.0003114757852464765,
                                    0.06429958742830122,
                                ],
                                [
                                    0.0042773794509485845,
                                    0.8830019763900693,
                                    0.0005434015384774811,
                                    0.1121772426205046,
                                ],
                                [
                                    0.06160544199926848,
                                    0.8256739138417495,
                                    0.00782640220370529,
                                    0.1048942419552768,
                                ],
                                [
                                    0.004501635807221871,
                                    0.929296397560357,
                                    0.00031914518220419467,
                                    0.06588282145021697,
                                ],
                                [
                                    0.06483531956982104,
                                    0.8689627137977578,
                                    0.004596524633152734,
                                    0.06160544199926842,
                                ],
                                [
                                    0.014285714285714264,
                                    0.609186129980153,
                                    0.00862745239069848,
                                    0.36790070334343433,
                                ],
                                [
                                    0.02184727646468036,
                                    0.9316340460087588,
                                    0.0010658902117323865,
                                    0.04545278731482855,
                                ],
                                [
                                    0.016607842140288268,
                                    0.7082086956534467,
                                    0.006305324536124478,
                                    0.26887813767014057,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.02167401713013965,
                                    0.9242457431643334,
                                    0.0012391495462730955,
                                    0.052841090159253944,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.014285714285714282,
                                    0.29281059724544484,
                                    0.03223296324084663,
                                    0.6606707252279942,
                                ],
                                [
                                    0.045452787314828526,
                                    0.9316340460087588,
                                    0.0010658902117323876,
                                    0.02184727646468039,
                                ],
                                [
                                    0.023857007454177532,
                                    0.48899092208027284,
                                    0.022661670072383382,
                                    0.4644904003931662,
                                ],
                                [
                                    0.3436032519089528,
                                    0.16924467762549755,
                                    0.3263872698834753,
                                    0.1607648005820743,
                                ],
                                [
                                    0.04473865097569651,
                                    0.9169965778504441,
                                    0.0017800265508644115,
                                    0.03648474462299504,
                                ],
                                [
                                    0.6443534877873862,
                                    0.3173817410387544,
                                    0.025637034005041956,
                                    0.012627737168817495,
                                ],
                                [
                                    0.004174589489585058,
                                    0.060436473723962644,
                                    0.060436473723962644,
                                    0.8749524630624896,
                                ],
                                [
                                    0.06429958742830123,
                                    0.9308796315822727,
                                    0.00031147578524647355,
                                    0.004509305204179546,
                                ],
                                [
                                    0.022638754587383344,
                                    0.3277463568997842,
                                    0.04197230862616436,
                                    0.607642579886668,
                                ],
                                [
                                    0.32605722701534895,
                                    0.024327884471818613,
                                    0.6045109287816773,
                                    0.045103959731155156,
                                ],
                                [
                                    0.06292193332911244,
                                    0.9109350224239222,
                                    0.001689129884435252,
                                    0.024453914362530086,
                                ],
                                [
                                    0.9062402713252077,
                                    0.06761668442782702,
                                    0.024327884471818592,
                                    0.0018151597751467471,
                                ],
                                [
                                    0.0030056212142793013,
                                    0.6204662230515879,
                                    0.0018151597751467643,
                                    0.374712995958986,
                                ],
                                [
                                    0.003340336928873789,
                                    0.6895633515399671,
                                    0.0014804440605522763,
                                    0.3056158674706068,
                                ],
                                [
                                    0.0030796279373977798,
                                    0.6357438208259161,
                                    0.0017411530520282858,
                                    0.35943539818465786,
                                ],
                                [
                                    0.0443546901677408,
                                    0.594468758595573,
                                    0.025077154035232963,
                                    0.33609939720145315,
                                ],
                                [
                                    0.003303884293671066,
                                    0.6820382419962038,
                                    0.0015168966957549994,
                                    0.3131409770143702,
                                ],
                                [
                                    0.04758456773829336,
                                    0.6377575585515814,
                                    0.02184727646468041,
                                    0.2928105972454448,
                                ],
                                [
                                    0.010285429507595268,
                                    0.4386018697840949,
                                    0.012627737168817476,
                                    0.5384849635394924,
                                ],
                                [
                                    0.017846991686561363,
                                    0.7610497858127007,
                                    0.005066174989851383,
                                    0.21603704751088665,
                                ],
                                [
                                    0.011957315272504373,
                                    0.509896143106667,
                                    0.010955851403908371,
                                    0.46719069021692033,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.017023490262355754,
                                    0.7259331906175536,
                                    0.005889676414056987,
                                    0.2511536427060337,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.010285429507595279,
                                    0.2108177929931427,
                                    0.03623324801896564,
                                    0.7426635294802963,
                                ],
                                [
                                    0.041452502536709526,
                                    0.8496412417564566,
                                    0.005066174989851388,
                                    0.10384008071698246,
                                ],
                                [
                                    0.01717656979024828,
                                    0.35206371612374654,
                                    0.029342107736312635,
                                    0.6014176063496925,
                                ],
                                [
                                    0.24738749182630274,
                                    0.12185279408769208,
                                    0.42260302996612537,
                                    0.20815668411987978,
                                ],
                                [
                                    0.038058213311767244,
                                    0.7800693718939177,
                                    0.00846046421479367,
                                    0.1734119505795214,
                                ],
                                [
                                    0.5481377277047361,
                                    0.2699898575009489,
                                    0.12185279408769208,
                                    0.06001962070662299,
                                ],
                                [
                                    0.0030056212142792753,
                                    0.04351305631228175,
                                    0.06160544199926843,
                                    0.8918758804741705,
                                ],
                                [
                                    0.06313061915299545,
                                    0.9139562141705918,
                                    0.0014804440605522618,
                                    0.021432722615860534,
                                ],
                                [
                                    0.016299452011379653,
                                    0.23597084351847272,
                                    0.04831161120216805,
                                    0.6994180932679795,
                                ],
                                [
                                    0.2347547036735855,
                                    0.01751559185626686,
                                    0.6958134521234407,
                                    0.05191625234670691,
                                ],
                                [
                                    0.05658263075310876,
                                    0.8191595090426107,
                                    0.008028432460438944,
                                    0.11622942774384162,
                                ],
                                [
                                    0.8149377479834442,
                                    0.06080439181227527,
                                    0.11563040781358205,
                                    0.008627452390698502,
                                ],
                                [
                                    0.0014804440605522765,
                                    0.3056158674706069,
                                    0.003340336928873789,
                                    0.6895633515399671,
                                ],
                                [
                                    0.001815159775146765,
                                    0.3747129959589861,
                                    0.003005621214279301,
                                    0.6204662230515878,
                                ],
                                [
                                    0.0015168966957549994,
                                    0.3131409770143702,
                                    0.003303884293671066,
                                    0.6820382419962038,
                                ],
                                [
                                    0.02184727646468041,
                                    0.2928105972454448,
                                    0.04758456773829336,
                                    0.6377575585515814,
                                ],
                                [
                                    0.0017411530520282858,
                                    0.35943539818465786,
                                    0.0030796279373977798,
                                    0.6357438208259161,
                                ],
                                [
                                    0.025077154035232963,
                                    0.33609939720145315,
                                    0.0443546901677408,
                                    0.594468758595573,
                                ],
                                [
                                    0.005066174989851382,
                                    0.21603704751088662,
                                    0.017846991686561363,
                                    0.7610497858127007,
                                ],
                                [
                                    0.012627737168817476,
                                    0.5384849635394924,
                                    0.010285429507595268,
                                    0.4386018697840949,
                                ],
                                [
                                    0.005889676414056989,
                                    0.25115364270603374,
                                    0.017023490262355754,
                                    0.7259331906175536,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.010955851403908371,
                                    0.46719069021692033,
                                    0.011957315272504373,
                                    0.509896143106667,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.00506617498985139,
                                    0.10384008071698249,
                                    0.041452502536709526,
                                    0.8496412417564566,
                                ],
                                [
                                    0.03623324801896564,
                                    0.7426635294802963,
                                    0.010285429507595279,
                                    0.21081779299314274,
                                ],
                                [
                                    0.008460464214793668,
                                    0.17341195057952138,
                                    0.038058213311767244,
                                    0.7800693718939177,
                                ],
                                [
                                    0.12185279408769206,
                                    0.06001962070662298,
                                    0.5481377277047361,
                                    0.2699898575009489,
                                ],
                                [
                                    0.029342107736312635,
                                    0.6014176063496925,
                                    0.01717656979024828,
                                    0.35206371612374654,
                                ],
                                [
                                    0.42260302996612537,
                                    0.20815668411987978,
                                    0.24738749182630274,
                                    0.12185279408769208,
                                ],
                                [
                                    0.0014804440605522657,
                                    0.02143272261586059,
                                    0.06313061915299543,
                                    0.9139562141705917,
                                ],
                                [
                                    0.061605441999268436,
                                    0.8918758804741707,
                                    0.003005621214279272,
                                    0.043513056312281695,
                                ],
                                [
                                    0.008028432460438942,
                                    0.1162294277438416,
                                    0.05658263075310876,
                                    0.8191595090426107,
                                ],
                                [
                                    0.11563040781358204,
                                    0.0086274523906985,
                                    0.8149377479834442,
                                    0.06080439181227527,
                                ],
                                [
                                    0.04831161120216805,
                                    0.6994180932679795,
                                    0.016299452011379653,
                                    0.23597084351847272,
                                ],
                                [
                                    0.6958134521234407,
                                    0.05191625234670691,
                                    0.2347547036735855,
                                    0.01751559185626686,
                                ],
                                [
                                    0.0003114757852464766,
                                    0.06429958742830123,
                                    0.004509305204179589,
                                    0.9308796315822727,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.1333967159166805,
                                    0.004174589489585101,
                                    0.8617825030938935,
                                ],
                                [
                                    0.0003191451822041947,
                                    0.06588282145021698,
                                    0.004501635807221871,
                                    0.929296397560357,
                                ],
                                [
                                    0.0045965246331527345,
                                    0.061605441999268436,
                                    0.06483531956982104,
                                    0.8689627137977578,
                                ],
                                [
                                    0.0005434015384774811,
                                    0.1121772426205046,
                                    0.0042773794509485845,
                                    0.8830019763900693,
                                ],
                                [
                                    0.00782640220370529,
                                    0.1048942419552768,
                                    0.06160544199926848,
                                    0.8256739138417495,
                                ],
                                [
                                    0.0010658902117323885,
                                    0.04545278731482864,
                                    0.021847276464680356,
                                    0.9316340460087587,
                                ],
                                [
                                    0.008627452390698481,
                                    0.3679007033434344,
                                    0.014285714285714263,
                                    0.6091861299801529,
                                ],
                                [
                                    0.0012391495462730972,
                                    0.05284109015925401,
                                    0.021674017130139646,
                                    0.9242457431643333,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.006305324536124479,
                                    0.2688781376701406,
                                    0.016607842140288265,
                                    0.7082086956534467,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.001065890211732391,
                                    0.021847276464680463,
                                    0.045452787314828526,
                                    0.9316340460087587,
                                ],
                                [
                                    0.03223296324084663,
                                    0.6606707252279942,
                                    0.014285714285714278,
                                    0.2928105972454448,
                                ],
                                [
                                    0.0017800265508644145,
                                    0.0364847446229951,
                                    0.0447386509756965,
                                    0.916996577850444,
                                ],
                                [
                                    0.025637034005041998,
                                    0.012627737168817516,
                                    0.6443534877873861,
                                    0.3173817410387544,
                                ],
                                [
                                    0.022661670072383382,
                                    0.46449040039316625,
                                    0.023857007454177532,
                                    0.48899092208027284,
                                ],
                                [
                                    0.32638726988347533,
                                    0.16076480058207432,
                                    0.3436032519089528,
                                    0.16924467762549755,
                                ],
                                [
                                    0.0003114757852464766,
                                    0.004509305204179589,
                                    0.06429958742830123,
                                    0.9308796315822727,
                                ],
                                [
                                    0.060436473723962644,
                                    0.8749524630624896,
                                    0.00417458948958506,
                                    0.060436473723962686,
                                ],
                                [
                                    0.0016891298844352522,
                                    0.02445391436253009,
                                    0.06292193332911244,
                                    0.9109350224239222,
                                ],
                                [
                                    0.024327884471818596,
                                    0.0018151597751467474,
                                    0.9062402713252077,
                                    0.06761668442782702,
                                ],
                                [
                                    0.04197230862616436,
                                    0.607642579886668,
                                    0.022638754587383344,
                                    0.3277463568997842,
                                ],
                                [
                                    0.6045109287816773,
                                    0.045103959731155156,
                                    0.32605722701534895,
                                    0.024327884471818613,
                                ],
                                [
                                    0.019841819196987024,
                                    0.8461152733864915,
                                    0.0030713474794257173,
                                    0.1309715599370957,
                                ],
                                [
                                    0.021432722615860485,
                                    0.9139562141705918,
                                    0.0014804440605522581,
                                    0.06313061915299543,
                                ],
                                [
                                    0.020330379768925377,
                                    0.8669489760720925,
                                    0.002582786907487367,
                                    0.11013785725149472,
                                ],
                                [
                                    0.06160544199926848,
                                    0.8256739138417495,
                                    0.00782640220370529,
                                    0.1048942419552768,
                                ],
                                [
                                    0.021396269980657762,
                                    0.912401763386921,
                                    0.001516896695754981,
                                    0.06468506993666617,
                                ],
                                [
                                    0.06483531956982104,
                                    0.8689627137977578,
                                    0.004596524633152734,
                                    0.06160544199926842,
                                ],
                                [
                                    0.06789998409762985,
                                    0.5555718601682373,
                                    0.04100627160920403,
                                    0.3355218841249287,
                                ],
                                [
                                    0.10384008071698249,
                                    0.8496412417564566,
                                    0.0050661749898513915,
                                    0.04145250253670954,
                                ],
                                [
                                    0.07893705520550652,
                                    0.6458794825882285,
                                    0.029969200501327356,
                                    0.24521426170493768,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.10301657929277688,
                                    0.8429031810016961,
                                    0.005889676414056999,
                                    0.04819056329147004,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.06789998409762983,
                                    0.2391963274335293,
                                    0.15320323840310818,
                                    0.5397004500657328,
                                ],
                                [
                                    0.21603704751088662,
                                    0.7610497858127007,
                                    0.00506617498985139,
                                    0.017846991686561387,
                                ],
                                [
                                    0.11339232987289838,
                                    0.399455599661552,
                                    0.1077108926278396,
                                    0.37944117783771,
                                ],
                                [
                                    0.3436032519089528,
                                    0.16924467762549755,
                                    0.3263872698834753,
                                    0.1607648005820743,
                                ],
                                [
                                    0.21264275828594434,
                                    0.7490924705401962,
                                    0.008460464214793672,
                                    0.02980430695906578,
                                ],
                                [
                                    0.6443534877873862,
                                    0.3173817410387544,
                                    0.025637034005041956,
                                    0.012627737168817495,
                                ],
                                [
                                    0.019841819196987062,
                                    0.04476924401656064,
                                    0.28725449233417205,
                                    0.6481344444522802,
                                ],
                                [
                                    0.3056158674706069,
                                    0.6895633515399671,
                                    0.0014804440605522622,
                                    0.0033403369288737567,
                                ],
                                [
                                    0.10760197535314313,
                                    0.2427831361340244,
                                    0.19949433617801599,
                                    0.45012055233481646,
                                ],
                                [
                                    0.32605722701534895,
                                    0.024327884471818613,
                                    0.6045109287816773,
                                    0.045103959731155156,
                                ],
                                [
                                    0.2990678790707202,
                                    0.6747890766823145,
                                    0.008028432460438944,
                                    0.018114611786526392,
                                ],
                                [
                                    0.9062402713252077,
                                    0.06761668442782702,
                                    0.024327884471818592,
                                    0.0018151597751467471,
                                ],
                                [
                                    0.014285714285714264,
                                    0.609186129980153,
                                    0.00862745239069848,
                                    0.36790070334343433,
                                ],
                                [
                                    0.01587661770458772,
                                    0.6770270707642532,
                                    0.007036548971825021,
                                    0.30005976255933403,
                                ],
                                [
                                    0.014637468158314628,
                                    0.6241859806049992,
                                    0.008275698518098116,
                                    0.352900852718588,
                                ],
                                [
                                    0.0443546901677408,
                                    0.594468758595573,
                                    0.025077154035232963,
                                    0.33609939720145315,
                                ],
                                [
                                    0.015703358370047014,
                                    0.6696387679198278,
                                    0.00720980830636573,
                                    0.30744806540375946,
                                ],
                                [
                                    0.04758456773829336,
                                    0.6377575585515814,
                                    0.02184727646468041,
                                    0.2928105972454448,
                                ],
                                [
                                    0.04888663500021088,
                                    0.40000066429147924,
                                    0.060019620706623,
                                    0.4910930800016869,
                                ],
                                [
                                    0.08482673161956351,
                                    0.6940700458796984,
                                    0.02407952408727036,
                                    0.19702369841346767,
                                ],
                                [
                                    0.05683310617973762,
                                    0.46502035219943366,
                                    0.052073149527096255,
                                    0.42607339209373246,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.08091263026700797,
                                    0.6620440506129013,
                                    0.027993625439825896,
                                    0.22904969368026476,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.04888663500021085,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.6066801899987349,
                                ],
                                [
                                    0.19702369841346765,
                                    0.6940700458796984,
                                    0.024079524087270352,
                                    0.0848267316195635,
                                ],
                                [
                                    0.08164021709267812,
                                    0.2876000688213167,
                                    0.1394630054080599,
                                    0.4912967086779453,
                                ],
                                [
                                    0.24738749182630274,
                                    0.12185279408769208,
                                    0.42260302996612537,
                                    0.20815668411987978,
                                ],
                                [
                                    0.18089064550572403,
                                    0.6372369396999609,
                                    0.04021257699501396,
                                    0.1416598377993011,
                                ],
                                [
                                    0.5481377277047361,
                                    0.2699898575009489,
                                    0.12185279408769208,
                                    0.06001962070662299,
                                ],
                                [
                                    0.014285714285714315,
                                    0.03223296324084671,
                                    0.29281059724544484,
                                    0.6606707252279942,
                                ],
                                [
                                    0.3000597625593341,
                                    0.6770270707642532,
                                    0.007036548971825038,
                                    0.01587661770458776,
                                ],
                                [
                                    0.07747127726609312,
                                    0.17479901826375924,
                                    0.229625034265066,
                                    0.5181046702050817,
                                ],
                                [
                                    0.2347547036735855,
                                    0.01751559185626686,
                                    0.6958134521234407,
                                    0.05191625234670691,
                                ],
                                [
                                    0.2689371809836702,
                                    0.6068049588120493,
                                    0.03815913054748896,
                                    0.08609872965679159,
                                ],
                                [
                                    0.8149377479834442,
                                    0.06080439181227527,
                                    0.11563040781358205,
                                    0.008627452390698502,
                                ],
                                [
                                    0.007036548971825022,
                                    0.3000597625593341,
                                    0.01587661770458772,
                                    0.6770270707642532,
                                ],
                                [
                                    0.008627452390698481,
                                    0.3679007033434344,
                                    0.014285714285714263,
                                    0.6091861299801529,
                                ],
                                [
                                    0.00720980830636573,
                                    0.30744806540375946,
                                    0.015703358370047014,
                                    0.6696387679198278,
                                ],
                                [
                                    0.02184727646468041,
                                    0.2928105972454448,
                                    0.04758456773829336,
                                    0.6377575585515814,
                                ],
                                [
                                    0.008275698518098116,
                                    0.352900852718588,
                                    0.014637468158314628,
                                    0.6241859806049992,
                                ],
                                [
                                    0.025077154035232963,
                                    0.33609939720145315,
                                    0.0443546901677408,
                                    0.594468758595573,
                                ],
                                [
                                    0.02407952408727036,
                                    0.19702369841346765,
                                    0.08482673161956351,
                                    0.6940700458796984,
                                ],
                                [
                                    0.060019620706623,
                                    0.4910930800016869,
                                    0.04888663500021088,
                                    0.40000066429147924,
                                ],
                                [
                                    0.0279936254398259,
                                    0.22904969368026482,
                                    0.08091263026700797,
                                    0.6620440506129013,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.052073149527096255,
                                    0.42607339209373246,
                                    0.05683310617973762,
                                    0.46502035219943366,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.02407952408727036,
                                    0.08482673161956351,
                                    0.19702369841346765,
                                    0.6940700458796984,
                                ],
                                [
                                    0.17221658750052715,
                                    0.6066801899987349,
                                    0.04888663500021086,
                                    0.17221658750052715,
                                ],
                                [
                                    0.04021257699501395,
                                    0.14165983779930108,
                                    0.18089064550572403,
                                    0.6372369396999609,
                                ],
                                [
                                    0.12185279408769206,
                                    0.06001962070662298,
                                    0.5481377277047361,
                                    0.2699898575009489,
                                ],
                                [
                                    0.1394630054080599,
                                    0.4912967086779453,
                                    0.08164021709267812,
                                    0.2876000688213167,
                                ],
                                [
                                    0.42260302996612537,
                                    0.20815668411987978,
                                    0.24738749182630274,
                                    0.12185279408769208,
                                ],
                                [
                                    0.007036548971825056,
                                    0.0158766177045878,
                                    0.3000597625593341,
                                    0.6770270707642531,
                                ],
                                [
                                    0.29281059724544484,
                                    0.6606707252279942,
                                    0.0142857142857143,
                                    0.03223296324084667,
                                ],
                                [
                                    0.038159130547488956,
                                    0.08609872965679158,
                                    0.2689371809836702,
                                    0.6068049588120493,
                                ],
                                [
                                    0.11563040781358204,
                                    0.0086274523906985,
                                    0.8149377479834442,
                                    0.06080439181227527,
                                ],
                                [
                                    0.229625034265066,
                                    0.5181046702050817,
                                    0.07747127726609312,
                                    0.17479901826375924,
                                ],
                                [
                                    0.6958134521234407,
                                    0.05191625234670691,
                                    0.2347547036735855,
                                    0.01751559185626686,
                                ],
                                [
                                    0.0014804440605522586,
                                    0.06313061915299545,
                                    0.021432722615860485,
                                    0.9139562141705918,
                                ],
                                [
                                    0.0030713474794257186,
                                    0.13097155993709575,
                                    0.019841819196987024,
                                    0.8461152733864915,
                                ],
                                [
                                    0.0015168966957549812,
                                    0.06468506993666619,
                                    0.021396269980657762,
                                    0.912401763386921,
                                ],
                                [
                                    0.0045965246331527345,
                                    0.061605441999268436,
                                    0.06483531956982104,
                                    0.8689627137977578,
                                ],
                                [
                                    0.002582786907487367,
                                    0.11013785725149472,
                                    0.020330379768925377,
                                    0.8669489760720925,
                                ],
                                [
                                    0.00782640220370529,
                                    0.1048942419552768,
                                    0.06160544199926848,
                                    0.8256739138417495,
                                ],
                                [
                                    0.005066174989851401,
                                    0.04145250253670962,
                                    0.10384008071698247,
                                    0.8496412417564565,
                                ],
                                [
                                    0.041006271609204045,
                                    0.33552188412492884,
                                    0.06789998409762983,
                                    0.5555718601682372,
                                ],
                                [
                                    0.005889676414057006,
                                    0.048190563291470104,
                                    0.10301657929277687,
                                    0.842903181001696,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.029969200501327363,
                                    0.24521426170493774,
                                    0.0789370552055065,
                                    0.6458794825882284,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.005066174989851407,
                                    0.01784699168656145,
                                    0.2160370475108866,
                                    0.7610497858127006,
                                ],
                                [
                                    0.15320323840310818,
                                    0.5397004500657328,
                                    0.06789998409762982,
                                    0.23919632743352925,
                                ],
                                [
                                    0.008460464214793685,
                                    0.02980430695906583,
                                    0.2126427582859443,
                                    0.7490924705401962,
                                ],
                                [
                                    0.025637034005041998,
                                    0.012627737168817516,
                                    0.6443534877873861,
                                    0.3173817410387544,
                                ],
                                [
                                    0.10771089262783962,
                                    0.37944117783771003,
                                    0.11339232987289838,
                                    0.399455599661552,
                                ],
                                [
                                    0.32638726988347533,
                                    0.16076480058207432,
                                    0.3436032519089528,
                                    0.16924467762549755,
                                ],
                                [
                                    0.0014804440605522765,
                                    0.003340336928873789,
                                    0.3056158674706069,
                                    0.6895633515399671,
                                ],
                                [
                                    0.28725449233417205,
                                    0.6481344444522802,
                                    0.019841819196987073,
                                    0.04476924401656067,
                                ],
                                [
                                    0.008028432460438946,
                                    0.018114611786526395,
                                    0.2990678790707202,
                                    0.6747890766823145,
                                ],
                                [
                                    0.024327884471818596,
                                    0.0018151597751467474,
                                    0.9062402713252077,
                                    0.06761668442782702,
                                ],
                                [
                                    0.19949433617801599,
                                    0.45012055233481646,
                                    0.10760197535314313,
                                    0.2427831361340244,
                                ],
                                [
                                    0.6045109287816773,
                                    0.045103959731155156,
                                    0.32605722701534895,
                                    0.024327884471818613,
                                ],
                                [
                                    0.04028317874172909,
                                    0.8256739138417495,
                                    0.00623549878483182,
                                    0.1278074086316896,
                                ],
                                [
                                    0.043513056312281646,
                                    0.8918758804741707,
                                    0.0030056212142792675,
                                    0.06160544199926842,
                                ],
                                [
                                    0.041275062230343,
                                    0.8460042936106749,
                                    0.00524361529621791,
                                    0.10747702886276418,
                                ],
                                [
                                    0.06160544199926848,
                                    0.8256739138417495,
                                    0.00782640220370529,
                                    0.1048942419552768,
                                ],
                                [
                                    0.04343904958916317,
                                    0.8903589837784157,
                                    0.0030796279373977455,
                                    0.06312233869502341,
                                ],
                                [
                                    0.06483531956982104,
                                    0.8689627137977578,
                                    0.004596524633152734,
                                    0.06160544199926842,
                                ],
                                [
                                    0.13785163390566152,
                                    0.4856202103602057,
                                    0.08325158859507649,
                                    0.2932765671390563,
                                ],
                                [
                                    0.2108177929931427,
                                    0.7426635294802963,
                                    0.010285429507595282,
                                    0.03623324801896565,
                                ],
                                [
                                    0.16025927222802275,
                                    0.5645572655657123,
                                    0.06084395027271525,
                                    0.2143395119335498,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.20914590722823362,
                                    0.7367738530662394,
                                    0.01195731527250439,
                                    0.04212292443302265,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.13785163390566155,
                                    0.16924467762549758,
                                    0.3110356653860286,
                                    0.38186802308281226,
                                ],
                                [
                                    0.4386018697840949,
                                    0.5384849635394924,
                                    0.010285429507595284,
                                    0.012627737168817495,
                                ],
                                [
                                    0.23021092203605442,
                                    0.28263700749839593,
                                    0.21867637725563568,
                                    0.26847569320991393,
                                ],
                                [
                                    0.3436032519089528,
                                    0.16924467762549755,
                                    0.3263872698834753,
                                    0.1607648005820743,
                                ],
                                [
                                    0.43171072950144185,
                                    0.5300244993246988,
                                    0.017176569790248286,
                                    0.021088201383611165,
                                ],
                                [
                                    0.6443534877873862,
                                    0.3173817410387544,
                                    0.025637034005041956,
                                    0.012627737168817495,
                                ],
                                [
                                    0.04028317874172911,
                                    0.024327884471818596,
                                    0.583188665524138,
                                    0.3522002712623143,
                                ],
                                [
                                    0.6204662230515878,
                                    0.3747129959589861,
                                    0.0030056212142792714,
                                    0.0018151597751467474,
                                ],
                                [
                                    0.2184552516622058,
                                    0.13192985982496175,
                                    0.4050165926036613,
                                    0.24459829590917115,
                                ],
                                [
                                    0.32605722701534895,
                                    0.024327884471818613,
                                    0.6045109287816773,
                                    0.045103959731155156,
                                ],
                                [
                                    0.6071723922544875,
                                    0.3666845634985472,
                                    0.016299452011379646,
                                    0.009843592235585692,
                                ],
                                [
                                    0.9062402713252077,
                                    0.06761668442782702,
                                    0.024327884471818592,
                                    0.0018151597751467471,
                                ],
                                [
                                    0.029003085670294082,
                                    0.5944687585955731,
                                    0.017515591856266832,
                                    0.35901256387786595,
                                ],
                                [
                                    0.03223296324084663,
                                    0.6606707252279942,
                                    0.014285714285714278,
                                    0.2928105972454448,
                                ],
                                [
                                    0.029717222009426107,
                                    0.6091062267538878,
                                    0.016801455517134807,
                                    0.3443750957195513,
                                ],
                                [
                                    0.0443546901677408,
                                    0.594468758595573,
                                    0.025077154035232963,
                                    0.33609939720145315,
                                ],
                                [
                                    0.03188120936824627,
                                    0.6534609169216286,
                                    0.014637468158314643,
                                    0.3000204055518106,
                                ],
                                [
                                    0.04758456773829336,
                                    0.6377575585515814,
                                    0.02184727646468041,
                                    0.2928105972454448,
                                ],
                                [
                                    0.09925042841304593,
                                    0.3496368708786442,
                                    0.12185279408769206,
                                    0.4292599066206178,
                                ],
                                [
                                    0.17221658750052715,
                                    0.6066801899987349,
                                    0.04888663500021086,
                                    0.17221658750052715,
                                ],
                                [
                                    0.11538348132078953,
                                    0.4064699770583818,
                                    0.10571974117994846,
                                    0.3724268004408802,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.1642701163210004,
                                    0.5786865645589089,
                                    0.0568331061797376,
                                    0.20021021294035304,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.09925042841304593,
                                    0.12185279408769206,
                                    0.3496368708786442,
                                    0.4292599066206178,
                                ],
                                [
                                    0.40000066429147924,
                                    0.4910930800016869,
                                    0.048886635000210864,
                                    0.060019620706622985,
                                ],
                                [
                                    0.16574727473362463,
                                    0.2034930111803702,
                                    0.28314002455806553,
                                    0.34761968952793965,
                                ],
                                [
                                    0.24738749182630274,
                                    0.12185279408769208,
                                    0.42260302996612537,
                                    0.20815668411987978,
                                ],
                                [
                                    0.36724708219901203,
                                    0.45088050300667293,
                                    0.08164021709267812,
                                    0.10023219770163695,
                                ],
                                [
                                    0.5481377277047361,
                                    0.2699898575009489,
                                    0.12185279408769208,
                                    0.06001962070662299,
                                ],
                                [
                                    0.029003085670294148,
                                    0.017515591856266877,
                                    0.5944687585955729,
                                    0.359012563877866,
                                ],
                                [
                                    0.6091861299801529,
                                    0.3679007033434344,
                                    0.014285714285714294,
                                    0.008627452390698502,
                                ],
                                [
                                    0.15728342640749238,
                                    0.09498686912235998,
                                    0.4661884178583747,
                                    0.2815412866117729,
                                ],
                                [
                                    0.2347547036735855,
                                    0.01751559185626686,
                                    0.6958134521234407,
                                    0.05191625234670691,
                                ],
                                [
                                    0.5460005669997741,
                                    0.32974157279594546,
                                    0.0774712772660931,
                                    0.046786582938187465,
                                ],
                                [
                                    0.8149377479834442,
                                    0.06080439181227527,
                                    0.11563040781358205,
                                    0.008627452390698502,
                                ],
                                [
                                    0.014285714285714282,
                                    0.29281059724544484,
                                    0.03223296324084663,
                                    0.6606707252279942,
                                ],
                                [
                                    0.017515591856266836,
                                    0.35901256387786606,
                                    0.02900308567029408,
                                    0.594468758595573,
                                ],
                                [
                                    0.014637468158314643,
                                    0.3000204055518106,
                                    0.03188120936824627,
                                    0.6534609169216286,
                                ],
                                [
                                    0.02184727646468041,
                                    0.2928105972454448,
                                    0.04758456773829336,
                                    0.6377575585515814,
                                ],
                                [
                                    0.016801455517134807,
                                    0.3443750957195513,
                                    0.029717222009426107,
                                    0.6091062267538878,
                                ],
                                [
                                    0.025077154035232963,
                                    0.33609939720145315,
                                    0.0443546901677408,
                                    0.594468758595573,
                                ],
                                [
                                    0.04888663500021085,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.6066801899987349,
                                ],
                                [
                                    0.12185279408769206,
                                    0.4292599066206178,
                                    0.09925042841304593,
                                    0.3496368708786442,
                                ],
                                [
                                    0.056833106179737615,
                                    0.2002102129403531,
                                    0.1642701163210004,
                                    0.5786865645589089,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.10571974117994846,
                                    0.3724268004408802,
                                    0.11538348132078953,
                                    0.4064699770583818,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.04888663500021088,
                                    0.060019620706623,
                                    0.40000066429147924,
                                    0.4910930800016869,
                                ],
                                [
                                    0.3496368708786442,
                                    0.4292599066206178,
                                    0.09925042841304595,
                                    0.12185279408769208,
                                ],
                                [
                                    0.0816402170926781,
                                    0.10023219770163694,
                                    0.36724708219901203,
                                    0.45088050300667293,
                                ],
                                [
                                    0.12185279408769206,
                                    0.06001962070662298,
                                    0.5481377277047361,
                                    0.2699898575009489,
                                ],
                                [
                                    0.28314002455806553,
                                    0.34761968952793965,
                                    0.16574727473362463,
                                    0.2034930111803702,
                                ],
                                [
                                    0.42260302996612537,
                                    0.20815668411987978,
                                    0.24738749182630274,
                                    0.12185279408769208,
                                ],
                                [
                                    0.014285714285714332,
                                    0.008627452390698523,
                                    0.6091861299801528,
                                    0.3679007033434344,
                                ],
                                [
                                    0.594468758595573,
                                    0.35901256387786606,
                                    0.029003085670294113,
                                    0.017515591856266857,
                                ],
                                [
                                    0.07747127726609308,
                                    0.04678658293818746,
                                    0.5460005669997741,
                                    0.32974157279594546,
                                ],
                                [
                                    0.11563040781358204,
                                    0.0086274523906985,
                                    0.8149377479834442,
                                    0.06080439181227527,
                                ],
                                [
                                    0.4661884178583747,
                                    0.2815412866117729,
                                    0.15728342640749238,
                                    0.09498686912235998,
                                ],
                                [
                                    0.6958134521234407,
                                    0.05191625234670691,
                                    0.2347547036735855,
                                    0.01751559185626686,
                                ],
                                [
                                    0.0030056212142792684,
                                    0.061605441999268436,
                                    0.043513056312281646,
                                    0.8918758804741707,
                                ],
                                [
                                    0.006235498784831823,
                                    0.12780740863168966,
                                    0.04028317874172909,
                                    0.8256739138417495,
                                ],
                                [
                                    0.0030796279373977464,
                                    0.06312233869502343,
                                    0.04343904958916317,
                                    0.8903589837784157,
                                ],
                                [
                                    0.0045965246331527345,
                                    0.061605441999268436,
                                    0.06483531956982104,
                                    0.8689627137977578,
                                ],
                                [
                                    0.00524361529621791,
                                    0.10747702886276418,
                                    0.041275062230343,
                                    0.8460042936106749,
                                ],
                                [
                                    0.00782640220370529,
                                    0.1048942419552768,
                                    0.06160544199926848,
                                    0.8256739138417495,
                                ],
                                [
                                    0.010285429507595303,
                                    0.03623324801896572,
                                    0.21081779299314268,
                                    0.7426635294802962,
                                ],
                                [
                                    0.08325158859507652,
                                    0.29327656713905637,
                                    0.1378516339056615,
                                    0.48562021036020564,
                                ],
                                [
                                    0.011957315272504406,
                                    0.04212292443302271,
                                    0.2091459072282336,
                                    0.7367738530662393,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.06084395027271526,
                                    0.21433951193354986,
                                    0.16025927222802275,
                                    0.5645572655657122,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.010285429507595319,
                                    0.012627737168817536,
                                    0.4386018697840948,
                                    0.5384849635394924,
                                ],
                                [
                                    0.3110356653860286,
                                    0.38186802308281226,
                                    0.13785163390566152,
                                    0.16924467762549755,
                                ],
                                [
                                    0.017176569790248314,
                                    0.0210882013836112,
                                    0.43171072950144185,
                                    0.5300244993246986,
                                ],
                                [
                                    0.025637034005041998,
                                    0.012627737168817516,
                                    0.6443534877873861,
                                    0.3173817410387544,
                                ],
                                [
                                    0.2186763772556357,
                                    0.26847569320991393,
                                    0.23021092203605442,
                                    0.28263700749839593,
                                ],
                                [
                                    0.32638726988347533,
                                    0.16076480058207432,
                                    0.3436032519089528,
                                    0.16924467762549755,
                                ],
                                [
                                    0.003005621214279301,
                                    0.001815159775146765,
                                    0.6204662230515878,
                                    0.3747129959589861,
                                ],
                                [
                                    0.583188665524138,
                                    0.3522002712623143,
                                    0.04028317874172913,
                                    0.02432788447181861,
                                ],
                                [
                                    0.01629945201137965,
                                    0.009843592235585693,
                                    0.6071723922544875,
                                    0.3666845634985472,
                                ],
                                [
                                    0.024327884471818596,
                                    0.0018151597751467474,
                                    0.9062402713252077,
                                    0.06761668442782702,
                                ],
                                [
                                    0.4050165926036613,
                                    0.24459829590917115,
                                    0.2184552516622058,
                                    0.13192985982496175,
                                ],
                                [
                                    0.6045109287816773,
                                    0.045103959731155156,
                                    0.32605722701534895,
                                    0.024327884471818613,
                                ],
                                [
                                    0.055950408449131114,
                                    0.8100066841343474,
                                    0.008660654764416588,
                                    0.12538225265210484,
                                ],
                                [
                                    0.060436473723962644,
                                    0.8749524630624896,
                                    0.004174589489585057,
                                    0.06043647372396263,
                                ],
                                [
                                    0.057328062548319896,
                                    0.829951293292698,
                                    0.007283000665227808,
                                    0.10543764349375427,
                                ],
                                [
                                    0.06160544199926848,
                                    0.8256739138417495,
                                    0.00782640220370529,
                                    0.1048942419552768,
                                ],
                                [
                                    0.06033368376259916,
                                    0.8734643496049797,
                                    0.004277379450948539,
                                    0.06192458718147262,
                                ],
                                [
                                    0.06483531956982104,
                                    0.8689627137977578,
                                    0.004596524633152734,
                                    0.06160544199926842,
                                ],
                                [
                                    0.19146590371757707,
                                    0.4320059405482901,
                                    0.11563040781358204,
                                    0.26089774792055076,
                                ],
                                [
                                    0.29281059724544484,
                                    0.6606707252279942,
                                    0.014285714285714287,
                                    0.032232963240846645,
                                ],
                                [
                                    0.22258848529324102,
                                    0.502228052500494,
                                    0.08450782623791812,
                                    0.1906756359683469,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.29048846939087086,
                                    0.6554312909036022,
                                    0.016607842140288293,
                                    0.03747239756523875,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.19146590371757705,
                                    0.11563040781358208,
                                    0.43200594054829006,
                                    0.2608977479205508,
                                ],
                                [
                                    0.6091861299801529,
                                    0.3679007033434344,
                                    0.014285714285714284,
                                    0.008627452390698495,
                                ],
                                [
                                    0.31974624445477523,
                                    0.19310168507967512,
                                    0.3037255998110919,
                                    0.18342647065445775,
                                ],
                                [
                                    0.3436032519089528,
                                    0.16924467762549755,
                                    0.3263872698834753,
                                    0.1607648005820743,
                                ],
                                [
                                    0.5996148368116896,
                                    0.362120392014451,
                                    0.02385700745417754,
                                    0.01440776371968191,
                                ],
                                [
                                    0.6443534877873862,
                                    0.3173817410387544,
                                    0.025637034005041956,
                                    0.012627737168817495,
                                ],
                                [
                                    0.055950408449131114,
                                    0.008660654764416591,
                                    0.8100066841343474,
                                    0.12538225265210487,
                                ],
                                [
                                    0.8617825030938935,
                                    0.1333967159166805,
                                    0.00417458948958506,
                                    0.0006461914998409586,
                                ],
                                [
                                    0.3034184724279656,
                                    0.04696663905920195,
                                    0.5625386201555129,
                                    0.08707626835731952,
                                ],
                                [
                                    0.32605722701534895,
                                    0.024327884471818613,
                                    0.6045109287816773,
                                    0.045103959731155156,
                                ],
                                [
                                    0.8433183379960952,
                                    0.13053861775693948,
                                    0.02263875458738334,
                                    0.003504289659581999,
                                ],
                                [
                                    0.9062402713252077,
                                    0.06761668442782702,
                                    0.024327884471818592,
                                    0.0018151597751467471,
                                ],
                                [
                                    0.04028317874172912,
                                    0.5831886655241381,
                                    0.02432788447181859,
                                    0.3522002712623142,
                                ],
                                [
                                    0.04476924401656064,
                                    0.6481344444522802,
                                    0.01984181919698706,
                                    0.287254492334172,
                                ],
                                [
                                    0.041275062230343024,
                                    0.5975483865329708,
                                    0.02333600098320468,
                                    0.3378405502534815,
                                ],
                                [
                                    0.0443546901677408,
                                    0.594468758595573,
                                    0.025077154035232963,
                                    0.33609939720145315,
                                ],
                                [
                                    0.04428068344462229,
                                    0.6410614428452525,
                                    0.02033037976892541,
                                    0.2943274939411998,
                                ],
                                [
                                    0.04758456773829336,
                                    0.6377575585515814,
                                    0.02184727646468041,
                                    0.2928105972454448,
                                ],
                                [
                                    0.13785163390566155,
                                    0.3110356653860286,
                                    0.16924467762549758,
                                    0.38186802308281226,
                                ],
                                [
                                    0.2391963274335293,
                                    0.5397004500657328,
                                    0.06789998409762983,
                                    0.15320323840310818,
                                ],
                                [
                                    0.16025927222802278,
                                    0.3615941861511485,
                                    0.14683703930313635,
                                    0.33130950231769235,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.2281592563256526,
                                    0.5147974245542567,
                                    0.0789370552055065,
                                    0.17810626391458415,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.1378516339056615,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.29327656713905637,
                                ],
                                [
                                    0.5555718601682372,
                                    0.33552188412492884,
                                    0.06789998409762982,
                                    0.04100627160920404,
                                ],
                                [
                                    0.23021092203605442,
                                    0.1390293638779404,
                                    0.3932609222298127,
                                    0.2374987918561925,
                                ],
                                [
                                    0.24738749182630274,
                                    0.12185279408769208,
                                    0.42260302996612537,
                                    0.20815668411987978,
                                ],
                                [
                                    0.5100795143929687,
                                    0.30804807081271623,
                                    0.11339232987289839,
                                    0.06848008492141668,
                                ],
                                [
                                    0.5481377277047361,
                                    0.2699898575009489,
                                    0.12185279408769208,
                                    0.06001962070662299,
                                ],
                                [
                                    0.04028317874172919,
                                    0.0062354987848318374,
                                    0.8256739138417494,
                                    0.12780740863168963,
                                ],
                                [
                                    0.8461152733864915,
                                    0.13097155993709575,
                                    0.01984181919698707,
                                    0.0030713474794257256,
                                ],
                                [
                                    0.21845525166220586,
                                    0.03381504386764651,
                                    0.6475018409212727,
                                    0.10022786354887496,
                                ],
                                [
                                    0.2347547036735855,
                                    0.01751559185626686,
                                    0.6958134521234407,
                                    0.05191625234670691,
                                ],
                                [
                                    0.7583551172303354,
                                    0.11738702256538402,
                                    0.10760197535314311,
                                    0.016655884851137448,
                                ],
                                [
                                    0.8149377479834442,
                                    0.06080439181227527,
                                    0.11563040781358205,
                                    0.008627452390698502,
                                ],
                                [
                                    0.019841819196987062,
                                    0.28725449233417205,
                                    0.04476924401656064,
                                    0.6481344444522802,
                                ],
                                [
                                    0.024327884471818596,
                                    0.3522002712623143,
                                    0.04028317874172911,
                                    0.583188665524138,
                                ],
                                [
                                    0.02033037976892541,
                                    0.2943274939411998,
                                    0.04428068344462229,
                                    0.6410614428452525,
                                ],
                                [
                                    0.02184727646468041,
                                    0.2928105972454448,
                                    0.04758456773829336,
                                    0.6377575585515814,
                                ],
                                [
                                    0.02333600098320468,
                                    0.3378405502534815,
                                    0.041275062230343024,
                                    0.5975483865329708,
                                ],
                                [
                                    0.025077154035232963,
                                    0.33609939720145315,
                                    0.0443546901677408,
                                    0.594468758595573,
                                ],
                                [
                                    0.06789998409762983,
                                    0.15320323840310818,
                                    0.2391963274335293,
                                    0.5397004500657328,
                                ],
                                [
                                    0.16924467762549758,
                                    0.38186802308281226,
                                    0.13785163390566155,
                                    0.3110356653860286,
                                ],
                                [
                                    0.07893705520550652,
                                    0.17810626391458417,
                                    0.2281592563256526,
                                    0.5147974245542567,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.14683703930313635,
                                    0.33130950231769235,
                                    0.16025927222802278,
                                    0.3615941861511485,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.06789998409762983,
                                    0.041006271609204045,
                                    0.5555718601682372,
                                    0.33552188412492884,
                                ],
                                [
                                    0.48562021036020564,
                                    0.29327656713905637,
                                    0.1378516339056615,
                                    0.08325158859507652,
                                ],
                                [
                                    0.11339232987289836,
                                    0.06848008492141668,
                                    0.5100795143929687,
                                    0.30804807081271623,
                                ],
                                [
                                    0.12185279408769206,
                                    0.06001962070662298,
                                    0.5481377277047361,
                                    0.2699898575009489,
                                ],
                                [
                                    0.3932609222298127,
                                    0.2374987918561925,
                                    0.23021092203605442,
                                    0.1390293638779404,
                                ],
                                [
                                    0.42260302996612537,
                                    0.20815668411987978,
                                    0.24738749182630274,
                                    0.12185279408769208,
                                ],
                                [
                                    0.01984181919698712,
                                    0.0030713474794257334,
                                    0.8461152733864914,
                                    0.13097155993709575,
                                ],
                                [
                                    0.8256739138417495,
                                    0.12780740863168966,
                                    0.04028317874172914,
                                    0.0062354987848318305,
                                ],
                                [
                                    0.10760197535314309,
                                    0.016655884851137445,
                                    0.7583551172303354,
                                    0.11738702256538402,
                                ],
                                [
                                    0.11563040781358204,
                                    0.0086274523906985,
                                    0.8149377479834442,
                                    0.06080439181227527,
                                ],
                                [
                                    0.6475018409212727,
                                    0.10022786354887496,
                                    0.21845525166220586,
                                    0.03381504386764651,
                                ],
                                [
                                    0.6958134521234407,
                                    0.05191625234670691,
                                    0.2347547036735855,
                                    0.01751559185626686,
                                ],
                                [
                                    0.004174589489585058,
                                    0.060436473723962644,
                                    0.060436473723962644,
                                    0.8749524630624896,
                                ],
                                [
                                    0.008660654764416591,
                                    0.12538225265210487,
                                    0.055950408449131114,
                                    0.8100066841343474,
                                ],
                                [
                                    0.00427737945094854,
                                    0.06192458718147263,
                                    0.06033368376259916,
                                    0.8734643496049797,
                                ],
                                [
                                    0.0045965246331527345,
                                    0.061605441999268436,
                                    0.06483531956982104,
                                    0.8689627137977578,
                                ],
                                [
                                    0.007283000665227808,
                                    0.10543764349375427,
                                    0.057328062548319896,
                                    0.829951293292698,
                                ],
                                [
                                    0.00782640220370529,
                                    0.1048942419552768,
                                    0.06160544199926848,
                                    0.8256739138417495,
                                ],
                                [
                                    0.014285714285714315,
                                    0.03223296324084671,
                                    0.29281059724544484,
                                    0.6606707252279942,
                                ],
                                [
                                    0.11563040781358208,
                                    0.2608977479205508,
                                    0.19146590371757705,
                                    0.43200594054829006,
                                ],
                                [
                                    0.016607842140288313,
                                    0.0374723975652388,
                                    0.2904884693908708,
                                    0.6554312909036021,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.08450782623791814,
                                    0.19067563596834697,
                                    0.222588485293241,
                                    0.502228052500494,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.014285714285714332,
                                    0.008627452390698523,
                                    0.6091861299801528,
                                    0.3679007033434344,
                                ],
                                [
                                    0.43200594054829006,
                                    0.2608977479205508,
                                    0.19146590371757702,
                                    0.11563040781358205,
                                ],
                                [
                                    0.02385700745417758,
                                    0.014407763719681934,
                                    0.5996148368116895,
                                    0.36212039201445095,
                                ],
                                [
                                    0.025637034005041998,
                                    0.012627737168817516,
                                    0.6443534877873861,
                                    0.3173817410387544,
                                ],
                                [
                                    0.3037255998110919,
                                    0.18342647065445777,
                                    0.31974624445477523,
                                    0.19310168507967512,
                                ],
                                [
                                    0.32638726988347533,
                                    0.16076480058207432,
                                    0.3436032519089528,
                                    0.16924467762549755,
                                ],
                                [
                                    0.004174589489585101,
                                    0.0006461914998409649,
                                    0.8617825030938935,
                                    0.1333967159166805,
                                ],
                                [
                                    0.8100066841343474,
                                    0.12538225265210487,
                                    0.05595040844913115,
                                    0.008660654764416596,
                                ],
                                [
                                    0.02263875458738334,
                                    0.0035042896595819995,
                                    0.8433183379960952,
                                    0.13053861775693948,
                                ],
                                [
                                    0.024327884471818596,
                                    0.0018151597751467474,
                                    0.9062402713252077,
                                    0.06761668442782702,
                                ],
                                [
                                    0.5625386201555129,
                                    0.08707626835731952,
                                    0.3034184724279656,
                                    0.04696663905920195,
                                ],
                                [
                                    0.6045109287816773,
                                    0.045103959731155156,
                                    0.32605722701534895,
                                    0.024327884471818613,
                                ],
                                [
                                    0.004174589489585101,
                                    0.8617825030938935,
                                    0.0006461914998409646,
                                    0.13339671591668045,
                                ],
                                [
                                    0.004509305204179589,
                                    0.9308796315822727,
                                    0.0003114757852464765,
                                    0.06429958742830122,
                                ],
                                [
                                    0.004196215827779333,
                                    0.8662469420305308,
                                    0.0006245651616467323,
                                    0.12893227698004314,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.004507691613025809,
                                    0.930546529458832,
                                    0.0003130893764002558,
                                    0.06463268955174192,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.014285714285714264,
                                    0.609186129980153,
                                    0.00862745239069848,
                                    0.36790070334343433,
                                ],
                                [
                                    0.02184727646468036,
                                    0.9316340460087588,
                                    0.0010658902117323865,
                                    0.04545278731482855,
                                ],
                                [
                                    0.014774274857652613,
                                    0.6300198326657539,
                                    0.00813889181876013,
                                    0.3470670006578333,
                                ],
                                [
                                    0.21278816697511638,
                                    0.4320059405482901,
                                    0.11722131123245548,
                                    0.23798458124413796,
                                ],
                                [
                                    0.021810823829477636,
                                    0.930079595225088,
                                    0.001102342846935109,
                                    0.047007238098499285,
                                ],
                                [
                                    0.3141328605029841,
                                    0.6377575585515814,
                                    0.01587661770458775,
                                    0.03223296324084665,
                                ],
                                [
                                    0.014285714285714282,
                                    0.29281059724544484,
                                    0.03223296324084663,
                                    0.6606707252279942,
                                ],
                                [
                                    0.045452787314828526,
                                    0.9316340460087588,
                                    0.0010658902117323876,
                                    0.02184727646468039,
                                ],
                                [
                                    0.016299452011379643,
                                    0.3340856594757879,
                                    0.03021922551518127,
                                    0.6193956629976511,
                                ],
                                [
                                    0.2347547036735855,
                                    0.11563040781358207,
                                    0.43523581811884265,
                                    0.21437907039398982,
                                ],
                                [
                                    0.04530253768167372,
                                    0.928554418071361,
                                    0.001216139844887194,
                                    0.024926904402078145,
                                ],
                                [
                                    0.6524749299361613,
                                    0.32138202581687336,
                                    0.017515591856266843,
                                    0.008627452390698495,
                                ],
                                [
                                    0.004174589489585058,
                                    0.060436473723962644,
                                    0.060436473723962644,
                                    0.8749524630624896,
                                ],
                                [
                                    0.06429958742830123,
                                    0.9308796315822727,
                                    0.00031147578524647355,
                                    0.004509305204179546,
                                ],
                                [
                                    0.008059329532117873,
                                    0.11667673162014601,
                                    0.05655173368142983,
                                    0.8187122051663063,
                                ],
                                [
                                    0.11607540638784729,
                                    0.008660654764416595,
                                    0.8144927494091789,
                                    0.06077118943855717,
                                ],
                                [
                                    0.06400973798124898,
                                    0.9266834157544934,
                                    0.0006013252322987148,
                                    0.008705521031958834,
                                ],
                                [
                                    0.9219075010326095,
                                    0.0687856527031328,
                                    0.00866065476441659,
                                    0.0006461914998409586,
                                ],
                                [
                                    0.0030056212142793013,
                                    0.6204662230515879,
                                    0.0018151597751467643,
                                    0.374712995958986,
                                ],
                                [
                                    0.003340336928873789,
                                    0.6895633515399671,
                                    0.0014804440605522763,
                                    0.3056158674706068,
                                ],
                                [
                                    0.003021191746669594,
                                    0.6236805300897501,
                                    0.001799589242756471,
                                    0.37149868892082377,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.0033326675319160707,
                                    0.6879801175180513,
                                    0.0014881134575099944,
                                    0.30719910149252255,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.010285429507595268,
                                    0.4386018697840949,
                                    0.012627737168817476,
                                    0.5384849635394924,
                                ],
                                [
                                    0.017846991686561363,
                                    0.7610497858127007,
                                    0.005066174989851383,
                                    0.21603704751088665,
                                ],
                                [
                                    0.010637183380195632,
                                    0.45360172040894114,
                                    0.012275983296217112,
                                    0.5234851129146461,
                                ],
                                [
                                    0.1532032384031082,
                                    0.3110356653860286,
                                    0.17680623980446367,
                                    0.3589548564063995,
                                ],
                                [
                                    0.017673732352020653,
                                    0.7536614829682753,
                                    0.005239434324392092,
                                    0.22342535035531202,
                                ],
                                [
                                    0.25454793193097597,
                                    0.51678728338932,
                                    0.07546154627659593,
                                    0.15320323840310818,
                                ],
                                [
                                    0.010285429507595279,
                                    0.2108177929931427,
                                    0.03623324801896564,
                                    0.7426635294802963,
                                ],
                                [
                                    0.041452502536709526,
                                    0.8496412417564566,
                                    0.005066174989851388,
                                    0.10384008071698246,
                                ],
                                [
                                    0.011735280527283422,
                                    0.24053501500256894,
                                    0.03478339699927749,
                                    0.7129463074708702,
                                ],
                                [
                                    0.16901870693477583,
                                    0.08325158859507653,
                                    0.5009718148576523,
                                    0.24675788961249534,
                                ],
                                [
                                    0.0407383661975775,
                                    0.8350037735981419,
                                    0.005780311328983414,
                                    0.11847754887529714,
                                ],
                                [
                                    0.5867389331973516,
                                    0.28900320659836787,
                                    0.08325158859507652,
                                    0.04100627160920404,
                                ],
                                [
                                    0.0030056212142792753,
                                    0.04351305631228175,
                                    0.06160544199926843,
                                    0.8918758804741705,
                                ],
                                [
                                    0.06313061915299545,
                                    0.9139562141705918,
                                    0.0014804440605522618,
                                    0.021432722615860534,
                                ],
                                [
                                    0.00580255660467555,
                                    0.0840049208778938,
                                    0.05880850660887215,
                                    0.8513840159085585,
                                ],
                                [
                                    0.08357197869773751,
                                    0.00623549878483183,
                                    0.8469961770992888,
                                    0.06319634541814194,
                                ],
                                [
                                    0.06175296505380666,
                                    0.8940116050122412,
                                    0.0028580981597410406,
                                    0.041377331774211074,
                                ],
                                [
                                    0.8894040733424998,
                                    0.06636049672354805,
                                    0.04116408245452639,
                                    0.0030713474794257256,
                                ],
                                [
                                    0.0014804440605522765,
                                    0.3056158674706069,
                                    0.003340336928873789,
                                    0.6895633515399671,
                                ],
                                [
                                    0.001815159775146765,
                                    0.3747129959589861,
                                    0.003005621214279301,
                                    0.6204662230515878,
                                ],
                                [
                                    0.0014881134575099946,
                                    0.3071991014925226,
                                    0.0033326675319160707,
                                    0.6879801175180513,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.0017995892427564713,
                                    0.3714986889208238,
                                    0.003021191746669594,
                                    0.6236805300897501,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.005066174989851382,
                                    0.21603704751088662,
                                    0.017846991686561363,
                                    0.7610497858127007,
                                ],
                                [
                                    0.012627737168817476,
                                    0.5384849635394924,
                                    0.010285429507595268,
                                    0.4386018697840949,
                                ],
                                [
                                    0.005239434324392093,
                                    0.2234253503553121,
                                    0.01767373235202065,
                                    0.7536614829682752,
                                ],
                                [
                                    0.07546154627659596,
                                    0.15320323840310823,
                                    0.2545479319309759,
                                    0.5167872833893199,
                                ],
                                [
                                    0.012275983296217112,
                                    0.5234851129146461,
                                    0.01063718338019563,
                                    0.4536017204089411,
                                ],
                                [
                                    0.17680623980446367,
                                    0.3589548564063995,
                                    0.15320323840310818,
                                    0.31103566538602856,
                                ],
                                [
                                    0.00506617498985139,
                                    0.10384008071698249,
                                    0.041452502536709526,
                                    0.8496412417564566,
                                ],
                                [
                                    0.03623324801896564,
                                    0.7426635294802963,
                                    0.010285429507595279,
                                    0.21081779299314274,
                                ],
                                [
                                    0.005780311328983412,
                                    0.11847754887529713,
                                    0.0407383661975775,
                                    0.8350037735981419,
                                ],
                                [
                                    0.0832515885950765,
                                    0.04100627160920403,
                                    0.5867389331973516,
                                    0.28900320659836787,
                                ],
                                [
                                    0.03478339699927749,
                                    0.7129463074708702,
                                    0.011735280527283422,
                                    0.24053501500256894,
                                ],
                                [
                                    0.5009718148576523,
                                    0.24675788961249534,
                                    0.16901870693477583,
                                    0.08325158859507653,
                                ],
                                [
                                    0.0014804440605522657,
                                    0.02143272261586059,
                                    0.06313061915299543,
                                    0.9139562141705917,
                                ],
                                [
                                    0.061605441999268436,
                                    0.8918758804741707,
                                    0.003005621214279272,
                                    0.043513056312281695,
                                ],
                                [
                                    0.0028580981597410415,
                                    0.04137733177421109,
                                    0.06175296505380666,
                                    0.8940116050122412,
                                ],
                                [
                                    0.04116408245452641,
                                    0.0030713474794257264,
                                    0.8894040733424998,
                                    0.06636049672354805,
                                ],
                                [
                                    0.05880850660887215,
                                    0.8513840159085585,
                                    0.0058025566046755505,
                                    0.08400492087789381,
                                ],
                                [
                                    0.8469961770992888,
                                    0.06319634541814194,
                                    0.08357197869773753,
                                    0.0062354987848318305,
                                ],
                                [
                                    0.0003114757852464766,
                                    0.06429958742830123,
                                    0.004509305204179589,
                                    0.9308796315822727,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.1333967159166805,
                                    0.004174589489585101,
                                    0.8617825030938935,
                                ],
                                [
                                    0.0003130893764002561,
                                    0.06463268955174198,
                                    0.004507691613025809,
                                    0.930546529458832,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.0006245651616467327,
                                    0.1289322769800432,
                                    0.004196215827779333,
                                    0.8662469420305308,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.0010658902117323885,
                                    0.04545278731482864,
                                    0.021847276464680356,
                                    0.9316340460087587,
                                ],
                                [
                                    0.008627452390698481,
                                    0.3679007033434344,
                                    0.014285714285714263,
                                    0.6091861299801529,
                                ],
                                [
                                    0.0011023428469351087,
                                    0.04700723809849927,
                                    0.021810823829477636,
                                    0.930079595225088,
                                ],
                                [
                                    0.01587661770458774,
                                    0.03223296324084664,
                                    0.3141328605029841,
                                    0.6377575585515814,
                                ],
                                [
                                    0.008138891818760131,
                                    0.34706700065783336,
                                    0.014774274857652613,
                                    0.6300198326657539,
                                ],
                                [
                                    0.11722131123245551,
                                    0.23798458124413802,
                                    0.21278816697511638,
                                    0.4320059405482901,
                                ],
                                [
                                    0.001065890211732391,
                                    0.021847276464680463,
                                    0.045452787314828526,
                                    0.9316340460087587,
                                ],
                                [
                                    0.03223296324084663,
                                    0.6606707252279942,
                                    0.014285714285714278,
                                    0.2928105972454448,
                                ],
                                [
                                    0.0012161398448871943,
                                    0.02492690440207815,
                                    0.04530253768167372,
                                    0.928554418071361,
                                ],
                                [
                                    0.017515591856266846,
                                    0.008627452390698495,
                                    0.6524749299361613,
                                    0.32138202581687336,
                                ],
                                [
                                    0.03021922551518127,
                                    0.6193956629976511,
                                    0.016299452011379643,
                                    0.3340856594757879,
                                ],
                                [
                                    0.43523581811884265,
                                    0.21437907039398982,
                                    0.2347547036735855,
                                    0.11563040781358207,
                                ],
                                [
                                    0.0003114757852464766,
                                    0.004509305204179589,
                                    0.06429958742830123,
                                    0.9308796315822727,
                                ],
                                [
                                    0.060436473723962644,
                                    0.8749524630624896,
                                    0.00417458948958506,
                                    0.060436473723962686,
                                ],
                                [
                                    0.0006013252322987178,
                                    0.008705521031958877,
                                    0.06400973798124898,
                                    0.9266834157544934,
                                ],
                                [
                                    0.008660654764416634,
                                    0.0006461914998409619,
                                    0.9219075010326095,
                                    0.0687856527031328,
                                ],
                                [
                                    0.05655173368142983,
                                    0.8187122051663063,
                                    0.008059329532117876,
                                    0.11667673162014604,
                                ],
                                [
                                    0.8144927494091789,
                                    0.06077118943855717,
                                    0.11607540638784732,
                                    0.008660654764416598,
                                ],
                                [
                                    0.019841819196987024,
                                    0.8461152733864915,
                                    0.0030713474794257173,
                                    0.1309715599370957,
                                ],
                                [
                                    0.021432722615860485,
                                    0.9139562141705918,
                                    0.0014804440605522581,
                                    0.06313061915299543,
                                ],
                                [
                                    0.01994460915835051,
                                    0.8504985486999596,
                                    0.002968557518062235,
                                    0.12658828462362764,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.021425053218902767,
                                    0.913629167852955,
                                    0.0014881134575099764,
                                    0.06345766547063221,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.06789998409762985,
                                    0.5555718601682373,
                                    0.04100627160920403,
                                    0.3355218841249287,
                                ],
                                [
                                    0.10384008071698249,
                                    0.8496412417564566,
                                    0.0050661749898513915,
                                    0.04145250253670954,
                                ],
                                [
                                    0.07022211195220385,
                                    0.5745719955712026,
                                    0.03868414375463003,
                                    0.3165217487219634,
                                ],
                                [
                                    0.21278816697511638,
                                    0.4320059405482901,
                                    0.11722131123245548,
                                    0.23798458124413796,
                                ],
                                [
                                    0.10366682138244178,
                                    0.8482235976721239,
                                    0.005239434324392101,
                                    0.0428701466210423,
                                ],
                                [
                                    0.3141328605029841,
                                    0.6377575585515814,
                                    0.01587661770458775,
                                    0.03223296324084665,
                                ],
                                [
                                    0.06789998409762983,
                                    0.2391963274335293,
                                    0.15320323840310818,
                                    0.5397004500657328,
                                ],
                                [
                                    0.21603704751088662,
                                    0.7610497858127007,
                                    0.00506617498985139,
                                    0.017846991686561387,
                                ],
                                [
                                    0.0774712772660931,
                                    0.27291383422107446,
                                    0.1436319452346449,
                                    0.5059829432781875,
                                ],
                                [
                                    0.2347547036735855,
                                    0.11563040781358207,
                                    0.43523581811884265,
                                    0.21437907039398982,
                                ],
                                [
                                    0.2153229111717546,
                                    0.75853404458128,
                                    0.005780311328983416,
                                    0.02036273291798192,
                                ],
                                [
                                    0.6524749299361613,
                                    0.32138202581687336,
                                    0.017515591856266843,
                                    0.008627452390698495,
                                ],
                                [
                                    0.019841819196987062,
                                    0.04476924401656064,
                                    0.28725449233417205,
                                    0.6481344444522802,
                                ],
                                [
                                    0.3056158674706069,
                                    0.6895633515399671,
                                    0.0014804440605522622,
                                    0.0033403369288737567,
                                ],
                                [
                                    0.03830598429478534,
                                    0.08643007685747853,
                                    0.2687903272363738,
                                    0.6064736116113624,
                                ],
                                [
                                    0.11607540638784729,
                                    0.008660654764416595,
                                    0.8144927494091789,
                                    0.06077118943855717,
                                ],
                                [
                                    0.3042382133714181,
                                    0.6864549403643243,
                                    0.0028580981597410406,
                                    0.006448748104516508,
                                ],
                                [
                                    0.9219075010326095,
                                    0.0687856527031328,
                                    0.00866065476441659,
                                    0.0006461914998409586,
                                ],
                                [
                                    0.014285714285714264,
                                    0.609186129980153,
                                    0.00862745239069848,
                                    0.36790070334343433,
                                ],
                                [
                                    0.01587661770458772,
                                    0.6770270707642532,
                                    0.007036548971825021,
                                    0.30005976255933403,
                                ],
                                [
                                    0.01435972100883274,
                                    0.6123420008275869,
                                    0.008553445667580001,
                                    0.36474483249600026,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.015840165069385,
                                    0.6754726199805824,
                                    0.007073001607027744,
                                    0.3016142133430048,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.04888663500021088,
                                    0.40000066429147924,
                                    0.060019620706623,
                                    0.4910930800016869,
                                ],
                                [
                                    0.08482673161956351,
                                    0.6940700458796984,
                                    0.02407952408727036,
                                    0.19702369841346767,
                                ],
                                [
                                    0.050558520765119984,
                                    0.41368038302401683,
                                    0.05834773494171389,
                                    0.4774133612691493,
                                ],
                                [
                                    0.1532032384031082,
                                    0.3110356653860286,
                                    0.17680623980446367,
                                    0.3589548564063995,
                                ],
                                [
                                    0.08400323019535791,
                                    0.687331985124938,
                                    0.024903025511475965,
                                    0.20376175916822814,
                                ],
                                [
                                    0.25454793193097597,
                                    0.51678728338932,
                                    0.07546154627659593,
                                    0.15320323840310818,
                                ],
                                [
                                    0.04888663500021085,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.6066801899987349,
                                ],
                                [
                                    0.19702369841346765,
                                    0.6940700458796984,
                                    0.024079524087270352,
                                    0.0848267316195635,
                                ],
                                [
                                    0.05577777528286387,
                                    0.1964925202469885,
                                    0.16532544721787412,
                                    0.5824042572522735,
                                ],
                                [
                                    0.16901870693477583,
                                    0.08325158859507653,
                                    0.5009718148576523,
                                    0.24675788961249534,
                                ],
                                [
                                    0.19362940918852536,
                                    0.6821127306071941,
                                    0.02747381331221264,
                                    0.09678404689206792,
                                ],
                                [
                                    0.5867389331973516,
                                    0.28900320659836787,
                                    0.08325158859507652,
                                    0.04100627160920404,
                                ],
                                [
                                    0.014285714285714315,
                                    0.03223296324084671,
                                    0.29281059724544484,
                                    0.6606707252279942,
                                ],
                                [
                                    0.3000597625593341,
                                    0.6770270707642532,
                                    0.007036548971825038,
                                    0.01587661770458776,
                                ],
                                [
                                    0.027579545082814672,
                                    0.06222793239975467,
                                    0.27951676644834444,
                                    0.6306757560690862,
                                ],
                                [
                                    0.08357197869773751,
                                    0.00623549878483183,
                                    0.8469961770992888,
                                    0.06319634541814194,
                                ],
                                [
                                    0.2935117741594474,
                                    0.6622527959066005,
                                    0.013584537371711721,
                                    0.030650892562240396,
                                ],
                                [
                                    0.8894040733424998,
                                    0.06636049672354805,
                                    0.04116408245452639,
                                    0.0030713474794257256,
                                ],
                                [
                                    0.007036548971825022,
                                    0.3000597625593341,
                                    0.01587661770458772,
                                    0.6770270707642532,
                                ],
                                [
                                    0.008627452390698481,
                                    0.3679007033434344,
                                    0.014285714285714263,
                                    0.6091861299801529,
                                ],
                                [
                                    0.007073001607027745,
                                    0.30161421334300487,
                                    0.015840165069385,
                                    0.6754726199805824,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.008553445667580003,
                                    0.3647448324960003,
                                    0.01435972100883274,
                                    0.6123420008275869,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.02407952408727036,
                                    0.19702369841346765,
                                    0.08482673161956351,
                                    0.6940700458796984,
                                ],
                                [
                                    0.060019620706623,
                                    0.4910930800016869,
                                    0.04888663500021088,
                                    0.40000066429147924,
                                ],
                                [
                                    0.024903025511475975,
                                    0.20376175916822822,
                                    0.08400323019535791,
                                    0.6873319851249379,
                                ],
                                [
                                    0.07546154627659596,
                                    0.15320323840310823,
                                    0.2545479319309759,
                                    0.5167872833893199,
                                ],
                                [
                                    0.05834773494171389,
                                    0.4774133612691493,
                                    0.05055852076511998,
                                    0.4136803830240168,
                                ],
                                [
                                    0.17680623980446367,
                                    0.3589548564063995,
                                    0.15320323840310818,
                                    0.31103566538602856,
                                ],
                                [
                                    0.02407952408727036,
                                    0.08482673161956351,
                                    0.19702369841346765,
                                    0.6940700458796984,
                                ],
                                [
                                    0.17221658750052715,
                                    0.6066801899987349,
                                    0.04888663500021086,
                                    0.17221658750052715,
                                ],
                                [
                                    0.027473813312212637,
                                    0.0967840468920679,
                                    0.19362940918852536,
                                    0.6821127306071941,
                                ],
                                [
                                    0.0832515885950765,
                                    0.04100627160920403,
                                    0.5867389331973516,
                                    0.28900320659836787,
                                ],
                                [
                                    0.16532544721787412,
                                    0.5824042572522735,
                                    0.05577777528286387,
                                    0.1964925202469885,
                                ],
                                [
                                    0.5009718148576523,
                                    0.24675788961249534,
                                    0.16901870693477583,
                                    0.08325158859507653,
                                ],
                                [
                                    0.007036548971825056,
                                    0.0158766177045878,
                                    0.3000597625593341,
                                    0.6770270707642531,
                                ],
                                [
                                    0.29281059724544484,
                                    0.6606707252279942,
                                    0.0142857142857143,
                                    0.03223296324084667,
                                ],
                                [
                                    0.013584537371711725,
                                    0.030650892562240406,
                                    0.2935117741594474,
                                    0.6622527959066005,
                                ],
                                [
                                    0.04116408245452641,
                                    0.0030713474794257264,
                                    0.8894040733424998,
                                    0.06636049672354805,
                                ],
                                [
                                    0.27951676644834444,
                                    0.6306757560690862,
                                    0.02757954508281468,
                                    0.06222793239975468,
                                ],
                                [
                                    0.8469961770992888,
                                    0.06319634541814194,
                                    0.08357197869773753,
                                    0.0062354987848318305,
                                ],
                                [
                                    0.0014804440605522586,
                                    0.06313061915299545,
                                    0.021432722615860485,
                                    0.9139562141705918,
                                ],
                                [
                                    0.0030713474794257186,
                                    0.13097155993709575,
                                    0.019841819196987024,
                                    0.8461152733864915,
                                ],
                                [
                                    0.0014881134575099777,
                                    0.06345766547063227,
                                    0.021425053218902767,
                                    0.913629167852955,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.0029685575180622365,
                                    0.1265882846236277,
                                    0.01994460915835051,
                                    0.8504985486999596,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.005066174989851401,
                                    0.04145250253670962,
                                    0.10384008071698247,
                                    0.8496412417564565,
                                ],
                                [
                                    0.041006271609204045,
                                    0.33552188412492884,
                                    0.06789998409762983,
                                    0.5555718601682372,
                                ],
                                [
                                    0.005239434324392099,
                                    0.042870146621042285,
                                    0.10366682138244178,
                                    0.8482235976721239,
                                ],
                                [
                                    0.01587661770458774,
                                    0.03223296324084664,
                                    0.3141328605029841,
                                    0.6377575585515814,
                                ],
                                [
                                    0.03868414375463003,
                                    0.3165217487219635,
                                    0.07022211195220385,
                                    0.5745719955712026,
                                ],
                                [
                                    0.11722131123245551,
                                    0.23798458124413802,
                                    0.21278816697511638,
                                    0.4320059405482901,
                                ],
                                [
                                    0.005066174989851407,
                                    0.01784699168656145,
                                    0.2160370475108866,
                                    0.7610497858127006,
                                ],
                                [
                                    0.15320323840310818,
                                    0.5397004500657328,
                                    0.06789998409762982,
                                    0.23919632743352925,
                                ],
                                [
                                    0.005780311328983416,
                                    0.020362732917981925,
                                    0.2153229111717546,
                                    0.75853404458128,
                                ],
                                [
                                    0.017515591856266846,
                                    0.008627452390698495,
                                    0.6524749299361613,
                                    0.32138202581687336,
                                ],
                                [
                                    0.1436319452346449,
                                    0.5059829432781875,
                                    0.0774712772660931,
                                    0.27291383422107446,
                                ],
                                [
                                    0.43523581811884265,
                                    0.21437907039398982,
                                    0.2347547036735855,
                                    0.11563040781358207,
                                ],
                                [
                                    0.0014804440605522765,
                                    0.003340336928873789,
                                    0.3056158674706069,
                                    0.6895633515399671,
                                ],
                                [
                                    0.28725449233417205,
                                    0.6481344444522802,
                                    0.019841819196987073,
                                    0.04476924401656067,
                                ],
                                [
                                    0.002858098159741055,
                                    0.00644874810451654,
                                    0.3042382133714181,
                                    0.6864549403643243,
                                ],
                                [
                                    0.008660654764416634,
                                    0.0006461914998409619,
                                    0.9219075010326095,
                                    0.0687856527031328,
                                ],
                                [
                                    0.2687903272363738,
                                    0.6064736116113624,
                                    0.03830598429478536,
                                    0.08643007685747857,
                                ],
                                [
                                    0.8144927494091789,
                                    0.06077118943855717,
                                    0.11607540638784732,
                                    0.008660654764416598,
                                ],
                                [
                                    0.04028317874172909,
                                    0.8256739138417495,
                                    0.00623549878483182,
                                    0.1278074086316896,
                                ],
                                [
                                    0.043513056312281646,
                                    0.8918758804741707,
                                    0.0030056212142792675,
                                    0.06160544199926842,
                                ],
                                [
                                    0.04049186456561208,
                                    0.829951293292698,
                                    0.0060268129609488295,
                                    0.12353002918074106,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.04349748577989135,
                                    0.8915567352919664,
                                    0.003021191746669561,
                                    0.061924587181472625,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.13785163390566152,
                                    0.4856202103602057,
                                    0.08325158859507649,
                                    0.2932765671390563,
                                ],
                                [
                                    0.2108177929931427,
                                    0.7426635294802963,
                                    0.010285429507595282,
                                    0.03623324801896565,
                                ],
                                [
                                    0.14256605502291253,
                                    0.502228052500494,
                                    0.07853716747782546,
                                    0.276668724998768,
                                ],
                                [
                                    0.21278816697511638,
                                    0.4320059405482901,
                                    0.11722131123245548,
                                    0.23798458124413796,
                                ],
                                [
                                    0.21046603912054235,
                                    0.7414243799340232,
                                    0.010637183380195646,
                                    0.03747239756523875,
                                ],
                                [
                                    0.3141328605029841,
                                    0.6377575585515814,
                                    0.01587661770458775,
                                    0.03223296324084665,
                                ],
                                [
                                    0.13785163390566155,
                                    0.16924467762549758,
                                    0.3110356653860286,
                                    0.38186802308281226,
                                ],
                                [
                                    0.4386018697840949,
                                    0.5384849635394924,
                                    0.010285429507595284,
                                    0.012627737168817495,
                                ],
                                [
                                    0.1572834264074924,
                                    0.19310168507967515,
                                    0.29160387288419776,
                                    0.3580110156286347,
                                ],
                                [
                                    0.2347547036735855,
                                    0.11563040781358207,
                                    0.43523581811884265,
                                    0.21437907039398982,
                                ],
                                [
                                    0.4371520187644067,
                                    0.536704936988628,
                                    0.011735280527283428,
                                    0.01440776371968191,
                                ],
                                [
                                    0.6524749299361613,
                                    0.32138202581687336,
                                    0.017515591856266843,
                                    0.008627452390698495,
                                ],
                                [
                                    0.04028317874172911,
                                    0.024327884471818596,
                                    0.583188665524138,
                                    0.3522002712623143,
                                ],
                                [
                                    0.6204662230515878,
                                    0.3747129959589861,
                                    0.0030056212142792714,
                                    0.0018151597751467474,
                                ],
                                [
                                    0.07776942209306194,
                                    0.04696663905920194,
                                    0.5457024221728052,
                                    0.32956151667493094,
                                ],
                                [
                                    0.11607540638784729,
                                    0.008660654764416595,
                                    0.8144927494091789,
                                    0.06077118943855717,
                                ],
                                [
                                    0.6176692876611916,
                                    0.3730238660745509,
                                    0.00580255660467555,
                                    0.003504289659581999,
                                ],
                                [
                                    0.9219075010326095,
                                    0.0687856527031328,
                                    0.00866065476441659,
                                    0.0006461914998409586,
                                ],
                                [
                                    0.029003085670294082,
                                    0.5944687585955731,
                                    0.017515591856266832,
                                    0.35901256387786595,
                                ],
                                [
                                    0.03223296324084663,
                                    0.6606707252279942,
                                    0.014285714285714278,
                                    0.2928105972454448,
                                ],
                                [
                                    0.029153335303448887,
                                    0.5975483865329708,
                                    0.017365342223112024,
                                    0.3559329359404682,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.032158956517728154,
                                    0.6591538285322392,
                                    0.014359721008832756,
                                    0.2943274939411998,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.09925042841304593,
                                    0.3496368708786442,
                                    0.12185279408769206,
                                    0.4292599066206178,
                                ],
                                [
                                    0.17221658750052715,
                                    0.6066801899987349,
                                    0.04888663500021086,
                                    0.17221658750052715,
                                ],
                                [
                                    0.10264471763798821,
                                    0.3615941861511486,
                                    0.11845850486274978,
                                    0.4173025913481134,
                                ],
                                [
                                    0.1532032384031082,
                                    0.3110356653860286,
                                    0.17680623980446367,
                                    0.3589548564063995,
                                ],
                                [
                                    0.17054470173561803,
                                    0.6007905135846778,
                                    0.05055852076511996,
                                    0.17810626391458415,
                                ],
                                [
                                    0.25454793193097597,
                                    0.51678728338932,
                                    0.07546154627659593,
                                    0.15320323840310818,
                                ],
                                [
                                    0.09925042841304593,
                                    0.12185279408769206,
                                    0.3496368708786442,
                                    0.4292599066206178,
                                ],
                                [
                                    0.40000066429147924,
                                    0.4910930800016869,
                                    0.048886635000210864,
                                    0.060019620706622985,
                                ],
                                [
                                    0.11324093165191196,
                                    0.1390293638779404,
                                    0.3356463676397782,
                                    0.41208333683036946,
                                ],
                                [
                                    0.16901870693477583,
                                    0.08325158859507653,
                                    0.5009718148576523,
                                    0.24675788961249534,
                                ],
                                [
                                    0.39310952400882626,
                                    0.4826326157868932,
                                    0.05577777528286388,
                                    0.06848008492141668,
                                ],
                                [
                                    0.5867389331973516,
                                    0.28900320659836787,
                                    0.08325158859507652,
                                    0.04100627160920404,
                                ],
                                [
                                    0.029003085670294148,
                                    0.017515591856266877,
                                    0.5944687585955729,
                                    0.359012563877866,
                                ],
                                [
                                    0.6091861299801529,
                                    0.3679007033434344,
                                    0.014285714285714294,
                                    0.008627452390698502,
                                ],
                                [
                                    0.05599243361492284,
                                    0.0338150438676465,
                                    0.5674794106509443,
                                    0.3427131118664864,
                                ],
                                [
                                    0.08357197869773751,
                                    0.00623549878483183,
                                    0.8469961770992888,
                                    0.06319634541814194,
                                ],
                                [
                                    0.5958922991830524,
                                    0.35987227088299545,
                                    0.02757954508281467,
                                    0.016655884851137448,
                                ],
                                [
                                    0.8894040733424998,
                                    0.06636049672354805,
                                    0.04116408245452639,
                                    0.0030713474794257256,
                                ],
                                [
                                    0.014285714285714282,
                                    0.29281059724544484,
                                    0.03223296324084663,
                                    0.6606707252279942,
                                ],
                                [
                                    0.017515591856266836,
                                    0.35901256387786606,
                                    0.02900308567029408,
                                    0.594468758595573,
                                ],
                                [
                                    0.01435972100883276,
                                    0.29432749394119984,
                                    0.032158956517728154,
                                    0.6591538285322392,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.017365342223112028,
                                    0.35593293594046826,
                                    0.029153335303448887,
                                    0.5975483865329708,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.04888663500021085,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.6066801899987349,
                                ],
                                [
                                    0.12185279408769206,
                                    0.4292599066206178,
                                    0.09925042841304593,
                                    0.3496368708786442,
                                ],
                                [
                                    0.050558520765119984,
                                    0.1781062639145842,
                                    0.170544701735618,
                                    0.6007905135846778,
                                ],
                                [
                                    0.07546154627659596,
                                    0.15320323840310823,
                                    0.2545479319309759,
                                    0.5167872833893199,
                                ],
                                [
                                    0.11845850486274978,
                                    0.4173025913481134,
                                    0.1026447176379882,
                                    0.3615941861511485,
                                ],
                                [
                                    0.17680623980446367,
                                    0.3589548564063995,
                                    0.15320323840310818,
                                    0.31103566538602856,
                                ],
                                [
                                    0.04888663500021088,
                                    0.060019620706623,
                                    0.40000066429147924,
                                    0.4910930800016869,
                                ],
                                [
                                    0.3496368708786442,
                                    0.4292599066206178,
                                    0.09925042841304595,
                                    0.12185279408769208,
                                ],
                                [
                                    0.055777775282863866,
                                    0.06848008492141666,
                                    0.39310952400882626,
                                    0.4826326157868932,
                                ],
                                [
                                    0.0832515885950765,
                                    0.04100627160920403,
                                    0.5867389331973516,
                                    0.28900320659836787,
                                ],
                                [
                                    0.3356463676397782,
                                    0.41208333683036946,
                                    0.11324093165191196,
                                    0.1390293638779404,
                                ],
                                [
                                    0.5009718148576523,
                                    0.24675788961249534,
                                    0.16901870693477583,
                                    0.08325158859507653,
                                ],
                                [
                                    0.014285714285714332,
                                    0.008627452390698523,
                                    0.6091861299801528,
                                    0.3679007033434344,
                                ],
                                [
                                    0.594468758595573,
                                    0.35901256387786606,
                                    0.029003085670294113,
                                    0.017515591856266857,
                                ],
                                [
                                    0.02757954508281468,
                                    0.01665588485113745,
                                    0.5958922991830524,
                                    0.35987227088299545,
                                ],
                                [
                                    0.04116408245452641,
                                    0.0030713474794257264,
                                    0.8894040733424998,
                                    0.06636049672354805,
                                ],
                                [
                                    0.5674794106509443,
                                    0.3427131118664864,
                                    0.05599243361492285,
                                    0.033815043867646506,
                                ],
                                [
                                    0.8469961770992888,
                                    0.06319634541814194,
                                    0.08357197869773753,
                                    0.0062354987848318305,
                                ],
                                [
                                    0.0030056212142792684,
                                    0.061605441999268436,
                                    0.043513056312281646,
                                    0.8918758804741707,
                                ],
                                [
                                    0.006235498784831823,
                                    0.12780740863168966,
                                    0.04028317874172909,
                                    0.8256739138417495,
                                ],
                                [
                                    0.0030211917466695637,
                                    0.06192458718147267,
                                    0.04349748577989135,
                                    0.8915567352919664,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.006026812960948832,
                                    0.12353002918074112,
                                    0.04049186456561208,
                                    0.829951293292698,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.010285429507595303,
                                    0.03623324801896572,
                                    0.21081779299314268,
                                    0.7426635294802962,
                                ],
                                [
                                    0.08325158859507652,
                                    0.29327656713905637,
                                    0.1378516339056615,
                                    0.48562021036020564,
                                ],
                                [
                                    0.010637183380195644,
                                    0.03747239756523874,
                                    0.21046603912054235,
                                    0.7414243799340232,
                                ],
                                [
                                    0.01587661770458774,
                                    0.03223296324084664,
                                    0.3141328605029841,
                                    0.6377575585515814,
                                ],
                                [
                                    0.07853716747782546,
                                    0.27666872499876805,
                                    0.14256605502291253,
                                    0.502228052500494,
                                ],
                                [
                                    0.11722131123245551,
                                    0.23798458124413802,
                                    0.21278816697511638,
                                    0.4320059405482901,
                                ],
                                [
                                    0.010285429507595319,
                                    0.012627737168817536,
                                    0.4386018697840948,
                                    0.5384849635394924,
                                ],
                                [
                                    0.3110356653860286,
                                    0.38186802308281226,
                                    0.13785163390566152,
                                    0.16924467762549755,
                                ],
                                [
                                    0.01173528052728343,
                                    0.014407763719681912,
                                    0.4371520187644067,
                                    0.536704936988628,
                                ],
                                [
                                    0.017515591856266846,
                                    0.008627452390698495,
                                    0.6524749299361613,
                                    0.32138202581687336,
                                ],
                                [
                                    0.29160387288419776,
                                    0.3580110156286347,
                                    0.1572834264074924,
                                    0.19310168507967515,
                                ],
                                [
                                    0.43523581811884265,
                                    0.21437907039398982,
                                    0.2347547036735855,
                                    0.11563040781358207,
                                ],
                                [
                                    0.003005621214279301,
                                    0.001815159775146765,
                                    0.6204662230515878,
                                    0.3747129959589861,
                                ],
                                [
                                    0.583188665524138,
                                    0.3522002712623143,
                                    0.04028317874172913,
                                    0.02432788447181861,
                                ],
                                [
                                    0.005802556604675578,
                                    0.003504289659582017,
                                    0.6176692876611916,
                                    0.3730238660745509,
                                ],
                                [
                                    0.008660654764416634,
                                    0.0006461914998409619,
                                    0.9219075010326095,
                                    0.0687856527031328,
                                ],
                                [
                                    0.5457024221728052,
                                    0.32956151667493094,
                                    0.07776942209306197,
                                    0.04696663905920195,
                                ],
                                [
                                    0.8144927494091789,
                                    0.06077118943855717,
                                    0.11607540638784732,
                                    0.008660654764416598,
                                ],
                                [
                                    0.055950408449131114,
                                    0.8100066841343474,
                                    0.008660654764416588,
                                    0.12538225265210484,
                                ],
                                [
                                    0.060436473723962644,
                                    0.8749524630624896,
                                    0.004174589489585057,
                                    0.06043647372396263,
                                ],
                                [
                                    0.05624025789618335,
                                    0.8142028999621267,
                                    0.008370805317364347,
                                    0.12118603682432554,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.06041484738576841,
                                    0.8746393736860893,
                                    0.004196215827779289,
                                    0.0607495631003629,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.19146590371757707,
                                    0.4320059405482901,
                                    0.11563040781358204,
                                    0.26089774792055076,
                                ],
                                [
                                    0.29281059724544484,
                                    0.6606707252279942,
                                    0.014285714285714287,
                                    0.032232963240846645,
                                ],
                                [
                                    0.19801389211746376,
                                    0.44678021540594276,
                                    0.10908241941369536,
                                    0.2461234730628981,
                                ],
                                [
                                    0.21278816697511638,
                                    0.4320059405482901,
                                    0.11722131123245548,
                                    0.23798458124413796,
                                ],
                                [
                                    0.2923220366735065,
                                    0.6595683823810591,
                                    0.014774274857652639,
                                    0.033335306087781756,
                                ],
                                [
                                    0.3141328605029841,
                                    0.6377575585515814,
                                    0.01587661770458775,
                                    0.03223296324084665,
                                ],
                                [
                                    0.19146590371757705,
                                    0.11563040781358208,
                                    0.43200594054829006,
                                    0.2608977479205508,
                                ],
                                [
                                    0.6091861299801529,
                                    0.3679007033434344,
                                    0.014285714285714284,
                                    0.008627452390698495,
                                ],
                                [
                                    0.2184552516622058,
                                    0.13192985982496175,
                                    0.4050165926036613,
                                    0.24459829590917115,
                                ],
                                [
                                    0.2347547036735855,
                                    0.11563040781358207,
                                    0.43523581811884265,
                                    0.21437907039398982,
                                ],
                                [
                                    0.6071723922544875,
                                    0.3666845634985472,
                                    0.016299452011379646,
                                    0.009843592235585692,
                                ],
                                [
                                    0.6524749299361613,
                                    0.32138202581687336,
                                    0.017515591856266843,
                                    0.008627452390698495,
                                ],
                                [
                                    0.055950408449131114,
                                    0.008660654764416591,
                                    0.8100066841343474,
                                    0.12538225265210487,
                                ],
                                [
                                    0.8617825030938935,
                                    0.1333967159166805,
                                    0.00417458948958506,
                                    0.0006461914998409586,
                                ],
                                [
                                    0.1080160768557294,
                                    0.016719984296534467,
                                    0.7579410157277491,
                                    0.117322923119987,
                                ],
                                [
                                    0.11607540638784729,
                                    0.008660654764416595,
                                    0.8144927494091789,
                                    0.06077118943855717,
                                ],
                                [
                                    0.8578977630513606,
                                    0.1327953906843818,
                                    0.008059329532117875,
                                    0.0012475167321396733,
                                ],
                                [
                                    0.9219075010326095,
                                    0.0687856527031328,
                                    0.00866065476441659,
                                    0.0006461914998409586,
                                ],
                                [
                                    0.04028317874172912,
                                    0.5831886655241381,
                                    0.02432788447181859,
                                    0.3522002712623142,
                                ],
                                [
                                    0.04476924401656064,
                                    0.6481344444522802,
                                    0.01984181919698706,
                                    0.287254492334172,
                                ],
                                [
                                    0.0404918645656121,
                                    0.5862098572708075,
                                    0.0241191986479356,
                                    0.34917907951564464,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.04466645405519716,
                                    0.6466463309947702,
                                    0.01994460915835054,
                                    0.288742605791682,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.13785163390566155,
                                    0.3110356653860286,
                                    0.16924467762549758,
                                    0.38186802308281226,
                                ],
                                [
                                    0.2391963274335293,
                                    0.5397004500657328,
                                    0.06789998409762983,
                                    0.15320323840310818,
                                ],
                                [
                                    0.14256605502291256,
                                    0.3216728487662242,
                                    0.16453025650824657,
                                    0.37123083970261667,
                                ],
                                [
                                    0.1532032384031082,
                                    0.3110356653860286,
                                    0.17680623980446367,
                                    0.3589548564063995,
                                ],
                                [
                                    0.2368741995789553,
                                    0.5344610157413406,
                                    0.07022211195220383,
                                    0.15844267272750026,
                                ],
                                [
                                    0.25454793193097597,
                                    0.51678728338932,
                                    0.07546154627659593,
                                    0.15320323840310818,
                                ],
                                [
                                    0.1378516339056615,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.29327656713905637,
                                ],
                                [
                                    0.5555718601682372,
                                    0.33552188412492884,
                                    0.06789998409762982,
                                    0.04100627160920404,
                                ],
                                [
                                    0.15728342640749238,
                                    0.09498686912235998,
                                    0.4661884178583747,
                                    0.2815412866117729,
                                ],
                                [
                                    0.16901870693477583,
                                    0.08325158859507653,
                                    0.5009718148576523,
                                    0.24675788961249534,
                                ],
                                [
                                    0.5460005669997741,
                                    0.32974157279594546,
                                    0.0774712772660931,
                                    0.046786582938187465,
                                ],
                                [
                                    0.5867389331973516,
                                    0.28900320659836787,
                                    0.08325158859507652,
                                    0.04100627160920404,
                                ],
                                [
                                    0.04028317874172919,
                                    0.0062354987848318374,
                                    0.8256739138417494,
                                    0.12780740863168963,
                                ],
                                [
                                    0.8461152733864915,
                                    0.13097155993709575,
                                    0.01984181919698707,
                                    0.0030713474794257256,
                                ],
                                [
                                    0.07776942209306197,
                                    0.01203805538950738,
                                    0.7881876704904166,
                                    0.1220048520270141,
                                ],
                                [
                                    0.08357197869773751,
                                    0.00623549878483183,
                                    0.8469961770992888,
                                    0.06319634541814194,
                                ],
                                [
                                    0.8276511082886931,
                                    0.1281134617773547,
                                    0.03830598429478535,
                                    0.005929445639166767,
                                ],
                                [
                                    0.8894040733424998,
                                    0.06636049672354805,
                                    0.04116408245452639,
                                    0.0030713474794257256,
                                ],
                                [
                                    0.019841819196987062,
                                    0.28725449233417205,
                                    0.04476924401656064,
                                    0.6481344444522802,
                                ],
                                [
                                    0.024327884471818596,
                                    0.3522002712623143,
                                    0.04028317874172911,
                                    0.583188665524138,
                                ],
                                [
                                    0.019944609158350543,
                                    0.28874260579168204,
                                    0.04466645405519716,
                                    0.6466463309947702,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.024119198647935602,
                                    0.3491790795156447,
                                    0.0404918645656121,
                                    0.5862098572708075,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.06789998409762983,
                                    0.15320323840310818,
                                    0.2391963274335293,
                                    0.5397004500657328,
                                ],
                                [
                                    0.16924467762549758,
                                    0.38186802308281226,
                                    0.13785163390566155,
                                    0.3110356653860286,
                                ],
                                [
                                    0.07022211195220386,
                                    0.15844267272750032,
                                    0.23687419957895525,
                                    0.5344610157413405,
                                ],
                                [
                                    0.07546154627659596,
                                    0.15320323840310823,
                                    0.2545479319309759,
                                    0.5167872833893199,
                                ],
                                [
                                    0.16453025650824657,
                                    0.37123083970261667,
                                    0.14256605502291256,
                                    0.3216728487662242,
                                ],
                                [
                                    0.17680623980446367,
                                    0.3589548564063995,
                                    0.15320323840310818,
                                    0.31103566538602856,
                                ],
                                [
                                    0.06789998409762983,
                                    0.041006271609204045,
                                    0.5555718601682372,
                                    0.33552188412492884,
                                ],
                                [
                                    0.48562021036020564,
                                    0.29327656713905637,
                                    0.1378516339056615,
                                    0.08325158859507652,
                                ],
                                [
                                    0.07747127726609308,
                                    0.04678658293818746,
                                    0.5460005669997741,
                                    0.32974157279594546,
                                ],
                                [
                                    0.0832515885950765,
                                    0.04100627160920403,
                                    0.5867389331973516,
                                    0.28900320659836787,
                                ],
                                [
                                    0.4661884178583747,
                                    0.2815412866117729,
                                    0.15728342640749238,
                                    0.09498686912235998,
                                ],
                                [
                                    0.5009718148576523,
                                    0.24675788961249534,
                                    0.16901870693477583,
                                    0.08325158859507653,
                                ],
                                [
                                    0.01984181919698712,
                                    0.0030713474794257334,
                                    0.8461152733864914,
                                    0.13097155993709575,
                                ],
                                [
                                    0.8256739138417495,
                                    0.12780740863168966,
                                    0.04028317874172914,
                                    0.0062354987848318305,
                                ],
                                [
                                    0.038305984294785364,
                                    0.005929445639166768,
                                    0.8276511082886931,
                                    0.1281134617773547,
                                ],
                                [
                                    0.04116408245452641,
                                    0.0030713474794257264,
                                    0.8894040733424998,
                                    0.06636049672354805,
                                ],
                                [
                                    0.7881876704904166,
                                    0.1220048520270141,
                                    0.07776942209306198,
                                    0.012038055389507382,
                                ],
                                [
                                    0.8469961770992888,
                                    0.06319634541814194,
                                    0.08357197869773753,
                                    0.0062354987848318305,
                                ],
                                [
                                    0.004174589489585058,
                                    0.060436473723962644,
                                    0.060436473723962644,
                                    0.8749524630624896,
                                ],
                                [
                                    0.008660654764416591,
                                    0.12538225265210487,
                                    0.055950408449131114,
                                    0.8100066841343474,
                                ],
                                [
                                    0.004196215827779293,
                                    0.06074956310036295,
                                    0.06041484738576841,
                                    0.8746393736860893,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.00837080531736435,
                                    0.12118603682432559,
                                    0.05624025789618335,
                                    0.8142028999621267,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.014285714285714315,
                                    0.03223296324084671,
                                    0.29281059724544484,
                                    0.6606707252279942,
                                ],
                                [
                                    0.11563040781358208,
                                    0.2608977479205508,
                                    0.19146590371757705,
                                    0.43200594054829006,
                                ],
                                [
                                    0.014774274857652633,
                                    0.03333530608778175,
                                    0.2923220366735065,
                                    0.6595683823810591,
                                ],
                                [
                                    0.01587661770458774,
                                    0.03223296324084664,
                                    0.3141328605029841,
                                    0.6377575585515814,
                                ],
                                [
                                    0.10908241941369537,
                                    0.24612347306289814,
                                    0.19801389211746376,
                                    0.44678021540594276,
                                ],
                                [
                                    0.11722131123245551,
                                    0.23798458124413802,
                                    0.21278816697511638,
                                    0.4320059405482901,
                                ],
                                [
                                    0.014285714285714332,
                                    0.008627452390698523,
                                    0.6091861299801528,
                                    0.3679007033434344,
                                ],
                                [
                                    0.43200594054829006,
                                    0.2608977479205508,
                                    0.19146590371757702,
                                    0.11563040781358205,
                                ],
                                [
                                    0.01629945201137965,
                                    0.009843592235585693,
                                    0.6071723922544875,
                                    0.3666845634985472,
                                ],
                                [
                                    0.017515591856266846,
                                    0.008627452390698495,
                                    0.6524749299361613,
                                    0.32138202581687336,
                                ],
                                [
                                    0.4050165926036613,
                                    0.24459829590917115,
                                    0.2184552516622058,
                                    0.13192985982496175,
                                ],
                                [
                                    0.43523581811884265,
                                    0.21437907039398982,
                                    0.2347547036735855,
                                    0.11563040781358207,
                                ],
                                [
                                    0.004174589489585101,
                                    0.0006461914998409649,
                                    0.8617825030938935,
                                    0.1333967159166805,
                                ],
                                [
                                    0.8100066841343474,
                                    0.12538225265210487,
                                    0.05595040844913115,
                                    0.008660654764416596,
                                ],
                                [
                                    0.008059329532117916,
                                    0.0012475167321396796,
                                    0.8578977630513606,
                                    0.1327953906843818,
                                ],
                                [
                                    0.008660654764416634,
                                    0.0006461914998409619,
                                    0.9219075010326095,
                                    0.0687856527031328,
                                ],
                                [
                                    0.7579410157277491,
                                    0.117322923119987,
                                    0.10801607685572945,
                                    0.016719984296534474,
                                ],
                                [
                                    0.8144927494091789,
                                    0.06077118943855717,
                                    0.11607540638784732,
                                    0.008660654764416598,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8617825030938935,
                                    0.004174589489585057,
                                    0.13339671591668045,
                                    0.0006461914998409577,
                                ],
                                [
                                    0.866268568368725,
                                    0.06463430314289571,
                                    0.06429958742830122,
                                    0.004797541060078002,
                                ],
                                [
                                    0.9264151926456354,
                                    0.004487678865985309,
                                    0.06876402636493852,
                                    0.00033310212344070525,
                                ],
                                [
                                    0.8617825030938935,
                                    0.06429958742830123,
                                    0.06878565270313274,
                                    0.005132256774672487,
                                ],
                                [
                                    0.9216176515855574,
                                    0.004464438936637298,
                                    0.07356156742501652,
                                    0.0003563420527887165,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6245377344775995,
                                    0.3076213247383002,
                                    0.045452787314828554,
                                    0.02238815346927171,
                                ],
                                [
                                    0.9108003433231577,
                                    0.02135871589274204,
                                    0.06628649000042952,
                                    0.0015544507836707387,
                                ],
                                [
                                    0.6091861299801529,
                                    0.30005976255933403,
                                    0.06080439181227523,
                                    0.029949715648237816,
                                ],
                                [
                                    0.888412189853886,
                                    0.020833702685600967,
                                    0.08867464346970123,
                                    0.0020794639908118116,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.3081622017428915,
                                    0.6256358316246874,
                                    0.02184727646468039,
                                    0.04435469016774077,
                                ],
                                [
                                    0.8903589837784157,
                                    0.043439049589163184,
                                    0.06312233869502341,
                                    0.0030796279373977472,
                                ],
                                [
                                    0.2928105972454448,
                                    0.5944687585955731,
                                    0.03719888096212706,
                                    0.07552176319685502,
                                ],
                                [
                                    0.8460042936106749,
                                    0.041275062230343024,
                                    0.10747702886276418,
                                    0.005243615296217912,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.8746393736860893,
                                    0.0604148473857684,
                                    0.0607495631003629,
                                    0.004196215827779288,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.8142028999621267,
                                    0.056240257896183345,
                                    0.12118603682432554,
                                    0.008370805317364345,
                                ],
                                [
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                    0.3056158674706068,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.6204662230515879,
                                    0.0030056212142792692,
                                    0.374712995958986,
                                    0.0018151597751467452,
                                ],
                                [
                                    0.6249522883264195,
                                    0.046629136884882134,
                                    0.3056158674706068,
                                    0.02280270731809158,
                                ],
                                [
                                    0.6683438782437913,
                                    0.0032375469675102716,
                                    0.32683534076678267,
                                    0.001583234021915743,
                                ],
                                [
                                    0.6204662230515879,
                                    0.046294421170287654,
                                    0.31010193274543835,
                                    0.023137423032686063,
                                ],
                                [
                                    0.6635463371837134,
                                    0.0032143070381622603,
                                    0.3316328818268606,
                                    0.0016064739512637542,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.4386018697840949,
                                    0.010285429507595284,
                                    0.5384849635394924,
                                    0.012627737168817495,
                                ],
                                [
                                    0.4539534742815415,
                                    0.22359860968985273,
                                    0.21603704751088665,
                                    0.10641086851771915,
                                ],
                                [
                                    0.6620272201394068,
                                    0.015524863831987383,
                                    0.3150596131841804,
                                    0.007388302844425396,
                                ],
                                [
                                    0.43860186978409477,
                                    0.2160370475108866,
                                    0.23138865200833333,
                                    0.11397243069668525,
                                ],
                                [
                                    0.639639066670135,
                                    0.014999850624846309,
                                    0.3374477666534521,
                                    0.00791331605156647,
                                ],
                                [
                                    0.8496412417564566,
                                    0.04145250253670954,
                                    0.10384008071698246,
                                    0.005066174989851391,
                                ],
                                [
                                    0.2108177929931427,
                                    0.010285429507595282,
                                    0.7426635294802963,
                                    0.03623324801896565,
                                ],
                                [
                                    0.2261693974905894,
                                    0.4591727287992854,
                                    0.10384008071698247,
                                    0.21081779299314274,
                                ],
                                [
                                    0.6534609169216286,
                                    0.03188120936824628,
                                    0.3000204055518106,
                                    0.01463746815831465,
                                ],
                                [
                                    0.21081779299314274,
                                    0.42800565577017113,
                                    0.11919168521442913,
                                    0.241984866022257,
                                ],
                                [
                                    0.6091062267538878,
                                    0.02971722200942612,
                                    0.3443750957195513,
                                    0.016801455517134814,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860534,
                                    0.0014804440605522616,
                                ],
                                [
                                    0.04351305631228175,
                                    0.003005621214279275,
                                    0.8918758804741705,
                                    0.061605441999268415,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.6466463309947702,
                                    0.044666454055197154,
                                    0.288742605791682,
                                    0.019944609158350536,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.5862098572708075,
                                    0.040491864565612094,
                                    0.34917907951564464,
                                    0.024119198647935592,
                                ],
                                [
                                    0.3747129959589861,
                                    0.0018151597751467456,
                                    0.6204662230515878,
                                    0.003005621214279269,
                                ],
                                [
                                    0.3056158674706069,
                                    0.001480444060552261,
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                ],
                                [
                                    0.3101019327454384,
                                    0.023137423032686066,
                                    0.6204662230515878,
                                    0.04629442117028765,
                                ],
                                [
                                    0.3316328818268607,
                                    0.0016064739512637546,
                                    0.6635463371837133,
                                    0.00321430703816226,
                                ],
                                [
                                    0.3056158674706068,
                                    0.02280270731809158,
                                    0.6249522883264195,
                                    0.046629136884882134,
                                ],
                                [
                                    0.32683534076678267,
                                    0.001583234021915743,
                                    0.6683438782437913,
                                    0.0032375469675102716,
                                ],
                                [
                                    0.5384849635394924,
                                    0.012627737168817495,
                                    0.4386018697840949,
                                    0.010285429507595284,
                                ],
                                [
                                    0.21603704751088662,
                                    0.00506617498985139,
                                    0.7610497858127007,
                                    0.017846991686561387,
                                ],
                                [
                                    0.23138865200833328,
                                    0.11397243069668524,
                                    0.4386018697840948,
                                    0.21603704751088662,
                                ],
                                [
                                    0.33744776665345205,
                                    0.007913316051566468,
                                    0.6396390666701351,
                                    0.01499985062484631,
                                ],
                                [
                                    0.21603704751088665,
                                    0.10641086851771915,
                                    0.4539534742815415,
                                    0.22359860968985273,
                                ],
                                [
                                    0.3150596131841804,
                                    0.007388302844425396,
                                    0.6620272201394068,
                                    0.015524863831987383,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.10384008071698249,
                                    0.0050661749898513915,
                                    0.8496412417564566,
                                    0.04145250253670954,
                                ],
                                [
                                    0.11919168521442913,
                                    0.241984866022257,
                                    0.21081779299314274,
                                    0.42800565577017113,
                                ],
                                [
                                    0.3443750957195513,
                                    0.016801455517134814,
                                    0.6091062267538878,
                                    0.02971722200942612,
                                ],
                                [
                                    0.10384008071698247,
                                    0.21081779299314274,
                                    0.2261693974905894,
                                    0.4591727287992854,
                                ],
                                [
                                    0.3000204055518106,
                                    0.01463746815831465,
                                    0.6534609169216286,
                                    0.03188120936824628,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.043513056312281695,
                                    0.003005621214279271,
                                ],
                                [
                                    0.02143272261586059,
                                    0.0014804440605522655,
                                    0.9139562141705917,
                                    0.06313061915299542,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.3491790795156447,
                                    0.024119198647935595,
                                    0.5862098572708075,
                                    0.040491864565612094,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.28874260579168204,
                                    0.01994460915835054,
                                    0.6466463309947702,
                                    0.044666454055197154,
                                ],
                                [
                                    0.1333967159166805,
                                    0.0006461914998409581,
                                    0.8617825030938935,
                                    0.004174589489585057,
                                ],
                                [
                                    0.06429958742830123,
                                    0.0003114757852464733,
                                    0.9308796315822727,
                                    0.004509305204179541,
                                ],
                                [
                                    0.0687856527031328,
                                    0.005132256774672492,
                                    0.8617825030938935,
                                    0.06429958742830122,
                                ],
                                [
                                    0.07356156742501657,
                                    0.0003563420527887168,
                                    0.9216176515855573,
                                    0.0044644389366372975,
                                ],
                                [
                                    0.06429958742830123,
                                    0.004797541060078003,
                                    0.866268568368725,
                                    0.06463430314289571,
                                ],
                                [
                                    0.06876402636493853,
                                    0.0003331021234407053,
                                    0.9264151926456354,
                                    0.004487678865985309,
                                ],
                                [
                                    0.3679007033434344,
                                    0.008627452390698495,
                                    0.6091861299801529,
                                    0.014285714285714284,
                                ],
                                [
                                    0.04545278731482864,
                                    0.0010658902117323902,
                                    0.9316340460087587,
                                    0.02184727646468039,
                                ],
                                [
                                    0.06080439181227523,
                                    0.029949715648237816,
                                    0.6091861299801529,
                                    0.30005976255933403,
                                ],
                                [
                                    0.08867464346970123,
                                    0.0020794639908118116,
                                    0.888412189853886,
                                    0.020833702685600967,
                                ],
                                [
                                    0.04545278731482858,
                                    0.022388153469271723,
                                    0.6245377344775995,
                                    0.3076213247383002,
                                ],
                                [
                                    0.06628649000042956,
                                    0.0015544507836707396,
                                    0.9108003433231577,
                                    0.02135871589274204,
                                ],
                                [
                                    0.6606707252279942,
                                    0.032232963240846645,
                                    0.2928105972454448,
                                    0.014285714285714285,
                                ],
                                [
                                    0.021847276464680463,
                                    0.0010658902117323915,
                                    0.9316340460087587,
                                    0.04545278731482855,
                                ],
                                [
                                    0.03719888096212706,
                                    0.07552176319685502,
                                    0.2928105972454448,
                                    0.5944687585955731,
                                ],
                                [
                                    0.10747702886276418,
                                    0.005243615296217912,
                                    0.8460042936106749,
                                    0.041275062230343024,
                                ],
                                [
                                    0.021847276464680394,
                                    0.044354690167740775,
                                    0.3081622017428915,
                                    0.6256358316246874,
                                ],
                                [
                                    0.06312233869502343,
                                    0.0030796279373977477,
                                    0.8903589837784157,
                                    0.043439049589163184,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.060436473723962686,
                                    0.004174589489585059,
                                ],
                                [
                                    0.004509305204179589,
                                    0.0003114757852464765,
                                    0.9308796315822727,
                                    0.06429958742830122,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.12118603682432559,
                                    0.008370805317364349,
                                    0.8142028999621267,
                                    0.056240257896183345,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.06074956310036295,
                                    0.004196215827779292,
                                    0.8746393736860893,
                                    0.0604148473857684,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8617825030938935,
                                    0.004174589489585057,
                                    0.13339671591668045,
                                    0.0006461914998409577,
                                ],
                                [
                                    0.866268568368725,
                                    0.06463430314289571,
                                    0.06429958742830122,
                                    0.004797541060078002,
                                ],
                                [
                                    0.9095729388571238,
                                    0.021329932654497036,
                                    0.06751389446646348,
                                    0.0015832340219157429,
                                ],
                                [
                                    0.8617825030938935,
                                    0.06429958742830123,
                                    0.06878565270313274,
                                    0.005132256774672487,
                                ],
                                [
                                    0.904862617226019,
                                    0.021219473296175836,
                                    0.0722242160975683,
                                    0.001693693380236943,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6245377344775995,
                                    0.3076213247383002,
                                    0.045452787314828554,
                                    0.02238815346927171,
                                ],
                                [
                                    0.8306411063534912,
                                    0.10151795286240844,
                                    0.06045263793967486,
                                    0.007388302844425396,
                                ],
                                [
                                    0.6091861299801529,
                                    0.30005976255933403,
                                    0.06080439181227523,
                                    0.029949715648237816,
                                ],
                                [
                                    0.8102233268661931,
                                    0.09902256567329373,
                                    0.08087041742697293,
                                    0.00988369003354011,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.3081622017428915,
                                    0.6256358316246874,
                                    0.02184727646468039,
                                    0.04435469016774077,
                                ],
                                [
                                    0.7273322790251555,
                                    0.20646575434242337,
                                    0.05156449847410651,
                                    0.01463746815831465,
                                ],
                                [
                                    0.2928105972454448,
                                    0.5944687585955731,
                                    0.03719888096212706,
                                    0.07552176319685502,
                                ],
                                [
                                    0.6910990310061899,
                                    0.19618032483482808,
                                    0.08779774649307216,
                                    0.02492289766590993,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.6479025186990492,
                                    0.2871517023728085,
                                    0.04500116976979164,
                                    0.01994460915835054,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.6031332746824886,
                                    0.26730988317582144,
                                    0.08977041378635228,
                                    0.0397864283553376,
                                ],
                                [
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                    0.3056158674706068,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.6204662230515879,
                                    0.0030056212142792692,
                                    0.374712995958986,
                                    0.0018151597751467452,
                                ],
                                [
                                    0.6249522883264195,
                                    0.046629136884882134,
                                    0.3056158674706068,
                                    0.02280270731809158,
                                ],
                                [
                                    0.6561933680786523,
                                    0.015388057132649397,
                                    0.320893465244935,
                                    0.007525109543763382,
                                ],
                                [
                                    0.6204662230515879,
                                    0.046294421170287654,
                                    0.31010193274543835,
                                    0.023137423032686063,
                                ],
                                [
                                    0.6514830464475475,
                                    0.015277597774328197,
                                    0.32560378687603986,
                                    0.007635568902084582,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.4386018697840949,
                                    0.010285429507595284,
                                    0.5384849635394924,
                                    0.012627737168817495,
                                ],
                                [
                                    0.4539534742815415,
                                    0.22359860968985273,
                                    0.21603704751088665,
                                    0.10641086851771915,
                                ],
                                [
                                    0.6037624234597074,
                                    0.07378966051168682,
                                    0.28733132083345875,
                                    0.03511659519514703,
                                ],
                                [
                                    0.43860186978409477,
                                    0.2160370475108866,
                                    0.23138865200833333,
                                    0.11397243069668525,
                                ],
                                [
                                    0.5833446439724093,
                                    0.0712942733225721,
                                    0.3077491003207568,
                                    0.03761198238426175,
                                ],
                                [
                                    0.8496412417564566,
                                    0.04145250253670954,
                                    0.10384008071698246,
                                    0.005066174989851391,
                                ],
                                [
                                    0.2108177929931427,
                                    0.010285429507595282,
                                    0.7426635294802963,
                                    0.03623324801896565,
                                ],
                                [
                                    0.2261693974905894,
                                    0.4591727287992854,
                                    0.10384008071698247,
                                    0.21081779299314274,
                                ],
                                [
                                    0.5338107736516757,
                                    0.15153135263819908,
                                    0.24508600384758628,
                                    0.06957186986253894,
                                ],
                                [
                                    0.21081779299314274,
                                    0.42800565577017113,
                                    0.11919168521442913,
                                    0.241984866022257,
                                ],
                                [
                                    0.49757752563271007,
                                    0.1412459231306038,
                                    0.28131925186655193,
                                    0.07985729937013422,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860534,
                                    0.0014804440605522616,
                                ],
                                [
                                    0.04351305631228175,
                                    0.003005621214279275,
                                    0.8918758804741705,
                                    0.061605441999268415,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.4790131786467894,
                                    0.212299606403178,
                                    0.21389050982205146,
                                    0.09479670512798105,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.4342439346302287,
                                    0.19245778720619094,
                                    0.2586597538386121,
                                    0.11463852432496811,
                                ],
                                [
                                    0.3747129959589861,
                                    0.0018151597751467456,
                                    0.6204662230515878,
                                    0.003005621214279269,
                                ],
                                [
                                    0.3056158674706069,
                                    0.001480444060552261,
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                ],
                                [
                                    0.3101019327454384,
                                    0.023137423032686066,
                                    0.6204662230515878,
                                    0.04629442117028765,
                                ],
                                [
                                    0.3256037868760399,
                                    0.007635568902084584,
                                    0.6514830464475474,
                                    0.015277597774328196,
                                ],
                                [
                                    0.3056158674706068,
                                    0.02280270731809158,
                                    0.6249522883264195,
                                    0.046629136884882134,
                                ],
                                [
                                    0.320893465244935,
                                    0.007525109543763382,
                                    0.6561933680786523,
                                    0.015388057132649397,
                                ],
                                [
                                    0.5384849635394924,
                                    0.012627737168817495,
                                    0.4386018697840949,
                                    0.010285429507595284,
                                ],
                                [
                                    0.21603704751088662,
                                    0.00506617498985139,
                                    0.7610497858127007,
                                    0.017846991686561387,
                                ],
                                [
                                    0.23138865200833328,
                                    0.11397243069668524,
                                    0.4386018697840948,
                                    0.21603704751088662,
                                ],
                                [
                                    0.30774910032075675,
                                    0.03761198238426174,
                                    0.5833446439724094,
                                    0.07129427332257211,
                                ],
                                [
                                    0.21603704751088665,
                                    0.10641086851771915,
                                    0.4539534742815415,
                                    0.22359860968985273,
                                ],
                                [
                                    0.28733132083345875,
                                    0.03511659519514703,
                                    0.6037624234597074,
                                    0.07378966051168682,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.10384008071698249,
                                    0.0050661749898513915,
                                    0.8496412417564566,
                                    0.04145250253670954,
                                ],
                                [
                                    0.11919168521442913,
                                    0.241984866022257,
                                    0.21081779299314274,
                                    0.42800565577017113,
                                ],
                                [
                                    0.28131925186655193,
                                    0.07985729937013422,
                                    0.49757752563271007,
                                    0.1412459231306038,
                                ],
                                [
                                    0.10384008071698247,
                                    0.21081779299314274,
                                    0.2261693974905894,
                                    0.4591727287992854,
                                ],
                                [
                                    0.24508600384758628,
                                    0.06957186986253894,
                                    0.5338107736516757,
                                    0.15153135263819908,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.043513056312281695,
                                    0.003005621214279271,
                                ],
                                [
                                    0.02143272261586059,
                                    0.0014804440605522655,
                                    0.9139562141705917,
                                    0.06313061915299542,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.25865975383861217,
                                    0.11463852432496813,
                                    0.4342439346302287,
                                    0.19245778720619094,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.21389050982205152,
                                    0.09479670512798108,
                                    0.4790131786467894,
                                    0.212299606403178,
                                ],
                                [
                                    0.1333967159166805,
                                    0.0006461914998409581,
                                    0.8617825030938935,
                                    0.004174589489585057,
                                ],
                                [
                                    0.06429958742830123,
                                    0.0003114757852464733,
                                    0.9308796315822727,
                                    0.004509305204179541,
                                ],
                                [
                                    0.0687856527031328,
                                    0.005132256774672492,
                                    0.8617825030938935,
                                    0.06429958742830122,
                                ],
                                [
                                    0.07222421609756836,
                                    0.0016936933802369446,
                                    0.9048626172260189,
                                    0.021219473296175833,
                                ],
                                [
                                    0.06429958742830123,
                                    0.004797541060078003,
                                    0.866268568368725,
                                    0.06463430314289571,
                                ],
                                [
                                    0.0675138944664635,
                                    0.001583234021915743,
                                    0.9095729388571238,
                                    0.021329932654497036,
                                ],
                                [
                                    0.3679007033434344,
                                    0.008627452390698495,
                                    0.6091861299801529,
                                    0.014285714285714284,
                                ],
                                [
                                    0.04545278731482864,
                                    0.0010658902117323902,
                                    0.9316340460087587,
                                    0.02184727646468039,
                                ],
                                [
                                    0.06080439181227523,
                                    0.029949715648237816,
                                    0.6091861299801529,
                                    0.30005976255933403,
                                ],
                                [
                                    0.08087041742697293,
                                    0.00988369003354011,
                                    0.8102233268661931,
                                    0.09902256567329373,
                                ],
                                [
                                    0.04545278731482858,
                                    0.022388153469271723,
                                    0.6245377344775995,
                                    0.3076213247383002,
                                ],
                                [
                                    0.0604526379396749,
                                    0.0073883028444254005,
                                    0.8306411063534912,
                                    0.10151795286240844,
                                ],
                                [
                                    0.6606707252279942,
                                    0.032232963240846645,
                                    0.2928105972454448,
                                    0.014285714285714285,
                                ],
                                [
                                    0.021847276464680463,
                                    0.0010658902117323915,
                                    0.9316340460087587,
                                    0.04545278731482855,
                                ],
                                [
                                    0.03719888096212706,
                                    0.07552176319685502,
                                    0.2928105972454448,
                                    0.5944687585955731,
                                ],
                                [
                                    0.08779774649307216,
                                    0.02492289766590993,
                                    0.6910990310061899,
                                    0.19618032483482808,
                                ],
                                [
                                    0.021847276464680394,
                                    0.044354690167740775,
                                    0.3081622017428915,
                                    0.6256358316246874,
                                ],
                                [
                                    0.05156449847410652,
                                    0.014637468158314652,
                                    0.7273322790251555,
                                    0.20646575434242337,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.060436473723962686,
                                    0.004174589489585059,
                                ],
                                [
                                    0.004509305204179589,
                                    0.0003114757852464765,
                                    0.9308796315822727,
                                    0.06429958742830122,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.08977041378635232,
                                    0.03978642835533761,
                                    0.6031332746824886,
                                    0.26730988317582144,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.04500116976979168,
                                    0.019944609158350557,
                                    0.6479025186990492,
                                    0.2871517023728085,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8617825030938935,
                                    0.004174589489585057,
                                    0.13339671591668045,
                                    0.0006461914998409577,
                                ],
                                [
                                    0.866268568368725,
                                    0.06463430314289571,
                                    0.06429958742830122,
                                    0.004797541060078002,
                                ],
                                [
                                    0.8875985010232221,
                                    0.04330437048839868,
                                    0.06588282145021696,
                                    0.00321430703816226,
                                ],
                                [
                                    0.8617825030938935,
                                    0.06429958742830123,
                                    0.06878565270313274,
                                    0.005132256774672487,
                                ],
                                [
                                    0.8830019763900694,
                                    0.0430801141321254,
                                    0.07047934608336968,
                                    0.0034385633944355436,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6245377344775995,
                                    0.3076213247383002,
                                    0.045452787314828554,
                                    0.02238815346927171,
                                ],
                                [
                                    0.726055687340008,
                                    0.2061033718758917,
                                    0.05284109015925395,
                                    0.014999850624846312,
                                ],
                                [
                                    0.6091861299801529,
                                    0.30005976255933403,
                                    0.06080439181227523,
                                    0.029949715648237816,
                                ],
                                [
                                    0.7082086956534467,
                                    0.20103719688604033,
                                    0.07068808184581535,
                                    0.020066025614697704,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.3081622017428915,
                                    0.6256358316246874,
                                    0.02184727646468039,
                                    0.04435469016774077,
                                ],
                                [
                                    0.5146279560853149,
                                    0.419170077282264,
                                    0.03648474462299504,
                                    0.02971722200942612,
                                ],
                                [
                                    0.2928105972454448,
                                    0.5944687585955731,
                                    0.03719888096212706,
                                    0.07552176319685502,
                                ],
                                [
                                    0.4889909220802729,
                                    0.398288433760745,
                                    0.06212177862803699,
                                    0.05059886553094509,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.3520742413716028,
                                    0.582979979700255,
                                    0.024453914362530086,
                                    0.040491864565612094,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.3277463568997842,
                                    0.5426968009585259,
                                    0.04878179883434868,
                                    0.0807750433073412,
                                ],
                                [
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                    0.3056158674706068,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.6204662230515879,
                                    0.0030056212142792692,
                                    0.374712995958986,
                                    0.0018151597751467452,
                                ],
                                [
                                    0.6249522883264195,
                                    0.046629136884882134,
                                    0.3056158674706068,
                                    0.02280270731809158,
                                ],
                                [
                                    0.6403403454590689,
                                    0.03124107975223274,
                                    0.3131409770143702,
                                    0.015277597774328196,
                                ],
                                [
                                    0.6204662230515879,
                                    0.046294421170287654,
                                    0.31010193274543835,
                                    0.023137423032686063,
                                ],
                                [
                                    0.6357438208259162,
                                    0.03101682339595946,
                                    0.31773750164752296,
                                    0.01550185413060148,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.4386018697840949,
                                    0.010285429507595284,
                                    0.5384849635394924,
                                    0.012627737168817495,
                                ],
                                [
                                    0.4539534742815415,
                                    0.22359860968985273,
                                    0.21603704751088665,
                                    0.10641086851771915,
                                ],
                                [
                                    0.5277431347932283,
                                    0.1498089491781659,
                                    0.2511536427060337,
                                    0.07129427332257211,
                                ],
                                [
                                    0.43860186978409477,
                                    0.2160370475108866,
                                    0.23138865200833333,
                                    0.11397243069668525,
                                ],
                                [
                                    0.5098961431066669,
                                    0.1447427741883145,
                                    0.2690006343925951,
                                    0.07636044831242352,
                                ],
                                [
                                    0.8496412417564566,
                                    0.04145250253670954,
                                    0.10384008071698246,
                                    0.005066174989851391,
                                ],
                                [
                                    0.2108177929931427,
                                    0.010285429507595282,
                                    0.7426635294802963,
                                    0.03623324801896565,
                                ],
                                [
                                    0.2261693974905894,
                                    0.4591727287992854,
                                    0.10384008071698247,
                                    0.21081779299314274,
                                ],
                                [
                                    0.37770075012878845,
                                    0.30764137616108633,
                                    0.1734119505795214,
                                    0.1412459231306038,
                                ],
                                [
                                    0.21081779299314274,
                                    0.42800565577017113,
                                    0.11919168521442913,
                                    0.241984866022257,
                                ],
                                [
                                    0.35206371612374654,
                                    0.28675973263956733,
                                    0.19904898458456335,
                                    0.16212756665212277,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860534,
                                    0.0014804440605522616,
                                ],
                                [
                                    0.04351305631228175,
                                    0.003005621214279275,
                                    0.8918758804741705,
                                    0.061605441999268415,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.26029872799029125,
                                    0.43101405705967616,
                                    0.11622942774384161,
                                    0.19245778720619094,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.23597084351847267,
                                    0.390730878317947,
                                    0.1405573122156602,
                                    0.23274096594792004,
                                ],
                                [
                                    0.3747129959589861,
                                    0.0018151597751467456,
                                    0.6204662230515878,
                                    0.003005621214279269,
                                ],
                                [
                                    0.3056158674706069,
                                    0.001480444060552261,
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                ],
                                [
                                    0.3101019327454384,
                                    0.023137423032686066,
                                    0.6204662230515878,
                                    0.04629442117028765,
                                ],
                                [
                                    0.317737501647523,
                                    0.015501854130601483,
                                    0.6357438208259161,
                                    0.03101682339595945,
                                ],
                                [
                                    0.3056158674706068,
                                    0.02280270731809158,
                                    0.6249522883264195,
                                    0.046629136884882134,
                                ],
                                [
                                    0.3131409770143702,
                                    0.015277597774328196,
                                    0.6403403454590689,
                                    0.03124107975223274,
                                ],
                                [
                                    0.5384849635394924,
                                    0.012627737168817495,
                                    0.4386018697840949,
                                    0.010285429507595284,
                                ],
                                [
                                    0.21603704751088662,
                                    0.00506617498985139,
                                    0.7610497858127007,
                                    0.017846991686561387,
                                ],
                                [
                                    0.23138865200833328,
                                    0.11397243069668524,
                                    0.4386018697840948,
                                    0.21603704751088662,
                                ],
                                [
                                    0.26900063439259503,
                                    0.0763604483124235,
                                    0.509896143106667,
                                    0.14474277418831452,
                                ],
                                [
                                    0.21603704751088665,
                                    0.10641086851771915,
                                    0.4539534742815415,
                                    0.22359860968985273,
                                ],
                                [
                                    0.2511536427060337,
                                    0.07129427332257211,
                                    0.5277431347932283,
                                    0.1498089491781659,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.10384008071698249,
                                    0.0050661749898513915,
                                    0.8496412417564566,
                                    0.04145250253670954,
                                ],
                                [
                                    0.11919168521442913,
                                    0.241984866022257,
                                    0.21081779299314274,
                                    0.42800565577017113,
                                ],
                                [
                                    0.19904898458456335,
                                    0.16212756665212277,
                                    0.35206371612374654,
                                    0.28675973263956733,
                                ],
                                [
                                    0.10384008071698247,
                                    0.21081779299314274,
                                    0.2261693974905894,
                                    0.4591727287992854,
                                ],
                                [
                                    0.1734119505795214,
                                    0.1412459231306038,
                                    0.37770075012878845,
                                    0.30764137616108633,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.043513056312281695,
                                    0.003005621214279271,
                                ],
                                [
                                    0.02143272261586059,
                                    0.0014804440605522655,
                                    0.9139562141705917,
                                    0.06313061915299542,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.14055731221566023,
                                    0.23274096594792007,
                                    0.23597084351847267,
                                    0.390730878317947,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.11622942774384162,
                                    0.19245778720619097,
                                    0.26029872799029125,
                                    0.43101405705967616,
                                ],
                                [
                                    0.1333967159166805,
                                    0.0006461914998409581,
                                    0.8617825030938935,
                                    0.004174589489585057,
                                ],
                                [
                                    0.06429958742830123,
                                    0.0003114757852464733,
                                    0.9308796315822727,
                                    0.004509305204179541,
                                ],
                                [
                                    0.0687856527031328,
                                    0.005132256774672492,
                                    0.8617825030938935,
                                    0.06429958742830122,
                                ],
                                [
                                    0.07047934608336975,
                                    0.003438563394435547,
                                    0.8830019763900694,
                                    0.04308011413212539,
                                ],
                                [
                                    0.06429958742830123,
                                    0.004797541060078003,
                                    0.866268568368725,
                                    0.06463430314289571,
                                ],
                                [
                                    0.06588282145021697,
                                    0.0032143070381622603,
                                    0.8875985010232221,
                                    0.04330437048839868,
                                ],
                                [
                                    0.3679007033434344,
                                    0.008627452390698495,
                                    0.6091861299801529,
                                    0.014285714285714284,
                                ],
                                [
                                    0.04545278731482864,
                                    0.0010658902117323902,
                                    0.9316340460087587,
                                    0.02184727646468039,
                                ],
                                [
                                    0.06080439181227523,
                                    0.029949715648237816,
                                    0.6091861299801529,
                                    0.30005976255933403,
                                ],
                                [
                                    0.07068808184581535,
                                    0.020066025614697704,
                                    0.7082086956534467,
                                    0.20103719688604033,
                                ],
                                [
                                    0.04545278731482858,
                                    0.022388153469271723,
                                    0.6245377344775995,
                                    0.3076213247383002,
                                ],
                                [
                                    0.05284109015925398,
                                    0.01499985062484632,
                                    0.726055687340008,
                                    0.2061033718758917,
                                ],
                                [
                                    0.6606707252279942,
                                    0.032232963240846645,
                                    0.2928105972454448,
                                    0.014285714285714285,
                                ],
                                [
                                    0.021847276464680463,
                                    0.0010658902117323915,
                                    0.9316340460087587,
                                    0.04545278731482855,
                                ],
                                [
                                    0.03719888096212706,
                                    0.07552176319685502,
                                    0.2928105972454448,
                                    0.5944687585955731,
                                ],
                                [
                                    0.06212177862803699,
                                    0.05059886553094509,
                                    0.4889909220802729,
                                    0.398288433760745,
                                ],
                                [
                                    0.021847276464680394,
                                    0.044354690167740775,
                                    0.3081622017428915,
                                    0.6256358316246874,
                                ],
                                [
                                    0.036484744622995044,
                                    0.029717222009426125,
                                    0.5146279560853149,
                                    0.419170077282264,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.060436473723962686,
                                    0.004174589489585059,
                                ],
                                [
                                    0.004509305204179589,
                                    0.0003114757852464765,
                                    0.9308796315822727,
                                    0.06429958742830122,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.0487817988343487,
                                    0.08077504330734124,
                                    0.3277463568997842,
                                    0.5426968009585259,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.024453914362530107,
                                    0.04049186456561213,
                                    0.3520742413716028,
                                    0.582979979700255,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8617825030938935,
                                    0.004174589489585057,
                                    0.13339671591668045,
                                    0.0006461914998409577,
                                ],
                                [
                                    0.866268568368725,
                                    0.06463430314289571,
                                    0.06429958742830122,
                                    0.004797541060078002,
                                ],
                                [
                                    0.8707562472347103,
                                    0.06014662427691039,
                                    0.06463268955174192,
                                    0.004464438936637297,
                                ],
                                [
                                    0.8617825030938935,
                                    0.06429958742830123,
                                    0.06878565270313274,
                                    0.005132256774672487,
                                ],
                                [
                                    0.8662469420305309,
                                    0.05983514849166392,
                                    0.06914199475592146,
                                    0.00477591472188377,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6245377344775995,
                                    0.3076213247383002,
                                    0.045452787314828554,
                                    0.02238815346927171,
                                ],
                                [
                                    0.6458964503703416,
                                    0.2862626088455581,
                                    0.047007238098499285,
                                    0.020833702685600967,
                                ],
                                [
                                    0.6091861299801529,
                                    0.30005976255933403,
                                    0.06080439181227523,
                                    0.029949715648237816,
                                ],
                                [
                                    0.6300198326657538,
                                    0.27922605987373306,
                                    0.06288385580308704,
                                    0.027870251657426,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.3081622017428915,
                                    0.6256358316246874,
                                    0.02184727646468039,
                                    0.04435469016774077,
                                ],
                                [
                                    0.3516012513320547,
                                    0.582196782035524,
                                    0.024926904402078145,
                                    0.04127506223034302,
                                ],
                                [
                                    0.2928105972454448,
                                    0.5944687585955731,
                                    0.03719888096212706,
                                    0.07552176319685502,
                                ],
                                [
                                    0.3340856594757879,
                                    0.55319369636523,
                                    0.04244249625834499,
                                    0.0702781479006371,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.12533738638456263,
                                    0.8097168346872952,
                                    0.008705521031958834,
                                    0.05624025789618335,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.11667673162014604,
                                    0.753766426238164,
                                    0.017366175796375425,
                                    0.11219066634531447,
                                ],
                                [
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                    0.3056158674706068,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.6204662230515879,
                                    0.0030056212142792692,
                                    0.374712995958986,
                                    0.0018151597751467452,
                                ],
                                [
                                    0.6249522883264195,
                                    0.046629136884882134,
                                    0.3056158674706068,
                                    0.02280270731809158,
                                ],
                                [
                                    0.6281898352939297,
                                    0.04339158991737186,
                                    0.30719910149252255,
                                    0.021219473296175833,
                                ],
                                [
                                    0.6204662230515879,
                                    0.046294421170287654,
                                    0.31010193274543835,
                                    0.023137423032686063,
                                ],
                                [
                                    0.6236805300897502,
                                    0.04308011413212539,
                                    0.3117084066967021,
                                    0.021530949081422304,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.4386018697840949,
                                    0.010285429507595284,
                                    0.5384849635394924,
                                    0.012627737168817495,
                                ],
                                [
                                    0.4539534742815415,
                                    0.22359860968985273,
                                    0.21603704751088665,
                                    0.10641086851771915,
                                ],
                                [
                                    0.46947833811352885,
                                    0.20807374585786534,
                                    0.22342535035531202,
                                    0.09902256567329375,
                                ],
                                [
                                    0.43860186978409477,
                                    0.2160370475108866,
                                    0.23138865200833333,
                                    0.11397243069668525,
                                ],
                                [
                                    0.45360172040894103,
                                    0.20103719688604027,
                                    0.23930196805989978,
                                    0.10605911464511877,
                                ],
                                [
                                    0.8496412417564566,
                                    0.04145250253670954,
                                    0.10384008071698246,
                                    0.005066174989851391,
                                ],
                                [
                                    0.2108177929931427,
                                    0.010285429507595282,
                                    0.7426635294802963,
                                    0.03623324801896565,
                                ],
                                [
                                    0.2261693974905894,
                                    0.4591727287992854,
                                    0.10384008071698247,
                                    0.21081779299314274,
                                ],
                                [
                                    0.25805060685883574,
                                    0.42729151943103905,
                                    0.11847754887529714,
                                    0.19618032483482806,
                                ],
                                [
                                    0.21081779299314274,
                                    0.42800565577017113,
                                    0.11919168521442913,
                                    0.241984866022257,
                                ],
                                [
                                    0.2405350150025689,
                                    0.39828843376074496,
                                    0.135993140731564,
                                    0.22518341050512214,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860534,
                                    0.0014804440605522616,
                                ],
                                [
                                    0.04351305631228175,
                                    0.003005621214279275,
                                    0.8918758804741705,
                                    0.061605441999268415,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.09266557564231039,
                                    0.598647209407657,
                                    0.041377331774211074,
                                    0.26730988317582144,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.0840049208778938,
                                    0.5426968009585259,
                                    0.05003798653862766,
                                    0.32326029162495257,
                                ],
                                [
                                    0.3747129959589861,
                                    0.0018151597751467456,
                                    0.6204662230515878,
                                    0.003005621214279269,
                                ],
                                [
                                    0.3056158674706069,
                                    0.001480444060552261,
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                ],
                                [
                                    0.3101019327454384,
                                    0.023137423032686066,
                                    0.6204662230515878,
                                    0.04629442117028765,
                                ],
                                [
                                    0.31170840669670213,
                                    0.021530949081422307,
                                    0.6236805300897501,
                                    0.04308011413212538,
                                ],
                                [
                                    0.3056158674706068,
                                    0.02280270731809158,
                                    0.6249522883264195,
                                    0.046629136884882134,
                                ],
                                [
                                    0.30719910149252255,
                                    0.021219473296175833,
                                    0.6281898352939297,
                                    0.04339158991737186,
                                ],
                                [
                                    0.5384849635394924,
                                    0.012627737168817495,
                                    0.4386018697840949,
                                    0.010285429507595284,
                                ],
                                [
                                    0.21603704751088662,
                                    0.00506617498985139,
                                    0.7610497858127007,
                                    0.017846991686561387,
                                ],
                                [
                                    0.23138865200833328,
                                    0.11397243069668524,
                                    0.4386018697840948,
                                    0.21603704751088662,
                                ],
                                [
                                    0.23930196805989976,
                                    0.10605911464511876,
                                    0.45360172040894114,
                                    0.2010371968860403,
                                ],
                                [
                                    0.21603704751088665,
                                    0.10641086851771915,
                                    0.4539534742815415,
                                    0.22359860968985273,
                                ],
                                [
                                    0.22342535035531202,
                                    0.09902256567329375,
                                    0.46947833811352885,
                                    0.20807374585786534,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.10384008071698249,
                                    0.0050661749898513915,
                                    0.8496412417564566,
                                    0.04145250253670954,
                                ],
                                [
                                    0.11919168521442913,
                                    0.241984866022257,
                                    0.21081779299314274,
                                    0.42800565577017113,
                                ],
                                [
                                    0.135993140731564,
                                    0.22518341050512214,
                                    0.2405350150025689,
                                    0.39828843376074496,
                                ],
                                [
                                    0.10384008071698247,
                                    0.21081779299314274,
                                    0.2261693974905894,
                                    0.4591727287992854,
                                ],
                                [
                                    0.11847754887529714,
                                    0.19618032483482806,
                                    0.25805060685883574,
                                    0.42729151943103905,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.043513056312281695,
                                    0.003005621214279271,
                                ],
                                [
                                    0.02143272261586059,
                                    0.0014804440605522655,
                                    0.9139562141705917,
                                    0.06313061915299542,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.05003798653862768,
                                    0.3232602916249526,
                                    0.0840049208778938,
                                    0.5426968009585259,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.04137733177421108,
                                    0.2673098831758215,
                                    0.09266557564231039,
                                    0.598647209407657,
                                ],
                                [
                                    0.1333967159166805,
                                    0.0006461914998409581,
                                    0.8617825030938935,
                                    0.004174589489585057,
                                ],
                                [
                                    0.06429958742830123,
                                    0.0003114757852464733,
                                    0.9308796315822727,
                                    0.004509305204179541,
                                ],
                                [
                                    0.0687856527031328,
                                    0.005132256774672492,
                                    0.8617825030938935,
                                    0.06429958742830122,
                                ],
                                [
                                    0.06914199475592152,
                                    0.004775914721883774,
                                    0.8662469420305308,
                                    0.059835148491663916,
                                ],
                                [
                                    0.06429958742830123,
                                    0.004797541060078003,
                                    0.866268568368725,
                                    0.06463430314289571,
                                ],
                                [
                                    0.06463268955174194,
                                    0.0044644389366372975,
                                    0.8707562472347103,
                                    0.06014662427691039,
                                ],
                                [
                                    0.3679007033434344,
                                    0.008627452390698495,
                                    0.6091861299801529,
                                    0.014285714285714284,
                                ],
                                [
                                    0.04545278731482864,
                                    0.0010658902117323902,
                                    0.9316340460087587,
                                    0.02184727646468039,
                                ],
                                [
                                    0.06080439181227523,
                                    0.029949715648237816,
                                    0.6091861299801529,
                                    0.30005976255933403,
                                ],
                                [
                                    0.06288385580308704,
                                    0.027870251657426,
                                    0.6300198326657538,
                                    0.27922605987373306,
                                ],
                                [
                                    0.04545278731482858,
                                    0.022388153469271723,
                                    0.6245377344775995,
                                    0.3076213247383002,
                                ],
                                [
                                    0.04700723809849932,
                                    0.02083370268560098,
                                    0.6458964503703416,
                                    0.2862626088455581,
                                ],
                                [
                                    0.6606707252279942,
                                    0.032232963240846645,
                                    0.2928105972454448,
                                    0.014285714285714285,
                                ],
                                [
                                    0.021847276464680463,
                                    0.0010658902117323915,
                                    0.9316340460087587,
                                    0.04545278731482855,
                                ],
                                [
                                    0.03719888096212706,
                                    0.07552176319685502,
                                    0.2928105972454448,
                                    0.5944687585955731,
                                ],
                                [
                                    0.04244249625834499,
                                    0.0702781479006371,
                                    0.3340856594757879,
                                    0.55319369636523,
                                ],
                                [
                                    0.021847276464680394,
                                    0.044354690167740775,
                                    0.3081622017428915,
                                    0.6256358316246874,
                                ],
                                [
                                    0.02492690440207815,
                                    0.041275062230343024,
                                    0.3516012513320547,
                                    0.582196782035524,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.060436473723962686,
                                    0.004174589489585059,
                                ],
                                [
                                    0.004509305204179589,
                                    0.0003114757852464765,
                                    0.9308796315822727,
                                    0.06429958742830122,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.017366175796375432,
                                    0.11219066634531451,
                                    0.11667673162014604,
                                    0.753766426238164,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.008705521031958841,
                                    0.0562402578961834,
                                    0.12533738638456263,
                                    0.8097168346872952,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.8461152733864915,
                                    0.019841819196987055,
                                    0.1309715599370957,
                                    0.0030713474794257217,
                                ],
                                [
                                    0.8674375366440308,
                                    0.0647215225718689,
                                    0.06313061915299543,
                                    0.004710321631104814,
                                ],
                                [
                                    0.9276653245441104,
                                    0.004493734671789248,
                                    0.06751389446646348,
                                    0.0003270463176367665,
                                ],
                                [
                                    0.8461152733864915,
                                    0.06313061915299543,
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                ],
                                [
                                    0.9048626172260189,
                                    0.004383275313468047,
                                    0.09031660178455507,
                                    0.00043750567595796693,
                                ],
                                [
                                    0.8496412417564566,
                                    0.10384008071698246,
                                    0.04145250253670954,
                                    0.005066174989851391,
                                ],
                                [
                                    0.5555718601682373,
                                    0.06789998409762983,
                                    0.3355218841249287,
                                    0.041006271609204024,
                                ],
                                [
                                    0.6285380192557186,
                                    0.3095916987202738,
                                    0.04145250253670954,
                                    0.020417779487298063,
                                ],
                                [
                                    0.9166341953839124,
                                    0.021495522592080027,
                                    0.060452637939674855,
                                    0.0014176440843327517,
                                ],
                                [
                                    0.5555718601682373,
                                    0.27365160210092115,
                                    0.11441866162419075,
                                    0.056357876106650696,
                                ],
                                [
                                    0.8102233268661932,
                                    0.019000135402965312,
                                    0.16686350645739398,
                                    0.003913031273447466,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.2391963274335293,
                                    0.06789998409762983,
                                    0.5397004500657328,
                                    0.15320323840310818,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.9019168239993326,
                                    0.044002936295140405,
                                    0.05156449847410651,
                                    0.002515741231420529,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.6910990310061899,
                                    0.03371750678754513,
                                    0.26238229146724923,
                                    0.012801170739015813,
                                ],
                                [
                                    0.6895633515399671,
                                    0.3056158674706068,
                                    0.0033403369288737567,
                                    0.001480444060552262,
                                ],
                                [
                                    0.04476924401656064,
                                    0.01984181919698706,
                                    0.6481344444522802,
                                    0.287254492334172,
                                ],
                                [
                                    0.06609150727410001,
                                    0.8857989117804657,
                                    0.0033403369288737563,
                                    0.04476924401656064,
                                ],
                                [
                                    0.8903877670166607,
                                    0.06150265203790494,
                                    0.04500116976979165,
                                    0.0031084111756427514,
                                ],
                                [
                                    0.044769244016560676,
                                    0.6000248635068458,
                                    0.02466260018641309,
                                    0.33054329229018037,
                                ],
                                [
                                    0.6031332746824886,
                                    0.041660832840917886,
                                    0.3322556621039636,
                                    0.022950230372629804,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6305083932376921,
                                    0.04704369073370201,
                                    0.3000597625593341,
                                    0.022388153469271706,
                                ],
                                [
                                    0.6742857537656389,
                                    0.0032663302057552757,
                                    0.320893465244935,
                                    0.0015544507836707385,
                                ],
                                [
                                    0.6091861299801528,
                                    0.04545278731482854,
                                    0.3213820258168734,
                                    0.02397905688814517,
                                ],
                                [
                                    0.6514830464475473,
                                    0.003155870847434075,
                                    0.34369617256302665,
                                    0.0016649101419919392,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.40000066429147924,
                                    0.048886635000210864,
                                    0.4910930800016869,
                                    0.060019620706622985,
                                ],
                                [
                                    0.4729668233789605,
                                    0.23296379503282033,
                                    0.19702369841346765,
                                    0.09704568317475157,
                                ],
                                [
                                    0.6897555124901286,
                                    0.01617510592165228,
                                    0.28733132083345875,
                                    0.006738060754760498,
                                ],
                                [
                                    0.4000006642914793,
                                    0.19702369841346767,
                                    0.26998985750094884,
                                    0.1329857797941042,
                                ],
                                [
                                    0.5833446439724094,
                                    0.013679718732537567,
                                    0.39374218935117783,
                                    0.009233447943875211,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.7083953186258528,
                                    0.03456136225405654,
                                    0.24508600384758628,
                                    0.011957315272504392,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.49757752563271007,
                                    0.024275932746461257,
                                    0.455903796840729,
                                    0.022242744780099678,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.05355522649838601,
                                    0.7177799888219099,
                                    0.01587661770458776,
                                    0.21278816697511635,
                                ],
                                [
                                    0.7214984269644008,
                                    0.049836788355895056,
                                    0.21389050982205146,
                                    0.014774274857652633,
                                ],
                                [
                                    0.03223296324084667,
                                    0.4320059405482901,
                                    0.0371988809621271,
                                    0.4985622152487361,
                                ],
                                [
                                    0.4342439346302288,
                                    0.029994969158908,
                                    0.5011450021562235,
                                    0.03461609405463969,
                                ],
                                [
                                    0.3679007033434344,
                                    0.008627452390698495,
                                    0.6091861299801529,
                                    0.014285714285714284,
                                ],
                                [
                                    0.3000597625593341,
                                    0.007036548971825033,
                                    0.6770270707642532,
                                    0.015876617704587745,
                                ],
                                [
                                    0.32138202581687336,
                                    0.023979056888145167,
                                    0.6091861299801529,
                                    0.04545278731482855,
                                ],
                                [
                                    0.3436961725630266,
                                    0.0016649101419919387,
                                    0.6514830464475474,
                                    0.0031558708474340755,
                                ],
                                [
                                    0.3000597625593341,
                                    0.022388153469271706,
                                    0.6305083932376921,
                                    0.04704369073370201,
                                ],
                                [
                                    0.320893465244935,
                                    0.0015544507836707385,
                                    0.6742857537656389,
                                    0.0032663302057552757,
                                ],
                                [
                                    0.4910930800016869,
                                    0.060019620706622985,
                                    0.40000066429147924,
                                    0.048886635000210864,
                                ],
                                [
                                    0.19702369841346765,
                                    0.024079524087270352,
                                    0.6940700458796984,
                                    0.0848267316195635,
                                ],
                                [
                                    0.2699898575009489,
                                    0.13298577979410423,
                                    0.40000066429147924,
                                    0.19702369841346765,
                                ],
                                [
                                    0.39374218935117794,
                                    0.009233447943875215,
                                    0.5833446439724093,
                                    0.013679718732537564,
                                ],
                                [
                                    0.19702369841346767,
                                    0.09704568317475158,
                                    0.47296682337896045,
                                    0.23296379503282028,
                                ],
                                [
                                    0.2873313208334588,
                                    0.0067380607547604995,
                                    0.6897555124901285,
                                    0.01617510592165228,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.08482673161956351,
                                    0.02407952408727036,
                                    0.6940700458796984,
                                    0.19702369841346767,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.455903796840729,
                                    0.022242744780099678,
                                    0.49757752563271007,
                                    0.024275932746461257,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.24508600384758633,
                                    0.011957315272504394,
                                    0.7083953186258528,
                                    0.03456136225405654,
                                ],
                                [
                                    0.6606707252279942,
                                    0.2928105972454448,
                                    0.03223296324084667,
                                    0.014285714285714296,
                                ],
                                [
                                    0.0158766177045878,
                                    0.0070365489718250546,
                                    0.6770270707642531,
                                    0.30005976255933403,
                                ],
                                [
                                    0.0371988809621271,
                                    0.4985622152487361,
                                    0.03223296324084667,
                                    0.43200594054829006,
                                ],
                                [
                                    0.5011450021562235,
                                    0.03461609405463969,
                                    0.43424393463022876,
                                    0.029994969158907998,
                                ],
                                [
                                    0.015876617704587766,
                                    0.21278816697511643,
                                    0.053555226498386004,
                                    0.7177799888219099,
                                ],
                                [
                                    0.21389050982205154,
                                    0.014774274857652639,
                                    0.7214984269644007,
                                    0.04983678835589505,
                                ],
                                [
                                    0.13097155993709575,
                                    0.003071347479425723,
                                    0.8461152733864915,
                                    0.019841819196987055,
                                ],
                                [
                                    0.06313061915299545,
                                    0.0014804440605522607,
                                    0.9139562141705918,
                                    0.021432722615860517,
                                ],
                                [
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                    0.8461152733864915,
                                    0.06313061915299543,
                                ],
                                [
                                    0.09031660178455507,
                                    0.00043750567595796693,
                                    0.9048626172260189,
                                    0.004383275313468047,
                                ],
                                [
                                    0.06313061915299548,
                                    0.004710321631104818,
                                    0.8674375366440308,
                                    0.0647215225718689,
                                ],
                                [
                                    0.06751389446646353,
                                    0.0003270463176367667,
                                    0.9276653245441104,
                                    0.004493734671789248,
                                ],
                                [
                                    0.33552188412492884,
                                    0.04100627160920404,
                                    0.5555718601682372,
                                    0.06789998409762982,
                                ],
                                [
                                    0.04145250253670962,
                                    0.0050661749898514,
                                    0.8496412417564565,
                                    0.10384008071698245,
                                ],
                                [
                                    0.11441866162419083,
                                    0.05635787610665073,
                                    0.5555718601682373,
                                    0.27365160210092115,
                                ],
                                [
                                    0.1668635064573941,
                                    0.003913031273447469,
                                    0.8102233268661931,
                                    0.019000135402965312,
                                ],
                                [
                                    0.041452502536709596,
                                    0.020417779487298088,
                                    0.6285380192557185,
                                    0.30959169872027376,
                                ],
                                [
                                    0.06045263793967493,
                                    0.0014176440843327535,
                                    0.9166341953839123,
                                    0.021495522592080027,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.01784699168656145,
                                    0.005066174989851407,
                                    0.7610497858127006,
                                    0.21603704751088662,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.2623822914672493,
                                    0.012801170739015814,
                                    0.6910990310061897,
                                    0.03371750678754512,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.05156449847410658,
                                    0.002515741231420532,
                                    0.9019168239993325,
                                    0.044002936295140405,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.04476924401656067,
                                    0.01984181919698707,
                                ],
                                [
                                    0.003340336928873789,
                                    0.0014804440605522763,
                                    0.6895633515399671,
                                    0.3056158674706068,
                                ],
                                [
                                    0.024662600186413093,
                                    0.3305432922901804,
                                    0.044769244016560676,
                                    0.6000248635068458,
                                ],
                                [
                                    0.3322556621039637,
                                    0.022950230372629808,
                                    0.6031332746824886,
                                    0.041660832840917886,
                                ],
                                [
                                    0.0033403369288737554,
                                    0.04476924401656063,
                                    0.06609150727410001,
                                    0.8857989117804657,
                                ],
                                [
                                    0.045001169769791634,
                                    0.0031084111756427505,
                                    0.8903877670166607,
                                    0.06150265203790494,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.8461152733864915,
                                    0.019841819196987055,
                                    0.1309715599370957,
                                    0.0030713474794257217,
                                ],
                                [
                                    0.8674375366440308,
                                    0.0647215225718689,
                                    0.06313061915299543,
                                    0.004710321631104814,
                                ],
                                [
                                    0.9108003433231577,
                                    0.02135871589274204,
                                    0.06628649000042952,
                                    0.0015544507836707387,
                                ],
                                [
                                    0.8461152733864915,
                                    0.06313061915299543,
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                ],
                                [
                                    0.888412189853886,
                                    0.020833702685600967,
                                    0.08867464346970123,
                                    0.0020794639908118116,
                                ],
                                [
                                    0.8496412417564566,
                                    0.10384008071698246,
                                    0.04145250253670954,
                                    0.005066174989851391,
                                ],
                                [
                                    0.5555718601682373,
                                    0.06789998409762983,
                                    0.3355218841249287,
                                    0.041006271609204024,
                                ],
                                [
                                    0.6285380192557186,
                                    0.3095916987202738,
                                    0.04145250253670954,
                                    0.020417779487298063,
                                ],
                                [
                                    0.835961523023919,
                                    0.10216819495207335,
                                    0.055132221269247106,
                                    0.006738060754760498,
                                ],
                                [
                                    0.5555718601682373,
                                    0.27365160210092115,
                                    0.11441866162419075,
                                    0.056357876106650696,
                                ],
                                [
                                    0.7389158398491674,
                                    0.09030762241999107,
                                    0.15217790444399867,
                                    0.01859863328684278,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.2391963274335293,
                                    0.06789998409762983,
                                    0.5397004500657328,
                                    0.15320323840310818,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.7367738530662394,
                                    0.20914590722823365,
                                    0.04212292443302265,
                                    0.011957315272504392,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.5645572655657123,
                                    0.16025927222802278,
                                    0.2143395119335498,
                                    0.060843950272715254,
                                ],
                                [
                                    0.6895633515399671,
                                    0.3056158674706068,
                                    0.0033403369288737567,
                                    0.001480444060552262,
                                ],
                                [
                                    0.04476924401656064,
                                    0.01984181919698706,
                                    0.6481344444522802,
                                    0.287254492334172,
                                ],
                                [
                                    0.06609150727410001,
                                    0.8857989117804657,
                                    0.0033403369288737563,
                                    0.04476924401656064,
                                ],
                                [
                                    0.6595683823810591,
                                    0.2923220366735064,
                                    0.033335306087781756,
                                    0.014774274857652635,
                                ],
                                [
                                    0.044769244016560676,
                                    0.6000248635068458,
                                    0.02466260018641309,
                                    0.33054329229018037,
                                ],
                                [
                                    0.44678021540594276,
                                    0.19801389211746373,
                                    0.2461234730628981,
                                    0.10908241941369534,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6305083932376921,
                                    0.04704369073370201,
                                    0.3000597625593341,
                                    0.022388153469271706,
                                ],
                                [
                                    0.6620272201394068,
                                    0.015524863831987383,
                                    0.3150596131841804,
                                    0.007388302844425396,
                                ],
                                [
                                    0.6091861299801528,
                                    0.04545278731482854,
                                    0.3213820258168734,
                                    0.02397905688814517,
                                ],
                                [
                                    0.639639066670135,
                                    0.014999850624846309,
                                    0.3374477666534521,
                                    0.00791331605156647,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.40000066429147924,
                                    0.048886635000210864,
                                    0.4910930800016869,
                                    0.060019620706622985,
                                ],
                                [
                                    0.4729668233789605,
                                    0.23296379503282033,
                                    0.19702369841346765,
                                    0.09704568317475157,
                                ],
                                [
                                    0.629050357971744,
                                    0.07688026044003675,
                                    0.2620433863214221,
                                    0.0320259952667971,
                                ],
                                [
                                    0.4000006642914793,
                                    0.19702369841346767,
                                    0.26998985750094884,
                                    0.1329857797941042,
                                ],
                                [
                                    0.5320046747969924,
                                    0.06501968790795447,
                                    0.35908906949617364,
                                    0.043886567798879374,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.5786865645589089,
                                    0.1642701163210004,
                                    0.20021021294035304,
                                    0.05683310617973761,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.4064699770583818,
                                    0.11538348132078954,
                                    0.3724268004408802,
                                    0.10571974117994848,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.05355522649838601,
                                    0.7177799888219099,
                                    0.01587661770458776,
                                    0.21278816697511635,
                                ],
                                [
                                    0.5344610157413406,
                                    0.23687419957895525,
                                    0.15844267272750026,
                                    0.07022211195220382,
                                ],
                                [
                                    0.03223296324084667,
                                    0.4320059405482901,
                                    0.0371988809621271,
                                    0.4985622152487361,
                                ],
                                [
                                    0.3216728487662242,
                                    0.14256605502291253,
                                    0.37123083970261667,
                                    0.16453025650824654,
                                ],
                                [
                                    0.3679007033434344,
                                    0.008627452390698495,
                                    0.6091861299801529,
                                    0.014285714285714284,
                                ],
                                [
                                    0.3000597625593341,
                                    0.007036548971825033,
                                    0.6770270707642532,
                                    0.015876617704587745,
                                ],
                                [
                                    0.32138202581687336,
                                    0.023979056888145167,
                                    0.6091861299801529,
                                    0.04545278731482855,
                                ],
                                [
                                    0.33744776665345205,
                                    0.007913316051566468,
                                    0.6396390666701351,
                                    0.01499985062484631,
                                ],
                                [
                                    0.3000597625593341,
                                    0.022388153469271706,
                                    0.6305083932376921,
                                    0.04704369073370201,
                                ],
                                [
                                    0.3150596131841804,
                                    0.007388302844425396,
                                    0.6620272201394068,
                                    0.015524863831987383,
                                ],
                                [
                                    0.4910930800016869,
                                    0.060019620706622985,
                                    0.40000066429147924,
                                    0.048886635000210864,
                                ],
                                [
                                    0.19702369841346765,
                                    0.024079524087270352,
                                    0.6940700458796984,
                                    0.0848267316195635,
                                ],
                                [
                                    0.2699898575009489,
                                    0.13298577979410423,
                                    0.40000066429147924,
                                    0.19702369841346765,
                                ],
                                [
                                    0.35908906949617375,
                                    0.04388656779887939,
                                    0.5320046747969924,
                                    0.06501968790795445,
                                ],
                                [
                                    0.19702369841346767,
                                    0.09704568317475158,
                                    0.47296682337896045,
                                    0.23296379503282028,
                                ],
                                [
                                    0.26204338632142216,
                                    0.03202599526679711,
                                    0.629050357971744,
                                    0.07688026044003675,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.08482673161956351,
                                    0.02407952408727036,
                                    0.6940700458796984,
                                    0.19702369841346767,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.3724268004408802,
                                    0.10571974117994848,
                                    0.4064699770583818,
                                    0.11538348132078954,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.2002102129403531,
                                    0.05683310617973762,
                                    0.5786865645589089,
                                    0.1642701163210004,
                                ],
                                [
                                    0.6606707252279942,
                                    0.2928105972454448,
                                    0.03223296324084667,
                                    0.014285714285714296,
                                ],
                                [
                                    0.0158766177045878,
                                    0.0070365489718250546,
                                    0.6770270707642531,
                                    0.30005976255933403,
                                ],
                                [
                                    0.0371988809621271,
                                    0.4985622152487361,
                                    0.03223296324084667,
                                    0.43200594054829006,
                                ],
                                [
                                    0.37123083970261667,
                                    0.16453025650824654,
                                    0.3216728487662242,
                                    0.14256605502291253,
                                ],
                                [
                                    0.015876617704587766,
                                    0.21278816697511643,
                                    0.053555226498386004,
                                    0.7177799888219099,
                                ],
                                [
                                    0.15844267272750032,
                                    0.07022211195220385,
                                    0.5344610157413405,
                                    0.23687419957895522,
                                ],
                                [
                                    0.13097155993709575,
                                    0.003071347479425723,
                                    0.8461152733864915,
                                    0.019841819196987055,
                                ],
                                [
                                    0.06313061915299545,
                                    0.0014804440605522607,
                                    0.9139562141705918,
                                    0.021432722615860517,
                                ],
                                [
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                    0.8461152733864915,
                                    0.06313061915299543,
                                ],
                                [
                                    0.08867464346970123,
                                    0.0020794639908118116,
                                    0.888412189853886,
                                    0.020833702685600967,
                                ],
                                [
                                    0.06313061915299548,
                                    0.004710321631104818,
                                    0.8674375366440308,
                                    0.0647215225718689,
                                ],
                                [
                                    0.06628649000042956,
                                    0.0015544507836707396,
                                    0.9108003433231577,
                                    0.02135871589274204,
                                ],
                                [
                                    0.33552188412492884,
                                    0.04100627160920404,
                                    0.5555718601682372,
                                    0.06789998409762982,
                                ],
                                [
                                    0.04145250253670962,
                                    0.0050661749898514,
                                    0.8496412417564565,
                                    0.10384008071698245,
                                ],
                                [
                                    0.11441866162419083,
                                    0.05635787610665073,
                                    0.5555718601682373,
                                    0.27365160210092115,
                                ],
                                [
                                    0.15217790444399876,
                                    0.01859863328684279,
                                    0.7389158398491673,
                                    0.09030762241999106,
                                ],
                                [
                                    0.041452502536709596,
                                    0.020417779487298088,
                                    0.6285380192557185,
                                    0.30959169872027376,
                                ],
                                [
                                    0.055132221269247175,
                                    0.006738060754760506,
                                    0.8359615230239189,
                                    0.10216819495207334,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.01784699168656145,
                                    0.005066174989851407,
                                    0.7610497858127006,
                                    0.21603704751088662,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.21433951193354986,
                                    0.06084395027271527,
                                    0.5645572655657122,
                                    0.16025927222802275,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.04212292443302271,
                                    0.011957315272504408,
                                    0.7367738530662393,
                                    0.20914590722823362,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.04476924401656067,
                                    0.01984181919698707,
                                ],
                                [
                                    0.003340336928873789,
                                    0.0014804440605522763,
                                    0.6895633515399671,
                                    0.3056158674706068,
                                ],
                                [
                                    0.024662600186413093,
                                    0.3305432922901804,
                                    0.044769244016560676,
                                    0.6000248635068458,
                                ],
                                [
                                    0.24612347306289814,
                                    0.10908241941369536,
                                    0.44678021540594276,
                                    0.19801389211746373,
                                ],
                                [
                                    0.0033403369288737554,
                                    0.04476924401656063,
                                    0.06609150727410001,
                                    0.8857989117804657,
                                ],
                                [
                                    0.03333530608778175,
                                    0.014774274857652632,
                                    0.6595683823810591,
                                    0.2923220366735064,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.8461152733864915,
                                    0.019841819196987055,
                                    0.1309715599370957,
                                    0.0030713474794257217,
                                ],
                                [
                                    0.8674375366440308,
                                    0.0647215225718689,
                                    0.06313061915299543,
                                    0.004710321631104814,
                                ],
                                [
                                    0.8887962525367729,
                                    0.043362806679126856,
                                    0.06468506993666619,
                                    0.003155870847434076,
                                ],
                                [
                                    0.8461152733864915,
                                    0.06313061915299543,
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                ],
                                [
                                    0.8669489760720925,
                                    0.042296916467394474,
                                    0.08653234640134658,
                                    0.004221761059166464,
                                ],
                                [
                                    0.8496412417564566,
                                    0.10384008071698246,
                                    0.04145250253670954,
                                    0.005066174989851391,
                                ],
                                [
                                    0.5555718601682373,
                                    0.06789998409762983,
                                    0.3355218841249287,
                                    0.041006271609204024,
                                ],
                                [
                                    0.6285380192557186,
                                    0.3095916987202738,
                                    0.04145250253670954,
                                    0.020417779487298063,
                                ],
                                [
                                    0.730706214207792,
                                    0.20742350376820046,
                                    0.04819056329147004,
                                    0.013679718732537566,
                                ],
                                [
                                    0.5555718601682373,
                                    0.27365160210092115,
                                    0.11441866162419075,
                                    0.056357876106650696,
                                ],
                                [
                                    0.6458794825882285,
                                    0.1833439796809301,
                                    0.13301729491103353,
                                    0.03775924281980792,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.2391963274335293,
                                    0.06789998409762983,
                                    0.5397004500657328,
                                    0.15320323840310818,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.5213083937492441,
                                    0.4246113665452289,
                                    0.02980430695906578,
                                    0.02427593274646126,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.39945559966155203,
                                    0.325360938132183,
                                    0.15165710104675786,
                                    0.1235263611595072,
                                ],
                                [
                                    0.6895633515399671,
                                    0.3056158674706068,
                                    0.0033403369288737567,
                                    0.001480444060552262,
                                ],
                                [
                                    0.04476924401656064,
                                    0.01984181919698706,
                                    0.6481344444522802,
                                    0.287254492334172,
                                ],
                                [
                                    0.06609150727410001,
                                    0.8857989117804657,
                                    0.0033403369288737563,
                                    0.04476924401656064,
                                ],
                                [
                                    0.3584135439476065,
                                    0.5934768751069591,
                                    0.018114611786526395,
                                    0.029994969158908,
                                ],
                                [
                                    0.044769244016560676,
                                    0.6000248635068458,
                                    0.02466260018641309,
                                    0.33054329229018037,
                                ],
                                [
                                    0.24278313613402444,
                                    0.4020109713893821,
                                    0.13374501960010846,
                                    0.221460872876485,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6305083932376921,
                                    0.04704369073370201,
                                    0.3000597625593341,
                                    0.022388153469271706,
                                ],
                                [
                                    0.6460332570696796,
                                    0.031518826901714626,
                                    0.30744806540375946,
                                    0.014999850624846312,
                                ],
                                [
                                    0.6091861299801528,
                                    0.04545278731482854,
                                    0.3213820258168734,
                                    0.02397905688814517,
                                ],
                                [
                                    0.6241859806049992,
                                    0.03045293668998223,
                                    0.3292953418684399,
                                    0.0160657408365787,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.40000066429147924,
                                    0.048886635000210864,
                                    0.4910930800016869,
                                    0.060019620706622985,
                                ],
                                [
                                    0.4729668233789605,
                                    0.23296379503282033,
                                    0.19702369841346765,
                                    0.09704568317475157,
                                ],
                                [
                                    0.5498470838189973,
                                    0.15608353459278357,
                                    0.22904969368026476,
                                    0.06501968790795447,
                                ],
                                [
                                    0.4000006642914793,
                                    0.19702369841346767,
                                    0.26998985750094884,
                                    0.1329857797941042,
                                ],
                                [
                                    0.4650203521994338,
                                    0.13200401050551322,
                                    0.31387642529982823,
                                    0.08909921199522482,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.40945286290900873,
                                    0.33350381797090056,
                                    0.1416598377993011,
                                    0.11538348132078954,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.28760006882131667,
                                    0.23425338955785463,
                                    0.2635126318869932,
                                    0.2146339097338355,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.05355522649838601,
                                    0.7177799888219099,
                                    0.01587661770458776,
                                    0.21278816697511635,
                                ],
                                [
                                    0.2904294260773413,
                                    0.48090578924295463,
                                    0.08609872965679159,
                                    0.1425660550229125,
                                ],
                                [
                                    0.03223296324084667,
                                    0.4320059405482901,
                                    0.0371988809621271,
                                    0.4985622152487361,
                                ],
                                [
                                    0.17479901826375924,
                                    0.2894398855253776,
                                    0.20172913747037366,
                                    0.3340319587404895,
                                ],
                                [
                                    0.3679007033434344,
                                    0.008627452390698495,
                                    0.6091861299801529,
                                    0.014285714285714284,
                                ],
                                [
                                    0.3000597625593341,
                                    0.007036548971825033,
                                    0.6770270707642532,
                                    0.015876617704587745,
                                ],
                                [
                                    0.32138202581687336,
                                    0.023979056888145167,
                                    0.6091861299801529,
                                    0.04545278731482855,
                                ],
                                [
                                    0.32929534186843984,
                                    0.016065740836578697,
                                    0.6241859806049993,
                                    0.030452936689982238,
                                ],
                                [
                                    0.3000597625593341,
                                    0.022388153469271706,
                                    0.6305083932376921,
                                    0.04704369073370201,
                                ],
                                [
                                    0.30744806540375946,
                                    0.014999850624846312,
                                    0.6460332570696796,
                                    0.031518826901714626,
                                ],
                                [
                                    0.4910930800016869,
                                    0.060019620706622985,
                                    0.40000066429147924,
                                    0.048886635000210864,
                                ],
                                [
                                    0.19702369841346765,
                                    0.024079524087270352,
                                    0.6940700458796984,
                                    0.0848267316195635,
                                ],
                                [
                                    0.2699898575009489,
                                    0.13298577979410423,
                                    0.40000066429147924,
                                    0.19702369841346765,
                                ],
                                [
                                    0.31387642529982834,
                                    0.08909921199522484,
                                    0.46502035219943366,
                                    0.1320040105055132,
                                ],
                                [
                                    0.19702369841346767,
                                    0.09704568317475158,
                                    0.47296682337896045,
                                    0.23296379503282028,
                                ],
                                [
                                    0.2290496936802648,
                                    0.06501968790795448,
                                    0.5498470838189972,
                                    0.15608353459278354,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.08482673161956351,
                                    0.02407952408727036,
                                    0.6940700458796984,
                                    0.19702369841346767,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.2635126318869932,
                                    0.2146339097338355,
                                    0.28760006882131667,
                                    0.23425338955785463,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.14165983779930114,
                                    0.11538348132078957,
                                    0.40945286290900873,
                                    0.33350381797090056,
                                ],
                                [
                                    0.6606707252279942,
                                    0.2928105972454448,
                                    0.03223296324084667,
                                    0.014285714285714296,
                                ],
                                [
                                    0.0158766177045878,
                                    0.0070365489718250546,
                                    0.6770270707642531,
                                    0.30005976255933403,
                                ],
                                [
                                    0.0371988809621271,
                                    0.4985622152487361,
                                    0.03223296324084667,
                                    0.43200594054829006,
                                ],
                                [
                                    0.20172913747037366,
                                    0.3340319587404895,
                                    0.1747990182637592,
                                    0.2894398855253775,
                                ],
                                [
                                    0.015876617704587766,
                                    0.21278816697511643,
                                    0.053555226498386004,
                                    0.7177799888219099,
                                ],
                                [
                                    0.08609872965679162,
                                    0.14256605502291256,
                                    0.2904294260773413,
                                    0.4809057892429545,
                                ],
                                [
                                    0.13097155993709575,
                                    0.003071347479425723,
                                    0.8461152733864915,
                                    0.019841819196987055,
                                ],
                                [
                                    0.06313061915299545,
                                    0.0014804440605522607,
                                    0.9139562141705918,
                                    0.021432722615860517,
                                ],
                                [
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                    0.8461152733864915,
                                    0.06313061915299543,
                                ],
                                [
                                    0.08653234640134658,
                                    0.004221761059166464,
                                    0.8669489760720925,
                                    0.042296916467394474,
                                ],
                                [
                                    0.06313061915299548,
                                    0.004710321631104818,
                                    0.8674375366440308,
                                    0.0647215225718689,
                                ],
                                [
                                    0.06468506993666623,
                                    0.003155870847434078,
                                    0.8887962525367729,
                                    0.043362806679126856,
                                ],
                                [
                                    0.33552188412492884,
                                    0.04100627160920404,
                                    0.5555718601682372,
                                    0.06789998409762982,
                                ],
                                [
                                    0.04145250253670962,
                                    0.0050661749898514,
                                    0.8496412417564565,
                                    0.10384008071698245,
                                ],
                                [
                                    0.11441866162419083,
                                    0.05635787610665073,
                                    0.5555718601682373,
                                    0.27365160210092115,
                                ],
                                [
                                    0.13301729491103362,
                                    0.03775924281980794,
                                    0.6458794825882284,
                                    0.18334397968093008,
                                ],
                                [
                                    0.041452502536709596,
                                    0.020417779487298088,
                                    0.6285380192557185,
                                    0.30959169872027376,
                                ],
                                [
                                    0.048190563291470104,
                                    0.013679718732537583,
                                    0.7307062142077919,
                                    0.20742350376820043,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.01784699168656145,
                                    0.005066174989851407,
                                    0.7610497858127006,
                                    0.21603704751088662,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.1516571010467579,
                                    0.12352636115950723,
                                    0.399455599661552,
                                    0.3253609381321829,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.02980430695906582,
                                    0.024275932746461292,
                                    0.5213083937492441,
                                    0.42461136654522885,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.04476924401656067,
                                    0.01984181919698707,
                                ],
                                [
                                    0.003340336928873789,
                                    0.0014804440605522763,
                                    0.6895633515399671,
                                    0.3056158674706068,
                                ],
                                [
                                    0.024662600186413093,
                                    0.3305432922901804,
                                    0.044769244016560676,
                                    0.6000248635068458,
                                ],
                                [
                                    0.13374501960010846,
                                    0.22146087287648505,
                                    0.24278313613402444,
                                    0.4020109713893821,
                                ],
                                [
                                    0.0033403369288737554,
                                    0.04476924401656063,
                                    0.06609150727410001,
                                    0.8857989117804657,
                                ],
                                [
                                    0.01811461178652639,
                                    0.029994969158907994,
                                    0.3584135439476065,
                                    0.5934768751069591,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.8461152733864915,
                                    0.019841819196987055,
                                    0.1309715599370957,
                                    0.0030713474794257217,
                                ],
                                [
                                    0.8674375366440308,
                                    0.0647215225718689,
                                    0.06313061915299543,
                                    0.004710321631104814,
                                ],
                                [
                                    0.87193127131582,
                                    0.06022778790007964,
                                    0.06345766547063221,
                                    0.004383275313468047,
                                ],
                                [
                                    0.8461152733864915,
                                    0.06313061915299543,
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                ],
                                [
                                    0.8504985486999596,
                                    0.05874734383952738,
                                    0.08489038808649274,
                                    0.0058637193740203085,
                                ],
                                [
                                    0.8496412417564566,
                                    0.10384008071698246,
                                    0.04145250253670954,
                                    0.005066174989851391,
                                ],
                                [
                                    0.5555718601682373,
                                    0.06789998409762983,
                                    0.3355218841249287,
                                    0.041006271609204024,
                                ],
                                [
                                    0.6285380192557186,
                                    0.3095916987202738,
                                    0.04145250253670954,
                                    0.020417779487298063,
                                ],
                                [
                                    0.6500335418477986,
                                    0.28809617612819377,
                                    0.04287014662104229,
                                    0.019000135402965312,
                                ],
                                [
                                    0.5555718601682373,
                                    0.27365160210092115,
                                    0.11441866162419075,
                                    0.056357876106650696,
                                ],
                                [
                                    0.5745719955712026,
                                    0.25465146669795585,
                                    0.11833169289763822,
                                    0.052444844833203226,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.2391963274335293,
                                    0.06789998409762983,
                                    0.5397004500657328,
                                    0.15320323840310818,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.356165422816151,
                                    0.5897543374783221,
                                    0.020362732917981925,
                                    0.03371750678754512,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.27291383422107446,
                                    0.45190270357266055,
                                    0.10361432151305844,
                                    0.1715691406932066,
                                ],
                                [
                                    0.6895633515399671,
                                    0.3056158674706068,
                                    0.0033403369288737567,
                                    0.001480444060552262,
                                ],
                                [
                                    0.04476924401656064,
                                    0.01984181919698706,
                                    0.6481344444522802,
                                    0.287254492334172,
                                ],
                                [
                                    0.06609150727410001,
                                    0.8857989117804657,
                                    0.0033403369288737563,
                                    0.04476924401656064,
                                ],
                                [
                                    0.12759415931200496,
                                    0.8242962597425606,
                                    0.006448748104516508,
                                    0.041660832840917886,
                                ],
                                [
                                    0.044769244016560676,
                                    0.6000248635068458,
                                    0.02466260018641309,
                                    0.33054329229018037,
                                ],
                                [
                                    0.08643007685747857,
                                    0.5583640306659279,
                                    0.0476128305590429,
                                    0.30759306191755054,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6305083932376921,
                                    0.04704369073370201,
                                    0.3000597625593341,
                                    0.022388153469271706,
                                ],
                                [
                                    0.6337747234434474,
                                    0.04377736052794672,
                                    0.3016142133430048,
                                    0.020833702685600967,
                                ],
                                [
                                    0.6091861299801528,
                                    0.04545278731482854,
                                    0.3213820258168734,
                                    0.02397905688814517,
                                ],
                                [
                                    0.6123420008275869,
                                    0.04229691646739446,
                                    0.32304693595886536,
                                    0.022314146746153226,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.40000066429147924,
                                    0.048886635000210864,
                                    0.4910930800016869,
                                    0.060019620706622985,
                                ],
                                [
                                    0.4729668233789605,
                                    0.23296379503282033,
                                    0.19702369841346765,
                                    0.09704568317475157,
                                ],
                                [
                                    0.4891419293006128,
                                    0.21678868911116803,
                                    0.20376175916822814,
                                    0.09030762241999106,
                                ],
                                [
                                    0.4000006642914793,
                                    0.19702369841346767,
                                    0.26998985750094884,
                                    0.1329857797941042,
                                ],
                                [
                                    0.41368038302401683,
                                    0.1833439796809301,
                                    0.27922330544482404,
                                    0.12375233185022898,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.27974410884206496,
                                    0.46321257203784433,
                                    0.09678404689206792,
                                    0.16025927222802275,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.19649252024698846,
                                    0.32536093813218286,
                                    0.18003563548714444,
                                    0.29811090613368424,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.05355522649838601,
                                    0.7177799888219099,
                                    0.01587661770458776,
                                    0.21278816697511635,
                                ],
                                [
                                    0.10339201485428108,
                                    0.6679432004660149,
                                    0.030650892562240396,
                                    0.1980138921174637,
                                ],
                                [
                                    0.03223296324084667,
                                    0.4320059405482901,
                                    0.0371988809621271,
                                    0.4985622152487361,
                                ],
                                [
                                    0.06222793239975468,
                                    0.40201097138938213,
                                    0.07181497501676679,
                                    0.4639461211940964,
                                ],
                                [
                                    0.3679007033434344,
                                    0.008627452390698495,
                                    0.6091861299801529,
                                    0.014285714285714284,
                                ],
                                [
                                    0.3000597625593341,
                                    0.007036548971825033,
                                    0.6770270707642532,
                                    0.015876617704587745,
                                ],
                                [
                                    0.32138202581687336,
                                    0.023979056888145167,
                                    0.6091861299801529,
                                    0.04545278731482855,
                                ],
                                [
                                    0.3230469359588653,
                                    0.022314146746153223,
                                    0.6123420008275869,
                                    0.04229691646739447,
                                ],
                                [
                                    0.3000597625593341,
                                    0.022388153469271706,
                                    0.6305083932376921,
                                    0.04704369073370201,
                                ],
                                [
                                    0.3016142133430048,
                                    0.020833702685600967,
                                    0.6337747234434474,
                                    0.04377736052794672,
                                ],
                                [
                                    0.4910930800016869,
                                    0.060019620706622985,
                                    0.40000066429147924,
                                    0.048886635000210864,
                                ],
                                [
                                    0.19702369841346765,
                                    0.024079524087270352,
                                    0.6940700458796984,
                                    0.0848267316195635,
                                ],
                                [
                                    0.2699898575009489,
                                    0.13298577979410423,
                                    0.40000066429147924,
                                    0.19702369841346765,
                                ],
                                [
                                    0.2792233054448241,
                                    0.123752331850229,
                                    0.4136803830240168,
                                    0.18334397968093008,
                                ],
                                [
                                    0.19702369841346767,
                                    0.09704568317475158,
                                    0.47296682337896045,
                                    0.23296379503282028,
                                ],
                                [
                                    0.20376175916822817,
                                    0.09030762241999107,
                                    0.4891419293006127,
                                    0.216788689111168,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.08482673161956351,
                                    0.02407952408727036,
                                    0.6940700458796984,
                                    0.19702369841346767,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.18003563548714444,
                                    0.29811090613368424,
                                    0.19649252024698846,
                                    0.32536093813218286,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.09678404689206793,
                                    0.16025927222802278,
                                    0.27974410884206496,
                                    0.46321257203784433,
                                ],
                                [
                                    0.6606707252279942,
                                    0.2928105972454448,
                                    0.03223296324084667,
                                    0.014285714285714296,
                                ],
                                [
                                    0.0158766177045878,
                                    0.0070365489718250546,
                                    0.6770270707642531,
                                    0.30005976255933403,
                                ],
                                [
                                    0.0371988809621271,
                                    0.4985622152487361,
                                    0.03223296324084667,
                                    0.43200594054829006,
                                ],
                                [
                                    0.07181497501676679,
                                    0.4639461211940964,
                                    0.062227932399754673,
                                    0.4020109713893821,
                                ],
                                [
                                    0.015876617704587766,
                                    0.21278816697511643,
                                    0.053555226498386004,
                                    0.7177799888219099,
                                ],
                                [
                                    0.030650892562240406,
                                    0.19801389211746379,
                                    0.10339201485428107,
                                    0.6679432004660147,
                                ],
                                [
                                    0.13097155993709575,
                                    0.003071347479425723,
                                    0.8461152733864915,
                                    0.019841819196987055,
                                ],
                                [
                                    0.06313061915299545,
                                    0.0014804440605522607,
                                    0.9139562141705918,
                                    0.021432722615860517,
                                ],
                                [
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                    0.8461152733864915,
                                    0.06313061915299543,
                                ],
                                [
                                    0.08489038808649274,
                                    0.0058637193740203085,
                                    0.8504985486999596,
                                    0.05874734383952738,
                                ],
                                [
                                    0.06313061915299548,
                                    0.004710321631104818,
                                    0.8674375366440308,
                                    0.0647215225718689,
                                ],
                                [
                                    0.06345766547063225,
                                    0.00438327531346805,
                                    0.87193127131582,
                                    0.06022778790007964,
                                ],
                                [
                                    0.33552188412492884,
                                    0.04100627160920404,
                                    0.5555718601682372,
                                    0.06789998409762982,
                                ],
                                [
                                    0.04145250253670962,
                                    0.0050661749898514,
                                    0.8496412417564565,
                                    0.10384008071698245,
                                ],
                                [
                                    0.11441866162419083,
                                    0.05635787610665073,
                                    0.5555718601682373,
                                    0.27365160210092115,
                                ],
                                [
                                    0.11833169289763829,
                                    0.05244484483320326,
                                    0.5745719955712025,
                                    0.2546514666979558,
                                ],
                                [
                                    0.041452502536709596,
                                    0.020417779487298088,
                                    0.6285380192557185,
                                    0.30959169872027376,
                                ],
                                [
                                    0.04287014662104235,
                                    0.019000135402965336,
                                    0.6500335418477985,
                                    0.2880961761281937,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.01784699168656145,
                                    0.005066174989851407,
                                    0.7610497858127006,
                                    0.21603704751088662,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.10361432151305847,
                                    0.17156914069320664,
                                    0.27291383422107446,
                                    0.45190270357266044,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.02036273291798195,
                                    0.03371750678754516,
                                    0.35616542281615093,
                                    0.589754337478322,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.04476924401656067,
                                    0.01984181919698707,
                                ],
                                [
                                    0.003340336928873789,
                                    0.0014804440605522763,
                                    0.6895633515399671,
                                    0.3056158674706068,
                                ],
                                [
                                    0.024662600186413093,
                                    0.3305432922901804,
                                    0.044769244016560676,
                                    0.6000248635068458,
                                ],
                                [
                                    0.047612830559042904,
                                    0.3075930619175506,
                                    0.08643007685747857,
                                    0.5583640306659279,
                                ],
                                [
                                    0.0033403369288737554,
                                    0.04476924401656063,
                                    0.06609150727410001,
                                    0.8857989117804657,
                                ],
                                [
                                    0.006448748104516506,
                                    0.04166083284091788,
                                    0.12759415931200496,
                                    0.8242962597425606,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8256739138417495,
                                    0.04028317874172911,
                                    0.1278074086316896,
                                    0.006235498784831823,
                                ],
                                [
                                    0.8689627137977578,
                                    0.06483531956982098,
                                    0.06160544199926842,
                                    0.00459652463315273,
                                ],
                                [
                                    0.929296397560357,
                                    0.004501635807221823,
                                    0.06588282145021697,
                                    0.00031914518220419125,
                                ],
                                [
                                    0.8256739138417495,
                                    0.06160544199926843,
                                    0.1048942419552768,
                                    0.007826402203705283,
                                ],
                                [
                                    0.8830019763900693,
                                    0.004277379450948539,
                                    0.1121772426205046,
                                    0.0005434015384774754,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.4856202103602057,
                                    0.13785163390566152,
                                    0.2932765671390563,
                                    0.0832515885950765,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.9242457431643334,
                                    0.02167401713013968,
                                    0.052841090159253944,
                                    0.0012391495462730974,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.7082086956534467,
                                    0.016607842140288293,
                                    0.26887813767014057,
                                    0.006305324536124488,
                                ],
                                [
                                    0.5384849635394924,
                                    0.4386018697840949,
                                    0.012627737168817495,
                                    0.010285429507595284,
                                ],
                                [
                                    0.16924467762549758,
                                    0.13785163390566155,
                                    0.38186802308281226,
                                    0.3110356653860286,
                                ],
                                [
                                    0.3173817410387544,
                                    0.6443534877873862,
                                    0.012627737168817495,
                                    0.025637034005041956,
                                ],
                                [
                                    0.9169965778504441,
                                    0.04473865097569653,
                                    0.03648474462299504,
                                    0.0017800265508644123,
                                ],
                                [
                                    0.16924467762549755,
                                    0.3436032519089528,
                                    0.1607648005820743,
                                    0.3263872698834753,
                                ],
                                [
                                    0.48899092208027284,
                                    0.023857007454177542,
                                    0.4644904003931662,
                                    0.02266167007238339,
                                ],
                                [
                                    0.3747129959589861,
                                    0.6204662230515878,
                                    0.0018151597751467474,
                                    0.0030056212142792714,
                                ],
                                [
                                    0.024327884471818596,
                                    0.04028317874172911,
                                    0.3522002712623143,
                                    0.583188665524138,
                                ],
                                [
                                    0.06761668442782702,
                                    0.9062402713252077,
                                    0.0018151597751467471,
                                    0.024327884471818592,
                                ],
                                [
                                    0.9109350224239222,
                                    0.06292193332911243,
                                    0.024453914362530086,
                                    0.0016891298844352517,
                                ],
                                [
                                    0.024327884471818613,
                                    0.32605722701534895,
                                    0.045103959731155156,
                                    0.6045109287816773,
                                ],
                                [
                                    0.3277463568997842,
                                    0.022638754587383337,
                                    0.607642579886668,
                                    0.04197230862616435,
                                ],
                                [
                                    0.6606707252279942,
                                    0.032232963240846645,
                                    0.2928105972454448,
                                    0.014285714285714285,
                                ],
                                [
                                    0.5944687585955731,
                                    0.029003085670294096,
                                    0.35901256387786595,
                                    0.01751559185626684,
                                ],
                                [
                                    0.6377575585515814,
                                    0.047584567738293324,
                                    0.2928105972454448,
                                    0.021847276464680394,
                                ],
                                [
                                    0.6820382419962038,
                                    0.003303884293671031,
                                    0.3131409770143702,
                                    0.0015168966957549834,
                                ],
                                [
                                    0.594468758595573,
                                    0.04435469016774077,
                                    0.33609939720145315,
                                    0.025077154035232946,
                                ],
                                [
                                    0.6357438208259161,
                                    0.0030796279373977472,
                                    0.35943539818465786,
                                    0.0017411530520282674,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.3496368708786442,
                                    0.09925042841304595,
                                    0.4292599066206178,
                                    0.12185279408769208,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.7259331906175536,
                                    0.01702349026235578,
                                    0.2511536427060337,
                                    0.005889676414056997,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.509896143106667,
                                    0.01195731527250439,
                                    0.46719069021692033,
                                    0.010955851403908388,
                                ],
                                [
                                    0.4910930800016869,
                                    0.40000066429147924,
                                    0.060019620706622985,
                                    0.048886635000210864,
                                ],
                                [
                                    0.12185279408769206,
                                    0.09925042841304593,
                                    0.4292599066206178,
                                    0.3496368708786442,
                                ],
                                [
                                    0.2699898575009489,
                                    0.5481377277047361,
                                    0.06001962070662299,
                                    0.12185279408769208,
                                ],
                                [
                                    0.7800693718939177,
                                    0.038058213311767265,
                                    0.1734119505795214,
                                    0.008460464214793673,
                                ],
                                [
                                    0.12185279408769208,
                                    0.24738749182630274,
                                    0.20815668411987978,
                                    0.42260302996612537,
                                ],
                                [
                                    0.35206371612374654,
                                    0.017176569790248286,
                                    0.6014176063496925,
                                    0.02934210773631265,
                                ],
                                [
                                    0.3679007033434344,
                                    0.6091861299801529,
                                    0.008627452390698502,
                                    0.014285714285714294,
                                ],
                                [
                                    0.017515591856266877,
                                    0.029003085670294148,
                                    0.359012563877866,
                                    0.5944687585955729,
                                ],
                                [
                                    0.06080439181227527,
                                    0.8149377479834442,
                                    0.008627452390698502,
                                    0.11563040781358205,
                                ],
                                [
                                    0.8191595090426107,
                                    0.05658263075310875,
                                    0.11622942774384162,
                                    0.008028432460438942,
                                ],
                                [
                                    0.01751559185626686,
                                    0.2347547036735855,
                                    0.05191625234670691,
                                    0.6958134521234407,
                                ],
                                [
                                    0.23597084351847272,
                                    0.01629945201137965,
                                    0.6994180932679795,
                                    0.048311611202168044,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.33609939720145315,
                                    0.025077154035232946,
                                    0.594468758595573,
                                    0.04435469016774077,
                                ],
                                [
                                    0.35943539818465786,
                                    0.0017411530520282674,
                                    0.6357438208259161,
                                    0.0030796279373977472,
                                ],
                                [
                                    0.2928105972454448,
                                    0.021847276464680394,
                                    0.6377575585515814,
                                    0.047584567738293324,
                                ],
                                [
                                    0.3131409770143702,
                                    0.0015168966957549834,
                                    0.6820382419962038,
                                    0.003303884293671031,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.46719069021692033,
                                    0.010955851403908388,
                                    0.509896143106667,
                                    0.01195731527250439,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.25115364270603374,
                                    0.005889676414056998,
                                    0.7259331906175536,
                                    0.01702349026235578,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.060019620706623,
                                    0.04888663500021088,
                                    0.4910930800016869,
                                    0.40000066429147924,
                                ],
                                [
                                    0.20815668411987978,
                                    0.42260302996612537,
                                    0.12185279408769208,
                                    0.24738749182630274,
                                ],
                                [
                                    0.6014176063496925,
                                    0.02934210773631265,
                                    0.35206371612374654,
                                    0.017176569790248286,
                                ],
                                [
                                    0.06001962070662298,
                                    0.12185279408769206,
                                    0.2699898575009489,
                                    0.5481377277047361,
                                ],
                                [
                                    0.17341195057952138,
                                    0.008460464214793672,
                                    0.7800693718939177,
                                    0.038058213311767265,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.05191625234670691,
                                    0.6958134521234407,
                                    0.01751559185626686,
                                    0.2347547036735855,
                                ],
                                [
                                    0.6994180932679795,
                                    0.048311611202168044,
                                    0.23597084351847272,
                                    0.01629945201137965,
                                ],
                                [
                                    0.0086274523906985,
                                    0.11563040781358204,
                                    0.06080439181227527,
                                    0.8149377479834442,
                                ],
                                [
                                    0.1162294277438416,
                                    0.00802843246043894,
                                    0.8191595090426107,
                                    0.05658263075310875,
                                ],
                                [
                                    0.12780740863168966,
                                    0.006235498784831825,
                                    0.8256739138417495,
                                    0.04028317874172911,
                                ],
                                [
                                    0.061605441999268436,
                                    0.0030056212142792697,
                                    0.8918758804741707,
                                    0.04351305631228167,
                                ],
                                [
                                    0.1048942419552768,
                                    0.007826402203705283,
                                    0.8256739138417495,
                                    0.06160544199926843,
                                ],
                                [
                                    0.1121772426205046,
                                    0.0005434015384774754,
                                    0.8830019763900693,
                                    0.004277379450948539,
                                ],
                                [
                                    0.061605441999268436,
                                    0.004596524633152731,
                                    0.8689627137977578,
                                    0.06483531956982098,
                                ],
                                [
                                    0.06588282145021698,
                                    0.0003191451822041913,
                                    0.929296397560357,
                                    0.004501635807221823,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.03623324801896572,
                                    0.010285429507595303,
                                    0.7426635294802962,
                                    0.2108177929931427,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.2688781376701406,
                                    0.006305324536124489,
                                    0.7082086956534467,
                                    0.01660784214028829,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.05284109015925401,
                                    0.001239149546273099,
                                    0.9242457431643333,
                                    0.02167401713013968,
                                ],
                                [
                                    0.38186802308281226,
                                    0.3110356653860286,
                                    0.16924467762549755,
                                    0.13785163390566152,
                                ],
                                [
                                    0.012627737168817536,
                                    0.010285429507595319,
                                    0.5384849635394924,
                                    0.4386018697840948,
                                ],
                                [
                                    0.16076480058207432,
                                    0.32638726988347533,
                                    0.16924467762549755,
                                    0.3436032519089528,
                                ],
                                [
                                    0.46449040039316625,
                                    0.022661670072383393,
                                    0.48899092208027284,
                                    0.023857007454177542,
                                ],
                                [
                                    0.012627737168817516,
                                    0.025637034005041998,
                                    0.3173817410387544,
                                    0.6443534877873861,
                                ],
                                [
                                    0.0364847446229951,
                                    0.0017800265508644152,
                                    0.916996577850444,
                                    0.04473865097569652,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181861,
                                    0.04028317874172913,
                                ],
                                [
                                    0.001815159775146765,
                                    0.003005621214279301,
                                    0.3747129959589861,
                                    0.6204662230515878,
                                ],
                                [
                                    0.045103959731155156,
                                    0.6045109287816773,
                                    0.024327884471818613,
                                    0.32605722701534895,
                                ],
                                [
                                    0.607642579886668,
                                    0.04197230862616435,
                                    0.3277463568997842,
                                    0.022638754587383337,
                                ],
                                [
                                    0.0018151597751467474,
                                    0.024327884471818596,
                                    0.06761668442782702,
                                    0.9062402713252077,
                                ],
                                [
                                    0.02445391436253009,
                                    0.001689129884435252,
                                    0.9109350224239222,
                                    0.06292193332911243,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8256739138417495,
                                    0.04028317874172911,
                                    0.1278074086316896,
                                    0.006235498784831823,
                                ],
                                [
                                    0.8689627137977578,
                                    0.06483531956982098,
                                    0.06160544199926842,
                                    0.00459652463315273,
                                ],
                                [
                                    0.912401763386921,
                                    0.021396269980657794,
                                    0.06468506993666617,
                                    0.0015168966957549831,
                                ],
                                [
                                    0.8256739138417495,
                                    0.06160544199926843,
                                    0.1048942419552768,
                                    0.007826402203705283,
                                ],
                                [
                                    0.8669489760720925,
                                    0.02033037976892541,
                                    0.11013785725149472,
                                    0.002582786907487371,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.4856202103602057,
                                    0.13785163390566152,
                                    0.2932765671390563,
                                    0.0832515885950765,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.8429031810016961,
                                    0.10301657929277686,
                                    0.04819056329147004,
                                    0.005889676414056997,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.6458794825882285,
                                    0.0789370552055065,
                                    0.24521426170493768,
                                    0.02996920050132735,
                                ],
                                [
                                    0.5384849635394924,
                                    0.4386018697840949,
                                    0.012627737168817495,
                                    0.010285429507595284,
                                ],
                                [
                                    0.16924467762549758,
                                    0.13785163390566155,
                                    0.38186802308281226,
                                    0.3110356653860286,
                                ],
                                [
                                    0.3173817410387544,
                                    0.6443534877873862,
                                    0.012627737168817495,
                                    0.025637034005041956,
                                ],
                                [
                                    0.7490924705401962,
                                    0.21264275828594437,
                                    0.02980430695906578,
                                    0.008460464214793673,
                                ],
                                [
                                    0.16924467762549755,
                                    0.3436032519089528,
                                    0.1607648005820743,
                                    0.3263872698834753,
                                ],
                                [
                                    0.399455599661552,
                                    0.11339232987289839,
                                    0.37944117783771,
                                    0.10771089262783962,
                                ],
                                [
                                    0.3747129959589861,
                                    0.6204662230515878,
                                    0.0018151597751467474,
                                    0.0030056212142792714,
                                ],
                                [
                                    0.024327884471818596,
                                    0.04028317874172911,
                                    0.3522002712623143,
                                    0.583188665524138,
                                ],
                                [
                                    0.06761668442782702,
                                    0.9062402713252077,
                                    0.0018151597751467471,
                                    0.024327884471818592,
                                ],
                                [
                                    0.6747890766823145,
                                    0.29906787907072013,
                                    0.018114611786526392,
                                    0.008028432460438942,
                                ],
                                [
                                    0.024327884471818613,
                                    0.32605722701534895,
                                    0.045103959731155156,
                                    0.6045109287816773,
                                ],
                                [
                                    0.2427831361340244,
                                    0.10760197535314311,
                                    0.45012055233481646,
                                    0.19949433617801596,
                                ],
                                [
                                    0.6606707252279942,
                                    0.032232963240846645,
                                    0.2928105972454448,
                                    0.014285714285714285,
                                ],
                                [
                                    0.5944687585955731,
                                    0.029003085670294096,
                                    0.35901256387786595,
                                    0.01751559185626684,
                                ],
                                [
                                    0.6377575585515814,
                                    0.047584567738293324,
                                    0.2928105972454448,
                                    0.021847276464680394,
                                ],
                                [
                                    0.6696387679198278,
                                    0.01570335837004704,
                                    0.30744806540375946,
                                    0.007209808306365742,
                                ],
                                [
                                    0.594468758595573,
                                    0.04435469016774077,
                                    0.33609939720145315,
                                    0.025077154035232946,
                                ],
                                [
                                    0.6241859806049992,
                                    0.01463746815831465,
                                    0.352900852718588,
                                    0.008275698518098128,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.3496368708786442,
                                    0.09925042841304595,
                                    0.4292599066206178,
                                    0.12185279408769208,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.6620440506129013,
                                    0.08091263026700796,
                                    0.22904969368026476,
                                    0.027993625439825885,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.46502035219943366,
                                    0.0568331061797376,
                                    0.42607339209373246,
                                    0.05207314952709625,
                                ],
                                [
                                    0.4910930800016869,
                                    0.40000066429147924,
                                    0.060019620706622985,
                                    0.048886635000210864,
                                ],
                                [
                                    0.12185279408769206,
                                    0.09925042841304593,
                                    0.4292599066206178,
                                    0.3496368708786442,
                                ],
                                [
                                    0.2699898575009489,
                                    0.5481377277047361,
                                    0.06001962070662299,
                                    0.12185279408769208,
                                ],
                                [
                                    0.6372369396999609,
                                    0.18089064550572406,
                                    0.1416598377993011,
                                    0.04021257699501396,
                                ],
                                [
                                    0.12185279408769208,
                                    0.24738749182630274,
                                    0.20815668411987978,
                                    0.42260302996612537,
                                ],
                                [
                                    0.2876000688213167,
                                    0.08164021709267812,
                                    0.4912967086779453,
                                    0.1394630054080599,
                                ],
                                [
                                    0.3679007033434344,
                                    0.6091861299801529,
                                    0.008627452390698502,
                                    0.014285714285714294,
                                ],
                                [
                                    0.017515591856266877,
                                    0.029003085670294148,
                                    0.359012563877866,
                                    0.5944687585955729,
                                ],
                                [
                                    0.06080439181227527,
                                    0.8149377479834442,
                                    0.008627452390698502,
                                    0.11563040781358205,
                                ],
                                [
                                    0.6068049588120493,
                                    0.26893718098367014,
                                    0.08609872965679159,
                                    0.038159130547488956,
                                ],
                                [
                                    0.01751559185626686,
                                    0.2347547036735855,
                                    0.05191625234670691,
                                    0.6958134521234407,
                                ],
                                [
                                    0.17479901826375924,
                                    0.07747127726609311,
                                    0.5181046702050817,
                                    0.22962503426506597,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.33609939720145315,
                                    0.025077154035232946,
                                    0.594468758595573,
                                    0.04435469016774077,
                                ],
                                [
                                    0.352900852718588,
                                    0.008275698518098128,
                                    0.6241859806049992,
                                    0.01463746815831465,
                                ],
                                [
                                    0.2928105972454448,
                                    0.021847276464680394,
                                    0.6377575585515814,
                                    0.047584567738293324,
                                ],
                                [
                                    0.30744806540375946,
                                    0.007209808306365742,
                                    0.6696387679198278,
                                    0.01570335837004704,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.42607339209373246,
                                    0.05207314952709625,
                                    0.46502035219943366,
                                    0.0568331061797376,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.22904969368026482,
                                    0.027993625439825892,
                                    0.6620440506129013,
                                    0.08091263026700796,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.060019620706623,
                                    0.04888663500021088,
                                    0.4910930800016869,
                                    0.40000066429147924,
                                ],
                                [
                                    0.20815668411987978,
                                    0.42260302996612537,
                                    0.12185279408769208,
                                    0.24738749182630274,
                                ],
                                [
                                    0.4912967086779453,
                                    0.1394630054080599,
                                    0.2876000688213167,
                                    0.08164021709267812,
                                ],
                                [
                                    0.06001962070662298,
                                    0.12185279408769206,
                                    0.2699898575009489,
                                    0.5481377277047361,
                                ],
                                [
                                    0.14165983779930108,
                                    0.04021257699501395,
                                    0.6372369396999609,
                                    0.18089064550572406,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.05191625234670691,
                                    0.6958134521234407,
                                    0.01751559185626686,
                                    0.2347547036735855,
                                ],
                                [
                                    0.5181046702050817,
                                    0.22962503426506597,
                                    0.17479901826375924,
                                    0.07747127726609311,
                                ],
                                [
                                    0.0086274523906985,
                                    0.11563040781358204,
                                    0.06080439181227527,
                                    0.8149377479834442,
                                ],
                                [
                                    0.08609872965679158,
                                    0.03815913054748895,
                                    0.6068049588120493,
                                    0.26893718098367014,
                                ],
                                [
                                    0.12780740863168966,
                                    0.006235498784831825,
                                    0.8256739138417495,
                                    0.04028317874172911,
                                ],
                                [
                                    0.061605441999268436,
                                    0.0030056212142792697,
                                    0.8918758804741707,
                                    0.04351305631228167,
                                ],
                                [
                                    0.1048942419552768,
                                    0.007826402203705283,
                                    0.8256739138417495,
                                    0.06160544199926843,
                                ],
                                [
                                    0.11013785725149472,
                                    0.002582786907487371,
                                    0.8669489760720925,
                                    0.02033037976892541,
                                ],
                                [
                                    0.061605441999268436,
                                    0.004596524633152731,
                                    0.8689627137977578,
                                    0.06483531956982098,
                                ],
                                [
                                    0.06468506993666619,
                                    0.0015168966957549836,
                                    0.912401763386921,
                                    0.021396269980657794,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.03623324801896572,
                                    0.010285429507595303,
                                    0.7426635294802962,
                                    0.2108177929931427,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.24521426170493774,
                                    0.029969200501327356,
                                    0.6458794825882284,
                                    0.07893705520550649,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.048190563291470104,
                                    0.005889676414057005,
                                    0.842903181001696,
                                    0.10301657929277684,
                                ],
                                [
                                    0.38186802308281226,
                                    0.3110356653860286,
                                    0.16924467762549755,
                                    0.13785163390566152,
                                ],
                                [
                                    0.012627737168817536,
                                    0.010285429507595319,
                                    0.5384849635394924,
                                    0.4386018697840948,
                                ],
                                [
                                    0.16076480058207432,
                                    0.32638726988347533,
                                    0.16924467762549755,
                                    0.3436032519089528,
                                ],
                                [
                                    0.37944117783771003,
                                    0.10771089262783963,
                                    0.399455599661552,
                                    0.11339232987289839,
                                ],
                                [
                                    0.012627737168817516,
                                    0.025637034005041998,
                                    0.3173817410387544,
                                    0.6443534877873861,
                                ],
                                [
                                    0.02980430695906583,
                                    0.008460464214793687,
                                    0.7490924705401962,
                                    0.21264275828594434,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181861,
                                    0.04028317874172913,
                                ],
                                [
                                    0.001815159775146765,
                                    0.003005621214279301,
                                    0.3747129959589861,
                                    0.6204662230515878,
                                ],
                                [
                                    0.045103959731155156,
                                    0.6045109287816773,
                                    0.024327884471818613,
                                    0.32605722701534895,
                                ],
                                [
                                    0.45012055233481646,
                                    0.19949433617801596,
                                    0.2427831361340244,
                                    0.10760197535314311,
                                ],
                                [
                                    0.0018151597751467474,
                                    0.024327884471818596,
                                    0.06761668442782702,
                                    0.9062402713252077,
                                ],
                                [
                                    0.018114611786526395,
                                    0.008028432460438944,
                                    0.6747890766823145,
                                    0.29906787907072013,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8256739138417495,
                                    0.04028317874172911,
                                    0.1278074086316896,
                                    0.006235498784831823,
                                ],
                                [
                                    0.8689627137977578,
                                    0.06483531956982098,
                                    0.06160544199926842,
                                    0.00459652463315273,
                                ],
                                [
                                    0.8903589837784157,
                                    0.043439049589163184,
                                    0.06312233869502341,
                                    0.0030796279373977472,
                                ],
                                [
                                    0.8256739138417495,
                                    0.06160544199926843,
                                    0.1048942419552768,
                                    0.007826402203705283,
                                ],
                                [
                                    0.8460042936106749,
                                    0.041275062230343024,
                                    0.10747702886276418,
                                    0.005243615296217912,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.4856202103602057,
                                    0.13785163390566152,
                                    0.2932765671390563,
                                    0.0832515885950765,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.7367738530662394,
                                    0.20914590722823365,
                                    0.04212292443302265,
                                    0.011957315272504392,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.5645572655657123,
                                    0.16025927222802278,
                                    0.2143395119335498,
                                    0.060843950272715254,
                                ],
                                [
                                    0.5384849635394924,
                                    0.4386018697840949,
                                    0.012627737168817495,
                                    0.010285429507595284,
                                ],
                                [
                                    0.16924467762549758,
                                    0.13785163390566155,
                                    0.38186802308281226,
                                    0.3110356653860286,
                                ],
                                [
                                    0.3173817410387544,
                                    0.6443534877873862,
                                    0.012627737168817495,
                                    0.025637034005041956,
                                ],
                                [
                                    0.5300244993246988,
                                    0.43171072950144185,
                                    0.021088201383611165,
                                    0.017176569790248286,
                                ],
                                [
                                    0.16924467762549755,
                                    0.3436032519089528,
                                    0.1607648005820743,
                                    0.3263872698834753,
                                ],
                                [
                                    0.28263700749839593,
                                    0.23021092203605442,
                                    0.26847569320991393,
                                    0.21867637725563568,
                                ],
                                [
                                    0.3747129959589861,
                                    0.6204662230515878,
                                    0.0018151597751467474,
                                    0.0030056212142792714,
                                ],
                                [
                                    0.024327884471818596,
                                    0.04028317874172911,
                                    0.3522002712623143,
                                    0.583188665524138,
                                ],
                                [
                                    0.06761668442782702,
                                    0.9062402713252077,
                                    0.0018151597751467471,
                                    0.024327884471818592,
                                ],
                                [
                                    0.3666845634985472,
                                    0.6071723922544875,
                                    0.009843592235585692,
                                    0.016299452011379646,
                                ],
                                [
                                    0.024327884471818613,
                                    0.32605722701534895,
                                    0.045103959731155156,
                                    0.6045109287816773,
                                ],
                                [
                                    0.13192985982496175,
                                    0.2184552516622058,
                                    0.24459829590917115,
                                    0.4050165926036613,
                                ],
                                [
                                    0.6606707252279942,
                                    0.032232963240846645,
                                    0.2928105972454448,
                                    0.014285714285714285,
                                ],
                                [
                                    0.5944687585955731,
                                    0.029003085670294096,
                                    0.35901256387786595,
                                    0.01751559185626684,
                                ],
                                [
                                    0.6377575585515814,
                                    0.047584567738293324,
                                    0.2928105972454448,
                                    0.021847276464680394,
                                ],
                                [
                                    0.6534609169216286,
                                    0.03188120936824628,
                                    0.3000204055518106,
                                    0.01463746815831465,
                                ],
                                [
                                    0.594468758595573,
                                    0.04435469016774077,
                                    0.33609939720145315,
                                    0.025077154035232946,
                                ],
                                [
                                    0.6091062267538878,
                                    0.02971722200942612,
                                    0.3443750957195513,
                                    0.016801455517134814,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.3496368708786442,
                                    0.09925042841304595,
                                    0.4292599066206178,
                                    0.12185279408769208,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.5786865645589089,
                                    0.1642701163210004,
                                    0.20021021294035304,
                                    0.05683310617973761,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.4064699770583818,
                                    0.11538348132078954,
                                    0.3724268004408802,
                                    0.10571974117994848,
                                ],
                                [
                                    0.4910930800016869,
                                    0.40000066429147924,
                                    0.060019620706622985,
                                    0.048886635000210864,
                                ],
                                [
                                    0.12185279408769206,
                                    0.09925042841304593,
                                    0.4292599066206178,
                                    0.3496368708786442,
                                ],
                                [
                                    0.2699898575009489,
                                    0.5481377277047361,
                                    0.06001962070662299,
                                    0.12185279408769208,
                                ],
                                [
                                    0.45088050300667293,
                                    0.36724708219901203,
                                    0.10023219770163695,
                                    0.08164021709267812,
                                ],
                                [
                                    0.12185279408769208,
                                    0.24738749182630274,
                                    0.20815668411987978,
                                    0.42260302996612537,
                                ],
                                [
                                    0.2034930111803702,
                                    0.16574727473362463,
                                    0.34761968952793965,
                                    0.28314002455806553,
                                ],
                                [
                                    0.3679007033434344,
                                    0.6091861299801529,
                                    0.008627452390698502,
                                    0.014285714285714294,
                                ],
                                [
                                    0.017515591856266877,
                                    0.029003085670294148,
                                    0.359012563877866,
                                    0.5944687585955729,
                                ],
                                [
                                    0.06080439181227527,
                                    0.8149377479834442,
                                    0.008627452390698502,
                                    0.11563040781358205,
                                ],
                                [
                                    0.32974157279594546,
                                    0.5460005669997741,
                                    0.046786582938187465,
                                    0.0774712772660931,
                                ],
                                [
                                    0.01751559185626686,
                                    0.2347547036735855,
                                    0.05191625234670691,
                                    0.6958134521234407,
                                ],
                                [
                                    0.09498686912235998,
                                    0.15728342640749238,
                                    0.2815412866117729,
                                    0.4661884178583747,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.33609939720145315,
                                    0.025077154035232946,
                                    0.594468758595573,
                                    0.04435469016774077,
                                ],
                                [
                                    0.3443750957195513,
                                    0.016801455517134814,
                                    0.6091062267538878,
                                    0.02971722200942612,
                                ],
                                [
                                    0.2928105972454448,
                                    0.021847276464680394,
                                    0.6377575585515814,
                                    0.047584567738293324,
                                ],
                                [
                                    0.3000204055518106,
                                    0.01463746815831465,
                                    0.6534609169216286,
                                    0.03188120936824628,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.3724268004408802,
                                    0.10571974117994848,
                                    0.4064699770583818,
                                    0.11538348132078954,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.2002102129403531,
                                    0.05683310617973762,
                                    0.5786865645589089,
                                    0.1642701163210004,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.060019620706623,
                                    0.04888663500021088,
                                    0.4910930800016869,
                                    0.40000066429147924,
                                ],
                                [
                                    0.20815668411987978,
                                    0.42260302996612537,
                                    0.12185279408769208,
                                    0.24738749182630274,
                                ],
                                [
                                    0.34761968952793965,
                                    0.28314002455806553,
                                    0.2034930111803702,
                                    0.16574727473362463,
                                ],
                                [
                                    0.06001962070662298,
                                    0.12185279408769206,
                                    0.2699898575009489,
                                    0.5481377277047361,
                                ],
                                [
                                    0.10023219770163694,
                                    0.0816402170926781,
                                    0.45088050300667293,
                                    0.36724708219901203,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.05191625234670691,
                                    0.6958134521234407,
                                    0.01751559185626686,
                                    0.2347547036735855,
                                ],
                                [
                                    0.2815412866117729,
                                    0.4661884178583747,
                                    0.09498686912235998,
                                    0.15728342640749238,
                                ],
                                [
                                    0.0086274523906985,
                                    0.11563040781358204,
                                    0.06080439181227527,
                                    0.8149377479834442,
                                ],
                                [
                                    0.04678658293818746,
                                    0.07747127726609308,
                                    0.32974157279594546,
                                    0.5460005669997741,
                                ],
                                [
                                    0.12780740863168966,
                                    0.006235498784831825,
                                    0.8256739138417495,
                                    0.04028317874172911,
                                ],
                                [
                                    0.061605441999268436,
                                    0.0030056212142792697,
                                    0.8918758804741707,
                                    0.04351305631228167,
                                ],
                                [
                                    0.1048942419552768,
                                    0.007826402203705283,
                                    0.8256739138417495,
                                    0.06160544199926843,
                                ],
                                [
                                    0.10747702886276418,
                                    0.005243615296217912,
                                    0.8460042936106749,
                                    0.041275062230343024,
                                ],
                                [
                                    0.061605441999268436,
                                    0.004596524633152731,
                                    0.8689627137977578,
                                    0.06483531956982098,
                                ],
                                [
                                    0.06312233869502343,
                                    0.0030796279373977477,
                                    0.8903589837784157,
                                    0.043439049589163184,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.03623324801896572,
                                    0.010285429507595303,
                                    0.7426635294802962,
                                    0.2108177929931427,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.21433951193354986,
                                    0.06084395027271527,
                                    0.5645572655657122,
                                    0.16025927222802275,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.04212292443302271,
                                    0.011957315272504408,
                                    0.7367738530662393,
                                    0.20914590722823362,
                                ],
                                [
                                    0.38186802308281226,
                                    0.3110356653860286,
                                    0.16924467762549755,
                                    0.13785163390566152,
                                ],
                                [
                                    0.012627737168817536,
                                    0.010285429507595319,
                                    0.5384849635394924,
                                    0.4386018697840948,
                                ],
                                [
                                    0.16076480058207432,
                                    0.32638726988347533,
                                    0.16924467762549755,
                                    0.3436032519089528,
                                ],
                                [
                                    0.26847569320991393,
                                    0.2186763772556357,
                                    0.28263700749839593,
                                    0.23021092203605442,
                                ],
                                [
                                    0.012627737168817516,
                                    0.025637034005041998,
                                    0.3173817410387544,
                                    0.6443534877873861,
                                ],
                                [
                                    0.0210882013836112,
                                    0.017176569790248314,
                                    0.5300244993246986,
                                    0.43171072950144185,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181861,
                                    0.04028317874172913,
                                ],
                                [
                                    0.001815159775146765,
                                    0.003005621214279301,
                                    0.3747129959589861,
                                    0.6204662230515878,
                                ],
                                [
                                    0.045103959731155156,
                                    0.6045109287816773,
                                    0.024327884471818613,
                                    0.32605722701534895,
                                ],
                                [
                                    0.24459829590917115,
                                    0.4050165926036613,
                                    0.13192985982496175,
                                    0.2184552516622058,
                                ],
                                [
                                    0.0018151597751467474,
                                    0.024327884471818596,
                                    0.06761668442782702,
                                    0.9062402713252077,
                                ],
                                [
                                    0.009843592235585693,
                                    0.01629945201137965,
                                    0.3666845634985472,
                                    0.6071723922544875,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8256739138417495,
                                    0.04028317874172911,
                                    0.1278074086316896,
                                    0.006235498784831823,
                                ],
                                [
                                    0.8689627137977578,
                                    0.06483531956982098,
                                    0.06160544199926842,
                                    0.00459652463315273,
                                ],
                                [
                                    0.8734643496049797,
                                    0.06033368376259915,
                                    0.06192458718147262,
                                    0.0042773794509485385,
                                ],
                                [
                                    0.8256739138417495,
                                    0.06160544199926843,
                                    0.1048942419552768,
                                    0.007826402203705283,
                                ],
                                [
                                    0.829951293292698,
                                    0.05732806254831988,
                                    0.10543764349375427,
                                    0.007283000665227806,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.4856202103602057,
                                    0.13785163390566152,
                                    0.2932765671390563,
                                    0.0832515885950765,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.6554312909036022,
                                    0.2904884693908708,
                                    0.03747239756523875,
                                    0.01660784214028829,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.502228052500494,
                                    0.222588485293241,
                                    0.1906756359683469,
                                    0.08450782623791811,
                                ],
                                [
                                    0.5384849635394924,
                                    0.4386018697840949,
                                    0.012627737168817495,
                                    0.010285429507595284,
                                ],
                                [
                                    0.16924467762549758,
                                    0.13785163390566155,
                                    0.38186802308281226,
                                    0.3110356653860286,
                                ],
                                [
                                    0.3173817410387544,
                                    0.6443534877873862,
                                    0.012627737168817495,
                                    0.025637034005041956,
                                ],
                                [
                                    0.362120392014451,
                                    0.5996148368116896,
                                    0.01440776371968191,
                                    0.02385700745417754,
                                ],
                                [
                                    0.16924467762549755,
                                    0.3436032519089528,
                                    0.1607648005820743,
                                    0.3263872698834753,
                                ],
                                [
                                    0.19310168507967512,
                                    0.31974624445477523,
                                    0.18342647065445775,
                                    0.3037255998110919,
                                ],
                                [
                                    0.3747129959589861,
                                    0.6204662230515878,
                                    0.0018151597751467474,
                                    0.0030056212142792714,
                                ],
                                [
                                    0.024327884471818596,
                                    0.04028317874172911,
                                    0.3522002712623143,
                                    0.583188665524138,
                                ],
                                [
                                    0.06761668442782702,
                                    0.9062402713252077,
                                    0.0018151597751467471,
                                    0.024327884471818592,
                                ],
                                [
                                    0.13053861775693948,
                                    0.8433183379960952,
                                    0.003504289659581999,
                                    0.02263875458738334,
                                ],
                                [
                                    0.024327884471818613,
                                    0.32605722701534895,
                                    0.045103959731155156,
                                    0.6045109287816773,
                                ],
                                [
                                    0.04696663905920195,
                                    0.3034184724279656,
                                    0.08707626835731952,
                                    0.5625386201555129,
                                ],
                                [
                                    0.6606707252279942,
                                    0.032232963240846645,
                                    0.2928105972454448,
                                    0.014285714285714285,
                                ],
                                [
                                    0.5944687585955731,
                                    0.029003085670294096,
                                    0.35901256387786595,
                                    0.01751559185626684,
                                ],
                                [
                                    0.6377575585515814,
                                    0.047584567738293324,
                                    0.2928105972454448,
                                    0.021847276464680394,
                                ],
                                [
                                    0.6410614428452525,
                                    0.044280683444622285,
                                    0.2943274939411998,
                                    0.020330379768925405,
                                ],
                                [
                                    0.594468758595573,
                                    0.04435469016774077,
                                    0.33609939720145315,
                                    0.025077154035232946,
                                ],
                                [
                                    0.5975483865329708,
                                    0.04127506223034302,
                                    0.3378405502534815,
                                    0.023336000983204673,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.3496368708786442,
                                    0.09925042841304595,
                                    0.4292599066206178,
                                    0.12185279408769208,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.5147974245542567,
                                    0.22815925632565257,
                                    0.17810626391458415,
                                    0.07893705520550649,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.3615941861511485,
                                    0.16025927222802275,
                                    0.33130950231769235,
                                    0.14683703930313632,
                                ],
                                [
                                    0.4910930800016869,
                                    0.40000066429147924,
                                    0.060019620706622985,
                                    0.048886635000210864,
                                ],
                                [
                                    0.12185279408769206,
                                    0.09925042841304593,
                                    0.4292599066206178,
                                    0.3496368708786442,
                                ],
                                [
                                    0.2699898575009489,
                                    0.5481377277047361,
                                    0.06001962070662299,
                                    0.12185279408769208,
                                ],
                                [
                                    0.30804807081271623,
                                    0.5100795143929687,
                                    0.06848008492141668,
                                    0.11339232987289839,
                                ],
                                [
                                    0.12185279408769208,
                                    0.24738749182630274,
                                    0.20815668411987978,
                                    0.42260302996612537,
                                ],
                                [
                                    0.1390293638779404,
                                    0.23021092203605442,
                                    0.2374987918561925,
                                    0.3932609222298127,
                                ],
                                [
                                    0.3679007033434344,
                                    0.6091861299801529,
                                    0.008627452390698502,
                                    0.014285714285714294,
                                ],
                                [
                                    0.017515591856266877,
                                    0.029003085670294148,
                                    0.359012563877866,
                                    0.5944687585955729,
                                ],
                                [
                                    0.06080439181227527,
                                    0.8149377479834442,
                                    0.008627452390698502,
                                    0.11563040781358205,
                                ],
                                [
                                    0.11738702256538402,
                                    0.7583551172303354,
                                    0.016655884851137448,
                                    0.10760197535314311,
                                ],
                                [
                                    0.01751559185626686,
                                    0.2347547036735855,
                                    0.05191625234670691,
                                    0.6958134521234407,
                                ],
                                [
                                    0.03381504386764651,
                                    0.21845525166220586,
                                    0.10022786354887496,
                                    0.6475018409212727,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.33609939720145315,
                                    0.025077154035232946,
                                    0.594468758595573,
                                    0.04435469016774077,
                                ],
                                [
                                    0.3378405502534815,
                                    0.023336000983204673,
                                    0.5975483865329708,
                                    0.04127506223034302,
                                ],
                                [
                                    0.2928105972454448,
                                    0.021847276464680394,
                                    0.6377575585515814,
                                    0.047584567738293324,
                                ],
                                [
                                    0.2943274939411998,
                                    0.020330379768925405,
                                    0.6410614428452525,
                                    0.044280683444622285,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.33130950231769235,
                                    0.14683703930313632,
                                    0.3615941861511485,
                                    0.16025927222802275,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.17810626391458417,
                                    0.0789370552055065,
                                    0.5147974245542567,
                                    0.22815925632565257,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.060019620706623,
                                    0.04888663500021088,
                                    0.4910930800016869,
                                    0.40000066429147924,
                                ],
                                [
                                    0.20815668411987978,
                                    0.42260302996612537,
                                    0.12185279408769208,
                                    0.24738749182630274,
                                ],
                                [
                                    0.2374987918561925,
                                    0.3932609222298127,
                                    0.1390293638779404,
                                    0.23021092203605442,
                                ],
                                [
                                    0.06001962070662298,
                                    0.12185279408769206,
                                    0.2699898575009489,
                                    0.5481377277047361,
                                ],
                                [
                                    0.06848008492141668,
                                    0.11339232987289836,
                                    0.30804807081271623,
                                    0.5100795143929687,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.05191625234670691,
                                    0.6958134521234407,
                                    0.01751559185626686,
                                    0.2347547036735855,
                                ],
                                [
                                    0.10022786354887496,
                                    0.6475018409212727,
                                    0.03381504386764651,
                                    0.21845525166220586,
                                ],
                                [
                                    0.0086274523906985,
                                    0.11563040781358204,
                                    0.06080439181227527,
                                    0.8149377479834442,
                                ],
                                [
                                    0.016655884851137445,
                                    0.10760197535314309,
                                    0.11738702256538402,
                                    0.7583551172303354,
                                ],
                                [
                                    0.12780740863168966,
                                    0.006235498784831825,
                                    0.8256739138417495,
                                    0.04028317874172911,
                                ],
                                [
                                    0.061605441999268436,
                                    0.0030056212142792697,
                                    0.8918758804741707,
                                    0.04351305631228167,
                                ],
                                [
                                    0.1048942419552768,
                                    0.007826402203705283,
                                    0.8256739138417495,
                                    0.06160544199926843,
                                ],
                                [
                                    0.10543764349375427,
                                    0.007283000665227806,
                                    0.829951293292698,
                                    0.05732806254831988,
                                ],
                                [
                                    0.061605441999268436,
                                    0.004596524633152731,
                                    0.8689627137977578,
                                    0.06483531956982098,
                                ],
                                [
                                    0.06192458718147263,
                                    0.004277379450948539,
                                    0.8734643496049797,
                                    0.06033368376259915,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.03623324801896572,
                                    0.010285429507595303,
                                    0.7426635294802962,
                                    0.2108177929931427,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.19067563596834697,
                                    0.08450782623791812,
                                    0.502228052500494,
                                    0.22258848529324093,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.0374723975652388,
                                    0.016607842140288313,
                                    0.6554312909036021,
                                    0.29048846939087075,
                                ],
                                [
                                    0.38186802308281226,
                                    0.3110356653860286,
                                    0.16924467762549755,
                                    0.13785163390566152,
                                ],
                                [
                                    0.012627737168817536,
                                    0.010285429507595319,
                                    0.5384849635394924,
                                    0.4386018697840948,
                                ],
                                [
                                    0.16076480058207432,
                                    0.32638726988347533,
                                    0.16924467762549755,
                                    0.3436032519089528,
                                ],
                                [
                                    0.18342647065445777,
                                    0.3037255998110919,
                                    0.19310168507967512,
                                    0.31974624445477523,
                                ],
                                [
                                    0.012627737168817516,
                                    0.025637034005041998,
                                    0.3173817410387544,
                                    0.6443534877873861,
                                ],
                                [
                                    0.014407763719681934,
                                    0.02385700745417758,
                                    0.36212039201445095,
                                    0.5996148368116895,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181861,
                                    0.04028317874172913,
                                ],
                                [
                                    0.001815159775146765,
                                    0.003005621214279301,
                                    0.3747129959589861,
                                    0.6204662230515878,
                                ],
                                [
                                    0.045103959731155156,
                                    0.6045109287816773,
                                    0.024327884471818613,
                                    0.32605722701534895,
                                ],
                                [
                                    0.08707626835731952,
                                    0.5625386201555129,
                                    0.04696663905920195,
                                    0.3034184724279656,
                                ],
                                [
                                    0.0018151597751467474,
                                    0.024327884471818596,
                                    0.06761668442782702,
                                    0.9062402713252077,
                                ],
                                [
                                    0.0035042896595819995,
                                    0.02263875458738334,
                                    0.13053861775693948,
                                    0.8433183379960952,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8100066841343474,
                                    0.0559504084491311,
                                    0.12538225265210484,
                                    0.008660654764416586,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879417,
                                    0.06043647372396264,
                                    0.004509305204179541,
                                ],
                                [
                                    0.930546529458832,
                                    0.0045076916130257615,
                                    0.06463268955174192,
                                    0.00031308937640025245,
                                ],
                                [
                                    0.8100066841343474,
                                    0.06043647372396264,
                                    0.1205614716626788,
                                    0.008995370479011071,
                                ],
                                [
                                    0.8662469420305308,
                                    0.004196215827779288,
                                    0.12893227698004314,
                                    0.0006245651616467257,
                                ],
                                [
                                    0.6606707252279942,
                                    0.2928105972454448,
                                    0.032232963240846645,
                                    0.014285714285714285,
                                ],
                                [
                                    0.4320059405482901,
                                    0.19146590371757705,
                                    0.26089774792055076,
                                    0.11563040781358203,
                                ],
                                [
                                    0.6377575585515814,
                                    0.3141328605029841,
                                    0.03223296324084665,
                                    0.01587661770458775,
                                ],
                                [
                                    0.930079595225088,
                                    0.021810823829477667,
                                    0.047007238098499285,
                                    0.0011023428469351107,
                                ],
                                [
                                    0.4320059405482901,
                                    0.21278816697511638,
                                    0.23798458124413796,
                                    0.11722131123245548,
                                ],
                                [
                                    0.6300198326657539,
                                    0.014774274857652635,
                                    0.3470670006578333,
                                    0.008138891818760142,
                                ],
                                [
                                    0.3679007033434344,
                                    0.6091861299801529,
                                    0.008627452390698495,
                                    0.014285714285714284,
                                ],
                                [
                                    0.11563040781358208,
                                    0.19146590371757705,
                                    0.2608977479205508,
                                    0.43200594054829006,
                                ],
                                [
                                    0.32138202581687336,
                                    0.6524749299361613,
                                    0.008627452390698495,
                                    0.017515591856266843,
                                ],
                                [
                                    0.928554418071361,
                                    0.04530253768167374,
                                    0.024926904402078145,
                                    0.0012161398448871947,
                                ],
                                [
                                    0.11563040781358207,
                                    0.2347547036735855,
                                    0.21437907039398982,
                                    0.43523581811884265,
                                ],
                                [
                                    0.3340856594757879,
                                    0.01629945201137965,
                                    0.6193956629976511,
                                    0.030219225515181285,
                                ],
                                [
                                    0.1333967159166805,
                                    0.8617825030938935,
                                    0.0006461914998409586,
                                    0.00417458948958506,
                                ],
                                [
                                    0.008660654764416591,
                                    0.055950408449131114,
                                    0.12538225265210487,
                                    0.8100066841343474,
                                ],
                                [
                                    0.0687856527031328,
                                    0.9219075010326095,
                                    0.0006461914998409586,
                                    0.00866065476441659,
                                ],
                                [
                                    0.9266834157544934,
                                    0.06400973798124897,
                                    0.008705521031958834,
                                    0.0006013252322987147,
                                ],
                                [
                                    0.008660654764416595,
                                    0.11607540638784729,
                                    0.06077118943855717,
                                    0.8144927494091789,
                                ],
                                [
                                    0.11667673162014601,
                                    0.008059329532117871,
                                    0.8187122051663063,
                                    0.056551733681429815,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.5831886655241381,
                                    0.040283178741729105,
                                    0.3522002712623142,
                                    0.024327884471818582,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711319,
                                    0.287254492334172,
                                    0.021432722615860517,
                                ],
                                [
                                    0.6879801175180513,
                                    0.0033326675319160356,
                                    0.30719910149252255,
                                    0.0014881134575099786,
                                ],
                                [
                                    0.583188665524138,
                                    0.04351305631228166,
                                    0.34737949027288817,
                                    0.025918787890692047,
                                ],
                                [
                                    0.6236805300897501,
                                    0.003021191746669562,
                                    0.37149868892082377,
                                    0.001799589242756452,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.3110356653860286,
                                    0.13785163390566152,
                                    0.38186802308281226,
                                    0.16924467762549755,
                                ],
                                [
                                    0.51678728338932,
                                    0.25454793193097597,
                                    0.15320323840310818,
                                    0.07546154627659593,
                                ],
                                [
                                    0.7536614829682753,
                                    0.01767373235202068,
                                    0.22342535035531202,
                                    0.005239434324392099,
                                ],
                                [
                                    0.3110356653860286,
                                    0.1532032384031082,
                                    0.3589548564063995,
                                    0.17680623980446367,
                                ],
                                [
                                    0.45360172040894114,
                                    0.010637183380195647,
                                    0.5234851129146461,
                                    0.012275983296217131,
                                ],
                                [
                                    0.33552188412492884,
                                    0.5555718601682372,
                                    0.04100627160920404,
                                    0.06789998409762982,
                                ],
                                [
                                    0.08325158859507652,
                                    0.1378516339056615,
                                    0.29327656713905637,
                                    0.48562021036020564,
                                ],
                                [
                                    0.28900320659836787,
                                    0.5867389331973516,
                                    0.04100627160920404,
                                    0.08325158859507652,
                                ],
                                [
                                    0.8350037735981419,
                                    0.04073836619757752,
                                    0.11847754887529714,
                                    0.005780311328983417,
                                ],
                                [
                                    0.08325158859507653,
                                    0.16901870693477583,
                                    0.24675788961249534,
                                    0.5009718148576523,
                                ],
                                [
                                    0.24053501500256894,
                                    0.01173528052728343,
                                    0.7129463074708702,
                                    0.03478339699927751,
                                ],
                                [
                                    0.13097155993709575,
                                    0.8461152733864915,
                                    0.0030713474794257256,
                                    0.01984181919698707,
                                ],
                                [
                                    0.0062354987848318374,
                                    0.04028317874172919,
                                    0.12780740863168963,
                                    0.8256739138417494,
                                ],
                                [
                                    0.06636049672354805,
                                    0.8894040733424998,
                                    0.0030713474794257256,
                                    0.04116408245452639,
                                ],
                                [
                                    0.8940116050122412,
                                    0.06175296505380665,
                                    0.041377331774211074,
                                    0.0028580981597410397,
                                ],
                                [
                                    0.00623549878483183,
                                    0.08357197869773751,
                                    0.06319634541814194,
                                    0.8469961770992888,
                                ],
                                [
                                    0.0840049208778938,
                                    0.005802556604675549,
                                    0.8513840159085585,
                                    0.058808506608872144,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.28725449233417205,
                                    0.019841819196987055,
                                    0.6481344444522802,
                                    0.044769244016560635,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069205,
                                    0.583188665524138,
                                    0.04351305631228166,
                                ],
                                [
                                    0.3714986889208238,
                                    0.0017995892427564522,
                                    0.6236805300897501,
                                    0.003021191746669562,
                                ],
                                [
                                    0.28725449233417205,
                                    0.02143272261586052,
                                    0.6433136634628541,
                                    0.04799912158711319,
                                ],
                                [
                                    0.3071991014925226,
                                    0.001488113457509979,
                                    0.6879801175180513,
                                    0.0033326675319160356,
                                ],
                                [
                                    0.38186802308281226,
                                    0.16924467762549755,
                                    0.3110356653860286,
                                    0.13785163390566152,
                                ],
                                [
                                    0.15320323840310818,
                                    0.06789998409762982,
                                    0.5397004500657328,
                                    0.23919632743352925,
                                ],
                                [
                                    0.3589548564063995,
                                    0.17680623980446367,
                                    0.31103566538602856,
                                    0.15320323840310818,
                                ],
                                [
                                    0.5234851129146461,
                                    0.012275983296217131,
                                    0.4536017204089411,
                                    0.010637183380195646,
                                ],
                                [
                                    0.15320323840310823,
                                    0.07546154627659596,
                                    0.5167872833893199,
                                    0.2545479319309759,
                                ],
                                [
                                    0.2234253503553121,
                                    0.005239434324392101,
                                    0.7536614829682752,
                                    0.017673732352020678,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.041006271609204045,
                                    0.06789998409762983,
                                    0.33552188412492884,
                                    0.5555718601682372,
                                ],
                                [
                                    0.24675788961249534,
                                    0.5009718148576523,
                                    0.08325158859507653,
                                    0.16901870693477583,
                                ],
                                [
                                    0.7129463074708702,
                                    0.03478339699927751,
                                    0.24053501500256894,
                                    0.01173528052728343,
                                ],
                                [
                                    0.04100627160920403,
                                    0.0832515885950765,
                                    0.28900320659836787,
                                    0.5867389331973516,
                                ],
                                [
                                    0.11847754887529713,
                                    0.005780311328983415,
                                    0.8350037735981419,
                                    0.04073836619757752,
                                ],
                                [
                                    0.12780740863168966,
                                    0.8256739138417495,
                                    0.0062354987848318305,
                                    0.04028317874172914,
                                ],
                                [
                                    0.0030713474794257334,
                                    0.01984181919698712,
                                    0.13097155993709575,
                                    0.8461152733864914,
                                ],
                                [
                                    0.06319634541814194,
                                    0.8469961770992888,
                                    0.0062354987848318305,
                                    0.08357197869773753,
                                ],
                                [
                                    0.8513840159085585,
                                    0.058808506608872144,
                                    0.08400492087789381,
                                    0.00580255660467555,
                                ],
                                [
                                    0.0030713474794257264,
                                    0.04116408245452641,
                                    0.06636049672354805,
                                    0.8894040733424998,
                                ],
                                [
                                    0.04137733177421109,
                                    0.002858098159741041,
                                    0.8940116050122412,
                                    0.06175296505380665,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011075,
                                    0.8100066841343474,
                                    0.06043647372396264,
                                ],
                                [
                                    0.1289322769800432,
                                    0.0006245651616467261,
                                    0.8662469420305308,
                                    0.004196215827779288,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179545,
                                    0.8701316820730636,
                                    0.06492253899879417,
                                ],
                                [
                                    0.06463268955174198,
                                    0.0003130893764002527,
                                    0.930546529458832,
                                    0.0045076916130257615,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.23798458124413802,
                                    0.11722131123245551,
                                    0.4320059405482901,
                                    0.21278816697511638,
                                ],
                                [
                                    0.34706700065783336,
                                    0.008138891818760144,
                                    0.6300198326657539,
                                    0.014774274857652635,
                                ],
                                [
                                    0.03223296324084664,
                                    0.01587661770458774,
                                    0.6377575585515814,
                                    0.3141328605029841,
                                ],
                                [
                                    0.04700723809849927,
                                    0.0011023428469351102,
                                    0.930079595225088,
                                    0.021810823829477667,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.21437907039398982,
                                    0.43523581811884265,
                                    0.11563040781358207,
                                    0.2347547036735855,
                                ],
                                [
                                    0.6193956629976511,
                                    0.030219225515181285,
                                    0.3340856594757879,
                                    0.01629945201137965,
                                ],
                                [
                                    0.008627452390698495,
                                    0.017515591856266846,
                                    0.32138202581687336,
                                    0.6524749299361613,
                                ],
                                [
                                    0.02492690440207815,
                                    0.0012161398448871947,
                                    0.928554418071361,
                                    0.04530253768167374,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.004174589489585101,
                                    0.1333967159166805,
                                    0.8617825030938935,
                                ],
                                [
                                    0.06077118943855717,
                                    0.8144927494091789,
                                    0.008660654764416598,
                                    0.11607540638784732,
                                ],
                                [
                                    0.8187122051663063,
                                    0.056551733681429815,
                                    0.11667673162014604,
                                    0.008059329532117875,
                                ],
                                [
                                    0.0006461914998409619,
                                    0.008660654764416634,
                                    0.0687856527031328,
                                    0.9219075010326095,
                                ],
                                [
                                    0.008705521031958877,
                                    0.0006013252322987177,
                                    0.9266834157544934,
                                    0.06400973798124897,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8100066841343474,
                                    0.0559504084491311,
                                    0.12538225265210484,
                                    0.008660654764416586,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879417,
                                    0.06043647372396264,
                                    0.004509305204179541,
                                ],
                                [
                                    0.913629167852955,
                                    0.021425053218902798,
                                    0.06345766547063221,
                                    0.0014881134575099788,
                                ],
                                [
                                    0.8100066841343474,
                                    0.06043647372396264,
                                    0.1205614716626788,
                                    0.008995370479011071,
                                ],
                                [
                                    0.8504985486999596,
                                    0.01994460915835054,
                                    0.12658828462362764,
                                    0.0029685575180622395,
                                ],
                                [
                                    0.6606707252279942,
                                    0.2928105972454448,
                                    0.032232963240846645,
                                    0.014285714285714285,
                                ],
                                [
                                    0.4320059405482901,
                                    0.19146590371757705,
                                    0.26089774792055076,
                                    0.11563040781358203,
                                ],
                                [
                                    0.6377575585515814,
                                    0.3141328605029841,
                                    0.03223296324084665,
                                    0.01587661770458775,
                                ],
                                [
                                    0.8482235976721239,
                                    0.10366682138244175,
                                    0.0428701466210423,
                                    0.005239434324392099,
                                ],
                                [
                                    0.4320059405482901,
                                    0.21278816697511638,
                                    0.23798458124413796,
                                    0.11722131123245548,
                                ],
                                [
                                    0.5745719955712026,
                                    0.07022211195220382,
                                    0.3165217487219634,
                                    0.038684143754630015,
                                ],
                                [
                                    0.3679007033434344,
                                    0.6091861299801529,
                                    0.008627452390698495,
                                    0.014285714285714284,
                                ],
                                [
                                    0.11563040781358208,
                                    0.19146590371757705,
                                    0.2608977479205508,
                                    0.43200594054829006,
                                ],
                                [
                                    0.32138202581687336,
                                    0.6524749299361613,
                                    0.008627452390698495,
                                    0.017515591856266843,
                                ],
                                [
                                    0.75853404458128,
                                    0.21532291117175462,
                                    0.02036273291798192,
                                    0.005780311328983416,
                                ],
                                [
                                    0.11563040781358207,
                                    0.2347547036735855,
                                    0.21437907039398982,
                                    0.43523581811884265,
                                ],
                                [
                                    0.27291383422107446,
                                    0.07747127726609311,
                                    0.5059829432781875,
                                    0.14363194523464493,
                                ],
                                [
                                    0.1333967159166805,
                                    0.8617825030938935,
                                    0.0006461914998409586,
                                    0.00417458948958506,
                                ],
                                [
                                    0.008660654764416591,
                                    0.055950408449131114,
                                    0.12538225265210487,
                                    0.8100066841343474,
                                ],
                                [
                                    0.0687856527031328,
                                    0.9219075010326095,
                                    0.0006461914998409586,
                                    0.00866065476441659,
                                ],
                                [
                                    0.6864549403643243,
                                    0.30423821337141804,
                                    0.006448748104516508,
                                    0.00285809815974104,
                                ],
                                [
                                    0.008660654764416595,
                                    0.11607540638784729,
                                    0.06077118943855717,
                                    0.8144927494091789,
                                ],
                                [
                                    0.08643007685747853,
                                    0.038305984294785336,
                                    0.6064736116113624,
                                    0.26879032723637375,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.5831886655241381,
                                    0.040283178741729105,
                                    0.3522002712623142,
                                    0.024327884471818582,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711319,
                                    0.287254492334172,
                                    0.021432722615860517,
                                ],
                                [
                                    0.6754726199805824,
                                    0.015840165069385022,
                                    0.3016142133430048,
                                    0.007073001607027754,
                                ],
                                [
                                    0.583188665524138,
                                    0.04351305631228166,
                                    0.34737949027288817,
                                    0.025918787890692047,
                                ],
                                [
                                    0.6123420008275869,
                                    0.014359721008832763,
                                    0.36474483249600026,
                                    0.008553445667580015,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.3110356653860286,
                                    0.13785163390566152,
                                    0.38186802308281226,
                                    0.16924467762549755,
                                ],
                                [
                                    0.51678728338932,
                                    0.25454793193097597,
                                    0.15320323840310818,
                                    0.07546154627659593,
                                ],
                                [
                                    0.687331985124938,
                                    0.0840032301953579,
                                    0.20376175916822814,
                                    0.024903025511475958,
                                ],
                                [
                                    0.3110356653860286,
                                    0.1532032384031082,
                                    0.3589548564063995,
                                    0.17680623980446367,
                                ],
                                [
                                    0.41368038302401683,
                                    0.05055852076511997,
                                    0.4774133612691493,
                                    0.05834773494171388,
                                ],
                                [
                                    0.33552188412492884,
                                    0.5555718601682372,
                                    0.04100627160920404,
                                    0.06789998409762982,
                                ],
                                [
                                    0.08325158859507652,
                                    0.1378516339056615,
                                    0.29327656713905637,
                                    0.48562021036020564,
                                ],
                                [
                                    0.28900320659836787,
                                    0.5867389331973516,
                                    0.04100627160920404,
                                    0.08325158859507652,
                                ],
                                [
                                    0.6821127306071941,
                                    0.1936294091885254,
                                    0.09678404689206792,
                                    0.027473813312212644,
                                ],
                                [
                                    0.08325158859507653,
                                    0.16901870693477583,
                                    0.24675788961249534,
                                    0.5009718148576523,
                                ],
                                [
                                    0.1964925202469885,
                                    0.05577777528286389,
                                    0.5824042572522735,
                                    0.16532544721787415,
                                ],
                                [
                                    0.13097155993709575,
                                    0.8461152733864915,
                                    0.0030713474794257256,
                                    0.01984181919698707,
                                ],
                                [
                                    0.0062354987848318374,
                                    0.04028317874172919,
                                    0.12780740863168963,
                                    0.8256739138417494,
                                ],
                                [
                                    0.06636049672354805,
                                    0.8894040733424998,
                                    0.0030713474794257256,
                                    0.04116408245452639,
                                ],
                                [
                                    0.6622527959066005,
                                    0.29351177415944735,
                                    0.030650892562240396,
                                    0.01358453737171172,
                                ],
                                [
                                    0.00623549878483183,
                                    0.08357197869773751,
                                    0.06319634541814194,
                                    0.8469961770992888,
                                ],
                                [
                                    0.06222793239975467,
                                    0.02757954508281467,
                                    0.6306757560690862,
                                    0.2795167664483444,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.28725449233417205,
                                    0.019841819196987055,
                                    0.6481344444522802,
                                    0.044769244016560635,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069205,
                                    0.583188665524138,
                                    0.04351305631228166,
                                ],
                                [
                                    0.3647448324960003,
                                    0.008553445667580015,
                                    0.6123420008275869,
                                    0.014359721008832763,
                                ],
                                [
                                    0.28725449233417205,
                                    0.02143272261586052,
                                    0.6433136634628541,
                                    0.04799912158711319,
                                ],
                                [
                                    0.30161421334300487,
                                    0.007073001607027755,
                                    0.6754726199805824,
                                    0.015840165069385022,
                                ],
                                [
                                    0.38186802308281226,
                                    0.16924467762549755,
                                    0.3110356653860286,
                                    0.13785163390566152,
                                ],
                                [
                                    0.15320323840310818,
                                    0.06789998409762982,
                                    0.5397004500657328,
                                    0.23919632743352925,
                                ],
                                [
                                    0.3589548564063995,
                                    0.17680623980446367,
                                    0.31103566538602856,
                                    0.15320323840310818,
                                ],
                                [
                                    0.4774133612691493,
                                    0.05834773494171388,
                                    0.4136803830240168,
                                    0.05055852076511996,
                                ],
                                [
                                    0.15320323840310823,
                                    0.07546154627659596,
                                    0.5167872833893199,
                                    0.2545479319309759,
                                ],
                                [
                                    0.20376175916822822,
                                    0.024903025511475968,
                                    0.6873319851249379,
                                    0.08400323019535788,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.041006271609204045,
                                    0.06789998409762983,
                                    0.33552188412492884,
                                    0.5555718601682372,
                                ],
                                [
                                    0.24675788961249534,
                                    0.5009718148576523,
                                    0.08325158859507653,
                                    0.16901870693477583,
                                ],
                                [
                                    0.5824042572522735,
                                    0.16532544721787415,
                                    0.1964925202469885,
                                    0.05577777528286389,
                                ],
                                [
                                    0.04100627160920403,
                                    0.0832515885950765,
                                    0.28900320659836787,
                                    0.5867389331973516,
                                ],
                                [
                                    0.0967840468920679,
                                    0.02747381331221264,
                                    0.6821127306071941,
                                    0.1936294091885254,
                                ],
                                [
                                    0.12780740863168966,
                                    0.8256739138417495,
                                    0.0062354987848318305,
                                    0.04028317874172914,
                                ],
                                [
                                    0.0030713474794257334,
                                    0.01984181919698712,
                                    0.13097155993709575,
                                    0.8461152733864914,
                                ],
                                [
                                    0.06319634541814194,
                                    0.8469961770992888,
                                    0.0062354987848318305,
                                    0.08357197869773753,
                                ],
                                [
                                    0.6306757560690862,
                                    0.2795167664483444,
                                    0.06222793239975468,
                                    0.027579545082814672,
                                ],
                                [
                                    0.0030713474794257264,
                                    0.04116408245452641,
                                    0.06636049672354805,
                                    0.8894040733424998,
                                ],
                                [
                                    0.030650892562240406,
                                    0.013584537371711723,
                                    0.6622527959066005,
                                    0.29351177415944735,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011075,
                                    0.8100066841343474,
                                    0.06043647372396264,
                                ],
                                [
                                    0.1265882846236277,
                                    0.002968557518062241,
                                    0.8504985486999596,
                                    0.01994460915835054,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179545,
                                    0.8701316820730636,
                                    0.06492253899879417,
                                ],
                                [
                                    0.06345766547063227,
                                    0.0014881134575099799,
                                    0.913629167852955,
                                    0.021425053218902798,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.23798458124413802,
                                    0.11722131123245551,
                                    0.4320059405482901,
                                    0.21278816697511638,
                                ],
                                [
                                    0.3165217487219635,
                                    0.03868414375463002,
                                    0.5745719955712026,
                                    0.07022211195220382,
                                ],
                                [
                                    0.03223296324084664,
                                    0.01587661770458774,
                                    0.6377575585515814,
                                    0.3141328605029841,
                                ],
                                [
                                    0.042870146621042285,
                                    0.0052394343243920985,
                                    0.8482235976721239,
                                    0.10366682138244175,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.21437907039398982,
                                    0.43523581811884265,
                                    0.11563040781358207,
                                    0.2347547036735855,
                                ],
                                [
                                    0.5059829432781875,
                                    0.14363194523464493,
                                    0.27291383422107446,
                                    0.07747127726609311,
                                ],
                                [
                                    0.008627452390698495,
                                    0.017515591856266846,
                                    0.32138202581687336,
                                    0.6524749299361613,
                                ],
                                [
                                    0.020362732917981925,
                                    0.005780311328983417,
                                    0.75853404458128,
                                    0.21532291117175462,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.004174589489585101,
                                    0.1333967159166805,
                                    0.8617825030938935,
                                ],
                                [
                                    0.06077118943855717,
                                    0.8144927494091789,
                                    0.008660654764416598,
                                    0.11607540638784732,
                                ],
                                [
                                    0.6064736116113624,
                                    0.26879032723637375,
                                    0.08643007685747857,
                                    0.03830598429478535,
                                ],
                                [
                                    0.0006461914998409619,
                                    0.008660654764416634,
                                    0.0687856527031328,
                                    0.9219075010326095,
                                ],
                                [
                                    0.00644874810451654,
                                    0.0028580981597410545,
                                    0.6864549403643243,
                                    0.30423821337141804,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8100066841343474,
                                    0.0559504084491311,
                                    0.12538225265210484,
                                    0.008660654764416586,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879417,
                                    0.06043647372396264,
                                    0.004509305204179541,
                                ],
                                [
                                    0.8915567352919664,
                                    0.04349748577989137,
                                    0.061924587181472625,
                                    0.0030211917466695624,
                                ],
                                [
                                    0.8100066841343474,
                                    0.06043647372396264,
                                    0.1205614716626788,
                                    0.008995370479011071,
                                ],
                                [
                                    0.829951293292698,
                                    0.0404918645656121,
                                    0.12353002918074106,
                                    0.006026812960948832,
                                ],
                                [
                                    0.6606707252279942,
                                    0.2928105972454448,
                                    0.032232963240846645,
                                    0.014285714285714285,
                                ],
                                [
                                    0.4320059405482901,
                                    0.19146590371757705,
                                    0.26089774792055076,
                                    0.11563040781358203,
                                ],
                                [
                                    0.6377575585515814,
                                    0.3141328605029841,
                                    0.03223296324084665,
                                    0.01587661770458775,
                                ],
                                [
                                    0.7414243799340232,
                                    0.21046603912054238,
                                    0.03747239756523875,
                                    0.010637183380195647,
                                ],
                                [
                                    0.4320059405482901,
                                    0.21278816697511638,
                                    0.23798458124413796,
                                    0.11722131123245548,
                                ],
                                [
                                    0.502228052500494,
                                    0.14256605502291253,
                                    0.276668724998768,
                                    0.07853716747782546,
                                ],
                                [
                                    0.3679007033434344,
                                    0.6091861299801529,
                                    0.008627452390698495,
                                    0.014285714285714284,
                                ],
                                [
                                    0.11563040781358208,
                                    0.19146590371757705,
                                    0.2608977479205508,
                                    0.43200594054829006,
                                ],
                                [
                                    0.32138202581687336,
                                    0.6524749299361613,
                                    0.008627452390698495,
                                    0.017515591856266843,
                                ],
                                [
                                    0.536704936988628,
                                    0.4371520187644067,
                                    0.01440776371968191,
                                    0.011735280527283428,
                                ],
                                [
                                    0.11563040781358207,
                                    0.2347547036735855,
                                    0.21437907039398982,
                                    0.43523581811884265,
                                ],
                                [
                                    0.19310168507967515,
                                    0.1572834264074924,
                                    0.3580110156286347,
                                    0.29160387288419776,
                                ],
                                [
                                    0.1333967159166805,
                                    0.8617825030938935,
                                    0.0006461914998409586,
                                    0.00417458948958506,
                                ],
                                [
                                    0.008660654764416591,
                                    0.055950408449131114,
                                    0.12538225265210487,
                                    0.8100066841343474,
                                ],
                                [
                                    0.0687856527031328,
                                    0.9219075010326095,
                                    0.0006461914998409586,
                                    0.00866065476441659,
                                ],
                                [
                                    0.3730238660745509,
                                    0.6176692876611916,
                                    0.003504289659581999,
                                    0.00580255660467555,
                                ],
                                [
                                    0.008660654764416595,
                                    0.11607540638784729,
                                    0.06077118943855717,
                                    0.8144927494091789,
                                ],
                                [
                                    0.04696663905920194,
                                    0.07776942209306194,
                                    0.32956151667493094,
                                    0.5457024221728052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.5831886655241381,
                                    0.040283178741729105,
                                    0.3522002712623142,
                                    0.024327884471818582,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711319,
                                    0.287254492334172,
                                    0.021432722615860517,
                                ],
                                [
                                    0.6591538285322392,
                                    0.03215895651772817,
                                    0.2943274939411998,
                                    0.014359721008832763,
                                ],
                                [
                                    0.583188665524138,
                                    0.04351305631228166,
                                    0.34737949027288817,
                                    0.025918787890692047,
                                ],
                                [
                                    0.5975483865329708,
                                    0.0291533353034489,
                                    0.3559329359404682,
                                    0.01736534222311203,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.3110356653860286,
                                    0.13785163390566152,
                                    0.38186802308281226,
                                    0.16924467762549755,
                                ],
                                [
                                    0.51678728338932,
                                    0.25454793193097597,
                                    0.15320323840310818,
                                    0.07546154627659593,
                                ],
                                [
                                    0.6007905135846778,
                                    0.17054470173561806,
                                    0.17810626391458415,
                                    0.05055852076511997,
                                ],
                                [
                                    0.3110356653860286,
                                    0.1532032384031082,
                                    0.3589548564063995,
                                    0.17680623980446367,
                                ],
                                [
                                    0.3615941861511486,
                                    0.10264471763798823,
                                    0.4173025913481134,
                                    0.1184585048627498,
                                ],
                                [
                                    0.33552188412492884,
                                    0.5555718601682372,
                                    0.04100627160920404,
                                    0.06789998409762982,
                                ],
                                [
                                    0.08325158859507652,
                                    0.1378516339056615,
                                    0.29327656713905637,
                                    0.48562021036020564,
                                ],
                                [
                                    0.28900320659836787,
                                    0.5867389331973516,
                                    0.04100627160920404,
                                    0.08325158859507652,
                                ],
                                [
                                    0.4826326157868932,
                                    0.39310952400882626,
                                    0.06848008492141668,
                                    0.05577777528286388,
                                ],
                                [
                                    0.08325158859507653,
                                    0.16901870693477583,
                                    0.24675788961249534,
                                    0.5009718148576523,
                                ],
                                [
                                    0.1390293638779404,
                                    0.11324093165191196,
                                    0.41208333683036946,
                                    0.3356463676397782,
                                ],
                                [
                                    0.13097155993709575,
                                    0.8461152733864915,
                                    0.0030713474794257256,
                                    0.01984181919698707,
                                ],
                                [
                                    0.0062354987848318374,
                                    0.04028317874172919,
                                    0.12780740863168963,
                                    0.8256739138417494,
                                ],
                                [
                                    0.06636049672354805,
                                    0.8894040733424998,
                                    0.0030713474794257256,
                                    0.04116408245452639,
                                ],
                                [
                                    0.35987227088299545,
                                    0.5958922991830524,
                                    0.016655884851137448,
                                    0.02757954508281467,
                                ],
                                [
                                    0.00623549878483183,
                                    0.08357197869773751,
                                    0.06319634541814194,
                                    0.8469961770992888,
                                ],
                                [
                                    0.0338150438676465,
                                    0.05599243361492284,
                                    0.3427131118664864,
                                    0.5674794106509443,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.28725449233417205,
                                    0.019841819196987055,
                                    0.6481344444522802,
                                    0.044769244016560635,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069205,
                                    0.583188665524138,
                                    0.04351305631228166,
                                ],
                                [
                                    0.35593293594046826,
                                    0.017365342223112035,
                                    0.5975483865329708,
                                    0.0291533353034489,
                                ],
                                [
                                    0.28725449233417205,
                                    0.02143272261586052,
                                    0.6433136634628541,
                                    0.04799912158711319,
                                ],
                                [
                                    0.29432749394119984,
                                    0.014359721008832767,
                                    0.6591538285322392,
                                    0.03215895651772817,
                                ],
                                [
                                    0.38186802308281226,
                                    0.16924467762549755,
                                    0.3110356653860286,
                                    0.13785163390566152,
                                ],
                                [
                                    0.15320323840310818,
                                    0.06789998409762982,
                                    0.5397004500657328,
                                    0.23919632743352925,
                                ],
                                [
                                    0.3589548564063995,
                                    0.17680623980446367,
                                    0.31103566538602856,
                                    0.15320323840310818,
                                ],
                                [
                                    0.4173025913481134,
                                    0.1184585048627498,
                                    0.3615941861511485,
                                    0.10264471763798821,
                                ],
                                [
                                    0.15320323840310823,
                                    0.07546154627659596,
                                    0.5167872833893199,
                                    0.2545479319309759,
                                ],
                                [
                                    0.1781062639145842,
                                    0.050558520765119984,
                                    0.6007905135846778,
                                    0.17054470173561803,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.041006271609204045,
                                    0.06789998409762983,
                                    0.33552188412492884,
                                    0.5555718601682372,
                                ],
                                [
                                    0.24675788961249534,
                                    0.5009718148576523,
                                    0.08325158859507653,
                                    0.16901870693477583,
                                ],
                                [
                                    0.41208333683036946,
                                    0.3356463676397782,
                                    0.1390293638779404,
                                    0.11324093165191196,
                                ],
                                [
                                    0.04100627160920403,
                                    0.0832515885950765,
                                    0.28900320659836787,
                                    0.5867389331973516,
                                ],
                                [
                                    0.06848008492141666,
                                    0.055777775282863866,
                                    0.4826326157868932,
                                    0.39310952400882626,
                                ],
                                [
                                    0.12780740863168966,
                                    0.8256739138417495,
                                    0.0062354987848318305,
                                    0.04028317874172914,
                                ],
                                [
                                    0.0030713474794257334,
                                    0.01984181919698712,
                                    0.13097155993709575,
                                    0.8461152733864914,
                                ],
                                [
                                    0.06319634541814194,
                                    0.8469961770992888,
                                    0.0062354987848318305,
                                    0.08357197869773753,
                                ],
                                [
                                    0.3427131118664864,
                                    0.5674794106509443,
                                    0.033815043867646506,
                                    0.05599243361492285,
                                ],
                                [
                                    0.0030713474794257264,
                                    0.04116408245452641,
                                    0.06636049672354805,
                                    0.8894040733424998,
                                ],
                                [
                                    0.01665588485113745,
                                    0.02757954508281468,
                                    0.35987227088299545,
                                    0.5958922991830524,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011075,
                                    0.8100066841343474,
                                    0.06043647372396264,
                                ],
                                [
                                    0.12353002918074112,
                                    0.006026812960948835,
                                    0.829951293292698,
                                    0.0404918645656121,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179545,
                                    0.8701316820730636,
                                    0.06492253899879417,
                                ],
                                [
                                    0.06192458718147267,
                                    0.003021191746669565,
                                    0.8915567352919664,
                                    0.04349748577989137,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.23798458124413802,
                                    0.11722131123245551,
                                    0.4320059405482901,
                                    0.21278816697511638,
                                ],
                                [
                                    0.27666872499876805,
                                    0.07853716747782548,
                                    0.502228052500494,
                                    0.14256605502291253,
                                ],
                                [
                                    0.03223296324084664,
                                    0.01587661770458774,
                                    0.6377575585515814,
                                    0.3141328605029841,
                                ],
                                [
                                    0.03747239756523874,
                                    0.010637183380195644,
                                    0.7414243799340232,
                                    0.21046603912054238,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.21437907039398982,
                                    0.43523581811884265,
                                    0.11563040781358207,
                                    0.2347547036735855,
                                ],
                                [
                                    0.3580110156286347,
                                    0.29160387288419776,
                                    0.19310168507967515,
                                    0.1572834264074924,
                                ],
                                [
                                    0.008627452390698495,
                                    0.017515591856266846,
                                    0.32138202581687336,
                                    0.6524749299361613,
                                ],
                                [
                                    0.014407763719681912,
                                    0.01173528052728343,
                                    0.536704936988628,
                                    0.4371520187644067,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.004174589489585101,
                                    0.1333967159166805,
                                    0.8617825030938935,
                                ],
                                [
                                    0.06077118943855717,
                                    0.8144927494091789,
                                    0.008660654764416598,
                                    0.11607540638784732,
                                ],
                                [
                                    0.32956151667493094,
                                    0.5457024221728052,
                                    0.04696663905920195,
                                    0.07776942209306197,
                                ],
                                [
                                    0.0006461914998409619,
                                    0.008660654764416634,
                                    0.0687856527031328,
                                    0.9219075010326095,
                                ],
                                [
                                    0.003504289659582017,
                                    0.005802556604675578,
                                    0.3730238660745509,
                                    0.6176692876611916,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8100066841343474,
                                    0.0559504084491311,
                                    0.12538225265210484,
                                    0.008660654764416586,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879417,
                                    0.06043647372396264,
                                    0.004509305204179541,
                                ],
                                [
                                    0.8746393736860893,
                                    0.0604148473857684,
                                    0.0607495631003629,
                                    0.004196215827779288,
                                ],
                                [
                                    0.8100066841343474,
                                    0.06043647372396264,
                                    0.1205614716626788,
                                    0.008995370479011071,
                                ],
                                [
                                    0.8142028999621267,
                                    0.056240257896183345,
                                    0.12118603682432554,
                                    0.008370805317364345,
                                ],
                                [
                                    0.6606707252279942,
                                    0.2928105972454448,
                                    0.032232963240846645,
                                    0.014285714285714285,
                                ],
                                [
                                    0.4320059405482901,
                                    0.19146590371757705,
                                    0.26089774792055076,
                                    0.11563040781358203,
                                ],
                                [
                                    0.6377575585515814,
                                    0.3141328605029841,
                                    0.03223296324084665,
                                    0.01587661770458775,
                                ],
                                [
                                    0.6595683823810591,
                                    0.2923220366735064,
                                    0.033335306087781756,
                                    0.014774274857652635,
                                ],
                                [
                                    0.4320059405482901,
                                    0.21278816697511638,
                                    0.23798458124413796,
                                    0.11722131123245548,
                                ],
                                [
                                    0.44678021540594276,
                                    0.19801389211746373,
                                    0.2461234730628981,
                                    0.10908241941369534,
                                ],
                                [
                                    0.3679007033434344,
                                    0.6091861299801529,
                                    0.008627452390698495,
                                    0.014285714285714284,
                                ],
                                [
                                    0.11563040781358208,
                                    0.19146590371757705,
                                    0.2608977479205508,
                                    0.43200594054829006,
                                ],
                                [
                                    0.32138202581687336,
                                    0.6524749299361613,
                                    0.008627452390698495,
                                    0.017515591856266843,
                                ],
                                [
                                    0.3666845634985472,
                                    0.6071723922544875,
                                    0.009843592235585692,
                                    0.016299452011379646,
                                ],
                                [
                                    0.11563040781358207,
                                    0.2347547036735855,
                                    0.21437907039398982,
                                    0.43523581811884265,
                                ],
                                [
                                    0.13192985982496175,
                                    0.2184552516622058,
                                    0.24459829590917115,
                                    0.4050165926036613,
                                ],
                                [
                                    0.1333967159166805,
                                    0.8617825030938935,
                                    0.0006461914998409586,
                                    0.00417458948958506,
                                ],
                                [
                                    0.008660654764416591,
                                    0.055950408449131114,
                                    0.12538225265210487,
                                    0.8100066841343474,
                                ],
                                [
                                    0.0687856527031328,
                                    0.9219075010326095,
                                    0.0006461914998409586,
                                    0.00866065476441659,
                                ],
                                [
                                    0.1327953906843818,
                                    0.8578977630513606,
                                    0.0012475167321396733,
                                    0.008059329532117875,
                                ],
                                [
                                    0.008660654764416595,
                                    0.11607540638784729,
                                    0.06077118943855717,
                                    0.8144927494091789,
                                ],
                                [
                                    0.016719984296534467,
                                    0.1080160768557294,
                                    0.117322923119987,
                                    0.7579410157277491,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.5831886655241381,
                                    0.040283178741729105,
                                    0.3522002712623142,
                                    0.024327884471818582,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711319,
                                    0.287254492334172,
                                    0.021432722615860517,
                                ],
                                [
                                    0.6466463309947702,
                                    0.044666454055197154,
                                    0.288742605791682,
                                    0.019944609158350536,
                                ],
                                [
                                    0.583188665524138,
                                    0.04351305631228166,
                                    0.34737949027288817,
                                    0.025918787890692047,
                                ],
                                [
                                    0.5862098572708075,
                                    0.040491864565612094,
                                    0.34917907951564464,
                                    0.024119198647935592,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.3110356653860286,
                                    0.13785163390566152,
                                    0.38186802308281226,
                                    0.16924467762549755,
                                ],
                                [
                                    0.51678728338932,
                                    0.25454793193097597,
                                    0.15320323840310818,
                                    0.07546154627659593,
                                ],
                                [
                                    0.5344610157413406,
                                    0.23687419957895525,
                                    0.15844267272750026,
                                    0.07022211195220382,
                                ],
                                [
                                    0.3110356653860286,
                                    0.1532032384031082,
                                    0.3589548564063995,
                                    0.17680623980446367,
                                ],
                                [
                                    0.3216728487662242,
                                    0.14256605502291253,
                                    0.37123083970261667,
                                    0.16453025650824654,
                                ],
                                [
                                    0.33552188412492884,
                                    0.5555718601682372,
                                    0.04100627160920404,
                                    0.06789998409762982,
                                ],
                                [
                                    0.08325158859507652,
                                    0.1378516339056615,
                                    0.29327656713905637,
                                    0.48562021036020564,
                                ],
                                [
                                    0.28900320659836787,
                                    0.5867389331973516,
                                    0.04100627160920404,
                                    0.08325158859507652,
                                ],
                                [
                                    0.32974157279594546,
                                    0.5460005669997741,
                                    0.046786582938187465,
                                    0.0774712772660931,
                                ],
                                [
                                    0.08325158859507653,
                                    0.16901870693477583,
                                    0.24675788961249534,
                                    0.5009718148576523,
                                ],
                                [
                                    0.09498686912235998,
                                    0.15728342640749238,
                                    0.2815412866117729,
                                    0.4661884178583747,
                                ],
                                [
                                    0.13097155993709575,
                                    0.8461152733864915,
                                    0.0030713474794257256,
                                    0.01984181919698707,
                                ],
                                [
                                    0.0062354987848318374,
                                    0.04028317874172919,
                                    0.12780740863168963,
                                    0.8256739138417494,
                                ],
                                [
                                    0.06636049672354805,
                                    0.8894040733424998,
                                    0.0030713474794257256,
                                    0.04116408245452639,
                                ],
                                [
                                    0.1281134617773547,
                                    0.8276511082886931,
                                    0.005929445639166767,
                                    0.03830598429478535,
                                ],
                                [
                                    0.00623549878483183,
                                    0.08357197869773751,
                                    0.06319634541814194,
                                    0.8469961770992888,
                                ],
                                [
                                    0.01203805538950738,
                                    0.07776942209306197,
                                    0.1220048520270141,
                                    0.7881876704904166,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.28725449233417205,
                                    0.019841819196987055,
                                    0.6481344444522802,
                                    0.044769244016560635,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069205,
                                    0.583188665524138,
                                    0.04351305631228166,
                                ],
                                [
                                    0.3491790795156447,
                                    0.024119198647935595,
                                    0.5862098572708075,
                                    0.040491864565612094,
                                ],
                                [
                                    0.28725449233417205,
                                    0.02143272261586052,
                                    0.6433136634628541,
                                    0.04799912158711319,
                                ],
                                [
                                    0.28874260579168204,
                                    0.01994460915835054,
                                    0.6466463309947702,
                                    0.044666454055197154,
                                ],
                                [
                                    0.38186802308281226,
                                    0.16924467762549755,
                                    0.3110356653860286,
                                    0.13785163390566152,
                                ],
                                [
                                    0.15320323840310818,
                                    0.06789998409762982,
                                    0.5397004500657328,
                                    0.23919632743352925,
                                ],
                                [
                                    0.3589548564063995,
                                    0.17680623980446367,
                                    0.31103566538602856,
                                    0.15320323840310818,
                                ],
                                [
                                    0.37123083970261667,
                                    0.16453025650824654,
                                    0.3216728487662242,
                                    0.14256605502291253,
                                ],
                                [
                                    0.15320323840310823,
                                    0.07546154627659596,
                                    0.5167872833893199,
                                    0.2545479319309759,
                                ],
                                [
                                    0.15844267272750032,
                                    0.07022211195220385,
                                    0.5344610157413405,
                                    0.23687419957895522,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.041006271609204045,
                                    0.06789998409762983,
                                    0.33552188412492884,
                                    0.5555718601682372,
                                ],
                                [
                                    0.24675788961249534,
                                    0.5009718148576523,
                                    0.08325158859507653,
                                    0.16901870693477583,
                                ],
                                [
                                    0.2815412866117729,
                                    0.4661884178583747,
                                    0.09498686912235998,
                                    0.15728342640749238,
                                ],
                                [
                                    0.04100627160920403,
                                    0.0832515885950765,
                                    0.28900320659836787,
                                    0.5867389331973516,
                                ],
                                [
                                    0.04678658293818746,
                                    0.07747127726609308,
                                    0.32974157279594546,
                                    0.5460005669997741,
                                ],
                                [
                                    0.12780740863168966,
                                    0.8256739138417495,
                                    0.0062354987848318305,
                                    0.04028317874172914,
                                ],
                                [
                                    0.0030713474794257334,
                                    0.01984181919698712,
                                    0.13097155993709575,
                                    0.8461152733864914,
                                ],
                                [
                                    0.06319634541814194,
                                    0.8469961770992888,
                                    0.0062354987848318305,
                                    0.08357197869773753,
                                ],
                                [
                                    0.1220048520270141,
                                    0.7881876704904166,
                                    0.012038055389507382,
                                    0.07776942209306198,
                                ],
                                [
                                    0.0030713474794257264,
                                    0.04116408245452641,
                                    0.06636049672354805,
                                    0.8894040733424998,
                                ],
                                [
                                    0.005929445639166768,
                                    0.038305984294785364,
                                    0.1281134617773547,
                                    0.8276511082886931,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011075,
                                    0.8100066841343474,
                                    0.06043647372396264,
                                ],
                                [
                                    0.12118603682432559,
                                    0.008370805317364349,
                                    0.8142028999621267,
                                    0.056240257896183345,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179545,
                                    0.8701316820730636,
                                    0.06492253899879417,
                                ],
                                [
                                    0.06074956310036295,
                                    0.004196215827779292,
                                    0.8746393736860893,
                                    0.0604148473857684,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.23798458124413802,
                                    0.11722131123245551,
                                    0.4320059405482901,
                                    0.21278816697511638,
                                ],
                                [
                                    0.24612347306289814,
                                    0.10908241941369536,
                                    0.44678021540594276,
                                    0.19801389211746373,
                                ],
                                [
                                    0.03223296324084664,
                                    0.01587661770458774,
                                    0.6377575585515814,
                                    0.3141328605029841,
                                ],
                                [
                                    0.03333530608778175,
                                    0.014774274857652632,
                                    0.6595683823810591,
                                    0.2923220366735064,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.21437907039398982,
                                    0.43523581811884265,
                                    0.11563040781358207,
                                    0.2347547036735855,
                                ],
                                [
                                    0.24459829590917115,
                                    0.4050165926036613,
                                    0.13192985982496175,
                                    0.2184552516622058,
                                ],
                                [
                                    0.008627452390698495,
                                    0.017515591856266846,
                                    0.32138202581687336,
                                    0.6524749299361613,
                                ],
                                [
                                    0.009843592235585693,
                                    0.01629945201137965,
                                    0.3666845634985472,
                                    0.6071723922544875,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.004174589489585101,
                                    0.1333967159166805,
                                    0.8617825030938935,
                                ],
                                [
                                    0.06077118943855717,
                                    0.8144927494091789,
                                    0.008660654764416598,
                                    0.11607540638784732,
                                ],
                                [
                                    0.117322923119987,
                                    0.7579410157277491,
                                    0.016719984296534474,
                                    0.10801607685572945,
                                ],
                                [
                                    0.0006461914998409619,
                                    0.008660654764416634,
                                    0.0687856527031328,
                                    0.9219075010326095,
                                ],
                                [
                                    0.0012475167321396796,
                                    0.008059329532117916,
                                    0.1327953906843818,
                                    0.8578977630513606,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.002605273234694582,
                                0.002605273234694582,
                                0.002605273234694582,
                                0.002605273234694582,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.002605273234694582,
                                0.002605273234694582,
                                0.002605273234694582,
                                0.002605273234694582,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.002605273234694582,
                                0.002605273234694582,
                                0.002605273234694582,
                                0.002605273234694582,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                1.543061997016364e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0006416480490910694,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.002580835941388298,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.002605273234694582,
                                0.002605273234694582,
                                0.002605273234694582,
                                0.002605273234694582,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                8.23070735107664e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.00034225567894676385,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.0013766203429143357,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                0.0013896552183791813,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                4.3902671201841935e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.00018255950429093366,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                0.0007342905986911238,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                0.0007412434136471217,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                2.8402819442138036e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.0010970674433967282,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.00395252231221204,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                0.0036180964260355904,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                1.5150090872935222e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0005851768165149458,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0021082791562050942,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                0.0019298960708161003,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                8.081072864114134e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.00031213386984334587,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.0011245581047716585,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                0.0010294083975623662,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                2.771663369113821e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.0009589364775968374,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0027966289102988296,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                0.0019660960061763334,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                1.4784078741479792e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0005114976281337404,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0014917245175331685,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                0.0010487174774732244,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                7.885841645486598e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.000272833320766048,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.0007956872747810468,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                0.0005593868987591871,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                0.00010622150675627545,
                                0.00010622150675627545,
                                0.00010622150675627545,
                                0.00010622150675627545,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                0.00010622150675627545,
                                0.00010622150675627545,
                                0.00010622150675627545,
                                0.00010622150675627545,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                1.450354964425137e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.00045502639555761686,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.001019167732349965,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                0.0003733403135947429,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                0.00010622150675627545,
                                0.00010622150675627545,
                                0.00010622150675627545,
                                0.00010622150675627545,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                7.73620715852409e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.00024271151166263002,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.0005436250366383696,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                0.00019914007794237195,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                4.1265002477046085e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0001294625508952475,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                0.0002899701109832521,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                0.00010622150675627545,
                                0.00010622150675627545,
                                0.00010622150675627545,
                                0.00010622150675627545,
                            ]
                        ),
                    )
                case 5:
                    return (
                        np.array(
                            [
                                [
                                    0.0019989413309687114,
                                    0.9063814599347185,
                                    0.00020161399605452332,
                                    0.09141798473825831,
                                ],
                                [
                                    0.0021021695508696182,
                                    0.9531883087454855,
                                    9.838577615361652e-05,
                                    0.04461113592749119,
                                ],
                                [
                                    0.0020927118227842397,
                                    0.9488998840394254,
                                    0.000107843504238995,
                                    0.048899560633551324,
                                ],
                                [
                                    0.04461113592749125,
                                    0.9063814599347184,
                                    0.0022989411031768252,
                                    0.04670846303461349,
                                ],
                                [
                                    0.00209755426653153,
                                    0.9510955969227013,
                                    0.00010300106049170473,
                                    0.046703847750275404,
                                ],
                                [
                                    0.044714364147392154,
                                    0.9084787870418407,
                                    0.0021957128832759197,
                                    0.04461113592749119,
                                ],
                                [
                                    0.007936507936507941,
                                    0.7252132901931455,
                                    0.0028887121709719418,
                                    0.26396148969937466,
                                ],
                                [
                                    0.010434593588739452,
                                    0.9534805494880724,
                                    0.00039062651874043086,
                                    0.035694230404447705,
                                ],
                                [
                                    0.010205719983678056,
                                    0.9325667947872899,
                                    0.000619500123801826,
                                    0.056607985105230255,
                                ],
                                [
                                    0.21755922457782248,
                                    0.7252132901931454,
                                    0.013206120369336006,
                                    0.04402136485969607,
                                ],
                                [
                                    0.010322905374053443,
                                    0.9432748295043943,
                                    0.0005023147334264394,
                                    0.04589995038812576,
                                ],
                                [
                                    0.220057310230054,
                                    0.7335404246483938,
                                    0.010708034717104496,
                                    0.035694230404447705,
                                ],
                                [
                                    0.011177380425911215,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.5111773804259112,
                                ],
                                [
                                    0.022904899683578235,
                                    0.9536400618010877,
                                    0.0005501388317558024,
                                    0.022904899683578207,
                                ],
                                [
                                    0.021830429075041857,
                                    0.9089047330424678,
                                    0.001624609440292181,
                                    0.06764022844219825,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.02238056790679766,
                                    0.9318096327260459,
                                    0.0010744706085363785,
                                    0.04473532875862004,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.007936507936507952,
                                    0.21200361690317066,
                                    0.028148348986680238,
                                    0.7519115261736411,
                                ],
                                [
                                    0.03569423040444776,
                                    0.9534805494880724,
                                    0.00039062651874043145,
                                    0.010434593588739452,
                                ],
                                [
                                    0.033151079010156695,
                                    0.8855467304538945,
                                    0.0029337779130314957,
                                    0.07836841262291726,
                                ],
                                [
                                    0.7066941925608805,
                                    0.21200361690317068,
                                    0.06254046249196094,
                                    0.01876172804398782,
                                ],
                                [
                                    0.03445319590932366,
                                    0.9203294704779158,
                                    0.0016316610138645353,
                                    0.04358567259889609,
                                ],
                                [
                                    0.7344519150288203,
                                    0.22033075135841906,
                                    0.03478274002402117,
                                    0.01043459358873945,
                                ],
                                [
                                    0.001998941330968689,
                                    0.04271058037267615,
                                    0.04271058037267615,
                                    0.912579897923679,
                                ],
                                [
                                    0.04461113592749122,
                                    0.9531883087454855,
                                    9.838577615361546e-05,
                                    0.002102169550869594,
                                ],
                                [
                                    0.04070702375736938,
                                    0.8697707046154401,
                                    0.004002497946275464,
                                    0.08551977368091507,
                                ],
                                [
                                    0.8677671480001333,
                                    0.04271058037267617,
                                    0.08532277496919864,
                                    0.004199496657991899,
                                ],
                                [
                                    0.042705965088338065,
                                    0.9124812849881163,
                                    0.0020035566153067757,
                                    0.042809193308238944,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979848,
                                    0.042710580372676124,
                                    0.0021021695508695944,
                                ],
                                [
                                    0.001613336693780218,
                                    0.7315364614358733,
                                    0.0005872186332430168,
                                    0.26626298323710357,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.7783433102466403,
                                    0.00048399041334210995,
                                    0.21945613442633646,
                                ],
                                [
                                    0.0016890184423618514,
                                    0.7658528931925724,
                                    0.0005115368846613834,
                                    0.23194655148040444,
                                ],
                                [
                                    0.03600545019906099,
                                    0.7315364614358733,
                                    0.010904626831607084,
                                    0.22155346153345873,
                                ],
                                [
                                    0.0016938608861091415,
                                    0.7680486060758482,
                                    0.0005066944409140931,
                                    0.22975083859712853,
                                ],
                                [
                                    0.03610867841896189,
                                    0.7336337885429954,
                                    0.010801398611706177,
                                    0.21945613442633644,
                                ],
                                [
                                    0.0064055204002616125,
                                    0.5853164341340025,
                                    0.00441969970721827,
                                    0.4038583457585176,
                                ],
                                [
                                    0.008903606052493124,
                                    0.8135836934289296,
                                    0.0019216140549867587,
                                    0.17559108646359065,
                                ],
                                [
                                    0.008236991391905727,
                                    0.7526705292056874,
                                    0.002588228715574154,
                                    0.23650425068683267,
                                ],
                                [
                                    0.1755910864635907,
                                    0.5853164341340025,
                                    0.0551742584835678,
                                    0.18391822091883903,
                                ],
                                [
                                    0.008354176782281115,
                                    0.7633785639227919,
                                    0.0024710433251987672,
                                    0.22579621596972818,
                                ],
                                [
                                    0.1780891721158222,
                                    0.5936435685892508,
                                    0.05267617283133629,
                                    0.17559108646359065,
                                ],
                                [
                                    0.009021214230797044,
                                    0.3755961132956237,
                                    0.014433824284536993,
                                    0.6009488481890423,
                                ],
                                [
                                    0.020748733488464063,
                                    0.8638685940379567,
                                    0.0027063050268699733,
                                    0.11267636744670925,
                                ],
                                [
                                    0.017619242607117242,
                                    0.7335729839841303,
                                    0.005835795908216794,
                                    0.24297197750053573,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.018169381438873044,
                                    0.7564778836677084,
                                    0.005285657076460991,
                                    0.2200670778169575,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.006405520400261623,
                                    0.17110718011831585,
                                    0.029679336522926567,
                                    0.792807962958496,
                                ],
                                [
                                    0.03416324286820143,
                                    0.9125841127032176,
                                    0.0019216140549867615,
                                    0.05133103037359428,
                                ],
                                [
                                    0.026756089024170638,
                                    0.7147208435607312,
                                    0.009328767899017555,
                                    0.2491942995160807,
                                ],
                                [
                                    0.5703697524665859,
                                    0.17110718011831585,
                                    0.19886490258625558,
                                    0.059658164828842654,
                                ],
                                [
                                    0.0280582059233376,
                                    0.7495035835847523,
                                    0.008026650999850593,
                                    0.21441155949205948,
                                ],
                                [
                                    0.5981274749345258,
                                    0.17943431457356424,
                                    0.1711071801183158,
                                    0.05133103037359428,
                                ],
                                [
                                    0.0016133366937802012,
                                    0.03447152022940799,
                                    0.04309618500986464,
                                    0.9208189580669471,
                                ],
                                [
                                    0.04422553129030273,
                                    0.9449492486022174,
                                    0.0004839904133421048,
                                    0.010341229694137788,
                                ],
                                [
                                    0.032854458560082206,
                                    0.7019880829874786,
                                    0.011855063143562635,
                                    0.25330239530887655,
                                ],
                                [
                                    0.7003710213181528,
                                    0.034471520229407984,
                                    0.2527189016511791,
                                    0.012438556801260093,
                                ],
                                [
                                    0.03485339989105089,
                                    0.7446986633601548,
                                    0.009856121812593946,
                                    0.2105918149362004,
                                ],
                                [
                                    0.7429832159146753,
                                    0.036568847336530284,
                                    0.2101067070546566,
                                    0.010341229694137788,
                                ],
                                [
                                    0.001048663553561164,
                                    0.4754962979311048,
                                    0.0011518917734620708,
                                    0.522303146741872,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.522303146741872,
                                    0.001048663553561164,
                                    0.4754962979311048,
                                ],
                                [
                                    0.0010978564416379722,
                                    0.4978018658948504,
                                    0.0011026988853852625,
                                    0.49999757877812634,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.0011026988853852625,
                                    0.49999757877812634,
                                    0.0010978564416379722,
                                    0.4978018658948504,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.004163567227624187,
                                    0.3804537602987967,
                                    0.006661652879855696,
                                    0.6087210195937235,
                                ],
                                [
                                    0.006661652879855697,
                                    0.6087210195937236,
                                    0.004163567227624186,
                                    0.3804537602987966,
                                ],
                                [
                                    0.005354017358552248,
                                    0.4892333725877078,
                                    0.005471202748927635,
                                    0.4999414073048123,
                                ],
                                [
                                    0.1141336296474635,
                                    0.3804537602987966,
                                    0.116631715299695,
                                    0.3887808947540449,
                                ],
                                [
                                    0.005471202748927635,
                                    0.4999414073048123,
                                    0.005354017358552248,
                                    0.4892333725877078,
                                ],
                                [
                                    0.116631715299695,
                                    0.3887808947540449,
                                    0.1141336296474635,
                                    0.3804537602987966,
                                ],
                                [
                                    0.005863759628833509,
                                    0.2441362403711665,
                                    0.017591278886500528,
                                    0.7324087211134995,
                                ],
                                [
                                    0.017591278886500528,
                                    0.7324087211134995,
                                    0.005863759628833509,
                                    0.2441362403711665,
                                ],
                                [
                                    0.011452449841789118,
                                    0.47682003090054387,
                                    0.01200258867354492,
                                    0.4997249305841221,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.01200258867354492,
                                    0.4997249305841221,
                                    0.011452449841789118,
                                    0.47682003090054387,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.004163567227624192,
                                    0.11121910524595506,
                                    0.031921289695564,
                                    0.8526960378308568,
                                ],
                                [
                                    0.031921289695564,
                                    0.8526960378308568,
                                    0.004163567227624192,
                                    0.11121910524595506,
                                ],
                                [
                                    0.017391370012010614,
                                    0.4645662015263953,
                                    0.018693486911177577,
                                    0.49934894155041654,
                                ],
                                [
                                    0.37073846629245083,
                                    0.11121910524595506,
                                    0.39849618876039067,
                                    0.11954623970120344,
                                ],
                                [
                                    0.018693486911177577,
                                    0.49934894155041654,
                                    0.017391370012010614,
                                    0.4645662015263953,
                                ],
                                [
                                    0.39849618876039067,
                                    0.11954623970120344,
                                    0.37073846629245083,
                                    0.11121910524595506,
                                ],
                                [
                                    0.0010486635535611527,
                                    0.022406374961772883,
                                    0.043660858150083685,
                                    0.9328841033345823,
                                ],
                                [
                                    0.043660858150083685,
                                    0.9328841033345823,
                                    0.0010486635535611527,
                                    0.022406374961772883,
                                ],
                                [
                                    0.021355290186338076,
                                    0.4562899489618395,
                                    0.023354231517306763,
                                    0.49900052933451566,
                                ],
                                [
                                    0.4552388641864047,
                                    0.022406374961772883,
                                    0.49785105878292724,
                                    0.02450370206889519,
                                ],
                                [
                                    0.023354231517306763,
                                    0.49900052933451566,
                                    0.021355290186338076,
                                    0.4562899489618395,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889519,
                                    0.4552388641864047,
                                    0.022406374961772883,
                                ],
                                [
                                    0.00048399041334211006,
                                    0.21945613442633652,
                                    0.0017165649136811247,
                                    0.7783433102466403,
                                ],
                                [
                                    0.000587218633243017,
                                    0.2662629832371037,
                                    0.0016133366937802177,
                                    0.7315364614358731,
                                ],
                                [
                                    0.0005066944409140932,
                                    0.22975083859712855,
                                    0.0016938608861091415,
                                    0.7680486060758482,
                                ],
                                [
                                    0.010801398611706179,
                                    0.21945613442633646,
                                    0.03610867841896189,
                                    0.7336337885429954,
                                ],
                                [
                                    0.0005115368846613836,
                                    0.2319465514804045,
                                    0.0016890184423618512,
                                    0.7658528931925723,
                                ],
                                [
                                    0.010904626831607086,
                                    0.22155346153345878,
                                    0.036005450199060984,
                                    0.7315364614358731,
                                ],
                                [
                                    0.0019216140549867596,
                                    0.17559108646359073,
                                    0.008903606052493122,
                                    0.8135836934289294,
                                ],
                                [
                                    0.004419699707218271,
                                    0.4038583457585177,
                                    0.006405520400261612,
                                    0.5853164341340024,
                                ],
                                [
                                    0.0024710433251987677,
                                    0.2257962159697282,
                                    0.008354176782281115,
                                    0.7633785639227919,
                                ],
                                [
                                    0.0526761728313363,
                                    0.17559108646359067,
                                    0.1780891721158222,
                                    0.5936435685892508,
                                ],
                                [
                                    0.0025882287155741543,
                                    0.2365042506868327,
                                    0.008236991391905727,
                                    0.7526705292056874,
                                ],
                                [
                                    0.05517425848356781,
                                    0.18391822091883905,
                                    0.1755910864635907,
                                    0.5853164341340025,
                                ],
                                [
                                    0.0027063050268699737,
                                    0.11267636744670928,
                                    0.020748733488464063,
                                    0.8638685940379567,
                                ],
                                [
                                    0.014433824284536993,
                                    0.6009488481890423,
                                    0.009021214230797044,
                                    0.3755961132956237,
                                ],
                                [
                                    0.005285657076460993,
                                    0.22006707781695756,
                                    0.018169381438873044,
                                    0.7564778836677084,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.0058357959082167956,
                                    0.2429719775005358,
                                    0.017619242607117242,
                                    0.7335729839841302,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.001921614054986761,
                                    0.05133103037359426,
                                    0.03416324286820143,
                                    0.9125841127032176,
                                ],
                                [
                                    0.029679336522926567,
                                    0.792807962958496,
                                    0.006405520400261622,
                                    0.17110718011831583,
                                ],
                                [
                                    0.0080266509998506,
                                    0.21441155949205967,
                                    0.02805820592333759,
                                    0.7495035835847521,
                                ],
                                [
                                    0.17110718011831594,
                                    0.05133103037359432,
                                    0.5981274749345256,
                                    0.17943431457356418,
                                ],
                                [
                                    0.009328767899017558,
                                    0.24919429951608077,
                                    0.02675608902417063,
                                    0.7147208435607311,
                                ],
                                [
                                    0.19886490258625567,
                                    0.05965816482884268,
                                    0.5703697524665858,
                                    0.17110718011831583,
                                ],
                                [
                                    0.0004839904133421043,
                                    0.010341229694137779,
                                    0.04422553129030273,
                                    0.9449492486022174,
                                ],
                                [
                                    0.04309618500986464,
                                    0.9208189580669471,
                                    0.0016133366937802005,
                                    0.03447152022940798,
                                ],
                                [
                                    0.009856121812593951,
                                    0.21059181493620052,
                                    0.034853399891050886,
                                    0.7446986633601547,
                                ],
                                [
                                    0.2101067070546567,
                                    0.010341229694137793,
                                    0.7429832159146752,
                                    0.036568847336530284,
                                ],
                                [
                                    0.01185506314356264,
                                    0.25330239530887666,
                                    0.0328544585600822,
                                    0.7019880829874785,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260098,
                                    0.7003710213181527,
                                    0.03447152022940798,
                                ],
                                [
                                    9.838577615361658e-05,
                                    0.04461113592749122,
                                    0.0021021695508696182,
                                    0.9531883087454855,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.09141798473825839,
                                    0.0019989413309687114,
                                    0.9063814599347184,
                                ],
                                [
                                    0.00010300106049170477,
                                    0.046703847750275425,
                                    0.00209755426653153,
                                    0.9510955969227013,
                                ],
                                [
                                    0.0021957128832759206,
                                    0.04461113592749121,
                                    0.044714364147392154,
                                    0.9084787870418407,
                                ],
                                [
                                    0.00010784350423899511,
                                    0.04889956063355137,
                                    0.0020927118227842397,
                                    0.9488998840394254,
                                ],
                                [
                                    0.0022989411031768274,
                                    0.04670846303461354,
                                    0.04461113592749125,
                                    0.9063814599347184,
                                ],
                                [
                                    0.00039062651874043145,
                                    0.03569423040444776,
                                    0.010434593588739452,
                                    0.9534805494880724,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.7252132901931454,
                                ],
                                [
                                    0.0005023147334264394,
                                    0.04589995038812577,
                                    0.010322905374053443,
                                    0.9432748295043943,
                                ],
                                [
                                    0.010708034717104497,
                                    0.03569423040444771,
                                    0.220057310230054,
                                    0.7335404246483938,
                                ],
                                [
                                    0.0006195001238018261,
                                    0.05660798510523027,
                                    0.010205719983678056,
                                    0.9325667947872899,
                                ],
                                [
                                    0.01320612036933601,
                                    0.044021364859696085,
                                    0.21755922457782248,
                                    0.7252132901931454,
                                ],
                                [
                                    0.000550138831755803,
                                    0.022904899683578235,
                                    0.022904899683578235,
                                    0.9536400618010877,
                                ],
                                [
                                    0.012277658089422822,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.46536758105875475,
                                ],
                                [
                                    0.0010744706085363794,
                                    0.044735328758620074,
                                    0.02238056790679766,
                                    0.9318096327260459,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.0016246094402921827,
                                    0.06764022844219832,
                                    0.021830429075041853,
                                    0.9089047330424677,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.00039062651874043145,
                                    0.010434593588739452,
                                    0.03569423040444776,
                                    0.9534805494880724,
                                ],
                                [
                                    0.028148348986680238,
                                    0.7519115261736411,
                                    0.007936507936507952,
                                    0.21200361690317066,
                                ],
                                [
                                    0.001631661013864542,
                                    0.04358567259889627,
                                    0.03445319590932365,
                                    0.9203294704779156,
                                ],
                                [
                                    0.03478274002402132,
                                    0.010434593588739494,
                                    0.7344519150288202,
                                    0.220330751358419,
                                ],
                                [
                                    0.002933777913031501,
                                    0.0783684126229174,
                                    0.03315107901015669,
                                    0.8855467304538944,
                                ],
                                [
                                    0.06254046249196105,
                                    0.01876172804398785,
                                    0.7066941925608805,
                                    0.21200361690317066,
                                ],
                                [
                                    9.838577615361658e-05,
                                    0.0021021695508696182,
                                    0.04461113592749122,
                                    0.9531883087454855,
                                ],
                                [
                                    0.04271058037267615,
                                    0.912579897923679,
                                    0.0019989413309686897,
                                    0.04271058037267617,
                                ],
                                [
                                    0.0020035566153067787,
                                    0.042809193308239,
                                    0.04270596508833806,
                                    0.9124812849881162,
                                ],
                                [
                                    0.042710580372676187,
                                    0.0021021695508695974,
                                    0.9103793425966558,
                                    0.04480790747979848,
                                ],
                                [
                                    0.0040024979462754675,
                                    0.08551977368091515,
                                    0.04070702375736937,
                                    0.86977070461544,
                                ],
                                [
                                    0.08532277496919871,
                                    0.004199496657991903,
                                    0.8677671480001332,
                                    0.04271058037267617,
                                ],
                                [
                                    0.009833417785021961,
                                    0.8985469834806652,
                                    0.0009918023224579217,
                                    0.09062779641185491,
                                ],
                                [
                                    0.010341229694137779,
                                    0.9449492486022174,
                                    0.00048399041334210404,
                                    0.044225531290302704,
                                ],
                                [
                                    0.010294704170792082,
                                    0.9406978916914176,
                                    0.0005305159366878005,
                                    0.04847688820110252,
                                ],
                                [
                                    0.04461113592749125,
                                    0.9063814599347184,
                                    0.0022989411031768252,
                                    0.04670846303461349,
                                ],
                                [
                                    0.010318525666565796,
                                    0.9428746255226671,
                                    0.000506694440914087,
                                    0.046300154369853026,
                                ],
                                [
                                    0.044714364147392154,
                                    0.9084787870418407,
                                    0.0021957128832759197,
                                    0.04461113592749119,
                                ],
                                [
                                    0.039042165512684385,
                                    0.6941076326169691,
                                    0.014210478915896631,
                                    0.25263972295445,
                                ],
                                [
                                    0.05133103037359426,
                                    0.9125841127032176,
                                    0.0019216140549867579,
                                    0.034163242868201375,
                                ],
                                [
                                    0.0502051295061375,
                                    0.8925673852648304,
                                    0.0030475149224435177,
                                    0.05417997030658856,
                                ],
                                [
                                    0.21755922457782248,
                                    0.7252132901931454,
                                    0.013206120369336006,
                                    0.04402136485969607,
                                ],
                                [
                                    0.05078160110338225,
                                    0.9028161337750655,
                                    0.0024710433251987664,
                                    0.04393122179635344,
                                ],
                                [
                                    0.220057310230054,
                                    0.7335404246483938,
                                    0.010708034717104496,
                                    0.035694230404447705,
                                ],
                                [
                                    0.054985031209919655,
                                    0.4215599302747463,
                                    0.060397641263659596,
                                    0.46305739725167444,
                                ],
                                [
                                    0.11267636744670928,
                                    0.8638685940379567,
                                    0.0027063050268699707,
                                    0.02074873348846404,
                                ],
                                [
                                    0.1073907103702483,
                                    0.8233444517472613,
                                    0.007991962103330957,
                                    0.061272875779159464,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.11009701539711826,
                                    0.8440931852357253,
                                    0.005285657076460987,
                                    0.040524142290695425,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.03904216551268439,
                                    0.18089795932699423,
                                    0.138470535005893,
                                    0.6415893401544284,
                                ],
                                [
                                    0.17559108646359062,
                                    0.8135836934289296,
                                    0.0019216140549867583,
                                    0.008903606052493124,
                                ],
                                [
                                    0.16308052911846518,
                                    0.7556172803455861,
                                    0.014432171400112187,
                                    0.06687001913583657,
                                ],
                                [
                                    0.7066941925608805,
                                    0.21200361690317068,
                                    0.06254046249196094,
                                    0.01876172804398782,
                                ],
                                [
                                    0.1694860495187268,
                                    0.7852966168685126,
                                    0.008026650999850579,
                                    0.037190682612910045,
                                ],
                                [
                                    0.7344519150288203,
                                    0.22033075135841906,
                                    0.03478274002402117,
                                    0.01043459358873945,
                                ],
                                [
                                    0.009833417785021966,
                                    0.03487610391862287,
                                    0.21010670705465664,
                                    0.7451837712416985,
                                ],
                                [
                                    0.21945613442633652,
                                    0.7783433102466403,
                                    0.00048399041334210453,
                                    0.001716564913681105,
                                ],
                                [
                                    0.2002505852420627,
                                    0.7102271431307468,
                                    0.019689539597615907,
                                    0.06983273202957463,
                                ],
                                [
                                    0.8677671480001333,
                                    0.04271058037267617,
                                    0.08532277496919864,
                                    0.004199496657991899,
                                ],
                                [
                                    0.2100840030270847,
                                    0.7451032470493697,
                                    0.009856121812593944,
                                    0.03495662811095177,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979848,
                                    0.042710580372676124,
                                    0.0021021695508695944,
                                ],
                                [
                                    0.007936507936507941,
                                    0.7252132901931455,
                                    0.0028887121709719418,
                                    0.26396148969937466,
                                ],
                                [
                                    0.008444319845623757,
                                    0.7716155553146976,
                                    0.002380900261856124,
                                    0.21755922457782245,
                                ],
                                [
                                    0.008308810135164038,
                                    0.7592331014997702,
                                    0.0025164099723158457,
                                    0.22994167839274998,
                                ],
                                [
                                    0.03600545019906099,
                                    0.7315364614358733,
                                    0.010904626831607084,
                                    0.22155346153345873,
                                ],
                                [
                                    0.00833263163093775,
                                    0.7614098353310196,
                                    0.002492588476542132,
                                    0.22776494456150048,
                                ],
                                [
                                    0.03610867841896189,
                                    0.7336337885429954,
                                    0.010801398611706177,
                                    0.21945613442633644,
                                ],
                                [
                                    0.031510758845398154,
                                    0.560211195688866,
                                    0.02174188558318287,
                                    0.386536159882553,
                                ],
                                [
                                    0.04379962370630803,
                                    0.7786876757751146,
                                    0.009453020722272993,
                                    0.1680596797963044,
                                ],
                                [
                                    0.04052033763741682,
                                    0.7203871829601763,
                                    0.012732306791164202,
                                    0.22636017261124264,
                                ],
                                [
                                    0.1755910864635907,
                                    0.5853164341340025,
                                    0.0551742584835678,
                                    0.18391822091883903,
                                ],
                                [
                                    0.041096809234661566,
                                    0.7306359314704115,
                                    0.01215583519391945,
                                    0.2161114241010075,
                                ],
                                [
                                    0.1780891721158222,
                                    0.5936435685892508,
                                    0.05267617283133629,
                                    0.17559108646359065,
                                ],
                                [
                                    0.044378175129644364,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.5443781751296444,
                                ],
                                [
                                    0.10206951136643398,
                                    0.7825478161599868,
                                    0.01331316110714526,
                                    0.10206951136643397,
                                ],
                                [
                                    0.08667456664547664,
                                    0.6645176599457708,
                                    0.028708105828102612,
                                    0.2200996675806499,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.08938087167234661,
                                    0.6852663934342348,
                                    0.02600180080123264,
                                    0.19935093409218585,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.03151075884539816,
                                    0.14600194167317931,
                                    0.1460019416731792,
                                    0.6764853578082433,
                                ],
                                [
                                    0.16805967979630437,
                                    0.7786876757751146,
                                    0.009453020722272994,
                                    0.04379962370630805,
                                ],
                                [
                                    0.13162157267537705,
                                    0.6098553599095248,
                                    0.04589112784320032,
                                    0.2126319395718979,
                                ],
                                [
                                    0.5703697524665859,
                                    0.17110718011831585,
                                    0.19886490258625558,
                                    0.059658164828842654,
                                ],
                                [
                                    0.13802709307563868,
                                    0.6395346964324513,
                                    0.039485607442938706,
                                    0.18295260304897135,
                                ],
                                [
                                    0.5981274749345258,
                                    0.17943431457356424,
                                    0.1711071801183158,
                                    0.05133103037359428,
                                ],
                                [
                                    0.007936507936507952,
                                    0.028148348986680238,
                                    0.21200361690317066,
                                    0.7519115261736411,
                                ],
                                [
                                    0.2175592245778225,
                                    0.7716155553146976,
                                    0.0023809002618561267,
                                    0.008444319845623766,
                                ],
                                [
                                    0.16162136032547725,
                                    0.5732211812220835,
                                    0.05831876451420138,
                                    0.20683869393823784,
                                ],
                                [
                                    0.7003710213181528,
                                    0.034471520229407984,
                                    0.2527189016511791,
                                    0.012438556801260093,
                                ],
                                [
                                    0.17145477811049922,
                                    0.6080972851407064,
                                    0.04848534672917941,
                                    0.17196259001961497,
                                ],
                                [
                                    0.7429832159146753,
                                    0.036568847336530284,
                                    0.2101067070546566,
                                    0.010341229694137788,
                                ],
                                [
                                    0.0051587040991820324,
                                    0.47138625738548395,
                                    0.00566651600829785,
                                    0.5177885225070362,
                                ],
                                [
                                    0.00566651600829785,
                                    0.5177885225070362,
                                    0.0051587040991820324,
                                    0.47138625738548395,
                                ],
                                [
                                    0.005400699305853084,
                                    0.4934990230306353,
                                    0.005424520801626798,
                                    0.4956757568618848,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.005424520801626798,
                                    0.4956757568618848,
                                    0.005400699305853084,
                                    0.4934990230306353,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.020481889783835576,
                                    0.3641354377425853,
                                    0.032770754644745444,
                                    0.5826119178288337,
                                ],
                                [
                                    0.03277075464474545,
                                    0.5826119178288338,
                                    0.020481889783835572,
                                    0.36413543774258517,
                                ],
                                [
                                    0.026338086415668135,
                                    0.4682493035305919,
                                    0.026914558012912884,
                                    0.47849805204082707,
                                ],
                                [
                                    0.1141336296474635,
                                    0.3804537602987966,
                                    0.116631715299695,
                                    0.3887808947540449,
                                ],
                                [
                                    0.026914558012912884,
                                    0.47849805204082707,
                                    0.026338086415668135,
                                    0.4682493035305919,
                                ],
                                [
                                    0.116631715299695,
                                    0.3887808947540449,
                                    0.1141336296474635,
                                    0.3804537602987966,
                                ],
                                [
                                    0.028845668118394813,
                                    0.2211543318816052,
                                    0.08653700435518444,
                                    0.6634629956448156,
                                ],
                                [
                                    0.08653700435518444,
                                    0.6634629956448156,
                                    0.028845668118394813,
                                    0.2211543318816052,
                                ],
                                [
                                    0.05633818372335464,
                                    0.43193429701897834,
                                    0.05904448875022461,
                                    0.4526830305074424,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.05904448875022461,
                                    0.4526830305074424,
                                    0.05633818372335464,
                                    0.43193429701897834,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.020481889783835576,
                                    0.09490078268974368,
                                    0.1570308107347418,
                                    0.727586516791679,
                                ],
                                [
                                    0.1570308107347418,
                                    0.727586516791679,
                                    0.020481889783835576,
                                    0.09490078268974368,
                                ],
                                [
                                    0.08555359005915787,
                                    0.39640398147924805,
                                    0.0919591104594195,
                                    0.4260833180021746,
                                ],
                                [
                                    0.37073846629245083,
                                    0.11121910524595506,
                                    0.39849618876039067,
                                    0.11954623970120344,
                                ],
                                [
                                    0.0919591104594195,
                                    0.4260833180021746,
                                    0.08555359005915787,
                                    0.39640398147924805,
                                ],
                                [
                                    0.39849618876039067,
                                    0.11954623970120344,
                                    0.37073846629245083,
                                    0.11121910524595506,
                                ],
                                [
                                    0.0051587040991820385,
                                    0.018296334416152,
                                    0.21478142074049658,
                                    0.7617635407441694,
                                ],
                                [
                                    0.21478142074049658,
                                    0.7617635407441694,
                                    0.0051587040991820385,
                                    0.018296334416152,
                                ],
                                [
                                    0.10505335352732832,
                                    0.3725918856208493,
                                    0.1148867713123503,
                                    0.4074679895394721,
                                ],
                                [
                                    0.4552388641864047,
                                    0.022406374961772883,
                                    0.49785105878292724,
                                    0.02450370206889519,
                                ],
                                [
                                    0.1148867713123503,
                                    0.4074679895394721,
                                    0.10505335352732832,
                                    0.3725918856208493,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889519,
                                    0.4552388641864047,
                                    0.022406374961772883,
                                ],
                                [
                                    0.0023809002618561245,
                                    0.2175592245778225,
                                    0.008444319845623757,
                                    0.7716155553146976,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.7252132901931454,
                                ],
                                [
                                    0.0024925884765421326,
                                    0.2277649445615005,
                                    0.00833263163093775,
                                    0.7614098353310196,
                                ],
                                [
                                    0.010801398611706179,
                                    0.21945613442633646,
                                    0.03610867841896189,
                                    0.7336337885429954,
                                ],
                                [
                                    0.0025164099723158466,
                                    0.22994167839275004,
                                    0.008308810135164036,
                                    0.7592331014997701,
                                ],
                                [
                                    0.010904626831607086,
                                    0.22155346153345878,
                                    0.036005450199060984,
                                    0.7315364614358731,
                                ],
                                [
                                    0.009453020722272996,
                                    0.16805967979630448,
                                    0.04379962370630802,
                                    0.7786876757751144,
                                ],
                                [
                                    0.021741885583182873,
                                    0.38653615988255313,
                                    0.03151075884539815,
                                    0.5602111956888659,
                                ],
                                [
                                    0.012155835193919452,
                                    0.21611142410100753,
                                    0.041096809234661566,
                                    0.7306359314704115,
                                ],
                                [
                                    0.0526761728313363,
                                    0.17559108646359067,
                                    0.1780891721158222,
                                    0.5936435685892508,
                                ],
                                [
                                    0.012732306791164204,
                                    0.22636017261124264,
                                    0.04052033763741682,
                                    0.7203871829601763,
                                ],
                                [
                                    0.05517425848356781,
                                    0.18391822091883905,
                                    0.1755910864635907,
                                    0.5853164341340025,
                                ],
                                [
                                    0.013313161107145264,
                                    0.10206951136643398,
                                    0.10206951136643398,
                                    0.7825478161599868,
                                ],
                                [
                                    0.0710044973439349,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.3402391523967764,
                                ],
                                [
                                    0.026001800801232648,
                                    0.1993509340921859,
                                    0.08938087167234661,
                                    0.6852663934342348,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.028708105828102622,
                                    0.22009966758064997,
                                    0.08667456664547663,
                                    0.6645176599457707,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.009453020722272991,
                                    0.04379962370630803,
                                    0.16805967979630437,
                                    0.7786876757751146,
                                ],
                                [
                                    0.1460019416731792,
                                    0.6764853578082433,
                                    0.031510758845398154,
                                    0.14600194167317931,
                                ],
                                [
                                    0.03948560744293874,
                                    0.1829526030489715,
                                    0.13802709307563862,
                                    0.6395346964324511,
                                ],
                                [
                                    0.17110718011831594,
                                    0.05133103037359432,
                                    0.5981274749345256,
                                    0.17943431457356418,
                                ],
                                [
                                    0.04589112784320034,
                                    0.212631939571898,
                                    0.13162157267537702,
                                    0.6098553599095247,
                                ],
                                [
                                    0.19886490258625567,
                                    0.05965816482884268,
                                    0.5703697524665858,
                                    0.17110718011831583,
                                ],
                                [
                                    0.0023809002618561245,
                                    0.008444319845623757,
                                    0.2175592245778225,
                                    0.7716155553146976,
                                ],
                                [
                                    0.21200361690317066,
                                    0.7519115261736411,
                                    0.007936507936507948,
                                    0.028148348986680227,
                                ],
                                [
                                    0.04848534672917944,
                                    0.17196259001961506,
                                    0.1714547781104992,
                                    0.6080972851407064,
                                ],
                                [
                                    0.2101067070546567,
                                    0.010341229694137793,
                                    0.7429832159146752,
                                    0.036568847336530284,
                                ],
                                [
                                    0.0583187645142014,
                                    0.20683869393823792,
                                    0.16162136032547722,
                                    0.5732211812220834,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260098,
                                    0.7003710213181527,
                                    0.03447152022940798,
                                ],
                                [
                                    0.0004839904133421043,
                                    0.04422553129030273,
                                    0.010341229694137779,
                                    0.9449492486022174,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.09062779641185499,
                                    0.00983341778502196,
                                    0.8985469834806651,
                                ],
                                [
                                    0.0005066944409140872,
                                    0.04630015436985305,
                                    0.010318525666565796,
                                    0.9428746255226671,
                                ],
                                [
                                    0.0021957128832759206,
                                    0.04461113592749121,
                                    0.044714364147392154,
                                    0.9084787870418407,
                                ],
                                [
                                    0.0005305159366878011,
                                    0.04847688820110257,
                                    0.010294704170792082,
                                    0.9406978916914176,
                                ],
                                [
                                    0.0022989411031768274,
                                    0.04670846303461354,
                                    0.04461113592749125,
                                    0.9063814599347184,
                                ],
                                [
                                    0.001921614054986761,
                                    0.03416324286820143,
                                    0.05133103037359426,
                                    0.9125841127032176,
                                ],
                                [
                                    0.014210478915896638,
                                    0.25263972295445003,
                                    0.039042165512684385,
                                    0.694107632616969,
                                ],
                                [
                                    0.002471043325198767,
                                    0.04393122179635344,
                                    0.05078160110338225,
                                    0.9028161337750655,
                                ],
                                [
                                    0.010708034717104497,
                                    0.03569423040444771,
                                    0.220057310230054,
                                    0.7335404246483938,
                                ],
                                [
                                    0.0030475149224435186,
                                    0.054179970306588575,
                                    0.0502051295061375,
                                    0.8925673852648304,
                                ],
                                [
                                    0.01320612036933601,
                                    0.044021364859696085,
                                    0.21755922457782248,
                                    0.7252132901931454,
                                ],
                                [
                                    0.0027063050268699737,
                                    0.020748733488464063,
                                    0.11267636744670928,
                                    0.8638685940379567,
                                ],
                                [
                                    0.060397641263659596,
                                    0.46305739725167444,
                                    0.054985031209919655,
                                    0.4215599302747463,
                                ],
                                [
                                    0.005285657076460991,
                                    0.04052414229069547,
                                    0.11009701539711826,
                                    0.8440931852357253,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.007991962103330965,
                                    0.061272875779159526,
                                    0.10739071037024829,
                                    0.8233444517472612,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.0019216140549867583,
                                    0.008903606052493124,
                                    0.17559108646359062,
                                    0.8135836934289296,
                                ],
                                [
                                    0.138470535005893,
                                    0.6415893401544284,
                                    0.03904216551268439,
                                    0.18089795932699423,
                                ],
                                [
                                    0.008026650999850612,
                                    0.0371906826129102,
                                    0.16948604951872676,
                                    0.7852966168685124,
                                ],
                                [
                                    0.03478274002402132,
                                    0.010434593588739494,
                                    0.7344519150288202,
                                    0.220330751358419,
                                ],
                                [
                                    0.014432171400112211,
                                    0.06687001913583668,
                                    0.16308052911846516,
                                    0.755617280345586,
                                ],
                                [
                                    0.06254046249196105,
                                    0.01876172804398785,
                                    0.7066941925608805,
                                    0.21200361690317066,
                                ],
                                [
                                    0.00048399041334211006,
                                    0.0017165649136811247,
                                    0.21945613442633652,
                                    0.7783433102466403,
                                ],
                                [
                                    0.21010670705465664,
                                    0.7451837712416985,
                                    0.009833417785021972,
                                    0.03487610391862289,
                                ],
                                [
                                    0.009856121812593958,
                                    0.03495662811095182,
                                    0.21008400302708466,
                                    0.7451032470493696,
                                ],
                                [
                                    0.042710580372676187,
                                    0.0021021695508695974,
                                    0.9103793425966558,
                                    0.04480790747979848,
                                ],
                                [
                                    0.019689539597615924,
                                    0.0698327320295747,
                                    0.20025058524206268,
                                    0.7102271431307466,
                                ],
                                [
                                    0.08532277496919871,
                                    0.004199496657991903,
                                    0.8677671480001332,
                                    0.04271058037267617,
                                ],
                                [
                                    0.02130609729826128,
                                    0.8870743039674259,
                                    0.002148941217072757,
                                    0.08947065751724008,
                                ],
                                [
                                    0.022406374961772883,
                                    0.9328841033345823,
                                    0.001048663553561152,
                                    0.04366085815008366,
                                ],
                                [
                                    0.022305567963745623,
                                    0.928687027898464,
                                    0.0011494705515884126,
                                    0.047857933586201905,
                                ],
                                [
                                    0.04461113592749125,
                                    0.9063814599347184,
                                    0.0022989411031768252,
                                    0.04670846303461349,
                                ],
                                [
                                    0.022357182073696077,
                                    0.9308359691155368,
                                    0.0010978564416379598,
                                    0.045708992369129155,
                                ],
                                [
                                    0.044714364147392154,
                                    0.9084787870418407,
                                    0.0021957128832759197,
                                    0.04461113592749119,
                                ],
                                [
                                    0.08459278303166455,
                                    0.6485570150979889,
                                    0.030789889441914704,
                                    0.23606031242843187,
                                ],
                                [
                                    0.11121910524595506,
                                    0.8526960378308568,
                                    0.004163567227624185,
                                    0.03192128969556395,
                                ],
                                [
                                    0.10877961228891124,
                                    0.8339929024820567,
                                    0.006603060184668003,
                                    0.050624425044364076,
                                ],
                                [
                                    0.21755922457782248,
                                    0.7252132901931454,
                                    0.013206120369336006,
                                    0.04402136485969607,
                                ],
                                [
                                    0.110028655115027,
                                    0.8435690797634208,
                                    0.005354017358552248,
                                    0.04104824776299996,
                                ],
                                [
                                    0.220057310230054,
                                    0.7335404246483938,
                                    0.010708034717104496,
                                    0.035694230404447705,
                                ],
                                [
                                    0.11913624037116649,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.3925912788865005,
                                ],
                                [
                                    0.2441362403711665,
                                    0.7324087211134995,
                                    0.005863759628833502,
                                    0.017591278886500507,
                                ],
                                [
                                    0.2326837905293774,
                                    0.6980513715881322,
                                    0.017316209470622606,
                                    0.051948628411867814,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.23854755015821089,
                                    0.7156426504746327,
                                    0.011452449841789104,
                                    0.034357349525367314,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.08459278303166454,
                                    0.13534734180801408,
                                    0.3000245444947562,
                                    0.4800353306655652,
                                ],
                                [
                                    0.3804537602987966,
                                    0.6087210195937236,
                                    0.004163567227624186,
                                    0.006661652879855697,
                                ],
                                [
                                    0.35334709628044025,
                                    0.565350713183611,
                                    0.03127023124598047,
                                    0.050031959289968286,
                                ],
                                [
                                    0.7066941925608805,
                                    0.21200361690317068,
                                    0.06254046249196094,
                                    0.01876172804398782,
                                ],
                                [
                                    0.3672259575144102,
                                    0.5875567088728292,
                                    0.017391370012010587,
                                    0.02782596360075004,
                                ],
                                [
                                    0.7344519150288203,
                                    0.22033075135841906,
                                    0.03478274002402117,
                                    0.01043459358873945,
                                ],
                                [
                                    0.021306097298261266,
                                    0.023403424405383573,
                                    0.4552388641864047,
                                    0.5000516141099505,
                                ],
                                [
                                    0.4754962979311048,
                                    0.522303146741872,
                                    0.001048663553561152,
                                    0.0011518917734620576,
                                ],
                                [
                                    0.43388357400006666,
                                    0.47659415437274283,
                                    0.04266138748459932,
                                    0.046860884142591215,
                                ],
                                [
                                    0.8677671480001333,
                                    0.04271058037267617,
                                    0.08532277496919864,
                                    0.004199496657991899,
                                ],
                                [
                                    0.45518967129832794,
                                    0.4999975787781264,
                                    0.021355290186338062,
                                    0.023457459737207656,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979848,
                                    0.042710580372676124,
                                    0.0021021695508695944,
                                ],
                                [
                                    0.017196056752640396,
                                    0.7159537413770131,
                                    0.006258981762693642,
                                    0.26059122010765295,
                                ],
                                [
                                    0.018296334416152,
                                    0.7617635407441694,
                                    0.005158704099182037,
                                    0.21478142074049653,
                                ],
                                [
                                    0.018002725099530496,
                                    0.7495391865354037,
                                    0.005452313415803542,
                                    0.22700577494926227,
                                ],
                                [
                                    0.03600545019906099,
                                    0.7315364614358733,
                                    0.010904626831607084,
                                    0.22155346153345873,
                                ],
                                [
                                    0.018054339209480946,
                                    0.7516881277524764,
                                    0.005400699305853089,
                                    0.2248568337321895,
                                ],
                                [
                                    0.03610867841896189,
                                    0.7336337885429954,
                                    0.010801398611706177,
                                    0.21945613442633644,
                                ],
                                [
                                    0.06827446047545314,
                                    0.523447494058811,
                                    0.0471082119981261,
                                    0.3611698334676098,
                                ],
                                [
                                    0.09490078268974368,
                                    0.727586516791679,
                                    0.020481889783835576,
                                    0.15703081073474182,
                                ],
                                [
                                    0.08779554323179535,
                                    0.6731119773657978,
                                    0.0275871292417839,
                                    0.21150535016062294,
                                ],
                                [
                                    0.1755910864635907,
                                    0.5853164341340025,
                                    0.0551742584835678,
                                    0.18391822091883903,
                                ],
                                [
                                    0.0890445860579111,
                                    0.6826881546471619,
                                    0.026338086415668146,
                                    0.2019291728792588,
                                ],
                                [
                                    0.1780891721158222,
                                    0.5936435685892508,
                                    0.05267617283133629,
                                    0.17559108646359065,
                                ],
                                [
                                    0.09615433188160519,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.4615370043551844,
                                ],
                                [
                                    0.2211543318816052,
                                    0.6634629956448156,
                                    0.028845668118394806,
                                    0.08653700435518441,
                                ],
                                [
                                    0.18779805664781188,
                                    0.5633941699434356,
                                    0.06220194335218813,
                                    0.1866058300565644,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.19366181627664536,
                                    0.5809854488299361,
                                    0.056338183723354626,
                                    0.16901455117006386,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.06827446047545316,
                                    0.10923824004312432,
                                    0.3163428670509676,
                                    0.5061444324304549,
                                ],
                                [
                                    0.36413543774258517,
                                    0.5826119178288338,
                                    0.02048188978383558,
                                    0.032770754644745465,
                                ],
                                [
                                    0.28518487623329297,
                                    0.4562920563516088,
                                    0.09943245129312779,
                                    0.15909061612197045,
                                ],
                                [
                                    0.5703697524665859,
                                    0.17110718011831585,
                                    0.19886490258625558,
                                    0.059658164828842654,
                                ],
                                [
                                    0.2990637374672629,
                                    0.47849805204082707,
                                    0.0855535900591579,
                                    0.13688462043275218,
                                ],
                                [
                                    0.5981274749345258,
                                    0.17943431457356424,
                                    0.1711071801183158,
                                    0.05133103037359428,
                                ],
                                [
                                    0.0171960567526404,
                                    0.018888800170547792,
                                    0.45934890473202555,
                                    0.5045662383447862,
                                ],
                                [
                                    0.47138625738548395,
                                    0.5177885225070362,
                                    0.005158704099182037,
                                    0.005666516008297856,
                                ],
                                [
                                    0.3501855106590764,
                                    0.3846570308884844,
                                    0.12635945082558955,
                                    0.13879800762684966,
                                ],
                                [
                                    0.7003710213181528,
                                    0.034471520229407984,
                                    0.2527189016511791,
                                    0.012438556801260093,
                                ],
                                [
                                    0.37149160795733766,
                                    0.408060455293868,
                                    0.1050533535273283,
                                    0.11539458322146608,
                                ],
                                [
                                    0.7429832159146753,
                                    0.036568847336530284,
                                    0.2101067070546566,
                                    0.010341229694137788,
                                ],
                                [
                                    0.011177380425911215,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.5111773804259112,
                                ],
                                [
                                    0.012277658089422822,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.46536758105875475,
                                ],
                                [
                                    0.011701712202691792,
                                    0.4871980101337966,
                                    0.011753326312642245,
                                    0.48934695135086936,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.011753326312642245,
                                    0.48934695135086936,
                                    0.011701712202691792,
                                    0.4871980101337966,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.04437817512964438,
                                    0.3402391523967765,
                                    0.07100449734393488,
                                    0.5443781751296443,
                                ],
                                [
                                    0.0710044973439349,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.3402391523967764,
                                ],
                                [
                                    0.05706681482373175,
                                    0.4375205751225283,
                                    0.0583158576498475,
                                    0.44709675240389246,
                                ],
                                [
                                    0.1141336296474635,
                                    0.3804537602987966,
                                    0.116631715299695,
                                    0.3887808947540449,
                                ],
                                [
                                    0.0583158576498475,
                                    0.44709675240389246,
                                    0.05706681482373175,
                                    0.4375205751225283,
                                ],
                                [
                                    0.116631715299695,
                                    0.3887808947540449,
                                    0.1141336296474635,
                                    0.3804537602987966,
                                ],
                                [0.0625, 0.1875, 0.1875, 0.5625],
                                [0.1875, 0.5625, 0.0625, 0.1875],
                                [
                                    0.12206812018558325,
                                    0.36620436055674976,
                                    0.12793187981441675,
                                    0.38379563944325024,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.12793187981441675,
                                    0.38379563944325024,
                                    0.12206812018558325,
                                    0.36620436055674976,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.044378175129644364,
                                    0.0710044973439349,
                                    0.3402391523967764,
                                    0.5443781751296444,
                                ],
                                [
                                    0.3402391523967764,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.0710044973439349,
                                ],
                                [
                                    0.18536923314622542,
                                    0.29658833839218046,
                                    0.19924809438019533,
                                    0.3187943340813988,
                                ],
                                [
                                    0.37073846629245083,
                                    0.11121910524595506,
                                    0.39849618876039067,
                                    0.11954623970120344,
                                ],
                                [
                                    0.19924809438019533,
                                    0.3187943340813988,
                                    0.18536923314622542,
                                    0.29658833839218046,
                                ],
                                [
                                    0.39849618876039067,
                                    0.11954623970120344,
                                    0.37073846629245083,
                                    0.11121910524595506,
                                ],
                                [
                                    0.011177380425911215,
                                    0.012277658089422822,
                                    0.46536758105875475,
                                    0.5111773804259112,
                                ],
                                [
                                    0.46536758105875475,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.012277658089422822,
                                ],
                                [
                                    0.22761943209320235,
                                    0.25002580705497524,
                                    0.24892552939146362,
                                    0.2734292314603588,
                                ],
                                [
                                    0.4552388641864047,
                                    0.022406374961772883,
                                    0.49785105878292724,
                                    0.02450370206889519,
                                ],
                                [
                                    0.24892552939146362,
                                    0.2734292314603588,
                                    0.22761943209320235,
                                    0.25002580705497524,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889519,
                                    0.4552388641864047,
                                    0.022406374961772883,
                                ],
                                [
                                    0.0051587040991820385,
                                    0.21478142074049658,
                                    0.018296334416152,
                                    0.7617635407441694,
                                ],
                                [
                                    0.006258981762693645,
                                    0.26059122010765307,
                                    0.017196056752640392,
                                    0.715953741377013,
                                ],
                                [
                                    0.0054006993058530895,
                                    0.22485683373218954,
                                    0.018054339209480946,
                                    0.7516881277524764,
                                ],
                                [
                                    0.010801398611706179,
                                    0.21945613442633646,
                                    0.03610867841896189,
                                    0.7336337885429954,
                                ],
                                [
                                    0.005452313415803543,
                                    0.22700577494926233,
                                    0.018002725099530492,
                                    0.7495391865354036,
                                ],
                                [
                                    0.010904626831607086,
                                    0.22155346153345878,
                                    0.036005450199060984,
                                    0.7315364614358731,
                                ],
                                [
                                    0.020481889783835586,
                                    0.1570308107347419,
                                    0.09490078268974367,
                                    0.7275865167916789,
                                ],
                                [
                                    0.047108211998126114,
                                    0.3611698334676099,
                                    0.06827446047545314,
                                    0.5234474940588109,
                                ],
                                [
                                    0.02633808641566815,
                                    0.20192917287925882,
                                    0.0890445860579111,
                                    0.6826881546471619,
                                ],
                                [
                                    0.0526761728313363,
                                    0.17559108646359067,
                                    0.1780891721158222,
                                    0.5936435685892508,
                                ],
                                [
                                    0.027587129241783904,
                                    0.21150535016062294,
                                    0.08779554323179535,
                                    0.6731119773657978,
                                ],
                                [
                                    0.05517425848356781,
                                    0.18391822091883905,
                                    0.1755910864635907,
                                    0.5853164341340025,
                                ],
                                [
                                    0.028845668118394813,
                                    0.08653700435518444,
                                    0.2211543318816052,
                                    0.6634629956448156,
                                ],
                                [
                                    0.1538456681183948,
                                    0.4615370043551844,
                                    0.09615433188160519,
                                    0.2884629956448156,
                                ],
                                [
                                    0.05633818372335464,
                                    0.16901455117006392,
                                    0.19366181627664536,
                                    0.5809854488299361,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.06220194335218815,
                                    0.18660583005656445,
                                    0.18779805664781185,
                                    0.5633941699434355,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.020481889783835572,
                                    0.03277075464474545,
                                    0.36413543774258517,
                                    0.5826119178288338,
                                ],
                                [
                                    0.3163428670509676,
                                    0.5061444324304549,
                                    0.06827446047545314,
                                    0.10923824004312431,
                                ],
                                [
                                    0.08555359005915797,
                                    0.1368846204327523,
                                    0.2990637374672628,
                                    0.47849805204082696,
                                ],
                                [
                                    0.17110718011831594,
                                    0.05133103037359432,
                                    0.5981274749345256,
                                    0.17943431457356418,
                                ],
                                [
                                    0.09943245129312783,
                                    0.1590906161219705,
                                    0.2851848762332929,
                                    0.45629205635160874,
                                ],
                                [
                                    0.19886490258625567,
                                    0.05965816482884268,
                                    0.5703697524665858,
                                    0.17110718011831583,
                                ],
                                [
                                    0.0051587040991820324,
                                    0.00566651600829785,
                                    0.47138625738548395,
                                    0.5177885225070362,
                                ],
                                [
                                    0.45934890473202555,
                                    0.5045662383447862,
                                    0.017196056752640392,
                                    0.018888800170547785,
                                ],
                                [
                                    0.10505335352732835,
                                    0.11539458322146613,
                                    0.3714916079573376,
                                    0.4080604552938679,
                                ],
                                [
                                    0.2101067070546567,
                                    0.010341229694137793,
                                    0.7429832159146752,
                                    0.036568847336530284,
                                ],
                                [
                                    0.1263594508255896,
                                    0.1387980076268497,
                                    0.3501855106590763,
                                    0.38465703088848435,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260098,
                                    0.7003710213181527,
                                    0.03447152022940798,
                                ],
                                [
                                    0.0010486635535611527,
                                    0.043660858150083685,
                                    0.022406374961772883,
                                    0.9328841033345823,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.08947065751724015,
                                    0.021306097298261276,
                                    0.8870743039674258,
                                ],
                                [
                                    0.0010978564416379603,
                                    0.04570899236912917,
                                    0.022357182073696077,
                                    0.9308359691155368,
                                ],
                                [
                                    0.0021957128832759206,
                                    0.04461113592749121,
                                    0.044714364147392154,
                                    0.9084787870418407,
                                ],
                                [
                                    0.0011494705515884137,
                                    0.04785793358620195,
                                    0.022305567963745623,
                                    0.928687027898464,
                                ],
                                [
                                    0.0022989411031768274,
                                    0.04670846303461354,
                                    0.04461113592749125,
                                    0.9063814599347184,
                                ],
                                [
                                    0.004163567227624192,
                                    0.031921289695564,
                                    0.11121910524595506,
                                    0.8526960378308568,
                                ],
                                [
                                    0.030789889441914717,
                                    0.23606031242843198,
                                    0.08459278303166454,
                                    0.6485570150979888,
                                ],
                                [
                                    0.005354017358552249,
                                    0.041048247762999965,
                                    0.110028655115027,
                                    0.8435690797634208,
                                ],
                                [
                                    0.010708034717104497,
                                    0.03569423040444771,
                                    0.220057310230054,
                                    0.7335404246483938,
                                ],
                                [
                                    0.006603060184668005,
                                    0.05062442504436409,
                                    0.10877961228891124,
                                    0.8339929024820567,
                                ],
                                [
                                    0.01320612036933601,
                                    0.044021364859696085,
                                    0.21755922457782248,
                                    0.7252132901931454,
                                ],
                                [
                                    0.005863759628833509,
                                    0.017591278886500528,
                                    0.2441362403711665,
                                    0.7324087211134995,
                                ],
                                [
                                    0.1308637596288335,
                                    0.3925912788865005,
                                    0.11913624037116649,
                                    0.3574087211134995,
                                ],
                                [
                                    0.011452449841789114,
                                    0.03435734952536734,
                                    0.23854755015821089,
                                    0.7156426504746327,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.017316209470622623,
                                    0.05194862841186787,
                                    0.23268379052937738,
                                    0.6980513715881321,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.004163567227624186,
                                    0.006661652879855697,
                                    0.3804537602987966,
                                    0.6087210195937236,
                                ],
                                [
                                    0.3000245444947562,
                                    0.4800353306655652,
                                    0.08459278303166454,
                                    0.13534734180801408,
                                ],
                                [
                                    0.01739137001201066,
                                    0.027825963600750153,
                                    0.3672259575144101,
                                    0.5875567088728291,
                                ],
                                [
                                    0.03478274002402132,
                                    0.010434593588739494,
                                    0.7344519150288202,
                                    0.220330751358419,
                                ],
                                [
                                    0.03127023124598052,
                                    0.05003195928996837,
                                    0.35334709628044025,
                                    0.5653507131836109,
                                ],
                                [
                                    0.06254046249196105,
                                    0.01876172804398785,
                                    0.7066941925608805,
                                    0.21200361690317066,
                                ],
                                [
                                    0.001048663553561164,
                                    0.0011518917734620708,
                                    0.4754962979311048,
                                    0.522303146741872,
                                ],
                                [
                                    0.4552388641864047,
                                    0.5000516141099505,
                                    0.021306097298261276,
                                    0.023403424405383583,
                                ],
                                [
                                    0.021355290186338093,
                                    0.023457459737207687,
                                    0.4551896712983279,
                                    0.49999757877812634,
                                ],
                                [
                                    0.042710580372676187,
                                    0.0021021695508695974,
                                    0.9103793425966558,
                                    0.04480790747979848,
                                ],
                                [
                                    0.042661387484599356,
                                    0.046860884142591264,
                                    0.4338835740000666,
                                    0.4765941543727428,
                                ],
                                [
                                    0.08532277496919871,
                                    0.004199496657991903,
                                    0.8677671480001332,
                                    0.04271058037267617,
                                ],
                                [
                                    0.0327787768115006,
                                    0.8756016244541865,
                                    0.003306080111687592,
                                    0.08831351862262524,
                                ],
                                [
                                    0.03447152022940799,
                                    0.9208189580669471,
                                    0.0016133366937802001,
                                    0.04309618500986461,
                                ],
                                [
                                    0.03431643175669916,
                                    0.9166761641055104,
                                    0.0017684251664890245,
                                    0.04723897897130129,
                                ],
                                [
                                    0.04461113592749125,
                                    0.9063814599347184,
                                    0.0022989411031768252,
                                    0.04670846303461349,
                                ],
                                [
                                    0.034395838480826356,
                                    0.9187973127084065,
                                    0.0016890184423618325,
                                    0.045117830368405276,
                                ],
                                [
                                    0.044714364147392154,
                                    0.9084787870418407,
                                    0.0021957128832759197,
                                    0.04461113592749119,
                                ],
                                [
                                    0.13014340055064463,
                                    0.6030063975790088,
                                    0.047369299967932744,
                                    0.21948090190241384,
                                ],
                                [
                                    0.17110718011831574,
                                    0.7928079629584961,
                                    0.006405520400261609,
                                    0.029679336522926526,
                                ],
                                [
                                    0.1673540950716849,
                                    0.775418419699283,
                                    0.010158605446892482,
                                    0.0470688797821396,
                                ],
                                [
                                    0.21755922457782248,
                                    0.7252132901931454,
                                    0.013206120369336006,
                                    0.04402136485969607,
                                ],
                                [
                                    0.16927570912667164,
                                    0.7843220257517761,
                                    0.008236991391905724,
                                    0.03816527372964648,
                                ],
                                [
                                    0.220057310230054,
                                    0.7335404246483938,
                                    0.010708034717104496,
                                    0.035694230404447705,
                                ],
                                [
                                    0.18328744953241333,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.3221251605213266,
                                ],
                                [
                                    0.3755961132956237,
                                    0.6009488481890423,
                                    0.009021214230797034,
                                    0.014433824284536975,
                                ],
                                [
                                    0.35797687068850653,
                                    0.5727582914290031,
                                    0.026640456837914255,
                                    0.04262438104457617,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.3669980849193035,
                                    0.58719211571354,
                                    0.01761924260711722,
                                    0.028190556760039193,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.13014340055064466,
                                    0.08979672428903396,
                                    0.46157855398361936,
                                    0.318481321176702,
                                ],
                                [
                                    0.5853164341340024,
                                    0.4038583457585177,
                                    0.006405520400261612,
                                    0.004419699707218271,
                                ],
                                [
                                    0.5436136634424152,
                                    0.375084146021636,
                                    0.04810829109184874,
                                    0.03319389944410001,
                                ],
                                [
                                    0.7066941925608805,
                                    0.21200361690317068,
                                    0.06254046249196094,
                                    0.01876172804398782,
                                ],
                                [
                                    0.5649658655100934,
                                    0.389816800877146,
                                    0.02675608902417059,
                                    0.018461244588590036,
                                ],
                                [
                                    0.7344519150288203,
                                    0.22033075135841906,
                                    0.03478274002402117,
                                    0.01043459358873945,
                                ],
                                [
                                    0.032778776811500564,
                                    0.011930744892144272,
                                    0.7003710213181528,
                                    0.2549194569782024,
                                ],
                                [
                                    0.7315364614358731,
                                    0.2662629832371037,
                                    0.0016133366937801992,
                                    0.0005872186332430102,
                                ],
                                [
                                    0.6675165627580706,
                                    0.2429611656147389,
                                    0.06563323537158273,
                                    0.023889036255607805,
                                ],
                                [
                                    0.8677671480001333,
                                    0.04271058037267617,
                                    0.08532277496919864,
                                    0.004199496657991899,
                                ],
                                [
                                    0.7002953395695711,
                                    0.25489191050688315,
                                    0.03285445856008218,
                                    0.011958291363463538,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979848,
                                    0.042710580372676124,
                                    0.0021021695508695944,
                                ],
                                [
                                    0.02645560556877285,
                                    0.7066941925608806,
                                    0.009629251354415343,
                                    0.25722095051593125,
                                ],
                                [
                                    0.028148348986680238,
                                    0.7519115261736411,
                                    0.00793650793650795,
                                    0.2120036169031706,
                                ],
                                [
                                    0.027696640063896955,
                                    0.7398452715710373,
                                    0.008388216859291238,
                                    0.2240698715057746,
                                ],
                                [
                                    0.03600545019906099,
                                    0.7315364614358733,
                                    0.010904626831607084,
                                    0.22155346153345873,
                                ],
                                [
                                    0.027776046788024145,
                                    0.7419664201739332,
                                    0.008308810135164045,
                                    0.22194872290287856,
                                ],
                                [
                                    0.03610867841896189,
                                    0.7336337885429954,
                                    0.010801398611706177,
                                    0.21945613442633644,
                                ],
                                [
                                    0.10503816210550808,
                                    0.48668379242875603,
                                    0.07247453841306929,
                                    0.3358035070526666,
                                ],
                                [
                                    0.14600194167317923,
                                    0.6764853578082434,
                                    0.03151075884539815,
                                    0.14600194167317926,
                                ],
                                [
                                    0.1350707488261738,
                                    0.6258367717714194,
                                    0.04244195169240357,
                                    0.19665052771000324,
                                ],
                                [
                                    0.1755910864635907,
                                    0.5853164341340025,
                                    0.0551742584835678,
                                    0.18391822091883903,
                                ],
                                [
                                    0.13699236288116054,
                                    0.6347403778239125,
                                    0.04052033763741681,
                                    0.18774692165751014,
                                ],
                                [
                                    0.1780891721158222,
                                    0.5936435685892508,
                                    0.05267617283133629,
                                    0.17559108646359065,
                                ],
                                [
                                    0.147930488633566,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.3786958335807245,
                                ],
                                [
                                    0.3402391523967764,
                                    0.5443781751296444,
                                    0.04437817512964435,
                                    0.07100449734393487,
                                ],
                                [
                                    0.28892154665014713,
                                    0.4622706799411004,
                                    0.09569578087627365,
                                    0.15311199253247887,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.2979427608809441,
                                    0.4767045042256373,
                                    0.08667456664547661,
                                    0.1386781682479419,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.10503816210550813,
                                    0.07247453841306935,
                                    0.48668379242875587,
                                    0.33580350705266665,
                                ],
                                [
                                    0.5602111956888659,
                                    0.38653615988255313,
                                    0.03151075884539816,
                                    0.021741885583182883,
                                ],
                                [
                                    0.4387481797912088,
                                    0.302728752793693,
                                    0.15297377474305524,
                                    0.10554929267204301,
                                ],
                                [
                                    0.5703697524665859,
                                    0.17110718011831585,
                                    0.19886490258625558,
                                    0.059658164828842654,
                                ],
                                [
                                    0.46010038185888696,
                                    0.317461407649203,
                                    0.13162157267537705,
                                    0.09081663781653301,
                                ],
                                [
                                    0.5981274749345258,
                                    0.17943431457356424,
                                    0.1711071801183158,
                                    0.05133103037359428,
                                ],
                                [
                                    0.026455605568772845,
                                    0.009629251354415346,
                                    0.7066941925608805,
                                    0.25722095051593136,
                                ],
                                [
                                    0.7252132901931454,
                                    0.2639614896993748,
                                    0.007936507936507948,
                                    0.0028887121709719457,
                                ],
                                [
                                    0.5387496609926755,
                                    0.19609288055488522,
                                    0.19440013713697774,
                                    0.07075732131546147,
                                ],
                                [
                                    0.7003710213181528,
                                    0.034471520229407984,
                                    0.2527189016511791,
                                    0.012438556801260093,
                                ],
                                [
                                    0.5715284378041762,
                                    0.2080236254470295,
                                    0.16162136032547716,
                                    0.0588265764233172,
                                ],
                                [
                                    0.7429832159146753,
                                    0.036568847336530284,
                                    0.2101067070546566,
                                    0.010341229694137788,
                                ],
                                [
                                    0.0171960567526404,
                                    0.45934890473202555,
                                    0.018888800170547792,
                                    0.5045662383447862,
                                ],
                                [
                                    0.018888800170547792,
                                    0.5045662383447862,
                                    0.0171960567526404,
                                    0.45934890473202555,
                                ],
                                [
                                    0.0180027250995305,
                                    0.4808969972369579,
                                    0.018082131823657692,
                                    0.4830181458398539,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.018082131823657692,
                                    0.4830181458398539,
                                    0.0180027250995305,
                                    0.4808969972369579,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.06827446047545313,
                                    0.3163428670509677,
                                    0.10923824004312424,
                                    0.5061444324304549,
                                ],
                                [
                                    0.10923824004312425,
                                    0.506144432430455,
                                    0.06827446047545312,
                                    0.31634286705096765,
                                ],
                                [
                                    0.08779554323179531,
                                    0.4067918467144648,
                                    0.08971715728678206,
                                    0.41569545276695785,
                                ],
                                [
                                    0.1141336296474635,
                                    0.3804537602987966,
                                    0.116631715299695,
                                    0.3887808947540449,
                                ],
                                [
                                    0.08971715728678206,
                                    0.41569545276695785,
                                    0.08779554323179531,
                                    0.4067918467144648,
                                ],
                                [
                                    0.116631715299695,
                                    0.3887808947540449,
                                    0.1141336296474635,
                                    0.3804537602987966,
                                ],
                                [
                                    0.09615433188160519,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.4615370043551844,
                                ],
                                [
                                    0.2884629956448156,
                                    0.4615370043551844,
                                    0.09615433188160519,
                                    0.1538456681183948,
                                ],
                                [
                                    0.18779805664781185,
                                    0.30047442409452113,
                                    0.1968192708786089,
                                    0.3149082483790581,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.1968192708786089,
                                    0.3149082483790581,
                                    0.18779805664781185,
                                    0.30047442409452113,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.06827446047545314,
                                    0.047108211998126114,
                                    0.5234474940588109,
                                    0.3611698334676099,
                                ],
                                [
                                    0.5234474940588109,
                                    0.3611698334676099,
                                    0.06827446047545314,
                                    0.047108211998126114,
                                ],
                                [
                                    0.2851848762332929,
                                    0.196772695305113,
                                    0.3065370783009711,
                                    0.211505350160623,
                                ],
                                [
                                    0.37073846629245083,
                                    0.11121910524595506,
                                    0.39849618876039067,
                                    0.11954623970120344,
                                ],
                                [
                                    0.3065370783009711,
                                    0.211505350160623,
                                    0.2851848762332929,
                                    0.196772695305113,
                                ],
                                [
                                    0.39849618876039067,
                                    0.11954623970120344,
                                    0.37073846629245083,
                                    0.11121910524595506,
                                ],
                                [
                                    0.017196056752640392,
                                    0.006258981762693645,
                                    0.715953741377013,
                                    0.26059122010765307,
                                ],
                                [
                                    0.715953741377013,
                                    0.26059122010765307,
                                    0.017196056752640392,
                                    0.006258981762693645,
                                ],
                                [
                                    0.3501855106590764,
                                    0.1274597284891012,
                                    0.3829642874705769,
                                    0.1393904733812455,
                                ],
                                [
                                    0.4552388641864047,
                                    0.022406374961772883,
                                    0.49785105878292724,
                                    0.02450370206889519,
                                ],
                                [
                                    0.3829642874705769,
                                    0.1393904733812455,
                                    0.3501855106590764,
                                    0.1274597284891012,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889519,
                                    0.4552388641864047,
                                    0.022406374961772883,
                                ],
                                [
                                    0.007936507936507952,
                                    0.21200361690317066,
                                    0.028148348986680238,
                                    0.7519115261736411,
                                ],
                                [
                                    0.009629251354415346,
                                    0.25722095051593136,
                                    0.026455605568772845,
                                    0.7066941925608805,
                                ],
                                [
                                    0.008308810135164046,
                                    0.2219487229028786,
                                    0.027776046788024145,
                                    0.7419664201739332,
                                ],
                                [
                                    0.010801398611706179,
                                    0.21945613442633646,
                                    0.03610867841896189,
                                    0.7336337885429954,
                                ],
                                [
                                    0.00838821685929124,
                                    0.22406987150577462,
                                    0.027696640063896952,
                                    0.7398452715710372,
                                ],
                                [
                                    0.010904626831607086,
                                    0.22155346153345878,
                                    0.036005450199060984,
                                    0.7315364614358731,
                                ],
                                [
                                    0.03151075884539816,
                                    0.14600194167317931,
                                    0.1460019416731792,
                                    0.6764853578082433,
                                ],
                                [
                                    0.0724745384130693,
                                    0.33580350705266665,
                                    0.10503816210550806,
                                    0.486683792428756,
                                ],
                                [
                                    0.04052033763741682,
                                    0.18774692165751014,
                                    0.13699236288116054,
                                    0.6347403778239125,
                                ],
                                [
                                    0.0526761728313363,
                                    0.17559108646359067,
                                    0.1780891721158222,
                                    0.5936435685892508,
                                ],
                                [
                                    0.04244195169240358,
                                    0.19665052771000327,
                                    0.1350707488261738,
                                    0.6258367717714194,
                                ],
                                [
                                    0.05517425848356781,
                                    0.18391822091883905,
                                    0.1755910864635907,
                                    0.5853164341340025,
                                ],
                                [
                                    0.044378175129644364,
                                    0.0710044973439349,
                                    0.3402391523967764,
                                    0.5443781751296444,
                                ],
                                [
                                    0.23668683889285475,
                                    0.3786958335807245,
                                    0.147930488633566,
                                    0.23668683889285475,
                                ],
                                [
                                    0.08667456664547664,
                                    0.13867816824794194,
                                    0.2979427608809441,
                                    0.4767045042256373,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.09569578087627367,
                                    0.15311199253247892,
                                    0.2889215466501471,
                                    0.4622706799411003,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.03151075884539815,
                                    0.021741885583182873,
                                    0.5602111956888659,
                                    0.38653615988255313,
                                ],
                                [
                                    0.48668379242875587,
                                    0.33580350705266665,
                                    0.1050381621055081,
                                    0.07247453841306935,
                                ],
                                [
                                    0.13162157267537716,
                                    0.09081663781653308,
                                    0.46010038185888685,
                                    0.3174614076492029,
                                ],
                                [
                                    0.17110718011831594,
                                    0.05133103037359432,
                                    0.5981274749345256,
                                    0.17943431457356418,
                                ],
                                [
                                    0.1529737747430553,
                                    0.10554929267204305,
                                    0.4387481797912087,
                                    0.30272875279369293,
                                ],
                                [
                                    0.19886490258625567,
                                    0.05965816482884268,
                                    0.5703697524665858,
                                    0.17110718011831583,
                                ],
                                [
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                    0.7252132901931454,
                                    0.2639614896993748,
                                ],
                                [
                                    0.7066941925608805,
                                    0.25722095051593136,
                                    0.026455605568772834,
                                    0.009629251354415343,
                                ],
                                [
                                    0.16162136032547725,
                                    0.05882657642331723,
                                    0.5715284378041761,
                                    0.20802362544702946,
                                ],
                                [
                                    0.2101067070546567,
                                    0.010341229694137793,
                                    0.7429832159146752,
                                    0.036568847336530284,
                                ],
                                [
                                    0.19440013713697782,
                                    0.0707573213154615,
                                    0.5387496609926755,
                                    0.1960928805548852,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260098,
                                    0.7003710213181527,
                                    0.03447152022940798,
                                ],
                                [
                                    0.0016133366937802012,
                                    0.04309618500986464,
                                    0.03447152022940799,
                                    0.9208189580669471,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.08831351862262532,
                                    0.0327787768115006,
                                    0.8756016244541865,
                                ],
                                [
                                    0.0016890184423618334,
                                    0.0451178303684053,
                                    0.034395838480826356,
                                    0.9187973127084065,
                                ],
                                [
                                    0.0021957128832759206,
                                    0.04461113592749121,
                                    0.044714364147392154,
                                    0.9084787870418407,
                                ],
                                [
                                    0.0017684251664890262,
                                    0.04723897897130134,
                                    0.03431643175669916,
                                    0.9166761641055104,
                                ],
                                [
                                    0.0022989411031768274,
                                    0.04670846303461354,
                                    0.04461113592749125,
                                    0.9063814599347184,
                                ],
                                [
                                    0.006405520400261619,
                                    0.02967933652292657,
                                    0.17110718011831574,
                                    0.7928079629584961,
                                ],
                                [
                                    0.047369299967932765,
                                    0.21948090190241393,
                                    0.1301434005506446,
                                    0.6030063975790088,
                                ],
                                [
                                    0.008236991391905726,
                                    0.03816527372964648,
                                    0.16927570912667164,
                                    0.7843220257517761,
                                ],
                                [
                                    0.010708034717104497,
                                    0.03569423040444771,
                                    0.220057310230054,
                                    0.7335404246483938,
                                ],
                                [
                                    0.010158605446892484,
                                    0.04706887978213961,
                                    0.1673540950716849,
                                    0.775418419699283,
                                ],
                                [
                                    0.01320612036933601,
                                    0.044021364859696085,
                                    0.21755922457782248,
                                    0.7252132901931454,
                                ],
                                [
                                    0.009021214230797044,
                                    0.014433824284536993,
                                    0.3755961132956237,
                                    0.6009488481890423,
                                ],
                                [
                                    0.20132987799400742,
                                    0.3221251605213266,
                                    0.18328744953241333,
                                    0.29325751195225264,
                                ],
                                [
                                    0.017619242607117235,
                                    0.02819055676003922,
                                    0.3669980849193035,
                                    0.58719211571354,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.026640456837914283,
                                    0.042624381044576214,
                                    0.3579768706885065,
                                    0.572758291429003,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.006405520400261612,
                                    0.004419699707218271,
                                    0.5853164341340024,
                                    0.4038583457585177,
                                ],
                                [
                                    0.46157855398361936,
                                    0.318481321176702,
                                    0.13014340055064466,
                                    0.08979672428903396,
                                ],
                                [
                                    0.0267560890241707,
                                    0.018461244588590112,
                                    0.5649658655100933,
                                    0.3898168008771459,
                                ],
                                [
                                    0.03478274002402132,
                                    0.010434593588739494,
                                    0.7344519150288202,
                                    0.220330751358419,
                                ],
                                [
                                    0.04810829109184882,
                                    0.033193899444100075,
                                    0.5436136634424152,
                                    0.3750841460216359,
                                ],
                                [
                                    0.06254046249196105,
                                    0.01876172804398785,
                                    0.7066941925608805,
                                    0.21200361690317066,
                                ],
                                [
                                    0.0016133366937802177,
                                    0.000587218633243017,
                                    0.7315364614358731,
                                    0.2662629832371037,
                                ],
                                [
                                    0.7003710213181528,
                                    0.2549194569782024,
                                    0.032778776811500585,
                                    0.011930744892144277,
                                ],
                                [
                                    0.03285445856008223,
                                    0.011958291363463555,
                                    0.7002953395695711,
                                    0.25489191050688315,
                                ],
                                [
                                    0.042710580372676187,
                                    0.0021021695508695974,
                                    0.9103793425966558,
                                    0.04480790747979848,
                                ],
                                [
                                    0.06563323537158279,
                                    0.023889036255607825,
                                    0.6675165627580705,
                                    0.24296116561473888,
                                ],
                                [
                                    0.08532277496919871,
                                    0.004199496657991903,
                                    0.8677671480001332,
                                    0.04271058037267617,
                                ],
                                [
                                    0.04061325326555385,
                                    0.8677671480001333,
                                    0.004096268438090991,
                                    0.08752333029622184,
                                ],
                                [
                                    0.04271058037267615,
                                    0.912579897923679,
                                    0.0019989413309686875,
                                    0.042710580372676124,
                                ],
                                [
                                    0.042518424104707006,
                                    0.9084741717575027,
                                    0.0021910975989378302,
                                    0.046816306538852485,
                                ],
                                [
                                    0.04461113592749125,
                                    0.9063814599347184,
                                    0.0022989411031768252,
                                    0.04670846303461349,
                                ],
                                [
                                    0.042616809880860626,
                                    0.9105763413083723,
                                    0.0020927118227842146,
                                    0.0447141369879829,
                                ],
                                [
                                    0.044714364147392154,
                                    0.9084787870418407,
                                    0.0021957128832759197,
                                    0.04461113592749119,
                                ],
                                [
                                    0.16124905812682114,
                                    0.5719007400028323,
                                    0.05869106671285747,
                                    0.2081591351574891,
                                ],
                                [
                                    0.21200361690317066,
                                    0.7519115261736411,
                                    0.00793650793650794,
                                    0.028148348986680196,
                                ],
                                [
                                    0.20735350459414445,
                                    0.7354190101768234,
                                    0.01258662024553418,
                                    0.0446408649834979,
                                ],
                                [
                                    0.21755922457782248,
                                    0.7252132901931454,
                                    0.013206120369336006,
                                    0.04402136485969607,
                                ],
                                [
                                    0.20973440485600056,
                                    0.7438633300224472,
                                    0.010205719983678056,
                                    0.036196545137874146,
                                ],
                                [
                                    0.220057310230054,
                                    0.7335404246483938,
                                    0.010708034717104496,
                                    0.035694230404447705,
                                ],
                                [
                                    0.22709510031642177,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.27400517734708985,
                                ],
                                [
                                    0.46536758105875475,
                                    0.5111773804259112,
                                    0.011177380425911203,
                                    0.012277658089422806,
                                ],
                                [
                                    0.44353715198371296,
                                    0.48719801013379666,
                                    0.03300780950095303,
                                    0.036257028381537396,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.4547145324096241,
                                    0.4994756682232194,
                                    0.02183042907504183,
                                    0.023979370292114586,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.16124905812682114,
                                    0.058691066712857495,
                                    0.5719007400028322,
                                    0.2081591351574892,
                                ],
                                [
                                    0.7252132901931454,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                ],
                                [
                                    0.6735431135507238,
                                    0.24515469591332736,
                                    0.05960668457892944,
                                    0.021695505957019315,
                                ],
                                [
                                    0.7066941925608805,
                                    0.21200361690317068,
                                    0.06254046249196094,
                                    0.01876172804398782,
                                ],
                                [
                                    0.6999987191194967,
                                    0.2547839472677427,
                                    0.03315107901015664,
                                    0.012066254602603986,
                                ],
                                [
                                    0.7344519150288203,
                                    0.22033075135841906,
                                    0.03478274002402117,
                                    0.01043459358873945,
                                ],
                                [
                                    0.040613253265553845,
                                    0.004096268438090994,
                                    0.8677671480001332,
                                    0.08752333029622192,
                                ],
                                [
                                    0.9063814599347184,
                                    0.09141798473825839,
                                    0.0019989413309686884,
                                    0.00020161399605452118,
                                ],
                                [
                                    0.827060124242764,
                                    0.08341760413004555,
                                    0.08132027702292317,
                                    0.008201994604267362,
                                ],
                                [
                                    0.8677671480001333,
                                    0.04271058037267617,
                                    0.08532277496919864,
                                    0.004199496657991899,
                                ],
                                [
                                    0.8676733775083177,
                                    0.08751387256813654,
                                    0.04070702375736935,
                                    0.00410572616617637,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979848,
                                    0.042710580372676124,
                                    0.0021021695508695944,
                                ],
                                [
                                    0.03277877681150057,
                                    0.7003710213181529,
                                    0.011930744892144267,
                                    0.25491945697820234,
                                ],
                                [
                                    0.03487610391862287,
                                    0.7451837712416985,
                                    0.009833417785021965,
                                    0.2101067070546566,
                                ],
                                [
                                    0.03431643175669914,
                                    0.733225479878235,
                                    0.0103930899469457,
                                    0.2220649984181201,
                                ],
                                [
                                    0.03600545019906099,
                                    0.7315364614358733,
                                    0.010904626831607084,
                                    0.22155346153345873,
                                ],
                                [
                                    0.034414817532852755,
                                    0.7353276494291046,
                                    0.010294704170792085,
                                    0.21996282886725052,
                                ],
                                [
                                    0.03610867841896189,
                                    0.7336337885429954,
                                    0.010801398611706177,
                                    0.21945613442633644,
                                ],
                                [
                                    0.1301434005506447,
                                    0.46157855398361947,
                                    0.08979672428903393,
                                    0.3184813211767019,
                                ],
                                [
                                    0.18089795932699423,
                                    0.6415893401544284,
                                    0.0390421655126844,
                                    0.13847053500589301,
                                ],
                                [
                                    0.16735409507168497,
                                    0.5935534255259082,
                                    0.05258602976799365,
                                    0.18650644963441318,
                                ],
                                [
                                    0.1755910864635907,
                                    0.5853164341340025,
                                    0.0551742584835678,
                                    0.18391822091883903,
                                ],
                                [
                                    0.16973499533354108,
                                    0.601997745371532,
                                    0.05020512950613752,
                                    0.17806212978878944,
                                ],
                                [
                                    0.1780891721158222,
                                    0.5936435685892508,
                                    0.05267617283133629,
                                    0.17559108646359065,
                                ],
                                [
                                    0.18328744953241333,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.3221251605213266,
                                ],
                                [
                                    0.4215599302747463,
                                    0.46305739725167444,
                                    0.05498503120991964,
                                    0.06039764126365958,
                                ],
                                [
                                    0.35797687068850653,
                                    0.393215355902741,
                                    0.11856809079615946,
                                    0.13023968261259306,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.3691542511144177,
                                    0.40549301399216375,
                                    0.10739071037024826,
                                    0.11796202452317024,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.1301434005506447,
                                    0.0473692999679328,
                                    0.6030063975790086,
                                    0.2194809019024139,
                                ],
                                [
                                    0.694107632616969,
                                    0.25263972295445003,
                                    0.0390421655126844,
                                    0.014210478915896644,
                                ],
                                [
                                    0.5436136634424152,
                                    0.19786326914248648,
                                    0.189536134687238,
                                    0.0689869327278602,
                                ],
                                [
                                    0.5703697524665859,
                                    0.17110718011831585,
                                    0.19886490258625558,
                                    0.059658164828842654,
                                ],
                                [
                                    0.5700692690111882,
                                    0.20749252049690184,
                                    0.16308052911846518,
                                    0.05935768137344487,
                                ],
                                [
                                    0.5981274749345258,
                                    0.17943431457356424,
                                    0.1711071801183158,
                                    0.05133103037359428,
                                ],
                                [
                                    0.0327787768115006,
                                    0.0033060801116875952,
                                    0.8756016244541865,
                                    0.08831351862262532,
                                ],
                                [
                                    0.8985469834806651,
                                    0.09062779641185499,
                                    0.00983341778502197,
                                    0.0009918023224579236,
                                ],
                                [
                                    0.6675165627580706,
                                    0.06732597878949019,
                                    0.24086383850761647,
                                    0.02429361994482273,
                                ],
                                [
                                    0.7003710213181528,
                                    0.034471520229407984,
                                    0.2527189016511791,
                                    0.012438556801260093,
                                ],
                                [
                                    0.7081298160236245,
                                    0.07142224722758118,
                                    0.20025058524206263,
                                    0.020197351506731735,
                                ],
                                [
                                    0.7429832159146753,
                                    0.036568847336530284,
                                    0.2101067070546566,
                                    0.010341229694137788,
                                ],
                                [
                                    0.021306097298261266,
                                    0.4552388641864047,
                                    0.023403424405383573,
                                    0.5000516141099505,
                                ],
                                [
                                    0.023403424405383573,
                                    0.5000516141099505,
                                    0.021306097298261266,
                                    0.4552388641864047,
                                ],
                                [
                                    0.02230556796374561,
                                    0.4765941543727428,
                                    0.02240395373989923,
                                    0.4786963239236124,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.02240395373989923,
                                    0.4786963239236124,
                                    0.02230556796374561,
                                    0.4765941543727428,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.08459278303166456,
                                    0.3000245444947563,
                                    0.13534734180801405,
                                    0.4800353306655651,
                                ],
                                [
                                    0.13534734180801408,
                                    0.4800353306655652,
                                    0.08459278303166454,
                                    0.3000245444947562,
                                ],
                                [
                                    0.10877961228891125,
                                    0.3858077776573488,
                                    0.11116051255076737,
                                    0.3942520975029726,
                                ],
                                [
                                    0.1141336296474635,
                                    0.3804537602987966,
                                    0.116631715299695,
                                    0.3887808947540449,
                                ],
                                [
                                    0.11116051255076737,
                                    0.3942520975029726,
                                    0.10877961228891125,
                                    0.3858077776573488,
                                ],
                                [
                                    0.116631715299695,
                                    0.3887808947540449,
                                    0.1141336296474635,
                                    0.3804537602987966,
                                ],
                                [
                                    0.11913624037116649,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.3925912788865005,
                                ],
                                [
                                    0.3574087211134995,
                                    0.3925912788865005,
                                    0.11913624037116649,
                                    0.1308637596288335,
                                ],
                                [
                                    0.23268379052937738,
                                    0.2555886902129556,
                                    0.2438611709552886,
                                    0.26786634830237843,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.2438611709552886,
                                    0.26786634830237843,
                                    0.23268379052937738,
                                    0.2555886902129556,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.08459278303166454,
                                    0.030789889441914717,
                                    0.6485570150979888,
                                    0.23606031242843198,
                                ],
                                [
                                    0.6485570150979888,
                                    0.23606031242843198,
                                    0.08459278303166454,
                                    0.030789889441914717,
                                ],
                                [
                                    0.35334709628044025,
                                    0.12861047525796568,
                                    0.37980270184921305,
                                    0.13823972661238101,
                                ],
                                [
                                    0.37073846629245083,
                                    0.11121910524595506,
                                    0.39849618876039067,
                                    0.11954623970120344,
                                ],
                                [
                                    0.37980270184921305,
                                    0.13823972661238101,
                                    0.35334709628044025,
                                    0.12861047525796568,
                                ],
                                [
                                    0.39849618876039067,
                                    0.11954623970120344,
                                    0.37073846629245083,
                                    0.11121910524595506,
                                ],
                                [
                                    0.021306097298261276,
                                    0.0021489412170727588,
                                    0.8870743039674258,
                                    0.08947065751724015,
                                ],
                                [
                                    0.8870743039674258,
                                    0.08947065751724015,
                                    0.021306097298261276,
                                    0.0021489412170727588,
                                ],
                                [
                                    0.4338835740000666,
                                    0.04376166514811096,
                                    0.4744968272656205,
                                    0.04785793358620195,
                                ],
                                [
                                    0.4552388641864047,
                                    0.022406374961772883,
                                    0.49785105878292724,
                                    0.02450370206889519,
                                ],
                                [
                                    0.4744968272656205,
                                    0.04785793358620195,
                                    0.4338835740000666,
                                    0.04376166514811096,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889519,
                                    0.4552388641864047,
                                    0.022406374961772883,
                                ],
                                [
                                    0.009833417785021966,
                                    0.21010670705465664,
                                    0.03487610391862287,
                                    0.7451837712416985,
                                ],
                                [
                                    0.011930744892144272,
                                    0.2549194569782024,
                                    0.032778776811500564,
                                    0.7003710213181528,
                                ],
                                [
                                    0.010294704170792085,
                                    0.21996282886725055,
                                    0.034414817532852755,
                                    0.7353276494291046,
                                ],
                                [
                                    0.010801398611706179,
                                    0.21945613442633646,
                                    0.03610867841896189,
                                    0.7336337885429954,
                                ],
                                [
                                    0.010393089946945702,
                                    0.22206499841812016,
                                    0.034316431756699135,
                                    0.7332254798782349,
                                ],
                                [
                                    0.010904626831607086,
                                    0.22155346153345878,
                                    0.036005450199060984,
                                    0.7315364614358731,
                                ],
                                [
                                    0.03904216551268441,
                                    0.13847053500589307,
                                    0.1808979593269942,
                                    0.6415893401544284,
                                ],
                                [
                                    0.08979672428903396,
                                    0.318481321176702,
                                    0.13014340055064466,
                                    0.46157855398361936,
                                ],
                                [
                                    0.05020512950613753,
                                    0.17806212978878944,
                                    0.16973499533354108,
                                    0.601997745371532,
                                ],
                                [
                                    0.0526761728313363,
                                    0.17559108646359067,
                                    0.1780891721158222,
                                    0.5936435685892508,
                                ],
                                [
                                    0.052586029767993654,
                                    0.1865064496344132,
                                    0.16735409507168497,
                                    0.5935534255259082,
                                ],
                                [
                                    0.05517425848356781,
                                    0.18391822091883905,
                                    0.1755910864635907,
                                    0.5853164341340025,
                                ],
                                [
                                    0.054985031209919655,
                                    0.060397641263659596,
                                    0.4215599302747463,
                                    0.46305739725167444,
                                ],
                                [
                                    0.29325751195225264,
                                    0.3221251605213266,
                                    0.18328744953241333,
                                    0.20132987799400742,
                                ],
                                [
                                    0.10739071037024829,
                                    0.11796202452317027,
                                    0.3691542511144177,
                                    0.40549301399216375,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.1185680907961595,
                                    0.13023968261259308,
                                    0.3579768706885065,
                                    0.3932153559027409,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.039042165512684385,
                                    0.014210478915896638,
                                    0.694107632616969,
                                    0.25263972295445003,
                                ],
                                [
                                    0.6030063975790086,
                                    0.2194809019024139,
                                    0.13014340055064466,
                                    0.04736929996793279,
                                ],
                                [
                                    0.16308052911846535,
                                    0.05935768137344492,
                                    0.5700692690111879,
                                    0.20749252049690178,
                                ],
                                [
                                    0.17110718011831594,
                                    0.05133103037359432,
                                    0.5981274749345256,
                                    0.17943431457356418,
                                ],
                                [
                                    0.1895361346872381,
                                    0.06898693272786025,
                                    0.5436136634424152,
                                    0.19786326914248645,
                                ],
                                [
                                    0.19886490258625567,
                                    0.05965816482884268,
                                    0.5703697524665858,
                                    0.17110718011831583,
                                ],
                                [
                                    0.00983341778502196,
                                    0.0009918023224579225,
                                    0.8985469834806651,
                                    0.09062779641185499,
                                ],
                                [
                                    0.8756016244541865,
                                    0.08831351862262532,
                                    0.032778776811500585,
                                    0.003306080111687594,
                                ],
                                [
                                    0.20025058524206274,
                                    0.020197351506731746,
                                    0.7081298160236243,
                                    0.07142224722758117,
                                ],
                                [
                                    0.2101067070546567,
                                    0.010341229694137793,
                                    0.7429832159146752,
                                    0.036568847336530284,
                                ],
                                [
                                    0.24086383850761658,
                                    0.02429361994482274,
                                    0.6675165627580705,
                                    0.06732597878949018,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260098,
                                    0.7003710213181527,
                                    0.03447152022940798,
                                ],
                                [
                                    0.001998941330968689,
                                    0.04271058037267615,
                                    0.04271058037267615,
                                    0.912579897923679,
                                ],
                                [
                                    0.004096268438090994,
                                    0.08752333029622192,
                                    0.040613253265553845,
                                    0.8677671480001332,
                                ],
                                [
                                    0.002092711822784216,
                                    0.04471413698798292,
                                    0.042616809880860626,
                                    0.9105763413083723,
                                ],
                                [
                                    0.0021957128832759206,
                                    0.04461113592749121,
                                    0.044714364147392154,
                                    0.9084787870418407,
                                ],
                                [
                                    0.0021910975989378324,
                                    0.046816306538852534,
                                    0.042518424104707006,
                                    0.9084741717575027,
                                ],
                                [
                                    0.0022989411031768274,
                                    0.04670846303461354,
                                    0.04461113592749125,
                                    0.9063814599347184,
                                ],
                                [
                                    0.007936507936507952,
                                    0.028148348986680238,
                                    0.21200361690317066,
                                    0.7519115261736411,
                                ],
                                [
                                    0.058691066712857495,
                                    0.2081591351574892,
                                    0.16124905812682114,
                                    0.5719007400028322,
                                ],
                                [
                                    0.010205719983678058,
                                    0.03619654513787415,
                                    0.20973440485600056,
                                    0.7438633300224472,
                                ],
                                [
                                    0.010708034717104497,
                                    0.03569423040444771,
                                    0.220057310230054,
                                    0.7335404246483938,
                                ],
                                [
                                    0.012586620245534183,
                                    0.04464086498349791,
                                    0.20735350459414445,
                                    0.7354190101768234,
                                ],
                                [
                                    0.01320612036933601,
                                    0.044021364859696085,
                                    0.21755922457782248,
                                    0.7252132901931454,
                                ],
                                [
                                    0.011177380425911215,
                                    0.012277658089422822,
                                    0.46536758105875475,
                                    0.5111773804259112,
                                ],
                                [
                                    0.2494498611682442,
                                    0.27400517734708985,
                                    0.22709510031642177,
                                    0.2494498611682442,
                                ],
                                [
                                    0.02183042907504185,
                                    0.023979370292114607,
                                    0.4547145324096241,
                                    0.4994756682232194,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.03300780950095306,
                                    0.03625702838153743,
                                    0.4435371519837129,
                                    0.4871980101337966,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                    0.7252132901931454,
                                    0.2639614896993748,
                                ],
                                [
                                    0.5719007400028322,
                                    0.2081591351574892,
                                    0.16124905812682114,
                                    0.058691066712857495,
                                ],
                                [
                                    0.03315107901015678,
                                    0.012066254602604036,
                                    0.6999987191194965,
                                    0.25478394726774267,
                                ],
                                [
                                    0.03478274002402132,
                                    0.010434593588739494,
                                    0.7344519150288202,
                                    0.220330751358419,
                                ],
                                [
                                    0.05960668457892954,
                                    0.021695505957019353,
                                    0.6735431135507237,
                                    0.24515469591332734,
                                ],
                                [
                                    0.06254046249196105,
                                    0.01876172804398785,
                                    0.7066941925608805,
                                    0.21200361690317066,
                                ],
                                [
                                    0.0019989413309687114,
                                    0.00020161399605452348,
                                    0.9063814599347184,
                                    0.09141798473825839,
                                ],
                                [
                                    0.8677671480001332,
                                    0.08752333029622192,
                                    0.040613253265553866,
                                    0.004096268438090996,
                                ],
                                [
                                    0.040707023757369405,
                                    0.004105726166176376,
                                    0.8676733775083176,
                                    0.08751387256813653,
                                ],
                                [
                                    0.042710580372676187,
                                    0.0021021695508695974,
                                    0.9103793425966558,
                                    0.04480790747979848,
                                ],
                                [
                                    0.08132027702292324,
                                    0.008201994604267371,
                                    0.8270601242427639,
                                    0.08341760413004554,
                                ],
                                [
                                    0.08532277496919871,
                                    0.004199496657991903,
                                    0.8677671480001332,
                                    0.04271058037267617,
                                ],
                                [
                                    0.0019989413309687114,
                                    0.9063814599347185,
                                    0.00020161399605452332,
                                    0.09141798473825831,
                                ],
                                [
                                    0.0021021695508696182,
                                    0.9531883087454855,
                                    9.838577615361652e-05,
                                    0.04461113592749119,
                                ],
                                [
                                    0.002074623079550345,
                                    0.9406978916914176,
                                    0.00012593224747289,
                                    0.05710155298155919,
                                ],
                                [
                                    0.04422553129030276,
                                    0.8985469834806652,
                                    0.002684545740365314,
                                    0.054542939488666765,
                                ],
                                [
                                    0.0020984445753240584,
                                    0.9514992903031237,
                                    0.00010211075169917615,
                                    0.046300154369853026,
                                ],
                                [
                                    0.044733343199418574,
                                    0.9088643916790292,
                                    0.0021767338312494965,
                                    0.04422553129030271,
                                ],
                                [
                                    0.007936507936507941,
                                    0.7252132901931455,
                                    0.0028887121709719418,
                                    0.26396148969937466,
                                ],
                                [
                                    0.010434593588739452,
                                    0.9534805494880724,
                                    0.00039062651874043086,
                                    0.035694230404447705,
                                ],
                                [
                                    0.009767978928152057,
                                    0.8925673852648304,
                                    0.001057241179327826,
                                    0.0966073946276897,
                                ],
                                [
                                    0.2082277315760135,
                                    0.694107632616969,
                                    0.02253761337114501,
                                    0.07512702243587252,
                                ],
                                [
                                    0.010344450525396807,
                                    0.9452435580961667,
                                    0.0004807695820830741,
                                    0.043931221796353434,
                                ],
                                [
                                    0.22051659643692337,
                                    0.7350714121846401,
                                    0.01024874851023513,
                                    0.034163242868201375,
                                ],
                                [
                                    0.011177380425911215,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.5111773804259112,
                                ],
                                [
                                    0.022904899683578235,
                                    0.9536400618010877,
                                    0.0005501388317558024,
                                    0.022904899683578207,
                                ],
                                [
                                    0.019775408802231415,
                                    0.8233444517472613,
                                    0.003679629713102623,
                                    0.15320050973740468,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.022481713829101385,
                                    0.9360208191939705,
                                    0.0009733246862326504,
                                    0.040524142290695425,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.007936507936507952,
                                    0.21200361690317066,
                                    0.028148348986680238,
                                    0.7519115261736411,
                                ],
                                [
                                    0.03569423040444776,
                                    0.9534805494880724,
                                    0.00039062651874043145,
                                    0.010434593588739452,
                                ],
                                [
                                    0.028287076560416964,
                                    0.755617280345586,
                                    0.0077977803627712235,
                                    0.2082978627312258,
                                ],
                                [
                                    0.6030063975790086,
                                    0.1808979593269942,
                                    0.16622825747383277,
                                    0.049867385620164274,
                                ],
                                [
                                    0.03469259696067859,
                                    0.9267244604639018,
                                    0.0013922599625096042,
                                    0.037190682612910045,
                                ],
                                [
                                    0.739555318529915,
                                    0.2218617388946654,
                                    0.02967933652292653,
                                    0.008903606052493124,
                                ],
                                [
                                    0.001998941330968689,
                                    0.04271058037267615,
                                    0.04271058037267615,
                                    0.912579897923679,
                                ],
                                [
                                    0.04461113592749122,
                                    0.9531883087454855,
                                    9.838577615361546e-05,
                                    0.002102169550869594,
                                ],
                                [
                                    0.03324006319727069,
                                    0.7102271431307468,
                                    0.011469458506374146,
                                    0.24506333516560835,
                                ],
                                [
                                    0.7085911024093945,
                                    0.03487610391862289,
                                    0.24449882055993732,
                                    0.012033973112045179,
                                ],
                                [
                                    0.043073480982292654,
                                    0.9203338501854034,
                                    0.0016360407213521818,
                                    0.03495662811095177,
                                ],
                                [
                                    0.9182138190507091,
                                    0.04519351211698697,
                                    0.03487610391862285,
                                    0.0017165649136811055,
                                ],
                                [
                                    0.001613336693780218,
                                    0.7315364614358733,
                                    0.0005872186332430168,
                                    0.26626298323710357,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.7783433102466403,
                                    0.00048399041334210995,
                                    0.21945613442633646,
                                ],
                                [
                                    0.0016744190978230753,
                                    0.7592331014997701,
                                    0.0005261362292001594,
                                    0.23856634317320666,
                                ],
                                [
                                    0.035694230404447747,
                                    0.7252132901931454,
                                    0.011215846626220324,
                                    0.2278766327761865,
                                ],
                                [
                                    0.0016982405935967893,
                                    0.7700345001114762,
                                    0.0005023147334264455,
                                    0.2277649445615005,
                                ],
                                [
                                    0.03620204231356357,
                                    0.7355306983915094,
                                    0.010708034717104506,
                                    0.21755922457782245,
                                ],
                                [
                                    0.0064055204002616125,
                                    0.5853164341340025,
                                    0.00441969970721827,
                                    0.4038583457585176,
                                ],
                                [
                                    0.008903606052493124,
                                    0.8135836934289296,
                                    0.0019216140549867587,
                                    0.17559108646359065,
                                ],
                                [
                                    0.007883692524994044,
                                    0.7203871829601763,
                                    0.0029415275824858384,
                                    0.2687875969323438,
                                ],
                                [
                                    0.16805967979630446,
                                    0.5602111956888659,
                                    0.06270566515085405,
                                    0.20902345936397557,
                                ],
                                [
                                    0.008460164122238796,
                                    0.7730633557915126,
                                    0.0023650559852410862,
                                    0.21611142410100748,
                                ],
                                [
                                    0.18034854465721437,
                                    0.6011749752565371,
                                    0.05041680028994416,
                                    0.1680596797963044,
                                ],
                                [
                                    0.009021214230797044,
                                    0.3755961132956237,
                                    0.014433824284536993,
                                    0.6009488481890423,
                                ],
                                [
                                    0.020748733488464063,
                                    0.8638685940379567,
                                    0.0027063050268699733,
                                    0.11267636744670925,
                                ],
                                [
                                    0.015960644847781997,
                                    0.6645176599457708,
                                    0.007494393667552041,
                                    0.3120273015388951,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.01866694987465197,
                                    0.7771940273924801,
                                    0.0047880886406820675,
                                    0.19935093409218588,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.006405520400261623,
                                    0.17110718011831585,
                                    0.029679336522926567,
                                    0.792807962958496,
                                ],
                                [
                                    0.03416324286820143,
                                    0.9125841127032176,
                                    0.0019216140549867615,
                                    0.05133103037359428,
                                ],
                                [
                                    0.022830374192410623,
                                    0.6098553599095247,
                                    0.013254482730777568,
                                    0.35405978316728715,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317931,
                                    0.2825508626240855,
                                    0.0847634032739792,
                                ],
                                [
                                    0.029235894592672243,
                                    0.7809625400278404,
                                    0.006848962330515949,
                                    0.18295260304897135,
                                ],
                                [
                                    0.6232327133796622,
                                    0.18696572124085045,
                                    0.14600194167317926,
                                    0.04379962370630804,
                                ],
                                [
                                    0.0016133366937802012,
                                    0.03447152022940799,
                                    0.04309618500986464,
                                    0.9208189580669471,
                                ],
                                [
                                    0.04422553129030273,
                                    0.9449492486022174,
                                    0.0004839904133421048,
                                    0.010341229694137788,
                                ],
                                [
                                    0.02682790776742892,
                                    0.5732211812220835,
                                    0.01788161393621592,
                                    0.3820692970742716,
                                ],
                                [
                                    0.5719007400028322,
                                    0.02814834898668023,
                                    0.3811891829664997,
                                    0.018761728043987843,
                                ],
                                [
                                    0.036661325552450885,
                                    0.7833278882767402,
                                    0.008048196151193952,
                                    0.17196259001961497,
                                ],
                                [
                                    0.7815234566441468,
                                    0.03846575718504431,
                                    0.17156646632518516,
                                    0.008444319845623766,
                                ],
                                [
                                    0.001048663553561164,
                                    0.4754962979311048,
                                    0.0011518917734620708,
                                    0.522303146741872,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.522303146741872,
                                    0.001048663553561164,
                                    0.4754962979311048,
                                ],
                                [
                                    0.0010883669156247604,
                                    0.4934990230306353,
                                    0.0011121884113984744,
                                    0.5043004216423415,
                                ],
                                [
                                    0.023201132560776126,
                                    0.47138625738548395,
                                    0.023708944469891947,
                                    0.481703665583848,
                                ],
                                [
                                    0.0011121884113984744,
                                    0.5043004216423415,
                                    0.0010883669156247604,
                                    0.4934990230306353,
                                ],
                                [
                                    0.023708944469891947,
                                    0.481703665583848,
                                    0.023201132560776126,
                                    0.47138625738548395,
                                ],
                                [
                                    0.004163567227624187,
                                    0.3804537602987967,
                                    0.006661652879855696,
                                    0.6087210195937235,
                                ],
                                [
                                    0.006661652879855697,
                                    0.6087210195937236,
                                    0.004163567227624186,
                                    0.3804537602987966,
                                ],
                                [
                                    0.005124374255117565,
                                    0.4682493035305919,
                                    0.005700845852362317,
                                    0.5209254763619282,
                                ],
                                [
                                    0.10923824004312431,
                                    0.36413543774258517,
                                    0.12152710490403419,
                                    0.40509921731025633,
                                ],
                                [
                                    0.005700845852362317,
                                    0.5209254763619282,
                                    0.005124374255117565,
                                    0.4682493035305919,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.005863759628833509,
                                    0.2441362403711665,
                                    0.017591278886500528,
                                    0.7324087211134995,
                                ],
                                [
                                    0.017591278886500528,
                                    0.7324087211134995,
                                    0.005863759628833509,
                                    0.2441362403711665,
                                ],
                                [
                                    0.010374366744232033,
                                    0.4319342970189784,
                                    0.013080671771102004,
                                    0.5446106644656875,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.013080671771102007,
                                    0.5446106644656876,
                                    0.010374366744232031,
                                    0.43193429701897834,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.004163567227624192,
                                    0.11121910524595506,
                                    0.031921289695564,
                                    0.8526960378308568,
                                ],
                                [
                                    0.031921289695564,
                                    0.8526960378308568,
                                    0.004163567227624192,
                                    0.11121910524595506,
                                ],
                                [
                                    0.014839668261463284,
                                    0.396403981479248,
                                    0.021245188661724906,
                                    0.5675111615975639,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974367,
                                    0.4528917880018739,
                                    0.13586456225741483,
                                ],
                                [
                                    0.021245188661724906,
                                    0.5675111615975639,
                                    0.014839668261463285,
                                    0.39640398147924805,
                                ],
                                [
                                    0.4528917880018739,
                                    0.13586456225741483,
                                    0.31634286705096765,
                                    0.09490078268974368,
                                ],
                                [
                                    0.0010486635535611527,
                                    0.022406374961772883,
                                    0.043660858150083685,
                                    0.9328841033345823,
                                ],
                                [
                                    0.043660858150083685,
                                    0.9328841033345823,
                                    0.0010486635535611527,
                                    0.022406374961772883,
                                ],
                                [
                                    0.017438051959311442,
                                    0.3725918856208494,
                                    0.027271469744333397,
                                    0.5826985926755058,
                                ],
                                [
                                    0.3717336031640088,
                                    0.018296334416152003,
                                    0.5813563198053231,
                                    0.02861374261451607,
                                ],
                                [
                                    0.027271469744333404,
                                    0.5826985926755059,
                                    0.017438051959311435,
                                    0.3725918856208493,
                                ],
                                [
                                    0.5813563198053232,
                                    0.028613742614516074,
                                    0.3717336031640087,
                                    0.018296334416152,
                                ],
                                [
                                    0.00048399041334211006,
                                    0.21945613442633652,
                                    0.0017165649136811247,
                                    0.7783433102466403,
                                ],
                                [
                                    0.000587218633243017,
                                    0.2662629832371037,
                                    0.0016133366937802177,
                                    0.7315364614358731,
                                ],
                                [
                                    0.0005023147334264456,
                                    0.22776494456150054,
                                    0.0016982405935967893,
                                    0.7700345001114762,
                                ],
                                [
                                    0.010708034717104508,
                                    0.21755922457782245,
                                    0.03620204231356357,
                                    0.7355306983915094,
                                ],
                                [
                                    0.0005261362292001595,
                                    0.23856634317320669,
                                    0.0016744190978230753,
                                    0.7592331014997701,
                                ],
                                [
                                    0.011215846626220325,
                                    0.22787663277618653,
                                    0.035694230404447747,
                                    0.7252132901931454,
                                ],
                                [
                                    0.0019216140549867596,
                                    0.17559108646359073,
                                    0.008903606052493122,
                                    0.8135836934289294,
                                ],
                                [
                                    0.004419699707218271,
                                    0.4038583457585177,
                                    0.006405520400261612,
                                    0.5853164341340024,
                                ],
                                [
                                    0.002365055985241087,
                                    0.21611142410100756,
                                    0.008460164122238796,
                                    0.7730633557915125,
                                ],
                                [
                                    0.05041680028994418,
                                    0.16805967979630448,
                                    0.18034854465721434,
                                    0.6011749752565371,
                                ],
                                [
                                    0.002941527582485839,
                                    0.26878759693234383,
                                    0.007883692524994044,
                                    0.7203871829601763,
                                ],
                                [
                                    0.06270566515085405,
                                    0.20902345936397562,
                                    0.16805967979630446,
                                    0.5602111956888659,
                                ],
                                [
                                    0.0027063050268699737,
                                    0.11267636744670928,
                                    0.020748733488464063,
                                    0.8638685940379567,
                                ],
                                [
                                    0.014433824284536993,
                                    0.6009488481890423,
                                    0.009021214230797044,
                                    0.3755961132956237,
                                ],
                                [
                                    0.004788088640682069,
                                    0.19935093409218593,
                                    0.018666949874651968,
                                    0.77719402739248,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.007494393667552043,
                                    0.3120273015388952,
                                    0.015960644847781993,
                                    0.6645176599457707,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.001921614054986761,
                                    0.05133103037359426,
                                    0.03416324286820143,
                                    0.9125841127032176,
                                ],
                                [
                                    0.029679336522926567,
                                    0.792807962958496,
                                    0.006405520400261622,
                                    0.17110718011831583,
                                ],
                                [
                                    0.00684896233051595,
                                    0.18295260304897137,
                                    0.029235894592672243,
                                    0.7809625400278404,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630805,
                                    0.6232327133796622,
                                    0.18696572124085045,
                                ],
                                [
                                    0.013254482730777568,
                                    0.35405978316728715,
                                    0.022830374192410623,
                                    0.6098553599095247,
                                ],
                                [
                                    0.2825508626240855,
                                    0.0847634032739792,
                                    0.486683792428756,
                                    0.14600194167317931,
                                ],
                                [
                                    0.0004839904133421043,
                                    0.010341229694137779,
                                    0.04422553129030273,
                                    0.9449492486022174,
                                ],
                                [
                                    0.04309618500986464,
                                    0.9208189580669471,
                                    0.0016133366937802005,
                                    0.03447152022940798,
                                ],
                                [
                                    0.00804819615119396,
                                    0.17196259001961517,
                                    0.03666132555245088,
                                    0.78332788827674,
                                ],
                                [
                                    0.17156646632518535,
                                    0.008444319845623775,
                                    0.7815234566441466,
                                    0.038465757185044296,
                                ],
                                [
                                    0.017881613936215922,
                                    0.38206929707427173,
                                    0.026827907767428917,
                                    0.5732211812220834,
                                ],
                                [
                                    0.3811891829664998,
                                    0.018761728043987846,
                                    0.5719007400028322,
                                    0.028148348986680227,
                                ],
                                [
                                    9.838577615361658e-05,
                                    0.04461113592749122,
                                    0.0021021695508696182,
                                    0.9531883087454855,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.09141798473825839,
                                    0.0019989413309687114,
                                    0.9063814599347184,
                                ],
                                [
                                    0.00010211075169917617,
                                    0.04630015436985303,
                                    0.0020984445753240584,
                                    0.9514992903031237,
                                ],
                                [
                                    0.0021767338312494965,
                                    0.04422553129030271,
                                    0.044733343199418574,
                                    0.9088643916790292,
                                ],
                                [
                                    0.00012593224747289007,
                                    0.0571015529815592,
                                    0.002074623079550345,
                                    0.9406978916914176,
                                ],
                                [
                                    0.002684545740365315,
                                    0.05454293948866678,
                                    0.04422553129030276,
                                    0.8985469834806652,
                                ],
                                [
                                    0.00039062651874043145,
                                    0.03569423040444776,
                                    0.010434593588739452,
                                    0.9534805494880724,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.7252132901931454,
                                ],
                                [
                                    0.0004807695820830745,
                                    0.04393122179635347,
                                    0.010344450525396807,
                                    0.9452435580961667,
                                ],
                                [
                                    0.010248748510235139,
                                    0.0341632428682014,
                                    0.22051659643692337,
                                    0.7350714121846401,
                                ],
                                [
                                    0.0010572411793278262,
                                    0.09660739462768973,
                                    0.009767978928152057,
                                    0.8925673852648304,
                                ],
                                [
                                    0.022537613371145016,
                                    0.07512702243587255,
                                    0.2082277315760135,
                                    0.694107632616969,
                                ],
                                [
                                    0.000550138831755803,
                                    0.022904899683578235,
                                    0.022904899683578235,
                                    0.9536400618010877,
                                ],
                                [
                                    0.012277658089422822,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.46536758105875475,
                                ],
                                [
                                    0.0009733246862326517,
                                    0.04052414229069548,
                                    0.022481713829101385,
                                    0.9360208191939705,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.0036796297131026254,
                                    0.15320050973740476,
                                    0.01977540880223141,
                                    0.8233444517472612,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.00039062651874043145,
                                    0.010434593588739452,
                                    0.03569423040444776,
                                    0.9534805494880724,
                                ],
                                [
                                    0.028148348986680238,
                                    0.7519115261736411,
                                    0.007936507936507952,
                                    0.21200361690317066,
                                ],
                                [
                                    0.0013922599625096068,
                                    0.037190682612910114,
                                    0.034692596960678584,
                                    0.9267244604639017,
                                ],
                                [
                                    0.02967933652292658,
                                    0.00890360605249314,
                                    0.739555318529915,
                                    0.22186173889466537,
                                ],
                                [
                                    0.007797780362771225,
                                    0.20829786273122586,
                                    0.028287076560416964,
                                    0.755617280345586,
                                ],
                                [
                                    0.1662282574738328,
                                    0.04986738562016429,
                                    0.6030063975790086,
                                    0.1808979593269942,
                                ],
                                [
                                    9.838577615361658e-05,
                                    0.0021021695508696182,
                                    0.04461113592749122,
                                    0.9531883087454855,
                                ],
                                [
                                    0.04271058037267615,
                                    0.912579897923679,
                                    0.0019989413309686897,
                                    0.04271058037267617,
                                ],
                                [
                                    0.0016360407213521812,
                                    0.03495662811095176,
                                    0.043073480982292654,
                                    0.9203338501854034,
                                ],
                                [
                                    0.034876103918622836,
                                    0.0017165649136811048,
                                    0.9182138190507091,
                                    0.04519351211698697,
                                ],
                                [
                                    0.011469458506374148,
                                    0.2450633351656084,
                                    0.03324006319727069,
                                    0.7102271431307468,
                                ],
                                [
                                    0.24449882055993738,
                                    0.012033973112045182,
                                    0.7085911024093945,
                                    0.03487610391862289,
                                ],
                                [
                                    0.009833417785021961,
                                    0.8985469834806652,
                                    0.0009918023224579217,
                                    0.09062779641185491,
                                ],
                                [
                                    0.010341229694137779,
                                    0.9449492486022174,
                                    0.00048399041334210404,
                                    0.044225531290302704,
                                ],
                                [
                                    0.010205719983678056,
                                    0.9325667947872899,
                                    0.000619500123801826,
                                    0.056607985105230255,
                                ],
                                [
                                    0.04422553129030276,
                                    0.8985469834806652,
                                    0.002684545740365314,
                                    0.054542939488666765,
                                ],
                                [
                                    0.010322905374053443,
                                    0.9432748295043943,
                                    0.0005023147334264394,
                                    0.04589995038812576,
                                ],
                                [
                                    0.044733343199418574,
                                    0.9088643916790292,
                                    0.0021767338312494965,
                                    0.04422553129030271,
                                ],
                                [
                                    0.039042165512684385,
                                    0.6941076326169691,
                                    0.014210478915896631,
                                    0.25263972295445,
                                ],
                                [
                                    0.05133103037359426,
                                    0.9125841127032176,
                                    0.0019216140549867579,
                                    0.034163242868201375,
                                ],
                                [
                                    0.048051744304703055,
                                    0.8542836198882794,
                                    0.0052009001238779665,
                                    0.09246373568313956,
                                ],
                                [
                                    0.2082277315760135,
                                    0.694107632616969,
                                    0.02253761337114501,
                                    0.07512702243587252,
                                ],
                                [
                                    0.05088758844333993,
                                    0.9047004201782235,
                                    0.0023650559852410854,
                                    0.04204693539319542,
                                ],
                                [
                                    0.22051659643692337,
                                    0.7350714121846401,
                                    0.01024874851023513,
                                    0.034163242868201375,
                                ],
                                [
                                    0.054985031209919655,
                                    0.4215599302747463,
                                    0.060397641263659596,
                                    0.46305739725167444,
                                ],
                                [
                                    0.11267636744670928,
                                    0.8638685940379567,
                                    0.0027063050268699707,
                                    0.02074873348846404,
                                ],
                                [
                                    0.09728142272575194,
                                    0.7458384378237408,
                                    0.018101249747827324,
                                    0.13877888970268,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.11059458383289718,
                                    0.8479079491901746,
                                    0.004788088640682063,
                                    0.03670937833624601,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.03904216551268439,
                                    0.18089795932699423,
                                    0.138470535005893,
                                    0.6415893401544284,
                                ],
                                [
                                    0.17559108646359062,
                                    0.8135836934289296,
                                    0.0019216140549867583,
                                    0.008903606052493124,
                                ],
                                [
                                    0.1391529793426633,
                                    0.6447513775633397,
                                    0.03835972117591408,
                                    0.17773592191808296,
                                ],
                                [
                                    0.6030063975790086,
                                    0.1808979593269942,
                                    0.16622825747383277,
                                    0.049867385620164274,
                                ],
                                [
                                    0.17066373818806144,
                                    0.7907533192365189,
                                    0.006848962330515937,
                                    0.03173398024490372,
                                ],
                                [
                                    0.739555318529915,
                                    0.2218617388946654,
                                    0.02967933652292653,
                                    0.008903606052493124,
                                ],
                                [
                                    0.009833417785021966,
                                    0.03487610391862287,
                                    0.21010670705465664,
                                    0.7451837712416985,
                                ],
                                [
                                    0.21945613442633652,
                                    0.7783433102466403,
                                    0.00048399041334210453,
                                    0.001716564913681105,
                                ],
                                [
                                    0.16351827017399126,
                                    0.5799489361540262,
                                    0.05642185466568735,
                                    0.20011093900629515,
                                ],
                                [
                                    0.7085911024093945,
                                    0.03487610391862289,
                                    0.24449882055993732,
                                    0.012033973112045179,
                                ],
                                [
                                    0.21189192868848467,
                                    0.7515154024792113,
                                    0.008048196151193949,
                                    0.028544472681110006,
                                ],
                                [
                                    0.9182138190507091,
                                    0.04519351211698697,
                                    0.03487610391862285,
                                    0.0017165649136811055,
                                ],
                                [
                                    0.007936507936507941,
                                    0.7252132901931455,
                                    0.0028887121709719418,
                                    0.26396148969937466,
                                ],
                                [
                                    0.008444319845623757,
                                    0.7716155553146976,
                                    0.002380900261856124,
                                    0.21755922457782245,
                                ],
                                [
                                    0.008236991391905727,
                                    0.7526705292056874,
                                    0.002588228715574154,
                                    0.23650425068683267,
                                ],
                                [
                                    0.035694230404447747,
                                    0.7252132901931454,
                                    0.011215846626220324,
                                    0.2278766327761865,
                                ],
                                [
                                    0.008354176782281115,
                                    0.7633785639227919,
                                    0.0024710433251987672,
                                    0.22579621596972818,
                                ],
                                [
                                    0.03620204231356357,
                                    0.7355306983915094,
                                    0.010708034717104506,
                                    0.21755922457782245,
                                ],
                                [
                                    0.031510758845398154,
                                    0.560211195688866,
                                    0.02174188558318287,
                                    0.386536159882553,
                                ],
                                [
                                    0.04379962370630803,
                                    0.7786876757751146,
                                    0.009453020722272993,
                                    0.1680596797963044,
                                ],
                                [
                                    0.03878234997990318,
                                    0.6894885255052672,
                                    0.01447029444867784,
                                    0.2572588300661518,
                                ],
                                [
                                    0.16805967979630446,
                                    0.5602111956888659,
                                    0.06270566515085405,
                                    0.20902345936397557,
                                ],
                                [
                                    0.041618194118540064,
                                    0.7399053257952114,
                                    0.011634450310040957,
                                    0.2068420297762076,
                                ],
                                [
                                    0.18034854465721437,
                                    0.6011749752565371,
                                    0.05041680028994416,
                                    0.1680596797963044,
                                ],
                                [
                                    0.044378175129644364,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.5443781751296444,
                                ],
                                [
                                    0.10206951136643398,
                                    0.7825478161599868,
                                    0.01331316110714526,
                                    0.10206951136643397,
                                ],
                                [
                                    0.07851540536737095,
                                    0.601962899426182,
                                    0.03686726710620831,
                                    0.28265442810023883,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.0918285664745162,
                                    0.7040324107926159,
                                    0.02355410599906305,
                                    0.1805849167338049,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.03151075884539816,
                                    0.14600194167317931,
                                    0.1460019416731792,
                                    0.6764853578082433,
                                ],
                                [
                                    0.16805967979630437,
                                    0.7786876757751146,
                                    0.009453020722272994,
                                    0.04379962370630805,
                                ],
                                [
                                    0.11230975324001312,
                                    0.5203759808619222,
                                    0.06520294727856425,
                                    0.30211131861950047,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317931,
                                    0.2825508626240855,
                                    0.0847634032739792,
                                ],
                                [
                                    0.14382051208541125,
                                    0.6663779225351014,
                                    0.03369218843316611,
                                    0.15610937694632118,
                                ],
                                [
                                    0.6232327133796622,
                                    0.18696572124085045,
                                    0.14600194167317926,
                                    0.04379962370630804,
                                ],
                                [
                                    0.007936507936507952,
                                    0.028148348986680238,
                                    0.21200361690317066,
                                    0.7519115261736411,
                                ],
                                [
                                    0.2175592245778225,
                                    0.7716155553146976,
                                    0.0023809002618561267,
                                    0.008444319845623766,
                                ],
                                [
                                    0.1319748715422888,
                                    0.46807421744722366,
                                    0.08796525329738981,
                                    0.3119856577130977,
                                ],
                                [
                                    0.5719007400028322,
                                    0.02814834898668023,
                                    0.3811891829664997,
                                    0.018761728043987843,
                                ],
                                [
                                    0.18034853005678222,
                                    0.6396406837724089,
                                    0.03959159478289641,
                                    0.1404191913879125,
                                ],
                                [
                                    0.7815234566441468,
                                    0.03846575718504431,
                                    0.17156646632518516,
                                    0.008444319845623766,
                                ],
                                [
                                    0.0051587040991820324,
                                    0.47138625738548395,
                                    0.00566651600829785,
                                    0.5177885225070362,
                                ],
                                [
                                    0.00566651600829785,
                                    0.5177885225070362,
                                    0.0051587040991820324,
                                    0.47138625738548395,
                                ],
                                [
                                    0.005354017358552248,
                                    0.4892333725877078,
                                    0.005471202748927635,
                                    0.4999414073048123,
                                ],
                                [
                                    0.023201132560776126,
                                    0.47138625738548395,
                                    0.023708944469891947,
                                    0.481703665583848,
                                ],
                                [
                                    0.005471202748927635,
                                    0.4999414073048123,
                                    0.005354017358552248,
                                    0.4892333725877078,
                                ],
                                [
                                    0.023708944469891947,
                                    0.481703665583848,
                                    0.023201132560776126,
                                    0.47138625738548395,
                                ],
                                [
                                    0.020481889783835576,
                                    0.3641354377425853,
                                    0.032770754644745444,
                                    0.5826119178288337,
                                ],
                                [
                                    0.03277075464474545,
                                    0.5826119178288338,
                                    0.020481889783835572,
                                    0.36413543774258517,
                                ],
                                [
                                    0.025208400144972068,
                                    0.44816527764073744,
                                    0.02804424428360895,
                                    0.49858207793068154,
                                ],
                                [
                                    0.10923824004312431,
                                    0.36413543774258517,
                                    0.12152710490403419,
                                    0.40509921731025633,
                                ],
                                [
                                    0.02804424428360895,
                                    0.49858207793068154,
                                    0.025208400144972068,
                                    0.44816527764073744,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.028845668118394813,
                                    0.2211543318816052,
                                    0.08653700435518444,
                                    0.6634629956448156,
                                ],
                                [
                                    0.08653700435518444,
                                    0.6634629956448156,
                                    0.028845668118394813,
                                    0.2211543318816052,
                                ],
                                [
                                    0.051034755683217,
                                    0.3912739080799934,
                                    0.06434791679036225,
                                    0.49334341944642734,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.06434791679036227,
                                    0.4933434194464274,
                                    0.05103475568321699,
                                    0.3912739080799934,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.020481889783835576,
                                    0.09490078268974368,
                                    0.1570308107347418,
                                    0.727586516791679,
                                ],
                                [
                                    0.1570308107347418,
                                    0.727586516791679,
                                    0.020481889783835576,
                                    0.09490078268974368,
                                ],
                                [
                                    0.0730009708365896,
                                    0.33824267890412163,
                                    0.10451172968198777,
                                    0.484244620577301,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974367,
                                    0.4528917880018739,
                                    0.13586456225741483,
                                ],
                                [
                                    0.10451172968198777,
                                    0.484244620577301,
                                    0.07300097083658962,
                                    0.3382426789041217,
                                ],
                                [
                                    0.4528917880018739,
                                    0.13586456225741483,
                                    0.31634286705096765,
                                    0.09490078268974368,
                                ],
                                [
                                    0.0051587040991820385,
                                    0.018296334416152,
                                    0.21478142074049658,
                                    0.7617635407441694,
                                ],
                                [
                                    0.21478142074049658,
                                    0.7617635407441694,
                                    0.0051587040991820385,
                                    0.018296334416152,
                                ],
                                [
                                    0.08578323316259262,
                                    0.3042467044175682,
                                    0.134156891677086,
                                    0.4758131707427532,
                                ],
                                [
                                    0.3717336031640088,
                                    0.018296334416152003,
                                    0.5813563198053231,
                                    0.02861374261451607,
                                ],
                                [
                                    0.13415689167708603,
                                    0.4758131707427533,
                                    0.0857832331625926,
                                    0.30424670441756807,
                                ],
                                [
                                    0.5813563198053232,
                                    0.028613742614516074,
                                    0.3717336031640087,
                                    0.018296334416152,
                                ],
                                [
                                    0.0023809002618561245,
                                    0.2175592245778225,
                                    0.008444319845623757,
                                    0.7716155553146976,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.7252132901931454,
                                ],
                                [
                                    0.0024710433251987677,
                                    0.2257962159697282,
                                    0.008354176782281115,
                                    0.7633785639227919,
                                ],
                                [
                                    0.010708034717104508,
                                    0.21755922457782245,
                                    0.03620204231356357,
                                    0.7355306983915094,
                                ],
                                [
                                    0.0025882287155741543,
                                    0.2365042506868327,
                                    0.008236991391905727,
                                    0.7526705292056874,
                                ],
                                [
                                    0.011215846626220325,
                                    0.22787663277618653,
                                    0.035694230404447747,
                                    0.7252132901931454,
                                ],
                                [
                                    0.009453020722272996,
                                    0.16805967979630448,
                                    0.04379962370630802,
                                    0.7786876757751144,
                                ],
                                [
                                    0.021741885583182873,
                                    0.38653615988255313,
                                    0.03151075884539815,
                                    0.5602111956888659,
                                ],
                                [
                                    0.011634450310040961,
                                    0.2068420297762077,
                                    0.04161819411854006,
                                    0.7399053257952113,
                                ],
                                [
                                    0.05041680028994418,
                                    0.16805967979630448,
                                    0.18034854465721434,
                                    0.6011749752565371,
                                ],
                                [
                                    0.014470294448677843,
                                    0.2572588300661518,
                                    0.03878234997990318,
                                    0.6894885255052672,
                                ],
                                [
                                    0.06270566515085405,
                                    0.20902345936397562,
                                    0.16805967979630446,
                                    0.5602111956888659,
                                ],
                                [
                                    0.013313161107145264,
                                    0.10206951136643398,
                                    0.10206951136643398,
                                    0.7825478161599868,
                                ],
                                [
                                    0.0710044973439349,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.3402391523967764,
                                ],
                                [
                                    0.023554105999063057,
                                    0.18058491673380495,
                                    0.09182856647451619,
                                    0.7040324107926158,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.03686726710620832,
                                    0.28265442810023894,
                                    0.07851540536737094,
                                    0.6019628994261819,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.009453020722272991,
                                    0.04379962370630803,
                                    0.16805967979630437,
                                    0.7786876757751146,
                                ],
                                [
                                    0.1460019416731792,
                                    0.6764853578082433,
                                    0.031510758845398154,
                                    0.14600194167317931,
                                ],
                                [
                                    0.03369218843316612,
                                    0.1561093769463212,
                                    0.14382051208541125,
                                    0.6663779225351014,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630805,
                                    0.6232327133796622,
                                    0.18696572124085045,
                                ],
                                [
                                    0.06520294727856425,
                                    0.30211131861950047,
                                    0.11230975324001312,
                                    0.5203759808619222,
                                ],
                                [
                                    0.2825508626240855,
                                    0.0847634032739792,
                                    0.486683792428756,
                                    0.14600194167317931,
                                ],
                                [
                                    0.0023809002618561245,
                                    0.008444319845623757,
                                    0.2175592245778225,
                                    0.7716155553146976,
                                ],
                                [
                                    0.21200361690317066,
                                    0.7519115261736411,
                                    0.007936507936507948,
                                    0.028148348986680227,
                                ],
                                [
                                    0.03959159478289645,
                                    0.14041919138791267,
                                    0.18034853005678217,
                                    0.6396406837724087,
                                ],
                                [
                                    0.17156646632518535,
                                    0.008444319845623775,
                                    0.7815234566441466,
                                    0.038465757185044296,
                                ],
                                [
                                    0.08796525329738984,
                                    0.3119856577130978,
                                    0.13197487154228876,
                                    0.4680742174472236,
                                ],
                                [
                                    0.3811891829664998,
                                    0.018761728043987846,
                                    0.5719007400028322,
                                    0.028148348986680227,
                                ],
                                [
                                    0.0004839904133421043,
                                    0.04422553129030273,
                                    0.010341229694137779,
                                    0.9449492486022174,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.09062779641185499,
                                    0.00983341778502196,
                                    0.8985469834806651,
                                ],
                                [
                                    0.0005023147334264394,
                                    0.04589995038812577,
                                    0.010322905374053443,
                                    0.9432748295043943,
                                ],
                                [
                                    0.0021767338312494965,
                                    0.04422553129030271,
                                    0.044733343199418574,
                                    0.9088643916790292,
                                ],
                                [
                                    0.0006195001238018261,
                                    0.05660798510523027,
                                    0.010205719983678056,
                                    0.9325667947872899,
                                ],
                                [
                                    0.002684545740365315,
                                    0.05454293948866678,
                                    0.04422553129030276,
                                    0.8985469834806652,
                                ],
                                [
                                    0.001921614054986761,
                                    0.03416324286820143,
                                    0.05133103037359426,
                                    0.9125841127032176,
                                ],
                                [
                                    0.014210478915896638,
                                    0.25263972295445003,
                                    0.039042165512684385,
                                    0.694107632616969,
                                ],
                                [
                                    0.002365055985241087,
                                    0.042046935393195456,
                                    0.05088758844333993,
                                    0.9047004201782235,
                                ],
                                [
                                    0.010248748510235139,
                                    0.0341632428682014,
                                    0.22051659643692337,
                                    0.7350714121846401,
                                ],
                                [
                                    0.005200900123877968,
                                    0.09246373568313959,
                                    0.048051744304703055,
                                    0.8542836198882794,
                                ],
                                [
                                    0.022537613371145016,
                                    0.07512702243587255,
                                    0.2082277315760135,
                                    0.694107632616969,
                                ],
                                [
                                    0.0027063050268699737,
                                    0.020748733488464063,
                                    0.11267636744670928,
                                    0.8638685940379567,
                                ],
                                [
                                    0.060397641263659596,
                                    0.46305739725167444,
                                    0.054985031209919655,
                                    0.4215599302747463,
                                ],
                                [
                                    0.004788088640682069,
                                    0.03670937833624606,
                                    0.11059458383289718,
                                    0.8479079491901746,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.01810124974782733,
                                    0.13877888970268004,
                                    0.09728142272575192,
                                    0.7458384378237407,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.0019216140549867583,
                                    0.008903606052493124,
                                    0.17559108646359062,
                                    0.8135836934289296,
                                ],
                                [
                                    0.138470535005893,
                                    0.6415893401544284,
                                    0.03904216551268439,
                                    0.18089795932699423,
                                ],
                                [
                                    0.006848962330515949,
                                    0.03173398024490377,
                                    0.1706637381880614,
                                    0.7907533192365188,
                                ],
                                [
                                    0.02967933652292658,
                                    0.00890360605249314,
                                    0.739555318529915,
                                    0.22186173889466537,
                                ],
                                [
                                    0.03835972117591409,
                                    0.17773592191808302,
                                    0.1391529793426633,
                                    0.6447513775633397,
                                ],
                                [
                                    0.1662282574738328,
                                    0.04986738562016429,
                                    0.6030063975790086,
                                    0.1808979593269942,
                                ],
                                [
                                    0.00048399041334211006,
                                    0.0017165649136811247,
                                    0.21945613442633652,
                                    0.7783433102466403,
                                ],
                                [
                                    0.21010670705465664,
                                    0.7451837712416985,
                                    0.009833417785021972,
                                    0.03487610391862289,
                                ],
                                [
                                    0.008048196151193947,
                                    0.028544472681109996,
                                    0.21189192868848467,
                                    0.7515154024792113,
                                ],
                                [
                                    0.034876103918622836,
                                    0.0017165649136811048,
                                    0.9182138190507091,
                                    0.04519351211698697,
                                ],
                                [
                                    0.05642185466568736,
                                    0.2001109390062952,
                                    0.16351827017399126,
                                    0.5799489361540262,
                                ],
                                [
                                    0.24449882055993738,
                                    0.012033973112045182,
                                    0.7085911024093945,
                                    0.03487610391862289,
                                ],
                                [
                                    0.02130609729826128,
                                    0.8870743039674259,
                                    0.002148941217072757,
                                    0.08947065751724008,
                                ],
                                [
                                    0.022406374961772883,
                                    0.9328841033345823,
                                    0.001048663553561152,
                                    0.04366085815008366,
                                ],
                                [
                                    0.02211276564515138,
                                    0.9206597491258165,
                                    0.001342272870182657,
                                    0.05588521235884942,
                                ],
                                [
                                    0.04422553129030276,
                                    0.8985469834806652,
                                    0.002684545740365314,
                                    0.054542939488666765,
                                ],
                                [
                                    0.022366671599709287,
                                    0.9312310632787385,
                                    0.0010883669156247482,
                                    0.045313898205927454,
                                ],
                                [
                                    0.044733343199418574,
                                    0.9088643916790292,
                                    0.0021767338312494965,
                                    0.04422553129030271,
                                ],
                                [
                                    0.08459278303166455,
                                    0.6485570150979889,
                                    0.030789889441914704,
                                    0.23606031242843187,
                                ],
                                [
                                    0.11121910524595506,
                                    0.8526960378308568,
                                    0.004163567227624185,
                                    0.03192128969556395,
                                ],
                                [
                                    0.10411386578800674,
                                    0.7982214984049757,
                                    0.011268806685572504,
                                    0.08639582912144503,
                                ],
                                [
                                    0.2082277315760135,
                                    0.694107632616969,
                                    0.02253761337114501,
                                    0.07512702243587252,
                                ],
                                [
                                    0.11025829821846168,
                                    0.8453297104031018,
                                    0.005124374255117565,
                                    0.03928761712331894,
                                ],
                                [
                                    0.22051659643692337,
                                    0.7350714121846401,
                                    0.01024874851023513,
                                    0.034163242868201375,
                                ],
                                [
                                    0.11913624037116649,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.3925912788865005,
                                ],
                                [
                                    0.2441362403711665,
                                    0.7324087211134995,
                                    0.005863759628833502,
                                    0.017591278886500507,
                                ],
                                [
                                    0.21077996513737318,
                                    0.6323398954121195,
                                    0.039220034862626825,
                                    0.11766010458788048,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.23962563325576797,
                                    0.7188768997673038,
                                    0.01037436674423202,
                                    0.031123100232696058,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.08459278303166454,
                                    0.13534734180801408,
                                    0.3000245444947562,
                                    0.4800353306655652,
                                ],
                                [
                                    0.3804537602987966,
                                    0.6087210195937236,
                                    0.004163567227624186,
                                    0.006661652879855697,
                                ],
                                [
                                    0.3015031987895043,
                                    0.4824011581164986,
                                    0.08311412873691638,
                                    0.13298151435708067,
                                ],
                                [
                                    0.6030063975790086,
                                    0.1808979593269942,
                                    0.16622825747383277,
                                    0.049867385620164274,
                                ],
                                [
                                    0.3697776592649575,
                                    0.5916393981596229,
                                    0.014839668261463265,
                                    0.023743274313956387,
                                ],
                                [
                                    0.739555318529915,
                                    0.2218617388946654,
                                    0.02967933652292653,
                                    0.008903606052493124,
                                ],
                                [
                                    0.021306097298261266,
                                    0.023403424405383573,
                                    0.4552388641864047,
                                    0.5000516141099505,
                                ],
                                [
                                    0.4754962979311048,
                                    0.522303146741872,
                                    0.001048663553561152,
                                    0.0011518917734620576,
                                ],
                                [
                                    0.35429555120469725,
                                    0.3891716551233202,
                                    0.12224941027996866,
                                    0.13428338339201384,
                                ],
                                [
                                    0.7085911024093945,
                                    0.03487610391862289,
                                    0.24449882055993732,
                                    0.012033973112045179,
                                ],
                                [
                                    0.45910690952535455,
                                    0.5043004216423416,
                                    0.017438051959311425,
                                    0.019154616872992532,
                                ],
                                [
                                    0.9182138190507091,
                                    0.04519351211698697,
                                    0.03487610391862285,
                                    0.0017165649136811055,
                                ],
                                [
                                    0.017196056752640396,
                                    0.7159537413770131,
                                    0.006258981762693642,
                                    0.26059122010765295,
                                ],
                                [
                                    0.018296334416152,
                                    0.7617635407441694,
                                    0.005158704099182037,
                                    0.21478142074049653,
                                ],
                                [
                                    0.017847115202223873,
                                    0.7430604053953692,
                                    0.005607923313110162,
                                    0.23348455608929666,
                                ],
                                [
                                    0.035694230404447747,
                                    0.7252132901931454,
                                    0.011215846626220324,
                                    0.2278766327761865,
                                ],
                                [
                                    0.018101021156781784,
                                    0.7536317195482912,
                                    0.005354017358552253,
                                    0.22291324193637468,
                                ],
                                [
                                    0.03620204231356357,
                                    0.7355306983915094,
                                    0.010708034717104506,
                                    0.21755922457782245,
                                ],
                                [
                                    0.06827446047545314,
                                    0.523447494058811,
                                    0.0471082119981261,
                                    0.3611698334676098,
                                ],
                                [
                                    0.09490078268974368,
                                    0.727586516791679,
                                    0.020481889783835576,
                                    0.15703081073474182,
                                ],
                                [
                                    0.08402983989815223,
                                    0.6442410355870181,
                                    0.03135283257542702,
                                    0.2403762919394026,
                                ],
                                [
                                    0.16805967979630446,
                                    0.5602111956888659,
                                    0.06270566515085405,
                                    0.20902345936397557,
                                ],
                                [
                                    0.09017427232860718,
                                    0.6913492475851443,
                                    0.02520840014497208,
                                    0.19326807994127648,
                                ],
                                [
                                    0.18034854465721437,
                                    0.6011749752565371,
                                    0.05041680028994416,
                                    0.1680596797963044,
                                ],
                                [
                                    0.09615433188160519,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.4615370043551844,
                                ],
                                [
                                    0.2211543318816052,
                                    0.6634629956448156,
                                    0.028845668118394806,
                                    0.08653700435518441,
                                ],
                                [
                                    0.17011957619838822,
                                    0.5103587285951646,
                                    0.07988042380161178,
                                    0.23964127140483535,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.19896524431678303,
                                    0.596895732950349,
                                    0.051034755683216984,
                                    0.15310426704965097,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.06827446047545316,
                                    0.10923824004312432,
                                    0.3163428670509676,
                                    0.5061444324304549,
                                ],
                                [
                                    0.36413543774258517,
                                    0.5826119178288338,
                                    0.02048188978383558,
                                    0.032770754644745465,
                                ],
                                [
                                    0.243341896214378,
                                    0.3893438378875573,
                                    0.14127543131204276,
                                    0.22603883458602195,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317931,
                                    0.2825508626240855,
                                    0.0847634032739792,
                                ],
                                [
                                    0.3116163566898311,
                                    0.49858207793068154,
                                    0.07300097083658963,
                                    0.11680059454289768,
                                ],
                                [
                                    0.6232327133796622,
                                    0.18696572124085045,
                                    0.14600194167317926,
                                    0.04379962370630804,
                                ],
                                [
                                    0.0171960567526404,
                                    0.018888800170547792,
                                    0.45934890473202555,
                                    0.5045662383447862,
                                ],
                                [
                                    0.47138625738548395,
                                    0.5177885225070362,
                                    0.005158704099182037,
                                    0.005666516008297856,
                                ],
                                [
                                    0.2859503700014161,
                                    0.3140987189880964,
                                    0.19059459148324984,
                                    0.20935631952723768,
                                ],
                                [
                                    0.5719007400028322,
                                    0.02814834898668023,
                                    0.3811891829664997,
                                    0.018761728043987843,
                                ],
                                [
                                    0.3907617283220734,
                                    0.4292274855071177,
                                    0.08578323316259258,
                                    0.09422755300821635,
                                ],
                                [
                                    0.7815234566441468,
                                    0.03846575718504431,
                                    0.17156646632518516,
                                    0.008444319845623766,
                                ],
                                [
                                    0.011177380425911215,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.5111773804259112,
                                ],
                                [
                                    0.012277658089422822,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.46536758105875475,
                                ],
                                [
                                    0.011600566280388063,
                                    0.482986823665872,
                                    0.011854472234945974,
                                    0.493558137818794,
                                ],
                                [
                                    0.023201132560776126,
                                    0.47138625738548395,
                                    0.023708944469891947,
                                    0.481703665583848,
                                ],
                                [
                                    0.011854472234945974,
                                    0.493558137818794,
                                    0.011600566280388063,
                                    0.482986823665872,
                                ],
                                [
                                    0.023708944469891947,
                                    0.481703665583848,
                                    0.023201132560776126,
                                    0.47138625738548395,
                                ],
                                [
                                    0.04437817512964438,
                                    0.3402391523967765,
                                    0.07100449734393488,
                                    0.5443781751296443,
                                ],
                                [
                                    0.0710044973439349,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.3402391523967764,
                                ],
                                [
                                    0.054619120021562155,
                                    0.41875455776414733,
                                    0.060763552452017096,
                                    0.4658627697622734,
                                ],
                                [
                                    0.10923824004312431,
                                    0.36413543774258517,
                                    0.12152710490403419,
                                    0.40509921731025633,
                                ],
                                [
                                    0.060763552452017096,
                                    0.4658627697622734,
                                    0.054619120021562155,
                                    0.41875455776414733,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [0.0625, 0.1875, 0.1875, 0.5625],
                                [0.1875, 0.5625, 0.0625, 0.1875],
                                [
                                    0.11057716594080261,
                                    0.33173149782240785,
                                    0.1394228340591974,
                                    0.41826850217759215,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.13942283405919742,
                                    0.41826850217759226,
                                    0.1105771659408026,
                                    0.3317314978224078,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.044378175129644364,
                                    0.0710044973439349,
                                    0.3402391523967764,
                                    0.5443781751296444,
                                ],
                                [
                                    0.3402391523967764,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.0710044973439349,
                                ],
                                [
                                    0.1581714335254838,
                                    0.25307221621522746,
                                    0.22644589400093695,
                                    0.3623104562583518,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974367,
                                    0.4528917880018739,
                                    0.13586456225741483,
                                ],
                                [
                                    0.22644589400093695,
                                    0.3623104562583518,
                                    0.15817143352548382,
                                    0.2530722162152275,
                                ],
                                [
                                    0.4528917880018739,
                                    0.13586456225741483,
                                    0.31634286705096765,
                                    0.09490078268974368,
                                ],
                                [
                                    0.011177380425911215,
                                    0.012277658089422822,
                                    0.46536758105875475,
                                    0.5111773804259112,
                                ],
                                [
                                    0.46536758105875475,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.012277658089422822,
                                ],
                                [
                                    0.1858668015820044,
                                    0.20416313599815641,
                                    0.29067815990266155,
                                    0.31929190251717765,
                                ],
                                [
                                    0.3717336031640088,
                                    0.018296334416152003,
                                    0.5813563198053231,
                                    0.02861374261451607,
                                ],
                                [
                                    0.2906781599026616,
                                    0.3192919025171777,
                                    0.18586680158200436,
                                    0.20416313599815633,
                                ],
                                [
                                    0.5813563198053232,
                                    0.028613742614516074,
                                    0.3717336031640087,
                                    0.018296334416152,
                                ],
                                [
                                    0.0051587040991820385,
                                    0.21478142074049658,
                                    0.018296334416152,
                                    0.7617635407441694,
                                ],
                                [
                                    0.006258981762693645,
                                    0.26059122010765307,
                                    0.017196056752640392,
                                    0.715953741377013,
                                ],
                                [
                                    0.005354017358552254,
                                    0.2229132419363747,
                                    0.018101021156781784,
                                    0.7536317195482912,
                                ],
                                [
                                    0.010708034717104508,
                                    0.21755922457782245,
                                    0.03620204231356357,
                                    0.7355306983915094,
                                ],
                                [
                                    0.005607923313110163,
                                    0.2334845560892967,
                                    0.017847115202223873,
                                    0.7430604053953692,
                                ],
                                [
                                    0.011215846626220325,
                                    0.22787663277618653,
                                    0.035694230404447747,
                                    0.7252132901931454,
                                ],
                                [
                                    0.020481889783835586,
                                    0.1570308107347419,
                                    0.09490078268974367,
                                    0.7275865167916789,
                                ],
                                [
                                    0.047108211998126114,
                                    0.3611698334676099,
                                    0.06827446047545314,
                                    0.5234474940588109,
                                ],
                                [
                                    0.02520840014497209,
                                    0.19326807994127657,
                                    0.09017427232860717,
                                    0.6913492475851442,
                                ],
                                [
                                    0.05041680028994418,
                                    0.16805967979630448,
                                    0.18034854465721434,
                                    0.6011749752565371,
                                ],
                                [
                                    0.03135283257542702,
                                    0.24037629193940263,
                                    0.08402983989815223,
                                    0.6442410355870181,
                                ],
                                [
                                    0.06270566515085405,
                                    0.20902345936397562,
                                    0.16805967979630446,
                                    0.5602111956888659,
                                ],
                                [
                                    0.028845668118394813,
                                    0.08653700435518444,
                                    0.2211543318816052,
                                    0.6634629956448156,
                                ],
                                [
                                    0.1538456681183948,
                                    0.4615370043551844,
                                    0.09615433188160519,
                                    0.2884629956448156,
                                ],
                                [
                                    0.051034755683217,
                                    0.153104267049651,
                                    0.198965244316783,
                                    0.596895732950349,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.07988042380161181,
                                    0.23964127140483543,
                                    0.1701195761983882,
                                    0.5103587285951645,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.020481889783835572,
                                    0.03277075464474545,
                                    0.36413543774258517,
                                    0.5826119178288338,
                                ],
                                [
                                    0.3163428670509676,
                                    0.5061444324304549,
                                    0.06827446047545314,
                                    0.10923824004312431,
                                ],
                                [
                                    0.07300097083658964,
                                    0.11680059454289769,
                                    0.3116163566898311,
                                    0.49858207793068154,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630805,
                                    0.6232327133796622,
                                    0.18696572124085045,
                                ],
                                [
                                    0.14127543131204276,
                                    0.22603883458602195,
                                    0.243341896214378,
                                    0.3893438378875573,
                                ],
                                [
                                    0.2825508626240855,
                                    0.0847634032739792,
                                    0.486683792428756,
                                    0.14600194167317931,
                                ],
                                [
                                    0.0051587040991820324,
                                    0.00566651600829785,
                                    0.47138625738548395,
                                    0.5177885225070362,
                                ],
                                [
                                    0.45934890473202555,
                                    0.5045662383447862,
                                    0.017196056752640392,
                                    0.018888800170547785,
                                ],
                                [
                                    0.08578323316259268,
                                    0.09422755300821645,
                                    0.3907617283220733,
                                    0.4292274855071176,
                                ],
                                [
                                    0.17156646632518535,
                                    0.008444319845623775,
                                    0.7815234566441466,
                                    0.038465757185044296,
                                ],
                                [
                                    0.1905945914832499,
                                    0.20935631952723774,
                                    0.2859503700014161,
                                    0.31409871898809627,
                                ],
                                [
                                    0.3811891829664998,
                                    0.018761728043987846,
                                    0.5719007400028322,
                                    0.028148348986680227,
                                ],
                                [
                                    0.0010486635535611527,
                                    0.043660858150083685,
                                    0.022406374961772883,
                                    0.9328841033345823,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.08947065751724015,
                                    0.021306097298261276,
                                    0.8870743039674258,
                                ],
                                [
                                    0.0010883669156247482,
                                    0.04531389820592746,
                                    0.022366671599709287,
                                    0.9312310632787385,
                                ],
                                [
                                    0.0021767338312494965,
                                    0.04422553129030271,
                                    0.044733343199418574,
                                    0.9088643916790292,
                                ],
                                [
                                    0.0013422728701826575,
                                    0.05588521235884943,
                                    0.02211276564515138,
                                    0.9206597491258165,
                                ],
                                [
                                    0.002684545740365315,
                                    0.05454293948866678,
                                    0.04422553129030276,
                                    0.8985469834806652,
                                ],
                                [
                                    0.004163567227624192,
                                    0.031921289695564,
                                    0.11121910524595506,
                                    0.8526960378308568,
                                ],
                                [
                                    0.030789889441914717,
                                    0.23606031242843198,
                                    0.08459278303166454,
                                    0.6485570150979888,
                                ],
                                [
                                    0.0051243742551175695,
                                    0.03928761712331898,
                                    0.11025829821846168,
                                    0.8453297104031018,
                                ],
                                [
                                    0.010248748510235139,
                                    0.0341632428682014,
                                    0.22051659643692337,
                                    0.7350714121846401,
                                ],
                                [
                                    0.011268806685572508,
                                    0.08639582912144506,
                                    0.10411386578800674,
                                    0.7982214984049757,
                                ],
                                [
                                    0.022537613371145016,
                                    0.07512702243587255,
                                    0.2082277315760135,
                                    0.694107632616969,
                                ],
                                [
                                    0.005863759628833509,
                                    0.017591278886500528,
                                    0.2441362403711665,
                                    0.7324087211134995,
                                ],
                                [
                                    0.1308637596288335,
                                    0.3925912788865005,
                                    0.11913624037116649,
                                    0.3574087211134995,
                                ],
                                [
                                    0.010374366744232033,
                                    0.0311231002326961,
                                    0.23962563325576797,
                                    0.7188768997673038,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.039220034862626846,
                                    0.11766010458788054,
                                    0.21077996513737315,
                                    0.6323398954121194,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.004163567227624186,
                                    0.006661652879855697,
                                    0.3804537602987966,
                                    0.6087210195937236,
                                ],
                                [
                                    0.3000245444947562,
                                    0.4800353306655652,
                                    0.08459278303166454,
                                    0.13534734180801408,
                                ],
                                [
                                    0.01483966826146329,
                                    0.023743274313956432,
                                    0.3697776592649575,
                                    0.5916393981596229,
                                ],
                                [
                                    0.02967933652292658,
                                    0.00890360605249314,
                                    0.739555318529915,
                                    0.22186173889466537,
                                ],
                                [
                                    0.0831141287369164,
                                    0.1329815143570807,
                                    0.3015031987895043,
                                    0.4824011581164986,
                                ],
                                [
                                    0.1662282574738328,
                                    0.04986738562016429,
                                    0.6030063975790086,
                                    0.1808979593269942,
                                ],
                                [
                                    0.001048663553561164,
                                    0.0011518917734620708,
                                    0.4754962979311048,
                                    0.522303146741872,
                                ],
                                [
                                    0.4552388641864047,
                                    0.5000516141099505,
                                    0.021306097298261276,
                                    0.023403424405383583,
                                ],
                                [
                                    0.017438051959311418,
                                    0.019154616872992525,
                                    0.45910690952535455,
                                    0.5043004216423416,
                                ],
                                [
                                    0.034876103918622836,
                                    0.0017165649136811048,
                                    0.9182138190507091,
                                    0.04519351211698697,
                                ],
                                [
                                    0.12224941027996869,
                                    0.13428338339201387,
                                    0.35429555120469725,
                                    0.3891716551233202,
                                ],
                                [
                                    0.24449882055993738,
                                    0.012033973112045182,
                                    0.7085911024093945,
                                    0.03487610391862289,
                                ],
                                [
                                    0.0327787768115006,
                                    0.8756016244541865,
                                    0.003306080111687592,
                                    0.08831351862262524,
                                ],
                                [
                                    0.03447152022940799,
                                    0.9208189580669471,
                                    0.0016133366937802001,
                                    0.04309618500986461,
                                ],
                                [
                                    0.0340198113066247,
                                    0.9087527034643432,
                                    0.0020650456165634884,
                                    0.05516243961246859,
                                ],
                                [
                                    0.04422553129030276,
                                    0.8985469834806652,
                                    0.002684545740365314,
                                    0.054542939488666765,
                                ],
                                [
                                    0.03441043782536513,
                                    0.9191872970530827,
                                    0.001674419097823057,
                                    0.044727846023729145,
                                ],
                                [
                                    0.044733343199418574,
                                    0.9088643916790292,
                                    0.0021767338312494965,
                                    0.04422553129030271,
                                ],
                                [
                                    0.13014340055064463,
                                    0.6030063975790088,
                                    0.047369299967932744,
                                    0.21948090190241384,
                                ],
                                [
                                    0.17110718011831574,
                                    0.7928079629584961,
                                    0.006405520400261609,
                                    0.029679336522926526,
                                ],
                                [
                                    0.16017598727131033,
                                    0.7421593769216721,
                                    0.017336713247267033,
                                    0.0803279225597505,
                                ],
                                [
                                    0.2082277315760135,
                                    0.694107632616969,
                                    0.02253761337114501,
                                    0.07512702243587252,
                                ],
                                [
                                    0.16962900799358333,
                                    0.7859590006279802,
                                    0.00788369252499404,
                                    0.03652829885344247,
                                ],
                                [
                                    0.22051659643692337,
                                    0.7350714121846401,
                                    0.01024874851023513,
                                    0.034163242868201375,
                                ],
                                [
                                    0.18328744953241333,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.3221251605213266,
                                ],
                                [
                                    0.3755961132956237,
                                    0.6009488481890423,
                                    0.009021214230797034,
                                    0.014433824284536975,
                                ],
                                [
                                    0.32427850754899445,
                                    0.5188413530004983,
                                    0.06033881997742633,
                                    0.09654131947308098,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.36865668267863877,
                                    0.5898458503444332,
                                    0.015960644847781976,
                                    0.0255368221291461,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.13014340055064466,
                                    0.08979672428903396,
                                    0.46157855398361936,
                                    0.318481321176702,
                                ],
                                [
                                    0.5853164341340024,
                                    0.4038583457585177,
                                    0.006405520400261612,
                                    0.004419699707218271,
                                ],
                                [
                                    0.46385341823634535,
                                    0.32005093866965756,
                                    0.12786853629791867,
                                    0.08822710679607838,
                                ],
                                [
                                    0.6030063975790086,
                                    0.1808979593269942,
                                    0.16622825747383277,
                                    0.049867385620164274,
                                ],
                                [
                                    0.5688915803418535,
                                    0.39252547708272695,
                                    0.022830374192410588,
                                    0.015752568383009063,
                                ],
                                [
                                    0.739555318529915,
                                    0.2218617388946654,
                                    0.02967933652292653,
                                    0.008903606052493124,
                                ],
                                [
                                    0.032778776811500564,
                                    0.011930744892144272,
                                    0.7003710213181528,
                                    0.2549194569782024,
                                ],
                                [
                                    0.7315364614358731,
                                    0.2662629832371037,
                                    0.0016133366937801992,
                                    0.0005872186332430102,
                                ],
                                [
                                    0.5450728322354033,
                                    0.19839437409261415,
                                    0.18807696589424996,
                                    0.06845582777773253,
                                ],
                                [
                                    0.7085911024093945,
                                    0.03487610391862289,
                                    0.24449882055993732,
                                    0.012033973112045179,
                                ],
                                [
                                    0.7063218903622244,
                                    0.25708544080547163,
                                    0.026827907767428903,
                                    0.009764761064875055,
                                ],
                                [
                                    0.9182138190507091,
                                    0.04519351211698697,
                                    0.03487610391862285,
                                    0.0017165649136811055,
                                ],
                                [
                                    0.02645560556877285,
                                    0.7066941925608806,
                                    0.009629251354415343,
                                    0.25722095051593125,
                                ],
                                [
                                    0.028148348986680238,
                                    0.7519115261736411,
                                    0.00793650793650795,
                                    0.2120036169031706,
                                ],
                                [
                                    0.02745723901254202,
                                    0.7334502815850511,
                                    0.00862761791064617,
                                    0.23046486149176065,
                                ],
                                [
                                    0.035694230404447747,
                                    0.7252132901931454,
                                    0.011215846626220324,
                                    0.2278766327761865,
                                ],
                                [
                                    0.02784786553128245,
                                    0.7438848751737905,
                                    0.008236991391905738,
                                    0.22003026790302121,
                                ],
                                [
                                    0.03620204231356357,
                                    0.7355306983915094,
                                    0.010708034717104506,
                                    0.21755922457782245,
                                ],
                                [
                                    0.10503816210550808,
                                    0.48668379242875603,
                                    0.07247453841306929,
                                    0.3358035070526666,
                                ],
                                [
                                    0.14600194167317923,
                                    0.6764853578082434,
                                    0.03151075884539815,
                                    0.14600194167317926,
                                ],
                                [
                                    0.1292773298164012,
                                    0.5989935456687692,
                                    0.04823537070217617,
                                    0.22349375381265343,
                                ],
                                [
                                    0.16805967979630446,
                                    0.5602111956888659,
                                    0.06270566515085405,
                                    0.20902345936397557,
                                ],
                                [
                                    0.1387303505386742,
                                    0.6427931693750772,
                                    0.03878234997990317,
                                    0.17969413010634538,
                                ],
                                [
                                    0.18034854465721437,
                                    0.6011749752565371,
                                    0.05041680028994416,
                                    0.1680596797963044,
                                ],
                                [
                                    0.147930488633566,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.3786958335807245,
                                ],
                                [
                                    0.3402391523967764,
                                    0.5443781751296444,
                                    0.04437817512964435,
                                    0.07100449734393487,
                                ],
                                [
                                    0.2617237470294055,
                                    0.4187545577641474,
                                    0.12289358049701526,
                                    0.19662811470943187,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.30610192215904986,
                                    0.48975905510808226,
                                    0.07851540536737092,
                                    0.12562361736549701,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.10503816210550813,
                                    0.07247453841306935,
                                    0.48668379242875587,
                                    0.33580350705266665,
                                ],
                                [
                                    0.5602111956888659,
                                    0.38653615988255313,
                                    0.03151075884539816,
                                    0.021741885583182883,
                                ],
                                [
                                    0.3743740391887428,
                                    0.2583116949131925,
                                    0.2173479153455212,
                                    0.1499663505525435,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317931,
                                    0.2825508626240855,
                                    0.0847634032739792,
                                ],
                                [
                                    0.4794122012942509,
                                    0.3307862333262618,
                                    0.11230975324001313,
                                    0.07749181213947418,
                                ],
                                [
                                    0.6232327133796622,
                                    0.18696572124085045,
                                    0.14600194167317926,
                                    0.04379962370630804,
                                ],
                                [
                                    0.026455605568772845,
                                    0.009629251354415346,
                                    0.7066941925608805,
                                    0.25722095051593136,
                                ],
                                [
                                    0.7252132901931454,
                                    0.2639614896993748,
                                    0.007936507936507948,
                                    0.0028887121709719457,
                                ],
                                [
                                    0.43992586846054343,
                                    0.16012322052896905,
                                    0.2932239296691099,
                                    0.10672698134137766,
                                ],
                                [
                                    0.5719007400028322,
                                    0.02814834898668023,
                                    0.3811891829664997,
                                    0.018761728043987843,
                                ],
                                [
                                    0.6011749265873646,
                                    0.21881428724182653,
                                    0.13197487154228876,
                                    0.04803591462852017,
                                ],
                                [
                                    0.7815234566441468,
                                    0.03846575718504431,
                                    0.17156646632518516,
                                    0.008444319845623766,
                                ],
                                [
                                    0.0171960567526404,
                                    0.45934890473202555,
                                    0.018888800170547792,
                                    0.5045662383447862,
                                ],
                                [
                                    0.018888800170547792,
                                    0.5045662383447862,
                                    0.0171960567526404,
                                    0.45934890473202555,
                                ],
                                [
                                    0.01784711520222388,
                                    0.4767402747440362,
                                    0.01823774172096431,
                                    0.4871748683327756,
                                ],
                                [
                                    0.023201132560776126,
                                    0.47138625738548395,
                                    0.023708944469891947,
                                    0.481703665583848,
                                ],
                                [
                                    0.01823774172096431,
                                    0.4871748683327756,
                                    0.01784711520222388,
                                    0.4767402747440362,
                                ],
                                [
                                    0.023708944469891947,
                                    0.481703665583848,
                                    0.023201132560776126,
                                    0.47138625738548395,
                                ],
                                [
                                    0.06827446047545313,
                                    0.3163428670509677,
                                    0.10923824004312424,
                                    0.5061444324304549,
                                ],
                                [
                                    0.10923824004312425,
                                    0.506144432430455,
                                    0.06827446047545312,
                                    0.31634286705096765,
                                ],
                                [
                                    0.08402983989815219,
                                    0.3893438378875573,
                                    0.09348286062042518,
                                    0.43314346159386535,
                                ],
                                [
                                    0.10923824004312431,
                                    0.36413543774258517,
                                    0.12152710490403419,
                                    0.40509921731025633,
                                ],
                                [
                                    0.09348286062042518,
                                    0.43314346159386535,
                                    0.08402983989815219,
                                    0.3893438378875573,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.09615433188160519,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.4615370043551844,
                                ],
                                [
                                    0.2884629956448156,
                                    0.4615370043551844,
                                    0.09615433188160519,
                                    0.1538456681183948,
                                ],
                                [
                                    0.17011957619838822,
                                    0.27218908756482224,
                                    0.21449775132803253,
                                    0.343193584908757,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.2144977513280326,
                                    0.3431935849087571,
                                    0.1701195761983882,
                                    0.2721890875648222,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.06827446047545314,
                                    0.047108211998126114,
                                    0.5234474940588109,
                                    0.3611698334676099,
                                ],
                                [
                                    0.5234474940588109,
                                    0.3611698334676099,
                                    0.06827446047545314,
                                    0.047108211998126114,
                                ],
                                [
                                    0.24334189621437793,
                                    0.16790175352633332,
                                    0.34838005831988605,
                                    0.24037629193940266,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974367,
                                    0.4528917880018739,
                                    0.13586456225741483,
                                ],
                                [
                                    0.34838005831988605,
                                    0.24037629193940266,
                                    0.243341896214378,
                                    0.16790175352633332,
                                ],
                                [
                                    0.4528917880018739,
                                    0.13586456225741483,
                                    0.31634286705096765,
                                    0.09490078268974368,
                                ],
                                [
                                    0.017196056752640392,
                                    0.006258981762693645,
                                    0.715953741377013,
                                    0.26059122010765307,
                                ],
                                [
                                    0.715953741377013,
                                    0.26059122010765307,
                                    0.017196056752640392,
                                    0.006258981762693645,
                                ],
                                [
                                    0.28595037000141615,
                                    0.10407956757874463,
                                    0.44719942812823715,
                                    0.16277063429160207,
                                ],
                                [
                                    0.3717336031640088,
                                    0.018296334416152003,
                                    0.5813563198053231,
                                    0.02861374261451607,
                                ],
                                [
                                    0.4471994281282372,
                                    0.1627706342916021,
                                    0.2859503700014161,
                                    0.1040795675787446,
                                ],
                                [
                                    0.5813563198053232,
                                    0.028613742614516074,
                                    0.3717336031640087,
                                    0.018296334416152,
                                ],
                                [
                                    0.007936507936507952,
                                    0.21200361690317066,
                                    0.028148348986680238,
                                    0.7519115261736411,
                                ],
                                [
                                    0.009629251354415346,
                                    0.25722095051593136,
                                    0.026455605568772845,
                                    0.7066941925608805,
                                ],
                                [
                                    0.00823699139190574,
                                    0.22003026790302124,
                                    0.02784786553128245,
                                    0.7438848751737905,
                                ],
                                [
                                    0.010708034717104508,
                                    0.21755922457782245,
                                    0.03620204231356357,
                                    0.7355306983915094,
                                ],
                                [
                                    0.00862761791064617,
                                    0.23046486149176068,
                                    0.02745723901254202,
                                    0.7334502815850511,
                                ],
                                [
                                    0.011215846626220325,
                                    0.22787663277618653,
                                    0.035694230404447747,
                                    0.7252132901931454,
                                ],
                                [
                                    0.03151075884539816,
                                    0.14600194167317931,
                                    0.1460019416731792,
                                    0.6764853578082433,
                                ],
                                [
                                    0.0724745384130693,
                                    0.33580350705266665,
                                    0.10503816210550806,
                                    0.486683792428756,
                                ],
                                [
                                    0.03878234997990319,
                                    0.17969413010634547,
                                    0.1387303505386742,
                                    0.6427931693750771,
                                ],
                                [
                                    0.05041680028994418,
                                    0.16805967979630448,
                                    0.18034854465721434,
                                    0.6011749752565371,
                                ],
                                [
                                    0.04823537070217618,
                                    0.2234937538126535,
                                    0.1292773298164012,
                                    0.5989935456687692,
                                ],
                                [
                                    0.06270566515085405,
                                    0.20902345936397562,
                                    0.16805967979630446,
                                    0.5602111956888659,
                                ],
                                [
                                    0.044378175129644364,
                                    0.0710044973439349,
                                    0.3402391523967764,
                                    0.5443781751296444,
                                ],
                                [
                                    0.23668683889285475,
                                    0.3786958335807245,
                                    0.147930488633566,
                                    0.23668683889285475,
                                ],
                                [
                                    0.07851540536737094,
                                    0.12562361736549704,
                                    0.3061019221590498,
                                    0.4897590551080822,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.1228935804970153,
                                    0.19662811470943195,
                                    0.26172374702940543,
                                    0.41875455776414733,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.03151075884539815,
                                    0.021741885583182873,
                                    0.5602111956888659,
                                    0.38653615988255313,
                                ],
                                [
                                    0.48668379242875587,
                                    0.33580350705266665,
                                    0.1050381621055081,
                                    0.07247453841306935,
                                ],
                                [
                                    0.11230975324001315,
                                    0.07749181213947419,
                                    0.4794122012942509,
                                    0.3307862333262618,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630805,
                                    0.6232327133796622,
                                    0.18696572124085045,
                                ],
                                [
                                    0.2173479153455212,
                                    0.1499663505525435,
                                    0.3743740391887428,
                                    0.2583116949131925,
                                ],
                                [
                                    0.2825508626240855,
                                    0.0847634032739792,
                                    0.486683792428756,
                                    0.14600194167317931,
                                ],
                                [
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                    0.7252132901931454,
                                    0.2639614896993748,
                                ],
                                [
                                    0.7066941925608805,
                                    0.25722095051593136,
                                    0.026455605568772834,
                                    0.009629251354415343,
                                ],
                                [
                                    0.1319748715422889,
                                    0.04803591462852023,
                                    0.6011749265873644,
                                    0.21881428724182647,
                                ],
                                [
                                    0.17156646632518535,
                                    0.008444319845623775,
                                    0.7815234566441466,
                                    0.038465757185044296,
                                ],
                                [
                                    0.29322392966910993,
                                    0.10672698134137769,
                                    0.4399258684605434,
                                    0.160123220528969,
                                ],
                                [
                                    0.3811891829664998,
                                    0.018761728043987846,
                                    0.5719007400028322,
                                    0.028148348986680227,
                                ],
                                [
                                    0.0016133366937802012,
                                    0.04309618500986464,
                                    0.03447152022940799,
                                    0.9208189580669471,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.08831351862262532,
                                    0.0327787768115006,
                                    0.8756016244541865,
                                ],
                                [
                                    0.0016744190978230573,
                                    0.04472784602372915,
                                    0.03441043782536513,
                                    0.9191872970530827,
                                ],
                                [
                                    0.0021767338312494965,
                                    0.04422553129030271,
                                    0.044733343199418574,
                                    0.9088643916790292,
                                ],
                                [
                                    0.002065045616563489,
                                    0.055162439612468604,
                                    0.0340198113066247,
                                    0.9087527034643432,
                                ],
                                [
                                    0.002684545740365315,
                                    0.05454293948866678,
                                    0.04422553129030276,
                                    0.8985469834806652,
                                ],
                                [
                                    0.006405520400261619,
                                    0.02967933652292657,
                                    0.17110718011831574,
                                    0.7928079629584961,
                                ],
                                [
                                    0.047369299967932765,
                                    0.21948090190241393,
                                    0.1301434005506446,
                                    0.6030063975790088,
                                ],
                                [
                                    0.007883692524994046,
                                    0.0365282988534425,
                                    0.16962900799358333,
                                    0.7859590006279802,
                                ],
                                [
                                    0.010248748510235139,
                                    0.0341632428682014,
                                    0.22051659643692337,
                                    0.7350714121846401,
                                ],
                                [
                                    0.017336713247267037,
                                    0.08032792255975053,
                                    0.16017598727131033,
                                    0.7421593769216721,
                                ],
                                [
                                    0.022537613371145016,
                                    0.07512702243587255,
                                    0.2082277315760135,
                                    0.694107632616969,
                                ],
                                [
                                    0.009021214230797044,
                                    0.014433824284536993,
                                    0.3755961132956237,
                                    0.6009488481890423,
                                ],
                                [
                                    0.20132987799400742,
                                    0.3221251605213266,
                                    0.18328744953241333,
                                    0.29325751195225264,
                                ],
                                [
                                    0.015960644847781997,
                                    0.025536822129146135,
                                    0.36865668267863877,
                                    0.5898458503444332,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.06033881997742636,
                                    0.09654131947308102,
                                    0.3242785075489944,
                                    0.5188413530004983,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.006405520400261612,
                                    0.004419699707218271,
                                    0.5853164341340024,
                                    0.4038583457585177,
                                ],
                                [
                                    0.46157855398361936,
                                    0.318481321176702,
                                    0.13014340055064466,
                                    0.08979672428903396,
                                ],
                                [
                                    0.022830374192410626,
                                    0.015752568383009095,
                                    0.5688915803418534,
                                    0.3925254770827269,
                                ],
                                [
                                    0.02967933652292658,
                                    0.00890360605249314,
                                    0.739555318529915,
                                    0.22186173889466537,
                                ],
                                [
                                    0.1278685362979187,
                                    0.0882271067960784,
                                    0.46385341823634535,
                                    0.32005093866965756,
                                ],
                                [
                                    0.1662282574738328,
                                    0.04986738562016429,
                                    0.6030063975790086,
                                    0.1808979593269942,
                                ],
                                [
                                    0.0016133366937802177,
                                    0.000587218633243017,
                                    0.7315364614358731,
                                    0.2662629832371037,
                                ],
                                [
                                    0.7003710213181528,
                                    0.2549194569782024,
                                    0.032778776811500585,
                                    0.011930744892144277,
                                ],
                                [
                                    0.026827907767428893,
                                    0.00976476106487505,
                                    0.7063218903622244,
                                    0.25708544080547163,
                                ],
                                [
                                    0.034876103918622836,
                                    0.0017165649136811048,
                                    0.9182138190507091,
                                    0.04519351211698697,
                                ],
                                [
                                    0.18807696589425002,
                                    0.06845582777773254,
                                    0.5450728322354033,
                                    0.19839437409261415,
                                ],
                                [
                                    0.24449882055993738,
                                    0.012033973112045182,
                                    0.7085911024093945,
                                    0.03487610391862289,
                                ],
                                [
                                    0.04061325326555385,
                                    0.8677671480001333,
                                    0.004096268438090991,
                                    0.08752333029622184,
                                ],
                                [
                                    0.04271058037267615,
                                    0.912579897923679,
                                    0.0019989413309686875,
                                    0.042710580372676124,
                                ],
                                [
                                    0.042150908210752416,
                                    0.9006216065602155,
                                    0.0025586134928924243,
                                    0.05466887173613966,
                                ],
                                [
                                    0.04422553129030276,
                                    0.8985469834806652,
                                    0.002684545740365314,
                                    0.054542939488666765,
                                ],
                                [
                                    0.04263489862409452,
                                    0.9109628362543533,
                                    0.00207462307955032,
                                    0.04432764204200188,
                                ],
                                [
                                    0.044733343199418574,
                                    0.9088643916790292,
                                    0.0021767338312494965,
                                    0.04422553129030271,
                                ],
                                [
                                    0.16124905812682114,
                                    0.5719007400028323,
                                    0.05869106671285747,
                                    0.2081591351574891,
                                ],
                                [
                                    0.21200361690317066,
                                    0.7519115261736411,
                                    0.00793650793650794,
                                    0.028148348986680196,
                                ],
                                [
                                    0.19845975264786142,
                                    0.703875611545121,
                                    0.021480372191817185,
                                    0.07618426361520035,
                                ],
                                [
                                    0.2082277315760135,
                                    0.694107632616969,
                                    0.02253761337114501,
                                    0.07512702243587252,
                                ],
                                [
                                    0.21017214591152655,
                                    0.7454158627100369,
                                    0.009767978928152057,
                                    0.03464401245028445,
                                ],
                                [
                                    0.22051659643692337,
                                    0.7350714121846401,
                                    0.01024874851023513,
                                    0.034163242868201375,
                                ],
                                [
                                    0.22709510031642177,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.27400517734708985,
                                ],
                                [
                                    0.46536758105875475,
                                    0.5111773804259112,
                                    0.011177380425911203,
                                    0.012277658089422806,
                                ],
                                [
                                    0.401784521472515,
                                    0.44133533907697775,
                                    0.07476044001215103,
                                    0.08211969943835627,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.4567695526824345,
                                    0.5017329803406373,
                                    0.019775408802231387,
                                    0.02172205817469669,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.16124905812682114,
                                    0.058691066712857495,
                                    0.5719007400028322,
                                    0.2081591351574892,
                                ],
                                [
                                    0.7252132901931454,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                ],
                                [
                                    0.5747193210185917,
                                    0.2091850358874112,
                                    0.15843047711106154,
                                    0.0576651659829355,
                                ],
                                [
                                    0.6030063975790086,
                                    0.1808979593269942,
                                    0.16622825747383277,
                                    0.049867385620164274,
                                ],
                                [
                                    0.7048627215692365,
                                    0.256554335855344,
                                    0.028287076560416922,
                                    0.010295866015002729,
                                ],
                                [
                                    0.739555318529915,
                                    0.2218617388946654,
                                    0.02967933652292653,
                                    0.008903606052493124,
                                ],
                                [
                                    0.040613253265553845,
                                    0.004096268438090994,
                                    0.8677671480001332,
                                    0.08752333029622192,
                                ],
                                [
                                    0.9063814599347184,
                                    0.09141798473825839,
                                    0.0019989413309686884,
                                    0.00020161399605452118,
                                ],
                                [
                                    0.6753510392121238,
                                    0.06811616711589358,
                                    0.23302936205356317,
                                    0.023503431618419324,
                                ],
                                [
                                    0.7085911024093945,
                                    0.03487610391862289,
                                    0.24449882055993732,
                                    0.012033973112045179,
                                ],
                                [
                                    0.8751403380684164,
                                    0.08826699309927963,
                                    0.03324006319727067,
                                    0.003352605635033287,
                                ],
                                [
                                    0.9182138190507091,
                                    0.04519351211698697,
                                    0.03487610391862285,
                                    0.0017165649136811055,
                                ],
                                [
                                    0.03277877681150057,
                                    0.7003710213181529,
                                    0.011930744892144267,
                                    0.25491945697820234,
                                ],
                                [
                                    0.03487610391862287,
                                    0.7451837712416985,
                                    0.009833417785021965,
                                    0.2101067070546566,
                                ],
                                [
                                    0.034019811306624674,
                                    0.7268877092909685,
                                    0.010689710397020165,
                                    0.22840276900538667,
                                ],
                                [
                                    0.035694230404447747,
                                    0.7252132901931454,
                                    0.011215846626220324,
                                    0.2278766327761865,
                                ],
                                [
                                    0.034503801719966774,
                                    0.7372289389851062,
                                    0.010205719983678061,
                                    0.2180615393112489,
                                ],
                                [
                                    0.03620204231356357,
                                    0.7355306983915094,
                                    0.010708034717104506,
                                    0.21755922457782245,
                                ],
                                [
                                    0.1301434005506447,
                                    0.46157855398361947,
                                    0.08979672428903393,
                                    0.3184813211767019,
                                ],
                                [
                                    0.18089795932699423,
                                    0.6415893401544284,
                                    0.0390421655126844,
                                    0.13847053500589301,
                                ],
                                [
                                    0.1601759872713104,
                                    0.5680948882138599,
                                    0.0597641375683682,
                                    0.2119649869464614,
                                ],
                                [
                                    0.16805967979630446,
                                    0.5602111956888659,
                                    0.06270566515085405,
                                    0.20902345936397557,
                                ],
                                [
                                    0.17188838053497554,
                                    0.6096351393787759,
                                    0.04805174430470307,
                                    0.1704247357815455,
                                ],
                                [
                                    0.18034854465721437,
                                    0.6011749752565371,
                                    0.05041680028994416,
                                    0.1680596797963044,
                                ],
                                [
                                    0.18328744953241333,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.3221251605213266,
                                ],
                                [
                                    0.4215599302747463,
                                    0.46305739725167444,
                                    0.05498503120991964,
                                    0.06039764126365958,
                                ],
                                [
                                    0.32427850754899445,
                                    0.3561997972445584,
                                    0.15226645393567154,
                                    0.1672552412707756,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.3792635387589141,
                                    0.416597438508218,
                                    0.0972814227257519,
                                    0.10685760000711604,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.1301434005506447,
                                    0.0473692999679328,
                                    0.6030063975790086,
                                    0.2194809019024139,
                                ],
                                [
                                    0.694107632616969,
                                    0.25263972295445003,
                                    0.0390421655126844,
                                    0.014210478915896644,
                                ],
                                [
                                    0.46385341823634535,
                                    0.16883231586558992,
                                    0.26929637989330796,
                                    0.09801788600475676,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317931,
                                    0.2825508626240855,
                                    0.0847634032739792,
                                ],
                                [
                                    0.59399681878699,
                                    0.21620161583352268,
                                    0.13915297934266332,
                                    0.05064858603682399,
                                ],
                                [
                                    0.6232327133796622,
                                    0.18696572124085045,
                                    0.14600194167317926,
                                    0.04379962370630804,
                                ],
                                [
                                    0.0327787768115006,
                                    0.0033060801116875952,
                                    0.8756016244541865,
                                    0.08831351862262532,
                                ],
                                [
                                    0.8985469834806651,
                                    0.09062779641185499,
                                    0.00983341778502197,
                                    0.0009918023224579236,
                                ],
                                [
                                    0.5450728322354034,
                                    0.05497625675410915,
                                    0.3633075690302838,
                                    0.03664334198020376,
                                ],
                                [
                                    0.5719007400028322,
                                    0.02814834898668023,
                                    0.3811891829664997,
                                    0.018761728043987843,
                                ],
                                [
                                    0.7448621310916959,
                                    0.0751270827374952,
                                    0.1635182701739912,
                                    0.016492515996817718,
                                ],
                                [
                                    0.7815234566441468,
                                    0.03846575718504431,
                                    0.17156646632518516,
                                    0.008444319845623766,
                                ],
                                [
                                    0.021306097298261266,
                                    0.4552388641864047,
                                    0.023403424405383573,
                                    0.5000516141099505,
                                ],
                                [
                                    0.023403424405383573,
                                    0.5000516141099505,
                                    0.021306097298261266,
                                    0.4552388641864047,
                                ],
                                [
                                    0.022112765645151366,
                                    0.4724746243011087,
                                    0.022596756058493473,
                                    0.48281585399524646,
                                ],
                                [
                                    0.023201132560776126,
                                    0.47138625738548395,
                                    0.023708944469891947,
                                    0.481703665583848,
                                ],
                                [
                                    0.022596756058493473,
                                    0.48281585399524646,
                                    0.022112765645151366,
                                    0.4724746243011087,
                                ],
                                [
                                    0.023708944469891947,
                                    0.481703665583848,
                                    0.023201132560776126,
                                    0.47138625738548395,
                                ],
                                [
                                    0.08459278303166456,
                                    0.3000245444947563,
                                    0.13534734180801405,
                                    0.4800353306655651,
                                ],
                                [
                                    0.13534734180801408,
                                    0.4800353306655652,
                                    0.08459278303166454,
                                    0.3000245444947562,
                                ],
                                [
                                    0.10411386578800674,
                                    0.36925981199770275,
                                    0.11582625905167188,
                                    0.41080006316261863,
                                ],
                                [
                                    0.10923824004312431,
                                    0.36413543774258517,
                                    0.12152710490403419,
                                    0.40509921731025633,
                                ],
                                [
                                    0.11582625905167188,
                                    0.41080006316261863,
                                    0.10411386578800674,
                                    0.36925981199770275,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.11913624037116649,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.3925912788865005,
                                ],
                                [
                                    0.3574087211134995,
                                    0.3925912788865005,
                                    0.11913624037116649,
                                    0.1308637596288335,
                                ],
                                [
                                    0.21077996513737318,
                                    0.23152869862583725,
                                    0.2657649963472928,
                                    0.2919263398894968,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.26576499634729284,
                                    0.29192633988949684,
                                    0.21077996513737315,
                                    0.23152869862583722,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.08459278303166454,
                                    0.030789889441914717,
                                    0.6485570150979888,
                                    0.23606031242843198,
                                ],
                                [
                                    0.6485570150979888,
                                    0.23606031242843198,
                                    0.08459278303166454,
                                    0.030789889441914717,
                                ],
                                [
                                    0.3015031987895043,
                                    0.10974045095120695,
                                    0.431646599340149,
                                    0.15710975091913976,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974367,
                                    0.4528917880018739,
                                    0.13586456225741483,
                                ],
                                [
                                    0.431646599340149,
                                    0.15710975091913976,
                                    0.3015031987895044,
                                    0.10974045095120696,
                                ],
                                [
                                    0.4528917880018739,
                                    0.13586456225741483,
                                    0.31634286705096765,
                                    0.09490078268974368,
                                ],
                                [
                                    0.021306097298261276,
                                    0.0021489412170727588,
                                    0.8870743039674258,
                                    0.08947065751724015,
                                ],
                                [
                                    0.8870743039674258,
                                    0.08947065751724015,
                                    0.021306097298261276,
                                    0.0021489412170727588,
                                ],
                                [
                                    0.35429555120469736,
                                    0.035734386375463445,
                                    0.5540848500609897,
                                    0.05588521235884947,
                                ],
                                [
                                    0.3717336031640088,
                                    0.018296334416152003,
                                    0.5813563198053231,
                                    0.02861374261451607,
                                ],
                                [
                                    0.5540848500609898,
                                    0.055885212358849475,
                                    0.35429555120469725,
                                    0.03573438637546344,
                                ],
                                [
                                    0.5813563198053232,
                                    0.028613742614516074,
                                    0.3717336031640087,
                                    0.018296334416152,
                                ],
                                [
                                    0.009833417785021966,
                                    0.21010670705465664,
                                    0.03487610391862287,
                                    0.7451837712416985,
                                ],
                                [
                                    0.011930744892144272,
                                    0.2549194569782024,
                                    0.032778776811500564,
                                    0.7003710213181528,
                                ],
                                [
                                    0.010205719983678061,
                                    0.21806153931124891,
                                    0.034503801719966774,
                                    0.7372289389851062,
                                ],
                                [
                                    0.010708034717104508,
                                    0.21755922457782245,
                                    0.03620204231356357,
                                    0.7355306983915094,
                                ],
                                [
                                    0.010689710397020167,
                                    0.2284027690053867,
                                    0.034019811306624674,
                                    0.7268877092909685,
                                ],
                                [
                                    0.011215846626220325,
                                    0.22787663277618653,
                                    0.035694230404447747,
                                    0.7252132901931454,
                                ],
                                [
                                    0.03904216551268441,
                                    0.13847053500589307,
                                    0.1808979593269942,
                                    0.6415893401544284,
                                ],
                                [
                                    0.08979672428903396,
                                    0.318481321176702,
                                    0.13014340055064466,
                                    0.46157855398361936,
                                ],
                                [
                                    0.04805174430470309,
                                    0.17042473578154557,
                                    0.17188838053497554,
                                    0.6096351393787758,
                                ],
                                [
                                    0.05041680028994418,
                                    0.16805967979630448,
                                    0.18034854465721434,
                                    0.6011749752565371,
                                ],
                                [
                                    0.059764137568368216,
                                    0.21196498694646146,
                                    0.1601759872713104,
                                    0.5680948882138599,
                                ],
                                [
                                    0.06270566515085405,
                                    0.20902345936397562,
                                    0.16805967979630446,
                                    0.5602111956888659,
                                ],
                                [
                                    0.054985031209919655,
                                    0.060397641263659596,
                                    0.4215599302747463,
                                    0.46305739725167444,
                                ],
                                [
                                    0.29325751195225264,
                                    0.3221251605213266,
                                    0.18328744953241333,
                                    0.20132987799400742,
                                ],
                                [
                                    0.09728142272575192,
                                    0.10685760000711607,
                                    0.37926353875891405,
                                    0.41659743850821795,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.1522664539356716,
                                    0.16725524127077565,
                                    0.3242785075489944,
                                    0.35619979724455836,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.039042165512684385,
                                    0.014210478915896638,
                                    0.694107632616969,
                                    0.25263972295445003,
                                ],
                                [
                                    0.6030063975790086,
                                    0.2194809019024139,
                                    0.13014340055064466,
                                    0.04736929996793279,
                                ],
                                [
                                    0.13915297934266332,
                                    0.050648586036824005,
                                    0.59399681878699,
                                    0.21620161583352268,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630805,
                                    0.6232327133796622,
                                    0.18696572124085045,
                                ],
                                [
                                    0.26929637989330796,
                                    0.09801788600475676,
                                    0.46385341823634535,
                                    0.16883231586558992,
                                ],
                                [
                                    0.2825508626240855,
                                    0.0847634032739792,
                                    0.486683792428756,
                                    0.14600194167317931,
                                ],
                                [
                                    0.00983341778502196,
                                    0.0009918023224579225,
                                    0.8985469834806651,
                                    0.09062779641185499,
                                ],
                                [
                                    0.8756016244541865,
                                    0.08831351862262532,
                                    0.032778776811500585,
                                    0.003306080111687594,
                                ],
                                [
                                    0.1635182701739914,
                                    0.016492515996817735,
                                    0.7448621310916957,
                                    0.07512708273749517,
                                ],
                                [
                                    0.17156646632518535,
                                    0.008444319845623775,
                                    0.7815234566441466,
                                    0.038465757185044296,
                                ],
                                [
                                    0.3633075690302839,
                                    0.03664334198020377,
                                    0.5450728322354033,
                                    0.054976256754109144,
                                ],
                                [
                                    0.3811891829664998,
                                    0.018761728043987846,
                                    0.5719007400028322,
                                    0.028148348986680227,
                                ],
                                [
                                    0.001998941330968689,
                                    0.04271058037267615,
                                    0.04271058037267615,
                                    0.912579897923679,
                                ],
                                [
                                    0.004096268438090994,
                                    0.08752333029622192,
                                    0.040613253265553845,
                                    0.8677671480001332,
                                ],
                                [
                                    0.0020746230795503206,
                                    0.04432764204200189,
                                    0.04263489862409452,
                                    0.9109628362543533,
                                ],
                                [
                                    0.0021767338312494965,
                                    0.04422553129030271,
                                    0.044733343199418574,
                                    0.9088643916790292,
                                ],
                                [
                                    0.0025586134928924247,
                                    0.05466887173613967,
                                    0.042150908210752416,
                                    0.9006216065602155,
                                ],
                                [
                                    0.002684545740365315,
                                    0.05454293948866678,
                                    0.04422553129030276,
                                    0.8985469834806652,
                                ],
                                [
                                    0.007936507936507952,
                                    0.028148348986680238,
                                    0.21200361690317066,
                                    0.7519115261736411,
                                ],
                                [
                                    0.058691066712857495,
                                    0.2081591351574892,
                                    0.16124905812682114,
                                    0.5719007400028322,
                                ],
                                [
                                    0.009767978928152064,
                                    0.03464401245028448,
                                    0.21017214591152655,
                                    0.7454158627100369,
                                ],
                                [
                                    0.010248748510235139,
                                    0.0341632428682014,
                                    0.22051659643692337,
                                    0.7350714121846401,
                                ],
                                [
                                    0.021480372191817188,
                                    0.07618426361520038,
                                    0.19845975264786142,
                                    0.703875611545121,
                                ],
                                [
                                    0.022537613371145016,
                                    0.07512702243587255,
                                    0.2082277315760135,
                                    0.694107632616969,
                                ],
                                [
                                    0.011177380425911215,
                                    0.012277658089422822,
                                    0.46536758105875475,
                                    0.5111773804259112,
                                ],
                                [
                                    0.2494498611682442,
                                    0.27400517734708985,
                                    0.22709510031642177,
                                    0.2494498611682442,
                                ],
                                [
                                    0.019775408802231415,
                                    0.021722058174696718,
                                    0.4567695526824345,
                                    0.5017329803406373,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.07476044001215107,
                                    0.08211969943835631,
                                    0.4017845214725149,
                                    0.4413353390769777,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                    0.7252132901931454,
                                    0.2639614896993748,
                                ],
                                [
                                    0.5719007400028322,
                                    0.2081591351574892,
                                    0.16124905812682114,
                                    0.058691066712857495,
                                ],
                                [
                                    0.028287076560416975,
                                    0.010295866015002746,
                                    0.7048627215692364,
                                    0.25655433585534393,
                                ],
                                [
                                    0.02967933652292658,
                                    0.00890360605249314,
                                    0.739555318529915,
                                    0.22186173889466537,
                                ],
                                [
                                    0.1584304771110616,
                                    0.057665165982935515,
                                    0.5747193210185917,
                                    0.2091850358874112,
                                ],
                                [
                                    0.1662282574738328,
                                    0.04986738562016429,
                                    0.6030063975790086,
                                    0.1808979593269942,
                                ],
                                [
                                    0.0019989413309687114,
                                    0.00020161399605452348,
                                    0.9063814599347184,
                                    0.09141798473825839,
                                ],
                                [
                                    0.8677671480001332,
                                    0.08752333029622192,
                                    0.040613253265553866,
                                    0.004096268438090996,
                                ],
                                [
                                    0.03324006319727066,
                                    0.0033526056350332858,
                                    0.8751403380684164,
                                    0.08826699309927963,
                                ],
                                [
                                    0.034876103918622836,
                                    0.0017165649136811048,
                                    0.9182138190507091,
                                    0.04519351211698697,
                                ],
                                [
                                    0.23302936205356323,
                                    0.023503431618419328,
                                    0.6753510392121238,
                                    0.06811616711589358,
                                ],
                                [
                                    0.24449882055993738,
                                    0.012033973112045182,
                                    0.7085911024093945,
                                    0.03487610391862289,
                                ],
                                [
                                    0.0019989413309687114,
                                    0.9063814599347185,
                                    0.00020161399605452332,
                                    0.09141798473825831,
                                ],
                                [
                                    0.0021021695508696182,
                                    0.9531883087454855,
                                    9.838577615361652e-05,
                                    0.04461113592749119,
                                ],
                                [
                                    0.0020481342190455196,
                                    0.9286870278984641,
                                    0.00015242110797771506,
                                    0.06911241677451271,
                                ],
                                [
                                    0.04366085815008371,
                                    0.8870743039674259,
                                    0.003249218880584362,
                                    0.06601561900190606,
                                ],
                                [
                                    0.002099748328995973,
                                    0.9520904523038476,
                                    0.00010080699802726166,
                                    0.045708992369129155,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.002148941217072757,
                                    0.04366085815008366,
                                ],
                                [
                                    0.007936507936507941,
                                    0.7252132901931455,
                                    0.0028887121709719418,
                                    0.26396148969937466,
                                ],
                                [
                                    0.010434593588739452,
                                    0.9534805494880724,
                                    0.00039062651874043086,
                                    0.035694230404447705,
                                ],
                                [
                                    0.009126958067436004,
                                    0.8339929024820567,
                                    0.0016982620400438795,
                                    0.1551818774104634,
                                ],
                                [
                                    0.19456284545150387,
                                    0.6485570150979889,
                                    0.03620249949565465,
                                    0.12067763995485266,
                                ],
                                [
                                    0.010376000893551758,
                                    0.9481265321295201,
                                    0.00044921921392812424,
                                    0.04104824776299995,
                                ],
                                [
                                    0.22118916766579436,
                                    0.7373133653572775,
                                    0.009576177281364126,
                                    0.03192128969556395,
                                ],
                                [
                                    0.011177380425911215,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.5111773804259112,
                                ],
                                [
                                    0.022904899683578235,
                                    0.9536400618010877,
                                    0.0005501388317558024,
                                    0.022904899683578207,
                                ],
                                [
                                    0.016766070638866825,
                                    0.6980513715881322,
                                    0.006688967876467213,
                                    0.2784935898965338,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.02262983026770033,
                                    0.9421876119592986,
                                    0.0008252082476337037,
                                    0.03435734952536731,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.007936507936507952,
                                    0.21200361690317066,
                                    0.028148348986680238,
                                    0.7519115261736411,
                                ],
                                [
                                    0.03569423040444776,
                                    0.9534805494880724,
                                    0.00039062651874043145,
                                    0.010434593588739452,
                                ],
                                [
                                    0.021164310720894374,
                                    0.5653507131836109,
                                    0.014920546202293817,
                                    0.3985644298932009,
                                ],
                                [
                                    0.4511676820964912,
                                    0.13534734180801408,
                                    0.3180669729563503,
                                    0.09541800313914443,
                                ],
                                [
                                    0.035043171954864276,
                                    0.9360891794760617,
                                    0.001041684968323912,
                                    0.02782596360075004,
                                ],
                                [
                                    0.7470286593636232,
                                    0.2241036920673028,
                                    0.022205995689218255,
                                    0.006661652879855697,
                                ],
                                [
                                    0.001998941330968689,
                                    0.04271058037267615,
                                    0.04271058037267615,
                                    0.912579897923679,
                                ],
                                [
                                    0.04461113592749122,
                                    0.9531883087454855,
                                    9.838577615361546e-05,
                                    0.002102169550869594,
                                ],
                                [
                                    0.02230556796374561,
                                    0.4765941543727428,
                                    0.02240395373989923,
                                    0.4786963239236124,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383583,
                                    0.4775936250382271,
                                    0.02350665262528449,
                                ],
                                [
                                    0.043611665262006875,
                                    0.9318330185591475,
                                    0.0010978564416379592,
                                    0.023457459737207653,
                                ],
                                [
                                    0.9296864985639484,
                                    0.04575818525720601,
                                    0.023403424405383556,
                                    0.0011518917734620578,
                                ],
                                [
                                    0.001613336693780218,
                                    0.7315364614358733,
                                    0.0005872186332430168,
                                    0.26626298323710357,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.7783433102466403,
                                    0.00048399041334210995,
                                    0.21945613442633646,
                                ],
                                [
                                    0.0016530400558438145,
                                    0.7495391865354037,
                                    0.0005475152711794203,
                                    0.2482602581375731,
                                ],
                                [
                                    0.035238485214234484,
                                    0.7159537413770131,
                                    0.011671591816433588,
                                    0.23713618159231892,
                                ],
                                [
                                    0.0017046541657942677,
                                    0.7729426109407872,
                                    0.0004959011612289669,
                                    0.22485683373218954,
                                ],
                                [
                                    0.03633876287774609,
                                    0.7383085022288354,
                                    0.010571314152921982,
                                    0.21478142074049653,
                                ],
                                [
                                    0.0064055204002616125,
                                    0.5853164341340025,
                                    0.00441969970721827,
                                    0.4038583457585176,
                                ],
                                [
                                    0.008903606052493124,
                                    0.8135836934289296,
                                    0.0019216140549867587,
                                    0.17559108646359065,
                                ],
                                [
                                    0.007366327427754993,
                                    0.6731119773657979,
                                    0.00345889267972489,
                                    0.31606280252672225,
                                ],
                                [
                                    0.1570308107347419,
                                    0.523447494058811,
                                    0.07373453421241662,
                                    0.24578716099403053,
                                ],
                                [
                                    0.008615370253870748,
                                    0.7872456070132614,
                                    0.002209849853609135,
                                    0.2019291728792588,
                                ],
                                [
                                    0.1836571329490324,
                                    0.6122038443180997,
                                    0.0471082119981261,
                                    0.15703081073474184,
                                ],
                                [
                                    0.009021214230797044,
                                    0.3755961132956237,
                                    0.014433824284536993,
                                    0.6009488481890423,
                                ],
                                [
                                    0.020748733488464063,
                                    0.8638685940379567,
                                    0.0027063050268699733,
                                    0.11267636744670925,
                                ],
                                [
                                    0.013531821346195568,
                                    0.5633941699434356,
                                    0.009923217169138469,
                                    0.41315079154123036,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.019395580975029077,
                                    0.8075304103146022,
                                    0.0040594575403049594,
                                    0.16901455117006386,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.006405520400261623,
                                    0.17110718011831585,
                                    0.029679336522926567,
                                    0.792807962958496,
                                ],
                                [
                                    0.03416324286820143,
                                    0.9125841127032176,
                                    0.0019216140549867615,
                                    0.05133103037359428,
                                ],
                                [
                                    0.017081621434100715,
                                    0.4562920563516088,
                                    0.019003235489087476,
                                    0.5076230867252031,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312431,
                                    0.40509921731025633,
                                    0.12152710490403419,
                                ],
                                [
                                    0.030960482668070617,
                                    0.8270305226440596,
                                    0.005124374255117571,
                                    0.13688462043275215,
                                ],
                                [
                                    0.6599964150097172,
                                    0.19799459030241304,
                                    0.10923824004312427,
                                    0.03277075464474546,
                                ],
                                [
                                    0.0016133366937802012,
                                    0.03447152022940799,
                                    0.04309618500986464,
                                    0.9208189580669471,
                                ],
                                [
                                    0.04422553129030273,
                                    0.9449492486022174,
                                    0.0004839904133421048,
                                    0.010341229694137788,
                                ],
                                [
                                    0.018002725099530485,
                                    0.38465703088848435,
                                    0.026706796604114354,
                                    0.5706334474078708,
                                ],
                                [
                                    0.38377095581746706,
                                    0.018888800170547785,
                                    0.5693189671518649,
                                    0.02802127686012029,
                                ],
                                [
                                    0.03930882239779175,
                                    0.839895895074889,
                                    0.005400699305853086,
                                    0.11539458322146608,
                                ],
                                [
                                    0.8379611564503106,
                                    0.041243561022370215,
                                    0.1151287665190213,
                                    0.005666516008297855,
                                ],
                                [
                                    0.001048663553561164,
                                    0.4754962979311048,
                                    0.0011518917734620708,
                                    0.522303146741872,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.522303146741872,
                                    0.001048663553561164,
                                    0.4754962979311048,
                                ],
                                [
                                    0.0010744706085363907,
                                    0.4871980101337966,
                                    0.001126084718486844,
                                    0.5106014345391802,
                                ],
                                [
                                    0.022904899683578235,
                                    0.46536758105875475,
                                    0.02400517734708984,
                                    0.4877223419105772,
                                ],
                                [
                                    0.001126084718486844,
                                    0.5106014345391802,
                                    0.0010744706085363907,
                                    0.4871980101337966,
                                ],
                                [
                                    0.02400517734708984,
                                    0.4877223419105772,
                                    0.022904899683578235,
                                    0.46536758105875475,
                                ],
                                [
                                    0.004163567227624187,
                                    0.3804537602987967,
                                    0.006661652879855696,
                                    0.6087210195937235,
                                ],
                                [
                                    0.006661652879855697,
                                    0.6087210195937236,
                                    0.004163567227624186,
                                    0.3804537602987966,
                                ],
                                [
                                    0.004788088640682064,
                                    0.43752057512252834,
                                    0.0060371314667978185,
                                    0.5516542047699917,
                                ],
                                [
                                    0.102069511366434,
                                    0.34023915239677643,
                                    0.1286958335807245,
                                    0.42899550265606506,
                                ],
                                [
                                    0.006037131466797819,
                                    0.5516542047699918,
                                    0.004788088640682063,
                                    0.4375205751225283,
                                ],
                                [
                                    0.12869583358072453,
                                    0.4289955026560652,
                                    0.10206951136643398,
                                    0.3402391523967764,
                                ],
                                [
                                    0.005863759628833509,
                                    0.2441362403711665,
                                    0.017591278886500528,
                                    0.7324087211134995,
                                ],
                                [
                                    0.017591278886500528,
                                    0.7324087211134995,
                                    0.005863759628833509,
                                    0.2441362403711665,
                                ],
                                [
                                    0.008795639443250264,
                                    0.36620436055674976,
                                    0.014659399072083773,
                                    0.6103406009279162,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.014659399072083773,
                                    0.6103406009279162,
                                    0.008795639443250264,
                                    0.36620436055674976,
                                ],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.004163567227624192,
                                    0.11121910524595506,
                                    0.031921289695564,
                                    0.8526960378308568,
                                ],
                                [
                                    0.031921289695564,
                                    0.8526960378308568,
                                    0.004163567227624192,
                                    0.11121910524595506,
                                ],
                                [
                                    0.011102997844609146,
                                    0.2965883383921805,
                                    0.024981859078579045,
                                    0.6673268046846312,
                                ],
                                [
                                    0.23668683889285477,
                                    0.07100449734393491,
                                    0.5325478161599867,
                                    0.1597608476032236,
                                ],
                                [
                                    0.024981859078579045,
                                    0.6673268046846312,
                                    0.011102997844609143,
                                    0.29658833839218046,
                                ],
                                [
                                    0.5325478161599867,
                                    0.1597608476032236,
                                    0.23668683889285475,
                                    0.0710044973439349,
                                ],
                                [
                                    0.0010486635535611527,
                                    0.022406374961772883,
                                    0.043660858150083685,
                                    0.9328841033345823,
                                ],
                                [
                                    0.043660858150083685,
                                    0.9328841033345823,
                                    0.0010486635535611527,
                                    0.022406374961772883,
                                ],
                                [
                                    0.011701712202691786,
                                    0.25002580705497524,
                                    0.033007809500953056,
                                    0.7052646712413799,
                                ],
                                [
                                    0.2494498611682442,
                                    0.012277658089422822,
                                    0.7036400618010877,
                                    0.034632418941245253,
                                ],
                                [
                                    0.033007809500953056,
                                    0.7052646712413799,
                                    0.011701712202691786,
                                    0.25002580705497524,
                                ],
                                [
                                    0.7036400618010877,
                                    0.034632418941245253,
                                    0.2494498611682442,
                                    0.012277658089422822,
                                ],
                                [
                                    0.00048399041334211006,
                                    0.21945613442633652,
                                    0.0017165649136811247,
                                    0.7783433102466403,
                                ],
                                [
                                    0.000587218633243017,
                                    0.2662629832371037,
                                    0.0016133366937802177,
                                    0.7315364614358731,
                                ],
                                [
                                    0.000495901161228967,
                                    0.2248568337321896,
                                    0.0017046541657942677,
                                    0.7729426109407872,
                                ],
                                [
                                    0.010571314152921986,
                                    0.21478142074049658,
                                    0.03633876287774609,
                                    0.7383085022288354,
                                ],
                                [
                                    0.0005475152711794204,
                                    0.2482602581375732,
                                    0.0016530400558438143,
                                    0.7495391865354036,
                                ],
                                [
                                    0.011671591816433591,
                                    0.237136181592319,
                                    0.035238485214234484,
                                    0.715953741377013,
                                ],
                                [
                                    0.0019216140549867596,
                                    0.17559108646359073,
                                    0.008903606052493122,
                                    0.8135836934289294,
                                ],
                                [
                                    0.004419699707218271,
                                    0.4038583457585177,
                                    0.006405520400261612,
                                    0.5853164341340024,
                                ],
                                [
                                    0.0022098498536091355,
                                    0.20192917287925885,
                                    0.008615370253870748,
                                    0.7872456070132613,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.0034588926797248913,
                                    0.31606280252672236,
                                    0.007366327427754992,
                                    0.6731119773657978,
                                ],
                                [
                                    0.07373453421241664,
                                    0.2457871609940306,
                                    0.15703081073474187,
                                    0.5234474940588109,
                                ],
                                [
                                    0.0027063050268699737,
                                    0.11267636744670928,
                                    0.020748733488464063,
                                    0.8638685940379567,
                                ],
                                [
                                    0.014433824284536993,
                                    0.6009488481890423,
                                    0.009021214230797044,
                                    0.3755961132956237,
                                ],
                                [
                                    0.0040594575403049594,
                                    0.16901455117006386,
                                    0.019395580975029077,
                                    0.8075304103146022,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.009923217169138469,
                                    0.41315079154123036,
                                    0.013531821346195568,
                                    0.5633941699434356,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.001921614054986761,
                                    0.05133103037359426,
                                    0.03416324286820143,
                                    0.9125841127032176,
                                ],
                                [
                                    0.029679336522926567,
                                    0.792807962958496,
                                    0.006405520400261622,
                                    0.17110718011831583,
                                ],
                                [
                                    0.005124374255117572,
                                    0.13688462043275218,
                                    0.030960482668070617,
                                    0.8270305226440596,
                                ],
                                [
                                    0.1092382400431243,
                                    0.032770754644745465,
                                    0.6599964150097172,
                                    0.19799459030241304,
                                ],
                                [
                                    0.019003235489087476,
                                    0.5076230867252031,
                                    0.017081621434100715,
                                    0.4562920563516088,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403419,
                                    0.36413543774258517,
                                    0.10923824004312431,
                                ],
                                [
                                    0.0004839904133421043,
                                    0.010341229694137779,
                                    0.04422553129030273,
                                    0.9449492486022174,
                                ],
                                [
                                    0.04309618500986464,
                                    0.9208189580669471,
                                    0.0016133366937802005,
                                    0.03447152022940798,
                                ],
                                [
                                    0.005400699305853088,
                                    0.1153945832214661,
                                    0.03930882239779175,
                                    0.839895895074889,
                                ],
                                [
                                    0.11512876651902133,
                                    0.005666516008297856,
                                    0.8379611564503106,
                                    0.041243561022370215,
                                ],
                                [
                                    0.026706796604114354,
                                    0.5706334474078708,
                                    0.018002725099530485,
                                    0.38465703088848435,
                                ],
                                [
                                    0.5693189671518649,
                                    0.02802127686012029,
                                    0.38377095581746706,
                                    0.018888800170547785,
                                ],
                                [
                                    9.838577615361658e-05,
                                    0.04461113592749122,
                                    0.0021021695508696182,
                                    0.9531883087454855,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.09141798473825839,
                                    0.0019989413309687114,
                                    0.9063814599347184,
                                ],
                                [
                                    0.00010080699802726174,
                                    0.045708992369129196,
                                    0.002099748328995973,
                                    0.9520904523038476,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.0001524211079777152,
                                    0.06911241677451278,
                                    0.0020481342190455196,
                                    0.928687027898464,
                                ],
                                [
                                    0.0032492188805843653,
                                    0.06601561900190613,
                                    0.043660858150083706,
                                    0.8870743039674258,
                                ],
                                [
                                    0.00039062651874043145,
                                    0.03569423040444776,
                                    0.010434593588739452,
                                    0.9534805494880724,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.7252132901931454,
                                ],
                                [
                                    0.00044921921392812483,
                                    0.041048247763000006,
                                    0.010376000893551758,
                                    0.9481265321295201,
                                ],
                                [
                                    0.009576177281364139,
                                    0.031921289695563994,
                                    0.22118916766579436,
                                    0.7373133653572775,
                                ],
                                [
                                    0.0016982620400438804,
                                    0.1551818774104635,
                                    0.009126958067436002,
                                    0.8339929024820566,
                                ],
                                [
                                    0.03620249949565466,
                                    0.12067763995485271,
                                    0.19456284545150385,
                                    0.6485570150979888,
                                ],
                                [
                                    0.000550138831755803,
                                    0.022904899683578235,
                                    0.022904899683578235,
                                    0.9536400618010877,
                                ],
                                [
                                    0.012277658089422822,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.46536758105875475,
                                ],
                                [
                                    0.0008252082476337047,
                                    0.03435734952536735,
                                    0.02262983026770033,
                                    0.9421876119592986,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.006688967876467214,
                                    0.27849358989653383,
                                    0.01676607063886682,
                                    0.6980513715881321,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.00039062651874043145,
                                    0.010434593588739452,
                                    0.03569423040444776,
                                    0.9534805494880724,
                                ],
                                [
                                    0.028148348986680238,
                                    0.7519115261736411,
                                    0.007936507936507952,
                                    0.21200361690317066,
                                ],
                                [
                                    0.0010416849683239128,
                                    0.027825963600750066,
                                    0.035043171954864276,
                                    0.9360891794760617,
                                ],
                                [
                                    0.022205995689218275,
                                    0.006661652879855703,
                                    0.7470286593636232,
                                    0.2241036920673028,
                                ],
                                [
                                    0.014920546202293817,
                                    0.3985644298932009,
                                    0.021164310720894374,
                                    0.5653507131836109,
                                ],
                                [
                                    0.3180669729563503,
                                    0.09541800313914443,
                                    0.4511676820964912,
                                    0.13534734180801408,
                                ],
                                [
                                    9.838577615361658e-05,
                                    0.0021021695508696182,
                                    0.04461113592749122,
                                    0.9531883087454855,
                                ],
                                [
                                    0.04271058037267615,
                                    0.912579897923679,
                                    0.0019989413309686897,
                                    0.04271058037267617,
                                ],
                                [
                                    0.001097856441637961,
                                    0.023457459737207694,
                                    0.043611665262006875,
                                    0.9318330185591475,
                                ],
                                [
                                    0.023403424405383594,
                                    0.0011518917734620597,
                                    0.9296864985639484,
                                    0.04575818525720601,
                                ],
                                [
                                    0.02240395373989923,
                                    0.4786963239236124,
                                    0.02230556796374561,
                                    0.4765941543727428,
                                ],
                                [
                                    0.4775936250382271,
                                    0.02350665262528449,
                                    0.4754962979311048,
                                    0.023403424405383583,
                                ],
                                [
                                    0.009833417785021961,
                                    0.8985469834806652,
                                    0.0009918023224579217,
                                    0.09062779641185491,
                                ],
                                [
                                    0.010341229694137779,
                                    0.9449492486022174,
                                    0.00048399041334210404,
                                    0.044225531290302704,
                                ],
                                [
                                    0.010075412991693013,
                                    0.9206597491258166,
                                    0.0007498071157868696,
                                    0.06851503076670355,
                                ],
                                [
                                    0.04366085815008371,
                                    0.8870743039674259,
                                    0.003249218880584362,
                                    0.06601561900190606,
                                ],
                                [
                                    0.010329318946250922,
                                    0.9438608816865927,
                                    0.0004959011612289608,
                                    0.045313898205927454,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.002148941217072757,
                                    0.04366085815008366,
                                ],
                                [
                                    0.039042165512684385,
                                    0.6941076326169691,
                                    0.014210478915896631,
                                    0.25263972295445,
                                ],
                                [
                                    0.05133103037359426,
                                    0.9125841127032176,
                                    0.0019216140549867579,
                                    0.034163242868201375,
                                ],
                                [
                                    0.04489836214451695,
                                    0.7982214984049758,
                                    0.00835428228406407,
                                    0.14852585716644323,
                                ],
                                [
                                    0.19456284545150387,
                                    0.6485570150979889,
                                    0.03620249949565465,
                                    0.12067763995485266,
                                ],
                                [
                                    0.051042794574971885,
                                    0.9074597384481,
                                    0.0022098498536091337,
                                    0.03928761712331894,
                                ],
                                [
                                    0.22118916766579436,
                                    0.7373133653572775,
                                    0.009576177281364126,
                                    0.03192128969556395,
                                ],
                                [
                                    0.054985031209919655,
                                    0.4215599302747463,
                                    0.060397641263659596,
                                    0.46305739725167444,
                                ],
                                [
                                    0.11267636744670928,
                                    0.8638685940379567,
                                    0.0027063050268699707,
                                    0.02074873348846404,
                                ],
                                [
                                    0.0824775468148795,
                                    0.6323398954121195,
                                    0.03290512565869977,
                                    0.25227743211430126,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.1113232149332743,
                                    0.8534942272937247,
                                    0.004059457540304956,
                                    0.031123100232696058,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.03904216551268439,
                                    0.18089795932699423,
                                    0.138470535005893,
                                    0.6415893401544284,
                                ],
                                [
                                    0.17559108646359062,
                                    0.8135836934289296,
                                    0.0019216140549867583,
                                    0.008903606052493124,
                                ],
                                [
                                    0.10411386578800669,
                                    0.4824011581164986,
                                    0.07339883473057068,
                                    0.34008614136492404,
                                ],
                                [
                                    0.4511676820964912,
                                    0.13534734180801408,
                                    0.3180669729563503,
                                    0.09541800313914443,
                                ],
                                [
                                    0.1723883262634598,
                                    0.7987440251674662,
                                    0.005124374255117563,
                                    0.023743274313956387,
                                ],
                                [
                                    0.7470286593636232,
                                    0.2241036920673028,
                                    0.022205995689218255,
                                    0.006661652879855697,
                                ],
                                [
                                    0.009833417785021966,
                                    0.03487610391862287,
                                    0.21010670705465664,
                                    0.7451837712416985,
                                ],
                                [
                                    0.21945613442633652,
                                    0.7783433102466403,
                                    0.00048399041334210453,
                                    0.001716564913681105,
                                ],
                                [
                                    0.10972806721316826,
                                    0.38917165512332014,
                                    0.11021205762651036,
                                    0.39088822003700124,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383583,
                                    0.4775936250382271,
                                    0.02350665262528449,
                                ],
                                [
                                    0.21453942553382552,
                                    0.7609052582873288,
                                    0.005400699305853084,
                                    0.01915461687299253,
                                ],
                                [
                                    0.9296864985639484,
                                    0.04575818525720601,
                                    0.023403424405383556,
                                    0.0011518917734620578,
                                ],
                                [
                                    0.007936507936507941,
                                    0.7252132901931455,
                                    0.0028887121709719418,
                                    0.26396148969937466,
                                ],
                                [
                                    0.008444319845623757,
                                    0.7716155553146976,
                                    0.002380900261856124,
                                    0.21755922457782245,
                                ],
                                [
                                    0.008131821195878157,
                                    0.7430604053953693,
                                    0.002693398911601726,
                                    0.2461143744971508,
                                ],
                                [
                                    0.035238485214234484,
                                    0.7159537413770131,
                                    0.011671591816433588,
                                    0.23713618159231892,
                                ],
                                [
                                    0.008385727150436065,
                                    0.7662615379561454,
                                    0.002439492957043817,
                                    0.22291324193637468,
                                ],
                                [
                                    0.03633876287774609,
                                    0.7383085022288354,
                                    0.010571314152921982,
                                    0.21478142074049653,
                                ],
                                [
                                    0.031510758845398154,
                                    0.560211195688866,
                                    0.02174188558318287,
                                    0.386536159882553,
                                ],
                                [
                                    0.04379962370630803,
                                    0.7786876757751146,
                                    0.009453020722272993,
                                    0.1680596797963044,
                                ],
                                [
                                    0.03623726920653465,
                                    0.6442410355870182,
                                    0.01701537522204637,
                                    0.30250631998440075,
                                ],
                                [
                                    0.1570308107347419,
                                    0.523447494058811,
                                    0.07373453421241662,
                                    0.24578716099403053,
                                ],
                                [
                                    0.04238170163698959,
                                    0.7534792756301425,
                                    0.010870942791591435,
                                    0.1932680799412765,
                                ],
                                [
                                    0.1836571329490324,
                                    0.6122038443180997,
                                    0.0471082119981261,
                                    0.15703081073474184,
                                ],
                                [
                                    0.044378175129644364,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.5443781751296444,
                                ],
                                [
                                    0.10206951136643398,
                                    0.7825478161599868,
                                    0.01331316110714526,
                                    0.10206951136643397,
                                ],
                                [
                                    0.06656726269446656,
                                    0.5103587285951646,
                                    0.0488154097791127,
                                    0.3742585989312561,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.09541293081286137,
                                    0.7315130604767698,
                                    0.01996974166071789,
                                    0.15310426704965094,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.03151075884539816,
                                    0.14600194167317931,
                                    0.1460019416731792,
                                    0.6764853578082433,
                                ],
                                [
                                    0.16805967979630437,
                                    0.7786876757751146,
                                    0.009453020722272994,
                                    0.04379962370630805,
                                ],
                                [
                                    0.08402983989815219,
                                    0.3893438378875573,
                                    0.09348286062042518,
                                    0.43314346159386535,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312431,
                                    0.40509921731025633,
                                    0.12152710490403419,
                                ],
                                [
                                    0.1523043003736053,
                                    0.7056867049385249,
                                    0.025208400144972064,
                                    0.11680059454289766,
                                ],
                                [
                                    0.6599964150097172,
                                    0.19799459030241304,
                                    0.10923824004312427,
                                    0.03277075464474546,
                                ],
                                [
                                    0.007936507936507952,
                                    0.028148348986680238,
                                    0.21200361690317066,
                                    0.7519115261736411,
                                ],
                                [
                                    0.2175592245778225,
                                    0.7716155553146976,
                                    0.0023809002618561267,
                                    0.008444319845623766,
                                ],
                                [
                                    0.08856103699991852,
                                    0.3140987189880963,
                                    0.1313790878397601,
                                    0.46596115617222506,
                                ],
                                [
                                    0.38377095581746706,
                                    0.018888800170547785,
                                    0.5693189671518649,
                                    0.02802127686012029,
                                ],
                                [
                                    0.1933723953205758,
                                    0.685832322152105,
                                    0.026567729519102825,
                                    0.09422755300821634,
                                ],
                                [
                                    0.8379611564503106,
                                    0.041243561022370215,
                                    0.1151287665190213,
                                    0.005666516008297855,
                                ],
                                [
                                    0.0051587040991820324,
                                    0.47138625738548395,
                                    0.00566651600829785,
                                    0.5177885225070362,
                                ],
                                [
                                    0.00566651600829785,
                                    0.5177885225070362,
                                    0.0051587040991820324,
                                    0.47138625738548395,
                                ],
                                [
                                    0.005285657076460987,
                                    0.482986823665872,
                                    0.005539563031018896,
                                    0.5061879562266481,
                                ],
                                [
                                    0.022904899683578235,
                                    0.46536758105875475,
                                    0.02400517734708984,
                                    0.4877223419105772,
                                ],
                                [
                                    0.005539563031018896,
                                    0.5061879562266481,
                                    0.005285657076460987,
                                    0.482986823665872,
                                ],
                                [
                                    0.02400517734708984,
                                    0.4877223419105772,
                                    0.022904899683578235,
                                    0.46536758105875475,
                                ],
                                [
                                    0.020481889783835576,
                                    0.3641354377425853,
                                    0.032770754644745444,
                                    0.5826119178288337,
                                ],
                                [
                                    0.03277075464474545,
                                    0.5826119178288338,
                                    0.020481889783835572,
                                    0.36413543774258517,
                                ],
                                [
                                    0.023554105999063043,
                                    0.4187545577641474,
                                    0.029698538429517977,
                                    0.5279927978072716,
                                ],
                                [
                                    0.102069511366434,
                                    0.34023915239677643,
                                    0.1286958335807245,
                                    0.42899550265606506,
                                ],
                                [
                                    0.029698538429517984,
                                    0.5279927978072717,
                                    0.02355410599906304,
                                    0.41875455776414733,
                                ],
                                [
                                    0.12869583358072453,
                                    0.4289955026560652,
                                    0.10206951136643398,
                                    0.3402391523967764,
                                ],
                                [
                                    0.028845668118394813,
                                    0.2211543318816052,
                                    0.08653700435518444,
                                    0.6634629956448156,
                                ],
                                [
                                    0.08653700435518444,
                                    0.6634629956448156,
                                    0.028845668118394813,
                                    0.2211543318816052,
                                ],
                                [
                                    0.04326850217759222,
                                    0.3317314978224078,
                                    0.07211417029598703,
                                    0.552885829704013,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.07211417029598703,
                                    0.552885829704013,
                                    0.04326850217759222,
                                    0.3317314978224078,
                                ],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.020481889783835576,
                                    0.09490078268974368,
                                    0.1570308107347418,
                                    0.727586516791679,
                                ],
                                [
                                    0.1570308107347418,
                                    0.727586516791679,
                                    0.020481889783835576,
                                    0.09490078268974368,
                                ],
                                [
                                    0.05461912002156214,
                                    0.2530722162152275,
                                    0.12289358049701524,
                                    0.569415083266195,
                                ],
                                [
                                    0.23668683889285477,
                                    0.07100449734393491,
                                    0.5325478161599867,
                                    0.1597608476032236,
                                ],
                                [
                                    0.12289358049701524,
                                    0.569415083266195,
                                    0.05461912002156213,
                                    0.2530722162152275,
                                ],
                                [
                                    0.5325478161599867,
                                    0.1597608476032236,
                                    0.23668683889285475,
                                    0.0710044973439349,
                                ],
                                [
                                    0.0051587040991820385,
                                    0.018296334416152,
                                    0.21478142074049658,
                                    0.7617635407441694,
                                ],
                                [
                                    0.21478142074049658,
                                    0.7617635407441694,
                                    0.0051587040991820385,
                                    0.018296334416152,
                                ],
                                [
                                    0.057564383259510674,
                                    0.20416313599815633,
                                    0.16237574158016793,
                                    0.575896739162165,
                                ],
                                [
                                    0.2494498611682442,
                                    0.012277658089422822,
                                    0.7036400618010877,
                                    0.034632418941245253,
                                ],
                                [
                                    0.16237574158016793,
                                    0.575896739162165,
                                    0.057564383259510674,
                                    0.20416313599815633,
                                ],
                                [
                                    0.7036400618010877,
                                    0.034632418941245253,
                                    0.2494498611682442,
                                    0.012277658089422822,
                                ],
                                [
                                    0.0023809002618561245,
                                    0.2175592245778225,
                                    0.008444319845623757,
                                    0.7716155553146976,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.7252132901931454,
                                ],
                                [
                                    0.002439492957043818,
                                    0.22291324193637474,
                                    0.008385727150436065,
                                    0.7662615379561454,
                                ],
                                [
                                    0.010571314152921986,
                                    0.21478142074049658,
                                    0.03633876287774609,
                                    0.7383085022288354,
                                ],
                                [
                                    0.002693398911601727,
                                    0.24611437449715087,
                                    0.008131821195878155,
                                    0.7430604053953692,
                                ],
                                [
                                    0.011671591816433591,
                                    0.237136181592319,
                                    0.035238485214234484,
                                    0.715953741377013,
                                ],
                                [
                                    0.009453020722272996,
                                    0.16805967979630448,
                                    0.04379962370630802,
                                    0.7786876757751144,
                                ],
                                [
                                    0.021741885583182873,
                                    0.38653615988255313,
                                    0.03151075884539815,
                                    0.5602111956888659,
                                ],
                                [
                                    0.010870942791591436,
                                    0.19326807994127657,
                                    0.04238170163698958,
                                    0.7534792756301424,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.017015375222046377,
                                    0.30250631998440086,
                                    0.036237269206534646,
                                    0.6442410355870181,
                                ],
                                [
                                    0.07373453421241664,
                                    0.2457871609940306,
                                    0.15703081073474187,
                                    0.5234474940588109,
                                ],
                                [
                                    0.013313161107145264,
                                    0.10206951136643398,
                                    0.10206951136643398,
                                    0.7825478161599868,
                                ],
                                [
                                    0.0710044973439349,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.3402391523967764,
                                ],
                                [
                                    0.01996974166071789,
                                    0.15310426704965094,
                                    0.09541293081286137,
                                    0.7315130604767698,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.0488154097791127,
                                    0.3742585989312561,
                                    0.06656726269446656,
                                    0.5103587285951646,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.009453020722272991,
                                    0.04379962370630803,
                                    0.16805967979630437,
                                    0.7786876757751146,
                                ],
                                [
                                    0.1460019416731792,
                                    0.6764853578082433,
                                    0.031510758845398154,
                                    0.14600194167317931,
                                ],
                                [
                                    0.025208400144972068,
                                    0.11680059454289769,
                                    0.1523043003736053,
                                    0.7056867049385249,
                                ],
                                [
                                    0.1092382400431243,
                                    0.032770754644745465,
                                    0.6599964150097172,
                                    0.19799459030241304,
                                ],
                                [
                                    0.09348286062042518,
                                    0.43314346159386535,
                                    0.08402983989815219,
                                    0.3893438378875573,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403419,
                                    0.36413543774258517,
                                    0.10923824004312431,
                                ],
                                [
                                    0.0023809002618561245,
                                    0.008444319845623757,
                                    0.2175592245778225,
                                    0.7716155553146976,
                                ],
                                [
                                    0.21200361690317066,
                                    0.7519115261736411,
                                    0.007936507936507948,
                                    0.028148348986680227,
                                ],
                                [
                                    0.026567729519102832,
                                    0.09422755300821636,
                                    0.1933723953205758,
                                    0.685832322152105,
                                ],
                                [
                                    0.11512876651902133,
                                    0.005666516008297856,
                                    0.8379611564503106,
                                    0.041243561022370215,
                                ],
                                [
                                    0.1313790878397601,
                                    0.46596115617222506,
                                    0.08856103699991852,
                                    0.3140987189880963,
                                ],
                                [
                                    0.5693189671518649,
                                    0.02802127686012029,
                                    0.38377095581746706,
                                    0.018888800170547785,
                                ],
                                [
                                    0.0004839904133421043,
                                    0.04422553129030273,
                                    0.010341229694137779,
                                    0.9449492486022174,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.09062779641185499,
                                    0.00983341778502196,
                                    0.8985469834806651,
                                ],
                                [
                                    0.0004959011612289613,
                                    0.045313898205927496,
                                    0.010329318946250922,
                                    0.9438608816865927,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.0007498071157868703,
                                    0.06851503076670362,
                                    0.010075412991693013,
                                    0.9206597491258165,
                                ],
                                [
                                    0.0032492188805843653,
                                    0.06601561900190613,
                                    0.043660858150083706,
                                    0.8870743039674258,
                                ],
                                [
                                    0.001921614054986761,
                                    0.03416324286820143,
                                    0.05133103037359426,
                                    0.9125841127032176,
                                ],
                                [
                                    0.014210478915896638,
                                    0.25263972295445003,
                                    0.039042165512684385,
                                    0.694107632616969,
                                ],
                                [
                                    0.0022098498536091368,
                                    0.039287617123319,
                                    0.051042794574971885,
                                    0.9074597384481,
                                ],
                                [
                                    0.009576177281364139,
                                    0.031921289695563994,
                                    0.22118916766579436,
                                    0.7373133653572775,
                                ],
                                [
                                    0.008354282284064075,
                                    0.14852585716644331,
                                    0.044898362144516944,
                                    0.7982214984049757,
                                ],
                                [
                                    0.03620249949565466,
                                    0.12067763995485271,
                                    0.19456284545150385,
                                    0.6485570150979888,
                                ],
                                [
                                    0.0027063050268699737,
                                    0.020748733488464063,
                                    0.11267636744670928,
                                    0.8638685940379567,
                                ],
                                [
                                    0.060397641263659596,
                                    0.46305739725167444,
                                    0.054985031209919655,
                                    0.4215599302747463,
                                ],
                                [
                                    0.00405945754030496,
                                    0.031123100232696096,
                                    0.1113232149332743,
                                    0.8534942272937247,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.032905125658699776,
                                    0.25227743211430126,
                                    0.08247754681487948,
                                    0.6323398954121194,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.0019216140549867583,
                                    0.008903606052493124,
                                    0.17559108646359062,
                                    0.8135836934289296,
                                ],
                                [
                                    0.138470535005893,
                                    0.6415893401544284,
                                    0.03904216551268439,
                                    0.18089795932699423,
                                ],
                                [
                                    0.005124374255117568,
                                    0.02374327431395641,
                                    0.1723883262634598,
                                    0.7987440251674662,
                                ],
                                [
                                    0.022205995689218275,
                                    0.006661652879855703,
                                    0.7470286593636232,
                                    0.2241036920673028,
                                ],
                                [
                                    0.07339883473057068,
                                    0.34008614136492404,
                                    0.10411386578800669,
                                    0.4824011581164986,
                                ],
                                [
                                    0.3180669729563503,
                                    0.09541800313914443,
                                    0.4511676820964912,
                                    0.13534734180801408,
                                ],
                                [
                                    0.00048399041334211006,
                                    0.0017165649136811247,
                                    0.21945613442633652,
                                    0.7783433102466403,
                                ],
                                [
                                    0.21010670705465664,
                                    0.7451837712416985,
                                    0.009833417785021972,
                                    0.03487610391862289,
                                ],
                                [
                                    0.005400699305853093,
                                    0.01915461687299256,
                                    0.21453942553382552,
                                    0.7609052582873288,
                                ],
                                [
                                    0.023403424405383594,
                                    0.0011518917734620597,
                                    0.9296864985639484,
                                    0.04575818525720601,
                                ],
                                [
                                    0.11021205762651036,
                                    0.39088822003700124,
                                    0.10972806721316826,
                                    0.38917165512332014,
                                ],
                                [
                                    0.4775936250382271,
                                    0.02350665262528449,
                                    0.4754962979311048,
                                    0.023403424405383583,
                                ],
                                [
                                    0.02130609729826128,
                                    0.8870743039674259,
                                    0.002148941217072757,
                                    0.08947065751724008,
                                ],
                                [
                                    0.022406374961772883,
                                    0.9328841033345823,
                                    0.001048663553561152,
                                    0.04366085815008366,
                                ],
                                [
                                    0.021830429075041857,
                                    0.9089047330424678,
                                    0.001624609440292181,
                                    0.06764022844219825,
                                ],
                                [
                                    0.04366085815008371,
                                    0.8870743039674259,
                                    0.003249218880584362,
                                    0.06601561900190606,
                                ],
                                [
                                    0.02238056790679766,
                                    0.9318096327260459,
                                    0.0010744706085363785,
                                    0.04473532875862004,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.002148941217072757,
                                    0.04366085815008366,
                                ],
                                [
                                    0.08459278303166455,
                                    0.6485570150979889,
                                    0.030789889441914704,
                                    0.23606031242843187,
                                ],
                                [
                                    0.11121910524595506,
                                    0.8526960378308568,
                                    0.004163567227624185,
                                    0.03192128969556395,
                                ],
                                [
                                    0.09728142272575194,
                                    0.7458384378237408,
                                    0.018101249747827324,
                                    0.13877888970268,
                                ],
                                [
                                    0.19456284545150387,
                                    0.6485570150979889,
                                    0.03620249949565465,
                                    0.12067763995485266,
                                ],
                                [
                                    0.11059458383289718,
                                    0.8479079491901746,
                                    0.004788088640682063,
                                    0.03670937833624601,
                                ],
                                [
                                    0.22118916766579436,
                                    0.7373133653572775,
                                    0.009576177281364126,
                                    0.03192128969556395,
                                ],
                                [
                                    0.11913624037116649,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.3925912788865005,
                                ],
                                [
                                    0.2441362403711665,
                                    0.7324087211134995,
                                    0.005863759628833502,
                                    0.017591278886500507,
                                ],
                                [
                                    0.17870436055674976,
                                    0.5361130816702493,
                                    0.07129563944325025,
                                    0.21388691832975076,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.24120436055674974,
                                    0.7236130816702492,
                                    0.008795639443250253,
                                    0.02638691832975076,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.08459278303166454,
                                    0.13534734180801408,
                                    0.3000245444947562,
                                    0.4800353306655652,
                                ],
                                [
                                    0.3804537602987966,
                                    0.6087210195937236,
                                    0.004163567227624186,
                                    0.006661652879855697,
                                ],
                                [
                                    0.2255838410482456,
                                    0.3609311828562597,
                                    0.15903348647817514,
                                    0.25445148961731956,
                                ],
                                [
                                    0.4511676820964912,
                                    0.13534734180801408,
                                    0.3180669729563503,
                                    0.09541800313914443,
                                ],
                                [
                                    0.3735143296818116,
                                    0.5976180217491144,
                                    0.011102997844609127,
                                    0.017764650724464825,
                                ],
                                [
                                    0.7470286593636232,
                                    0.2241036920673028,
                                    0.022205995689218255,
                                    0.006661652879855697,
                                ],
                                [
                                    0.021306097298261266,
                                    0.023403424405383573,
                                    0.4552388641864047,
                                    0.5000516141099505,
                                ],
                                [
                                    0.4754962979311048,
                                    0.522303146741872,
                                    0.001048663553561152,
                                    0.0011518917734620576,
                                ],
                                [
                                    0.2377481489655524,
                                    0.261151573370936,
                                    0.23879681251911355,
                                    0.26230346514439806,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383583,
                                    0.4775936250382271,
                                    0.02350665262528449,
                                ],
                                [
                                    0.4648432492819742,
                                    0.5106014345391802,
                                    0.011701712202691778,
                                    0.012853603976153835,
                                ],
                                [
                                    0.9296864985639484,
                                    0.04575818525720601,
                                    0.023403424405383556,
                                    0.0011518917734620578,
                                ],
                                [
                                    0.017196056752640396,
                                    0.7159537413770131,
                                    0.006258981762693642,
                                    0.26059122010765295,
                                ],
                                [
                                    0.018296334416152,
                                    0.7617635407441694,
                                    0.005158704099182037,
                                    0.21478142074049653,
                                ],
                                [
                                    0.017619242607117242,
                                    0.7335729839841303,
                                    0.005835795908216794,
                                    0.24297197750053573,
                                ],
                                [
                                    0.035238485214234484,
                                    0.7159537413770131,
                                    0.011671591816433588,
                                    0.23713618159231892,
                                ],
                                [
                                    0.018169381438873044,
                                    0.7564778836677084,
                                    0.005285657076460991,
                                    0.2200670778169575,
                                ],
                                [
                                    0.03633876287774609,
                                    0.7383085022288354,
                                    0.010571314152921982,
                                    0.21478142074049653,
                                ],
                                [
                                    0.06827446047545314,
                                    0.523447494058811,
                                    0.0471082119981261,
                                    0.3611698334676098,
                                ],
                                [
                                    0.09490078268974368,
                                    0.727586516791679,
                                    0.020481889783835576,
                                    0.15703081073474182,
                                ],
                                [
                                    0.07851540536737095,
                                    0.601962899426182,
                                    0.03686726710620831,
                                    0.28265442810023883,
                                ],
                                [
                                    0.1570308107347419,
                                    0.523447494058811,
                                    0.07373453421241662,
                                    0.24578716099403053,
                                ],
                                [
                                    0.0918285664745162,
                                    0.7040324107926159,
                                    0.02355410599906305,
                                    0.1805849167338049,
                                ],
                                [
                                    0.1836571329490324,
                                    0.6122038443180997,
                                    0.0471082119981261,
                                    0.15703081073474184,
                                ],
                                [
                                    0.09615433188160519,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.4615370043551844,
                                ],
                                [
                                    0.2211543318816052,
                                    0.6634629956448156,
                                    0.028845668118394806,
                                    0.08653700435518441,
                                ],
                                [
                                    0.1442314978224078,
                                    0.4326944934672234,
                                    0.1057685021775922,
                                    0.3173055065327766,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.2067314978224078,
                                    0.6201944934672234,
                                    0.043268502177592205,
                                    0.12980550653277662,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.06827446047545316,
                                    0.10923824004312432,
                                    0.3163428670509676,
                                    0.5061444324304549,
                                ],
                                [
                                    0.36413543774258517,
                                    0.5826119178288338,
                                    0.02048188978383558,
                                    0.032770754644745465,
                                ],
                                [
                                    0.18206771887129258,
                                    0.2913059589144169,
                                    0.20254960865512817,
                                    0.32407671355916234,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312431,
                                    0.40509921731025633,
                                    0.12152710490403419,
                                ],
                                [
                                    0.3299982075048586,
                                    0.5279927978072716,
                                    0.054619120021562134,
                                    0.0873898746663076,
                                ],
                                [
                                    0.6599964150097172,
                                    0.19799459030241304,
                                    0.10923824004312427,
                                    0.03277075464474546,
                                ],
                                [
                                    0.0171960567526404,
                                    0.018888800170547792,
                                    0.45934890473202555,
                                    0.5045662383447862,
                                ],
                                [
                                    0.47138625738548395,
                                    0.5177885225070362,
                                    0.005158704099182037,
                                    0.005666516008297856,
                                ],
                                [
                                    0.19188547790873353,
                                    0.2107742780792813,
                                    0.28465948357593246,
                                    0.3126807604360527,
                                ],
                                [
                                    0.38377095581746706,
                                    0.018888800170547785,
                                    0.5693189671518649,
                                    0.02802127686012029,
                                ],
                                [
                                    0.4189805782251553,
                                    0.46022413924752553,
                                    0.05756438325951065,
                                    0.0632308992678085,
                                ],
                                [
                                    0.8379611564503106,
                                    0.041243561022370215,
                                    0.1151287665190213,
                                    0.005666516008297855,
                                ],
                                [
                                    0.011177380425911215,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.5111773804259112,
                                ],
                                [
                                    0.012277658089422822,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.46536758105875475,
                                ],
                                [
                                    0.011452449841789118,
                                    0.47682003090054387,
                                    0.01200258867354492,
                                    0.4997249305841221,
                                ],
                                [
                                    0.022904899683578235,
                                    0.46536758105875475,
                                    0.02400517734708984,
                                    0.4877223419105772,
                                ],
                                [
                                    0.01200258867354492,
                                    0.4997249305841221,
                                    0.011452449841789118,
                                    0.47682003090054387,
                                ],
                                [
                                    0.02400517734708984,
                                    0.4877223419105772,
                                    0.022904899683578235,
                                    0.46536758105875475,
                                ],
                                [
                                    0.04437817512964438,
                                    0.3402391523967765,
                                    0.07100449734393488,
                                    0.5443781751296443,
                                ],
                                [
                                    0.0710044973439349,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.3402391523967764,
                                ],
                                [
                                    0.051034755683217,
                                    0.3912739080799934,
                                    0.06434791679036225,
                                    0.49334341944642734,
                                ],
                                [
                                    0.102069511366434,
                                    0.34023915239677643,
                                    0.1286958335807245,
                                    0.42899550265606506,
                                ],
                                [
                                    0.06434791679036227,
                                    0.4933434194464274,
                                    0.05103475568321699,
                                    0.3912739080799934,
                                ],
                                [
                                    0.12869583358072453,
                                    0.4289955026560652,
                                    0.10206951136643398,
                                    0.3402391523967764,
                                ],
                                [0.0625, 0.1875, 0.1875, 0.5625],
                                [0.1875, 0.5625, 0.0625, 0.1875],
                                [0.09375, 0.28125, 0.15625, 0.46875],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.15625, 0.46875, 0.09375, 0.28125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.044378175129644364,
                                    0.0710044973439349,
                                    0.3402391523967764,
                                    0.5443781751296444,
                                ],
                                [
                                    0.3402391523967764,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.0710044973439349,
                                ],
                                [
                                    0.11834341944642739,
                                    0.18934791679036228,
                                    0.26627390807999335,
                                    0.42603475568321697,
                                ],
                                [
                                    0.23668683889285477,
                                    0.07100449734393491,
                                    0.5325478161599867,
                                    0.1597608476032236,
                                ],
                                [
                                    0.26627390807999335,
                                    0.42603475568321697,
                                    0.11834341944642737,
                                    0.18934791679036225,
                                ],
                                [
                                    0.5325478161599867,
                                    0.1597608476032236,
                                    0.23668683889285475,
                                    0.0710044973439349,
                                ],
                                [
                                    0.011177380425911215,
                                    0.012277658089422822,
                                    0.46536758105875475,
                                    0.5111773804259112,
                                ],
                                [
                                    0.46536758105875475,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.012277658089422822,
                                ],
                                [
                                    0.1247249305841221,
                                    0.13700258867354492,
                                    0.35182003090054387,
                                    0.3864524498417891,
                                ],
                                [
                                    0.2494498611682442,
                                    0.012277658089422822,
                                    0.7036400618010877,
                                    0.034632418941245253,
                                ],
                                [
                                    0.35182003090054387,
                                    0.3864524498417891,
                                    0.1247249305841221,
                                    0.13700258867354492,
                                ],
                                [
                                    0.7036400618010877,
                                    0.034632418941245253,
                                    0.2494498611682442,
                                    0.012277658089422822,
                                ],
                                [
                                    0.0051587040991820385,
                                    0.21478142074049658,
                                    0.018296334416152,
                                    0.7617635407441694,
                                ],
                                [
                                    0.006258981762693645,
                                    0.26059122010765307,
                                    0.017196056752640392,
                                    0.715953741377013,
                                ],
                                [
                                    0.005285657076460993,
                                    0.22006707781695756,
                                    0.018169381438873044,
                                    0.7564778836677084,
                                ],
                                [
                                    0.010571314152921986,
                                    0.21478142074049658,
                                    0.03633876287774609,
                                    0.7383085022288354,
                                ],
                                [
                                    0.0058357959082167956,
                                    0.2429719775005358,
                                    0.017619242607117242,
                                    0.7335729839841302,
                                ],
                                [
                                    0.011671591816433591,
                                    0.237136181592319,
                                    0.035238485214234484,
                                    0.715953741377013,
                                ],
                                [
                                    0.020481889783835586,
                                    0.1570308107347419,
                                    0.09490078268974367,
                                    0.7275865167916789,
                                ],
                                [
                                    0.047108211998126114,
                                    0.3611698334676099,
                                    0.06827446047545314,
                                    0.5234474940588109,
                                ],
                                [
                                    0.023554105999063057,
                                    0.18058491673380495,
                                    0.09182856647451619,
                                    0.7040324107926158,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.03686726710620832,
                                    0.28265442810023894,
                                    0.07851540536737094,
                                    0.6019628994261819,
                                ],
                                [
                                    0.07373453421241664,
                                    0.2457871609940306,
                                    0.15703081073474187,
                                    0.5234474940588109,
                                ],
                                [
                                    0.028845668118394813,
                                    0.08653700435518444,
                                    0.2211543318816052,
                                    0.6634629956448156,
                                ],
                                [
                                    0.1538456681183948,
                                    0.4615370043551844,
                                    0.09615433188160519,
                                    0.2884629956448156,
                                ],
                                [
                                    0.043268502177592205,
                                    0.12980550653277662,
                                    0.2067314978224078,
                                    0.6201944934672234,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.1057685021775922,
                                    0.3173055065327766,
                                    0.1442314978224078,
                                    0.4326944934672234,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.020481889783835572,
                                    0.03277075464474545,
                                    0.36413543774258517,
                                    0.5826119178288338,
                                ],
                                [
                                    0.3163428670509676,
                                    0.5061444324304549,
                                    0.06827446047545314,
                                    0.10923824004312431,
                                ],
                                [
                                    0.05461912002156215,
                                    0.08738987466630761,
                                    0.3299982075048586,
                                    0.5279927978072716,
                                ],
                                [
                                    0.1092382400431243,
                                    0.032770754644745465,
                                    0.6599964150097172,
                                    0.19799459030241304,
                                ],
                                [
                                    0.20254960865512817,
                                    0.32407671355916234,
                                    0.18206771887129258,
                                    0.2913059589144169,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403419,
                                    0.36413543774258517,
                                    0.10923824004312431,
                                ],
                                [
                                    0.0051587040991820324,
                                    0.00566651600829785,
                                    0.47138625738548395,
                                    0.5177885225070362,
                                ],
                                [
                                    0.45934890473202555,
                                    0.5045662383447862,
                                    0.017196056752640392,
                                    0.018888800170547785,
                                ],
                                [
                                    0.05756438325951067,
                                    0.06323089926780852,
                                    0.4189805782251553,
                                    0.46022413924752553,
                                ],
                                [
                                    0.11512876651902133,
                                    0.005666516008297856,
                                    0.8379611564503106,
                                    0.041243561022370215,
                                ],
                                [
                                    0.28465948357593246,
                                    0.3126807604360527,
                                    0.19188547790873353,
                                    0.2107742780792813,
                                ],
                                [
                                    0.5693189671518649,
                                    0.02802127686012029,
                                    0.38377095581746706,
                                    0.018888800170547785,
                                ],
                                [
                                    0.0010486635535611527,
                                    0.043660858150083685,
                                    0.022406374961772883,
                                    0.9328841033345823,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.08947065751724015,
                                    0.021306097298261276,
                                    0.8870743039674258,
                                ],
                                [
                                    0.0010744706085363794,
                                    0.044735328758620074,
                                    0.02238056790679766,
                                    0.9318096327260459,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.0016246094402921827,
                                    0.06764022844219832,
                                    0.021830429075041853,
                                    0.9089047330424677,
                                ],
                                [
                                    0.0032492188805843653,
                                    0.06601561900190613,
                                    0.043660858150083706,
                                    0.8870743039674258,
                                ],
                                [
                                    0.004163567227624192,
                                    0.031921289695564,
                                    0.11121910524595506,
                                    0.8526960378308568,
                                ],
                                [
                                    0.030789889441914717,
                                    0.23606031242843198,
                                    0.08459278303166454,
                                    0.6485570150979888,
                                ],
                                [
                                    0.004788088640682069,
                                    0.03670937833624606,
                                    0.11059458383289718,
                                    0.8479079491901746,
                                ],
                                [
                                    0.009576177281364139,
                                    0.031921289695563994,
                                    0.22118916766579436,
                                    0.7373133653572775,
                                ],
                                [
                                    0.01810124974782733,
                                    0.13877888970268004,
                                    0.09728142272575192,
                                    0.7458384378237407,
                                ],
                                [
                                    0.03620249949565466,
                                    0.12067763995485271,
                                    0.19456284545150385,
                                    0.6485570150979888,
                                ],
                                [
                                    0.005863759628833509,
                                    0.017591278886500528,
                                    0.2441362403711665,
                                    0.7324087211134995,
                                ],
                                [
                                    0.1308637596288335,
                                    0.3925912788865005,
                                    0.11913624037116649,
                                    0.3574087211134995,
                                ],
                                [
                                    0.008795639443250264,
                                    0.02638691832975079,
                                    0.24120436055674974,
                                    0.7236130816702492,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.07129563944325026,
                                    0.2138869183297508,
                                    0.17870436055674974,
                                    0.5361130816702492,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.004163567227624186,
                                    0.006661652879855697,
                                    0.3804537602987966,
                                    0.6087210195937236,
                                ],
                                [
                                    0.3000245444947562,
                                    0.4800353306655652,
                                    0.08459278303166454,
                                    0.13534734180801408,
                                ],
                                [
                                    0.011102997844609138,
                                    0.017764650724464842,
                                    0.3735143296818116,
                                    0.5976180217491144,
                                ],
                                [
                                    0.022205995689218275,
                                    0.006661652879855703,
                                    0.7470286593636232,
                                    0.2241036920673028,
                                ],
                                [
                                    0.15903348647817514,
                                    0.25445148961731956,
                                    0.2255838410482456,
                                    0.3609311828562597,
                                ],
                                [
                                    0.3180669729563503,
                                    0.09541800313914443,
                                    0.4511676820964912,
                                    0.13534734180801408,
                                ],
                                [
                                    0.001048663553561164,
                                    0.0011518917734620708,
                                    0.4754962979311048,
                                    0.522303146741872,
                                ],
                                [
                                    0.4552388641864047,
                                    0.5000516141099505,
                                    0.021306097298261276,
                                    0.023403424405383583,
                                ],
                                [
                                    0.011701712202691797,
                                    0.012853603976153857,
                                    0.4648432492819742,
                                    0.5106014345391802,
                                ],
                                [
                                    0.023403424405383594,
                                    0.0011518917734620597,
                                    0.9296864985639484,
                                    0.04575818525720601,
                                ],
                                [
                                    0.23879681251911355,
                                    0.26230346514439806,
                                    0.2377481489655524,
                                    0.261151573370936,
                                ],
                                [
                                    0.4775936250382271,
                                    0.02350665262528449,
                                    0.4754962979311048,
                                    0.023403424405383583,
                                ],
                                [
                                    0.0327787768115006,
                                    0.8756016244541865,
                                    0.003306080111687592,
                                    0.08831351862262524,
                                ],
                                [
                                    0.03447152022940799,
                                    0.9208189580669471,
                                    0.0016133366937802001,
                                    0.04309618500986461,
                                ],
                                [
                                    0.0335854451583907,
                                    0.8971497169591189,
                                    0.0024994117647974923,
                                    0.06676542611769293,
                                ],
                                [
                                    0.04366085815008371,
                                    0.8870743039674259,
                                    0.003249218880584362,
                                    0.06601561900190606,
                                ],
                                [
                                    0.034431816867344395,
                                    0.9197583837654991,
                                    0.001653040055843796,
                                    0.04415675931131262,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.002148941217072757,
                                    0.04366085815008366,
                                ],
                                [
                                    0.13014340055064463,
                                    0.6030063975790088,
                                    0.047369299967932744,
                                    0.21948090190241384,
                                ],
                                [
                                    0.17110718011831574,
                                    0.7928079629584961,
                                    0.006405520400261609,
                                    0.029679336522926526,
                                ],
                                [
                                    0.1496644833069868,
                                    0.6934553772425059,
                                    0.02784821721159056,
                                    0.12903192223891674,
                                ],
                                [
                                    0.19456284545150387,
                                    0.6485570150979889,
                                    0.03620249949565465,
                                    0.12067763995485266,
                                ],
                                [
                                    0.17014637309082237,
                                    0.7883561599322495,
                                    0.007366327427754988,
                                    0.03413113954917309,
                                ],
                                [
                                    0.22118916766579436,
                                    0.7373133653572775,
                                    0.009576177281364126,
                                    0.03192128969556395,
                                ],
                                [
                                    0.18328744953241333,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.3221251605213266,
                                ],
                                [
                                    0.3755961132956237,
                                    0.6009488481890423,
                                    0.009021214230797034,
                                    0.014433824284536975,
                                ],
                                [
                                    0.27493117429862,
                                    0.43988626792837904,
                                    0.10968615322780073,
                                    0.17549640454520027,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.3710855061802252,
                                    0.5937319360467738,
                                    0.01353182134619555,
                                    0.021650736426805463,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.13014340055064466,
                                    0.08979672428903396,
                                    0.46157855398361936,
                                    0.318481321176702,
                                ],
                                [
                                    0.5853164341340024,
                                    0.4038583457585177,
                                    0.006405520400261612,
                                    0.004419699707218271,
                                ],
                                [
                                    0.3470538163084844,
                                    0.23946120759602083,
                                    0.24466813822577957,
                                    0.16881683786971516,
                                ],
                                [
                                    0.4511676820964912,
                                    0.13534734180801408,
                                    0.3180669729563503,
                                    0.09541800313914443,
                                ],
                                [
                                    0.5746403331001633,
                                    0.3964920183307627,
                                    0.017081621434100688,
                                    0.011786027134973263,
                                ],
                                [
                                    0.7470286593636232,
                                    0.2241036920673028,
                                    0.022205995689218255,
                                    0.006661652879855697,
                                ],
                                [
                                    0.032778776811500564,
                                    0.011930744892144272,
                                    0.7003710213181528,
                                    0.2549194569782024,
                                ],
                                [
                                    0.7315364614358731,
                                    0.2662629832371037,
                                    0.0016133366937801992,
                                    0.0005872186332430102,
                                ],
                                [
                                    0.36576823071793657,
                                    0.13313149161855184,
                                    0.36738156741171674,
                                    0.13371871025179485,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383583,
                                    0.4775936250382271,
                                    0.02350665262528449,
                                ],
                                [
                                    0.7151470730301228,
                                    0.26029761079103153,
                                    0.01800272509953047,
                                    0.006552591079315142,
                                ],
                                [
                                    0.9296864985639484,
                                    0.04575818525720601,
                                    0.023403424405383556,
                                    0.0011518917734620578,
                                ],
                                [
                                    0.02645560556877285,
                                    0.7066941925608806,
                                    0.009629251354415343,
                                    0.25722095051593125,
                                ],
                                [
                                    0.028148348986680238,
                                    0.7519115261736411,
                                    0.00793650793650795,
                                    0.2120036169031706,
                                ],
                                [
                                    0.02710666401835633,
                                    0.7240855625728911,
                                    0.008978192904831862,
                                    0.23982958050392064,
                                ],
                                [
                                    0.035238485214234484,
                                    0.7159537413770131,
                                    0.011671591816433588,
                                    0.23713618159231892,
                                ],
                                [
                                    0.027953035727310022,
                                    0.7466942293792714,
                                    0.008131821195878165,
                                    0.21722091369754035,
                                ],
                                [
                                    0.03633876287774609,
                                    0.7383085022288354,
                                    0.010571314152921982,
                                    0.21478142074049653,
                                ],
                                [
                                    0.10503816210550808,
                                    0.48668379242875603,
                                    0.07247453841306929,
                                    0.3358035070526666,
                                ],
                                [
                                    0.14600194167317923,
                                    0.6764853578082434,
                                    0.03151075884539815,
                                    0.14600194167317926,
                                ],
                                [
                                    0.12079354152820716,
                                    0.5596847632653457,
                                    0.05671915899037021,
                                    0.2628025362160769,
                                ],
                                [
                                    0.1570308107347419,
                                    0.523447494058811,
                                    0.07373453421241662,
                                    0.24578716099403053,
                                ],
                                [
                                    0.14127543131204273,
                                    0.6545855459550893,
                                    0.036237269206534646,
                                    0.1679017535263333,
                                ],
                                [
                                    0.1836571329490324,
                                    0.6122038443180997,
                                    0.0471082119981261,
                                    0.15703081073474184,
                                ],
                                [
                                    0.147930488633566,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.3786958335807245,
                                ],
                                [
                                    0.3402391523967764,
                                    0.5443781751296444,
                                    0.04437817512964435,
                                    0.07100449734393487,
                                ],
                                [
                                    0.22189573295034903,
                                    0.35503025833928215,
                                    0.16272159457607172,
                                    0.2603524141342971,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.31805006483195425,
                                    0.508875926457677,
                                    0.06656726269446653,
                                    0.10650674601590229,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.10503816210550813,
                                    0.07247453841306935,
                                    0.48668379242875587,
                                    0.33580350705266665,
                                ],
                                [
                                    0.5602111956888659,
                                    0.38653615988255313,
                                    0.03151075884539816,
                                    0.021741885583182883,
                                ],
                                [
                                    0.28010559784443295,
                                    0.19326807994127657,
                                    0.31161635668983106,
                                    0.21500996552445942,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312431,
                                    0.40509921731025633,
                                    0.12152710490403419,
                                ],
                                [
                                    0.5076921146361119,
                                    0.35029889067601844,
                                    0.0840298398981522,
                                    0.05797915478971754,
                                ],
                                [
                                    0.6599964150097172,
                                    0.19799459030241304,
                                    0.10923824004312427,
                                    0.03277075464474546,
                                ],
                                [
                                    0.026455605568772845,
                                    0.009629251354415346,
                                    0.7066941925608805,
                                    0.25722095051593136,
                                ],
                                [
                                    0.7252132901931454,
                                    0.2639614896993748,
                                    0.007936507936507948,
                                    0.0028887121709719457,
                                ],
                                [
                                    0.29520991881754854,
                                    0.1074498371704663,
                                    0.43793987931210476,
                                    0.1594003646998804,
                                ],
                                [
                                    0.38377095581746706,
                                    0.018888800170547785,
                                    0.5693189671518649,
                                    0.02802127686012029,
                                ],
                                [
                                    0.6445887611297348,
                                    0.234615956342946,
                                    0.08856103699991848,
                                    0.03223424552740068,
                                ],
                                [
                                    0.8379611564503106,
                                    0.041243561022370215,
                                    0.1151287665190213,
                                    0.005666516008297855,
                                ],
                                [
                                    0.0171960567526404,
                                    0.45934890473202555,
                                    0.018888800170547792,
                                    0.5045662383447862,
                                ],
                                [
                                    0.018888800170547792,
                                    0.5045662383447862,
                                    0.0171960567526404,
                                    0.45934890473202555,
                                ],
                                [
                                    0.017619242607117246,
                                    0.47065323813521576,
                                    0.018465614316070945,
                                    0.49326190494159605,
                                ],
                                [
                                    0.022904899683578235,
                                    0.46536758105875475,
                                    0.02400517734708984,
                                    0.4877223419105772,
                                ],
                                [
                                    0.018465614316070945,
                                    0.49326190494159605,
                                    0.017619242607117246,
                                    0.47065323813521576,
                                ],
                                [
                                    0.02400517734708984,
                                    0.4877223419105772,
                                    0.022904899683578235,
                                    0.46536758105875475,
                                ],
                                [
                                    0.06827446047545313,
                                    0.3163428670509677,
                                    0.10923824004312424,
                                    0.5061444324304549,
                                ],
                                [
                                    0.10923824004312425,
                                    0.506144432430455,
                                    0.06827446047545312,
                                    0.31634286705096765,
                                ],
                                [
                                    0.07851540536737091,
                                    0.36379325839583954,
                                    0.09899729515120646,
                                    0.4586940410855831,
                                ],
                                [
                                    0.102069511366434,
                                    0.34023915239677643,
                                    0.1286958335807245,
                                    0.42899550265606506,
                                ],
                                [
                                    0.09899729515120648,
                                    0.4586940410855832,
                                    0.0785154053673709,
                                    0.3637932583958395,
                                ],
                                [
                                    0.12869583358072453,
                                    0.4289955026560652,
                                    0.10206951136643398,
                                    0.3402391523967764,
                                ],
                                [
                                    0.09615433188160519,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.4615370043551844,
                                ],
                                [
                                    0.2884629956448156,
                                    0.4615370043551844,
                                    0.09615433188160519,
                                    0.1538456681183948,
                                ],
                                [
                                    0.1442314978224078,
                                    0.2307685021775922,
                                    0.24038582970401295,
                                    0.38461417029598705,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.24038582970401295,
                                    0.38461417029598705,
                                    0.1442314978224078,
                                    0.2307685021775922,
                                ],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.06827446047545314,
                                    0.047108211998126114,
                                    0.5234474940588109,
                                    0.3611698334676099,
                                ],
                                [
                                    0.5234474940588109,
                                    0.3611698334676099,
                                    0.06827446047545314,
                                    0.047108211998126114,
                                ],
                                [
                                    0.1820677188712926,
                                    0.12562361736549707,
                                    0.40965423566297143,
                                    0.2826544281002389,
                                ],
                                [
                                    0.23668683889285477,
                                    0.07100449734393491,
                                    0.5325478161599867,
                                    0.1597608476032236,
                                ],
                                [
                                    0.40965423566297143,
                                    0.2826544281002389,
                                    0.18206771887129258,
                                    0.12562361736549704,
                                ],
                                [
                                    0.5325478161599867,
                                    0.1597608476032236,
                                    0.23668683889285475,
                                    0.0710044973439349,
                                ],
                                [
                                    0.017196056752640392,
                                    0.006258981762693645,
                                    0.715953741377013,
                                    0.26059122010765307,
                                ],
                                [
                                    0.715953741377013,
                                    0.26059122010765307,
                                    0.017196056752640392,
                                    0.006258981762693645,
                                ],
                                [
                                    0.19188547790873353,
                                    0.0698420413489335,
                                    0.5412643202209197,
                                    0.1970081605214132,
                                ],
                                [
                                    0.2494498611682442,
                                    0.012277658089422822,
                                    0.7036400618010877,
                                    0.034632418941245253,
                                ],
                                [
                                    0.5412643202209197,
                                    0.1970081605214132,
                                    0.19188547790873353,
                                    0.0698420413489335,
                                ],
                                [
                                    0.7036400618010877,
                                    0.034632418941245253,
                                    0.2494498611682442,
                                    0.012277658089422822,
                                ],
                                [
                                    0.007936507936507952,
                                    0.21200361690317066,
                                    0.028148348986680238,
                                    0.7519115261736411,
                                ],
                                [
                                    0.009629251354415346,
                                    0.25722095051593136,
                                    0.026455605568772845,
                                    0.7066941925608805,
                                ],
                                [
                                    0.008131821195878167,
                                    0.2172209136975404,
                                    0.027953035727310022,
                                    0.7466942293792714,
                                ],
                                [
                                    0.010571314152921986,
                                    0.21478142074049658,
                                    0.03633876287774609,
                                    0.7383085022288354,
                                ],
                                [
                                    0.008978192904831865,
                                    0.23982958050392073,
                                    0.027106664018356326,
                                    0.724085562572891,
                                ],
                                [
                                    0.011671591816433591,
                                    0.237136181592319,
                                    0.035238485214234484,
                                    0.715953741377013,
                                ],
                                [
                                    0.03151075884539816,
                                    0.14600194167317931,
                                    0.1460019416731792,
                                    0.6764853578082433,
                                ],
                                [
                                    0.0724745384130693,
                                    0.33580350705266665,
                                    0.10503816210550806,
                                    0.486683792428756,
                                ],
                                [
                                    0.03623726920653465,
                                    0.16790175352633332,
                                    0.1412754313120427,
                                    0.6545855459550893,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.05671915899037023,
                                    0.262802536216077,
                                    0.12079354152820715,
                                    0.5596847632653457,
                                ],
                                [
                                    0.07373453421241664,
                                    0.2457871609940306,
                                    0.15703081073474187,
                                    0.5234474940588109,
                                ],
                                [
                                    0.044378175129644364,
                                    0.0710044973439349,
                                    0.3402391523967764,
                                    0.5443781751296444,
                                ],
                                [
                                    0.23668683889285475,
                                    0.3786958335807245,
                                    0.147930488633566,
                                    0.23668683889285475,
                                ],
                                [
                                    0.06656726269446653,
                                    0.10650674601590229,
                                    0.31805006483195425,
                                    0.508875926457677,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.16272159457607172,
                                    0.2603524141342971,
                                    0.22189573295034903,
                                    0.35503025833928215,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.03151075884539815,
                                    0.021741885583182873,
                                    0.5602111956888659,
                                    0.38653615988255313,
                                ],
                                [
                                    0.48668379242875587,
                                    0.33580350705266665,
                                    0.1050381621055081,
                                    0.07247453841306935,
                                ],
                                [
                                    0.08402983989815221,
                                    0.05797915478971755,
                                    0.5076921146361119,
                                    0.35029889067601844,
                                ],
                                [
                                    0.1092382400431243,
                                    0.032770754644745465,
                                    0.6599964150097172,
                                    0.19799459030241304,
                                ],
                                [
                                    0.31161635668983106,
                                    0.21500996552445942,
                                    0.28010559784443295,
                                    0.19326807994127657,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403419,
                                    0.36413543774258517,
                                    0.10923824004312431,
                                ],
                                [
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                    0.7252132901931454,
                                    0.2639614896993748,
                                ],
                                [
                                    0.7066941925608805,
                                    0.25722095051593136,
                                    0.026455605568772834,
                                    0.009629251354415343,
                                ],
                                [
                                    0.0885610369999185,
                                    0.03223424552740069,
                                    0.6445887611297348,
                                    0.234615956342946,
                                ],
                                [
                                    0.11512876651902133,
                                    0.005666516008297856,
                                    0.8379611564503106,
                                    0.041243561022370215,
                                ],
                                [
                                    0.43793987931210476,
                                    0.1594003646998804,
                                    0.29520991881754854,
                                    0.1074498371704663,
                                ],
                                [
                                    0.5693189671518649,
                                    0.02802127686012029,
                                    0.38377095581746706,
                                    0.018888800170547785,
                                ],
                                [
                                    0.0016133366937802012,
                                    0.04309618500986464,
                                    0.03447152022940799,
                                    0.9208189580669471,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.08831351862262532,
                                    0.0327787768115006,
                                    0.8756016244541865,
                                ],
                                [
                                    0.0016530400558437976,
                                    0.04415675931131266,
                                    0.034431816867344395,
                                    0.9197583837654991,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.002499411764797495,
                                    0.066765426117693,
                                    0.033585445158390695,
                                    0.8971497169591188,
                                ],
                                [
                                    0.0032492188805843653,
                                    0.06601561900190613,
                                    0.043660858150083706,
                                    0.8870743039674258,
                                ],
                                [
                                    0.006405520400261619,
                                    0.02967933652292657,
                                    0.17110718011831574,
                                    0.7928079629584961,
                                ],
                                [
                                    0.047369299967932765,
                                    0.21948090190241393,
                                    0.1301434005506446,
                                    0.6030063975790088,
                                ],
                                [
                                    0.007366327427754998,
                                    0.034131139549173135,
                                    0.17014637309082237,
                                    0.7883561599322495,
                                ],
                                [
                                    0.009576177281364139,
                                    0.031921289695563994,
                                    0.22118916766579436,
                                    0.7373133653572775,
                                ],
                                [
                                    0.027848217211590573,
                                    0.12903192223891682,
                                    0.1496644833069868,
                                    0.6934553772425058,
                                ],
                                [
                                    0.03620249949565466,
                                    0.12067763995485271,
                                    0.19456284545150385,
                                    0.6485570150979888,
                                ],
                                [
                                    0.009021214230797044,
                                    0.014433824284536993,
                                    0.3755961132956237,
                                    0.6009488481890423,
                                ],
                                [
                                    0.20132987799400742,
                                    0.3221251605213266,
                                    0.18328744953241333,
                                    0.29325751195225264,
                                ],
                                [
                                    0.013531821346195566,
                                    0.021650736426805487,
                                    0.3710855061802252,
                                    0.5937319360467738,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.10968615322780076,
                                    0.1754964045452003,
                                    0.27493117429862,
                                    0.4398862679283789,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.006405520400261612,
                                    0.004419699707218271,
                                    0.5853164341340024,
                                    0.4038583457585177,
                                ],
                                [
                                    0.46157855398361936,
                                    0.318481321176702,
                                    0.13014340055064466,
                                    0.08979672428903396,
                                ],
                                [
                                    0.017081621434100705,
                                    0.011786027134973273,
                                    0.5746403331001633,
                                    0.3964920183307627,
                                ],
                                [
                                    0.022205995689218275,
                                    0.006661652879855703,
                                    0.7470286593636232,
                                    0.2241036920673028,
                                ],
                                [
                                    0.24466813822577957,
                                    0.16881683786971516,
                                    0.3470538163084844,
                                    0.23946120759602083,
                                ],
                                [
                                    0.3180669729563503,
                                    0.09541800313914443,
                                    0.4511676820964912,
                                    0.13534734180801408,
                                ],
                                [
                                    0.0016133366937802177,
                                    0.000587218633243017,
                                    0.7315364614358731,
                                    0.2662629832371037,
                                ],
                                [
                                    0.7003710213181528,
                                    0.2549194569782024,
                                    0.032778776811500585,
                                    0.011930744892144277,
                                ],
                                [
                                    0.018002725099530503,
                                    0.006552591079315153,
                                    0.7151470730301228,
                                    0.26029761079103153,
                                ],
                                [
                                    0.023403424405383594,
                                    0.0011518917734620597,
                                    0.9296864985639484,
                                    0.04575818525720601,
                                ],
                                [
                                    0.36738156741171674,
                                    0.13371871025179485,
                                    0.36576823071793657,
                                    0.13313149161855184,
                                ],
                                [
                                    0.4775936250382271,
                                    0.02350665262528449,
                                    0.4754962979311048,
                                    0.023403424405383583,
                                ],
                                [
                                    0.04061325326555385,
                                    0.8677671480001333,
                                    0.004096268438090991,
                                    0.08752333029622184,
                                ],
                                [
                                    0.04271058037267615,
                                    0.912579897923679,
                                    0.0019989413309686875,
                                    0.042710580372676124,
                                ],
                                [
                                    0.041612723931038195,
                                    0.8891224381864714,
                                    0.0030967977726066467,
                                    0.06616804010988378,
                                ],
                                [
                                    0.04366085815008371,
                                    0.8870743039674259,
                                    0.003249218880584362,
                                    0.06601561900190606,
                                ],
                                [
                                    0.04266138748459934,
                                    0.9115288131482442,
                                    0.0020481342190454953,
                                    0.04376166514811092,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.002148941217072757,
                                    0.04366085815008366,
                                ],
                                [
                                    0.16124905812682114,
                                    0.5719007400028323,
                                    0.05869106671285747,
                                    0.2081591351574891,
                                ],
                                [
                                    0.21200361690317066,
                                    0.7519115261736411,
                                    0.00793650793650794,
                                    0.028148348986680196,
                                ],
                                [
                                    0.18543588738406785,
                                    0.6576839731654248,
                                    0.034504237455610764,
                                    0.12237590199489654,
                                ],
                                [
                                    0.19456284545150387,
                                    0.6485570150979889,
                                    0.03620249949565465,
                                    0.12067763995485266,
                                ],
                                [
                                    0.2108131667722426,
                                    0.7476893662508293,
                                    0.009126958067436002,
                                    0.03237050890949208,
                                ],
                                [
                                    0.22118916766579436,
                                    0.7373133653572775,
                                    0.009576177281364126,
                                    0.03192128969556395,
                                ],
                                [
                                    0.22709510031642177,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.27400517734708985,
                                ],
                                [
                                    0.46536758105875475,
                                    0.5111773804259112,
                                    0.011177380425911203,
                                    0.012277658089422806,
                                ],
                                [
                                    0.3406426504746327,
                                    0.37417479175236634,
                                    0.13590231101003328,
                                    0.14928024676296772,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.45977889084579915,
                                    0.5050385513811998,
                                    0.016766070638866804,
                                    0.01841648713413421,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.16124905812682114,
                                    0.058691066712857495,
                                    0.5719007400028322,
                                    0.2081591351574892,
                                ],
                                [
                                    0.7252132901931454,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                ],
                                [
                                    0.4300033713755968,
                                    0.15651165252890845,
                                    0.3031464267540565,
                                    0.11033854934143825,
                                ],
                                [
                                    0.4511676820964912,
                                    0.13534734180801408,
                                    0.3180669729563503,
                                    0.09541800313914443,
                                ],
                                [
                                    0.711985487408759,
                                    0.2591468640221671,
                                    0.021164310720894343,
                                    0.007703337848179608,
                                ],
                                [
                                    0.7470286593636232,
                                    0.2241036920673028,
                                    0.022205995689218255,
                                    0.006661652879855697,
                                ],
                                [
                                    0.040613253265553845,
                                    0.004096268438090994,
                                    0.8677671480001332,
                                    0.08752333029622192,
                                ],
                                [
                                    0.9063814599347184,
                                    0.09141798473825839,
                                    0.0019989413309686884,
                                    0.00020161399605452118,
                                ],
                                [
                                    0.4531907299673592,
                                    0.045708992369129196,
                                    0.4551896712983279,
                                    0.045910606365183716,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383583,
                                    0.4775936250382271,
                                    0.02350665262528449,
                                ],
                                [
                                    0.8860748333019415,
                                    0.0893698505192129,
                                    0.022305567963745596,
                                    0.002249748215100017,
                                ],
                                [
                                    0.9296864985639484,
                                    0.04575818525720601,
                                    0.023403424405383556,
                                    0.0011518917734620578,
                                ],
                                [
                                    0.03277877681150057,
                                    0.7003710213181529,
                                    0.011930744892144267,
                                    0.25491945697820234,
                                ],
                                [
                                    0.03487610391862287,
                                    0.7451837712416985,
                                    0.009833417785021965,
                                    0.2101067070546566,
                                ],
                                [
                                    0.033585445158390674,
                                    0.7176067814328568,
                                    0.011124076545254168,
                                    0.23768369686349836,
                                ],
                                [
                                    0.035238485214234484,
                                    0.7159537413770131,
                                    0.011671591816433588,
                                    0.23713618159231892,
                                ],
                                [
                                    0.03463410871195182,
                                    0.7400131563946296,
                                    0.010075412991693017,
                                    0.2152773219017255,
                                ],
                                [
                                    0.03633876287774609,
                                    0.7383085022288354,
                                    0.010571314152921982,
                                    0.21478142074049653,
                                ],
                                [
                                    0.1301434005506447,
                                    0.46157855398361947,
                                    0.08979672428903393,
                                    0.3184813211767019,
                                ],
                                [
                                    0.18089795932699423,
                                    0.6415893401544284,
                                    0.0390421655126844,
                                    0.13847053500589301,
                                ],
                                [
                                    0.1496644833069869,
                                    0.530813821486566,
                                    0.07027564153269172,
                                    0.2492460536737554,
                                ],
                                [
                                    0.1570308107347419,
                                    0.523447494058811,
                                    0.07373453421241662,
                                    0.24578716099403053,
                                ],
                                [
                                    0.17504176269516167,
                                    0.6208192145719704,
                                    0.044898362144516965,
                                    0.15924066058835096,
                                ],
                                [
                                    0.1836571329490324,
                                    0.6122038443180997,
                                    0.0471082119981261,
                                    0.15703081073474184,
                                ],
                                [
                                    0.18328744953241333,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.3221251605213266,
                                ],
                                [
                                    0.4215599302747463,
                                    0.46305739725167444,
                                    0.05498503120991964,
                                    0.06039764126365958,
                                ],
                                [
                                    0.27493117429862,
                                    0.30199481699101116,
                                    0.20161378718604595,
                                    0.22146022152432288,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.3940674146697865,
                                    0.43285857661984467,
                                    0.08247754681487945,
                                    0.09059646189548937,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.1301434005506447,
                                    0.0473692999679328,
                                    0.6030063975790086,
                                    0.2194809019024139,
                                ],
                                [
                                    0.694107632616969,
                                    0.25263972295445003,
                                    0.0390421655126844,
                                    0.014210478915896644,
                                ],
                                [
                                    0.3470538163084845,
                                    0.12631986147722502,
                                    0.38609598182116883,
                                    0.14053034039312168,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312431,
                                    0.40509921731025633,
                                    0.12152710490403419,
                                ],
                                [
                                    0.6290359323416466,
                                    0.22895507297048365,
                                    0.1041138657880067,
                                    0.03789512889986303,
                                ],
                                [
                                    0.6599964150097172,
                                    0.19799459030241304,
                                    0.10923824004312427,
                                    0.03277075464474546,
                                ],
                                [
                                    0.0327787768115006,
                                    0.0033060801116875952,
                                    0.8756016244541865,
                                    0.08831351862262532,
                                ],
                                [
                                    0.8985469834806651,
                                    0.09062779641185499,
                                    0.00983341778502197,
                                    0.0009918023224579236,
                                ],
                                [
                                    0.36576823071793657,
                                    0.036891525270078274,
                                    0.5426121705477505,
                                    0.05472807346423464,
                                ],
                                [
                                    0.38377095581746706,
                                    0.018888800170547785,
                                    0.5693189671518649,
                                    0.02802127686012029,
                                ],
                                [
                                    0.7986523340525188,
                                    0.08055238342016197,
                                    0.10972806721316822,
                                    0.011067215314150941,
                                ],
                                [
                                    0.8379611564503106,
                                    0.041243561022370215,
                                    0.1151287665190213,
                                    0.005666516008297855,
                                ],
                                [
                                    0.021306097298261266,
                                    0.4552388641864047,
                                    0.023403424405383573,
                                    0.5000516141099505,
                                ],
                                [
                                    0.023403424405383573,
                                    0.5000516141099505,
                                    0.021306097298261266,
                                    0.4552388641864047,
                                ],
                                [
                                    0.021830429075041843,
                                    0.46644205166729114,
                                    0.022879092628602996,
                                    0.488848426629064,
                                ],
                                [
                                    0.022904899683578235,
                                    0.46536758105875475,
                                    0.02400517734708984,
                                    0.4877223419105772,
                                ],
                                [
                                    0.022879092628602996,
                                    0.488848426629064,
                                    0.021830429075041843,
                                    0.46644205166729114,
                                ],
                                [
                                    0.02400517734708984,
                                    0.4877223419105772,
                                    0.022904899683578235,
                                    0.46536758105875475,
                                ],
                                [
                                    0.08459278303166456,
                                    0.3000245444947563,
                                    0.13534734180801405,
                                    0.4800353306655651,
                                ],
                                [
                                    0.13534734180801408,
                                    0.4800353306655652,
                                    0.08459278303166454,
                                    0.3000245444947562,
                                ],
                                [
                                    0.09728142272575194,
                                    0.3450272410374585,
                                    0.12265870211392668,
                                    0.43503263412286286,
                                ],
                                [
                                    0.102069511366434,
                                    0.34023915239677643,
                                    0.1286958335807245,
                                    0.42899550265606506,
                                ],
                                [
                                    0.12265870211392671,
                                    0.43503263412286297,
                                    0.09728142272575192,
                                    0.34502724103745847,
                                ],
                                [
                                    0.12869583358072453,
                                    0.4289955026560652,
                                    0.10206951136643398,
                                    0.3402391523967764,
                                ],
                                [
                                    0.11913624037116649,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.3925912788865005,
                                ],
                                [
                                    0.3574087211134995,
                                    0.3925912788865005,
                                    0.11913624037116649,
                                    0.1308637596288335,
                                ],
                                [
                                    0.17870436055674974,
                                    0.19629563944325026,
                                    0.2978406009279162,
                                    0.3271593990720838,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.2978406009279162,
                                    0.3271593990720838,
                                    0.17870436055674974,
                                    0.19629563944325026,
                                ],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.08459278303166454,
                                    0.030789889441914717,
                                    0.6485570150979888,
                                    0.23606031242843198,
                                ],
                                [
                                    0.6485570150979888,
                                    0.23606031242843198,
                                    0.08459278303166454,
                                    0.030789889441914717,
                                ],
                                [
                                    0.22558384104824564,
                                    0.08210749518854404,
                                    0.5075659570814077,
                                    0.18474270668180265,
                                ],
                                [
                                    0.23668683889285477,
                                    0.07100449734393491,
                                    0.5325478161599867,
                                    0.1597608476032236,
                                ],
                                [
                                    0.5075659570814077,
                                    0.18474270668180265,
                                    0.22558384104824558,
                                    0.08210749518854403,
                                ],
                                [
                                    0.5325478161599867,
                                    0.1597608476032236,
                                    0.23668683889285475,
                                    0.0710044973439349,
                                ],
                                [
                                    0.021306097298261276,
                                    0.0021489412170727588,
                                    0.8870743039674258,
                                    0.08947065751724015,
                                ],
                                [
                                    0.8870743039674258,
                                    0.08947065751724015,
                                    0.021306097298261276,
                                    0.0021489412170727588,
                                ],
                                [
                                    0.2377481489655524,
                                    0.023979370292114607,
                                    0.6706322523001347,
                                    0.0676402284421983,
                                ],
                                [
                                    0.2494498611682442,
                                    0.012277658089422822,
                                    0.7036400618010877,
                                    0.034632418941245253,
                                ],
                                [
                                    0.6706322523001347,
                                    0.0676402284421983,
                                    0.2377481489655524,
                                    0.023979370292114607,
                                ],
                                [
                                    0.7036400618010877,
                                    0.034632418941245253,
                                    0.2494498611682442,
                                    0.012277658089422822,
                                ],
                                [
                                    0.009833417785021966,
                                    0.21010670705465664,
                                    0.03487610391862287,
                                    0.7451837712416985,
                                ],
                                [
                                    0.011930744892144272,
                                    0.2549194569782024,
                                    0.032778776811500564,
                                    0.7003710213181528,
                                ],
                                [
                                    0.010075412991693018,
                                    0.21527732190172555,
                                    0.03463410871195182,
                                    0.7400131563946296,
                                ],
                                [
                                    0.010571314152921986,
                                    0.21478142074049658,
                                    0.03633876287774609,
                                    0.7383085022288354,
                                ],
                                [
                                    0.011124076545254172,
                                    0.23768369686349844,
                                    0.03358544515839067,
                                    0.7176067814328567,
                                ],
                                [
                                    0.011671591816433591,
                                    0.237136181592319,
                                    0.035238485214234484,
                                    0.715953741377013,
                                ],
                                [
                                    0.03904216551268441,
                                    0.13847053500589307,
                                    0.1808979593269942,
                                    0.6415893401544284,
                                ],
                                [
                                    0.08979672428903396,
                                    0.318481321176702,
                                    0.13014340055064466,
                                    0.46157855398361936,
                                ],
                                [
                                    0.04489836214451698,
                                    0.159240660588351,
                                    0.17504176269516164,
                                    0.6208192145719703,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.07027564153269175,
                                    0.2492460536737555,
                                    0.14966448330698687,
                                    0.5308138214865659,
                                ],
                                [
                                    0.07373453421241664,
                                    0.2457871609940306,
                                    0.15703081073474187,
                                    0.5234474940588109,
                                ],
                                [
                                    0.054985031209919655,
                                    0.060397641263659596,
                                    0.4215599302747463,
                                    0.46305739725167444,
                                ],
                                [
                                    0.29325751195225264,
                                    0.3221251605213266,
                                    0.18328744953241333,
                                    0.20132987799400742,
                                ],
                                [
                                    0.08247754681487945,
                                    0.09059646189548937,
                                    0.3940674146697865,
                                    0.43285857661984467,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.20161378718604595,
                                    0.22146022152432288,
                                    0.27493117429862,
                                    0.30199481699101116,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.039042165512684385,
                                    0.014210478915896638,
                                    0.694107632616969,
                                    0.25263972295445003,
                                ],
                                [
                                    0.6030063975790086,
                                    0.2194809019024139,
                                    0.13014340055064466,
                                    0.04736929996793279,
                                ],
                                [
                                    0.10411386578800673,
                                    0.03789512889986304,
                                    0.6290359323416466,
                                    0.22895507297048365,
                                ],
                                [
                                    0.1092382400431243,
                                    0.032770754644745465,
                                    0.6599964150097172,
                                    0.19799459030241304,
                                ],
                                [
                                    0.38609598182116883,
                                    0.14053034039312168,
                                    0.3470538163084845,
                                    0.12631986147722502,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403419,
                                    0.36413543774258517,
                                    0.10923824004312431,
                                ],
                                [
                                    0.00983341778502196,
                                    0.0009918023224579225,
                                    0.8985469834806651,
                                    0.09062779641185499,
                                ],
                                [
                                    0.8756016244541865,
                                    0.08831351862262532,
                                    0.032778776811500585,
                                    0.003306080111687594,
                                ],
                                [
                                    0.10972806721316825,
                                    0.011067215314150945,
                                    0.7986523340525188,
                                    0.08055238342016197,
                                ],
                                [
                                    0.11512876651902133,
                                    0.005666516008297856,
                                    0.8379611564503106,
                                    0.041243561022370215,
                                ],
                                [
                                    0.5426121705477505,
                                    0.05472807346423464,
                                    0.36576823071793657,
                                    0.036891525270078274,
                                ],
                                [
                                    0.5693189671518649,
                                    0.02802127686012029,
                                    0.38377095581746706,
                                    0.018888800170547785,
                                ],
                                [
                                    0.001998941330968689,
                                    0.04271058037267615,
                                    0.04271058037267615,
                                    0.912579897923679,
                                ],
                                [
                                    0.004096268438090994,
                                    0.08752333029622192,
                                    0.040613253265553845,
                                    0.8677671480001332,
                                ],
                                [
                                    0.002048134219045497,
                                    0.04376166514811096,
                                    0.04266138748459934,
                                    0.9115288131482442,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.0030967977726066498,
                                    0.06616804010988385,
                                    0.04161272393103819,
                                    0.8891224381864713,
                                ],
                                [
                                    0.0032492188805843653,
                                    0.06601561900190613,
                                    0.043660858150083706,
                                    0.8870743039674258,
                                ],
                                [
                                    0.007936507936507952,
                                    0.028148348986680238,
                                    0.21200361690317066,
                                    0.7519115261736411,
                                ],
                                [
                                    0.058691066712857495,
                                    0.2081591351574892,
                                    0.16124905812682114,
                                    0.5719007400028322,
                                ],
                                [
                                    0.009126958067436014,
                                    0.03237050890949212,
                                    0.2108131667722426,
                                    0.7476893662508293,
                                ],
                                [
                                    0.009576177281364139,
                                    0.031921289695563994,
                                    0.22118916766579436,
                                    0.7373133653572775,
                                ],
                                [
                                    0.034504237455610785,
                                    0.1223759019948966,
                                    0.18543588738406783,
                                    0.6576839731654248,
                                ],
                                [
                                    0.03620249949565466,
                                    0.12067763995485271,
                                    0.19456284545150385,
                                    0.6485570150979888,
                                ],
                                [
                                    0.011177380425911215,
                                    0.012277658089422822,
                                    0.46536758105875475,
                                    0.5111773804259112,
                                ],
                                [
                                    0.2494498611682442,
                                    0.27400517734708985,
                                    0.22709510031642177,
                                    0.2494498611682442,
                                ],
                                [
                                    0.01676607063886682,
                                    0.018416487134134234,
                                    0.45977889084579915,
                                    0.5050385513811998,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.1359023110100333,
                                    0.14928024676296775,
                                    0.34064265047463266,
                                    0.3741747917523663,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                    0.7252132901931454,
                                    0.2639614896993748,
                                ],
                                [
                                    0.5719007400028322,
                                    0.2081591351574892,
                                    0.16124905812682114,
                                    0.058691066712857495,
                                ],
                                [
                                    0.021164310720894364,
                                    0.007703337848179616,
                                    0.711985487408759,
                                    0.2591468640221671,
                                ],
                                [
                                    0.022205995689218275,
                                    0.006661652879855703,
                                    0.7470286593636232,
                                    0.2241036920673028,
                                ],
                                [
                                    0.3031464267540565,
                                    0.11033854934143825,
                                    0.4300033713755968,
                                    0.15651165252890845,
                                ],
                                [
                                    0.3180669729563503,
                                    0.09541800313914443,
                                    0.4511676820964912,
                                    0.13534734180801408,
                                ],
                                [
                                    0.0019989413309687114,
                                    0.00020161399605452348,
                                    0.9063814599347184,
                                    0.09141798473825839,
                                ],
                                [
                                    0.8677671480001332,
                                    0.08752333029622192,
                                    0.040613253265553866,
                                    0.004096268438090996,
                                ],
                                [
                                    0.022305567963745634,
                                    0.002249748215100021,
                                    0.8860748333019415,
                                    0.0893698505192129,
                                ],
                                [
                                    0.023403424405383594,
                                    0.0011518917734620597,
                                    0.9296864985639484,
                                    0.04575818525720601,
                                ],
                                [
                                    0.4551896712983279,
                                    0.045910606365183716,
                                    0.4531907299673592,
                                    0.045708992369129196,
                                ],
                                [
                                    0.4775936250382271,
                                    0.02350665262528449,
                                    0.4754962979311048,
                                    0.023403424405383583,
                                ],
                                [
                                    0.0019989413309687114,
                                    0.9063814599347185,
                                    0.00020161399605452332,
                                    0.09141798473825831,
                                ],
                                [
                                    0.0021021695508696182,
                                    0.9531883087454855,
                                    9.838577615361652e-05,
                                    0.04461113592749119,
                                ],
                                [
                                    0.002021645358540695,
                                    0.9166761641055106,
                                    0.00017890996848254006,
                                    0.08112328056746622,
                                ],
                                [
                                    0.04309618500986467,
                                    0.8756016244541865,
                                    0.003813892020803409,
                                    0.07748829851514534,
                                ],
                                [
                                    0.0021010520826678877,
                                    0.9526816143045715,
                                    9.950324435534717e-05,
                                    0.045117830368405276,
                                ],
                                [
                                    0.04478892842777206,
                                    0.9099937379594674,
                                    0.0021211486028960176,
                                    0.043096185009864604,
                                ],
                                [
                                    0.007936507936507941,
                                    0.7252132901931455,
                                    0.0028887121709719418,
                                    0.26396148969937466,
                                ],
                                [
                                    0.010434593588739452,
                                    0.9534805494880724,
                                    0.00039062651874043086,
                                    0.035694230404447705,
                                ],
                                [
                                    0.00848593720671995,
                                    0.7754184196992829,
                                    0.002339282900759933,
                                    0.2137563601932371,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.01040755126170671,
                                    0.9510095061628737,
                                    0.0004176688457731745,
                                    0.038165273729646475,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.011177380425911215,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.5111773804259112,
                                ],
                                [
                                    0.022904899683578235,
                                    0.9536400618010877,
                                    0.0005501388317558024,
                                    0.022904899683578207,
                                ],
                                [
                                    0.013756732475502234,
                                    0.572758291429003,
                                    0.009698306039831803,
                                    0.40378667005566293,
                                ],
                                [
                                    0.29325751195225264,
                                    0.29325751195225264,
                                    0.20674248804774736,
                                    0.20674248804774736,
                                ],
                                [
                                    0.02277794670629928,
                                    0.9483544047246267,
                                    0.000677091809034757,
                                    0.028190556760039193,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.007936507936507952,
                                    0.21200361690317066,
                                    0.028148348986680238,
                                    0.7519115261736411,
                                ],
                                [
                                    0.03569423040444776,
                                    0.9534805494880724,
                                    0.00039062651874043145,
                                    0.010434593588739452,
                                ],
                                [
                                    0.014041544881371788,
                                    0.375084146021636,
                                    0.022043312041816403,
                                    0.5888309970551758,
                                ],
                                [
                                    0.2993289666139738,
                                    0.08979672428903396,
                                    0.4699056884388677,
                                    0.14096862065812454,
                                ],
                                [
                                    0.035393746949049974,
                                    0.9454538984882218,
                                    0.0006911099741382195,
                                    0.018461244588590033,
                                ],
                                [
                                    0.7545020001973315,
                                    0.22634564523994025,
                                    0.014732654855509982,
                                    0.00441969970721827,
                                ],
                                [
                                    0.001998941330968689,
                                    0.04271058037267615,
                                    0.04271058037267615,
                                    0.912579897923679,
                                ],
                                [
                                    0.04461113592749122,
                                    0.9531883087454855,
                                    9.838577615361546e-05,
                                    0.002102169550869594,
                                ],
                                [
                                    0.011371072730220536,
                                    0.2429611656147389,
                                    0.033338448973424306,
                                    0.7123293126816163,
                                ],
                                [
                                    0.24240149345281517,
                                    0.01193074489214428,
                                    0.7106884295165168,
                                    0.03497933213852379,
                                ],
                                [
                                    0.0441498495417211,
                                    0.9433321869328917,
                                    0.0005596721619237368,
                                    0.011958291363463536,
                                ],
                                [
                                    0.9411591780771876,
                                    0.04632285839742507,
                                    0.011930744892144263,
                                    0.0005872186332430102,
                                ],
                                [
                                    0.001613336693780218,
                                    0.7315364614358733,
                                    0.0005872186332430168,
                                    0.26626298323710357,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.7783433102466403,
                                    0.00048399041334210995,
                                    0.21945613442633646,
                                ],
                                [
                                    0.0016316610138645536,
                                    0.7398452715710372,
                                    0.0005688943131586813,
                                    0.2579541731019395,
                                ],
                                [
                                    0.03478274002402122,
                                    0.7066941925608805,
                                    0.012127337006646853,
                                    0.24639573040845136,
                                ],
                                [
                                    0.0017110677379917466,
                                    0.7758507217700982,
                                    0.0004894875890314882,
                                    0.22194872290287856,
                                ],
                                [
                                    0.036475483441928615,
                                    0.7410863060661613,
                                    0.01043459358873946,
                                    0.2120036169031706,
                                ],
                                [
                                    0.0064055204002616125,
                                    0.5853164341340025,
                                    0.00441969970721827,
                                    0.4038583457585176,
                                ],
                                [
                                    0.008903606052493124,
                                    0.8135836934289296,
                                    0.0019216140549867587,
                                    0.17559108646359065,
                                ],
                                [
                                    0.00684896233051594,
                                    0.6258367717714194,
                                    0.003976257776963942,
                                    0.3633380081211008,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.008770576385502698,
                                    0.80142785823501,
                                    0.0020546437219771834,
                                    0.1877469216575101,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.009021214230797044,
                                    0.3755961132956237,
                                    0.014433824284536993,
                                    0.6009488481890423,
                                ],
                                [
                                    0.020748733488464063,
                                    0.8638685940379567,
                                    0.0027063050268699733,
                                    0.11267636744670925,
                                ],
                                [
                                    0.01110299784460914,
                                    0.4622706799411003,
                                    0.012352040670724897,
                                    0.5142742815435656,
                                ],
                                [
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.26331316110714525,
                                    0.26331316110714525,
                                ],
                                [
                                    0.020124212075406184,
                                    0.8378667932367241,
                                    0.0033308264399278514,
                                    0.13867816824794188,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.006405520400261623,
                                    0.17110718011831585,
                                    0.029679336522926567,
                                    0.792807962958496,
                                ],
                                [
                                    0.03416324286820143,
                                    0.9125841127032176,
                                    0.0019216140549867615,
                                    0.05133103037359428,
                                ],
                                [
                                    0.011332868675790812,
                                    0.302728752793693,
                                    0.02475198824739738,
                                    0.6611863902831189,
                                ],
                                [
                                    0.24158708305641444,
                                    0.07247453841306935,
                                    0.5276475719964271,
                                    0.15829080653408914,
                                ],
                                [
                                    0.032685070743469,
                                    0.8730985052602788,
                                    0.0033997861797191954,
                                    0.090816637816533,
                                ],
                                [
                                    0.6967601166397722,
                                    0.20902345936397562,
                                    0.07247453841306932,
                                    0.02174188558318288,
                                ],
                                [
                                    0.0016133366937802012,
                                    0.03447152022940799,
                                    0.04309618500986464,
                                    0.9208189580669471,
                                ],
                                [
                                    0.04422553129030273,
                                    0.9449492486022174,
                                    0.0004839904133421048,
                                    0.010341229694137788,
                                ],
                                [
                                    0.009177542431632053,
                                    0.19609288055488527,
                                    0.035531979272012786,
                                    0.7591975977414699,
                                ],
                                [
                                    0.19564117163210198,
                                    0.009629251354415346,
                                    0.75744875133723,
                                    0.03728082567625273,
                                ],
                                [
                                    0.04195631924313262,
                                    0.896463901873038,
                                    0.002753202460512222,
                                    0.0588265764233172,
                                ],
                                [
                                    0.8943988562564745,
                                    0.04402136485969613,
                                    0.058691066712857475,
                                    0.0028887121709719452,
                                ],
                                [
                                    0.001048663553561164,
                                    0.4754962979311048,
                                    0.0011518917734620708,
                                    0.522303146741872,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.522303146741872,
                                    0.001048663553561164,
                                    0.4754962979311048,
                                ],
                                [
                                    0.001060574301448021,
                                    0.4808969972369579,
                                    0.0011399810255752138,
                                    0.5169024474360189,
                                ],
                                [
                                    0.02260866680638034,
                                    0.45934890473202555,
                                    0.024301410224287733,
                                    0.4937410182373064,
                                ],
                                [
                                    0.0011399810255752138,
                                    0.5169024474360189,
                                    0.001060574301448021,
                                    0.4808969972369579,
                                ],
                                [
                                    0.024301410224287733,
                                    0.4937410182373064,
                                    0.02260866680638034,
                                    0.45934890473202555,
                                ],
                                [
                                    0.004163567227624187,
                                    0.3804537602987967,
                                    0.006661652879855696,
                                    0.6087210195937235,
                                ],
                                [
                                    0.006661652879855697,
                                    0.6087210195937236,
                                    0.004163567227624186,
                                    0.3804537602987966,
                                ],
                                [
                                    0.004451803026246561,
                                    0.4067918467144647,
                                    0.006373417081233321,
                                    0.5823829331780555,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.006373417081233321,
                                    0.5823829331780555,
                                    0.004451803026246562,
                                    0.4067918467144648,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.005863759628833509,
                                    0.2441362403711665,
                                    0.017591278886500528,
                                    0.7324087211134995,
                                ],
                                [
                                    0.017591278886500528,
                                    0.7324087211134995,
                                    0.005863759628833509,
                                    0.2441362403711665,
                                ],
                                [
                                    0.007216912142268497,
                                    0.3004744240945212,
                                    0.01623812637306554,
                                    0.6760705373901448,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.01623812637306554,
                                    0.6760705373901448,
                                    0.007216912142268496,
                                    0.30047442409452113,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.004163567227624192,
                                    0.11121910524595506,
                                    0.031921289695564,
                                    0.8526960378308568,
                                ],
                                [
                                    0.031921289695564,
                                    0.8526960378308568,
                                    0.004163567227624192,
                                    0.11121910524595506,
                                ],
                                [
                                    0.007366327427755003,
                                    0.196772695305113,
                                    0.028718529495433187,
                                    0.7671424477716988,
                                ],
                                [
                                    0.15703081073474187,
                                    0.047108211998126114,
                                    0.6122038443180996,
                                    0.18365713294903238,
                                ],
                                [
                                    0.028718529495433187,
                                    0.7671424477716988,
                                    0.007366327427755003,
                                    0.196772695305113,
                                ],
                                [
                                    0.6122038443180996,
                                    0.18365713294903238,
                                    0.15703081073474187,
                                    0.047108211998126114,
                                ],
                                [
                                    0.0010486635535611527,
                                    0.022406374961772883,
                                    0.043660858150083685,
                                    0.9328841033345823,
                                ],
                                [
                                    0.043660858150083685,
                                    0.9328841033345823,
                                    0.0010486635535611527,
                                    0.022406374961772883,
                                ],
                                [
                                    0.005965372446072136,
                                    0.1274597284891012,
                                    0.038744149257572705,
                                    0.8278307498072539,
                                ],
                                [
                                    0.1271661191724797,
                                    0.006258981762693645,
                                    0.8259238037968523,
                                    0.04065109526797443,
                                ],
                                [
                                    0.038744149257572705,
                                    0.8278307498072539,
                                    0.005965372446072136,
                                    0.1274597284891012,
                                ],
                                [
                                    0.8259238037968523,
                                    0.04065109526797443,
                                    0.1271661191724797,
                                    0.006258981762693645,
                                ],
                                [
                                    0.00048399041334211006,
                                    0.21945613442633652,
                                    0.0017165649136811247,
                                    0.7783433102466403,
                                ],
                                [
                                    0.000587218633243017,
                                    0.2662629832371037,
                                    0.0016133366937802177,
                                    0.7315364614358731,
                                ],
                                [
                                    0.0004894875890314887,
                                    0.22194872290287876,
                                    0.001711067737991746,
                                    0.775850721770098,
                                ],
                                [
                                    0.01043459358873947,
                                    0.2120036169031708,
                                    0.0364754834419286,
                                    0.7410863060661611,
                                ],
                                [
                                    0.0005688943131586815,
                                    0.25795417310193963,
                                    0.0016316610138645533,
                                    0.7398452715710371,
                                ],
                                [
                                    0.012127337006646859,
                                    0.24639573040845147,
                                    0.034782740024021215,
                                    0.7066941925608804,
                                ],
                                [
                                    0.0019216140549867596,
                                    0.17559108646359073,
                                    0.008903606052493122,
                                    0.8135836934289294,
                                ],
                                [
                                    0.004419699707218271,
                                    0.4038583457585177,
                                    0.006405520400261612,
                                    0.5853164341340024,
                                ],
                                [
                                    0.002054643721977184,
                                    0.18774692165751014,
                                    0.008770576385502698,
                                    0.80142785823501,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.003976257776963942,
                                    0.3633380081211008,
                                    0.00684896233051594,
                                    0.6258367717714194,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.0027063050268699737,
                                    0.11267636744670928,
                                    0.020748733488464063,
                                    0.8638685940379567,
                                ],
                                [
                                    0.014433824284536993,
                                    0.6009488481890423,
                                    0.009021214230797044,
                                    0.3755961132956237,
                                ],
                                [
                                    0.003330826439927852,
                                    0.1386781682479419,
                                    0.020124212075406184,
                                    0.8378667932367241,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.012352040670724897,
                                    0.5142742815435656,
                                    0.01110299784460914,
                                    0.4622706799411003,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.001921614054986761,
                                    0.05133103037359426,
                                    0.03416324286820143,
                                    0.9125841127032176,
                                ],
                                [
                                    0.029679336522926567,
                                    0.792807962958496,
                                    0.006405520400261622,
                                    0.17110718011831583,
                                ],
                                [
                                    0.0033997861797191945,
                                    0.09081663781653299,
                                    0.032685070743469,
                                    0.8730985052602788,
                                ],
                                [
                                    0.0724745384130693,
                                    0.021741885583182876,
                                    0.6967601166397722,
                                    0.20902345936397562,
                                ],
                                [
                                    0.02475198824739738,
                                    0.6611863902831189,
                                    0.01133286867579081,
                                    0.30272875279369293,
                                ],
                                [
                                    0.5276475719964271,
                                    0.15829080653408914,
                                    0.2415870830564144,
                                    0.07247453841306933,
                                ],
                                [
                                    0.0004839904133421043,
                                    0.010341229694137779,
                                    0.04422553129030273,
                                    0.9449492486022174,
                                ],
                                [
                                    0.04309618500986464,
                                    0.9208189580669471,
                                    0.0016133366937802005,
                                    0.03447152022940798,
                                ],
                                [
                                    0.0027532024605122244,
                                    0.05882657642331726,
                                    0.04195631924313262,
                                    0.8964639018730379,
                                ],
                                [
                                    0.05869106671285754,
                                    0.0028887121709719483,
                                    0.8943988562564744,
                                    0.04402136485969613,
                                ],
                                [
                                    0.03553197927201279,
                                    0.75919759774147,
                                    0.00917754243163205,
                                    0.19609288055488522,
                                ],
                                [
                                    0.7574487513372301,
                                    0.03728082567625273,
                                    0.19564117163210193,
                                    0.009629251354415343,
                                ],
                                [
                                    9.838577615361658e-05,
                                    0.04461113592749122,
                                    0.0021021695508696182,
                                    0.9531883087454855,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.09141798473825839,
                                    0.0019989413309687114,
                                    0.9063814599347184,
                                ],
                                [
                                    9.950324435534757e-05,
                                    0.045117830368405464,
                                    0.0021010520826678872,
                                    0.9526816143045713,
                                ],
                                [
                                    0.0021211486028960263,
                                    0.043096185009864785,
                                    0.044788928427772046,
                                    0.9099937379594671,
                                ],
                                [
                                    0.00017890996848254036,
                                    0.08112328056746636,
                                    0.0020216453585406944,
                                    0.9166761641055104,
                                ],
                                [
                                    0.0038138920208034156,
                                    0.07748829851514548,
                                    0.04309618500986466,
                                    0.8756016244541864,
                                ],
                                [
                                    0.00039062651874043145,
                                    0.03569423040444776,
                                    0.010434593588739452,
                                    0.9534805494880724,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.7252132901931454,
                                ],
                                [
                                    0.0004176688457731752,
                                    0.038165273729646544,
                                    0.010407551261706708,
                                    0.9510095061628736,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.0023392829007599335,
                                    0.21375636019323715,
                                    0.00848593720671995,
                                    0.7754184196992829,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.000550138831755803,
                                    0.022904899683578235,
                                    0.022904899683578235,
                                    0.9536400618010877,
                                ],
                                [
                                    0.012277658089422822,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.46536758105875475,
                                ],
                                [
                                    0.0006770918090347577,
                                    0.02819055676003922,
                                    0.02277794670629928,
                                    0.9483544047246267,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.009698306039831803,
                                    0.40378667005566293,
                                    0.013756732475502234,
                                    0.572758291429003,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.00039062651874043145,
                                    0.010434593588739452,
                                    0.03569423040444776,
                                    0.9534805494880724,
                                ],
                                [
                                    0.028148348986680238,
                                    0.7519115261736411,
                                    0.007936507936507952,
                                    0.21200361690317066,
                                ],
                                [
                                    0.0006911099741382229,
                                    0.018461244588590123,
                                    0.03539374694904997,
                                    0.9454538984882217,
                                ],
                                [
                                    0.014732654855510055,
                                    0.004419699707218292,
                                    0.7545020001973315,
                                    0.22634564523994022,
                                ],
                                [
                                    0.022043312041816407,
                                    0.5888309970551759,
                                    0.014041544881371786,
                                    0.3750841460216359,
                                ],
                                [
                                    0.4699056884388678,
                                    0.14096862065812457,
                                    0.29932896661397373,
                                    0.08979672428903394,
                                ],
                                [
                                    9.838577615361658e-05,
                                    0.0021021695508696182,
                                    0.04461113592749122,
                                    0.9531883087454855,
                                ],
                                [
                                    0.04271058037267615,
                                    0.912579897923679,
                                    0.0019989413309686897,
                                    0.04271058037267617,
                                ],
                                [
                                    0.0005596721619237409,
                                    0.011958291363463625,
                                    0.044149849541721096,
                                    0.9433321869328916,
                                ],
                                [
                                    0.011930744892144352,
                                    0.0005872186332430146,
                                    0.9411591780771876,
                                    0.04632285839742506,
                                ],
                                [
                                    0.033338448973424306,
                                    0.7123293126816164,
                                    0.011371072730220533,
                                    0.24296116561473885,
                                ],
                                [
                                    0.7106884295165169,
                                    0.0349793321385238,
                                    0.24240149345281511,
                                    0.011930744892144277,
                                ],
                                [
                                    0.009833417785021961,
                                    0.8985469834806652,
                                    0.0009918023224579217,
                                    0.09062779641185491,
                                ],
                                [
                                    0.010341229694137779,
                                    0.9449492486022174,
                                    0.00048399041334210404,
                                    0.044225531290302704,
                                ],
                                [
                                    0.009945105999707968,
                                    0.9087527034643432,
                                    0.000880114107771913,
                                    0.08042207642817684,
                                ],
                                [
                                    0.04309618500986467,
                                    0.8756016244541865,
                                    0.003813892020803409,
                                    0.07748829851514534,
                                ],
                                [
                                    0.0103357325184484,
                                    0.944446933868791,
                                    0.0004894875890314823,
                                    0.044727846023729145,
                                ],
                                [
                                    0.04478892842777206,
                                    0.9099937379594674,
                                    0.0021211486028960176,
                                    0.043096185009864604,
                                ],
                                [
                                    0.039042165512684385,
                                    0.6941076326169691,
                                    0.014210478915896631,
                                    0.25263972295445,
                                ],
                                [
                                    0.05133103037359426,
                                    0.9125841127032176,
                                    0.0019216140549867579,
                                    0.034163242868201375,
                                ],
                                [
                                    0.04174497998433084,
                                    0.7421593769216721,
                                    0.011507664444250174,
                                    0.20458797864974687,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.05119800070660384,
                                    0.9102190567179765,
                                    0.0020546437219771826,
                                    0.03652829885344247,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.054985031209919655,
                                    0.4215599302747463,
                                    0.060397641263659596,
                                    0.46305739725167444,
                                ],
                                [
                                    0.11267636744670928,
                                    0.8638685940379567,
                                    0.0027063050268699707,
                                    0.02074873348846404,
                                ],
                                [
                                    0.06767367090400704,
                                    0.5188413530004983,
                                    0.04770900156957222,
                                    0.36577597452592253,
                                ],
                                [
                                    0.29325751195225264,
                                    0.29325751195225264,
                                    0.20674248804774736,
                                    0.20674248804774736,
                                ],
                                [
                                    0.1120518460336514,
                                    0.8590805053972747,
                                    0.0033308264399278483,
                                    0.0255368221291461,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.03904216551268439,
                                    0.18089795932699423,
                                    0.138470535005893,
                                    0.6415893401544284,
                                ],
                                [
                                    0.17559108646359062,
                                    0.8135836934289296,
                                    0.0019216140549867583,
                                    0.008903606052493124,
                                ],
                                [
                                    0.06907475223335012,
                                    0.3200509386696576,
                                    0.10843794828522725,
                                    0.502436360811765,
                                ],
                                [
                                    0.2993289666139738,
                                    0.08979672428903396,
                                    0.4699056884388677,
                                    0.14096862065812454,
                                ],
                                [
                                    0.17411291433885817,
                                    0.8067347310984135,
                                    0.0033997861797191893,
                                    0.015752568383009063,
                                ],
                                [
                                    0.7545020001973315,
                                    0.22634564523994025,
                                    0.014732654855509982,
                                    0.00441969970721827,
                                ],
                                [
                                    0.009833417785021966,
                                    0.03487610391862287,
                                    0.21010670705465664,
                                    0.7451837712416985,
                                ],
                                [
                                    0.21945613442633652,
                                    0.7783433102466403,
                                    0.00048399041334210453,
                                    0.001716564913681105,
                                ],
                                [
                                    0.055937864252345273,
                                    0.19839437409261415,
                                    0.16400226058733333,
                                    0.5816655010677072,
                                ],
                                [
                                    0.24240149345281517,
                                    0.01193074489214428,
                                    0.7106884295165168,
                                    0.03497933213852379,
                                ],
                                [
                                    0.2171869223791664,
                                    0.7702951140954464,
                                    0.0027532024605122205,
                                    0.009764761064875054,
                                ],
                                [
                                    0.9411591780771876,
                                    0.04632285839742507,
                                    0.011930744892144263,
                                    0.0005872186332430102,
                                ],
                                [
                                    0.007936507936507941,
                                    0.7252132901931455,
                                    0.0028887121709719418,
                                    0.26396148969937466,
                                ],
                                [
                                    0.008444319845623757,
                                    0.7716155553146976,
                                    0.002380900261856124,
                                    0.21755922457782245,
                                ],
                                [
                                    0.008026650999850584,
                                    0.7334502815850512,
                                    0.0027985691076292986,
                                    0.2557244983074689,
                                ],
                                [
                                    0.03478274002402122,
                                    0.7066941925608805,
                                    0.012127337006646853,
                                    0.24639573040845136,
                                ],
                                [
                                    0.008417277518591015,
                                    0.769144511989499,
                                    0.0024079425888888675,
                                    0.2200302679030212,
                                ],
                                [
                                    0.036475483441928615,
                                    0.7410863060661613,
                                    0.01043459358873946,
                                    0.2120036169031706,
                                ],
                                [
                                    0.031510758845398154,
                                    0.560211195688866,
                                    0.02174188558318287,
                                    0.386536159882553,
                                ],
                                [
                                    0.04379962370630803,
                                    0.7786876757751146,
                                    0.009453020722272993,
                                    0.1680596797963044,
                                ],
                                [
                                    0.03369218843316612,
                                    0.5989935456687692,
                                    0.019560455995414904,
                                    0.3477538099026498,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.04314520915543911,
                                    0.7670532254650736,
                                    0.010107435273141912,
                                    0.17969413010634538,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.044378175129644364,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.5443781751296444,
                                ],
                                [
                                    0.10206951136643398,
                                    0.7825478161599868,
                                    0.01331316110714526,
                                    0.10206951136643397,
                                ],
                                [
                                    0.054619120021562155,
                                    0.41875455776414733,
                                    0.060763552452017096,
                                    0.4658627697622734,
                                ],
                                [
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.26331316110714525,
                                    0.26331316110714525,
                                ],
                                [
                                    0.09899729515120652,
                                    0.7589937101609238,
                                    0.01638537732237273,
                                    0.12562361736549701,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.03151075884539816,
                                    0.14600194167317931,
                                    0.1460019416731792,
                                    0.6764853578082433,
                                ],
                                [
                                    0.16805967979630437,
                                    0.7786876757751146,
                                    0.009453020722272994,
                                    0.04379962370630805,
                                ],
                                [
                                    0.05574992655629129,
                                    0.2583116949131925,
                                    0.12176277396228609,
                                    0.5641756045682301,
                                ],
                                [
                                    0.24158708305641444,
                                    0.07247453841306935,
                                    0.5276475719964271,
                                    0.15829080653408914,
                                ],
                                [
                                    0.16078808866179936,
                                    0.7449954873419484,
                                    0.016724611856778024,
                                    0.07749181213947418,
                                ],
                                [
                                    0.6967601166397722,
                                    0.20902345936397562,
                                    0.07247453841306932,
                                    0.02174188558318288,
                                ],
                                [
                                    0.007936507936507952,
                                    0.028148348986680238,
                                    0.21200361690317066,
                                    0.7519115261736411,
                                ],
                                [
                                    0.2175592245778225,
                                    0.7716155553146976,
                                    0.0023809002618561267,
                                    0.008444319845623766,
                                ],
                                [
                                    0.045147202457548254,
                                    0.16012322052896907,
                                    0.17479292238213037,
                                    0.6199366546313523,
                                ],
                                [
                                    0.19564117163210198,
                                    0.009629251354415346,
                                    0.75744875133723,
                                    0.03728082567625273,
                                ],
                                [
                                    0.20639626058436938,
                                    0.7320239605318013,
                                    0.013543864255309249,
                                    0.04803591462852017,
                                ],
                                [
                                    0.8943988562564745,
                                    0.04402136485969613,
                                    0.058691066712857475,
                                    0.0028887121709719452,
                                ],
                                [
                                    0.0051587040991820324,
                                    0.47138625738548395,
                                    0.00566651600829785,
                                    0.5177885225070362,
                                ],
                                [
                                    0.00566651600829785,
                                    0.5177885225070362,
                                    0.0051587040991820324,
                                    0.47138625738548395,
                                ],
                                [
                                    0.005217296794369726,
                                    0.4767402747440362,
                                    0.005607923313110157,
                                    0.512434505148484,
                                ],
                                [
                                    0.02260866680638034,
                                    0.45934890473202555,
                                    0.024301410224287733,
                                    0.4937410182373064,
                                ],
                                [
                                    0.005607923313110157,
                                    0.512434505148484,
                                    0.005217296794369726,
                                    0.4767402747440362,
                                ],
                                [
                                    0.024301410224287733,
                                    0.4937410182373064,
                                    0.02260866680638034,
                                    0.45934890473202555,
                                ],
                                [
                                    0.020481889783835576,
                                    0.3641354377425853,
                                    0.032770754644745444,
                                    0.5826119178288337,
                                ],
                                [
                                    0.03277075464474545,
                                    0.5826119178288338,
                                    0.020481889783835572,
                                    0.36413543774258517,
                                ],
                                [
                                    0.02189981185315401,
                                    0.3893438378875572,
                                    0.03135283257542701,
                                    0.5574035176838618,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.03135283257542701,
                                    0.5574035176838618,
                                    0.021899811853154014,
                                    0.3893438378875573,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.028845668118394813,
                                    0.2211543318816052,
                                    0.08653700435518444,
                                    0.6634629956448156,
                                ],
                                [
                                    0.08653700435518444,
                                    0.6634629956448156,
                                    0.028845668118394813,
                                    0.2211543318816052,
                                ],
                                [
                                    0.035502248671967454,
                                    0.27218908756482224,
                                    0.0798804238016118,
                                    0.6124282399615986,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.0798804238016118,
                                    0.6124282399615986,
                                    0.03550224867196745,
                                    0.2721890875648222,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.020481889783835576,
                                    0.09490078268974368,
                                    0.1570308107347418,
                                    0.727586516791679,
                                ],
                                [
                                    0.1570308107347418,
                                    0.727586516791679,
                                    0.020481889783835576,
                                    0.09490078268974368,
                                ],
                                [
                                    0.03623726920653465,
                                    0.16790175352633332,
                                    0.1412754313120427,
                                    0.6545855459550893,
                                ],
                                [
                                    0.15703081073474187,
                                    0.047108211998126114,
                                    0.6122038443180996,
                                    0.18365713294903238,
                                ],
                                [
                                    0.1412754313120427,
                                    0.6545855459550893,
                                    0.03623726920653465,
                                    0.16790175352633332,
                                ],
                                [
                                    0.6122038443180996,
                                    0.18365713294903238,
                                    0.15703081073474187,
                                    0.047108211998126114,
                                ],
                                [
                                    0.0051587040991820385,
                                    0.018296334416152,
                                    0.21478142074049658,
                                    0.7617635407441694,
                                ],
                                [
                                    0.21478142074049658,
                                    0.7617635407441694,
                                    0.0051587040991820385,
                                    0.018296334416152,
                                ],
                                [
                                    0.029345533356428748,
                                    0.1040795675787446,
                                    0.19059459148324986,
                                    0.6759803075815768,
                                ],
                                [
                                    0.1271661191724797,
                                    0.006258981762693645,
                                    0.8259238037968523,
                                    0.04065109526797443,
                                ],
                                [
                                    0.19059459148324986,
                                    0.6759803075815768,
                                    0.029345533356428748,
                                    0.1040795675787446,
                                ],
                                [
                                    0.8259238037968523,
                                    0.04065109526797443,
                                    0.1271661191724797,
                                    0.006258981762693645,
                                ],
                                [
                                    0.0023809002618561245,
                                    0.2175592245778225,
                                    0.008444319845623757,
                                    0.7716155553146976,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.7252132901931454,
                                ],
                                [
                                    0.0024079425888888697,
                                    0.22003026790302138,
                                    0.008417277518591013,
                                    0.7691445119894987,
                                ],
                                [
                                    0.01043459358873947,
                                    0.2120036169031708,
                                    0.0364754834419286,
                                    0.7410863060661611,
                                ],
                                [
                                    0.0027985691076293,
                                    0.255724498307469,
                                    0.008026650999850582,
                                    0.7334502815850511,
                                ],
                                [
                                    0.012127337006646859,
                                    0.24639573040845147,
                                    0.034782740024021215,
                                    0.7066941925608804,
                                ],
                                [
                                    0.009453020722272996,
                                    0.16805967979630448,
                                    0.04379962370630802,
                                    0.7786876757751144,
                                ],
                                [
                                    0.021741885583182873,
                                    0.38653615988255313,
                                    0.03151075884539815,
                                    0.5602111956888659,
                                ],
                                [
                                    0.010107435273141913,
                                    0.1796941301063454,
                                    0.04314520915543911,
                                    0.7670532254650736,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.019560455995414904,
                                    0.3477538099026498,
                                    0.03369218843316612,
                                    0.5989935456687692,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.013313161107145264,
                                    0.10206951136643398,
                                    0.10206951136643398,
                                    0.7825478161599868,
                                ],
                                [
                                    0.0710044973439349,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.3402391523967764,
                                ],
                                [
                                    0.016385377322372732,
                                    0.12562361736549701,
                                    0.09899729515120652,
                                    0.7589937101609238,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.060763552452017096,
                                    0.4658627697622734,
                                    0.054619120021562155,
                                    0.41875455776414733,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.009453020722272991,
                                    0.04379962370630803,
                                    0.16805967979630437,
                                    0.7786876757751146,
                                ],
                                [
                                    0.1460019416731792,
                                    0.6764853578082433,
                                    0.031510758845398154,
                                    0.14600194167317931,
                                ],
                                [
                                    0.01672461185677802,
                                    0.07749181213947416,
                                    0.16078808866179936,
                                    0.7449954873419484,
                                ],
                                [
                                    0.0724745384130693,
                                    0.021741885583182876,
                                    0.6967601166397722,
                                    0.20902345936397562,
                                ],
                                [
                                    0.12176277396228609,
                                    0.5641756045682301,
                                    0.055749926556291275,
                                    0.25831169491319245,
                                ],
                                [
                                    0.5276475719964271,
                                    0.15829080653408914,
                                    0.2415870830564144,
                                    0.07247453841306933,
                                ],
                                [
                                    0.0023809002618561245,
                                    0.008444319845623757,
                                    0.2175592245778225,
                                    0.7716155553146976,
                                ],
                                [
                                    0.21200361690317066,
                                    0.7519115261736411,
                                    0.007936507936507948,
                                    0.028148348986680227,
                                ],
                                [
                                    0.013543864255309263,
                                    0.04803591462852022,
                                    0.20639626058436936,
                                    0.7320239605318012,
                                ],
                                [
                                    0.05869106671285754,
                                    0.0028887121709719483,
                                    0.8943988562564744,
                                    0.04402136485969613,
                                ],
                                [
                                    0.1747929223821304,
                                    0.6199366546313524,
                                    0.04514720245754824,
                                    0.16012322052896902,
                                ],
                                [
                                    0.7574487513372301,
                                    0.03728082567625273,
                                    0.19564117163210193,
                                    0.009629251354415343,
                                ],
                                [
                                    0.0004839904133421043,
                                    0.04422553129030273,
                                    0.010341229694137779,
                                    0.9449492486022174,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.09062779641185499,
                                    0.00983341778502196,
                                    0.8985469834806651,
                                ],
                                [
                                    0.0004894875890314843,
                                    0.044727846023729326,
                                    0.010335732518448399,
                                    0.9444469338687908,
                                ],
                                [
                                    0.0021211486028960263,
                                    0.043096185009864785,
                                    0.044788928427772046,
                                    0.9099937379594671,
                                ],
                                [
                                    0.0008801141077719145,
                                    0.08042207642817698,
                                    0.009945105999707968,
                                    0.9087527034643431,
                                ],
                                [
                                    0.0038138920208034156,
                                    0.07748829851514548,
                                    0.04309618500986466,
                                    0.8756016244541864,
                                ],
                                [
                                    0.001921614054986761,
                                    0.03416324286820143,
                                    0.05133103037359426,
                                    0.9125841127032176,
                                ],
                                [
                                    0.014210478915896638,
                                    0.25263972295445003,
                                    0.039042165512684385,
                                    0.694107632616969,
                                ],
                                [
                                    0.0020546437219771865,
                                    0.03652829885344253,
                                    0.05119800070660383,
                                    0.9102190567179764,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.011507664444250177,
                                    0.20458797864974693,
                                    0.04174497998433084,
                                    0.7421593769216721,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.0027063050268699737,
                                    0.020748733488464063,
                                    0.11267636744670928,
                                    0.8638685940379567,
                                ],
                                [
                                    0.060397641263659596,
                                    0.46305739725167444,
                                    0.054985031209919655,
                                    0.4215599302747463,
                                ],
                                [
                                    0.0033308264399278514,
                                    0.025536822129146125,
                                    0.1120518460336514,
                                    0.8590805053972747,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.04770900156957222,
                                    0.36577597452592253,
                                    0.06767367090400704,
                                    0.5188413530004983,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.0019216140549867583,
                                    0.008903606052493124,
                                    0.17559108646359062,
                                    0.8135836934289296,
                                ],
                                [
                                    0.138470535005893,
                                    0.6415893401544284,
                                    0.03904216551268439,
                                    0.18089795932699423,
                                ],
                                [
                                    0.003399786179719206,
                                    0.01575256838300914,
                                    0.17411291433885817,
                                    0.8067347310984135,
                                ],
                                [
                                    0.014732654855510055,
                                    0.004419699707218292,
                                    0.7545020001973315,
                                    0.22634564523994022,
                                ],
                                [
                                    0.10843794828522726,
                                    0.5024363608117651,
                                    0.0690747522333501,
                                    0.32005093866965756,
                                ],
                                [
                                    0.4699056884388678,
                                    0.14096862065812457,
                                    0.29932896661397373,
                                    0.08979672428903394,
                                ],
                                [
                                    0.00048399041334211006,
                                    0.0017165649136811247,
                                    0.21945613442633652,
                                    0.7783433102466403,
                                ],
                                [
                                    0.21010670705465664,
                                    0.7451837712416985,
                                    0.009833417785021972,
                                    0.03487610391862289,
                                ],
                                [
                                    0.0027532024605122405,
                                    0.009764761064875125,
                                    0.21718692237916637,
                                    0.7702951140954463,
                                ],
                                [
                                    0.011930744892144352,
                                    0.0005872186332430146,
                                    0.9411591780771876,
                                    0.04632285839742506,
                                ],
                                [
                                    0.16400226058733336,
                                    0.5816655010677073,
                                    0.05593786425234527,
                                    0.19839437409261412,
                                ],
                                [
                                    0.7106884295165169,
                                    0.0349793321385238,
                                    0.24240149345281511,
                                    0.011930744892144277,
                                ],
                                [
                                    0.02130609729826128,
                                    0.8870743039674259,
                                    0.002148941217072757,
                                    0.08947065751724008,
                                ],
                                [
                                    0.022406374961772883,
                                    0.9328841033345823,
                                    0.001048663553561152,
                                    0.04366085815008366,
                                ],
                                [
                                    0.021548092504932333,
                                    0.8971497169591189,
                                    0.0019069460104017045,
                                    0.07939524452554705,
                                ],
                                [
                                    0.04309618500986467,
                                    0.8756016244541865,
                                    0.003813892020803409,
                                    0.07748829851514534,
                                ],
                                [
                                    0.02239446421388603,
                                    0.9323882021733534,
                                    0.0010605743014480088,
                                    0.04415675931131262,
                                ],
                                [
                                    0.04478892842777206,
                                    0.9099937379594674,
                                    0.0021211486028960176,
                                    0.043096185009864604,
                                ],
                                [
                                    0.08459278303166455,
                                    0.6485570150979889,
                                    0.030789889441914704,
                                    0.23606031242843187,
                                ],
                                [
                                    0.11121910524595506,
                                    0.8526960378308568,
                                    0.004163567227624185,
                                    0.03192128969556395,
                                ],
                                [
                                    0.0904489796634971,
                                    0.6934553772425058,
                                    0.024933692810082137,
                                    0.1911619502839149,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.1109308694473327,
                                    0.8504861879772477,
                                    0.004451803026246562,
                                    0.03413113954917309,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.11913624037116649,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.3925912788865005,
                                ],
                                [
                                    0.2441362403711665,
                                    0.7324087211134995,
                                    0.005863759628833502,
                                    0.017591278886500507,
                                ],
                                [
                                    0.14662875597612632,
                                    0.4398862679283789,
                                    0.10337124402387368,
                                    0.3101137320716211,
                                ],
                                [
                                    0.29325751195225264,
                                    0.29325751195225264,
                                    0.20674248804774736,
                                    0.20674248804774736,
                                ],
                                [
                                    0.2427830878577315,
                                    0.7283492635731945,
                                    0.007216912142268488,
                                    0.021650736426805463,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.08459278303166454,
                                    0.13534734180801408,
                                    0.3000245444947562,
                                    0.4800353306655652,
                                ],
                                [
                                    0.3804537602987966,
                                    0.6087210195937236,
                                    0.004163567227624186,
                                    0.006661652879855697,
                                ],
                                [
                                    0.1496644833069869,
                                    0.23946120759602085,
                                    0.23495284421943385,
                                    0.3759214648775584,
                                ],
                                [
                                    0.2993289666139738,
                                    0.08979672428903396,
                                    0.4699056884388677,
                                    0.14096862065812454,
                                ],
                                [
                                    0.37725100009866575,
                                    0.603596645338606,
                                    0.007366327427754991,
                                    0.011786027134973261,
                                ],
                                [
                                    0.7545020001973315,
                                    0.22634564523994025,
                                    0.014732654855509982,
                                    0.00441969970721827,
                                ],
                                [
                                    0.021306097298261266,
                                    0.023403424405383573,
                                    0.4552388641864047,
                                    0.5000516141099505,
                                ],
                                [
                                    0.4754962979311048,
                                    0.522303146741872,
                                    0.001048663553561152,
                                    0.0011518917734620576,
                                ],
                                [
                                    0.12120074672640758,
                                    0.13313149161855187,
                                    0.3553442147582584,
                                    0.39032354689678217,
                                ],
                                [
                                    0.24240149345281517,
                                    0.01193074489214428,
                                    0.7106884295165168,
                                    0.03497933213852379,
                                ],
                                [
                                    0.4705795890385938,
                                    0.5169024474360189,
                                    0.0059653724460721315,
                                    0.006552591079315142,
                                ],
                                [
                                    0.9411591780771876,
                                    0.04632285839742507,
                                    0.011930744892144263,
                                    0.0005872186332430102,
                                ],
                                [
                                    0.017196056752640396,
                                    0.7159537413770131,
                                    0.006258981762693642,
                                    0.26059122010765295,
                                ],
                                [
                                    0.018296334416152,
                                    0.7617635407441694,
                                    0.005158704099182037,
                                    0.21478142074049653,
                                ],
                                [
                                    0.01739137001201061,
                                    0.7240855625728911,
                                    0.006063668503323427,
                                    0.2524593989117748,
                                ],
                                [
                                    0.03478274002402122,
                                    0.7066941925608805,
                                    0.012127337006646853,
                                    0.24639573040845136,
                                ],
                                [
                                    0.018237741720964307,
                                    0.7593240477871257,
                                    0.00521729679436973,
                                    0.21722091369754035,
                                ],
                                [
                                    0.036475483441928615,
                                    0.7410863060661613,
                                    0.01043459358873946,
                                    0.2120036169031706,
                                ],
                                [
                                    0.06827446047545314,
                                    0.523447494058811,
                                    0.0471082119981261,
                                    0.3611698334676098,
                                ],
                                [
                                    0.09490078268974368,
                                    0.727586516791679,
                                    0.020481889783835576,
                                    0.15703081073474182,
                                ],
                                [
                                    0.07300097083658966,
                                    0.5596847632653457,
                                    0.0423817016369896,
                                    0.3249325642610751,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.09348286062042523,
                                    0.7167155740000875,
                                    0.02189981185315402,
                                    0.1679017535263333,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.09615433188160519,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.4615370043551844,
                                ],
                                [
                                    0.2211543318816052,
                                    0.6634629956448156,
                                    0.028845668118394806,
                                    0.08653700435518441,
                                ],
                                [
                                    0.11834341944642737,
                                    0.35503025833928215,
                                    0.13165658055357263,
                                    0.39496974166071785,
                                ],
                                [
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.26331316110714525,
                                    0.26331316110714525,
                                ],
                                [
                                    0.21449775132803256,
                                    0.6434932539840976,
                                    0.03550224867196743,
                                    0.10650674601590229,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.06827446047545316,
                                    0.10923824004312432,
                                    0.3163428670509676,
                                    0.5061444324304549,
                                ],
                                [
                                    0.36413543774258517,
                                    0.5826119178288338,
                                    0.02048188978383558,
                                    0.032770754644745465,
                                ],
                                [
                                    0.12079354152820722,
                                    0.19326807994127657,
                                    0.26382378599821354,
                                    0.42211459253230266,
                                ],
                                [
                                    0.24158708305641444,
                                    0.07247453841306935,
                                    0.5276475719964271,
                                    0.15829080653408914,
                                ],
                                [
                                    0.3483800583198861,
                                    0.5574035176838618,
                                    0.03623726920653466,
                                    0.05797915478971754,
                                ],
                                [
                                    0.6967601166397722,
                                    0.20902345936397562,
                                    0.07247453841306932,
                                    0.02174188558318288,
                                ],
                                [
                                    0.0171960567526404,
                                    0.018888800170547792,
                                    0.45934890473202555,
                                    0.5045662383447862,
                                ],
                                [
                                    0.47138625738548395,
                                    0.5177885225070362,
                                    0.005158704099182037,
                                    0.005666516008297856,
                                ],
                                [
                                    0.09782058581605099,
                                    0.10744983717046633,
                                    0.378724375668615,
                                    0.4160052013448677,
                                ],
                                [
                                    0.19564117163210198,
                                    0.009629251354415346,
                                    0.75744875133723,
                                    0.03728082567625273,
                                ],
                                [
                                    0.44719942812823726,
                                    0.49122079298793336,
                                    0.029345533356428737,
                                    0.03223424552740068,
                                ],
                                [
                                    0.8943988562564745,
                                    0.04402136485969613,
                                    0.058691066712857475,
                                    0.0028887121709719452,
                                ],
                                [
                                    0.011177380425911215,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.5111773804259112,
                                ],
                                [
                                    0.012277658089422822,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.46536758105875475,
                                ],
                                [
                                    0.01130433340319017,
                                    0.47065323813521576,
                                    0.012150705112143867,
                                    0.5058917233494502,
                                ],
                                [
                                    0.02260866680638034,
                                    0.45934890473202555,
                                    0.024301410224287733,
                                    0.4937410182373064,
                                ],
                                [
                                    0.012150705112143867,
                                    0.5058917233494502,
                                    0.01130433340319017,
                                    0.47065323813521576,
                                ],
                                [
                                    0.024301410224287733,
                                    0.4937410182373064,
                                    0.02260866680638034,
                                    0.45934890473202555,
                                ],
                                [
                                    0.04437817512964438,
                                    0.3402391523967765,
                                    0.07100449734393488,
                                    0.5443781751296443,
                                ],
                                [
                                    0.0710044973439349,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.3402391523967764,
                                ],
                                [
                                    0.047450391344871834,
                                    0.3637932583958394,
                                    0.06793228112870742,
                                    0.5208240691305813,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.06793228112870742,
                                    0.5208240691305813,
                                    0.04745039134487184,
                                    0.3637932583958395,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [0.0625, 0.1875, 0.1875, 0.5625],
                                [0.1875, 0.5625, 0.0625, 0.1875],
                                [
                                    0.07692283405919742,
                                    0.23076850217759226,
                                    0.17307716594080258,
                                    0.5192314978224077,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.17307716594080258,
                                    0.5192314978224077,
                                    0.0769228340591974,
                                    0.2307685021775922,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.044378175129644364,
                                    0.0710044973439349,
                                    0.3402391523967764,
                                    0.5443781751296444,
                                ],
                                [
                                    0.3402391523967764,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.0710044973439349,
                                ],
                                [
                                    0.07851540536737094,
                                    0.12562361736549704,
                                    0.3061019221590498,
                                    0.4897590551080822,
                                ],
                                [
                                    0.15703081073474187,
                                    0.047108211998126114,
                                    0.6122038443180996,
                                    0.18365713294903238,
                                ],
                                [
                                    0.3061019221590498,
                                    0.4897590551080822,
                                    0.07851540536737094,
                                    0.12562361736549704,
                                ],
                                [
                                    0.6122038443180996,
                                    0.18365713294903238,
                                    0.15703081073474187,
                                    0.047108211998126114,
                                ],
                                [
                                    0.011177380425911215,
                                    0.012277658089422822,
                                    0.46536758105875475,
                                    0.5111773804259112,
                                ],
                                [
                                    0.46536758105875475,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.012277658089422822,
                                ],
                                [
                                    0.06358305958623985,
                                    0.0698420413489335,
                                    0.41296190189842613,
                                    0.4536129971664005,
                                ],
                                [
                                    0.1271661191724797,
                                    0.006258981762693645,
                                    0.8259238037968523,
                                    0.04065109526797443,
                                ],
                                [
                                    0.41296190189842613,
                                    0.4536129971664005,
                                    0.06358305958623985,
                                    0.0698420413489335,
                                ],
                                [
                                    0.8259238037968523,
                                    0.04065109526797443,
                                    0.1271661191724797,
                                    0.006258981762693645,
                                ],
                                [
                                    0.0051587040991820385,
                                    0.21478142074049658,
                                    0.018296334416152,
                                    0.7617635407441694,
                                ],
                                [
                                    0.006258981762693645,
                                    0.26059122010765307,
                                    0.017196056752640392,
                                    0.715953741377013,
                                ],
                                [
                                    0.005217296794369735,
                                    0.2172209136975405,
                                    0.0182377417209643,
                                    0.7593240477871255,
                                ],
                                [
                                    0.01043459358873947,
                                    0.2120036169031708,
                                    0.0364754834419286,
                                    0.7410863060661611,
                                ],
                                [
                                    0.006063668503323429,
                                    0.25245939891177493,
                                    0.017391370012010608,
                                    0.724085562572891,
                                ],
                                [
                                    0.012127337006646859,
                                    0.24639573040845147,
                                    0.034782740024021215,
                                    0.7066941925608804,
                                ],
                                [
                                    0.020481889783835586,
                                    0.1570308107347419,
                                    0.09490078268974367,
                                    0.7275865167916789,
                                ],
                                [
                                    0.047108211998126114,
                                    0.3611698334676099,
                                    0.06827446047545314,
                                    0.5234474940588109,
                                ],
                                [
                                    0.021899811853154025,
                                    0.1679017535263333,
                                    0.09348286062042523,
                                    0.7167155740000875,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.0423817016369896,
                                    0.3249325642610751,
                                    0.07300097083658966,
                                    0.5596847632653457,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.028845668118394813,
                                    0.08653700435518444,
                                    0.2211543318816052,
                                    0.6634629956448156,
                                ],
                                [
                                    0.1538456681183948,
                                    0.4615370043551844,
                                    0.09615433188160519,
                                    0.2884629956448156,
                                ],
                                [
                                    0.03550224867196744,
                                    0.10650674601590232,
                                    0.21449775132803256,
                                    0.6434932539840976,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.13165658055357263,
                                    0.39496974166071785,
                                    0.11834341944642737,
                                    0.35503025833928215,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.020481889783835572,
                                    0.03277075464474545,
                                    0.36413543774258517,
                                    0.5826119178288338,
                                ],
                                [
                                    0.3163428670509676,
                                    0.5061444324304549,
                                    0.06827446047545314,
                                    0.10923824004312431,
                                ],
                                [
                                    0.03623726920653465,
                                    0.05797915478971753,
                                    0.3483800583198861,
                                    0.5574035176838618,
                                ],
                                [
                                    0.0724745384130693,
                                    0.021741885583182876,
                                    0.6967601166397722,
                                    0.20902345936397562,
                                ],
                                [
                                    0.26382378599821354,
                                    0.42211459253230266,
                                    0.1207935415282072,
                                    0.19326807994127654,
                                ],
                                [
                                    0.5276475719964271,
                                    0.15829080653408914,
                                    0.2415870830564144,
                                    0.07247453841306933,
                                ],
                                [
                                    0.0051587040991820324,
                                    0.00566651600829785,
                                    0.47138625738548395,
                                    0.5177885225070362,
                                ],
                                [
                                    0.45934890473202555,
                                    0.5045662383447862,
                                    0.017196056752640392,
                                    0.018888800170547785,
                                ],
                                [
                                    0.02934553335642877,
                                    0.032234245527400715,
                                    0.4471994281282372,
                                    0.4912207929879333,
                                ],
                                [
                                    0.05869106671285754,
                                    0.0028887121709719483,
                                    0.8943988562564744,
                                    0.04402136485969613,
                                ],
                                [
                                    0.37872437566861505,
                                    0.41600520134486774,
                                    0.09782058581605096,
                                    0.1074498371704663,
                                ],
                                [
                                    0.7574487513372301,
                                    0.03728082567625273,
                                    0.19564117163210193,
                                    0.009629251354415343,
                                ],
                                [
                                    0.0010486635535611527,
                                    0.043660858150083685,
                                    0.022406374961772883,
                                    0.9328841033345823,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.08947065751724015,
                                    0.021306097298261276,
                                    0.8870743039674258,
                                ],
                                [
                                    0.0010605743014480131,
                                    0.0441567593113128,
                                    0.022394464213886023,
                                    0.9323882021733532,
                                ],
                                [
                                    0.0021211486028960263,
                                    0.043096185009864785,
                                    0.044788928427772046,
                                    0.9099937379594671,
                                ],
                                [
                                    0.0019069460104017078,
                                    0.07939524452554718,
                                    0.02154809250493233,
                                    0.8971497169591188,
                                ],
                                [
                                    0.0038138920208034156,
                                    0.07748829851514548,
                                    0.04309618500986466,
                                    0.8756016244541864,
                                ],
                                [
                                    0.004163567227624192,
                                    0.031921289695564,
                                    0.11121910524595506,
                                    0.8526960378308568,
                                ],
                                [
                                    0.030789889441914717,
                                    0.23606031242843198,
                                    0.08459278303166454,
                                    0.6485570150979888,
                                ],
                                [
                                    0.00445180302624657,
                                    0.03413113954917315,
                                    0.11093086944733269,
                                    0.8504861879772476,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.024933692810082144,
                                    0.19116195028391494,
                                    0.0904489796634971,
                                    0.6934553772425058,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.005863759628833509,
                                    0.017591278886500528,
                                    0.2441362403711665,
                                    0.7324087211134995,
                                ],
                                [
                                    0.1308637596288335,
                                    0.3925912788865005,
                                    0.11913624037116649,
                                    0.3574087211134995,
                                ],
                                [
                                    0.0072169121422684945,
                                    0.021650736426805484,
                                    0.2427830878577315,
                                    0.7283492635731945,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.10337124402387368,
                                    0.3101137320716211,
                                    0.14662875597612632,
                                    0.4398862679283789,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.004163567227624186,
                                    0.006661652879855697,
                                    0.3804537602987966,
                                    0.6087210195937236,
                                ],
                                [
                                    0.3000245444947562,
                                    0.4800353306655652,
                                    0.08459278303166454,
                                    0.13534734180801408,
                                ],
                                [
                                    0.007366327427755027,
                                    0.01178602713497332,
                                    0.37725100009866575,
                                    0.6035966453386059,
                                ],
                                [
                                    0.014732654855510055,
                                    0.004419699707218292,
                                    0.7545020001973315,
                                    0.22634564523994022,
                                ],
                                [
                                    0.2349528442194339,
                                    0.37592146487755845,
                                    0.14966448330698687,
                                    0.23946120759602083,
                                ],
                                [
                                    0.4699056884388678,
                                    0.14096862065812457,
                                    0.29932896661397373,
                                    0.08979672428903394,
                                ],
                                [
                                    0.001048663553561164,
                                    0.0011518917734620708,
                                    0.4754962979311048,
                                    0.522303146741872,
                                ],
                                [
                                    0.4552388641864047,
                                    0.5000516141099505,
                                    0.021306097298261276,
                                    0.023403424405383583,
                                ],
                                [
                                    0.005965372446072176,
                                    0.00655259107931519,
                                    0.4705795890385938,
                                    0.5169024474360189,
                                ],
                                [
                                    0.011930744892144352,
                                    0.0005872186332430146,
                                    0.9411591780771876,
                                    0.04632285839742506,
                                ],
                                [
                                    0.35534421475825845,
                                    0.3903235468967822,
                                    0.12120074672640756,
                                    0.13313149161855184,
                                ],
                                [
                                    0.7106884295165169,
                                    0.0349793321385238,
                                    0.24240149345281511,
                                    0.011930744892144277,
                                ],
                                [
                                    0.0327787768115006,
                                    0.8756016244541865,
                                    0.003306080111687592,
                                    0.08831351862262524,
                                ],
                                [
                                    0.03447152022940799,
                                    0.9208189580669471,
                                    0.0016133366937802001,
                                    0.04309618500986461,
                                ],
                                [
                                    0.033151079010156695,
                                    0.8855467304538945,
                                    0.0029337779130314957,
                                    0.07836841262291726,
                                ],
                                [
                                    0.04309618500986467,
                                    0.8756016244541865,
                                    0.003813892020803409,
                                    0.07748829851514534,
                                ],
                                [
                                    0.03445319590932366,
                                    0.9203294704779158,
                                    0.0016316610138645353,
                                    0.04358567259889609,
                                ],
                                [
                                    0.04478892842777206,
                                    0.9099937379594674,
                                    0.0021211486028960176,
                                    0.043096185009864604,
                                ],
                                [
                                    0.13014340055064463,
                                    0.6030063975790088,
                                    0.047369299967932744,
                                    0.21948090190241384,
                                ],
                                [
                                    0.17110718011831574,
                                    0.7928079629584961,
                                    0.006405520400261609,
                                    0.029679336522926526,
                                ],
                                [
                                    0.1391529793426633,
                                    0.6447513775633397,
                                    0.03835972117591408,
                                    0.17773592191808296,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.17066373818806144,
                                    0.7907533192365189,
                                    0.006848962330515937,
                                    0.03173398024490372,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.18328744953241333,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.3221251605213266,
                                ],
                                [
                                    0.3755961132956237,
                                    0.6009488481890423,
                                    0.009021214230797034,
                                    0.014433824284536975,
                                ],
                                [
                                    0.2255838410482456,
                                    0.3609311828562597,
                                    0.15903348647817514,
                                    0.25445148961731956,
                                ],
                                [
                                    0.29325751195225264,
                                    0.29325751195225264,
                                    0.20674248804774736,
                                    0.20674248804774736,
                                ],
                                [
                                    0.3735143296818116,
                                    0.5976180217491144,
                                    0.011102997844609127,
                                    0.017764650724464825,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.13014340055064466,
                                    0.08979672428903396,
                                    0.46157855398361936,
                                    0.318481321176702,
                                ],
                                [
                                    0.5853164341340024,
                                    0.4038583457585177,
                                    0.006405520400261612,
                                    0.004419699707218271,
                                ],
                                [
                                    0.23025421438062363,
                                    0.15887147652238412,
                                    0.3614677401536404,
                                    0.24940656894335186,
                                ],
                                [
                                    0.2993289666139738,
                                    0.08979672428903396,
                                    0.4699056884388677,
                                    0.14096862065812454,
                                ],
                                [
                                    0.5803890858584733,
                                    0.40045855957879856,
                                    0.01133286867579079,
                                    0.007819485886937462,
                                ],
                                [
                                    0.7545020001973315,
                                    0.22634564523994025,
                                    0.014732654855509982,
                                    0.00441969970721827,
                                ],
                                [
                                    0.032778776811500564,
                                    0.011930744892144272,
                                    0.7003710213181528,
                                    0.2549194569782024,
                                ],
                                [
                                    0.7315364614358731,
                                    0.2662629832371037,
                                    0.0016133366937801992,
                                    0.0005872186332430102,
                                ],
                                [
                                    0.18646362920046988,
                                    0.06786860914448956,
                                    0.5466861689291834,
                                    0.19898159272585714,
                                ],
                                [
                                    0.24240149345281517,
                                    0.01193074489214428,
                                    0.7106884295165168,
                                    0.03497933213852379,
                                ],
                                [
                                    0.7239722556980213,
                                    0.2635097807765915,
                                    0.009177542431632043,
                                    0.0033404210937552307,
                                ],
                                [
                                    0.9411591780771876,
                                    0.04632285839742507,
                                    0.011930744892144263,
                                    0.0005872186332430102,
                                ],
                                [
                                    0.02645560556877285,
                                    0.7066941925608806,
                                    0.009629251354415343,
                                    0.25722095051593125,
                                ],
                                [
                                    0.028148348986680238,
                                    0.7519115261736411,
                                    0.00793650793650795,
                                    0.2120036169031706,
                                ],
                                [
                                    0.026756089024170638,
                                    0.7147208435607312,
                                    0.009328767899017555,
                                    0.2491942995160807,
                                ],
                                [
                                    0.03478274002402122,
                                    0.7066941925608805,
                                    0.012127337006646853,
                                    0.24639573040845136,
                                ],
                                [
                                    0.0280582059233376,
                                    0.7495035835847523,
                                    0.008026650999850593,
                                    0.21441155949205948,
                                ],
                                [
                                    0.036475483441928615,
                                    0.7410863060661613,
                                    0.01043459358873946,
                                    0.2120036169031706,
                                ],
                                [
                                    0.10503816210550808,
                                    0.48668379242875603,
                                    0.07247453841306929,
                                    0.3358035070526666,
                                ],
                                [
                                    0.14600194167317923,
                                    0.6764853578082434,
                                    0.03151075884539815,
                                    0.14600194167317926,
                                ],
                                [
                                    0.11230975324001312,
                                    0.5203759808619222,
                                    0.06520294727856425,
                                    0.30211131861950047,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.14382051208541125,
                                    0.6663779225351014,
                                    0.03369218843316611,
                                    0.15610937694632118,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.147930488633566,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.3786958335807245,
                                ],
                                [
                                    0.3402391523967764,
                                    0.5443781751296444,
                                    0.04437817512964435,
                                    0.07100449734393487,
                                ],
                                [
                                    0.18206771887129258,
                                    0.2913059589144169,
                                    0.20254960865512817,
                                    0.32407671355916234,
                                ],
                                [
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.26331316110714525,
                                    0.26331316110714525,
                                ],
                                [
                                    0.3299982075048586,
                                    0.5279927978072716,
                                    0.054619120021562134,
                                    0.0873898746663076,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.10503816210550813,
                                    0.07247453841306935,
                                    0.48668379242875587,
                                    0.33580350705266665,
                                ],
                                [
                                    0.5602111956888659,
                                    0.38653615988255313,
                                    0.03151075884539816,
                                    0.021741885583182883,
                                ],
                                [
                                    0.18583715650012314,
                                    0.12822446496936066,
                                    0.4058847980341409,
                                    0.2800535804963753,
                                ],
                                [
                                    0.24158708305641444,
                                    0.07247453841306935,
                                    0.5276475719964271,
                                    0.15829080653408914,
                                ],
                                [
                                    0.5359720279779727,
                                    0.3698115480257751,
                                    0.05574992655629128,
                                    0.03846649743996092,
                                ],
                                [
                                    0.6967601166397722,
                                    0.20902345936397562,
                                    0.07247453841306932,
                                    0.02174188558318288,
                                ],
                                [
                                    0.026455605568772845,
                                    0.009629251354415346,
                                    0.7066941925608805,
                                    0.25722095051593136,
                                ],
                                [
                                    0.7252132901931454,
                                    0.2639614896993748,
                                    0.007936507936507948,
                                    0.0028887121709719457,
                                ],
                                [
                                    0.1504939691745537,
                                    0.0547764538119636,
                                    0.5826558289550996,
                                    0.21207374805838308,
                                ],
                                [
                                    0.19564117163210198,
                                    0.009629251354415346,
                                    0.75744875133723,
                                    0.03728082567625273,
                                ],
                                [
                                    0.6880025956721051,
                                    0.25041762544406554,
                                    0.045147202457548226,
                                    0.016432576426281195,
                                ],
                                [
                                    0.8943988562564745,
                                    0.04402136485969613,
                                    0.058691066712857475,
                                    0.0028887121709719452,
                                ],
                                [
                                    0.0171960567526404,
                                    0.45934890473202555,
                                    0.018888800170547792,
                                    0.5045662383447862,
                                ],
                                [
                                    0.018888800170547792,
                                    0.5045662383447862,
                                    0.0171960567526404,
                                    0.45934890473202555,
                                ],
                                [
                                    0.017391370012010614,
                                    0.4645662015263953,
                                    0.018693486911177577,
                                    0.49934894155041654,
                                ],
                                [
                                    0.02260866680638034,
                                    0.45934890473202555,
                                    0.024301410224287733,
                                    0.4937410182373064,
                                ],
                                [
                                    0.018693486911177577,
                                    0.49934894155041654,
                                    0.017391370012010614,
                                    0.4645662015263953,
                                ],
                                [
                                    0.024301410224287733,
                                    0.4937410182373064,
                                    0.02260866680638034,
                                    0.45934890473202555,
                                ],
                                [
                                    0.06827446047545313,
                                    0.3163428670509677,
                                    0.10923824004312424,
                                    0.5061444324304549,
                                ],
                                [
                                    0.10923824004312425,
                                    0.506144432430455,
                                    0.06827446047545312,
                                    0.31634286705096765,
                                ],
                                [
                                    0.0730009708365896,
                                    0.33824267890412163,
                                    0.10451172968198777,
                                    0.484244620577301,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.10451172968198777,
                                    0.484244620577301,
                                    0.07300097083658962,
                                    0.3382426789041217,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.09615433188160519,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.4615370043551844,
                                ],
                                [
                                    0.2884629956448156,
                                    0.4615370043551844,
                                    0.09615433188160519,
                                    0.1538456681183948,
                                ],
                                [
                                    0.11834341944642739,
                                    0.18934791679036228,
                                    0.26627390807999335,
                                    0.42603475568321697,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.26627390807999335,
                                    0.42603475568321697,
                                    0.11834341944642737,
                                    0.18934791679036225,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.06827446047545314,
                                    0.047108211998126114,
                                    0.5234474940588109,
                                    0.3611698334676099,
                                ],
                                [
                                    0.5234474940588109,
                                    0.3611698334676099,
                                    0.06827446047545314,
                                    0.047108211998126114,
                                ],
                                [
                                    0.1207935415282072,
                                    0.08334548120466079,
                                    0.4709284130060568,
                                    0.3249325642610752,
                                ],
                                [
                                    0.15703081073474187,
                                    0.047108211998126114,
                                    0.6122038443180996,
                                    0.18365713294903238,
                                ],
                                [
                                    0.4709284130060568,
                                    0.3249325642610752,
                                    0.1207935415282072,
                                    0.08334548120466079,
                                ],
                                [
                                    0.6122038443180996,
                                    0.18365713294903238,
                                    0.15703081073474187,
                                    0.047108211998126114,
                                ],
                                [
                                    0.017196056752640392,
                                    0.006258981762693645,
                                    0.715953741377013,
                                    0.26059122010765307,
                                ],
                                [
                                    0.715953741377013,
                                    0.26059122010765307,
                                    0.017196056752640392,
                                    0.006258981762693645,
                                ],
                                [
                                    0.09782058581605095,
                                    0.03560451511912239,
                                    0.6353292123136024,
                                    0.2312456867512243,
                                ],
                                [
                                    0.1271661191724797,
                                    0.006258981762693645,
                                    0.8259238037968523,
                                    0.04065109526797443,
                                ],
                                [
                                    0.6353292123136024,
                                    0.2312456867512243,
                                    0.09782058581605095,
                                    0.03560451511912239,
                                ],
                                [
                                    0.8259238037968523,
                                    0.04065109526797443,
                                    0.1271661191724797,
                                    0.006258981762693645,
                                ],
                                [
                                    0.007936507936507952,
                                    0.21200361690317066,
                                    0.028148348986680238,
                                    0.7519115261736411,
                                ],
                                [
                                    0.009629251354415346,
                                    0.25722095051593136,
                                    0.026455605568772845,
                                    0.7066941925608805,
                                ],
                                [
                                    0.0080266509998506,
                                    0.21441155949205967,
                                    0.02805820592333759,
                                    0.7495035835847521,
                                ],
                                [
                                    0.01043459358873947,
                                    0.2120036169031708,
                                    0.0364754834419286,
                                    0.7410863060661611,
                                ],
                                [
                                    0.009328767899017558,
                                    0.24919429951608077,
                                    0.02675608902417063,
                                    0.7147208435607311,
                                ],
                                [
                                    0.012127337006646859,
                                    0.24639573040845147,
                                    0.034782740024021215,
                                    0.7066941925608804,
                                ],
                                [
                                    0.03151075884539816,
                                    0.14600194167317931,
                                    0.1460019416731792,
                                    0.6764853578082433,
                                ],
                                [
                                    0.0724745384130693,
                                    0.33580350705266665,
                                    0.10503816210550806,
                                    0.486683792428756,
                                ],
                                [
                                    0.03369218843316612,
                                    0.1561093769463212,
                                    0.14382051208541125,
                                    0.6663779225351014,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.06520294727856425,
                                    0.30211131861950047,
                                    0.11230975324001312,
                                    0.5203759808619222,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.044378175129644364,
                                    0.0710044973439349,
                                    0.3402391523967764,
                                    0.5443781751296444,
                                ],
                                [
                                    0.23668683889285475,
                                    0.3786958335807245,
                                    0.147930488633566,
                                    0.23668683889285475,
                                ],
                                [
                                    0.05461912002156215,
                                    0.08738987466630761,
                                    0.3299982075048586,
                                    0.5279927978072716,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.20254960865512817,
                                    0.32407671355916234,
                                    0.18206771887129258,
                                    0.2913059589144169,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.03151075884539815,
                                    0.021741885583182873,
                                    0.5602111956888659,
                                    0.38653615988255313,
                                ],
                                [
                                    0.48668379242875587,
                                    0.33580350705266665,
                                    0.1050381621055081,
                                    0.07247453841306935,
                                ],
                                [
                                    0.055749926556291275,
                                    0.03846649743996091,
                                    0.5359720279779727,
                                    0.3698115480257751,
                                ],
                                [
                                    0.0724745384130693,
                                    0.021741885583182876,
                                    0.6967601166397722,
                                    0.20902345936397562,
                                ],
                                [
                                    0.4058847980341409,
                                    0.2800535804963753,
                                    0.18583715650012309,
                                    0.12822446496936066,
                                ],
                                [
                                    0.5276475719964271,
                                    0.15829080653408914,
                                    0.2415870830564144,
                                    0.07247453841306933,
                                ],
                                [
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                    0.7252132901931454,
                                    0.2639614896993748,
                                ],
                                [
                                    0.7066941925608805,
                                    0.25722095051593136,
                                    0.026455605568772834,
                                    0.009629251354415343,
                                ],
                                [
                                    0.045147202457548274,
                                    0.01643257642628121,
                                    0.6880025956721051,
                                    0.2504176254440655,
                                ],
                                [
                                    0.05869106671285754,
                                    0.0028887121709719483,
                                    0.8943988562564744,
                                    0.04402136485969613,
                                ],
                                [
                                    0.5826558289550997,
                                    0.2120737480583831,
                                    0.15049396917455368,
                                    0.05477645381196359,
                                ],
                                [
                                    0.7574487513372301,
                                    0.03728082567625273,
                                    0.19564117163210193,
                                    0.009629251354415343,
                                ],
                                [
                                    0.0016133366937802012,
                                    0.04309618500986464,
                                    0.03447152022940799,
                                    0.9208189580669471,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.08831351862262532,
                                    0.0327787768115006,
                                    0.8756016244541865,
                                ],
                                [
                                    0.001631661013864542,
                                    0.04358567259889627,
                                    0.03445319590932365,
                                    0.9203294704779156,
                                ],
                                [
                                    0.0021211486028960263,
                                    0.043096185009864785,
                                    0.044788928427772046,
                                    0.9099937379594671,
                                ],
                                [
                                    0.002933777913031501,
                                    0.0783684126229174,
                                    0.03315107901015669,
                                    0.8855467304538944,
                                ],
                                [
                                    0.0038138920208034156,
                                    0.07748829851514548,
                                    0.04309618500986466,
                                    0.8756016244541864,
                                ],
                                [
                                    0.006405520400261619,
                                    0.02967933652292657,
                                    0.17110718011831574,
                                    0.7928079629584961,
                                ],
                                [
                                    0.047369299967932765,
                                    0.21948090190241393,
                                    0.1301434005506446,
                                    0.6030063975790088,
                                ],
                                [
                                    0.006848962330515949,
                                    0.03173398024490377,
                                    0.1706637381880614,
                                    0.7907533192365188,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.03835972117591409,
                                    0.17773592191808302,
                                    0.1391529793426633,
                                    0.6447513775633397,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.009021214230797044,
                                    0.014433824284536993,
                                    0.3755961132956237,
                                    0.6009488481890423,
                                ],
                                [
                                    0.20132987799400742,
                                    0.3221251605213266,
                                    0.18328744953241333,
                                    0.29325751195225264,
                                ],
                                [
                                    0.011102997844609138,
                                    0.017764650724464842,
                                    0.3735143296818116,
                                    0.5976180217491144,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.15903348647817514,
                                    0.25445148961731956,
                                    0.2255838410482456,
                                    0.3609311828562597,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.006405520400261612,
                                    0.004419699707218271,
                                    0.5853164341340024,
                                    0.4038583457585177,
                                ],
                                [
                                    0.46157855398361936,
                                    0.318481321176702,
                                    0.13014340055064466,
                                    0.08979672428903396,
                                ],
                                [
                                    0.011332868675790846,
                                    0.0078194858869375,
                                    0.5803890858584732,
                                    0.4004585595787985,
                                ],
                                [
                                    0.014732654855510055,
                                    0.004419699707218292,
                                    0.7545020001973315,
                                    0.22634564523994022,
                                ],
                                [
                                    0.36146774015364047,
                                    0.2494065689433519,
                                    0.2302542143806236,
                                    0.1588714765223841,
                                ],
                                [
                                    0.4699056884388678,
                                    0.14096862065812457,
                                    0.29932896661397373,
                                    0.08979672428903394,
                                ],
                                [
                                    0.0016133366937802177,
                                    0.000587218633243017,
                                    0.7315364614358731,
                                    0.2662629832371037,
                                ],
                                [
                                    0.7003710213181528,
                                    0.2549194569782024,
                                    0.032778776811500585,
                                    0.011930744892144277,
                                ],
                                [
                                    0.00917754243163211,
                                    0.0033404210937552554,
                                    0.7239722556980211,
                                    0.26350978077659143,
                                ],
                                [
                                    0.011930744892144352,
                                    0.0005872186332430146,
                                    0.9411591780771876,
                                    0.04632285839742506,
                                ],
                                [
                                    0.5466861689291835,
                                    0.19898159272585716,
                                    0.18646362920046985,
                                    0.06786860914448954,
                                ],
                                [
                                    0.7106884295165169,
                                    0.0349793321385238,
                                    0.24240149345281511,
                                    0.011930744892144277,
                                ],
                                [
                                    0.04061325326555385,
                                    0.8677671480001333,
                                    0.004096268438090991,
                                    0.08752333029622184,
                                ],
                                [
                                    0.04271058037267615,
                                    0.912579897923679,
                                    0.0019989413309686875,
                                    0.042710580372676124,
                                ],
                                [
                                    0.04107453965132397,
                                    0.8776232698127272,
                                    0.0036349820523208687,
                                    0.07766720848362789,
                                ],
                                [
                                    0.04309618500986467,
                                    0.8756016244541865,
                                    0.003813892020803409,
                                    0.07748829851514534,
                                ],
                                [
                                    0.04268787634510417,
                                    0.9120947900421352,
                                    0.0020216453585406705,
                                    0.043195688254219954,
                                ],
                                [
                                    0.04478892842777206,
                                    0.9099937379594674,
                                    0.0021211486028960176,
                                    0.043096185009864604,
                                ],
                                [
                                    0.16124905812682114,
                                    0.5719007400028323,
                                    0.05869106671285747,
                                    0.2081591351574891,
                                ],
                                [
                                    0.21200361690317066,
                                    0.7519115261736411,
                                    0.00793650793650794,
                                    0.028148348986680196,
                                ],
                                [
                                    0.17241202212027426,
                                    0.6114923347857286,
                                    0.047528102719404344,
                                    0.1685675403745927,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.21145418763295867,
                                    0.7499628697916217,
                                    0.00848593720671995,
                                    0.030097005368699702,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.22709510031642177,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.27400517734708985,
                                ],
                                [
                                    0.46536758105875475,
                                    0.5111773804259112,
                                    0.011177380425911203,
                                    0.012277658089422806,
                                ],
                                [
                                    0.2795007794767504,
                                    0.3070142444277549,
                                    0.19704418200791557,
                                    0.21644079408757916,
                                ],
                                [
                                    0.29325751195225264,
                                    0.29325751195225264,
                                    0.20674248804774736,
                                    0.20674248804774736,
                                ],
                                [
                                    0.4627882290091637,
                                    0.5083441224217623,
                                    0.013756732475502218,
                                    0.015110916093571732,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.16124905812682114,
                                    0.058691066712857495,
                                    0.5719007400028322,
                                    0.2081591351574892,
                                ],
                                [
                                    0.7252132901931454,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                ],
                                [
                                    0.285287421732602,
                                    0.10383826917040574,
                                    0.4478623763970513,
                                    0.16301193269994094,
                                ],
                                [
                                    0.2993289666139738,
                                    0.08979672428903396,
                                    0.4699056884388677,
                                    0.14096862065812454,
                                ],
                                [
                                    0.7191082532482815,
                                    0.2617393921889902,
                                    0.014041544881371763,
                                    0.0051108096813564895,
                                ],
                                [
                                    0.7545020001973315,
                                    0.22634564523994025,
                                    0.014732654855509982,
                                    0.00441969970721827,
                                ],
                                [
                                    0.040613253265553845,
                                    0.004096268438090994,
                                    0.8677671480001332,
                                    0.08752333029622192,
                                ],
                                [
                                    0.9063814599347184,
                                    0.09141798473825839,
                                    0.0019989413309686884,
                                    0.00020161399605452118,
                                ],
                                [
                                    0.2310304207225946,
                                    0.023301817622364815,
                                    0.6773499805430925,
                                    0.0683177811119481,
                                ],
                                [
                                    0.24240149345281517,
                                    0.01193074489214428,
                                    0.7106884295165168,
                                    0.03497933213852379,
                                ],
                                [
                                    0.8970093285354666,
                                    0.09047270793914616,
                                    0.011371072730220526,
                                    0.0011468907951667471,
                                ],
                                [
                                    0.9411591780771876,
                                    0.04632285839742507,
                                    0.011930744892144263,
                                    0.0005872186332430102,
                                ],
                                [
                                    0.03277877681150057,
                                    0.7003710213181529,
                                    0.011930744892144267,
                                    0.25491945697820234,
                                ],
                                [
                                    0.03487610391862287,
                                    0.7451837712416985,
                                    0.009833417785021965,
                                    0.2101067070546566,
                                ],
                                [
                                    0.03315107901015667,
                                    0.7083258535747451,
                                    0.011558442693488172,
                                    0.24696462472161004,
                                ],
                                [
                                    0.03478274002402122,
                                    0.7066941925608805,
                                    0.012127337006646853,
                                    0.24639573040845136,
                                ],
                                [
                                    0.03476441570393687,
                                    0.7427973738041531,
                                    0.009945105999707972,
                                    0.2124931044922021,
                                ],
                                [
                                    0.036475483441928615,
                                    0.7410863060661613,
                                    0.01043459358873946,
                                    0.2120036169031706,
                                ],
                                [
                                    0.1301434005506447,
                                    0.46157855398361947,
                                    0.08979672428903393,
                                    0.3184813211767019,
                                ],
                                [
                                    0.18089795932699423,
                                    0.6415893401544284,
                                    0.0390421655126844,
                                    0.13847053500589301,
                                ],
                                [
                                    0.13915297934266335,
                                    0.49353275475927194,
                                    0.08078714549701525,
                                    0.28652712040104944,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.17819514485534776,
                                    0.632003289765165,
                                    0.04174497998433086,
                                    0.14805658539515645,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.18328744953241333,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.3221251605213266,
                                ],
                                [
                                    0.4215599302747463,
                                    0.46305739725167444,
                                    0.05498503120991964,
                                    0.06039764126365958,
                                ],
                                [
                                    0.2255838410482456,
                                    0.24778983673746388,
                                    0.2509611204364204,
                                    0.27566520177787013,
                                ],
                                [
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.26331316110714525,
                                    0.26331316110714525,
                                ],
                                [
                                    0.4088712905806589,
                                    0.44911971473147133,
                                    0.06767367090400701,
                                    0.07433532378386272,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.1301434005506447,
                                    0.0473692999679328,
                                    0.6030063975790086,
                                    0.2194809019024139,
                                ],
                                [
                                    0.694107632616969,
                                    0.25263972295445003,
                                    0.0390421655126844,
                                    0.014210478915896644,
                                ],
                                [
                                    0.23025421438062363,
                                    0.08380740708886016,
                                    0.5028955837490297,
                                    0.18304279478148652,
                                ],
                                [
                                    0.24158708305641444,
                                    0.07247453841306935,
                                    0.5276475719964271,
                                    0.15829080653408914,
                                ],
                                [
                                    0.6640750458963032,
                                    0.2417085301074446,
                                    0.06907475223335012,
                                    0.025141671762902076,
                                ],
                                [
                                    0.6967601166397722,
                                    0.20902345936397562,
                                    0.07247453841306932,
                                    0.02174188558318288,
                                ],
                                [
                                    0.0327787768115006,
                                    0.0033060801116875952,
                                    0.8756016244541865,
                                    0.08831351862262532,
                                ],
                                [
                                    0.8985469834806651,
                                    0.09062779641185499,
                                    0.00983341778502197,
                                    0.0009918023224579236,
                                ],
                                [
                                    0.1864636292004699,
                                    0.0188067937860474,
                                    0.7219167720652172,
                                    0.07281280494826552,
                                ],
                                [
                                    0.19564117163210198,
                                    0.009629251354415346,
                                    0.75744875133723,
                                    0.03728082567625273,
                                ],
                                [
                                    0.8524425370133418,
                                    0.08597768410282874,
                                    0.05593786425234525,
                                    0.005641914631484167,
                                ],
                                [
                                    0.8943988562564745,
                                    0.04402136485969613,
                                    0.058691066712857475,
                                    0.0028887121709719452,
                                ],
                                [
                                    0.021306097298261266,
                                    0.4552388641864047,
                                    0.023403424405383573,
                                    0.5000516141099505,
                                ],
                                [
                                    0.023403424405383573,
                                    0.5000516141099505,
                                    0.021306097298261266,
                                    0.4552388641864047,
                                ],
                                [
                                    0.02154809250493232,
                                    0.46040947903347357,
                                    0.02316142919871252,
                                    0.4948809992628816,
                                ],
                                [
                                    0.02260866680638034,
                                    0.45934890473202555,
                                    0.024301410224287733,
                                    0.4937410182373064,
                                ],
                                [
                                    0.02316142919871252,
                                    0.4948809992628816,
                                    0.02154809250493232,
                                    0.46040947903347357,
                                ],
                                [
                                    0.024301410224287733,
                                    0.4937410182373064,
                                    0.02260866680638034,
                                    0.45934890473202555,
                                ],
                                [
                                    0.08459278303166456,
                                    0.3000245444947563,
                                    0.13534734180801405,
                                    0.4800353306655651,
                                ],
                                [
                                    0.13534734180801408,
                                    0.4800353306655652,
                                    0.08459278303166454,
                                    0.3000245444947562,
                                ],
                                [
                                    0.0904489796634971,
                                    0.3207946700772142,
                                    0.12949114517618152,
                                    0.4592652050831072,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.12949114517618152,
                                    0.4592652050831072,
                                    0.09044897966349712,
                                    0.3207946700772142,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.11913624037116649,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.3925912788865005,
                                ],
                                [
                                    0.3574087211134995,
                                    0.3925912788865005,
                                    0.11913624037116649,
                                    0.1308637596288335,
                                ],
                                [
                                    0.14662875597612635,
                                    0.16106258026066333,
                                    0.3299162055085396,
                                    0.3623924582546707,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.3299162055085396,
                                    0.3623924582546707,
                                    0.14662875597612632,
                                    0.1610625802606633,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.08459278303166454,
                                    0.030789889441914717,
                                    0.6485570150979888,
                                    0.23606031242843198,
                                ],
                                [
                                    0.6485570150979888,
                                    0.23606031242843198,
                                    0.08459278303166454,
                                    0.030789889441914717,
                                ],
                                [
                                    0.14966448330698687,
                                    0.05447453942588112,
                                    0.5834853148226664,
                                    0.21237566244446557,
                                ],
                                [
                                    0.15703081073474187,
                                    0.047108211998126114,
                                    0.6122038443180996,
                                    0.18365713294903238,
                                ],
                                [
                                    0.5834853148226664,
                                    0.21237566244446557,
                                    0.14966448330698687,
                                    0.05447453942588112,
                                ],
                                [
                                    0.6122038443180996,
                                    0.18365713294903238,
                                    0.15703081073474187,
                                    0.047108211998126114,
                                ],
                                [
                                    0.021306097298261276,
                                    0.0021489412170727588,
                                    0.8870743039674258,
                                    0.08947065751724015,
                                ],
                                [
                                    0.8870743039674258,
                                    0.08947065751724015,
                                    0.021306097298261276,
                                    0.0021489412170727588,
                                ],
                                [
                                    0.12120074672640757,
                                    0.01222435420876578,
                                    0.7871796545392795,
                                    0.07939524452554714,
                                ],
                                [
                                    0.1271661191724797,
                                    0.006258981762693645,
                                    0.8259238037968523,
                                    0.04065109526797443,
                                ],
                                [
                                    0.7871796545392795,
                                    0.07939524452554714,
                                    0.12120074672640757,
                                    0.01222435420876578,
                                ],
                                [
                                    0.8259238037968523,
                                    0.04065109526797443,
                                    0.1271661191724797,
                                    0.006258981762693645,
                                ],
                                [
                                    0.009833417785021966,
                                    0.21010670705465664,
                                    0.03487610391862287,
                                    0.7451837712416985,
                                ],
                                [
                                    0.011930744892144272,
                                    0.2549194569782024,
                                    0.032778776811500564,
                                    0.7003710213181528,
                                ],
                                [
                                    0.00994510599970798,
                                    0.21249310449220227,
                                    0.03476441570393686,
                                    0.7427973738041529,
                                ],
                                [
                                    0.01043459358873947,
                                    0.2120036169031708,
                                    0.0364754834419286,
                                    0.7410863060661611,
                                ],
                                [
                                    0.011558442693488177,
                                    0.24696462472161015,
                                    0.03315107901015666,
                                    0.708325853574745,
                                ],
                                [
                                    0.012127337006646859,
                                    0.24639573040845147,
                                    0.034782740024021215,
                                    0.7066941925608804,
                                ],
                                [
                                    0.03904216551268441,
                                    0.13847053500589307,
                                    0.1808979593269942,
                                    0.6415893401544284,
                                ],
                                [
                                    0.08979672428903396,
                                    0.318481321176702,
                                    0.13014340055064466,
                                    0.46157855398361936,
                                ],
                                [
                                    0.04174497998433087,
                                    0.14805658539515648,
                                    0.17819514485534776,
                                    0.632003289765165,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.08078714549701525,
                                    0.28652712040104944,
                                    0.13915297934266335,
                                    0.49353275475927194,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.054985031209919655,
                                    0.060397641263659596,
                                    0.4215599302747463,
                                    0.46305739725167444,
                                ],
                                [
                                    0.29325751195225264,
                                    0.3221251605213266,
                                    0.18328744953241333,
                                    0.20132987799400742,
                                ],
                                [
                                    0.06767367090400703,
                                    0.07433532378386273,
                                    0.4088712905806589,
                                    0.44911971473147133,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.2509611204364204,
                                    0.27566520177787013,
                                    0.2255838410482456,
                                    0.24778983673746388,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.039042165512684385,
                                    0.014210478915896638,
                                    0.694107632616969,
                                    0.25263972295445003,
                                ],
                                [
                                    0.6030063975790086,
                                    0.2194809019024139,
                                    0.13014340055064466,
                                    0.04736929996793279,
                                ],
                                [
                                    0.06907475223335012,
                                    0.025141671762902072,
                                    0.6640750458963032,
                                    0.2417085301074446,
                                ],
                                [
                                    0.0724745384130693,
                                    0.021741885583182876,
                                    0.6967601166397722,
                                    0.20902345936397562,
                                ],
                                [
                                    0.5028955837490297,
                                    0.18304279478148652,
                                    0.2302542143806236,
                                    0.08380740708886014,
                                ],
                                [
                                    0.5276475719964271,
                                    0.15829080653408914,
                                    0.2415870830564144,
                                    0.07247453841306933,
                                ],
                                [
                                    0.00983341778502196,
                                    0.0009918023224579225,
                                    0.8985469834806651,
                                    0.09062779641185499,
                                ],
                                [
                                    0.8756016244541865,
                                    0.08831351862262532,
                                    0.032778776811500585,
                                    0.003306080111687594,
                                ],
                                [
                                    0.05593786425234531,
                                    0.005641914631484173,
                                    0.8524425370133418,
                                    0.08597768410282874,
                                ],
                                [
                                    0.05869106671285754,
                                    0.0028887121709719483,
                                    0.8943988562564744,
                                    0.04402136485969613,
                                ],
                                [
                                    0.7219167720652173,
                                    0.07281280494826553,
                                    0.18646362920046988,
                                    0.018806793786047393,
                                ],
                                [
                                    0.7574487513372301,
                                    0.03728082567625273,
                                    0.19564117163210193,
                                    0.009629251354415343,
                                ],
                                [
                                    0.001998941330968689,
                                    0.04271058037267615,
                                    0.04271058037267615,
                                    0.912579897923679,
                                ],
                                [
                                    0.004096268438090994,
                                    0.08752333029622192,
                                    0.040613253265553845,
                                    0.8677671480001332,
                                ],
                                [
                                    0.0020216453585406788,
                                    0.043195688254220134,
                                    0.04268787634510416,
                                    0.912094790042135,
                                ],
                                [
                                    0.0021211486028960263,
                                    0.043096185009864785,
                                    0.044788928427772046,
                                    0.9099937379594671,
                                ],
                                [
                                    0.003634982052320875,
                                    0.07766720848362801,
                                    0.04107453965132397,
                                    0.8776232698127271,
                                ],
                                [
                                    0.0038138920208034156,
                                    0.07748829851514548,
                                    0.04309618500986466,
                                    0.8756016244541864,
                                ],
                                [
                                    0.007936507936507952,
                                    0.028148348986680238,
                                    0.21200361690317066,
                                    0.7519115261736411,
                                ],
                                [
                                    0.058691066712857495,
                                    0.2081591351574892,
                                    0.16124905812682114,
                                    0.5719007400028322,
                                ],
                                [
                                    0.008485937206719965,
                                    0.030097005368699758,
                                    0.21145418763295865,
                                    0.7499628697916216,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.04752810271940436,
                                    0.16856754037459273,
                                    0.17241202212027426,
                                    0.6114923347857286,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.011177380425911215,
                                    0.012277658089422822,
                                    0.46536758105875475,
                                    0.5111773804259112,
                                ],
                                [
                                    0.2494498611682442,
                                    0.27400517734708985,
                                    0.22709510031642177,
                                    0.2494498611682442,
                                ],
                                [
                                    0.013756732475502232,
                                    0.015110916093571746,
                                    0.4627882290091637,
                                    0.5083441224217623,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.19704418200791557,
                                    0.21644079408757916,
                                    0.2795007794767504,
                                    0.3070142444277549,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                    0.7252132901931454,
                                    0.2639614896993748,
                                ],
                                [
                                    0.5719007400028322,
                                    0.2081591351574892,
                                    0.16124905812682114,
                                    0.058691066712857495,
                                ],
                                [
                                    0.014041544881371831,
                                    0.005110809681356515,
                                    0.7191082532482814,
                                    0.26173939218899017,
                                ],
                                [
                                    0.014732654855510055,
                                    0.004419699707218292,
                                    0.7545020001973315,
                                    0.22634564523994022,
                                ],
                                [
                                    0.4478623763970514,
                                    0.16301193269994096,
                                    0.28528742173260196,
                                    0.10383826917040573,
                                ],
                                [
                                    0.4699056884388678,
                                    0.14096862065812457,
                                    0.29932896661397373,
                                    0.08979672428903394,
                                ],
                                [
                                    0.0019989413309687114,
                                    0.00020161399605452348,
                                    0.9063814599347184,
                                    0.09141798473825839,
                                ],
                                [
                                    0.8677671480001332,
                                    0.08752333029622192,
                                    0.040613253265553866,
                                    0.004096268438090996,
                                ],
                                [
                                    0.01137107273022061,
                                    0.0011468907951667554,
                                    0.8970093285354664,
                                    0.09047270793914616,
                                ],
                                [
                                    0.011930744892144352,
                                    0.0005872186332430146,
                                    0.9411591780771876,
                                    0.04632285839742506,
                                ],
                                [
                                    0.6773499805430926,
                                    0.06831778111194811,
                                    0.23103042072259458,
                                    0.02330181762236481,
                                ],
                                [
                                    0.7106884295165169,
                                    0.0349793321385238,
                                    0.24240149345281511,
                                    0.011930744892144277,
                                ],
                                [
                                    0.0019989413309687114,
                                    0.9063814599347185,
                                    0.00020161399605452332,
                                    0.09141798473825831,
                                ],
                                [
                                    0.0021021695508696182,
                                    0.9531883087454855,
                                    9.838577615361652e-05,
                                    0.04461113592749119,
                                ],
                                [
                                    0.0020035566153067995,
                                    0.9084741717575027,
                                    0.00019699871171643512,
                                    0.0893252729154741,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991899,
                                    0.08532277496919864,
                                ],
                                [
                                    0.0021019423914604165,
                                    0.9530853076849939,
                                    9.861293556281859e-05,
                                    0.0447141369879829,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.007936507936507941,
                                    0.7252132901931455,
                                    0.0028887121709719418,
                                    0.26396148969937466,
                                ],
                                [
                                    0.010434593588739452,
                                    0.9534805494880724,
                                    0.00039062651874043086,
                                    0.035694230404447705,
                                ],
                                [
                                    0.008048196151193949,
                                    0.7354190101768235,
                                    0.002777023956285933,
                                    0.2537557697156966,
                                ],
                                [
                                    0.1715664663251852,
                                    0.5719007400028322,
                                    0.05919887862197328,
                                    0.19733391505000922,
                                ],
                                [
                                    0.010429096413050074,
                                    0.9529782347546459,
                                    0.0003961236944298092,
                                    0.036196545137874146,
                                ],
                                [
                                    0.22232102510153476,
                                    0.7410863060661613,
                                    0.008444319845623759,
                                    0.0281483489866802,
                                ],
                                [
                                    0.011177380425911215,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.5111773804259112,
                                ],
                                [
                                    0.022904899683578235,
                                    0.9536400618010877,
                                    0.0005501388317558024,
                                    0.022904899683578207,
                                ],
                                [
                                    0.011701712202691792,
                                    0.4871980101337966,
                                    0.011753326312642245,
                                    0.48934695135086936,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.022879092628603007,
                                    0.9525655911925514,
                                    0.0005759458867310289,
                                    0.023979370292114582,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    0.007936507936507952,
                                    0.21200361690317066,
                                    0.028148348986680238,
                                    0.7519115261736411,
                                ],
                                [
                                    0.03569423040444776,
                                    0.9534805494880724,
                                    0.00039062651874043145,
                                    0.010434593588739452,
                                ],
                                [
                                    0.009177542431632059,
                                    0.2451546959133274,
                                    0.02690731449155613,
                                    0.7187604471634844,
                                ],
                                [
                                    0.19564117163210193,
                                    0.058691066712857495,
                                    0.5735934834207396,
                                    0.172074278234301,
                                ],
                                [
                                    0.0356331480004049,
                                    0.9518488884742078,
                                    0.0004517089227832882,
                                    0.012066254602603986,
                                ],
                                [
                                    0.7596054036984262,
                                    0.22787663277618656,
                                    0.00962925135441533,
                                    0.0028887121709719426,
                                ],
                                [
                                    0.001998941330968689,
                                    0.04271058037267615,
                                    0.04271058037267615,
                                    0.912579897923679,
                                ],
                                [
                                    0.04461113592749122,
                                    0.9531883087454855,
                                    9.838577615361546e-05,
                                    0.002102169550869594,
                                ],
                                [
                                    0.003904112170121851,
                                    0.08341760413004554,
                                    0.04080540953352299,
                                    0.8718728741663097,
                                ],
                                [
                                    0.08322544786207639,
                                    0.004096268438090996,
                                    0.8698644751072555,
                                    0.04281380859257708,
                                ],
                                [
                                    0.04451736543567569,
                                    0.9511847521301787,
                                    0.00019215626796914272,
                                    0.00410572616617637,
                                ],
                                [
                                    0.948993654531241,
                                    0.046708463034613554,
                                    0.0040962684380909916,
                                    0.00020161399605452123,
                                ],
                                [
                                    0.001613336693780218,
                                    0.7315364614358733,
                                    0.0005872186332430168,
                                    0.26626298323710357,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.7783433102466403,
                                    0.00048399041334210995,
                                    0.21945613442633646,
                                ],
                                [
                                    0.0016170616693257777,
                                    0.733225479878235,
                                    0.0005834936576974572,
                                    0.26457396479474177,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.0017154474454793942,
                                    0.7778366158057263,
                                    0.00048510788154384056,
                                    0.21996282886725052,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.0064055204002616125,
                                    0.5853164341340025,
                                    0.00441969970721827,
                                    0.4038583457585176,
                                ],
                                [
                                    0.008903606052493124,
                                    0.8135836934289296,
                                    0.0019216140549867587,
                                    0.17559108646359065,
                                ],
                                [
                                    0.006495663463604256,
                                    0.5935534255259082,
                                    0.0043295566438756265,
                                    0.3956213543666119,
                                ],
                                [
                                    0.13847053500589307,
                                    0.4615785539836194,
                                    0.09229480994126545,
                                    0.3076561010692221,
                                ],
                                [
                                    0.00887656372546038,
                                    0.8111126501037307,
                                    0.0019486563820195024,
                                    0.17806212978878944,
                                ],
                                [
                                    0.1892250937822426,
                                    0.6307641200469485,
                                    0.041540251164915915,
                                    0.13847053500589301,
                                ],
                                [
                                    0.009021214230797044,
                                    0.3755961132956237,
                                    0.014433824284536993,
                                    0.6009488481890423,
                                ],
                                [
                                    0.020748733488464063,
                                    0.8638685940379567,
                                    0.0027063050268699733,
                                    0.11267636744670925,
                                ],
                                [
                                    0.009444400085273892,
                                    0.3932153559027409,
                                    0.014010638430060144,
                                    0.583329605581925,
                                ],
                                [
                                    0.20132987799400742,
                                    0.20132987799400742,
                                    0.2986701220059926,
                                    0.2986701220059926,
                                ],
                                [
                                    0.020621780511185107,
                                    0.8585829369614957,
                                    0.0028332580041489277,
                                    0.11796202452317024,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.006405520400261623,
                                    0.17110718011831585,
                                    0.029679336522926567,
                                    0.792807962958496,
                                ],
                                [
                                    0.03416324286820143,
                                    0.9125841127032176,
                                    0.0019216140549867615,
                                    0.05133103037359428,
                                ],
                                [
                                    0.007407153844030798,
                                    0.19786326914248653,
                                    0.028677703079157395,
                                    0.7660518739343253,
                                ],
                                [
                                    0.15790112301858453,
                                    0.0473692999679328,
                                    0.611333532034257,
                                    0.1833960449792257,
                                ],
                                [
                                    0.033862759412803645,
                                    0.904557461703367,
                                    0.00222209751038455,
                                    0.05935768137344487,
                                ],
                                [
                                    0.7218653550849088,
                                    0.21655486603126187,
                                    0.04736929996793278,
                                    0.014210478915896644,
                                ],
                                [
                                    0.0016133366937802012,
                                    0.03447152022940799,
                                    0.04309618500986464,
                                    0.9208189580669471,
                                ],
                                [
                                    0.04422553129030273,
                                    0.9449492486022174,
                                    0.0004839904133421048,
                                    0.010341229694137788,
                                ],
                                [
                                    0.003150991638978766,
                                    0.06732597878949013,
                                    0.041558530064666074,
                                    0.8879644995068651,
                                ],
                                [
                                    0.0671708903167813,
                                    0.0033060801116875918,
                                    0.8859190326525506,
                                    0.04360399691898048,
                                ],
                                [
                                    0.04376424490453261,
                                    0.9350931267896234,
                                    0.0009452767991122263,
                                    0.020197351506731735,
                                ],
                                [
                                    0.9329390969859458,
                                    0.045918274708210145,
                                    0.020150825983386036,
                                    0.0009918023224579234,
                                ],
                                [
                                    0.001048663553561164,
                                    0.4754962979311048,
                                    0.0011518917734620708,
                                    0.522303146741872,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.522303146741872,
                                    0.001048663553561164,
                                    0.4754962979311048,
                                ],
                                [
                                    0.0010510847754348091,
                                    0.4765941543727428,
                                    0.0011494705515884256,
                                    0.521205290300234,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.0011494705515884256,
                                    0.521205290300234,
                                    0.0010510847754348091,
                                    0.4765941543727428,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.004163567227624187,
                                    0.3804537602987967,
                                    0.006661652879855696,
                                    0.6087210195937235,
                                ],
                                [
                                    0.006661652879855697,
                                    0.6087210195937236,
                                    0.004163567227624186,
                                    0.3804537602987966,
                                ],
                                [
                                    0.00422215992281188,
                                    0.3858077776573489,
                                    0.006603060184668002,
                                    0.6033670022351711,
                                ],
                                [
                                    0.0900053930854045,
                                    0.3000245444947563,
                                    0.140759951861754,
                                    0.4692101105580852,
                                ],
                                [
                                    0.006603060184668004,
                                    0.6033670022351713,
                                    0.004222159922811879,
                                    0.3858077776573488,
                                ],
                                [
                                    0.14075995186175402,
                                    0.4692101105580853,
                                    0.09000539308540448,
                                    0.3000245444947562,
                                ],
                                [
                                    0.005863759628833509,
                                    0.2441362403711665,
                                    0.017591278886500528,
                                    0.7324087211134995,
                                ],
                                [
                                    0.017591278886500528,
                                    0.7324087211134995,
                                    0.005863759628833509,
                                    0.2441362403711665,
                                ],
                                [
                                    0.006138829044711411,
                                    0.2555886902129556,
                                    0.017316209470622627,
                                    0.7209562712717104,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.017316209470622627,
                                    0.7209562712717104,
                                    0.006138829044711411,
                                    0.2555886902129556,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.004163567227624192,
                                    0.11121910524595506,
                                    0.031921289695564,
                                    0.8526960378308568,
                                ],
                                [
                                    0.031921289695564,
                                    0.8526960378308568,
                                    0.004163567227624192,
                                    0.11121910524595506,
                                ],
                                [
                                    0.004814625677207673,
                                    0.12861047525796568,
                                    0.031270231245980516,
                                    0.8353046678188462,
                                ],
                                [
                                    0.10263521149325863,
                                    0.030789889441914717,
                                    0.6665994435595829,
                                    0.1999754555052438,
                                ],
                                [
                                    0.031270231245980516,
                                    0.8353046678188462,
                                    0.004814625677207673,
                                    0.12861047525796568,
                                ],
                                [
                                    0.6665994435595829,
                                    0.1999754555052438,
                                    0.10263521149325863,
                                    0.030789889441914717,
                                ],
                                [
                                    0.0010486635535611527,
                                    0.022406374961772883,
                                    0.043660858150083685,
                                    0.9328841033345823,
                                ],
                                [
                                    0.043660858150083685,
                                    0.9328841033345823,
                                    0.0010486635535611527,
                                    0.022406374961772883,
                                ],
                                [
                                    0.002048134219045497,
                                    0.04376166514811096,
                                    0.04266138748459934,
                                    0.9115288131482442,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727588,
                                    0.9094290648192482,
                                    0.04476113581359532,
                                ],
                                [
                                    0.04266138748459934,
                                    0.9115288131482442,
                                    0.002048134219045497,
                                    0.04376166514811096,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359532,
                                    0.0436608581500837,
                                    0.0021489412170727588,
                                ],
                                [
                                    0.00048399041334211006,
                                    0.21945613442633652,
                                    0.0017165649136811247,
                                    0.7783433102466403,
                                ],
                                [
                                    0.000587218633243017,
                                    0.2662629832371037,
                                    0.0016133366937802177,
                                    0.7315364614358731,
                                ],
                                [
                                    0.00048510788154384083,
                                    0.21996282886725063,
                                    0.001715447445479394,
                                    0.7778366158057262,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.0005834936576974574,
                                    0.2645739647947419,
                                    0.0016170616693257775,
                                    0.7332254798782349,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.0019216140549867596,
                                    0.17559108646359073,
                                    0.008903606052493122,
                                    0.8135836934289294,
                                ],
                                [
                                    0.004419699707218271,
                                    0.4038583457585177,
                                    0.006405520400261612,
                                    0.5853164341340024,
                                ],
                                [
                                    0.0019486563820195046,
                                    0.17806212978878963,
                                    0.008876563725460378,
                                    0.8111126501037305,
                                ],
                                [
                                    0.041540251164915956,
                                    0.13847053500589315,
                                    0.18922509378224253,
                                    0.6307641200469484,
                                ],
                                [
                                    0.004329556643875628,
                                    0.395621354366612,
                                    0.006495663463604254,
                                    0.5935534255259081,
                                ],
                                [
                                    0.09229480994126547,
                                    0.30765610106922214,
                                    0.13847053500589304,
                                    0.46157855398361936,
                                ],
                                [
                                    0.0027063050268699737,
                                    0.11267636744670928,
                                    0.020748733488464063,
                                    0.8638685940379567,
                                ],
                                [
                                    0.014433824284536993,
                                    0.6009488481890423,
                                    0.009021214230797044,
                                    0.3755961132956237,
                                ],
                                [
                                    0.002833258004148928,
                                    0.11796202452317027,
                                    0.020621780511185107,
                                    0.8585829369614957,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.014010638430060144,
                                    0.583329605581925,
                                    0.009444400085273892,
                                    0.3932153559027409,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.001921614054986761,
                                    0.05133103037359426,
                                    0.03416324286820143,
                                    0.9125841127032176,
                                ],
                                [
                                    0.029679336522926567,
                                    0.792807962958496,
                                    0.006405520400261622,
                                    0.17110718011831583,
                                ],
                                [
                                    0.0022220975103845525,
                                    0.05935768137344493,
                                    0.03386275941280364,
                                    0.9045574617033669,
                                ],
                                [
                                    0.04736929996793283,
                                    0.014210478915896657,
                                    0.7218653550849087,
                                    0.21655486603126184,
                                ],
                                [
                                    0.028677703079157398,
                                    0.7660518739343254,
                                    0.007407153844030796,
                                    0.19786326914248648,
                                ],
                                [
                                    0.6113335320342571,
                                    0.18339604497922574,
                                    0.15790112301858447,
                                    0.04736929996793279,
                                ],
                                [
                                    0.0004839904133421043,
                                    0.010341229694137779,
                                    0.04422553129030273,
                                    0.9449492486022174,
                                ],
                                [
                                    0.04309618500986464,
                                    0.9208189580669471,
                                    0.0016133366937802005,
                                    0.03447152022940798,
                                ],
                                [
                                    0.0009452767991122286,
                                    0.020197351506731784,
                                    0.04376424490453261,
                                    0.9350931267896234,
                                ],
                                [
                                    0.02015082598338609,
                                    0.000991802322457926,
                                    0.9329390969859458,
                                    0.045918274708210145,
                                ],
                                [
                                    0.041558530064666074,
                                    0.8879644995068651,
                                    0.0031509916389787676,
                                    0.06732597878949018,
                                ],
                                [
                                    0.8859190326525506,
                                    0.04360399691898048,
                                    0.06717089031678135,
                                    0.003306080111687594,
                                ],
                                [
                                    9.838577615361658e-05,
                                    0.04461113592749122,
                                    0.0021021695508696182,
                                    0.9531883087454855,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.09141798473825839,
                                    0.0019989413309687114,
                                    0.9063814599347184,
                                ],
                                [
                                    9.861293556281873e-05,
                                    0.04471413698798296,
                                    0.002101942391460416,
                                    0.9530853076849938,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.0001969987117164353,
                                    0.08932527291547418,
                                    0.0020035566153067995,
                                    0.9084741717575026,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.00039062651874043145,
                                    0.03569423040444776,
                                    0.010434593588739452,
                                    0.9534805494880724,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.7252132901931454,
                                ],
                                [
                                    0.00039612369442980903,
                                    0.03619654513787413,
                                    0.010429096413050074,
                                    0.9529782347546459,
                                ],
                                [
                                    0.008444319845623756,
                                    0.02814834898668019,
                                    0.22232102510153476,
                                    0.7410863060661613,
                                ],
                                [
                                    0.0027770239562859337,
                                    0.25375576971569663,
                                    0.008048196151193949,
                                    0.7354190101768235,
                                ],
                                [
                                    0.059198878621973296,
                                    0.19733391505000927,
                                    0.1715664663251852,
                                    0.5719007400028322,
                                ],
                                [
                                    0.000550138831755803,
                                    0.022904899683578235,
                                    0.022904899683578235,
                                    0.9536400618010877,
                                ],
                                [
                                    0.012277658089422822,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.46536758105875475,
                                ],
                                [
                                    0.0005759458867310299,
                                    0.023979370292114624,
                                    0.022879092628603007,
                                    0.9525655911925514,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.011753326312642245,
                                    0.48934695135086936,
                                    0.011701712202691792,
                                    0.4871980101337966,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.00039062651874043145,
                                    0.010434593588739452,
                                    0.03569423040444776,
                                    0.9534805494880724,
                                ],
                                [
                                    0.028148348986680238,
                                    0.7519115261736411,
                                    0.007936507936507952,
                                    0.21200361690317066,
                                ],
                                [
                                    0.00045170892278329156,
                                    0.012066254602604074,
                                    0.0356331480004049,
                                    0.9518488884742078,
                                ],
                                [
                                    0.009629251354415402,
                                    0.002888712170971964,
                                    0.7596054036984261,
                                    0.22787663277618653,
                                ],
                                [
                                    0.026907314491556138,
                                    0.7187604471634845,
                                    0.009177542431632057,
                                    0.24515469591332734,
                                ],
                                [
                                    0.5735934834207397,
                                    0.17207427823430102,
                                    0.1956411716321019,
                                    0.05869106671285748,
                                ],
                                [
                                    9.838577615361658e-05,
                                    0.0021021695508696182,
                                    0.04461113592749122,
                                    0.9531883087454855,
                                ],
                                [
                                    0.04271058037267615,
                                    0.912579897923679,
                                    0.0019989413309686897,
                                    0.04271058037267617,
                                ],
                                [
                                    0.0001921562679691434,
                                    0.004105726166176385,
                                    0.04451736543567569,
                                    0.9511847521301787,
                                ],
                                [
                                    0.004096268438091006,
                                    0.0002016139960545219,
                                    0.948993654531241,
                                    0.046708463034613554,
                                ],
                                [
                                    0.04080540953352299,
                                    0.8718728741663097,
                                    0.0039041121701218514,
                                    0.08341760413004555,
                                ],
                                [
                                    0.8698644751072555,
                                    0.04281380859257708,
                                    0.0832254478620764,
                                    0.004096268438090997,
                                ],
                                [
                                    0.009833417785021961,
                                    0.8985469834806652,
                                    0.0009918023224579217,
                                    0.09062779641185491,
                                ],
                                [
                                    0.010341229694137779,
                                    0.9449492486022174,
                                    0.00048399041334210404,
                                    0.044225531290302704,
                                ],
                                [
                                    0.009856121812593944,
                                    0.9006216065602155,
                                    0.0009690982948859387,
                                    0.0885531733323046,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991899,
                                    0.08532277496919864,
                                ],
                                [
                                    0.010340112225936048,
                                    0.9448471378505183,
                                    0.0004851078815438347,
                                    0.04432764204200188,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.039042165512684385,
                                    0.6941076326169691,
                                    0.014210478915896631,
                                    0.25263972295445,
                                ],
                                [
                                    0.05133103037359426,
                                    0.9125841127032176,
                                    0.0019216140549867579,
                                    0.034163242868201375,
                                ],
                                [
                                    0.039591594782896394,
                                    0.703875611545121,
                                    0.013661049645684624,
                                    0.24287174402629788,
                                ],
                                [
                                    0.1715664663251852,
                                    0.5719007400028322,
                                    0.05919887862197328,
                                    0.19733391505000922,
                                ],
                                [
                                    0.05130398804656152,
                                    0.9121033431211345,
                                    0.0019486563820195015,
                                    0.03464401245028446,
                                ],
                                [
                                    0.22232102510153476,
                                    0.7410863060661613,
                                    0.008444319845623759,
                                    0.0281483489866802,
                                ],
                                [
                                    0.054985031209919655,
                                    0.4215599302747463,
                                    0.060397641263659596,
                                    0.46305739725167444,
                                ],
                                [
                                    0.11267636744670928,
                                    0.8638685940379567,
                                    0.0027063050268699707,
                                    0.02074873348846404,
                                ],
                                [
                                    0.05756438325951067,
                                    0.4413353390769777,
                                    0.057818289214068584,
                                    0.44328198844944305,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.11254941446943031,
                                    0.862895269351724,
                                    0.002833258004148925,
                                    0.021722058174696687,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    0.03904216551268439,
                                    0.18089795932699423,
                                    0.138470535005893,
                                    0.6415893401544284,
                                ],
                                [
                                    0.17559108646359062,
                                    0.8135836934289296,
                                    0.0019216140549867583,
                                    0.008903606052493124,
                                ],
                                [
                                    0.045147202457548226,
                                    0.20918503588741122,
                                    0.13236549806102915,
                                    0.6133022635940114,
                                ],
                                [
                                    0.19564117163210193,
                                    0.058691066712857495,
                                    0.5735934834207396,
                                    0.172074278234301,
                                ],
                                [
                                    0.17529060300819282,
                                    0.8121914334664199,
                                    0.002222097510384546,
                                    0.010295866015002727,
                                ],
                                [
                                    0.7596054036984262,
                                    0.22787663277618656,
                                    0.00962925135441533,
                                    0.0028887121709719426,
                                ],
                                [
                                    0.009833417785021966,
                                    0.03487610391862287,
                                    0.21010670705465664,
                                    0.7451837712416985,
                                ],
                                [
                                    0.21945613442633652,
                                    0.7783433102466403,
                                    0.00048399041334210453,
                                    0.001716564913681105,
                                ],
                                [
                                    0.019205549184273814,
                                    0.06811616711589356,
                                    0.2007345756554048,
                                    0.7119437080444279,
                                ],
                                [
                                    0.08322544786207639,
                                    0.004096268438090996,
                                    0.8698644751072555,
                                    0.04281380859257708,
                                ],
                                [
                                    0.2189948480405664,
                                    0.7767072695252881,
                                    0.000945276799112226,
                                    0.003352605635033287,
                                ],
                                [
                                    0.948993654531241,
                                    0.046708463034613554,
                                    0.0040962684380909916,
                                    0.00020161399605452123,
                                ],
                                [
                                    0.007936507936507941,
                                    0.7252132901931455,
                                    0.0028887121709719418,
                                    0.26396148969937466,
                                ],
                                [
                                    0.008444319845623757,
                                    0.7716155553146976,
                                    0.002380900261856124,
                                    0.21755922457782245,
                                ],
                                [
                                    0.007954832256592275,
                                    0.7268877092909685,
                                    0.0028703878508876063,
                                    0.2622870706015516,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.008438822669934381,
                                    0.7711132405812713,
                                    0.002386397437545502,
                                    0.21806153931124886,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.031510758845398154,
                                    0.560211195688866,
                                    0.02174188558318287,
                                    0.386536159882553,
                                ],
                                [
                                    0.04379962370630803,
                                    0.7786876757751146,
                                    0.009453020722272993,
                                    0.1680596797963044,
                                ],
                                [
                                    0.031954200775652475,
                                    0.56809488821386,
                                    0.02129844365292854,
                                    0.378652467357559,
                                ],
                                [
                                    0.13847053500589307,
                                    0.4615785539836194,
                                    0.09229480994126545,
                                    0.3076561010692221,
                                ],
                                [
                                    0.0436665940393176,
                                    0.7763226197898735,
                                    0.009586050389263417,
                                    0.17042473578154552,
                                ],
                                [
                                    0.1892250937822426,
                                    0.6307641200469485,
                                    0.041540251164915915,
                                    0.13847053500589301,
                                ],
                                [
                                    0.044378175129644364,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.5443781751296444,
                                ],
                                [
                                    0.10206951136643398,
                                    0.7825478161599868,
                                    0.01331316110714526,
                                    0.10206951136643397,
                                ],
                                [
                                    0.04645995874345646,
                                    0.3561997972445584,
                                    0.06892271373012279,
                                    0.5284175302818623,
                                ],
                                [
                                    0.20132987799400742,
                                    0.20132987799400742,
                                    0.2986701220059926,
                                    0.2986701220059926,
                                ],
                                [
                                    0.10144498995337611,
                                    0.7777597275193047,
                                    0.013937682520203137,
                                    0.10685760000711603,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.03151075884539816,
                                    0.14600194167317931,
                                    0.1460019416731792,
                                    0.6764853578082433,
                                ],
                                [
                                    0.16805967979630437,
                                    0.7786876757751146,
                                    0.009453020722272994,
                                    0.04379962370630805,
                                ],
                                [
                                    0.03643810712092735,
                                    0.16883231586558997,
                                    0.14107459339765002,
                                    0.6536549836158326,
                                ],
                                [
                                    0.15790112301858453,
                                    0.0473692999679328,
                                    0.611333532034257,
                                    0.1833960449792257,
                                ],
                                [
                                    0.16658150767157195,
                                    0.7718387134445986,
                                    0.010931192847005427,
                                    0.050648586036824,
                                ],
                                [
                                    0.7218653550849088,
                                    0.21655486603126187,
                                    0.04736929996793278,
                                    0.014210478915896644,
                                ],
                                [
                                    0.007936507936507952,
                                    0.028148348986680238,
                                    0.21200361690317066,
                                    0.7519115261736411,
                                ],
                                [
                                    0.2175592245778225,
                                    0.7716155553146976,
                                    0.0023809002618561267,
                                    0.008444319845623766,
                                ],
                                [
                                    0.015500713674359788,
                                    0.05497625675410911,
                                    0.20443941116531883,
                                    0.7250836184062123,
                                ],
                                [
                                    0.0671708903167813,
                                    0.0033060801116875918,
                                    0.8859190326525506,
                                    0.04360399691898048,
                                ],
                                [
                                    0.21529001253065236,
                                    0.7635673591635036,
                                    0.0046501123090262435,
                                    0.016492515996817718,
                                ],
                                [
                                    0.9329390969859458,
                                    0.045918274708210145,
                                    0.020150825983386036,
                                    0.0009918023224579234,
                                ],
                                [
                                    0.0051587040991820324,
                                    0.47138625738548395,
                                    0.00566651600829785,
                                    0.5177885225070362,
                                ],
                                [
                                    0.00566651600829785,
                                    0.5177885225070362,
                                    0.0051587040991820324,
                                    0.47138625738548395,
                                ],
                                [
                                    0.0051706148470688894,
                                    0.4724746243011087,
                                    0.005654605260410993,
                                    0.5167001555914115,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.005654605260410993,
                                    0.5167001555914115,
                                    0.0051706148470688894,
                                    0.4724746243011087,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.020481889783835576,
                                    0.3641354377425853,
                                    0.032770754644745444,
                                    0.5826119178288337,
                                ],
                                [
                                    0.03277075464474545,
                                    0.5826119178288338,
                                    0.020481889783835572,
                                    0.36413543774258517,
                                ],
                                [
                                    0.020770125582457954,
                                    0.36925981199770286,
                                    0.03248251884612307,
                                    0.5774875435737161,
                                ],
                                [
                                    0.0900053930854045,
                                    0.3000245444947563,
                                    0.140759951861754,
                                    0.4692101105580852,
                                ],
                                [
                                    0.03248251884612307,
                                    0.5774875435737162,
                                    0.020770125582457947,
                                    0.36925981199770275,
                                ],
                                [
                                    0.14075995186175402,
                                    0.4692101105580853,
                                    0.09000539308540448,
                                    0.3000245444947562,
                                ],
                                [
                                    0.028845668118394813,
                                    0.2211543318816052,
                                    0.08653700435518444,
                                    0.6634629956448156,
                                ],
                                [
                                    0.08653700435518444,
                                    0.6634629956448156,
                                    0.028845668118394813,
                                    0.2211543318816052,
                                ],
                                [
                                    0.030198820631829798,
                                    0.23152869862583722,
                                    0.08518385184174945,
                                    0.6530886289005835,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.08518385184174945,
                                    0.6530886289005835,
                                    0.030198820631829798,
                                    0.23152869862583722,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.020481889783835576,
                                    0.09490078268974368,
                                    0.1570308107347418,
                                    0.727586516791679,
                                ],
                                [
                                    0.1570308107347418,
                                    0.727586516791679,
                                    0.020481889783835576,
                                    0.09490078268974368,
                                ],
                                [
                                    0.023684649983966383,
                                    0.10974045095120696,
                                    0.153828050534611,
                                    0.7127468485302156,
                                ],
                                [
                                    0.10263521149325863,
                                    0.030789889441914717,
                                    0.6665994435595829,
                                    0.1999754555052438,
                                ],
                                [
                                    0.153828050534611,
                                    0.7127468485302156,
                                    0.023684649983966383,
                                    0.10974045095120696,
                                ],
                                [
                                    0.6665994435595829,
                                    0.1999754555052438,
                                    0.10263521149325863,
                                    0.030789889441914717,
                                ],
                                [
                                    0.0051587040991820385,
                                    0.018296334416152,
                                    0.21478142074049658,
                                    0.7617635407441694,
                                ],
                                [
                                    0.21478142074049658,
                                    0.7617635407441694,
                                    0.0051587040991820385,
                                    0.018296334416152,
                                ],
                                [
                                    0.010075412991693022,
                                    0.03573438637546344,
                                    0.2098647118479856,
                                    0.7443254887848579,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727588,
                                    0.9094290648192482,
                                    0.04476113581359532,
                                ],
                                [
                                    0.2098647118479856,
                                    0.7443254887848579,
                                    0.010075412991693022,
                                    0.03573438637546344,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359532,
                                    0.0436608581500837,
                                    0.0021489412170727588,
                                ],
                                [
                                    0.0023809002618561245,
                                    0.2175592245778225,
                                    0.008444319845623757,
                                    0.7716155553146976,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.7252132901931454,
                                ],
                                [
                                    0.0023863974375455035,
                                    0.21806153931124897,
                                    0.00843882266993438,
                                    0.7711132405812712,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.0028703878508876076,
                                    0.2622870706015517,
                                    0.007954832256592275,
                                    0.7268877092909684,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.009453020722272996,
                                    0.16805967979630448,
                                    0.04379962370630802,
                                    0.7786876757751144,
                                ],
                                [
                                    0.021741885583182873,
                                    0.38653615988255313,
                                    0.03151075884539815,
                                    0.5602111956888659,
                                ],
                                [
                                    0.009586050389263428,
                                    0.17042473578154568,
                                    0.043666594039317594,
                                    0.7763226197898733,
                                ],
                                [
                                    0.041540251164915956,
                                    0.13847053500589315,
                                    0.18922509378224253,
                                    0.6307641200469484,
                                ],
                                [
                                    0.02129844365292855,
                                    0.3786524673575591,
                                    0.031954200775652475,
                                    0.5680948882138599,
                                ],
                                [
                                    0.09229480994126547,
                                    0.30765610106922214,
                                    0.13847053500589304,
                                    0.46157855398361936,
                                ],
                                [
                                    0.013313161107145264,
                                    0.10206951136643398,
                                    0.10206951136643398,
                                    0.7825478161599868,
                                ],
                                [
                                    0.0710044973439349,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.3402391523967764,
                                ],
                                [
                                    0.01393768252020314,
                                    0.10685760000711605,
                                    0.10144498995337611,
                                    0.7777597275193047,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.06892271373012279,
                                    0.5284175302818623,
                                    0.04645995874345646,
                                    0.3561997972445584,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.009453020722272991,
                                    0.04379962370630803,
                                    0.16805967979630437,
                                    0.7786876757751146,
                                ],
                                [
                                    0.1460019416731792,
                                    0.6764853578082433,
                                    0.031510758845398154,
                                    0.14600194167317931,
                                ],
                                [
                                    0.010931192847005437,
                                    0.050648586036824046,
                                    0.16658150767157193,
                                    0.7718387134445985,
                                ],
                                [
                                    0.04736929996793283,
                                    0.014210478915896657,
                                    0.7218653550849087,
                                    0.21655486603126184,
                                ],
                                [
                                    0.14107459339765005,
                                    0.6536549836158327,
                                    0.03643810712092734,
                                    0.16883231586558992,
                                ],
                                [
                                    0.6113335320342571,
                                    0.18339604497922574,
                                    0.15790112301858447,
                                    0.04736929996793279,
                                ],
                                [
                                    0.0023809002618561245,
                                    0.008444319845623757,
                                    0.2175592245778225,
                                    0.7716155553146976,
                                ],
                                [
                                    0.21200361690317066,
                                    0.7519115261736411,
                                    0.007936507936507948,
                                    0.028148348986680227,
                                ],
                                [
                                    0.004650112309026255,
                                    0.01649251599681776,
                                    0.21529001253065236,
                                    0.7635673591635036,
                                ],
                                [
                                    0.02015082598338609,
                                    0.000991802322457926,
                                    0.9329390969859458,
                                    0.045918274708210145,
                                ],
                                [
                                    0.20443941116531883,
                                    0.7250836184062123,
                                    0.015500713674359796,
                                    0.054976256754109144,
                                ],
                                [
                                    0.8859190326525506,
                                    0.04360399691898048,
                                    0.06717089031678135,
                                    0.003306080111687594,
                                ],
                                [
                                    0.0004839904133421043,
                                    0.04422553129030273,
                                    0.010341229694137779,
                                    0.9449492486022174,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.09062779641185499,
                                    0.00983341778502196,
                                    0.8985469834806651,
                                ],
                                [
                                    0.00048510788154383535,
                                    0.044327642042001944,
                                    0.010340112225936048,
                                    0.9448471378505182,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.0009690982948859397,
                                    0.08855317333230468,
                                    0.009856121812593942,
                                    0.9006216065602154,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.001921614054986761,
                                    0.03416324286820143,
                                    0.05133103037359426,
                                    0.9125841127032176,
                                ],
                                [
                                    0.014210478915896638,
                                    0.25263972295445003,
                                    0.039042165512684385,
                                    0.694107632616969,
                                ],
                                [
                                    0.0019486563820195009,
                                    0.034644012450284443,
                                    0.05130398804656152,
                                    0.9121033431211345,
                                ],
                                [
                                    0.008444319845623756,
                                    0.02814834898668019,
                                    0.22232102510153476,
                                    0.7410863060661613,
                                ],
                                [
                                    0.013661049645684627,
                                    0.24287174402629794,
                                    0.039591594782896394,
                                    0.703875611545121,
                                ],
                                [
                                    0.059198878621973296,
                                    0.19733391505000927,
                                    0.1715664663251852,
                                    0.5719007400028322,
                                ],
                                [
                                    0.0027063050268699737,
                                    0.020748733488464063,
                                    0.11267636744670928,
                                    0.8638685940379567,
                                ],
                                [
                                    0.060397641263659596,
                                    0.46305739725167444,
                                    0.054985031209919655,
                                    0.4215599302747463,
                                ],
                                [
                                    0.00283325800414893,
                                    0.021722058174696725,
                                    0.11254941446943031,
                                    0.862895269351724,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.057818289214068584,
                                    0.44328198844944305,
                                    0.05756438325951067,
                                    0.4413353390769777,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.0019216140549867583,
                                    0.008903606052493124,
                                    0.17559108646359062,
                                    0.8135836934289296,
                                ],
                                [
                                    0.138470535005893,
                                    0.6415893401544284,
                                    0.03904216551268439,
                                    0.18089795932699423,
                                ],
                                [
                                    0.0022220975103845624,
                                    0.010295866015002804,
                                    0.1752906030081928,
                                    0.8121914334664199,
                                ],
                                [
                                    0.009629251354415402,
                                    0.002888712170971964,
                                    0.7596054036984261,
                                    0.22787663277618653,
                                ],
                                [
                                    0.13236549806102915,
                                    0.6133022635940115,
                                    0.04514720245754821,
                                    0.20918503588741116,
                                ],
                                [
                                    0.5735934834207397,
                                    0.17207427823430102,
                                    0.1956411716321019,
                                    0.05869106671285748,
                                ],
                                [
                                    0.00048399041334211006,
                                    0.0017165649136811247,
                                    0.21945613442633652,
                                    0.7783433102466403,
                                ],
                                [
                                    0.21010670705465664,
                                    0.7451837712416985,
                                    0.009833417785021972,
                                    0.03487610391862289,
                                ],
                                [
                                    0.0009452767991122293,
                                    0.0033526056350332988,
                                    0.2189948480405664,
                                    0.7767072695252881,
                                ],
                                [
                                    0.004096268438091006,
                                    0.0002016139960545219,
                                    0.948993654531241,
                                    0.046708463034613554,
                                ],
                                [
                                    0.2007345756554048,
                                    0.7119437080444279,
                                    0.019205549184273817,
                                    0.06811616711589358,
                                ],
                                [
                                    0.8698644751072555,
                                    0.04281380859257708,
                                    0.0832254478620764,
                                    0.004096268438090997,
                                ],
                                [
                                    0.02130609729826128,
                                    0.8870743039674259,
                                    0.002148941217072757,
                                    0.08947065751724008,
                                ],
                                [
                                    0.022406374961772883,
                                    0.9328841033345823,
                                    0.001048663553561152,
                                    0.04366085815008366,
                                ],
                                [
                                    0.021355290186338086,
                                    0.8891224381864714,
                                    0.0020997483289959496,
                                    0.08742252329819458,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991899,
                                    0.08532277496919864,
                                ],
                                [
                                    0.02240395373989924,
                                    0.9327832963365551,
                                    0.0010510847754347972,
                                    0.04376166514811092,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08459278303166455,
                                    0.6485570150979889,
                                    0.030789889441914704,
                                    0.23606031242843187,
                                ],
                                [
                                    0.11121910524595506,
                                    0.8526960378308568,
                                    0.004163567227624185,
                                    0.03192128969556395,
                                ],
                                [
                                    0.0857832331625926,
                                    0.6576839731654248,
                                    0.02959943931098664,
                                    0.22693335436099588,
                                ],
                                [
                                    0.1715664663251852,
                                    0.5719007400028322,
                                    0.05919887862197328,
                                    0.19733391505000922,
                                ],
                                [
                                    0.11116051255076738,
                                    0.8522468186169286,
                                    0.0042221599228118795,
                                    0.03237050890949208,
                                ],
                                [
                                    0.22232102510153476,
                                    0.7410863060661613,
                                    0.008444319845623759,
                                    0.0281483489866802,
                                ],
                                [
                                    0.11913624037116649,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.3925912788865005,
                                ],
                                [
                                    0.2441362403711665,
                                    0.7324087211134995,
                                    0.005863759628833502,
                                    0.017591278886500507,
                                ],
                                [
                                    0.1247249305841221,
                                    0.3741747917523663,
                                    0.1252750694158779,
                                    0.3758252082476337,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.2438611709552886,
                                    0.7315835128658658,
                                    0.006138829044711403,
                                    0.01841648713413421,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    0.08459278303166454,
                                    0.13534734180801408,
                                    0.3000245444947562,
                                    0.4800353306655652,
                                ],
                                [
                                    0.3804537602987966,
                                    0.6087210195937236,
                                    0.004163567227624186,
                                    0.006661652879855697,
                                ],
                                [
                                    0.09782058581605096,
                                    0.15651165252890847,
                                    0.2867967417103698,
                                    0.4588710199446708,
                                ],
                                [
                                    0.19564117163210193,
                                    0.058691066712857495,
                                    0.5735934834207396,
                                    0.172074278234301,
                                ],
                                [
                                    0.3798027018492131,
                                    0.6076793346253997,
                                    0.004814625677207665,
                                    0.007703337848179608,
                                ],
                                [
                                    0.7596054036984262,
                                    0.22787663277618656,
                                    0.00962925135441533,
                                    0.0028887121709719426,
                                ],
                                [
                                    0.021306097298261266,
                                    0.023403424405383573,
                                    0.4552388641864047,
                                    0.5000516141099505,
                                ],
                                [
                                    0.4754962979311048,
                                    0.522303146741872,
                                    0.001048663553561152,
                                    0.0011518917734620576,
                                ],
                                [
                                    0.041612723931038195,
                                    0.04570899236912919,
                                    0.43493223755362775,
                                    0.47774604614620486,
                                ],
                                [
                                    0.08322544786207639,
                                    0.004096268438090996,
                                    0.8698644751072555,
                                    0.04281380859257708,
                                ],
                                [
                                    0.4744968272656205,
                                    0.521205290300234,
                                    0.0020481342190454958,
                                    0.0022497482151000174,
                                ],
                                [
                                    0.948993654531241,
                                    0.046708463034613554,
                                    0.0040962684380909916,
                                    0.00020161399605452123,
                                ],
                                [
                                    0.017196056752640396,
                                    0.7159537413770131,
                                    0.006258981762693642,
                                    0.26059122010765295,
                                ],
                                [
                                    0.018296334416152,
                                    0.7617635407441694,
                                    0.005158704099182037,
                                    0.21478142074049653,
                                ],
                                [
                                    0.017235760114703992,
                                    0.7176067814328568,
                                    0.0062192784006300465,
                                    0.2589381800518092,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.018284423668265142,
                                    0.7612676395829405,
                                    0.005170614847068894,
                                    0.21527732190172547,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.06827446047545314,
                                    0.523447494058811,
                                    0.0471082119981261,
                                    0.3611698334676098,
                                ],
                                [
                                    0.09490078268974368,
                                    0.727586516791679,
                                    0.020481889783835576,
                                    0.15703081073474182,
                                ],
                                [
                                    0.06923526750294653,
                                    0.530813821486566,
                                    0.04614740497063272,
                                    0.3538035060398548,
                                ],
                                [
                                    0.13847053500589307,
                                    0.4615785539836194,
                                    0.09229480994126545,
                                    0.3076561010692221,
                                ],
                                [
                                    0.0946125468911213,
                                    0.7253766669380698,
                                    0.020770125582457957,
                                    0.15924066058835099,
                                ],
                                [
                                    0.1892250937822426,
                                    0.6307641200469485,
                                    0.041540251164915915,
                                    0.13847053500589301,
                                ],
                                [
                                    0.09615433188160519,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.4615370043551844,
                                ],
                                [
                                    0.2211543318816052,
                                    0.6634629956448156,
                                    0.028845668118394806,
                                    0.08653700435518441,
                                ],
                                [
                                    0.10066493899700371,
                                    0.30199481699101116,
                                    0.1493350610029963,
                                    0.44800518300898884,
                                ],
                                [
                                    0.20132987799400742,
                                    0.20132987799400742,
                                    0.2986701220059926,
                                    0.2986701220059926,
                                ],
                                [
                                    0.2198011793681702,
                                    0.6594035381045106,
                                    0.03019882063182979,
                                    0.09059646189548937,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.06827446047545316,
                                    0.10923824004312432,
                                    0.3163428670509676,
                                    0.5061444324304549,
                                ],
                                [
                                    0.36413543774258517,
                                    0.5826119178288338,
                                    0.02048188978383558,
                                    0.032770754644745465,
                                ],
                                [
                                    0.07895056150929226,
                                    0.12631986147722507,
                                    0.3056667660171285,
                                    0.4890628109963542,
                                ],
                                [
                                    0.15790112301858453,
                                    0.0473692999679328,
                                    0.611333532034257,
                                    0.1833960449792257,
                                ],
                                [
                                    0.3609326775424544,
                                    0.5774875435737162,
                                    0.02368464998396639,
                                    0.03789512889986303,
                                ],
                                [
                                    0.7218653550849088,
                                    0.21655486603126187,
                                    0.04736929996793278,
                                    0.014210478915896644,
                                ],
                                [
                                    0.0171960567526404,
                                    0.018888800170547792,
                                    0.45934890473202555,
                                    0.5045662383447862,
                                ],
                                [
                                    0.47138625738548395,
                                    0.5177885225070362,
                                    0.005158704099182037,
                                    0.005666516008297856,
                                ],
                                [
                                    0.03358544515839065,
                                    0.036891525270078246,
                                    0.4429595163262753,
                                    0.4865635132452558,
                                ],
                                [
                                    0.0671708903167813,
                                    0.0033060801116875918,
                                    0.8859190326525506,
                                    0.04360399691898048,
                                ],
                                [
                                    0.4664695484929729,
                                    0.512387823201183,
                                    0.010075412991693018,
                                    0.011067215314150943,
                                ],
                                [
                                    0.9329390969859458,
                                    0.045918274708210145,
                                    0.020150825983386036,
                                    0.0009918023224579234,
                                ],
                                [
                                    0.011177380425911215,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.5111773804259112,
                                ],
                                [
                                    0.012277658089422822,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.46536758105875475,
                                ],
                                [
                                    0.011203187480886442,
                                    0.46644205166729114,
                                    0.012251851034447595,
                                    0.5101029098173748,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.012251851034447595,
                                    0.5101029098173748,
                                    0.011203187480886442,
                                    0.46644205166729114,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.04437817512964438,
                                    0.3402391523967765,
                                    0.07100449734393488,
                                    0.5443781751296443,
                                ],
                                [
                                    0.0710044973439349,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.3402391523967764,
                                ],
                                [
                                    0.04500269654270225,
                                    0.3450272410374585,
                                    0.070379975930877,
                                    0.5395900864889622,
                                ],
                                [
                                    0.0900053930854045,
                                    0.3000245444947563,
                                    0.140759951861754,
                                    0.4692101105580852,
                                ],
                                [
                                    0.07037997593087701,
                                    0.5395900864889623,
                                    0.04500269654270224,
                                    0.34502724103745847,
                                ],
                                [
                                    0.14075995186175402,
                                    0.4692101105580853,
                                    0.09000539308540448,
                                    0.3000245444947562,
                                ],
                                [0.0625, 0.1875, 0.1875, 0.5625],
                                [0.1875, 0.5625, 0.0625, 0.1875],
                                [
                                    0.06543187981441675,
                                    0.19629563944325026,
                                    0.18456812018558325,
                                    0.5537043605567498,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.18456812018558325,
                                    0.5537043605567498,
                                    0.06543187981441675,
                                    0.19629563944325026,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.044378175129644364,
                                    0.0710044973439349,
                                    0.3402391523967764,
                                    0.5443781751296444,
                                ],
                                [
                                    0.3402391523967764,
                                    0.5443781751296444,
                                    0.044378175129644364,
                                    0.0710044973439349,
                                ],
                                [
                                    0.051317605746629316,
                                    0.08210749518854403,
                                    0.33329972177979145,
                                    0.5332751772850353,
                                ],
                                [
                                    0.10263521149325863,
                                    0.030789889441914717,
                                    0.6665994435595829,
                                    0.1999754555052438,
                                ],
                                [
                                    0.33329972177979145,
                                    0.5332751772850353,
                                    0.051317605746629316,
                                    0.08210749518854403,
                                ],
                                [
                                    0.6665994435595829,
                                    0.1999754555052438,
                                    0.10263521149325863,
                                    0.030789889441914717,
                                ],
                                [
                                    0.011177380425911215,
                                    0.012277658089422822,
                                    0.46536758105875475,
                                    0.5111773804259112,
                                ],
                                [
                                    0.46536758105875475,
                                    0.5111773804259112,
                                    0.011177380425911215,
                                    0.012277658089422822,
                                ],
                                [
                                    0.02183042907504185,
                                    0.023979370292114607,
                                    0.4547145324096241,
                                    0.4994756682232194,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727588,
                                    0.9094290648192482,
                                    0.04476113581359532,
                                ],
                                [
                                    0.4547145324096241,
                                    0.4994756682232194,
                                    0.02183042907504185,
                                    0.023979370292114607,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359532,
                                    0.0436608581500837,
                                    0.0021489412170727588,
                                ],
                                [
                                    0.0051587040991820385,
                                    0.21478142074049658,
                                    0.018296334416152,
                                    0.7617635407441694,
                                ],
                                [
                                    0.006258981762693645,
                                    0.26059122010765307,
                                    0.017196056752640392,
                                    0.715953741377013,
                                ],
                                [
                                    0.005170614847068896,
                                    0.21527732190172558,
                                    0.018284423668265142,
                                    0.7612676395829404,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.006219278400630049,
                                    0.2589381800518093,
                                    0.01723576011470399,
                                    0.7176067814328567,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.020481889783835586,
                                    0.1570308107347419,
                                    0.09490078268974367,
                                    0.7275865167916789,
                                ],
                                [
                                    0.047108211998126114,
                                    0.3611698334676099,
                                    0.06827446047545314,
                                    0.5234474940588109,
                                ],
                                [
                                    0.020770125582457978,
                                    0.15924066058835115,
                                    0.09461254689112127,
                                    0.7253766669380696,
                                ],
                                [
                                    0.041540251164915956,
                                    0.13847053500589315,
                                    0.18922509378224253,
                                    0.6307641200469484,
                                ],
                                [
                                    0.04614740497063274,
                                    0.3538035060398549,
                                    0.06923526750294652,
                                    0.5308138214865659,
                                ],
                                [
                                    0.09229480994126547,
                                    0.30765610106922214,
                                    0.13847053500589304,
                                    0.46157855398361936,
                                ],
                                [
                                    0.028845668118394813,
                                    0.08653700435518444,
                                    0.2211543318816052,
                                    0.6634629956448156,
                                ],
                                [
                                    0.1538456681183948,
                                    0.4615370043551844,
                                    0.09615433188160519,
                                    0.2884629956448156,
                                ],
                                [
                                    0.030198820631829798,
                                    0.0905964618954894,
                                    0.2198011793681702,
                                    0.6594035381045106,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.1493350610029963,
                                    0.44800518300898884,
                                    0.10066493899700371,
                                    0.30199481699101116,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.020481889783835572,
                                    0.03277075464474545,
                                    0.36413543774258517,
                                    0.5826119178288338,
                                ],
                                [
                                    0.3163428670509676,
                                    0.5061444324304549,
                                    0.06827446047545314,
                                    0.10923824004312431,
                                ],
                                [
                                    0.023684649983966414,
                                    0.03789512889986307,
                                    0.36093267754245434,
                                    0.5774875435737162,
                                ],
                                [
                                    0.04736929996793283,
                                    0.014210478915896657,
                                    0.7218653550849087,
                                    0.21655486603126184,
                                ],
                                [
                                    0.30566676601712855,
                                    0.48906281099635424,
                                    0.07895056150929224,
                                    0.12631986147722502,
                                ],
                                [
                                    0.6113335320342571,
                                    0.18339604497922574,
                                    0.15790112301858447,
                                    0.04736929996793279,
                                ],
                                [
                                    0.0051587040991820324,
                                    0.00566651600829785,
                                    0.47138625738548395,
                                    0.5177885225070362,
                                ],
                                [
                                    0.45934890473202555,
                                    0.5045662383447862,
                                    0.017196056752640392,
                                    0.018888800170547785,
                                ],
                                [
                                    0.010075412991693044,
                                    0.01106721531415097,
                                    0.4664695484929729,
                                    0.512387823201183,
                                ],
                                [
                                    0.02015082598338609,
                                    0.000991802322457926,
                                    0.9329390969859458,
                                    0.045918274708210145,
                                ],
                                [
                                    0.4429595163262753,
                                    0.4865635132452558,
                                    0.033585445158390674,
                                    0.03689152527007827,
                                ],
                                [
                                    0.8859190326525506,
                                    0.04360399691898048,
                                    0.06717089031678135,
                                    0.003306080111687594,
                                ],
                                [
                                    0.0010486635535611527,
                                    0.043660858150083685,
                                    0.022406374961772883,
                                    0.9328841033345823,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.08947065751724015,
                                    0.021306097298261276,
                                    0.8870743039674258,
                                ],
                                [
                                    0.0010510847754347987,
                                    0.04376166514811098,
                                    0.02240395373989924,
                                    0.932783296336555,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.0020997483289959514,
                                    0.08742252329819467,
                                    0.021355290186338086,
                                    0.8891224381864713,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.004163567227624192,
                                    0.031921289695564,
                                    0.11121910524595506,
                                    0.8526960378308568,
                                ],
                                [
                                    0.030789889441914717,
                                    0.23606031242843198,
                                    0.08459278303166454,
                                    0.6485570150979888,
                                ],
                                [
                                    0.004222159922811878,
                                    0.032370508909492064,
                                    0.11116051255076738,
                                    0.8522468186169286,
                                ],
                                [
                                    0.008444319845623756,
                                    0.02814834898668019,
                                    0.22232102510153476,
                                    0.7410863060661613,
                                ],
                                [
                                    0.029599439310986648,
                                    0.2269333543609959,
                                    0.0857832331625926,
                                    0.6576839731654248,
                                ],
                                [
                                    0.059198878621973296,
                                    0.19733391505000927,
                                    0.1715664663251852,
                                    0.5719007400028322,
                                ],
                                [
                                    0.005863759628833509,
                                    0.017591278886500528,
                                    0.2441362403711665,
                                    0.7324087211134995,
                                ],
                                [
                                    0.1308637596288335,
                                    0.3925912788865005,
                                    0.11913624037116649,
                                    0.3574087211134995,
                                ],
                                [
                                    0.0061388290447114136,
                                    0.01841648713413424,
                                    0.2438611709552886,
                                    0.7315835128658658,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.1252750694158779,
                                    0.3758252082476337,
                                    0.1247249305841221,
                                    0.3741747917523663,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.004163567227624186,
                                    0.006661652879855697,
                                    0.3804537602987966,
                                    0.6087210195937236,
                                ],
                                [
                                    0.3000245444947562,
                                    0.4800353306655652,
                                    0.08459278303166454,
                                    0.13534734180801408,
                                ],
                                [
                                    0.004814625677207701,
                                    0.007703337848179665,
                                    0.37980270184921305,
                                    0.6076793346253996,
                                ],
                                [
                                    0.009629251354415402,
                                    0.002888712170971964,
                                    0.7596054036984261,
                                    0.22787663277618653,
                                ],
                                [
                                    0.28679674171036984,
                                    0.45887101994467083,
                                    0.09782058581605095,
                                    0.15651165252890845,
                                ],
                                [
                                    0.5735934834207397,
                                    0.17207427823430102,
                                    0.1956411716321019,
                                    0.05869106671285748,
                                ],
                                [
                                    0.001048663553561164,
                                    0.0011518917734620708,
                                    0.4754962979311048,
                                    0.522303146741872,
                                ],
                                [
                                    0.4552388641864047,
                                    0.5000516141099505,
                                    0.021306097298261276,
                                    0.023403424405383583,
                                ],
                                [
                                    0.002048134219045503,
                                    0.002249748215100025,
                                    0.4744968272656205,
                                    0.521205290300234,
                                ],
                                [
                                    0.004096268438091006,
                                    0.0002016139960545219,
                                    0.948993654531241,
                                    0.046708463034613554,
                                ],
                                [
                                    0.43493223755362775,
                                    0.47774604614620486,
                                    0.0416127239310382,
                                    0.045708992369129196,
                                ],
                                [
                                    0.8698644751072555,
                                    0.04281380859257708,
                                    0.0832254478620764,
                                    0.004096268438090997,
                                ],
                                [
                                    0.0327787768115006,
                                    0.8756016244541865,
                                    0.003306080111687592,
                                    0.08831351862262524,
                                ],
                                [
                                    0.03447152022940799,
                                    0.9208189580669471,
                                    0.0016133366937802001,
                                    0.04309618500986461,
                                ],
                                [
                                    0.032854458560082234,
                                    0.8776232698127273,
                                    0.00323039836310596,
                                    0.08629187326408458,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991899,
                                    0.08532277496919864,
                                ],
                                [
                                    0.034467795253862434,
                                    0.9207194548225919,
                                    0.0016170616693257597,
                                    0.04319568825421996,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.13014340055064463,
                                    0.6030063975790088,
                                    0.047369299967932744,
                                    0.21948090190241384,
                                ],
                                [
                                    0.17110718011831574,
                                    0.7928079629584961,
                                    0.006405520400261609,
                                    0.029679336522926526,
                                ],
                                [
                                    0.13197487154228874,
                                    0.6114923347857287,
                                    0.04553782897628863,
                                    0.21099496469569387,
                                ],
                                [
                                    0.1715664663251852,
                                    0.5719007400028322,
                                    0.05919887862197328,
                                    0.19733391505000922,
                                ],
                                [
                                    0.17101703705497312,
                                    0.7923902941127229,
                                    0.006495663463604253,
                                    0.030097005368699706,
                                ],
                                [
                                    0.22232102510153476,
                                    0.7410863060661613,
                                    0.008444319845623759,
                                    0.0281483489866802,
                                ],
                                [
                                    0.18328744953241333,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.3221251605213266,
                                ],
                                [
                                    0.3755961132956237,
                                    0.6009488481890423,
                                    0.009021214230797034,
                                    0.014433824284536975,
                                ],
                                [
                                    0.19188547790873353,
                                    0.3070142444277549,
                                    0.19273184961768722,
                                    0.30836842804582437,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.37517292744114683,
                                    0.6002717563800075,
                                    0.009444400085273882,
                                    0.01511091609357173,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    0.13014340055064466,
                                    0.08979672428903396,
                                    0.46157855398361936,
                                    0.318481321176702,
                                ],
                                [
                                    0.5853164341340024,
                                    0.4038583457585177,
                                    0.006405520400261612,
                                    0.004419699707218271,
                                ],
                                [
                                    0.15049396917455368,
                                    0.10383826917040576,
                                    0.4412279853597103,
                                    0.30443977629533026,
                                ],
                                [
                                    0.19564117163210193,
                                    0.058691066712857495,
                                    0.5735934834207396,
                                    0.172074278234301,
                                ],
                                [
                                    0.5843148006902332,
                                    0.4031672357843795,
                                    0.007407153844030783,
                                    0.00511080968135649,
                                ],
                                [
                                    0.7596054036984262,
                                    0.22787663277618656,
                                    0.00962925135441533,
                                    0.0028887121709719426,
                                ],
                                [
                                    0.032778776811500564,
                                    0.011930744892144272,
                                    0.7003710213181528,
                                    0.2549194569782024,
                                ],
                                [
                                    0.7315364614358731,
                                    0.2662629832371037,
                                    0.0016133366937801992,
                                    0.0005872186332430102,
                                ],
                                [
                                    0.06401989867780257,
                                    0.02330181762236481,
                                    0.6691298994518508,
                                    0.2435483842479819,
                                ],
                                [
                                    0.08322544786207639,
                                    0.004096268438090996,
                                    0.8698644751072555,
                                    0.04281380859257708,
                                ],
                                [
                                    0.7299988064906745,
                                    0.2657033110751799,
                                    0.003150991638978766,
                                    0.0011468907951667471,
                                ],
                                [
                                    0.948993654531241,
                                    0.046708463034613554,
                                    0.0040962684380909916,
                                    0.00020161399605452123,
                                ],
                                [
                                    0.02645560556877285,
                                    0.7066941925608806,
                                    0.009629251354415343,
                                    0.25722095051593125,
                                ],
                                [
                                    0.028148348986680238,
                                    0.7519115261736411,
                                    0.00793650793650795,
                                    0.2120036169031706,
                                ],
                                [
                                    0.026516687972815704,
                                    0.7083258535747451,
                                    0.009568168950372486,
                                    0.2555892895020667,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.028130024666595907,
                                    0.7514220385846098,
                                    0.007954832256592286,
                                    0.21249310449220207,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.10503816210550808,
                                    0.48668379242875603,
                                    0.07247453841306929,
                                    0.3358035070526666,
                                ],
                                [
                                    0.14600194167317923,
                                    0.6764853578082434,
                                    0.03151075884539815,
                                    0.14600194167317926,
                                ],
                                [
                                    0.10651633423024051,
                                    0.493532754759272,
                                    0.07099636628833686,
                                    0.32895454472215063,
                                ],
                                [
                                    0.13847053500589307,
                                    0.4615785539836194,
                                    0.09229480994126545,
                                    0.3076561010692221,
                                ],
                                [
                                    0.1455584997429249,
                                    0.6744307140862662,
                                    0.031954200775652475,
                                    0.14805658539515645,
                                ],
                                [
                                    0.1892250937822426,
                                    0.6307641200469485,
                                    0.041540251164915915,
                                    0.13847053500589301,
                                ],
                                [
                                    0.147930488633566,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.3786958335807245,
                                ],
                                [
                                    0.3402391523967764,
                                    0.5443781751296444,
                                    0.04437817512964435,
                                    0.07100449734393487,
                                ],
                                [
                                    0.15486991925055096,
                                    0.24778983673746388,
                                    0.22974740827586979,
                                    0.3675928357361154,
                                ],
                                [
                                    0.20132987799400742,
                                    0.20132987799400742,
                                    0.2986701220059926,
                                    0.2986701220059926,
                                ],
                                [
                                    0.3381573687829643,
                                    0.5410473486897165,
                                    0.046459958743456445,
                                    0.07433532378386272,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.10503816210550813,
                                    0.07247453841306935,
                                    0.48668379242875587,
                                    0.33580350705266665,
                                ],
                                [
                                    0.5602111956888659,
                                    0.38653615988255313,
                                    0.03151075884539816,
                                    0.021741885583182883,
                                ],
                                [
                                    0.12146301589765715,
                                    0.08380740708886017,
                                    0.4702589386366069,
                                    0.3244706383768758,
                                ],
                                [
                                    0.15790112301858453,
                                    0.0473692999679328,
                                    0.611333532034257,
                                    0.1833960449792257,
                                ],
                                [
                                    0.5552838474133367,
                                    0.38313637370283393,
                                    0.03643810712092734,
                                    0.025141671762902076,
                                ],
                                [
                                    0.7218653550849088,
                                    0.21655486603126187,
                                    0.04736929996793278,
                                    0.014210478915896644,
                                ],
                                [
                                    0.026455605568772845,
                                    0.009629251354415346,
                                    0.7066941925608805,
                                    0.25722095051593136,
                                ],
                                [
                                    0.7252132901931454,
                                    0.2639614896993748,
                                    0.007936507936507948,
                                    0.0028887121709719457,
                                ],
                                [
                                    0.05167017664242152,
                                    0.01880679378604738,
                                    0.6814796214872317,
                                    0.2480434080842993,
                                ],
                                [
                                    0.0671708903167813,
                                    0.0033060801116875918,
                                    0.8859190326525506,
                                    0.04360399691898048,
                                ],
                                [
                                    0.7176490844552935,
                                    0.2612082872388625,
                                    0.015500713674359795,
                                    0.0056419146314841675,
                                ],
                                [
                                    0.9329390969859458,
                                    0.045918274708210145,
                                    0.020150825983386036,
                                    0.0009918023224579234,
                                ],
                                [
                                    0.0171960567526404,
                                    0.45934890473202555,
                                    0.018888800170547792,
                                    0.5045662383447862,
                                ],
                                [
                                    0.018888800170547792,
                                    0.5045662383447862,
                                    0.0171960567526404,
                                    0.45934890473202555,
                                ],
                                [
                                    0.017235760114703996,
                                    0.46040947903347357,
                                    0.018849096808484195,
                                    0.5035056640433382,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.018849096808484195,
                                    0.5035056640433382,
                                    0.017235760114703996,
                                    0.46040947903347357,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.06827446047545313,
                                    0.3163428670509677,
                                    0.10923824004312424,
                                    0.5061444324304549,
                                ],
                                [
                                    0.10923824004312425,
                                    0.506144432430455,
                                    0.06827446047545312,
                                    0.31634286705096765,
                                ],
                                [
                                    0.06923526750294651,
                                    0.3207946700772143,
                                    0.10827743301563086,
                                    0.5016926294042083,
                                ],
                                [
                                    0.0900053930854045,
                                    0.3000245444947563,
                                    0.140759951861754,
                                    0.4692101105580852,
                                ],
                                [
                                    0.10827743301563088,
                                    0.5016926294042084,
                                    0.0692352675029465,
                                    0.3207946700772142,
                                ],
                                [
                                    0.14075995186175402,
                                    0.4692101105580853,
                                    0.09000539308540448,
                                    0.3000245444947562,
                                ],
                                [
                                    0.09615433188160519,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.4615370043551844,
                                ],
                                [
                                    0.2884629956448156,
                                    0.4615370043551844,
                                    0.09615433188160519,
                                    0.1538456681183948,
                                ],
                                [
                                    0.10066493899700371,
                                    0.1610625802606633,
                                    0.28395238852941707,
                                    0.4543200922129159,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.28395238852941707,
                                    0.4543200922129159,
                                    0.10066493899700371,
                                    0.1610625802606633,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.06827446047545314,
                                    0.047108211998126114,
                                    0.5234474940588109,
                                    0.3611698334676099,
                                ],
                                [
                                    0.5234474940588109,
                                    0.3611698334676099,
                                    0.06827446047545314,
                                    0.047108211998126114,
                                ],
                                [
                                    0.07895056150929224,
                                    0.05447453942588112,
                                    0.5127713930249718,
                                    0.3538035060398549,
                                ],
                                [
                                    0.10263521149325863,
                                    0.030789889441914717,
                                    0.6665994435595829,
                                    0.1999754555052438,
                                ],
                                [
                                    0.5127713930249718,
                                    0.3538035060398549,
                                    0.07895056150929224,
                                    0.05447453942588112,
                                ],
                                [
                                    0.6665994435595829,
                                    0.1999754555052438,
                                    0.10263521149325863,
                                    0.030789889441914717,
                                ],
                                [
                                    0.017196056752640392,
                                    0.006258981762693645,
                                    0.715953741377013,
                                    0.26059122010765307,
                                ],
                                [
                                    0.715953741377013,
                                    0.26059122010765307,
                                    0.017196056752640392,
                                    0.006258981762693645,
                                ],
                                [
                                    0.033585445158390674,
                                    0.01222435420876578,
                                    0.6995643529712626,
                                    0.2546258476615809,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727588,
                                    0.9094290648192482,
                                    0.04476113581359532,
                                ],
                                [
                                    0.6995643529712626,
                                    0.2546258476615809,
                                    0.033585445158390674,
                                    0.01222435420876578,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359532,
                                    0.0436608581500837,
                                    0.0021489412170727588,
                                ],
                                [
                                    0.007936507936507952,
                                    0.21200361690317066,
                                    0.028148348986680238,
                                    0.7519115261736411,
                                ],
                                [
                                    0.009629251354415346,
                                    0.25722095051593136,
                                    0.026455605568772845,
                                    0.7066941925608805,
                                ],
                                [
                                    0.00795483225659229,
                                    0.21249310449220218,
                                    0.028130024666595903,
                                    0.7514220385846097,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.009568168950372491,
                                    0.25558928950206683,
                                    0.0265166879728157,
                                    0.708325853574745,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.03151075884539816,
                                    0.14600194167317931,
                                    0.1460019416731792,
                                    0.6764853578082433,
                                ],
                                [
                                    0.0724745384130693,
                                    0.33580350705266665,
                                    0.10503816210550806,
                                    0.486683792428756,
                                ],
                                [
                                    0.03195420077565251,
                                    0.14805658539515662,
                                    0.14555849974292487,
                                    0.674430714086266,
                                ],
                                [
                                    0.041540251164915956,
                                    0.13847053500589315,
                                    0.18922509378224253,
                                    0.6307641200469484,
                                ],
                                [
                                    0.07099636628833687,
                                    0.32895454472215074,
                                    0.1065163342302405,
                                    0.4935327547592719,
                                ],
                                [
                                    0.09229480994126547,
                                    0.30765610106922214,
                                    0.13847053500589304,
                                    0.46157855398361936,
                                ],
                                [
                                    0.044378175129644364,
                                    0.0710044973439349,
                                    0.3402391523967764,
                                    0.5443781751296444,
                                ],
                                [
                                    0.23668683889285475,
                                    0.3786958335807245,
                                    0.147930488633566,
                                    0.23668683889285475,
                                ],
                                [
                                    0.04645995874345646,
                                    0.07433532378386273,
                                    0.3381573687829643,
                                    0.5410473486897165,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.22974740827586979,
                                    0.3675928357361154,
                                    0.15486991925055096,
                                    0.24778983673746388,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.03151075884539815,
                                    0.021741885583182873,
                                    0.5602111956888659,
                                    0.38653615988255313,
                                ],
                                [
                                    0.48668379242875587,
                                    0.33580350705266665,
                                    0.1050381621055081,
                                    0.07247453841306935,
                                ],
                                [
                                    0.036438107120927384,
                                    0.025141671762902103,
                                    0.5552838474133366,
                                    0.3831363737028339,
                                ],
                                [
                                    0.04736929996793283,
                                    0.014210478915896657,
                                    0.7218653550849087,
                                    0.21655486603126184,
                                ],
                                [
                                    0.47025893863660695,
                                    0.32447063837687584,
                                    0.12146301589765711,
                                    0.08380740708886016,
                                ],
                                [
                                    0.6113335320342571,
                                    0.18339604497922574,
                                    0.15790112301858447,
                                    0.04736929996793279,
                                ],
                                [
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                    0.7252132901931454,
                                    0.2639614896993748,
                                ],
                                [
                                    0.7066941925608805,
                                    0.25722095051593136,
                                    0.026455605568772834,
                                    0.009629251354415343,
                                ],
                                [
                                    0.015500713674359833,
                                    0.005641914631484181,
                                    0.7176490844552935,
                                    0.2612082872388625,
                                ],
                                [
                                    0.02015082598338609,
                                    0.000991802322457926,
                                    0.9329390969859458,
                                    0.045918274708210145,
                                ],
                                [
                                    0.6814796214872317,
                                    0.2480434080842993,
                                    0.05167017664242155,
                                    0.018806793786047393,
                                ],
                                [
                                    0.8859190326525506,
                                    0.04360399691898048,
                                    0.06717089031678135,
                                    0.003306080111687594,
                                ],
                                [
                                    0.0016133366937802012,
                                    0.04309618500986464,
                                    0.03447152022940799,
                                    0.9208189580669471,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.08831351862262532,
                                    0.0327787768115006,
                                    0.8756016244541865,
                                ],
                                [
                                    0.001617061669325762,
                                    0.043195688254220016,
                                    0.03446779525386243,
                                    0.9207194548225918,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.003230398363105963,
                                    0.08629187326408466,
                                    0.03285445856008223,
                                    0.8776232698127272,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.006405520400261619,
                                    0.02967933652292657,
                                    0.17110718011831574,
                                    0.7928079629584961,
                                ],
                                [
                                    0.047369299967932765,
                                    0.21948090190241393,
                                    0.1301434005506446,
                                    0.6030063975790088,
                                ],
                                [
                                    0.00649566346360425,
                                    0.030097005368699692,
                                    0.17101703705497312,
                                    0.7923902941127229,
                                ],
                                [
                                    0.008444319845623756,
                                    0.02814834898668019,
                                    0.22232102510153476,
                                    0.7410863060661613,
                                ],
                                [
                                    0.04553782897628864,
                                    0.21099496469569393,
                                    0.13197487154228874,
                                    0.6114923347857287,
                                ],
                                [
                                    0.059198878621973296,
                                    0.19733391505000927,
                                    0.1715664663251852,
                                    0.5719007400028322,
                                ],
                                [
                                    0.009021214230797044,
                                    0.014433824284536993,
                                    0.3755961132956237,
                                    0.6009488481890423,
                                ],
                                [
                                    0.20132987799400742,
                                    0.3221251605213266,
                                    0.18328744953241333,
                                    0.29325751195225264,
                                ],
                                [
                                    0.009444400085273898,
                                    0.015110916093571757,
                                    0.37517292744114683,
                                    0.6002717563800075,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.19273184961768722,
                                    0.30836842804582437,
                                    0.19188547790873353,
                                    0.3070142444277549,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.006405520400261612,
                                    0.004419699707218271,
                                    0.5853164341340024,
                                    0.4038583457585177,
                                ],
                                [
                                    0.46157855398361936,
                                    0.318481321176702,
                                    0.13014340055064466,
                                    0.08979672428903396,
                                ],
                                [
                                    0.007407153844030838,
                                    0.005110809681356528,
                                    0.5843148006902332,
                                    0.40316723578437946,
                                ],
                                [
                                    0.009629251354415402,
                                    0.002888712170971964,
                                    0.7596054036984261,
                                    0.22787663277618653,
                                ],
                                [
                                    0.4412279853597104,
                                    0.30443977629533026,
                                    0.15049396917455365,
                                    0.10383826917040573,
                                ],
                                [
                                    0.5735934834207397,
                                    0.17207427823430102,
                                    0.1956411716321019,
                                    0.05869106671285748,
                                ],
                                [
                                    0.0016133366937802177,
                                    0.000587218633243017,
                                    0.7315364614358731,
                                    0.2662629832371037,
                                ],
                                [
                                    0.7003710213181528,
                                    0.2549194569782024,
                                    0.032778776811500585,
                                    0.011930744892144277,
                                ],
                                [
                                    0.0031509916389787767,
                                    0.0011468907951667513,
                                    0.7299988064906745,
                                    0.2657033110751799,
                                ],
                                [
                                    0.004096268438091006,
                                    0.0002016139960545219,
                                    0.948993654531241,
                                    0.046708463034613554,
                                ],
                                [
                                    0.6691298994518508,
                                    0.2435483842479819,
                                    0.06401989867780258,
                                    0.023301817622364815,
                                ],
                                [
                                    0.8698644751072555,
                                    0.04281380859257708,
                                    0.0832254478620764,
                                    0.004096268438090997,
                                ],
                                [
                                    0.04061325326555385,
                                    0.8677671480001333,
                                    0.004096268438090991,
                                    0.08752333029622184,
                                ],
                                [
                                    0.04271058037267615,
                                    0.912579897923679,
                                    0.0019989413309686875,
                                    0.042710580372676124,
                                ],
                                [
                                    0.04070702375736938,
                                    0.8697707046154401,
                                    0.004002497946275464,
                                    0.08551977368091507,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991899,
                                    0.08532277496919864,
                                ],
                                [
                                    0.042705965088338065,
                                    0.9124812849881163,
                                    0.0020035566153067757,
                                    0.042809193308238944,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.16124905812682114,
                                    0.5719007400028323,
                                    0.05869106671285747,
                                    0.2081591351574891,
                                ],
                                [
                                    0.21200361690317066,
                                    0.7519115261736411,
                                    0.00793650793650794,
                                    0.028148348986680196,
                                ],
                                [
                                    0.16351827017399126,
                                    0.5799489361540262,
                                    0.05642185466568735,
                                    0.20011093900629515,
                                ],
                                [
                                    0.1715664663251852,
                                    0.5719007400028322,
                                    0.05919887862197328,
                                    0.19733391505000922,
                                ],
                                [
                                    0.21189192868848467,
                                    0.7515154024792113,
                                    0.008048196151193949,
                                    0.028544472681110006,
                                ],
                                [
                                    0.22232102510153476,
                                    0.7410863060661613,
                                    0.008444319845623759,
                                    0.0281483489866802,
                                ],
                                [
                                    0.22709510031642177,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.27400517734708985,
                                ],
                                [
                                    0.46536758105875475,
                                    0.5111773804259112,
                                    0.011177380425911203,
                                    0.012277658089422806,
                                ],
                                [
                                    0.2377481489655524,
                                    0.261151573370936,
                                    0.23879681251911355,
                                    0.26230346514439806,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.4648432492819742,
                                    0.5106014345391802,
                                    0.011701712202691778,
                                    0.012853603976153835,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    0.16124905812682114,
                                    0.058691066712857495,
                                    0.5719007400028322,
                                    0.2081591351574892,
                                ],
                                [
                                    0.7252132901931454,
                                    0.2639614896993748,
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                ],
                                [
                                    0.18646362920046988,
                                    0.06786860914448956,
                                    0.5466861689291834,
                                    0.19898159272585714,
                                ],
                                [
                                    0.19564117163210193,
                                    0.058691066712857495,
                                    0.5735934834207396,
                                    0.172074278234301,
                                ],
                                [
                                    0.7239722556980213,
                                    0.2635097807765915,
                                    0.009177542431632043,
                                    0.0033404210937552307,
                                ],
                                [
                                    0.7596054036984262,
                                    0.22787663277618656,
                                    0.00962925135441533,
                                    0.0028887121709719426,
                                ],
                                [
                                    0.040613253265553845,
                                    0.004096268438090994,
                                    0.8677671480001332,
                                    0.08752333029622192,
                                ],
                                [
                                    0.9063814599347184,
                                    0.09141798473825839,
                                    0.0019989413309686884,
                                    0.00020161399605452118,
                                ],
                                [
                                    0.07932133569195454,
                                    0.008000380608212848,
                                    0.8290590655737325,
                                    0.08361921812610007,
                                ],
                                [
                                    0.08322544786207639,
                                    0.004096268438090996,
                                    0.8698644751072555,
                                    0.04281380859257708,
                                ],
                                [
                                    0.9044762890955652,
                                    0.09122582847028925,
                                    0.0039041121701218493,
                                    0.000393770264023664,
                                ],
                                [
                                    0.948993654531241,
                                    0.046708463034613554,
                                    0.0040962684380909916,
                                    0.00020161399605452123,
                                ],
                                [
                                    0.03277877681150057,
                                    0.7003710213181529,
                                    0.011930744892144267,
                                    0.25491945697820234,
                                ],
                                [
                                    0.03487610391862287,
                                    0.7451837712416985,
                                    0.009833417785021965,
                                    0.2101067070546566,
                                ],
                                [
                                    0.032854458560082206,
                                    0.7019880829874786,
                                    0.011855063143562635,
                                    0.25330239530887655,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.03485339989105089,
                                    0.7446986633601548,
                                    0.009856121812593946,
                                    0.2105918149362004,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.1301434005506447,
                                    0.46157855398361947,
                                    0.08979672428903393,
                                    0.3184813211767019,
                                ],
                                [
                                    0.18089795932699423,
                                    0.6415893401544284,
                                    0.0390421655126844,
                                    0.13847053500589301,
                                ],
                                [
                                    0.1319748715422888,
                                    0.46807421744722366,
                                    0.08796525329738981,
                                    0.3119856577130977,
                                ],
                                [
                                    0.13847053500589307,
                                    0.4615785539836194,
                                    0.09229480994126545,
                                    0.3076561010692221,
                                ],
                                [
                                    0.18034853005678222,
                                    0.6396406837724089,
                                    0.03959159478289641,
                                    0.1404191913879125,
                                ],
                                [
                                    0.1892250937822426,
                                    0.6307641200469485,
                                    0.041540251164915915,
                                    0.13847053500589301,
                                ],
                                [
                                    0.18328744953241333,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.3221251605213266,
                                ],
                                [
                                    0.4215599302747463,
                                    0.46305739725167444,
                                    0.05498503120991964,
                                    0.06039764126365958,
                                ],
                                [
                                    0.19188547790873353,
                                    0.2107742780792813,
                                    0.28465948357593246,
                                    0.3126807604360527,
                                ],
                                [
                                    0.20132987799400742,
                                    0.20132987799400742,
                                    0.2986701220059926,
                                    0.2986701220059926,
                                ],
                                [
                                    0.4189805782251553,
                                    0.46022413924752553,
                                    0.05756438325951065,
                                    0.0632308992678085,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.1301434005506447,
                                    0.0473692999679328,
                                    0.6030063975790086,
                                    0.2194809019024139,
                                ],
                                [
                                    0.694107632616969,
                                    0.25263972295445003,
                                    0.0390421655126844,
                                    0.014210478915896644,
                                ],
                                [
                                    0.1504939691745537,
                                    0.0547764538119636,
                                    0.5826558289550996,
                                    0.21207374805838308,
                                ],
                                [
                                    0.15790112301858453,
                                    0.0473692999679328,
                                    0.611333532034257,
                                    0.1833960449792257,
                                ],
                                [
                                    0.6880025956721051,
                                    0.25041762544406554,
                                    0.045147202457548226,
                                    0.016432576426281195,
                                ],
                                [
                                    0.7218653550849088,
                                    0.21655486603126187,
                                    0.04736929996793278,
                                    0.014210478915896644,
                                ],
                                [
                                    0.0327787768115006,
                                    0.0033060801116875952,
                                    0.8756016244541865,
                                    0.08831351862262532,
                                ],
                                [
                                    0.8985469834806651,
                                    0.09062779641185499,
                                    0.00983341778502197,
                                    0.0009918023224579236,
                                ],
                                [
                                    0.06401989867780254,
                                    0.006457071750666358,
                                    0.8443605025878845,
                                    0.08516252698364656,
                                ],
                                [
                                    0.0671708903167813,
                                    0.0033060801116875918,
                                    0.8859190326525506,
                                    0.04360399691898048,
                                ],
                                [
                                    0.8891748520814132,
                                    0.08968251961274276,
                                    0.01920554918427381,
                                    0.0019370791215701498,
                                ],
                                [
                                    0.9329390969859458,
                                    0.045918274708210145,
                                    0.020150825983386036,
                                    0.0009918023224579234,
                                ],
                                [
                                    0.021306097298261266,
                                    0.4552388641864047,
                                    0.023403424405383573,
                                    0.5000516141099505,
                                ],
                                [
                                    0.023403424405383573,
                                    0.5000516141099505,
                                    0.021306097298261266,
                                    0.4552388641864047,
                                ],
                                [
                                    0.021355290186338076,
                                    0.4562899489618395,
                                    0.023354231517306763,
                                    0.49900052933451566,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.023354231517306763,
                                    0.49900052933451566,
                                    0.021355290186338076,
                                    0.4562899489618395,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.08459278303166456,
                                    0.3000245444947563,
                                    0.13534734180801405,
                                    0.4800353306655651,
                                ],
                                [
                                    0.13534734180801408,
                                    0.4800353306655652,
                                    0.08459278303166454,
                                    0.3000245444947562,
                                ],
                                [
                                    0.08578323316259262,
                                    0.3042467044175682,
                                    0.134156891677086,
                                    0.4758131707427532,
                                ],
                                [
                                    0.0900053930854045,
                                    0.3000245444947563,
                                    0.140759951861754,
                                    0.4692101105580852,
                                ],
                                [
                                    0.13415689167708603,
                                    0.4758131707427533,
                                    0.0857832331625926,
                                    0.30424670441756807,
                                ],
                                [
                                    0.14075995186175402,
                                    0.4692101105580853,
                                    0.09000539308540448,
                                    0.3000245444947562,
                                ],
                                [
                                    0.11913624037116649,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.3925912788865005,
                                ],
                                [
                                    0.3574087211134995,
                                    0.3925912788865005,
                                    0.11913624037116649,
                                    0.1308637596288335,
                                ],
                                [
                                    0.1247249305841221,
                                    0.13700258867354492,
                                    0.35182003090054387,
                                    0.3864524498417891,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.35182003090054387,
                                    0.3864524498417891,
                                    0.1247249305841221,
                                    0.13700258867354492,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.08459278303166454,
                                    0.030789889441914717,
                                    0.6485570150979888,
                                    0.23606031242843198,
                                ],
                                [
                                    0.6485570150979888,
                                    0.23606031242843198,
                                    0.08459278303166454,
                                    0.030789889441914717,
                                ],
                                [
                                    0.09782058581605095,
                                    0.03560451511912239,
                                    0.6353292123136024,
                                    0.2312456867512243,
                                ],
                                [
                                    0.10263521149325863,
                                    0.030789889441914717,
                                    0.6665994435595829,
                                    0.1999754555052438,
                                ],
                                [
                                    0.6353292123136024,
                                    0.2312456867512243,
                                    0.09782058581605095,
                                    0.03560451511912239,
                                ],
                                [
                                    0.6665994435595829,
                                    0.1999754555052438,
                                    0.10263521149325863,
                                    0.030789889441914717,
                                ],
                                [
                                    0.021306097298261276,
                                    0.0021489412170727588,
                                    0.8870743039674258,
                                    0.08947065751724015,
                                ],
                                [
                                    0.8870743039674258,
                                    0.08947065751724015,
                                    0.021306097298261276,
                                    0.0021489412170727588,
                                ],
                                [
                                    0.0416127239310382,
                                    0.004197075436118256,
                                    0.8667676773346489,
                                    0.08742252329819465,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727588,
                                    0.9094290648192482,
                                    0.04476113581359532,
                                ],
                                [
                                    0.8667676773346489,
                                    0.08742252329819465,
                                    0.0416127239310382,
                                    0.004197075436118256,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359532,
                                    0.0436608581500837,
                                    0.0021489412170727588,
                                ],
                                [
                                    0.009833417785021966,
                                    0.21010670705465664,
                                    0.03487610391862287,
                                    0.7451837712416985,
                                ],
                                [
                                    0.011930744892144272,
                                    0.2549194569782024,
                                    0.032778776811500564,
                                    0.7003710213181528,
                                ],
                                [
                                    0.009856121812593951,
                                    0.21059181493620052,
                                    0.034853399891050886,
                                    0.7446986633601547,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.01185506314356264,
                                    0.25330239530887666,
                                    0.0328544585600822,
                                    0.7019880829874785,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.03904216551268441,
                                    0.13847053500589307,
                                    0.1808979593269942,
                                    0.6415893401544284,
                                ],
                                [
                                    0.08979672428903396,
                                    0.318481321176702,
                                    0.13014340055064466,
                                    0.46157855398361936,
                                ],
                                [
                                    0.03959159478289645,
                                    0.14041919138791267,
                                    0.18034853005678217,
                                    0.6396406837724087,
                                ],
                                [
                                    0.041540251164915956,
                                    0.13847053500589315,
                                    0.18922509378224253,
                                    0.6307641200469484,
                                ],
                                [
                                    0.08796525329738984,
                                    0.3119856577130978,
                                    0.13197487154228876,
                                    0.4680742174472236,
                                ],
                                [
                                    0.09229480994126547,
                                    0.30765610106922214,
                                    0.13847053500589304,
                                    0.46157855398361936,
                                ],
                                [
                                    0.054985031209919655,
                                    0.060397641263659596,
                                    0.4215599302747463,
                                    0.46305739725167444,
                                ],
                                [
                                    0.29325751195225264,
                                    0.3221251605213266,
                                    0.18328744953241333,
                                    0.20132987799400742,
                                ],
                                [
                                    0.05756438325951067,
                                    0.06323089926780852,
                                    0.4189805782251553,
                                    0.46022413924752553,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.28465948357593246,
                                    0.3126807604360527,
                                    0.19188547790873353,
                                    0.2107742780792813,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.039042165512684385,
                                    0.014210478915896638,
                                    0.694107632616969,
                                    0.25263972295445003,
                                ],
                                [
                                    0.6030063975790086,
                                    0.2194809019024139,
                                    0.13014340055064466,
                                    0.04736929996793279,
                                ],
                                [
                                    0.045147202457548274,
                                    0.01643257642628121,
                                    0.6880025956721051,
                                    0.2504176254440655,
                                ],
                                [
                                    0.04736929996793283,
                                    0.014210478915896657,
                                    0.7218653550849087,
                                    0.21655486603126184,
                                ],
                                [
                                    0.5826558289550997,
                                    0.2120737480583831,
                                    0.15049396917455368,
                                    0.05477645381196359,
                                ],
                                [
                                    0.6113335320342571,
                                    0.18339604497922574,
                                    0.15790112301858447,
                                    0.04736929996793279,
                                ],
                                [
                                    0.00983341778502196,
                                    0.0009918023224579225,
                                    0.8985469834806651,
                                    0.09062779641185499,
                                ],
                                [
                                    0.8756016244541865,
                                    0.08831351862262532,
                                    0.032778776811500585,
                                    0.003306080111687594,
                                ],
                                [
                                    0.01920554918427386,
                                    0.0019370791215701545,
                                    0.8891748520814132,
                                    0.08968251961274276,
                                ],
                                [
                                    0.02015082598338609,
                                    0.000991802322457926,
                                    0.9329390969859458,
                                    0.045918274708210145,
                                ],
                                [
                                    0.8443605025878845,
                                    0.08516252698364656,
                                    0.06401989867780258,
                                    0.0064570717506663615,
                                ],
                                [
                                    0.8859190326525506,
                                    0.04360399691898048,
                                    0.06717089031678135,
                                    0.003306080111687594,
                                ],
                                [
                                    0.001998941330968689,
                                    0.04271058037267615,
                                    0.04271058037267615,
                                    0.912579897923679,
                                ],
                                [
                                    0.004096268438090994,
                                    0.08752333029622192,
                                    0.040613253265553845,
                                    0.8677671480001332,
                                ],
                                [
                                    0.0020035566153067787,
                                    0.042809193308239,
                                    0.04270596508833806,
                                    0.9124812849881162,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.0040024979462754675,
                                    0.08551977368091515,
                                    0.04070702375736937,
                                    0.86977070461544,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.007936507936507952,
                                    0.028148348986680238,
                                    0.21200361690317066,
                                    0.7519115261736411,
                                ],
                                [
                                    0.058691066712857495,
                                    0.2081591351574892,
                                    0.16124905812682114,
                                    0.5719007400028322,
                                ],
                                [
                                    0.008048196151193947,
                                    0.028544472681109996,
                                    0.21189192868848467,
                                    0.7515154024792113,
                                ],
                                [
                                    0.008444319845623756,
                                    0.02814834898668019,
                                    0.22232102510153476,
                                    0.7410863060661613,
                                ],
                                [
                                    0.05642185466568736,
                                    0.2001109390062952,
                                    0.16351827017399126,
                                    0.5799489361540262,
                                ],
                                [
                                    0.059198878621973296,
                                    0.19733391505000927,
                                    0.1715664663251852,
                                    0.5719007400028322,
                                ],
                                [
                                    0.011177380425911215,
                                    0.012277658089422822,
                                    0.46536758105875475,
                                    0.5111773804259112,
                                ],
                                [
                                    0.2494498611682442,
                                    0.27400517734708985,
                                    0.22709510031642177,
                                    0.2494498611682442,
                                ],
                                [
                                    0.011701712202691797,
                                    0.012853603976153857,
                                    0.4648432492819742,
                                    0.5106014345391802,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.23879681251911355,
                                    0.26230346514439806,
                                    0.2377481489655524,
                                    0.261151573370936,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.00793650793650794,
                                    0.0028887121709719426,
                                    0.7252132901931454,
                                    0.2639614896993748,
                                ],
                                [
                                    0.5719007400028322,
                                    0.2081591351574892,
                                    0.16124905812682114,
                                    0.058691066712857495,
                                ],
                                [
                                    0.00917754243163211,
                                    0.0033404210937552554,
                                    0.7239722556980211,
                                    0.26350978077659143,
                                ],
                                [
                                    0.009629251354415402,
                                    0.002888712170971964,
                                    0.7596054036984261,
                                    0.22787663277618653,
                                ],
                                [
                                    0.5466861689291835,
                                    0.19898159272585716,
                                    0.18646362920046985,
                                    0.06786860914448954,
                                ],
                                [
                                    0.5735934834207397,
                                    0.17207427823430102,
                                    0.1956411716321019,
                                    0.05869106671285748,
                                ],
                                [
                                    0.0019989413309687114,
                                    0.00020161399605452348,
                                    0.9063814599347184,
                                    0.09141798473825839,
                                ],
                                [
                                    0.8677671480001332,
                                    0.08752333029622192,
                                    0.040613253265553866,
                                    0.004096268438090996,
                                ],
                                [
                                    0.0039041121701218627,
                                    0.00039377026402366534,
                                    0.9044762890955652,
                                    0.09122582847028925,
                                ],
                                [
                                    0.004096268438091006,
                                    0.0002016139960545219,
                                    0.948993654531241,
                                    0.046708463034613554,
                                ],
                                [
                                    0.8290590655737325,
                                    0.08361921812610007,
                                    0.07932133569195456,
                                    0.008000380608212848,
                                ],
                                [
                                    0.8698644751072555,
                                    0.04281380859257708,
                                    0.0832254478620764,
                                    0.004096268438090997,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9063814599347185,
                                    0.0019989413309686862,
                                    0.09141798473825831,
                                    0.00020161399605452077,
                                ],
                                [
                                    0.9084787870418407,
                                    0.0447143641473921,
                                    0.04461113592749119,
                                    0.002195712883275917,
                                ],
                                [
                                    0.9510955969227013,
                                    0.0020975542665315036,
                                    0.046703847750275404,
                                    0.00010300106049170343,
                                ],
                                [
                                    0.9063814599347184,
                                    0.04461113592749119,
                                    0.04670846303461349,
                                    0.002298941103176822,
                                ],
                                [
                                    0.9488998840394254,
                                    0.0020927118227842133,
                                    0.048899560633551324,
                                    0.00010784350423899364,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7335404246483938,
                                    0.22005731023005395,
                                    0.035694230404447705,
                                    0.010708034717104494,
                                ],
                                [
                                    0.9432748295043943,
                                    0.01032290537405344,
                                    0.04589995038812576,
                                    0.0005023147334264392,
                                ],
                                [
                                    0.7252132901931454,
                                    0.21755922457782245,
                                    0.04402136485969607,
                                    0.013206120369336003,
                                ],
                                [
                                    0.9325667947872899,
                                    0.010205719983678052,
                                    0.056607985105230255,
                                    0.0006195001238018258,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.9318096327260459,
                                    0.02238056790679763,
                                    0.04473532875862004,
                                    0.0010744706085363772,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.9089047330424678,
                                    0.021830429075041832,
                                    0.06764022844219825,
                                    0.001624609440292179,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.22033075135841906,
                                    0.7344519150288203,
                                    0.01043459358873945,
                                    0.03478274002402117,
                                ],
                                [
                                    0.9203294704779158,
                                    0.0344531959093236,
                                    0.04358567259889609,
                                    0.0016316610138645327,
                                ],
                                [
                                    0.21200361690317068,
                                    0.7066941925608805,
                                    0.01876172804398782,
                                    0.06254046249196094,
                                ],
                                [
                                    0.8855467304538945,
                                    0.033151079010156646,
                                    0.07836841262291726,
                                    0.0029337779130314914,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.9124812849881163,
                                    0.04270596508833804,
                                    0.042809193308238944,
                                    0.002003556615306775,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991899,
                                    0.08532277496919864,
                                ],
                                [
                                    0.8697707046154401,
                                    0.04070702375736935,
                                    0.08551977368091507,
                                    0.0040024979462754615,
                                ],
                                [
                                    0.7783433102466403,
                                    0.001716564913681103,
                                    0.21945613442633646,
                                    0.0004839904133421038,
                                ],
                                [
                                    0.7315364614358733,
                                    0.0016133366937801977,
                                    0.26626298323710357,
                                    0.0005872186332430093,
                                ],
                                [
                                    0.7336337885429954,
                                    0.03610867841896185,
                                    0.21945613442633644,
                                    0.010801398611706165,
                                ],
                                [
                                    0.7680486060758482,
                                    0.0016938608861091203,
                                    0.22975083859712853,
                                    0.0005066944409140867,
                                ],
                                [
                                    0.7315364614358733,
                                    0.03600545019906095,
                                    0.22155346153345873,
                                    0.01090462683160707,
                                ],
                                [
                                    0.7658528931925724,
                                    0.0016890184423618301,
                                    0.23194655148040444,
                                    0.000511536884661377,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.5853164341340025,
                                    0.006405520400261611,
                                    0.4038583457585176,
                                    0.004419699707218268,
                                ],
                                [
                                    0.5936435685892508,
                                    0.17808917211582218,
                                    0.17559108646359065,
                                    0.05267617283133628,
                                ],
                                [
                                    0.7633785639227919,
                                    0.008354176782281113,
                                    0.22579621596972818,
                                    0.0024710433251987664,
                                ],
                                [
                                    0.5853164341340025,
                                    0.17559108646359065,
                                    0.18391822091883903,
                                    0.05517425848356779,
                                ],
                                [
                                    0.7526705292056874,
                                    0.008236991391905726,
                                    0.23650425068683267,
                                    0.002588228715574153,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.3755961132956237,
                                    0.009021214230797034,
                                    0.6009488481890423,
                                    0.014433824284536975,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.7564778836677084,
                                    0.018169381438873023,
                                    0.2200670778169575,
                                    0.005285657076460985,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.7335729839841303,
                                    0.01761924260711722,
                                    0.24297197750053573,
                                    0.005835795908216787,
                                ],
                                [
                                    0.9125841127032176,
                                    0.034163242868201375,
                                    0.05133103037359428,
                                    0.0019216140549867587,
                                ],
                                [
                                    0.17110718011831585,
                                    0.0064055204002616125,
                                    0.792807962958496,
                                    0.029679336522926522,
                                ],
                                [
                                    0.17943431457356424,
                                    0.5981274749345258,
                                    0.05133103037359428,
                                    0.1711071801183158,
                                ],
                                [
                                    0.7495035835847523,
                                    0.028058205923337555,
                                    0.21441155949205948,
                                    0.00802665099985058,
                                ],
                                [
                                    0.17110718011831585,
                                    0.5703697524665859,
                                    0.059658164828842654,
                                    0.19886490258625558,
                                ],
                                [
                                    0.7147208435607312,
                                    0.026756089024170596,
                                    0.2491942995160807,
                                    0.009328767899017541,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137788,
                                    0.0004839904133421045,
                                ],
                                [
                                    0.03447152022940799,
                                    0.0016133366937802001,
                                    0.9208189580669471,
                                    0.04309618500986461,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.7446986633601548,
                                    0.03485339989105087,
                                    0.2105918149362004,
                                    0.00985612181259394,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.7019880829874786,
                                    0.032854458560082185,
                                    0.25330239530887655,
                                    0.011855063143562628,
                                ],
                                [
                                    0.522303146741872,
                                    0.0011518917734620563,
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                ],
                                [
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                    0.522303146741872,
                                    0.0011518917734620563,
                                ],
                                [
                                    0.4775936250382271,
                                    0.023506652625284463,
                                    0.4754962979311048,
                                    0.023403424405383556,
                                ],
                                [
                                    0.49999757877812634,
                                    0.0011026988853852487,
                                    0.4978018658948504,
                                    0.0010978564416379583,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383556,
                                    0.4775936250382271,
                                    0.023506652625284463,
                                ],
                                [
                                    0.4978018658948504,
                                    0.0010978564416379583,
                                    0.49999757877812634,
                                    0.0011026988853852487,
                                ],
                                [
                                    0.6087210195937236,
                                    0.006661652879855695,
                                    0.3804537602987966,
                                    0.004163567227624184,
                                ],
                                [
                                    0.3804537602987967,
                                    0.004163567227624185,
                                    0.6087210195937235,
                                    0.006661652879855694,
                                ],
                                [
                                    0.3887808947540449,
                                    0.11663171529969497,
                                    0.3804537602987966,
                                    0.11413362964746347,
                                ],
                                [
                                    0.4999414073048123,
                                    0.005471202748927633,
                                    0.4892333725877078,
                                    0.005354017358552246,
                                ],
                                [
                                    0.3804537602987966,
                                    0.11413362964746347,
                                    0.3887808947540449,
                                    0.11663171529969497,
                                ],
                                [
                                    0.4892333725877078,
                                    0.005354017358552246,
                                    0.4999414073048123,
                                    0.005471202748927633,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.2441362403711665,
                                    0.005863759628833502,
                                    0.7324087211134995,
                                    0.017591278886500507,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.4997249305841221,
                                    0.012002588673544905,
                                    0.47682003090054387,
                                    0.011452449841789104,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.47682003090054387,
                                    0.011452449841789104,
                                    0.4997249305841221,
                                    0.012002588673544905,
                                ],
                                [
                                    0.8526960378308568,
                                    0.03192128969556395,
                                    0.11121910524595506,
                                    0.004163567227624185,
                                ],
                                [
                                    0.11121910524595506,
                                    0.004163567227624185,
                                    0.8526960378308568,
                                    0.03192128969556395,
                                ],
                                [
                                    0.11954623970120344,
                                    0.39849618876039067,
                                    0.11121910524595506,
                                    0.37073846629245083,
                                ],
                                [
                                    0.49934894155041654,
                                    0.01869348691117755,
                                    0.4645662015263953,
                                    0.017391370012010587,
                                ],
                                [
                                    0.11121910524595506,
                                    0.37073846629245083,
                                    0.11954623970120344,
                                    0.39849618876039067,
                                ],
                                [
                                    0.4645662015263953,
                                    0.017391370012010587,
                                    0.49934894155041654,
                                    0.01869348691117755,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.022406374961772883,
                                    0.001048663553561152,
                                ],
                                [
                                    0.022406374961772883,
                                    0.001048663553561152,
                                    0.9328841033345823,
                                    0.04366085815008366,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.49900052933451566,
                                    0.02335423151730675,
                                    0.4562899489618395,
                                    0.021355290186338062,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.4562899489618395,
                                    0.021355290186338062,
                                    0.49900052933451566,
                                    0.02335423151730675,
                                ],
                                [
                                    0.2662629832371037,
                                    0.0005872186332430096,
                                    0.7315364614358731,
                                    0.0016133366937801975,
                                ],
                                [
                                    0.21945613442633652,
                                    0.00048399041334210393,
                                    0.7783433102466403,
                                    0.001716564913681103,
                                ],
                                [
                                    0.22155346153345878,
                                    0.010904626831607074,
                                    0.7315364614358731,
                                    0.03600545019906094,
                                ],
                                [
                                    0.2319465514804045,
                                    0.0005115368846613771,
                                    0.7658528931925723,
                                    0.00168901844236183,
                                ],
                                [
                                    0.21945613442633646,
                                    0.010801398611706167,
                                    0.7336337885429954,
                                    0.03610867841896185,
                                ],
                                [
                                    0.22975083859712855,
                                    0.0005066944409140868,
                                    0.7680486060758482,
                                    0.0016938608861091203,
                                ],
                                [
                                    0.4038583457585177,
                                    0.004419699707218269,
                                    0.5853164341340024,
                                    0.00640552040026161,
                                ],
                                [
                                    0.17559108646359073,
                                    0.001921614054986759,
                                    0.8135836934289294,
                                    0.00890360605249312,
                                ],
                                [
                                    0.18391822091883905,
                                    0.055174258483567794,
                                    0.5853164341340025,
                                    0.17559108646359065,
                                ],
                                [
                                    0.2365042506868327,
                                    0.0025882287155741535,
                                    0.7526705292056874,
                                    0.008236991391905726,
                                ],
                                [
                                    0.17559108646359067,
                                    0.052676172831336285,
                                    0.5936435685892508,
                                    0.17808917211582218,
                                ],
                                [
                                    0.2257962159697282,
                                    0.002471043325198767,
                                    0.7633785639227919,
                                    0.008354176782281113,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.11267636744670928,
                                    0.0027063050268699707,
                                    0.8638685940379567,
                                    0.02074873348846404,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.2429719775005358,
                                    0.005835795908216789,
                                    0.7335729839841302,
                                    0.01761924260711722,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.22006707781695756,
                                    0.005285657076460987,
                                    0.7564778836677084,
                                    0.018169381438873023,
                                ],
                                [
                                    0.792807962958496,
                                    0.029679336522926522,
                                    0.17110718011831583,
                                    0.006405520400261612,
                                ],
                                [
                                    0.05133103037359426,
                                    0.0019216140549867579,
                                    0.9125841127032176,
                                    0.034163242868201375,
                                ],
                                [
                                    0.05965816482884268,
                                    0.19886490258625567,
                                    0.17110718011831583,
                                    0.5703697524665858,
                                ],
                                [
                                    0.24919429951608077,
                                    0.009328767899017544,
                                    0.7147208435607311,
                                    0.02675608902417059,
                                ],
                                [
                                    0.05133103037359432,
                                    0.17110718011831594,
                                    0.17943431457356418,
                                    0.5981274749345256,
                                ],
                                [
                                    0.21441155949205967,
                                    0.008026650999850587,
                                    0.7495035835847521,
                                    0.028058205923337548,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.03447152022940798,
                                    0.0016133366937801995,
                                ],
                                [
                                    0.010341229694137779,
                                    0.00048399041334210404,
                                    0.9449492486022174,
                                    0.044225531290302704,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.25330239530887666,
                                    0.011855063143562633,
                                    0.7019880829874785,
                                    0.03285445856008218,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.21059181493620052,
                                    0.009856121812593946,
                                    0.7446986633601547,
                                    0.034853399891050865,
                                ],
                                [
                                    0.09141798473825839,
                                    0.00020161399605452096,
                                    0.9063814599347184,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.04461113592749122,
                                    9.838577615361534e-05,
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.04670846303461354,
                                    0.002298941103176825,
                                    0.9063814599347184,
                                    0.04461113592749119,
                                ],
                                [
                                    0.04889956063355137,
                                    0.00010784350423899374,
                                    0.9488998840394254,
                                    0.0020927118227842133,
                                ],
                                [
                                    0.04461113592749121,
                                    0.002195712883275918,
                                    0.9084787870418407,
                                    0.0447143641473921,
                                ],
                                [
                                    0.046703847750275425,
                                    0.00010300106049170347,
                                    0.9510955969227013,
                                    0.0020975542665315036,
                                ],
                                [
                                    0.2639614896993748,
                                    0.0028887121709719418,
                                    0.7252132901931454,
                                    0.007936507936507938,
                                ],
                                [
                                    0.03569423040444776,
                                    0.00039062651874043134,
                                    0.9534805494880724,
                                    0.010434593588739449,
                                ],
                                [
                                    0.044021364859696085,
                                    0.013206120369336006,
                                    0.7252132901931454,
                                    0.21755922457782245,
                                ],
                                [
                                    0.05660798510523027,
                                    0.000619500123801826,
                                    0.9325667947872899,
                                    0.010205719983678052,
                                ],
                                [
                                    0.03569423040444771,
                                    0.010708034717104496,
                                    0.7335404246483938,
                                    0.22005731023005395,
                                ],
                                [
                                    0.04589995038812577,
                                    0.0005023147334264393,
                                    0.9432748295043943,
                                    0.01032290537405344,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.022904899683578235,
                                    0.0005501388317558024,
                                    0.9536400618010877,
                                    0.022904899683578207,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.06764022844219832,
                                    0.0016246094402921807,
                                    0.9089047330424677,
                                    0.02183042907504183,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.044735328758620074,
                                    0.0010744706085363783,
                                    0.9318096327260459,
                                    0.02238056790679763,
                                ],
                                [
                                    0.7519115261736411,
                                    0.028148348986680196,
                                    0.21200361690317066,
                                    0.00793650793650794,
                                ],
                                [
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                    0.9534805494880724,
                                    0.035694230404447705,
                                ],
                                [
                                    0.01876172804398785,
                                    0.06254046249196105,
                                    0.21200361690317066,
                                    0.7066941925608805,
                                ],
                                [
                                    0.0783684126229174,
                                    0.002933777913031496,
                                    0.8855467304538944,
                                    0.03315107901015664,
                                ],
                                [
                                    0.010434593588739494,
                                    0.03478274002402132,
                                    0.220330751358419,
                                    0.7344519150288202,
                                ],
                                [
                                    0.04358567259889627,
                                    0.0016316610138645397,
                                    0.9203294704779156,
                                    0.034453195909323595,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.04271058037267617,
                                    0.0019989413309686884,
                                ],
                                [
                                    0.0021021695508696182,
                                    9.838577615361652e-05,
                                    0.9531883087454855,
                                    0.04461113592749119,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.08551977368091515,
                                    0.004002497946275465,
                                    0.86977070461544,
                                    0.04070702375736934,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.042809193308239,
                                    0.0020035566153067774,
                                    0.9124812849881162,
                                    0.04270596508833804,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9063814599347185,
                                    0.0019989413309686862,
                                    0.09141798473825831,
                                    0.00020161399605452077,
                                ],
                                [
                                    0.9084787870418407,
                                    0.0447143641473921,
                                    0.04461113592749119,
                                    0.002195712883275917,
                                ],
                                [
                                    0.9428746255226671,
                                    0.010318525666565792,
                                    0.046300154369853026,
                                    0.0005066944409140868,
                                ],
                                [
                                    0.9063814599347184,
                                    0.04461113592749119,
                                    0.04670846303461349,
                                    0.002298941103176822,
                                ],
                                [
                                    0.9406978916914176,
                                    0.010294704170792078,
                                    0.04847688820110252,
                                    0.0005305159366878004,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7335404246483938,
                                    0.22005731023005395,
                                    0.035694230404447705,
                                    0.010708034717104494,
                                ],
                                [
                                    0.9028161337750655,
                                    0.05078160110338226,
                                    0.04393122179635344,
                                    0.002471043325198767,
                                ],
                                [
                                    0.7252132901931454,
                                    0.21755922457782245,
                                    0.04402136485969607,
                                    0.013206120369336003,
                                ],
                                [
                                    0.8925673852648304,
                                    0.05020512950613751,
                                    0.05417997030658856,
                                    0.003047514922443518,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.8440931852357253,
                                    0.11009701539711823,
                                    0.040524142290695425,
                                    0.005285657076460985,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.8233444517472613,
                                    0.10739071037024828,
                                    0.061272875779159464,
                                    0.007991962103330955,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.22033075135841906,
                                    0.7344519150288203,
                                    0.01043459358873945,
                                    0.03478274002402117,
                                ],
                                [
                                    0.7852966168685126,
                                    0.1694860495187268,
                                    0.037190682612910045,
                                    0.00802665099985058,
                                ],
                                [
                                    0.21200361690317068,
                                    0.7066941925608805,
                                    0.01876172804398782,
                                    0.06254046249196094,
                                ],
                                [
                                    0.7556172803455861,
                                    0.1630805291184652,
                                    0.06687001913583657,
                                    0.014432171400112189,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.7451032470493697,
                                    0.21008400302708463,
                                    0.03495662811095177,
                                    0.00985612181259394,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991899,
                                    0.08532277496919864,
                                ],
                                [
                                    0.7102271431307468,
                                    0.20025058524206266,
                                    0.06983273202957463,
                                    0.0196895395976159,
                                ],
                                [
                                    0.7783433102466403,
                                    0.001716564913681103,
                                    0.21945613442633646,
                                    0.0004839904133421038,
                                ],
                                [
                                    0.7315364614358733,
                                    0.0016133366937801977,
                                    0.26626298323710357,
                                    0.0005872186332430093,
                                ],
                                [
                                    0.7336337885429954,
                                    0.03610867841896185,
                                    0.21945613442633644,
                                    0.010801398611706165,
                                ],
                                [
                                    0.7614098353310196,
                                    0.008332631630937747,
                                    0.22776494456150048,
                                    0.0024925884765421313,
                                ],
                                [
                                    0.7315364614358733,
                                    0.03600545019906095,
                                    0.22155346153345873,
                                    0.01090462683160707,
                                ],
                                [
                                    0.7592331014997702,
                                    0.008308810135164034,
                                    0.22994167839274998,
                                    0.002516409972315845,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.5853164341340025,
                                    0.006405520400261611,
                                    0.4038583457585176,
                                    0.004419699707218268,
                                ],
                                [
                                    0.5936435685892508,
                                    0.17808917211582218,
                                    0.17559108646359065,
                                    0.05267617283133628,
                                ],
                                [
                                    0.7306359314704115,
                                    0.04109680923466157,
                                    0.2161114241010075,
                                    0.012155835193919452,
                                ],
                                [
                                    0.5853164341340025,
                                    0.17559108646359065,
                                    0.18391822091883903,
                                    0.05517425848356779,
                                ],
                                [
                                    0.7203871829601763,
                                    0.040520337637416824,
                                    0.22636017261124264,
                                    0.012732306791164204,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.3755961132956237,
                                    0.009021214230797034,
                                    0.6009488481890423,
                                    0.014433824284536975,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.6852663934342348,
                                    0.08938087167234658,
                                    0.19935093409218585,
                                    0.026001800801232634,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.6645176599457708,
                                    0.08667456664547663,
                                    0.2200996675806499,
                                    0.028708105828102605,
                                ],
                                [
                                    0.9125841127032176,
                                    0.034163242868201375,
                                    0.05133103037359428,
                                    0.0019216140549867587,
                                ],
                                [
                                    0.17110718011831585,
                                    0.0064055204002616125,
                                    0.792807962958496,
                                    0.029679336522926522,
                                ],
                                [
                                    0.17943431457356424,
                                    0.5981274749345258,
                                    0.05133103037359428,
                                    0.1711071801183158,
                                ],
                                [
                                    0.6395346964324513,
                                    0.13802709307563868,
                                    0.18295260304897135,
                                    0.03948560744293871,
                                ],
                                [
                                    0.17110718011831585,
                                    0.5703697524665859,
                                    0.059658164828842654,
                                    0.19886490258625558,
                                ],
                                [
                                    0.6098553599095248,
                                    0.13162157267537708,
                                    0.2126319395718979,
                                    0.045891127843200326,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137788,
                                    0.0004839904133421045,
                                ],
                                [
                                    0.03447152022940799,
                                    0.0016133366937802001,
                                    0.9208189580669471,
                                    0.04309618500986461,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.6080972851407064,
                                    0.17145477811049917,
                                    0.17196259001961497,
                                    0.048485346729179396,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.5732211812220835,
                                    0.1616213603254772,
                                    0.20683869393823784,
                                    0.058318764514201364,
                                ],
                                [
                                    0.522303146741872,
                                    0.0011518917734620563,
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                ],
                                [
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                    0.522303146741872,
                                    0.0011518917734620563,
                                ],
                                [
                                    0.4775936250382271,
                                    0.023506652625284463,
                                    0.4754962979311048,
                                    0.023403424405383556,
                                ],
                                [
                                    0.4956757568618848,
                                    0.005424520801626797,
                                    0.4934990230306353,
                                    0.005400699305853083,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383556,
                                    0.4775936250382271,
                                    0.023506652625284463,
                                ],
                                [
                                    0.4934990230306353,
                                    0.005400699305853083,
                                    0.4956757568618848,
                                    0.005424520801626797,
                                ],
                                [
                                    0.6087210195937236,
                                    0.006661652879855695,
                                    0.3804537602987966,
                                    0.004163567227624184,
                                ],
                                [
                                    0.3804537602987967,
                                    0.004163567227624185,
                                    0.6087210195937235,
                                    0.006661652879855694,
                                ],
                                [
                                    0.3887808947540449,
                                    0.11663171529969497,
                                    0.3804537602987966,
                                    0.11413362964746347,
                                ],
                                [
                                    0.47849805204082707,
                                    0.026914558012912888,
                                    0.4682493035305919,
                                    0.02633808641566814,
                                ],
                                [
                                    0.3804537602987966,
                                    0.11413362964746347,
                                    0.3887808947540449,
                                    0.11663171529969497,
                                ],
                                [
                                    0.4682493035305919,
                                    0.02633808641566814,
                                    0.47849805204082707,
                                    0.026914558012912888,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.2441362403711665,
                                    0.005863759628833502,
                                    0.7324087211134995,
                                    0.017591278886500507,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.4526830305074424,
                                    0.0590444887502246,
                                    0.43193429701897834,
                                    0.056338183723354626,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.43193429701897834,
                                    0.056338183723354626,
                                    0.4526830305074424,
                                    0.0590444887502246,
                                ],
                                [
                                    0.8526960378308568,
                                    0.03192128969556395,
                                    0.11121910524595506,
                                    0.004163567227624185,
                                ],
                                [
                                    0.11121910524595506,
                                    0.004163567227624185,
                                    0.8526960378308568,
                                    0.03192128969556395,
                                ],
                                [
                                    0.11954623970120344,
                                    0.39849618876039067,
                                    0.11121910524595506,
                                    0.37073846629245083,
                                ],
                                [
                                    0.4260833180021746,
                                    0.09195911045941951,
                                    0.39640398147924805,
                                    0.08555359005915789,
                                ],
                                [
                                    0.11121910524595506,
                                    0.37073846629245083,
                                    0.11954623970120344,
                                    0.39849618876039067,
                                ],
                                [
                                    0.39640398147924805,
                                    0.08555359005915789,
                                    0.4260833180021746,
                                    0.09195911045941951,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.022406374961772883,
                                    0.001048663553561152,
                                ],
                                [
                                    0.022406374961772883,
                                    0.001048663553561152,
                                    0.9328841033345823,
                                    0.04366085815008366,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.4074679895394721,
                                    0.11488677131235027,
                                    0.3725918856208493,
                                    0.1050533535273283,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.3725918856208493,
                                    0.1050533535273283,
                                    0.4074679895394721,
                                    0.11488677131235027,
                                ],
                                [
                                    0.2662629832371037,
                                    0.0005872186332430096,
                                    0.7315364614358731,
                                    0.0016133366937801975,
                                ],
                                [
                                    0.21945613442633652,
                                    0.00048399041334210393,
                                    0.7783433102466403,
                                    0.001716564913681103,
                                ],
                                [
                                    0.22155346153345878,
                                    0.010904626831607074,
                                    0.7315364614358731,
                                    0.03600545019906094,
                                ],
                                [
                                    0.22994167839275004,
                                    0.0025164099723158457,
                                    0.7592331014997701,
                                    0.008308810135164034,
                                ],
                                [
                                    0.21945613442633646,
                                    0.010801398611706167,
                                    0.7336337885429954,
                                    0.03610867841896185,
                                ],
                                [
                                    0.2277649445615005,
                                    0.0024925884765421317,
                                    0.7614098353310196,
                                    0.008332631630937747,
                                ],
                                [
                                    0.4038583457585177,
                                    0.004419699707218269,
                                    0.5853164341340024,
                                    0.00640552040026161,
                                ],
                                [
                                    0.17559108646359073,
                                    0.001921614054986759,
                                    0.8135836934289294,
                                    0.00890360605249312,
                                ],
                                [
                                    0.18391822091883905,
                                    0.055174258483567794,
                                    0.5853164341340025,
                                    0.17559108646359065,
                                ],
                                [
                                    0.22636017261124264,
                                    0.012732306791164206,
                                    0.7203871829601763,
                                    0.040520337637416824,
                                ],
                                [
                                    0.17559108646359067,
                                    0.052676172831336285,
                                    0.5936435685892508,
                                    0.17808917211582218,
                                ],
                                [
                                    0.21611142410100753,
                                    0.012155835193919454,
                                    0.7306359314704115,
                                    0.04109680923466157,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.11267636744670928,
                                    0.0027063050268699707,
                                    0.8638685940379567,
                                    0.02074873348846404,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.22009966758064997,
                                    0.028708105828102615,
                                    0.6645176599457707,
                                    0.08667456664547661,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.1993509340921859,
                                    0.02600180080123264,
                                    0.6852663934342348,
                                    0.08938087167234658,
                                ],
                                [
                                    0.792807962958496,
                                    0.029679336522926522,
                                    0.17110718011831583,
                                    0.006405520400261612,
                                ],
                                [
                                    0.05133103037359426,
                                    0.0019216140549867579,
                                    0.9125841127032176,
                                    0.034163242868201375,
                                ],
                                [
                                    0.05965816482884268,
                                    0.19886490258625567,
                                    0.17110718011831583,
                                    0.5703697524665858,
                                ],
                                [
                                    0.212631939571898,
                                    0.04589112784320035,
                                    0.6098553599095247,
                                    0.13162157267537705,
                                ],
                                [
                                    0.05133103037359432,
                                    0.17110718011831594,
                                    0.17943431457356418,
                                    0.5981274749345256,
                                ],
                                [
                                    0.1829526030489715,
                                    0.03948560744293875,
                                    0.6395346964324511,
                                    0.13802709307563865,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.03447152022940798,
                                    0.0016133366937801995,
                                ],
                                [
                                    0.010341229694137779,
                                    0.00048399041334210404,
                                    0.9449492486022174,
                                    0.044225531290302704,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.20683869393823792,
                                    0.058318764514201385,
                                    0.5732211812220834,
                                    0.16162136032547716,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.17196259001961506,
                                    0.048485346729179424,
                                    0.6080972851407064,
                                    0.17145477811049914,
                                ],
                                [
                                    0.09141798473825839,
                                    0.00020161399605452096,
                                    0.9063814599347184,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.04461113592749122,
                                    9.838577615361534e-05,
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.04670846303461354,
                                    0.002298941103176825,
                                    0.9063814599347184,
                                    0.04461113592749119,
                                ],
                                [
                                    0.04847688820110257,
                                    0.000530515936687801,
                                    0.9406978916914176,
                                    0.010294704170792078,
                                ],
                                [
                                    0.04461113592749121,
                                    0.002195712883275918,
                                    0.9084787870418407,
                                    0.0447143641473921,
                                ],
                                [
                                    0.04630015436985305,
                                    0.0005066944409140871,
                                    0.9428746255226671,
                                    0.010318525666565792,
                                ],
                                [
                                    0.2639614896993748,
                                    0.0028887121709719418,
                                    0.7252132901931454,
                                    0.007936507936507938,
                                ],
                                [
                                    0.03569423040444776,
                                    0.00039062651874043134,
                                    0.9534805494880724,
                                    0.010434593588739449,
                                ],
                                [
                                    0.044021364859696085,
                                    0.013206120369336006,
                                    0.7252132901931454,
                                    0.21755922457782245,
                                ],
                                [
                                    0.054179970306588575,
                                    0.003047514922443519,
                                    0.8925673852648304,
                                    0.05020512950613751,
                                ],
                                [
                                    0.03569423040444771,
                                    0.010708034717104496,
                                    0.7335404246483938,
                                    0.22005731023005395,
                                ],
                                [
                                    0.04393122179635344,
                                    0.0024710433251987672,
                                    0.9028161337750655,
                                    0.05078160110338226,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.022904899683578235,
                                    0.0005501388317558024,
                                    0.9536400618010877,
                                    0.022904899683578207,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.061272875779159526,
                                    0.007991962103330964,
                                    0.8233444517472612,
                                    0.10739071037024826,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.04052414229069547,
                                    0.00528565707646099,
                                    0.8440931852357253,
                                    0.11009701539711823,
                                ],
                                [
                                    0.7519115261736411,
                                    0.028148348986680196,
                                    0.21200361690317066,
                                    0.00793650793650794,
                                ],
                                [
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                    0.9534805494880724,
                                    0.035694230404447705,
                                ],
                                [
                                    0.01876172804398785,
                                    0.06254046249196105,
                                    0.21200361690317066,
                                    0.7066941925608805,
                                ],
                                [
                                    0.06687001913583668,
                                    0.014432171400112213,
                                    0.755617280345586,
                                    0.16308052911846518,
                                ],
                                [
                                    0.010434593588739494,
                                    0.03478274002402132,
                                    0.220330751358419,
                                    0.7344519150288202,
                                ],
                                [
                                    0.0371906826129102,
                                    0.008026650999850614,
                                    0.7852966168685124,
                                    0.16948604951872678,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.04271058037267617,
                                    0.0019989413309686884,
                                ],
                                [
                                    0.0021021695508696182,
                                    9.838577615361652e-05,
                                    0.9531883087454855,
                                    0.04461113592749119,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.0698327320295747,
                                    0.019689539597615918,
                                    0.7102271431307466,
                                    0.20025058524206266,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.03495662811095182,
                                    0.009856121812593955,
                                    0.7451032470493696,
                                    0.2100840030270846,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9063814599347185,
                                    0.0019989413309686862,
                                    0.09141798473825831,
                                    0.00020161399605452077,
                                ],
                                [
                                    0.9084787870418407,
                                    0.0447143641473921,
                                    0.04461113592749119,
                                    0.002195712883275917,
                                ],
                                [
                                    0.9308359691155368,
                                    0.02235718207369605,
                                    0.045708992369129155,
                                    0.0010978564416379585,
                                ],
                                [
                                    0.9063814599347184,
                                    0.04461113592749119,
                                    0.04670846303461349,
                                    0.002298941103176822,
                                ],
                                [
                                    0.928687027898464,
                                    0.022305567963745596,
                                    0.047857933586201905,
                                    0.001149470551588411,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7335404246483938,
                                    0.22005731023005395,
                                    0.035694230404447705,
                                    0.010708034717104494,
                                ],
                                [
                                    0.8435690797634208,
                                    0.11002865511502698,
                                    0.04104824776299996,
                                    0.005354017358552247,
                                ],
                                [
                                    0.7252132901931454,
                                    0.21755922457782245,
                                    0.04402136485969607,
                                    0.013206120369336003,
                                ],
                                [
                                    0.8339929024820567,
                                    0.10877961228891123,
                                    0.050624425044364076,
                                    0.006603060184668001,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.7156426504746327,
                                    0.23854755015821089,
                                    0.034357349525367314,
                                    0.011452449841789104,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.6980513715881322,
                                    0.2326837905293774,
                                    0.051948628411867814,
                                    0.017316209470622606,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.22033075135841906,
                                    0.7344519150288203,
                                    0.01043459358873945,
                                    0.03478274002402117,
                                ],
                                [
                                    0.5875567088728292,
                                    0.3672259575144102,
                                    0.02782596360075004,
                                    0.017391370012010587,
                                ],
                                [
                                    0.21200361690317068,
                                    0.7066941925608805,
                                    0.01876172804398782,
                                    0.06254046249196094,
                                ],
                                [
                                    0.565350713183611,
                                    0.35334709628044025,
                                    0.050031959289968286,
                                    0.03127023124598047,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.4999975787781264,
                                    0.45518967129832794,
                                    0.023457459737207656,
                                    0.021355290186338062,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991899,
                                    0.08532277496919864,
                                ],
                                [
                                    0.47659415437274283,
                                    0.43388357400006666,
                                    0.046860884142591215,
                                    0.04266138748459932,
                                ],
                                [
                                    0.7783433102466403,
                                    0.001716564913681103,
                                    0.21945613442633646,
                                    0.0004839904133421038,
                                ],
                                [
                                    0.7315364614358733,
                                    0.0016133366937801977,
                                    0.26626298323710357,
                                    0.0005872186332430093,
                                ],
                                [
                                    0.7336337885429954,
                                    0.03610867841896185,
                                    0.21945613442633644,
                                    0.010801398611706165,
                                ],
                                [
                                    0.7516881277524764,
                                    0.018054339209480925,
                                    0.2248568337321895,
                                    0.005400699305853083,
                                ],
                                [
                                    0.7315364614358733,
                                    0.03600545019906095,
                                    0.22155346153345873,
                                    0.01090462683160707,
                                ],
                                [
                                    0.7495391865354037,
                                    0.018002725099530475,
                                    0.22700577494926227,
                                    0.005452313415803535,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.5853164341340025,
                                    0.006405520400261611,
                                    0.4038583457585176,
                                    0.004419699707218268,
                                ],
                                [
                                    0.5936435685892508,
                                    0.17808917211582218,
                                    0.17559108646359065,
                                    0.05267617283133628,
                                ],
                                [
                                    0.6826881546471619,
                                    0.08904458605791109,
                                    0.2019291728792588,
                                    0.02633808641566814,
                                ],
                                [
                                    0.5853164341340025,
                                    0.17559108646359065,
                                    0.18391822091883903,
                                    0.05517425848356779,
                                ],
                                [
                                    0.6731119773657978,
                                    0.08779554323179532,
                                    0.21150535016062294,
                                    0.027587129241783893,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.3755961132956237,
                                    0.009021214230797034,
                                    0.6009488481890423,
                                    0.014433824284536975,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.5809854488299361,
                                    0.19366181627664536,
                                    0.16901455117006386,
                                    0.056338183723354626,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.5633941699434356,
                                    0.18779805664781188,
                                    0.1866058300565644,
                                    0.06220194335218813,
                                ],
                                [
                                    0.9125841127032176,
                                    0.034163242868201375,
                                    0.05133103037359428,
                                    0.0019216140549867587,
                                ],
                                [
                                    0.17110718011831585,
                                    0.0064055204002616125,
                                    0.792807962958496,
                                    0.029679336522926522,
                                ],
                                [
                                    0.17943431457356424,
                                    0.5981274749345258,
                                    0.05133103037359428,
                                    0.1711071801183158,
                                ],
                                [
                                    0.47849805204082707,
                                    0.2990637374672629,
                                    0.13688462043275218,
                                    0.0855535900591579,
                                ],
                                [
                                    0.17110718011831585,
                                    0.5703697524665859,
                                    0.059658164828842654,
                                    0.19886490258625558,
                                ],
                                [
                                    0.4562920563516088,
                                    0.28518487623329297,
                                    0.15909061612197045,
                                    0.09943245129312779,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137788,
                                    0.0004839904133421045,
                                ],
                                [
                                    0.03447152022940799,
                                    0.0016133366937802001,
                                    0.9208189580669471,
                                    0.04309618500986461,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.408060455293868,
                                    0.37149160795733766,
                                    0.11539458322146608,
                                    0.1050533535273283,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.3846570308884844,
                                    0.3501855106590764,
                                    0.13879800762684966,
                                    0.12635945082558955,
                                ],
                                [
                                    0.522303146741872,
                                    0.0011518917734620563,
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                ],
                                [
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                    0.522303146741872,
                                    0.0011518917734620563,
                                ],
                                [
                                    0.4775936250382271,
                                    0.023506652625284463,
                                    0.4754962979311048,
                                    0.023403424405383556,
                                ],
                                [
                                    0.48934695135086936,
                                    0.011753326312642231,
                                    0.4871980101337966,
                                    0.011701712202691778,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383556,
                                    0.4775936250382271,
                                    0.023506652625284463,
                                ],
                                [
                                    0.4871980101337966,
                                    0.011701712202691778,
                                    0.48934695135086936,
                                    0.011753326312642231,
                                ],
                                [
                                    0.6087210195937236,
                                    0.006661652879855695,
                                    0.3804537602987966,
                                    0.004163567227624184,
                                ],
                                [
                                    0.3804537602987967,
                                    0.004163567227624185,
                                    0.6087210195937235,
                                    0.006661652879855694,
                                ],
                                [
                                    0.3887808947540449,
                                    0.11663171529969497,
                                    0.3804537602987966,
                                    0.11413362964746347,
                                ],
                                [
                                    0.44709675240389246,
                                    0.05831585764984749,
                                    0.4375205751225283,
                                    0.057066814823731736,
                                ],
                                [
                                    0.3804537602987966,
                                    0.11413362964746347,
                                    0.3887808947540449,
                                    0.11663171529969497,
                                ],
                                [
                                    0.4375205751225283,
                                    0.057066814823731736,
                                    0.44709675240389246,
                                    0.05831585764984749,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.2441362403711665,
                                    0.005863759628833502,
                                    0.7324087211134995,
                                    0.017591278886500507,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.38379563944325024,
                                    0.12793187981441675,
                                    0.36620436055674976,
                                    0.12206812018558325,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.36620436055674976,
                                    0.12206812018558325,
                                    0.38379563944325024,
                                    0.12793187981441675,
                                ],
                                [
                                    0.8526960378308568,
                                    0.03192128969556395,
                                    0.11121910524595506,
                                    0.004163567227624185,
                                ],
                                [
                                    0.11121910524595506,
                                    0.004163567227624185,
                                    0.8526960378308568,
                                    0.03192128969556395,
                                ],
                                [
                                    0.11954623970120344,
                                    0.39849618876039067,
                                    0.11121910524595506,
                                    0.37073846629245083,
                                ],
                                [
                                    0.3187943340813988,
                                    0.19924809438019533,
                                    0.29658833839218046,
                                    0.18536923314622542,
                                ],
                                [
                                    0.11121910524595506,
                                    0.37073846629245083,
                                    0.11954623970120344,
                                    0.39849618876039067,
                                ],
                                [
                                    0.29658833839218046,
                                    0.18536923314622542,
                                    0.3187943340813988,
                                    0.19924809438019533,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.022406374961772883,
                                    0.001048663553561152,
                                ],
                                [
                                    0.022406374961772883,
                                    0.001048663553561152,
                                    0.9328841033345823,
                                    0.04366085815008366,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.2734292314603588,
                                    0.24892552939146362,
                                    0.25002580705497524,
                                    0.22761943209320235,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.25002580705497524,
                                    0.22761943209320235,
                                    0.2734292314603588,
                                    0.24892552939146362,
                                ],
                                [
                                    0.2662629832371037,
                                    0.0005872186332430096,
                                    0.7315364614358731,
                                    0.0016133366937801975,
                                ],
                                [
                                    0.21945613442633652,
                                    0.00048399041334210393,
                                    0.7783433102466403,
                                    0.001716564913681103,
                                ],
                                [
                                    0.22155346153345878,
                                    0.010904626831607074,
                                    0.7315364614358731,
                                    0.03600545019906094,
                                ],
                                [
                                    0.22700577494926233,
                                    0.005452313415803537,
                                    0.7495391865354036,
                                    0.01800272509953047,
                                ],
                                [
                                    0.21945613442633646,
                                    0.010801398611706167,
                                    0.7336337885429954,
                                    0.03610867841896185,
                                ],
                                [
                                    0.22485683373218954,
                                    0.0054006993058530834,
                                    0.7516881277524764,
                                    0.018054339209480925,
                                ],
                                [
                                    0.4038583457585177,
                                    0.004419699707218269,
                                    0.5853164341340024,
                                    0.00640552040026161,
                                ],
                                [
                                    0.17559108646359073,
                                    0.001921614054986759,
                                    0.8135836934289294,
                                    0.00890360605249312,
                                ],
                                [
                                    0.18391822091883905,
                                    0.055174258483567794,
                                    0.5853164341340025,
                                    0.17559108646359065,
                                ],
                                [
                                    0.21150535016062294,
                                    0.027587129241783897,
                                    0.6731119773657978,
                                    0.08779554323179532,
                                ],
                                [
                                    0.17559108646359067,
                                    0.052676172831336285,
                                    0.5936435685892508,
                                    0.17808917211582218,
                                ],
                                [
                                    0.20192917287925882,
                                    0.026338086415668142,
                                    0.6826881546471619,
                                    0.08904458605791109,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.11267636744670928,
                                    0.0027063050268699707,
                                    0.8638685940379567,
                                    0.02074873348846404,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.18660583005656445,
                                    0.06220194335218815,
                                    0.5633941699434355,
                                    0.18779805664781185,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.16901455117006392,
                                    0.05633818372335464,
                                    0.5809854488299361,
                                    0.19366181627664536,
                                ],
                                [
                                    0.792807962958496,
                                    0.029679336522926522,
                                    0.17110718011831583,
                                    0.006405520400261612,
                                ],
                                [
                                    0.05133103037359426,
                                    0.0019216140549867579,
                                    0.9125841127032176,
                                    0.034163242868201375,
                                ],
                                [
                                    0.05965816482884268,
                                    0.19886490258625567,
                                    0.17110718011831583,
                                    0.5703697524665858,
                                ],
                                [
                                    0.1590906161219705,
                                    0.09943245129312783,
                                    0.45629205635160874,
                                    0.2851848762332929,
                                ],
                                [
                                    0.05133103037359432,
                                    0.17110718011831594,
                                    0.17943431457356418,
                                    0.5981274749345256,
                                ],
                                [
                                    0.1368846204327523,
                                    0.08555359005915797,
                                    0.47849805204082696,
                                    0.2990637374672628,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.03447152022940798,
                                    0.0016133366937801995,
                                ],
                                [
                                    0.010341229694137779,
                                    0.00048399041334210404,
                                    0.9449492486022174,
                                    0.044225531290302704,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.1387980076268497,
                                    0.1263594508255896,
                                    0.38465703088848435,
                                    0.3501855106590763,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.11539458322146613,
                                    0.10505335352732835,
                                    0.4080604552938679,
                                    0.3714916079573376,
                                ],
                                [
                                    0.09141798473825839,
                                    0.00020161399605452096,
                                    0.9063814599347184,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.04461113592749122,
                                    9.838577615361534e-05,
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.04670846303461354,
                                    0.002298941103176825,
                                    0.9063814599347184,
                                    0.04461113592749119,
                                ],
                                [
                                    0.04785793358620195,
                                    0.0011494705515884124,
                                    0.928687027898464,
                                    0.022305567963745596,
                                ],
                                [
                                    0.04461113592749121,
                                    0.002195712883275918,
                                    0.9084787870418407,
                                    0.0447143641473921,
                                ],
                                [
                                    0.04570899236912917,
                                    0.001097856441637959,
                                    0.9308359691155368,
                                    0.02235718207369605,
                                ],
                                [
                                    0.2639614896993748,
                                    0.0028887121709719418,
                                    0.7252132901931454,
                                    0.007936507936507938,
                                ],
                                [
                                    0.03569423040444776,
                                    0.00039062651874043134,
                                    0.9534805494880724,
                                    0.010434593588739449,
                                ],
                                [
                                    0.044021364859696085,
                                    0.013206120369336006,
                                    0.7252132901931454,
                                    0.21755922457782245,
                                ],
                                [
                                    0.05062442504436409,
                                    0.006603060184668003,
                                    0.8339929024820567,
                                    0.10877961228891123,
                                ],
                                [
                                    0.03569423040444771,
                                    0.010708034717104496,
                                    0.7335404246483938,
                                    0.22005731023005395,
                                ],
                                [
                                    0.041048247762999965,
                                    0.005354017358552248,
                                    0.8435690797634208,
                                    0.11002865511502698,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.022904899683578235,
                                    0.0005501388317558024,
                                    0.9536400618010877,
                                    0.022904899683578207,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.05194862841186787,
                                    0.017316209470622623,
                                    0.6980513715881321,
                                    0.23268379052937738,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.03435734952536734,
                                    0.011452449841789114,
                                    0.7156426504746327,
                                    0.23854755015821089,
                                ],
                                [
                                    0.7519115261736411,
                                    0.028148348986680196,
                                    0.21200361690317066,
                                    0.00793650793650794,
                                ],
                                [
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                    0.9534805494880724,
                                    0.035694230404447705,
                                ],
                                [
                                    0.01876172804398785,
                                    0.06254046249196105,
                                    0.21200361690317066,
                                    0.7066941925608805,
                                ],
                                [
                                    0.05003195928996837,
                                    0.03127023124598052,
                                    0.5653507131836109,
                                    0.35334709628044025,
                                ],
                                [
                                    0.010434593588739494,
                                    0.03478274002402132,
                                    0.220330751358419,
                                    0.7344519150288202,
                                ],
                                [
                                    0.027825963600750153,
                                    0.01739137001201066,
                                    0.5875567088728291,
                                    0.3672259575144101,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.04271058037267617,
                                    0.0019989413309686884,
                                ],
                                [
                                    0.0021021695508696182,
                                    9.838577615361652e-05,
                                    0.9531883087454855,
                                    0.04461113592749119,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.046860884142591264,
                                    0.042661387484599356,
                                    0.4765941543727428,
                                    0.4338835740000666,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.023457459737207687,
                                    0.021355290186338093,
                                    0.49999757877812634,
                                    0.4551896712983279,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9063814599347185,
                                    0.0019989413309686862,
                                    0.09141798473825831,
                                    0.00020161399605452077,
                                ],
                                [
                                    0.9084787870418407,
                                    0.0447143641473921,
                                    0.04461113592749119,
                                    0.002195712883275917,
                                ],
                                [
                                    0.9187973127084065,
                                    0.03439583848082631,
                                    0.045117830368405276,
                                    0.00168901844236183,
                                ],
                                [
                                    0.9063814599347184,
                                    0.04461113592749119,
                                    0.04670846303461349,
                                    0.002298941103176822,
                                ],
                                [
                                    0.9166761641055104,
                                    0.034316431756699114,
                                    0.04723897897130129,
                                    0.001768425166489022,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7335404246483938,
                                    0.22005731023005395,
                                    0.035694230404447705,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7843220257517761,
                                    0.16927570912667167,
                                    0.03816527372964648,
                                    0.008236991391905726,
                                ],
                                [
                                    0.7252132901931454,
                                    0.21755922457782245,
                                    0.04402136485969607,
                                    0.013206120369336003,
                                ],
                                [
                                    0.775418419699283,
                                    0.16735409507168492,
                                    0.0470688797821396,
                                    0.010158605446892482,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.58719211571354,
                                    0.3669980849193035,
                                    0.028190556760039193,
                                    0.01761924260711722,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.5727582914290031,
                                    0.35797687068850653,
                                    0.04262438104457617,
                                    0.026640456837914255,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.22033075135841906,
                                    0.7344519150288203,
                                    0.01043459358873945,
                                    0.03478274002402117,
                                ],
                                [
                                    0.389816800877146,
                                    0.5649658655100934,
                                    0.018461244588590036,
                                    0.02675608902417059,
                                ],
                                [
                                    0.21200361690317068,
                                    0.7066941925608805,
                                    0.01876172804398782,
                                    0.06254046249196094,
                                ],
                                [
                                    0.375084146021636,
                                    0.5436136634424152,
                                    0.03319389944410001,
                                    0.04810829109184874,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.25489191050688315,
                                    0.7002953395695711,
                                    0.011958291363463538,
                                    0.03285445856008218,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991899,
                                    0.08532277496919864,
                                ],
                                [
                                    0.2429611656147389,
                                    0.6675165627580706,
                                    0.023889036255607805,
                                    0.06563323537158273,
                                ],
                                [
                                    0.7783433102466403,
                                    0.001716564913681103,
                                    0.21945613442633646,
                                    0.0004839904133421038,
                                ],
                                [
                                    0.7315364614358733,
                                    0.0016133366937801977,
                                    0.26626298323710357,
                                    0.0005872186332430093,
                                ],
                                [
                                    0.7336337885429954,
                                    0.03610867841896185,
                                    0.21945613442633644,
                                    0.010801398611706165,
                                ],
                                [
                                    0.7419664201739332,
                                    0.027776046788024103,
                                    0.22194872290287856,
                                    0.008308810135164033,
                                ],
                                [
                                    0.7315364614358733,
                                    0.03600545019906095,
                                    0.22155346153345873,
                                    0.01090462683160707,
                                ],
                                [
                                    0.7398452715710373,
                                    0.027696640063896914,
                                    0.2240698715057746,
                                    0.008388216859291225,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.5853164341340025,
                                    0.006405520400261611,
                                    0.4038583457585176,
                                    0.004419699707218268,
                                ],
                                [
                                    0.5936435685892508,
                                    0.17808917211582218,
                                    0.17559108646359065,
                                    0.05267617283133628,
                                ],
                                [
                                    0.6347403778239125,
                                    0.13699236288116057,
                                    0.18774692165751014,
                                    0.04052033763741682,
                                ],
                                [
                                    0.5853164341340025,
                                    0.17559108646359065,
                                    0.18391822091883903,
                                    0.05517425848356779,
                                ],
                                [
                                    0.6258367717714194,
                                    0.13507074882617381,
                                    0.19665052771000324,
                                    0.04244195169240358,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.3755961132956237,
                                    0.009021214230797034,
                                    0.6009488481890423,
                                    0.014433824284536975,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.4767045042256373,
                                    0.2979427608809441,
                                    0.1386781682479419,
                                    0.08667456664547661,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.4622706799411004,
                                    0.28892154665014713,
                                    0.15311199253247887,
                                    0.09569578087627365,
                                ],
                                [
                                    0.9125841127032176,
                                    0.034163242868201375,
                                    0.05133103037359428,
                                    0.0019216140549867587,
                                ],
                                [
                                    0.17110718011831585,
                                    0.0064055204002616125,
                                    0.792807962958496,
                                    0.029679336522926522,
                                ],
                                [
                                    0.17943431457356424,
                                    0.5981274749345258,
                                    0.05133103037359428,
                                    0.1711071801183158,
                                ],
                                [
                                    0.317461407649203,
                                    0.46010038185888696,
                                    0.09081663781653301,
                                    0.13162157267537705,
                                ],
                                [
                                    0.17110718011831585,
                                    0.5703697524665859,
                                    0.059658164828842654,
                                    0.19886490258625558,
                                ],
                                [
                                    0.302728752793693,
                                    0.4387481797912088,
                                    0.10554929267204301,
                                    0.15297377474305524,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137788,
                                    0.0004839904133421045,
                                ],
                                [
                                    0.03447152022940799,
                                    0.0016133366937802001,
                                    0.9208189580669471,
                                    0.04309618500986461,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.2080236254470295,
                                    0.5715284378041762,
                                    0.0588265764233172,
                                    0.16162136032547716,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.19609288055488522,
                                    0.5387496609926755,
                                    0.07075732131546147,
                                    0.19440013713697774,
                                ],
                                [
                                    0.522303146741872,
                                    0.0011518917734620563,
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                ],
                                [
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                    0.522303146741872,
                                    0.0011518917734620563,
                                ],
                                [
                                    0.4775936250382271,
                                    0.023506652625284463,
                                    0.4754962979311048,
                                    0.023403424405383556,
                                ],
                                [
                                    0.4830181458398539,
                                    0.018082131823657664,
                                    0.4808969972369579,
                                    0.01800272509953047,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383556,
                                    0.4775936250382271,
                                    0.023506652625284463,
                                ],
                                [
                                    0.4808969972369579,
                                    0.01800272509953047,
                                    0.4830181458398539,
                                    0.018082131823657664,
                                ],
                                [
                                    0.6087210195937236,
                                    0.006661652879855695,
                                    0.3804537602987966,
                                    0.004163567227624184,
                                ],
                                [
                                    0.3804537602987967,
                                    0.004163567227624185,
                                    0.6087210195937235,
                                    0.006661652879855694,
                                ],
                                [
                                    0.3887808947540449,
                                    0.11663171529969497,
                                    0.3804537602987966,
                                    0.11413362964746347,
                                ],
                                [
                                    0.41569545276695785,
                                    0.08971715728678208,
                                    0.4067918467144648,
                                    0.08779554323179532,
                                ],
                                [
                                    0.3804537602987966,
                                    0.11413362964746347,
                                    0.3887808947540449,
                                    0.11663171529969497,
                                ],
                                [
                                    0.4067918467144648,
                                    0.08779554323179532,
                                    0.41569545276695785,
                                    0.08971715728678208,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.2441362403711665,
                                    0.005863759628833502,
                                    0.7324087211134995,
                                    0.017591278886500507,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.3149082483790581,
                                    0.1968192708786089,
                                    0.30047442409452113,
                                    0.18779805664781185,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.30047442409452113,
                                    0.18779805664781185,
                                    0.3149082483790581,
                                    0.1968192708786089,
                                ],
                                [
                                    0.8526960378308568,
                                    0.03192128969556395,
                                    0.11121910524595506,
                                    0.004163567227624185,
                                ],
                                [
                                    0.11121910524595506,
                                    0.004163567227624185,
                                    0.8526960378308568,
                                    0.03192128969556395,
                                ],
                                [
                                    0.11954623970120344,
                                    0.39849618876039067,
                                    0.11121910524595506,
                                    0.37073846629245083,
                                ],
                                [
                                    0.211505350160623,
                                    0.3065370783009711,
                                    0.196772695305113,
                                    0.2851848762332929,
                                ],
                                [
                                    0.11121910524595506,
                                    0.37073846629245083,
                                    0.11954623970120344,
                                    0.39849618876039067,
                                ],
                                [
                                    0.196772695305113,
                                    0.2851848762332929,
                                    0.211505350160623,
                                    0.3065370783009711,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.022406374961772883,
                                    0.001048663553561152,
                                ],
                                [
                                    0.022406374961772883,
                                    0.001048663553561152,
                                    0.9328841033345823,
                                    0.04366085815008366,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.1393904733812455,
                                    0.3829642874705769,
                                    0.1274597284891012,
                                    0.3501855106590764,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.1274597284891012,
                                    0.3501855106590764,
                                    0.1393904733812455,
                                    0.3829642874705769,
                                ],
                                [
                                    0.2662629832371037,
                                    0.0005872186332430096,
                                    0.7315364614358731,
                                    0.0016133366937801975,
                                ],
                                [
                                    0.21945613442633652,
                                    0.00048399041334210393,
                                    0.7783433102466403,
                                    0.001716564913681103,
                                ],
                                [
                                    0.22155346153345878,
                                    0.010904626831607074,
                                    0.7315364614358731,
                                    0.03600545019906094,
                                ],
                                [
                                    0.22406987150577462,
                                    0.008388216859291227,
                                    0.7398452715710372,
                                    0.02769664006389691,
                                ],
                                [
                                    0.21945613442633646,
                                    0.010801398611706167,
                                    0.7336337885429954,
                                    0.03610867841896185,
                                ],
                                [
                                    0.2219487229028786,
                                    0.008308810135164034,
                                    0.7419664201739332,
                                    0.027776046788024103,
                                ],
                                [
                                    0.4038583457585177,
                                    0.004419699707218269,
                                    0.5853164341340024,
                                    0.00640552040026161,
                                ],
                                [
                                    0.17559108646359073,
                                    0.001921614054986759,
                                    0.8135836934289294,
                                    0.00890360605249312,
                                ],
                                [
                                    0.18391822091883905,
                                    0.055174258483567794,
                                    0.5853164341340025,
                                    0.17559108646359065,
                                ],
                                [
                                    0.19665052771000327,
                                    0.042441951692403584,
                                    0.6258367717714194,
                                    0.13507074882617381,
                                ],
                                [
                                    0.17559108646359067,
                                    0.052676172831336285,
                                    0.5936435685892508,
                                    0.17808917211582218,
                                ],
                                [
                                    0.18774692165751014,
                                    0.040520337637416824,
                                    0.6347403778239125,
                                    0.13699236288116057,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.11267636744670928,
                                    0.0027063050268699707,
                                    0.8638685940379567,
                                    0.02074873348846404,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.15311199253247892,
                                    0.09569578087627367,
                                    0.4622706799411003,
                                    0.2889215466501471,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.13867816824794194,
                                    0.08667456664547664,
                                    0.4767045042256373,
                                    0.2979427608809441,
                                ],
                                [
                                    0.792807962958496,
                                    0.029679336522926522,
                                    0.17110718011831583,
                                    0.006405520400261612,
                                ],
                                [
                                    0.05133103037359426,
                                    0.0019216140549867579,
                                    0.9125841127032176,
                                    0.034163242868201375,
                                ],
                                [
                                    0.05965816482884268,
                                    0.19886490258625567,
                                    0.17110718011831583,
                                    0.5703697524665858,
                                ],
                                [
                                    0.10554929267204305,
                                    0.1529737747430553,
                                    0.30272875279369293,
                                    0.4387481797912087,
                                ],
                                [
                                    0.05133103037359432,
                                    0.17110718011831594,
                                    0.17943431457356418,
                                    0.5981274749345256,
                                ],
                                [
                                    0.09081663781653308,
                                    0.13162157267537716,
                                    0.3174614076492029,
                                    0.46010038185888685,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.03447152022940798,
                                    0.0016133366937801995,
                                ],
                                [
                                    0.010341229694137779,
                                    0.00048399041334210404,
                                    0.9449492486022174,
                                    0.044225531290302704,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.0707573213154615,
                                    0.19440013713697782,
                                    0.1960928805548852,
                                    0.5387496609926755,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.05882657642331723,
                                    0.16162136032547725,
                                    0.20802362544702946,
                                    0.5715284378041761,
                                ],
                                [
                                    0.09141798473825839,
                                    0.00020161399605452096,
                                    0.9063814599347184,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.04461113592749122,
                                    9.838577615361534e-05,
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.04670846303461354,
                                    0.002298941103176825,
                                    0.9063814599347184,
                                    0.04461113592749119,
                                ],
                                [
                                    0.04723897897130134,
                                    0.0017684251664890236,
                                    0.9166761641055104,
                                    0.034316431756699114,
                                ],
                                [
                                    0.04461113592749121,
                                    0.002195712883275918,
                                    0.9084787870418407,
                                    0.0447143641473921,
                                ],
                                [
                                    0.0451178303684053,
                                    0.0016890184423618308,
                                    0.9187973127084065,
                                    0.03439583848082631,
                                ],
                                [
                                    0.2639614896993748,
                                    0.0028887121709719418,
                                    0.7252132901931454,
                                    0.007936507936507938,
                                ],
                                [
                                    0.03569423040444776,
                                    0.00039062651874043134,
                                    0.9534805494880724,
                                    0.010434593588739449,
                                ],
                                [
                                    0.044021364859696085,
                                    0.013206120369336006,
                                    0.7252132901931454,
                                    0.21755922457782245,
                                ],
                                [
                                    0.04706887978213961,
                                    0.010158605446892486,
                                    0.775418419699283,
                                    0.16735409507168492,
                                ],
                                [
                                    0.03569423040444771,
                                    0.010708034717104496,
                                    0.7335404246483938,
                                    0.22005731023005395,
                                ],
                                [
                                    0.03816527372964648,
                                    0.008236991391905727,
                                    0.7843220257517761,
                                    0.16927570912667167,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.022904899683578235,
                                    0.0005501388317558024,
                                    0.9536400618010877,
                                    0.022904899683578207,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.042624381044576214,
                                    0.026640456837914283,
                                    0.572758291429003,
                                    0.3579768706885065,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.02819055676003922,
                                    0.017619242607117235,
                                    0.58719211571354,
                                    0.3669980849193035,
                                ],
                                [
                                    0.7519115261736411,
                                    0.028148348986680196,
                                    0.21200361690317066,
                                    0.00793650793650794,
                                ],
                                [
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                    0.9534805494880724,
                                    0.035694230404447705,
                                ],
                                [
                                    0.01876172804398785,
                                    0.06254046249196105,
                                    0.21200361690317066,
                                    0.7066941925608805,
                                ],
                                [
                                    0.033193899444100075,
                                    0.04810829109184882,
                                    0.3750841460216359,
                                    0.5436136634424152,
                                ],
                                [
                                    0.010434593588739494,
                                    0.03478274002402132,
                                    0.220330751358419,
                                    0.7344519150288202,
                                ],
                                [
                                    0.018461244588590112,
                                    0.0267560890241707,
                                    0.3898168008771459,
                                    0.5649658655100933,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.04271058037267617,
                                    0.0019989413309686884,
                                ],
                                [
                                    0.0021021695508696182,
                                    9.838577615361652e-05,
                                    0.9531883087454855,
                                    0.04461113592749119,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.023889036255607825,
                                    0.06563323537158279,
                                    0.24296116561473888,
                                    0.6675165627580705,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.011958291363463555,
                                    0.03285445856008223,
                                    0.25489191050688315,
                                    0.7002953395695711,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9063814599347185,
                                    0.0019989413309686862,
                                    0.09141798473825831,
                                    0.00020161399605452077,
                                ],
                                [
                                    0.9084787870418407,
                                    0.0447143641473921,
                                    0.04461113592749119,
                                    0.002195712883275917,
                                ],
                                [
                                    0.9105763413083723,
                                    0.0426168098808606,
                                    0.0447141369879829,
                                    0.0020927118227842133,
                                ],
                                [
                                    0.9063814599347184,
                                    0.04461113592749119,
                                    0.04670846303461349,
                                    0.002298941103176822,
                                ],
                                [
                                    0.9084741717575027,
                                    0.04251842410470698,
                                    0.046816306538852485,
                                    0.002191097598937829,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7335404246483938,
                                    0.22005731023005395,
                                    0.035694230404447705,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7438633300224472,
                                    0.2097344048560005,
                                    0.036196545137874146,
                                    0.010205719983678054,
                                ],
                                [
                                    0.7252132901931454,
                                    0.21755922457782245,
                                    0.04402136485969607,
                                    0.013206120369336003,
                                ],
                                [
                                    0.7354190101768234,
                                    0.2073535045941444,
                                    0.0446408649834979,
                                    0.012586620245534176,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.4994756682232194,
                                    0.4547145324096241,
                                    0.023979370292114586,
                                    0.02183042907504183,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.48719801013379666,
                                    0.44353715198371296,
                                    0.036257028381537396,
                                    0.03300780950095303,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.22033075135841906,
                                    0.7344519150288203,
                                    0.01043459358873945,
                                    0.03478274002402117,
                                ],
                                [
                                    0.2547839472677427,
                                    0.6999987191194967,
                                    0.012066254602603986,
                                    0.03315107901015664,
                                ],
                                [
                                    0.21200361690317068,
                                    0.7066941925608805,
                                    0.01876172804398782,
                                    0.06254046249196094,
                                ],
                                [
                                    0.24515469591332736,
                                    0.6735431135507238,
                                    0.021695505957019315,
                                    0.05960668457892944,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08751387256813654,
                                    0.8676733775083177,
                                    0.00410572616617637,
                                    0.04070702375736935,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991899,
                                    0.08532277496919864,
                                ],
                                [
                                    0.08341760413004555,
                                    0.827060124242764,
                                    0.008201994604267362,
                                    0.08132027702292317,
                                ],
                                [
                                    0.7783433102466403,
                                    0.001716564913681103,
                                    0.21945613442633646,
                                    0.0004839904133421038,
                                ],
                                [
                                    0.7315364614358733,
                                    0.0016133366937801977,
                                    0.26626298323710357,
                                    0.0005872186332430093,
                                ],
                                [
                                    0.7336337885429954,
                                    0.03610867841896185,
                                    0.21945613442633644,
                                    0.010801398611706165,
                                ],
                                [
                                    0.7353276494291046,
                                    0.034414817532852734,
                                    0.21996282886725052,
                                    0.010294704170792078,
                                ],
                                [
                                    0.7315364614358733,
                                    0.03600545019906095,
                                    0.22155346153345873,
                                    0.01090462683160707,
                                ],
                                [
                                    0.733225479878235,
                                    0.03431643175669912,
                                    0.2220649984181201,
                                    0.010393089946945693,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.5853164341340025,
                                    0.006405520400261611,
                                    0.4038583457585176,
                                    0.004419699707218268,
                                ],
                                [
                                    0.5936435685892508,
                                    0.17808917211582218,
                                    0.17559108646359065,
                                    0.05267617283133628,
                                ],
                                [
                                    0.601997745371532,
                                    0.16973499533354106,
                                    0.17806212978878944,
                                    0.05020512950613751,
                                ],
                                [
                                    0.5853164341340025,
                                    0.17559108646359065,
                                    0.18391822091883903,
                                    0.05517425848356779,
                                ],
                                [
                                    0.5935534255259082,
                                    0.16735409507168492,
                                    0.18650644963441318,
                                    0.05258602976799363,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.3755961132956237,
                                    0.009021214230797034,
                                    0.6009488481890423,
                                    0.014433824284536975,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.40549301399216375,
                                    0.3691542511144177,
                                    0.11796202452317024,
                                    0.10739071037024826,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.393215355902741,
                                    0.35797687068850653,
                                    0.13023968261259306,
                                    0.11856809079615946,
                                ],
                                [
                                    0.9125841127032176,
                                    0.034163242868201375,
                                    0.05133103037359428,
                                    0.0019216140549867587,
                                ],
                                [
                                    0.17110718011831585,
                                    0.0064055204002616125,
                                    0.792807962958496,
                                    0.029679336522926522,
                                ],
                                [
                                    0.17943431457356424,
                                    0.5981274749345258,
                                    0.05133103037359428,
                                    0.1711071801183158,
                                ],
                                [
                                    0.20749252049690184,
                                    0.5700692690111882,
                                    0.05935768137344487,
                                    0.16308052911846518,
                                ],
                                [
                                    0.17110718011831585,
                                    0.5703697524665859,
                                    0.059658164828842654,
                                    0.19886490258625558,
                                ],
                                [
                                    0.19786326914248648,
                                    0.5436136634424152,
                                    0.0689869327278602,
                                    0.189536134687238,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137788,
                                    0.0004839904133421045,
                                ],
                                [
                                    0.03447152022940799,
                                    0.0016133366937802001,
                                    0.9208189580669471,
                                    0.04309618500986461,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.07142224722758118,
                                    0.7081298160236245,
                                    0.020197351506731735,
                                    0.20025058524206263,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.06732597878949019,
                                    0.6675165627580706,
                                    0.02429361994482273,
                                    0.24086383850761647,
                                ],
                                [
                                    0.522303146741872,
                                    0.0011518917734620563,
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                ],
                                [
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                    0.522303146741872,
                                    0.0011518917734620563,
                                ],
                                [
                                    0.4775936250382271,
                                    0.023506652625284463,
                                    0.4754962979311048,
                                    0.023403424405383556,
                                ],
                                [
                                    0.4786963239236124,
                                    0.022403953739899216,
                                    0.4765941543727428,
                                    0.022305567963745596,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383556,
                                    0.4775936250382271,
                                    0.023506652625284463,
                                ],
                                [
                                    0.4765941543727428,
                                    0.022305567963745596,
                                    0.4786963239236124,
                                    0.022403953739899216,
                                ],
                                [
                                    0.6087210195937236,
                                    0.006661652879855695,
                                    0.3804537602987966,
                                    0.004163567227624184,
                                ],
                                [
                                    0.3804537602987967,
                                    0.004163567227624185,
                                    0.6087210195937235,
                                    0.006661652879855694,
                                ],
                                [
                                    0.3887808947540449,
                                    0.11663171529969497,
                                    0.3804537602987966,
                                    0.11413362964746347,
                                ],
                                [
                                    0.3942520975029726,
                                    0.11116051255076734,
                                    0.3858077776573488,
                                    0.10877961228891123,
                                ],
                                [
                                    0.3804537602987966,
                                    0.11413362964746347,
                                    0.3887808947540449,
                                    0.11663171529969497,
                                ],
                                [
                                    0.3858077776573488,
                                    0.10877961228891123,
                                    0.3942520975029726,
                                    0.11116051255076734,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.2441362403711665,
                                    0.005863759628833502,
                                    0.7324087211134995,
                                    0.017591278886500507,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.26786634830237843,
                                    0.2438611709552886,
                                    0.2555886902129556,
                                    0.23268379052937738,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.2555886902129556,
                                    0.23268379052937738,
                                    0.26786634830237843,
                                    0.2438611709552886,
                                ],
                                [
                                    0.8526960378308568,
                                    0.03192128969556395,
                                    0.11121910524595506,
                                    0.004163567227624185,
                                ],
                                [
                                    0.11121910524595506,
                                    0.004163567227624185,
                                    0.8526960378308568,
                                    0.03192128969556395,
                                ],
                                [
                                    0.11954623970120344,
                                    0.39849618876039067,
                                    0.11121910524595506,
                                    0.37073846629245083,
                                ],
                                [
                                    0.13823972661238101,
                                    0.37980270184921305,
                                    0.12861047525796568,
                                    0.35334709628044025,
                                ],
                                [
                                    0.11121910524595506,
                                    0.37073846629245083,
                                    0.11954623970120344,
                                    0.39849618876039067,
                                ],
                                [
                                    0.12861047525796568,
                                    0.35334709628044025,
                                    0.13823972661238101,
                                    0.37980270184921305,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.022406374961772883,
                                    0.001048663553561152,
                                ],
                                [
                                    0.022406374961772883,
                                    0.001048663553561152,
                                    0.9328841033345823,
                                    0.04366085815008366,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.04785793358620195,
                                    0.4744968272656205,
                                    0.04376166514811096,
                                    0.4338835740000666,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.04376166514811096,
                                    0.4338835740000666,
                                    0.04785793358620195,
                                    0.4744968272656205,
                                ],
                                [
                                    0.2662629832371037,
                                    0.0005872186332430096,
                                    0.7315364614358731,
                                    0.0016133366937801975,
                                ],
                                [
                                    0.21945613442633652,
                                    0.00048399041334210393,
                                    0.7783433102466403,
                                    0.001716564913681103,
                                ],
                                [
                                    0.22155346153345878,
                                    0.010904626831607074,
                                    0.7315364614358731,
                                    0.03600545019906094,
                                ],
                                [
                                    0.22206499841812016,
                                    0.010393089946945697,
                                    0.7332254798782349,
                                    0.034316431756699114,
                                ],
                                [
                                    0.21945613442633646,
                                    0.010801398611706167,
                                    0.7336337885429954,
                                    0.03610867841896185,
                                ],
                                [
                                    0.21996282886725055,
                                    0.01029470417079208,
                                    0.7353276494291046,
                                    0.034414817532852734,
                                ],
                                [
                                    0.4038583457585177,
                                    0.004419699707218269,
                                    0.5853164341340024,
                                    0.00640552040026161,
                                ],
                                [
                                    0.17559108646359073,
                                    0.001921614054986759,
                                    0.8135836934289294,
                                    0.00890360605249312,
                                ],
                                [
                                    0.18391822091883905,
                                    0.055174258483567794,
                                    0.5853164341340025,
                                    0.17559108646359065,
                                ],
                                [
                                    0.1865064496344132,
                                    0.05258602976799364,
                                    0.5935534255259082,
                                    0.16735409507168492,
                                ],
                                [
                                    0.17559108646359067,
                                    0.052676172831336285,
                                    0.5936435685892508,
                                    0.17808917211582218,
                                ],
                                [
                                    0.17806212978878944,
                                    0.050205129506137515,
                                    0.601997745371532,
                                    0.16973499533354106,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.11267636744670928,
                                    0.0027063050268699707,
                                    0.8638685940379567,
                                    0.02074873348846404,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.13023968261259308,
                                    0.1185680907961595,
                                    0.3932153559027409,
                                    0.3579768706885065,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.11796202452317027,
                                    0.10739071037024829,
                                    0.40549301399216375,
                                    0.3691542511144177,
                                ],
                                [
                                    0.792807962958496,
                                    0.029679336522926522,
                                    0.17110718011831583,
                                    0.006405520400261612,
                                ],
                                [
                                    0.05133103037359426,
                                    0.0019216140549867579,
                                    0.9125841127032176,
                                    0.034163242868201375,
                                ],
                                [
                                    0.05965816482884268,
                                    0.19886490258625567,
                                    0.17110718011831583,
                                    0.5703697524665858,
                                ],
                                [
                                    0.06898693272786025,
                                    0.1895361346872381,
                                    0.19786326914248645,
                                    0.5436136634424152,
                                ],
                                [
                                    0.05133103037359432,
                                    0.17110718011831594,
                                    0.17943431457356418,
                                    0.5981274749345256,
                                ],
                                [
                                    0.05935768137344492,
                                    0.16308052911846535,
                                    0.20749252049690178,
                                    0.5700692690111879,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.03447152022940798,
                                    0.0016133366937801995,
                                ],
                                [
                                    0.010341229694137779,
                                    0.00048399041334210404,
                                    0.9449492486022174,
                                    0.044225531290302704,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.02429361994482274,
                                    0.24086383850761658,
                                    0.06732597878949018,
                                    0.6675165627580705,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.020197351506731746,
                                    0.20025058524206274,
                                    0.07142224722758117,
                                    0.7081298160236243,
                                ],
                                [
                                    0.09141798473825839,
                                    0.00020161399605452096,
                                    0.9063814599347184,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.04461113592749122,
                                    9.838577615361534e-05,
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.04670846303461354,
                                    0.002298941103176825,
                                    0.9063814599347184,
                                    0.04461113592749119,
                                ],
                                [
                                    0.046816306538852534,
                                    0.002191097598937831,
                                    0.9084741717575027,
                                    0.04251842410470698,
                                ],
                                [
                                    0.04461113592749121,
                                    0.002195712883275918,
                                    0.9084787870418407,
                                    0.0447143641473921,
                                ],
                                [
                                    0.04471413698798292,
                                    0.0020927118227842146,
                                    0.9105763413083723,
                                    0.0426168098808606,
                                ],
                                [
                                    0.2639614896993748,
                                    0.0028887121709719418,
                                    0.7252132901931454,
                                    0.007936507936507938,
                                ],
                                [
                                    0.03569423040444776,
                                    0.00039062651874043134,
                                    0.9534805494880724,
                                    0.010434593588739449,
                                ],
                                [
                                    0.044021364859696085,
                                    0.013206120369336006,
                                    0.7252132901931454,
                                    0.21755922457782245,
                                ],
                                [
                                    0.04464086498349791,
                                    0.01258662024553418,
                                    0.7354190101768234,
                                    0.2073535045941444,
                                ],
                                [
                                    0.03569423040444771,
                                    0.010708034717104496,
                                    0.7335404246483938,
                                    0.22005731023005395,
                                ],
                                [
                                    0.03619654513787415,
                                    0.010205719983678056,
                                    0.7438633300224472,
                                    0.2097344048560005,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.022904899683578235,
                                    0.0005501388317558024,
                                    0.9536400618010877,
                                    0.022904899683578207,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.03625702838153743,
                                    0.03300780950095306,
                                    0.4871980101337966,
                                    0.4435371519837129,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.023979370292114607,
                                    0.02183042907504185,
                                    0.4994756682232194,
                                    0.4547145324096241,
                                ],
                                [
                                    0.7519115261736411,
                                    0.028148348986680196,
                                    0.21200361690317066,
                                    0.00793650793650794,
                                ],
                                [
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                    0.9534805494880724,
                                    0.035694230404447705,
                                ],
                                [
                                    0.01876172804398785,
                                    0.06254046249196105,
                                    0.21200361690317066,
                                    0.7066941925608805,
                                ],
                                [
                                    0.021695505957019353,
                                    0.05960668457892954,
                                    0.24515469591332734,
                                    0.6735431135507237,
                                ],
                                [
                                    0.010434593588739494,
                                    0.03478274002402132,
                                    0.220330751358419,
                                    0.7344519150288202,
                                ],
                                [
                                    0.012066254602604036,
                                    0.03315107901015678,
                                    0.25478394726774267,
                                    0.6999987191194965,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.04271058037267617,
                                    0.0019989413309686884,
                                ],
                                [
                                    0.0021021695508696182,
                                    9.838577615361652e-05,
                                    0.9531883087454855,
                                    0.04461113592749119,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.008201994604267371,
                                    0.08132027702292324,
                                    0.08341760413004554,
                                    0.8270601242427639,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.004105726166176376,
                                    0.040707023757369405,
                                    0.08751387256813653,
                                    0.8676733775083176,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.8985469834806652,
                                    0.009833417785021958,
                                    0.09062779641185491,
                                    0.0009918023224579212,
                                ],
                                [
                                    0.9088643916790292,
                                    0.044733343199418525,
                                    0.04422553129030271,
                                    0.002176733831249494,
                                ],
                                [
                                    0.9514992903031237,
                                    0.002098444575324032,
                                    0.046300154369853026,
                                    0.00010211075169917487,
                                ],
                                [
                                    0.8985469834806652,
                                    0.044225531290302704,
                                    0.054542939488666765,
                                    0.002684545740365311,
                                ],
                                [
                                    0.9406978916914176,
                                    0.0020746230795503184,
                                    0.05710155298155919,
                                    0.00012593224747288844,
                                ],
                                [
                                    0.9125841127032176,
                                    0.051331030373594266,
                                    0.034163242868201375,
                                    0.001921614054986758,
                                ],
                                [
                                    0.6941076326169691,
                                    0.03904216551268439,
                                    0.25263972295445,
                                    0.014210478915896635,
                                ],
                                [
                                    0.7350714121846401,
                                    0.2205165964369233,
                                    0.034163242868201375,
                                    0.010248748510235129,
                                ],
                                [
                                    0.9452435580961667,
                                    0.010344450525396804,
                                    0.043931221796353434,
                                    0.00048076958208307394,
                                ],
                                [
                                    0.694107632616969,
                                    0.20822773157601343,
                                    0.07512702243587252,
                                    0.022537613371145005,
                                ],
                                [
                                    0.8925673852648304,
                                    0.009767978928152054,
                                    0.0966073946276897,
                                    0.0010572411793278256,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.4215599302747463,
                                    0.05498503120991964,
                                    0.46305739725167444,
                                    0.06039764126365958,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.9360208191939705,
                                    0.022481713829101357,
                                    0.040524142290695425,
                                    0.0009733246862326492,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.8233444517472613,
                                    0.01977540880223139,
                                    0.15320050973740468,
                                    0.003679629713102619,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                ],
                                [
                                    0.18089795932699423,
                                    0.0390421655126844,
                                    0.6415893401544284,
                                    0.13847053500589301,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.9267244604639018,
                                    0.034692596960678536,
                                    0.037190682612910045,
                                    0.001392259962509602,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.755617280345586,
                                    0.028287076560416922,
                                    0.2082978627312258,
                                    0.007797780362771211,
                                ],
                                [
                                    0.7783433102466403,
                                    0.21945613442633646,
                                    0.001716564913681105,
                                    0.0004839904133421044,
                                ],
                                [
                                    0.03487610391862287,
                                    0.009833417785021965,
                                    0.7451837712416985,
                                    0.2101067070546566,
                                ],
                                [
                                    0.04519351211698697,
                                    0.9182138190507091,
                                    0.0017165649136811055,
                                    0.03487610391862285,
                                ],
                                [
                                    0.9203338501854034,
                                    0.04307348098229263,
                                    0.03495662811095177,
                                    0.0016360407213521807,
                                ],
                                [
                                    0.03487610391862289,
                                    0.7085911024093945,
                                    0.012033973112045179,
                                    0.24449882055993732,
                                ],
                                [
                                    0.7102271431307468,
                                    0.03324006319727067,
                                    0.24506333516560835,
                                    0.011469458506374139,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7355306983915094,
                                    0.036202042313563526,
                                    0.21755922457782245,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7700345001114762,
                                    0.0016982405935967678,
                                    0.2277649445615005,
                                    0.0005023147334264392,
                                ],
                                [
                                    0.7252132901931454,
                                    0.035694230404447705,
                                    0.2278766327761865,
                                    0.011215846626220312,
                                ],
                                [
                                    0.7592331014997701,
                                    0.0016744190978230543,
                                    0.23856634317320666,
                                    0.0005261362292001527,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.560211195688866,
                                    0.031510758845398154,
                                    0.386536159882553,
                                    0.02174188558318287,
                                ],
                                [
                                    0.6011749752565371,
                                    0.1803485446572143,
                                    0.1680596797963044,
                                    0.05041680028994414,
                                ],
                                [
                                    0.7730633557915126,
                                    0.008460164122238795,
                                    0.21611142410100748,
                                    0.0023650559852410854,
                                ],
                                [
                                    0.5602111956888659,
                                    0.1680596797963044,
                                    0.20902345936397557,
                                    0.06270566515085402,
                                ],
                                [
                                    0.7203871829601763,
                                    0.00788369252499404,
                                    0.2687875969323438,
                                    0.002941527582485837,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.3402391523967764,
                                    0.04437817512964435,
                                    0.5443781751296444,
                                    0.07100449734393487,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.7771940273924801,
                                    0.018666949874651947,
                                    0.19935093409218588,
                                    0.004788088640682062,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.6645176599457708,
                                    0.015960644847781976,
                                    0.3120273015388951,
                                    0.007494393667552031,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.7809625400278404,
                                    0.029235894592672198,
                                    0.18295260304897135,
                                    0.0068489623305159385,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.6098553599095247,
                                    0.022830374192410588,
                                    0.35405978316728715,
                                    0.013254482730777548,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.03846575718504431,
                                    0.7815234566441468,
                                    0.008444319845623766,
                                    0.17156646632518516,
                                ],
                                [
                                    0.7833278882767402,
                                    0.036661325552450864,
                                    0.17196259001961497,
                                    0.008048196151193947,
                                ],
                                [
                                    0.02814834898668023,
                                    0.5719007400028322,
                                    0.018761728043987843,
                                    0.3811891829664997,
                                ],
                                [
                                    0.5732211812220835,
                                    0.026827907767428903,
                                    0.3820692970742716,
                                    0.017881613936215908,
                                ],
                                [
                                    0.5177885225070362,
                                    0.005666516008297848,
                                    0.47138625738548395,
                                    0.005158704099182031,
                                ],
                                [
                                    0.47138625738548395,
                                    0.005158704099182031,
                                    0.5177885225070362,
                                    0.005666516008297848,
                                ],
                                [
                                    0.481703665583848,
                                    0.023708944469891916,
                                    0.47138625738548395,
                                    0.023201132560776102,
                                ],
                                [
                                    0.5043004216423415,
                                    0.0011121884113984603,
                                    0.4934990230306353,
                                    0.0010883669156247467,
                                ],
                                [
                                    0.47138625738548395,
                                    0.023201132560776102,
                                    0.481703665583848,
                                    0.023708944469891916,
                                ],
                                [
                                    0.4934990230306353,
                                    0.0010883669156247467,
                                    0.5043004216423415,
                                    0.0011121884113984603,
                                ],
                                [
                                    0.5826119178288338,
                                    0.03277075464474545,
                                    0.36413543774258517,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3641354377425853,
                                    0.02048188978383558,
                                    0.5826119178288337,
                                    0.032770754644745444,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403416,
                                    0.36413543774258517,
                                    0.10923824004312428,
                                ],
                                [
                                    0.5209254763619282,
                                    0.005700845852362316,
                                    0.4682493035305919,
                                    0.0051243742551175635,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312428,
                                    0.40509921731025633,
                                    0.12152710490403416,
                                ],
                                [
                                    0.4682493035305919,
                                    0.0051243742551175635,
                                    0.5209254763619282,
                                    0.005700845852362316,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.2211543318816052,
                                    0.028845668118394806,
                                    0.6634629956448156,
                                    0.08653700435518441,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.5446106644656876,
                                    0.013080671771101992,
                                    0.43193429701897834,
                                    0.01037436674423202,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.4319342970189784,
                                    0.010374366744232021,
                                    0.5446106644656875,
                                    0.013080671771101988,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974368,
                                    0.020481889783835576,
                                ],
                                [
                                    0.09490078268974368,
                                    0.020481889783835576,
                                    0.727586516791679,
                                    0.15703081073474182,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.5675111615975639,
                                    0.021245188661724874,
                                    0.39640398147924805,
                                    0.014839668261463263,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.396403981479248,
                                    0.014839668261463261,
                                    0.5675111615975639,
                                    0.021245188661724874,
                                ],
                                [
                                    0.7617635407441694,
                                    0.21478142074049653,
                                    0.018296334416152,
                                    0.005158704099182037,
                                ],
                                [
                                    0.018296334416152,
                                    0.005158704099182037,
                                    0.7617635407441694,
                                    0.21478142074049653,
                                ],
                                [
                                    0.028613742614516074,
                                    0.5813563198053232,
                                    0.018296334416152,
                                    0.3717336031640087,
                                ],
                                [
                                    0.5826985926755059,
                                    0.027271469744333386,
                                    0.3725918856208493,
                                    0.017438051959311425,
                                ],
                                [
                                    0.018296334416152003,
                                    0.3717336031640088,
                                    0.02861374261451607,
                                    0.5813563198053231,
                                ],
                                [
                                    0.3725918856208494,
                                    0.017438051959311432,
                                    0.5826985926755058,
                                    0.02727146974433338,
                                ],
                                [
                                    0.2639614896993748,
                                    0.0028887121709719418,
                                    0.7252132901931454,
                                    0.007936507936507938,
                                ],
                                [
                                    0.2175592245778225,
                                    0.0023809002618561236,
                                    0.7716155553146976,
                                    0.008444319845623756,
                                ],
                                [
                                    0.22787663277618653,
                                    0.011215846626220312,
                                    0.7252132901931454,
                                    0.035694230404447705,
                                ],
                                [
                                    0.23856634317320669,
                                    0.0005261362292001527,
                                    0.7592331014997701,
                                    0.0016744190978230543,
                                ],
                                [
                                    0.21755922457782245,
                                    0.010708034717104494,
                                    0.7355306983915094,
                                    0.036202042313563526,
                                ],
                                [
                                    0.22776494456150054,
                                    0.0005023147334264392,
                                    0.7700345001114762,
                                    0.0016982405935967678,
                                ],
                                [
                                    0.38653615988255313,
                                    0.021741885583182876,
                                    0.5602111956888659,
                                    0.03151075884539815,
                                ],
                                [
                                    0.16805967979630448,
                                    0.009453020722272998,
                                    0.7786876757751144,
                                    0.04379962370630803,
                                ],
                                [
                                    0.20902345936397562,
                                    0.06270566515085403,
                                    0.5602111956888659,
                                    0.1680596797963044,
                                ],
                                [
                                    0.26878759693234383,
                                    0.002941527582485838,
                                    0.7203871829601763,
                                    0.00788369252499404,
                                ],
                                [
                                    0.16805967979630448,
                                    0.050416800289944164,
                                    0.6011749752565371,
                                    0.18034854465721428,
                                ],
                                [
                                    0.21611142410100756,
                                    0.0023650559852410862,
                                    0.7730633557915125,
                                    0.008460164122238793,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.10206951136643398,
                                    0.01331316110714526,
                                    0.7825478161599868,
                                    0.10206951136643397,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.3120273015388952,
                                    0.007494393667552034,
                                    0.6645176599457707,
                                    0.015960644847781976,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.19935093409218593,
                                    0.004788088640682063,
                                    0.77719402739248,
                                    0.018666949874651947,
                                ],
                                [
                                    0.6764853578082433,
                                    0.14600194167317923,
                                    0.14600194167317931,
                                    0.03151075884539816,
                                ],
                                [
                                    0.04379962370630803,
                                    0.009453020722272993,
                                    0.7786876757751146,
                                    0.1680596797963044,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.35405978316728715,
                                    0.013254482730777548,
                                    0.6098553599095247,
                                    0.022830374192410588,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.18295260304897137,
                                    0.006848962330515939,
                                    0.7809625400278404,
                                    0.029235894592672198,
                                ],
                                [
                                    0.7519115261736411,
                                    0.2120036169031706,
                                    0.028148348986680227,
                                    0.007936507936507946,
                                ],
                                [
                                    0.008444319845623757,
                                    0.002380900261856124,
                                    0.7716155553146976,
                                    0.21755922457782245,
                                ],
                                [
                                    0.018761728043987846,
                                    0.3811891829664998,
                                    0.028148348986680227,
                                    0.5719007400028322,
                                ],
                                [
                                    0.38206929707427173,
                                    0.01788161393621591,
                                    0.5732211812220834,
                                    0.0268279077674289,
                                ],
                                [
                                    0.008444319845623775,
                                    0.17156646632518535,
                                    0.038465757185044296,
                                    0.7815234566441466,
                                ],
                                [
                                    0.17196259001961517,
                                    0.008048196151193955,
                                    0.78332788827674,
                                    0.03666132555245086,
                                ],
                                [
                                    0.09062779641185499,
                                    0.0009918023224579223,
                                    0.8985469834806651,
                                    0.009833417785021958,
                                ],
                                [
                                    0.04422553129030273,
                                    0.00048399041334210415,
                                    0.9449492486022174,
                                    0.010341229694137775,
                                ],
                                [
                                    0.05454293948866678,
                                    0.0026845457403653116,
                                    0.8985469834806652,
                                    0.044225531290302704,
                                ],
                                [
                                    0.0571015529815592,
                                    0.00012593224747288847,
                                    0.9406978916914176,
                                    0.0020746230795503184,
                                ],
                                [
                                    0.04422553129030271,
                                    0.0021767338312494943,
                                    0.9088643916790292,
                                    0.044733343199418525,
                                ],
                                [
                                    0.04630015436985303,
                                    0.00010211075169917488,
                                    0.9514992903031237,
                                    0.002098444575324032,
                                ],
                                [
                                    0.25263972295445003,
                                    0.01421047891589664,
                                    0.694107632616969,
                                    0.039042165512684385,
                                ],
                                [
                                    0.03416324286820143,
                                    0.0019216140549867611,
                                    0.9125841127032176,
                                    0.051331030373594266,
                                ],
                                [
                                    0.07512702243587255,
                                    0.022537613371145012,
                                    0.694107632616969,
                                    0.20822773157601343,
                                ],
                                [
                                    0.09660739462768973,
                                    0.001057241179327826,
                                    0.8925673852648304,
                                    0.009767978928152054,
                                ],
                                [
                                    0.0341632428682014,
                                    0.010248748510235136,
                                    0.7350714121846401,
                                    0.2205165964369233,
                                ],
                                [
                                    0.04393122179635347,
                                    0.0004807695820830743,
                                    0.9452435580961667,
                                    0.010344450525396804,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.020748733488464063,
                                    0.0027063050268699733,
                                    0.8638685940379567,
                                    0.11267636744670925,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.15320050973740476,
                                    0.003679629713102621,
                                    0.8233444517472612,
                                    0.019775408802231387,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.04052414229069548,
                                    0.0009733246862326505,
                                    0.9360208191939705,
                                    0.022481713829101357,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699423,
                                    0.0390421655126844,
                                ],
                                [
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                    0.8135836934289296,
                                    0.17559108646359065,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.20829786273122586,
                                    0.007797780362771213,
                                    0.755617280345586,
                                    0.028287076560416922,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.037190682612910114,
                                    0.0013922599625096046,
                                    0.9267244604639017,
                                    0.03469259696067853,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862289,
                                    0.009833417785021968,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.00048399041334210995,
                                    0.7783433102466403,
                                    0.21945613442633646,
                                ],
                                [
                                    0.012033973112045182,
                                    0.24449882055993738,
                                    0.03487610391862289,
                                    0.7085911024093945,
                                ],
                                [
                                    0.2450633351656084,
                                    0.01146945850637414,
                                    0.7102271431307468,
                                    0.03324006319727067,
                                ],
                                [
                                    0.0017165649136811048,
                                    0.034876103918622836,
                                    0.04519351211698697,
                                    0.9182138190507091,
                                ],
                                [
                                    0.03495662811095176,
                                    0.00163604072135218,
                                    0.9203338501854034,
                                    0.04307348098229263,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.8985469834806652,
                                    0.009833417785021958,
                                    0.09062779641185491,
                                    0.0009918023224579212,
                                ],
                                [
                                    0.9088643916790292,
                                    0.044733343199418525,
                                    0.04422553129030271,
                                    0.002176733831249494,
                                ],
                                [
                                    0.9432748295043943,
                                    0.01032290537405344,
                                    0.04589995038812576,
                                    0.0005023147334264392,
                                ],
                                [
                                    0.8985469834806652,
                                    0.044225531290302704,
                                    0.054542939488666765,
                                    0.002684545740365311,
                                ],
                                [
                                    0.9325667947872899,
                                    0.010205719983678052,
                                    0.056607985105230255,
                                    0.0006195001238018258,
                                ],
                                [
                                    0.9125841127032176,
                                    0.051331030373594266,
                                    0.034163242868201375,
                                    0.001921614054986758,
                                ],
                                [
                                    0.6941076326169691,
                                    0.03904216551268439,
                                    0.25263972295445,
                                    0.014210478915896635,
                                ],
                                [
                                    0.7350714121846401,
                                    0.2205165964369233,
                                    0.034163242868201375,
                                    0.010248748510235129,
                                ],
                                [
                                    0.9047004201782235,
                                    0.05088758844333994,
                                    0.04204693539319542,
                                    0.0023650559852410854,
                                ],
                                [
                                    0.694107632616969,
                                    0.20822773157601343,
                                    0.07512702243587252,
                                    0.022537613371145005,
                                ],
                                [
                                    0.8542836198882794,
                                    0.048051744304703055,
                                    0.09246373568313956,
                                    0.005200900123877967,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.4215599302747463,
                                    0.05498503120991964,
                                    0.46305739725167444,
                                    0.06039764126365958,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.8479079491901746,
                                    0.11059458383289715,
                                    0.03670937833624601,
                                    0.004788088640682062,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.7458384378237408,
                                    0.09728142272575191,
                                    0.13877888970268,
                                    0.018101249747827317,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                ],
                                [
                                    0.18089795932699423,
                                    0.0390421655126844,
                                    0.6415893401544284,
                                    0.13847053500589301,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.7907533192365189,
                                    0.17066373818806146,
                                    0.03173398024490372,
                                    0.006848962330515938,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.6447513775633397,
                                    0.1391529793426633,
                                    0.17773592191808296,
                                    0.03835972117591408,
                                ],
                                [
                                    0.7783433102466403,
                                    0.21945613442633646,
                                    0.001716564913681105,
                                    0.0004839904133421044,
                                ],
                                [
                                    0.03487610391862287,
                                    0.009833417785021965,
                                    0.7451837712416985,
                                    0.2101067070546566,
                                ],
                                [
                                    0.04519351211698697,
                                    0.9182138190507091,
                                    0.0017165649136811055,
                                    0.03487610391862285,
                                ],
                                [
                                    0.7515154024792113,
                                    0.2118919286884846,
                                    0.028544472681110006,
                                    0.008048196151193947,
                                ],
                                [
                                    0.03487610391862289,
                                    0.7085911024093945,
                                    0.012033973112045179,
                                    0.24449882055993732,
                                ],
                                [
                                    0.5799489361540262,
                                    0.1635182701739912,
                                    0.20011093900629515,
                                    0.05642185466568733,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7355306983915094,
                                    0.036202042313563526,
                                    0.21755922457782245,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7633785639227919,
                                    0.008354176782281113,
                                    0.22579621596972818,
                                    0.0024710433251987664,
                                ],
                                [
                                    0.7252132901931454,
                                    0.035694230404447705,
                                    0.2278766327761865,
                                    0.011215846626220312,
                                ],
                                [
                                    0.7526705292056874,
                                    0.008236991391905726,
                                    0.23650425068683267,
                                    0.002588228715574153,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.560211195688866,
                                    0.031510758845398154,
                                    0.386536159882553,
                                    0.02174188558318287,
                                ],
                                [
                                    0.6011749752565371,
                                    0.1803485446572143,
                                    0.1680596797963044,
                                    0.05041680028994414,
                                ],
                                [
                                    0.7399053257952114,
                                    0.04161819411854007,
                                    0.2068420297762076,
                                    0.011634450310040957,
                                ],
                                [
                                    0.5602111956888659,
                                    0.1680596797963044,
                                    0.20902345936397557,
                                    0.06270566515085402,
                                ],
                                [
                                    0.6894885255052672,
                                    0.03878234997990318,
                                    0.2572588300661518,
                                    0.014470294448677841,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.3402391523967764,
                                    0.04437817512964435,
                                    0.5443781751296444,
                                    0.07100449734393487,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.7040324107926159,
                                    0.09182856647451619,
                                    0.1805849167338049,
                                    0.023554105999063043,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.601962899426182,
                                    0.07851540536737092,
                                    0.28265442810023883,
                                    0.0368672671062083,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.6663779225351014,
                                    0.14382051208541127,
                                    0.15610937694632118,
                                    0.03369218843316612,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.5203759808619222,
                                    0.11230975324001313,
                                    0.30211131861950047,
                                    0.06520294727856427,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.03846575718504431,
                                    0.7815234566441468,
                                    0.008444319845623766,
                                    0.17156646632518516,
                                ],
                                [
                                    0.6396406837724089,
                                    0.18034853005678217,
                                    0.1404191913879125,
                                    0.0395915947828964,
                                ],
                                [
                                    0.02814834898668023,
                                    0.5719007400028322,
                                    0.018761728043987843,
                                    0.3811891829664997,
                                ],
                                [
                                    0.46807421744722366,
                                    0.13197487154228876,
                                    0.3119856577130977,
                                    0.0879652532973898,
                                ],
                                [
                                    0.5177885225070362,
                                    0.005666516008297848,
                                    0.47138625738548395,
                                    0.005158704099182031,
                                ],
                                [
                                    0.47138625738548395,
                                    0.005158704099182031,
                                    0.5177885225070362,
                                    0.005666516008297848,
                                ],
                                [
                                    0.481703665583848,
                                    0.023708944469891916,
                                    0.47138625738548395,
                                    0.023201132560776102,
                                ],
                                [
                                    0.4999414073048123,
                                    0.005471202748927633,
                                    0.4892333725877078,
                                    0.005354017358552246,
                                ],
                                [
                                    0.47138625738548395,
                                    0.023201132560776102,
                                    0.481703665583848,
                                    0.023708944469891916,
                                ],
                                [
                                    0.4892333725877078,
                                    0.005354017358552246,
                                    0.4999414073048123,
                                    0.005471202748927633,
                                ],
                                [
                                    0.5826119178288338,
                                    0.03277075464474545,
                                    0.36413543774258517,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3641354377425853,
                                    0.02048188978383558,
                                    0.5826119178288337,
                                    0.032770754644745444,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403416,
                                    0.36413543774258517,
                                    0.10923824004312428,
                                ],
                                [
                                    0.49858207793068154,
                                    0.028044244283608955,
                                    0.44816527764073744,
                                    0.02520840014497207,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312428,
                                    0.40509921731025633,
                                    0.12152710490403416,
                                ],
                                [
                                    0.44816527764073744,
                                    0.02520840014497207,
                                    0.49858207793068154,
                                    0.028044244283608955,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.2211543318816052,
                                    0.028845668118394806,
                                    0.6634629956448156,
                                    0.08653700435518441,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.4933434194464274,
                                    0.06434791679036225,
                                    0.3912739080799934,
                                    0.051034755683216984,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.3912739080799934,
                                    0.05103475568321699,
                                    0.49334341944642734,
                                    0.06434791679036224,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974368,
                                    0.020481889783835576,
                                ],
                                [
                                    0.09490078268974368,
                                    0.020481889783835576,
                                    0.727586516791679,
                                    0.15703081073474182,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.484244620577301,
                                    0.10451172968198778,
                                    0.3382426789041217,
                                    0.07300097083658963,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.33824267890412163,
                                    0.07300097083658962,
                                    0.484244620577301,
                                    0.10451172968198778,
                                ],
                                [
                                    0.7617635407441694,
                                    0.21478142074049653,
                                    0.018296334416152,
                                    0.005158704099182037,
                                ],
                                [
                                    0.018296334416152,
                                    0.005158704099182037,
                                    0.7617635407441694,
                                    0.21478142074049653,
                                ],
                                [
                                    0.028613742614516074,
                                    0.5813563198053232,
                                    0.018296334416152,
                                    0.3717336031640087,
                                ],
                                [
                                    0.4758131707427533,
                                    0.13415689167708597,
                                    0.30424670441756807,
                                    0.08578323316259258,
                                ],
                                [
                                    0.018296334416152003,
                                    0.3717336031640088,
                                    0.02861374261451607,
                                    0.5813563198053231,
                                ],
                                [
                                    0.3042467044175682,
                                    0.0857832331625926,
                                    0.4758131707427532,
                                    0.13415689167708597,
                                ],
                                [
                                    0.2639614896993748,
                                    0.0028887121709719418,
                                    0.7252132901931454,
                                    0.007936507936507938,
                                ],
                                [
                                    0.2175592245778225,
                                    0.0023809002618561236,
                                    0.7716155553146976,
                                    0.008444319845623756,
                                ],
                                [
                                    0.22787663277618653,
                                    0.011215846626220312,
                                    0.7252132901931454,
                                    0.035694230404447705,
                                ],
                                [
                                    0.2365042506868327,
                                    0.0025882287155741535,
                                    0.7526705292056874,
                                    0.008236991391905726,
                                ],
                                [
                                    0.21755922457782245,
                                    0.010708034717104494,
                                    0.7355306983915094,
                                    0.036202042313563526,
                                ],
                                [
                                    0.2257962159697282,
                                    0.002471043325198767,
                                    0.7633785639227919,
                                    0.008354176782281113,
                                ],
                                [
                                    0.38653615988255313,
                                    0.021741885583182876,
                                    0.5602111956888659,
                                    0.03151075884539815,
                                ],
                                [
                                    0.16805967979630448,
                                    0.009453020722272998,
                                    0.7786876757751144,
                                    0.04379962370630803,
                                ],
                                [
                                    0.20902345936397562,
                                    0.06270566515085403,
                                    0.5602111956888659,
                                    0.1680596797963044,
                                ],
                                [
                                    0.2572588300661518,
                                    0.014470294448677845,
                                    0.6894885255052672,
                                    0.03878234997990318,
                                ],
                                [
                                    0.16805967979630448,
                                    0.050416800289944164,
                                    0.6011749752565371,
                                    0.18034854465721428,
                                ],
                                [
                                    0.2068420297762077,
                                    0.011634450310040963,
                                    0.7399053257952113,
                                    0.041618194118540064,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.10206951136643398,
                                    0.01331316110714526,
                                    0.7825478161599868,
                                    0.10206951136643397,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.28265442810023894,
                                    0.03686726710620831,
                                    0.6019628994261819,
                                    0.07851540536737091,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.18058491673380495,
                                    0.02355410599906305,
                                    0.7040324107926158,
                                    0.09182856647451618,
                                ],
                                [
                                    0.6764853578082433,
                                    0.14600194167317923,
                                    0.14600194167317931,
                                    0.03151075884539816,
                                ],
                                [
                                    0.04379962370630803,
                                    0.009453020722272993,
                                    0.7786876757751146,
                                    0.1680596797963044,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.30211131861950047,
                                    0.06520294727856427,
                                    0.5203759808619222,
                                    0.11230975324001313,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.1561093769463212,
                                    0.033692188433166126,
                                    0.6663779225351014,
                                    0.14382051208541127,
                                ],
                                [
                                    0.7519115261736411,
                                    0.2120036169031706,
                                    0.028148348986680227,
                                    0.007936507936507946,
                                ],
                                [
                                    0.008444319845623757,
                                    0.002380900261856124,
                                    0.7716155553146976,
                                    0.21755922457782245,
                                ],
                                [
                                    0.018761728043987846,
                                    0.3811891829664998,
                                    0.028148348986680227,
                                    0.5719007400028322,
                                ],
                                [
                                    0.3119856577130978,
                                    0.08796525329738981,
                                    0.4680742174472236,
                                    0.13197487154228874,
                                ],
                                [
                                    0.008444319845623775,
                                    0.17156646632518535,
                                    0.038465757185044296,
                                    0.7815234566441466,
                                ],
                                [
                                    0.14041919138791267,
                                    0.03959159478289644,
                                    0.6396406837724087,
                                    0.1803485300567821,
                                ],
                                [
                                    0.09062779641185499,
                                    0.0009918023224579223,
                                    0.8985469834806651,
                                    0.009833417785021958,
                                ],
                                [
                                    0.04422553129030273,
                                    0.00048399041334210415,
                                    0.9449492486022174,
                                    0.010341229694137775,
                                ],
                                [
                                    0.05454293948866678,
                                    0.0026845457403653116,
                                    0.8985469834806652,
                                    0.044225531290302704,
                                ],
                                [
                                    0.05660798510523027,
                                    0.000619500123801826,
                                    0.9325667947872899,
                                    0.010205719983678052,
                                ],
                                [
                                    0.04422553129030271,
                                    0.0021767338312494943,
                                    0.9088643916790292,
                                    0.044733343199418525,
                                ],
                                [
                                    0.04589995038812577,
                                    0.0005023147334264393,
                                    0.9432748295043943,
                                    0.01032290537405344,
                                ],
                                [
                                    0.25263972295445003,
                                    0.01421047891589664,
                                    0.694107632616969,
                                    0.039042165512684385,
                                ],
                                [
                                    0.03416324286820143,
                                    0.0019216140549867611,
                                    0.9125841127032176,
                                    0.051331030373594266,
                                ],
                                [
                                    0.07512702243587255,
                                    0.022537613371145012,
                                    0.694107632616969,
                                    0.20822773157601343,
                                ],
                                [
                                    0.09246373568313959,
                                    0.005200900123877969,
                                    0.8542836198882794,
                                    0.048051744304703055,
                                ],
                                [
                                    0.0341632428682014,
                                    0.010248748510235136,
                                    0.7350714121846401,
                                    0.2205165964369233,
                                ],
                                [
                                    0.042046935393195456,
                                    0.0023650559852410875,
                                    0.9047004201782235,
                                    0.05088758844333994,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.020748733488464063,
                                    0.0027063050268699733,
                                    0.8638685940379567,
                                    0.11267636744670925,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.13877888970268004,
                                    0.018101249747827328,
                                    0.7458384378237407,
                                    0.0972814227257519,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.03670937833624606,
                                    0.004788088640682068,
                                    0.8479079491901746,
                                    0.11059458383289715,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699423,
                                    0.0390421655126844,
                                ],
                                [
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                    0.8135836934289296,
                                    0.17559108646359065,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.17773592191808302,
                                    0.038359721175914095,
                                    0.6447513775633397,
                                    0.1391529793426633,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.03173398024490377,
                                    0.006848962330515951,
                                    0.7907533192365188,
                                    0.17066373818806144,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862289,
                                    0.009833417785021968,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.00048399041334210995,
                                    0.7783433102466403,
                                    0.21945613442633646,
                                ],
                                [
                                    0.012033973112045182,
                                    0.24449882055993738,
                                    0.03487610391862289,
                                    0.7085911024093945,
                                ],
                                [
                                    0.2001109390062952,
                                    0.056421854665687346,
                                    0.5799489361540262,
                                    0.1635182701739912,
                                ],
                                [
                                    0.0017165649136811048,
                                    0.034876103918622836,
                                    0.04519351211698697,
                                    0.9182138190507091,
                                ],
                                [
                                    0.028544472681109996,
                                    0.008048196151193943,
                                    0.7515154024792113,
                                    0.2118919286884846,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.8985469834806652,
                                    0.009833417785021958,
                                    0.09062779641185491,
                                    0.0009918023224579212,
                                ],
                                [
                                    0.9088643916790292,
                                    0.044733343199418525,
                                    0.04422553129030271,
                                    0.002176733831249494,
                                ],
                                [
                                    0.9312310632787385,
                                    0.022366671599709263,
                                    0.045313898205927454,
                                    0.001088366915624747,
                                ],
                                [
                                    0.8985469834806652,
                                    0.044225531290302704,
                                    0.054542939488666765,
                                    0.002684545740365311,
                                ],
                                [
                                    0.9206597491258165,
                                    0.022112765645151352,
                                    0.05588521235884942,
                                    0.0013422728701826556,
                                ],
                                [
                                    0.9125841127032176,
                                    0.051331030373594266,
                                    0.034163242868201375,
                                    0.001921614054986758,
                                ],
                                [
                                    0.6941076326169691,
                                    0.03904216551268439,
                                    0.25263972295445,
                                    0.014210478915896635,
                                ],
                                [
                                    0.7350714121846401,
                                    0.2205165964369233,
                                    0.034163242868201375,
                                    0.010248748510235129,
                                ],
                                [
                                    0.8453297104031018,
                                    0.11025829821846166,
                                    0.03928761712331894,
                                    0.005124374255117564,
                                ],
                                [
                                    0.694107632616969,
                                    0.20822773157601343,
                                    0.07512702243587252,
                                    0.022537613371145005,
                                ],
                                [
                                    0.7982214984049757,
                                    0.10411386578800672,
                                    0.08639582912144503,
                                    0.011268806685572503,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.4215599302747463,
                                    0.05498503120991964,
                                    0.46305739725167444,
                                    0.06039764126365958,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.7188768997673038,
                                    0.23962563325576797,
                                    0.031123100232696058,
                                    0.01037436674423202,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.6323398954121195,
                                    0.21077996513737318,
                                    0.11766010458788048,
                                    0.039220034862626825,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                ],
                                [
                                    0.18089795932699423,
                                    0.0390421655126844,
                                    0.6415893401544284,
                                    0.13847053500589301,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.5916393981596229,
                                    0.3697776592649575,
                                    0.023743274313956387,
                                    0.014839668261463265,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.4824011581164986,
                                    0.3015031987895043,
                                    0.13298151435708067,
                                    0.08311412873691638,
                                ],
                                [
                                    0.7783433102466403,
                                    0.21945613442633646,
                                    0.001716564913681105,
                                    0.0004839904133421044,
                                ],
                                [
                                    0.03487610391862287,
                                    0.009833417785021965,
                                    0.7451837712416985,
                                    0.2101067070546566,
                                ],
                                [
                                    0.04519351211698697,
                                    0.9182138190507091,
                                    0.0017165649136811055,
                                    0.03487610391862285,
                                ],
                                [
                                    0.5043004216423416,
                                    0.45910690952535455,
                                    0.019154616872992532,
                                    0.017438051959311425,
                                ],
                                [
                                    0.03487610391862289,
                                    0.7085911024093945,
                                    0.012033973112045179,
                                    0.24449882055993732,
                                ],
                                [
                                    0.3891716551233202,
                                    0.35429555120469725,
                                    0.13428338339201384,
                                    0.12224941027996866,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7355306983915094,
                                    0.036202042313563526,
                                    0.21755922457782245,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7536317195482912,
                                    0.018101021156781763,
                                    0.22291324193637468,
                                    0.005354017358552247,
                                ],
                                [
                                    0.7252132901931454,
                                    0.035694230404447705,
                                    0.2278766327761865,
                                    0.011215846626220312,
                                ],
                                [
                                    0.7430604053953692,
                                    0.017847115202223852,
                                    0.23348455608929666,
                                    0.005607923313110156,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.560211195688866,
                                    0.031510758845398154,
                                    0.386536159882553,
                                    0.02174188558318287,
                                ],
                                [
                                    0.6011749752565371,
                                    0.1803485446572143,
                                    0.1680596797963044,
                                    0.05041680028994414,
                                ],
                                [
                                    0.6913492475851443,
                                    0.09017427232860716,
                                    0.19326807994127648,
                                    0.02520840014497207,
                                ],
                                [
                                    0.5602111956888659,
                                    0.1680596797963044,
                                    0.20902345936397557,
                                    0.06270566515085402,
                                ],
                                [
                                    0.6442410355870181,
                                    0.0840298398981522,
                                    0.2403762919394026,
                                    0.03135283257542701,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.3402391523967764,
                                    0.04437817512964435,
                                    0.5443781751296444,
                                    0.07100449734393487,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.596895732950349,
                                    0.19896524431678303,
                                    0.15310426704965097,
                                    0.051034755683216984,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.5103587285951646,
                                    0.17011957619838822,
                                    0.23964127140483535,
                                    0.07988042380161178,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.49858207793068154,
                                    0.3116163566898311,
                                    0.11680059454289768,
                                    0.07300097083658963,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.3893438378875573,
                                    0.243341896214378,
                                    0.22603883458602195,
                                    0.14127543131204276,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.03846575718504431,
                                    0.7815234566441468,
                                    0.008444319845623766,
                                    0.17156646632518516,
                                ],
                                [
                                    0.4292274855071177,
                                    0.3907617283220734,
                                    0.09422755300821635,
                                    0.08578323316259258,
                                ],
                                [
                                    0.02814834898668023,
                                    0.5719007400028322,
                                    0.018761728043987843,
                                    0.3811891829664997,
                                ],
                                [
                                    0.3140987189880964,
                                    0.2859503700014161,
                                    0.20935631952723768,
                                    0.19059459148324984,
                                ],
                                [
                                    0.5177885225070362,
                                    0.005666516008297848,
                                    0.47138625738548395,
                                    0.005158704099182031,
                                ],
                                [
                                    0.47138625738548395,
                                    0.005158704099182031,
                                    0.5177885225070362,
                                    0.005666516008297848,
                                ],
                                [
                                    0.481703665583848,
                                    0.023708944469891916,
                                    0.47138625738548395,
                                    0.023201132560776102,
                                ],
                                [
                                    0.493558137818794,
                                    0.011854472234945958,
                                    0.482986823665872,
                                    0.011600566280388051,
                                ],
                                [
                                    0.47138625738548395,
                                    0.023201132560776102,
                                    0.481703665583848,
                                    0.023708944469891916,
                                ],
                                [
                                    0.482986823665872,
                                    0.011600566280388051,
                                    0.493558137818794,
                                    0.011854472234945958,
                                ],
                                [
                                    0.5826119178288338,
                                    0.03277075464474545,
                                    0.36413543774258517,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3641354377425853,
                                    0.02048188978383558,
                                    0.5826119178288337,
                                    0.032770754644745444,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403416,
                                    0.36413543774258517,
                                    0.10923824004312428,
                                ],
                                [
                                    0.4658627697622734,
                                    0.06076355245201708,
                                    0.41875455776414733,
                                    0.05461912002156214,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312428,
                                    0.40509921731025633,
                                    0.12152710490403416,
                                ],
                                [
                                    0.41875455776414733,
                                    0.05461912002156214,
                                    0.4658627697622734,
                                    0.06076355245201708,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.2211543318816052,
                                    0.028845668118394806,
                                    0.6634629956448156,
                                    0.08653700435518441,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.41826850217759226,
                                    0.13942283405919742,
                                    0.3317314978224078,
                                    0.1105771659408026,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.33173149782240785,
                                    0.11057716594080261,
                                    0.41826850217759215,
                                    0.1394228340591974,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974368,
                                    0.020481889783835576,
                                ],
                                [
                                    0.09490078268974368,
                                    0.020481889783835576,
                                    0.727586516791679,
                                    0.15703081073474182,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.3623104562583518,
                                    0.22644589400093695,
                                    0.2530722162152275,
                                    0.15817143352548382,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.25307221621522746,
                                    0.1581714335254838,
                                    0.3623104562583518,
                                    0.22644589400093695,
                                ],
                                [
                                    0.7617635407441694,
                                    0.21478142074049653,
                                    0.018296334416152,
                                    0.005158704099182037,
                                ],
                                [
                                    0.018296334416152,
                                    0.005158704099182037,
                                    0.7617635407441694,
                                    0.21478142074049653,
                                ],
                                [
                                    0.028613742614516074,
                                    0.5813563198053232,
                                    0.018296334416152,
                                    0.3717336031640087,
                                ],
                                [
                                    0.3192919025171777,
                                    0.2906781599026616,
                                    0.20416313599815633,
                                    0.18586680158200436,
                                ],
                                [
                                    0.018296334416152003,
                                    0.3717336031640088,
                                    0.02861374261451607,
                                    0.5813563198053231,
                                ],
                                [
                                    0.20416313599815641,
                                    0.1858668015820044,
                                    0.31929190251717765,
                                    0.29067815990266155,
                                ],
                                [
                                    0.2639614896993748,
                                    0.0028887121709719418,
                                    0.7252132901931454,
                                    0.007936507936507938,
                                ],
                                [
                                    0.2175592245778225,
                                    0.0023809002618561236,
                                    0.7716155553146976,
                                    0.008444319845623756,
                                ],
                                [
                                    0.22787663277618653,
                                    0.011215846626220312,
                                    0.7252132901931454,
                                    0.035694230404447705,
                                ],
                                [
                                    0.2334845560892967,
                                    0.005607923313110156,
                                    0.7430604053953692,
                                    0.017847115202223852,
                                ],
                                [
                                    0.21755922457782245,
                                    0.010708034717104494,
                                    0.7355306983915094,
                                    0.036202042313563526,
                                ],
                                [
                                    0.2229132419363747,
                                    0.005354017358552247,
                                    0.7536317195482912,
                                    0.018101021156781763,
                                ],
                                [
                                    0.38653615988255313,
                                    0.021741885583182876,
                                    0.5602111956888659,
                                    0.03151075884539815,
                                ],
                                [
                                    0.16805967979630448,
                                    0.009453020722272998,
                                    0.7786876757751144,
                                    0.04379962370630803,
                                ],
                                [
                                    0.20902345936397562,
                                    0.06270566515085403,
                                    0.5602111956888659,
                                    0.1680596797963044,
                                ],
                                [
                                    0.24037629193940263,
                                    0.031352832575427016,
                                    0.6442410355870181,
                                    0.0840298398981522,
                                ],
                                [
                                    0.16805967979630448,
                                    0.050416800289944164,
                                    0.6011749752565371,
                                    0.18034854465721428,
                                ],
                                [
                                    0.19326807994127657,
                                    0.025208400144972082,
                                    0.6913492475851442,
                                    0.09017427232860714,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.10206951136643398,
                                    0.01331316110714526,
                                    0.7825478161599868,
                                    0.10206951136643397,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.23964127140483543,
                                    0.07988042380161181,
                                    0.5103587285951645,
                                    0.1701195761983882,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.153104267049651,
                                    0.051034755683217,
                                    0.596895732950349,
                                    0.198965244316783,
                                ],
                                [
                                    0.6764853578082433,
                                    0.14600194167317923,
                                    0.14600194167317931,
                                    0.03151075884539816,
                                ],
                                [
                                    0.04379962370630803,
                                    0.009453020722272993,
                                    0.7786876757751146,
                                    0.1680596797963044,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.22603883458602195,
                                    0.14127543131204276,
                                    0.3893438378875573,
                                    0.243341896214378,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.11680059454289769,
                                    0.07300097083658964,
                                    0.49858207793068154,
                                    0.3116163566898311,
                                ],
                                [
                                    0.7519115261736411,
                                    0.2120036169031706,
                                    0.028148348986680227,
                                    0.007936507936507946,
                                ],
                                [
                                    0.008444319845623757,
                                    0.002380900261856124,
                                    0.7716155553146976,
                                    0.21755922457782245,
                                ],
                                [
                                    0.018761728043987846,
                                    0.3811891829664998,
                                    0.028148348986680227,
                                    0.5719007400028322,
                                ],
                                [
                                    0.20935631952723774,
                                    0.1905945914832499,
                                    0.31409871898809627,
                                    0.2859503700014161,
                                ],
                                [
                                    0.008444319845623775,
                                    0.17156646632518535,
                                    0.038465757185044296,
                                    0.7815234566441466,
                                ],
                                [
                                    0.09422755300821645,
                                    0.08578323316259268,
                                    0.4292274855071176,
                                    0.3907617283220733,
                                ],
                                [
                                    0.09062779641185499,
                                    0.0009918023224579223,
                                    0.8985469834806651,
                                    0.009833417785021958,
                                ],
                                [
                                    0.04422553129030273,
                                    0.00048399041334210415,
                                    0.9449492486022174,
                                    0.010341229694137775,
                                ],
                                [
                                    0.05454293948866678,
                                    0.0026845457403653116,
                                    0.8985469834806652,
                                    0.044225531290302704,
                                ],
                                [
                                    0.05588521235884943,
                                    0.0013422728701826558,
                                    0.9206597491258165,
                                    0.022112765645151352,
                                ],
                                [
                                    0.04422553129030271,
                                    0.0021767338312494943,
                                    0.9088643916790292,
                                    0.044733343199418525,
                                ],
                                [
                                    0.04531389820592746,
                                    0.0010883669156247471,
                                    0.9312310632787385,
                                    0.022366671599709263,
                                ],
                                [
                                    0.25263972295445003,
                                    0.01421047891589664,
                                    0.694107632616969,
                                    0.039042165512684385,
                                ],
                                [
                                    0.03416324286820143,
                                    0.0019216140549867611,
                                    0.9125841127032176,
                                    0.051331030373594266,
                                ],
                                [
                                    0.07512702243587255,
                                    0.022537613371145012,
                                    0.694107632616969,
                                    0.20822773157601343,
                                ],
                                [
                                    0.08639582912144506,
                                    0.011268806685572506,
                                    0.7982214984049757,
                                    0.10411386578800672,
                                ],
                                [
                                    0.0341632428682014,
                                    0.010248748510235136,
                                    0.7350714121846401,
                                    0.2205165964369233,
                                ],
                                [
                                    0.03928761712331898,
                                    0.005124374255117568,
                                    0.8453297104031018,
                                    0.11025829821846166,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.020748733488464063,
                                    0.0027063050268699733,
                                    0.8638685940379567,
                                    0.11267636744670925,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.11766010458788054,
                                    0.039220034862626846,
                                    0.6323398954121194,
                                    0.21077996513737315,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.0311231002326961,
                                    0.010374366744232033,
                                    0.7188768997673038,
                                    0.23962563325576797,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699423,
                                    0.0390421655126844,
                                ],
                                [
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                    0.8135836934289296,
                                    0.17559108646359065,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.1329815143570807,
                                    0.0831141287369164,
                                    0.4824011581164986,
                                    0.3015031987895043,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.023743274313956432,
                                    0.01483966826146329,
                                    0.5916393981596229,
                                    0.3697776592649575,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862289,
                                    0.009833417785021968,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.00048399041334210995,
                                    0.7783433102466403,
                                    0.21945613442633646,
                                ],
                                [
                                    0.012033973112045182,
                                    0.24449882055993738,
                                    0.03487610391862289,
                                    0.7085911024093945,
                                ],
                                [
                                    0.13428338339201387,
                                    0.12224941027996869,
                                    0.3891716551233202,
                                    0.35429555120469725,
                                ],
                                [
                                    0.0017165649136811048,
                                    0.034876103918622836,
                                    0.04519351211698697,
                                    0.9182138190507091,
                                ],
                                [
                                    0.019154616872992525,
                                    0.017438051959311418,
                                    0.5043004216423416,
                                    0.45910690952535455,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.8985469834806652,
                                    0.009833417785021958,
                                    0.09062779641185491,
                                    0.0009918023224579212,
                                ],
                                [
                                    0.9088643916790292,
                                    0.044733343199418525,
                                    0.04422553129030271,
                                    0.002176733831249494,
                                ],
                                [
                                    0.9191872970530827,
                                    0.034410437825365084,
                                    0.044727846023729145,
                                    0.0016744190978230545,
                                ],
                                [
                                    0.8985469834806652,
                                    0.044225531290302704,
                                    0.054542939488666765,
                                    0.002684545740365311,
                                ],
                                [
                                    0.9087527034643432,
                                    0.03401981130662465,
                                    0.05516243961246859,
                                    0.002065045616563485,
                                ],
                                [
                                    0.9125841127032176,
                                    0.051331030373594266,
                                    0.034163242868201375,
                                    0.001921614054986758,
                                ],
                                [
                                    0.6941076326169691,
                                    0.03904216551268439,
                                    0.25263972295445,
                                    0.014210478915896635,
                                ],
                                [
                                    0.7350714121846401,
                                    0.2205165964369233,
                                    0.034163242868201375,
                                    0.010248748510235129,
                                ],
                                [
                                    0.7859590006279802,
                                    0.16962900799358335,
                                    0.03652829885344247,
                                    0.00788369252499404,
                                ],
                                [
                                    0.694107632616969,
                                    0.20822773157601343,
                                    0.07512702243587252,
                                    0.022537613371145005,
                                ],
                                [
                                    0.7421593769216721,
                                    0.16017598727131035,
                                    0.0803279225597505,
                                    0.017336713247267033,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.4215599302747463,
                                    0.05498503120991964,
                                    0.46305739725167444,
                                    0.06039764126365958,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.5898458503444332,
                                    0.36865668267863877,
                                    0.0255368221291461,
                                    0.015960644847781976,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.5188413530004983,
                                    0.32427850754899445,
                                    0.09654131947308098,
                                    0.06033881997742633,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                ],
                                [
                                    0.18089795932699423,
                                    0.0390421655126844,
                                    0.6415893401544284,
                                    0.13847053500589301,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.39252547708272695,
                                    0.5688915803418535,
                                    0.015752568383009063,
                                    0.022830374192410588,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.32005093866965756,
                                    0.46385341823634535,
                                    0.08822710679607838,
                                    0.12786853629791867,
                                ],
                                [
                                    0.7783433102466403,
                                    0.21945613442633646,
                                    0.001716564913681105,
                                    0.0004839904133421044,
                                ],
                                [
                                    0.03487610391862287,
                                    0.009833417785021965,
                                    0.7451837712416985,
                                    0.2101067070546566,
                                ],
                                [
                                    0.04519351211698697,
                                    0.9182138190507091,
                                    0.0017165649136811055,
                                    0.03487610391862285,
                                ],
                                [
                                    0.25708544080547163,
                                    0.7063218903622244,
                                    0.009764761064875055,
                                    0.026827907767428903,
                                ],
                                [
                                    0.03487610391862289,
                                    0.7085911024093945,
                                    0.012033973112045179,
                                    0.24449882055993732,
                                ],
                                [
                                    0.19839437409261415,
                                    0.5450728322354033,
                                    0.06845582777773253,
                                    0.18807696589424996,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7355306983915094,
                                    0.036202042313563526,
                                    0.21755922457782245,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7438848751737905,
                                    0.02784786553128241,
                                    0.22003026790302121,
                                    0.008236991391905726,
                                ],
                                [
                                    0.7252132901931454,
                                    0.035694230404447705,
                                    0.2278766327761865,
                                    0.011215846626220312,
                                ],
                                [
                                    0.7334502815850511,
                                    0.02745723901254198,
                                    0.23046486149176065,
                                    0.008627617910646156,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.560211195688866,
                                    0.031510758845398154,
                                    0.386536159882553,
                                    0.02174188558318287,
                                ],
                                [
                                    0.6011749752565371,
                                    0.1803485446572143,
                                    0.1680596797963044,
                                    0.05041680028994414,
                                ],
                                [
                                    0.6427931693750772,
                                    0.13873035053867422,
                                    0.17969413010634538,
                                    0.03878234997990318,
                                ],
                                [
                                    0.5602111956888659,
                                    0.1680596797963044,
                                    0.20902345936397557,
                                    0.06270566515085402,
                                ],
                                [
                                    0.5989935456687692,
                                    0.12927732981640122,
                                    0.22349375381265343,
                                    0.04823537070217618,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.3402391523967764,
                                    0.04437817512964435,
                                    0.5443781751296444,
                                    0.07100449734393487,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.48975905510808226,
                                    0.30610192215904986,
                                    0.12562361736549701,
                                    0.07851540536737092,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.4187545577641474,
                                    0.2617237470294055,
                                    0.19662811470943187,
                                    0.12289358049701526,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.3307862333262618,
                                    0.4794122012942509,
                                    0.07749181213947418,
                                    0.11230975324001313,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.2583116949131925,
                                    0.3743740391887428,
                                    0.1499663505525435,
                                    0.2173479153455212,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.03846575718504431,
                                    0.7815234566441468,
                                    0.008444319845623766,
                                    0.17156646632518516,
                                ],
                                [
                                    0.21881428724182653,
                                    0.6011749265873646,
                                    0.04803591462852017,
                                    0.13197487154228876,
                                ],
                                [
                                    0.02814834898668023,
                                    0.5719007400028322,
                                    0.018761728043987843,
                                    0.3811891829664997,
                                ],
                                [
                                    0.16012322052896905,
                                    0.43992586846054343,
                                    0.10672698134137766,
                                    0.2932239296691099,
                                ],
                                [
                                    0.5177885225070362,
                                    0.005666516008297848,
                                    0.47138625738548395,
                                    0.005158704099182031,
                                ],
                                [
                                    0.47138625738548395,
                                    0.005158704099182031,
                                    0.5177885225070362,
                                    0.005666516008297848,
                                ],
                                [
                                    0.481703665583848,
                                    0.023708944469891916,
                                    0.47138625738548395,
                                    0.023201132560776102,
                                ],
                                [
                                    0.4871748683327756,
                                    0.018237741720964283,
                                    0.4767402747440362,
                                    0.017847115202223852,
                                ],
                                [
                                    0.47138625738548395,
                                    0.023201132560776102,
                                    0.481703665583848,
                                    0.023708944469891916,
                                ],
                                [
                                    0.4767402747440362,
                                    0.017847115202223852,
                                    0.4871748683327756,
                                    0.018237741720964283,
                                ],
                                [
                                    0.5826119178288338,
                                    0.03277075464474545,
                                    0.36413543774258517,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3641354377425853,
                                    0.02048188978383558,
                                    0.5826119178288337,
                                    0.032770754644745444,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403416,
                                    0.36413543774258517,
                                    0.10923824004312428,
                                ],
                                [
                                    0.43314346159386535,
                                    0.0934828606204252,
                                    0.3893438378875573,
                                    0.0840298398981522,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312428,
                                    0.40509921731025633,
                                    0.12152710490403416,
                                ],
                                [
                                    0.3893438378875573,
                                    0.0840298398981522,
                                    0.43314346159386535,
                                    0.0934828606204252,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.2211543318816052,
                                    0.028845668118394806,
                                    0.6634629956448156,
                                    0.08653700435518441,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.3431935849087571,
                                    0.2144977513280326,
                                    0.2721890875648222,
                                    0.1701195761983882,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.27218908756482224,
                                    0.17011957619838822,
                                    0.343193584908757,
                                    0.21449775132803253,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974368,
                                    0.020481889783835576,
                                ],
                                [
                                    0.09490078268974368,
                                    0.020481889783835576,
                                    0.727586516791679,
                                    0.15703081073474182,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.24037629193940266,
                                    0.34838005831988605,
                                    0.16790175352633332,
                                    0.243341896214378,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.16790175352633332,
                                    0.24334189621437793,
                                    0.24037629193940266,
                                    0.34838005831988605,
                                ],
                                [
                                    0.7617635407441694,
                                    0.21478142074049653,
                                    0.018296334416152,
                                    0.005158704099182037,
                                ],
                                [
                                    0.018296334416152,
                                    0.005158704099182037,
                                    0.7617635407441694,
                                    0.21478142074049653,
                                ],
                                [
                                    0.028613742614516074,
                                    0.5813563198053232,
                                    0.018296334416152,
                                    0.3717336031640087,
                                ],
                                [
                                    0.1627706342916021,
                                    0.4471994281282372,
                                    0.1040795675787446,
                                    0.2859503700014161,
                                ],
                                [
                                    0.018296334416152003,
                                    0.3717336031640088,
                                    0.02861374261451607,
                                    0.5813563198053231,
                                ],
                                [
                                    0.10407956757874463,
                                    0.28595037000141615,
                                    0.16277063429160207,
                                    0.44719942812823715,
                                ],
                                [
                                    0.2639614896993748,
                                    0.0028887121709719418,
                                    0.7252132901931454,
                                    0.007936507936507938,
                                ],
                                [
                                    0.2175592245778225,
                                    0.0023809002618561236,
                                    0.7716155553146976,
                                    0.008444319845623756,
                                ],
                                [
                                    0.22787663277618653,
                                    0.011215846626220312,
                                    0.7252132901931454,
                                    0.035694230404447705,
                                ],
                                [
                                    0.23046486149176068,
                                    0.008627617910646158,
                                    0.7334502815850511,
                                    0.02745723901254198,
                                ],
                                [
                                    0.21755922457782245,
                                    0.010708034717104494,
                                    0.7355306983915094,
                                    0.036202042313563526,
                                ],
                                [
                                    0.22003026790302124,
                                    0.008236991391905727,
                                    0.7438848751737905,
                                    0.02784786553128241,
                                ],
                                [
                                    0.38653615988255313,
                                    0.021741885583182876,
                                    0.5602111956888659,
                                    0.03151075884539815,
                                ],
                                [
                                    0.16805967979630448,
                                    0.009453020722272998,
                                    0.7786876757751144,
                                    0.04379962370630803,
                                ],
                                [
                                    0.20902345936397562,
                                    0.06270566515085403,
                                    0.5602111956888659,
                                    0.1680596797963044,
                                ],
                                [
                                    0.2234937538126535,
                                    0.048235370702176185,
                                    0.5989935456687692,
                                    0.12927732981640122,
                                ],
                                [
                                    0.16805967979630448,
                                    0.050416800289944164,
                                    0.6011749752565371,
                                    0.18034854465721428,
                                ],
                                [
                                    0.17969413010634547,
                                    0.038782349979903194,
                                    0.6427931693750771,
                                    0.1387303505386742,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.10206951136643398,
                                    0.01331316110714526,
                                    0.7825478161599868,
                                    0.10206951136643397,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.19662811470943195,
                                    0.1228935804970153,
                                    0.41875455776414733,
                                    0.26172374702940543,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.12562361736549704,
                                    0.07851540536737094,
                                    0.4897590551080822,
                                    0.3061019221590498,
                                ],
                                [
                                    0.6764853578082433,
                                    0.14600194167317923,
                                    0.14600194167317931,
                                    0.03151075884539816,
                                ],
                                [
                                    0.04379962370630803,
                                    0.009453020722272993,
                                    0.7786876757751146,
                                    0.1680596797963044,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.1499663505525435,
                                    0.2173479153455212,
                                    0.2583116949131925,
                                    0.3743740391887428,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.07749181213947419,
                                    0.11230975324001315,
                                    0.3307862333262618,
                                    0.4794122012942509,
                                ],
                                [
                                    0.7519115261736411,
                                    0.2120036169031706,
                                    0.028148348986680227,
                                    0.007936507936507946,
                                ],
                                [
                                    0.008444319845623757,
                                    0.002380900261856124,
                                    0.7716155553146976,
                                    0.21755922457782245,
                                ],
                                [
                                    0.018761728043987846,
                                    0.3811891829664998,
                                    0.028148348986680227,
                                    0.5719007400028322,
                                ],
                                [
                                    0.10672698134137769,
                                    0.29322392966910993,
                                    0.160123220528969,
                                    0.4399258684605434,
                                ],
                                [
                                    0.008444319845623775,
                                    0.17156646632518535,
                                    0.038465757185044296,
                                    0.7815234566441466,
                                ],
                                [
                                    0.04803591462852023,
                                    0.1319748715422889,
                                    0.21881428724182647,
                                    0.6011749265873644,
                                ],
                                [
                                    0.09062779641185499,
                                    0.0009918023224579223,
                                    0.8985469834806651,
                                    0.009833417785021958,
                                ],
                                [
                                    0.04422553129030273,
                                    0.00048399041334210415,
                                    0.9449492486022174,
                                    0.010341229694137775,
                                ],
                                [
                                    0.05454293948866678,
                                    0.0026845457403653116,
                                    0.8985469834806652,
                                    0.044225531290302704,
                                ],
                                [
                                    0.055162439612468604,
                                    0.0020650456165634853,
                                    0.9087527034643432,
                                    0.03401981130662465,
                                ],
                                [
                                    0.04422553129030271,
                                    0.0021767338312494943,
                                    0.9088643916790292,
                                    0.044733343199418525,
                                ],
                                [
                                    0.04472784602372915,
                                    0.0016744190978230547,
                                    0.9191872970530827,
                                    0.034410437825365084,
                                ],
                                [
                                    0.25263972295445003,
                                    0.01421047891589664,
                                    0.694107632616969,
                                    0.039042165512684385,
                                ],
                                [
                                    0.03416324286820143,
                                    0.0019216140549867611,
                                    0.9125841127032176,
                                    0.051331030373594266,
                                ],
                                [
                                    0.07512702243587255,
                                    0.022537613371145012,
                                    0.694107632616969,
                                    0.20822773157601343,
                                ],
                                [
                                    0.08032792255975053,
                                    0.01733671324726704,
                                    0.7421593769216721,
                                    0.16017598727131035,
                                ],
                                [
                                    0.0341632428682014,
                                    0.010248748510235136,
                                    0.7350714121846401,
                                    0.2205165964369233,
                                ],
                                [
                                    0.0365282988534425,
                                    0.007883692524994048,
                                    0.7859590006279802,
                                    0.16962900799358335,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.020748733488464063,
                                    0.0027063050268699733,
                                    0.8638685940379567,
                                    0.11267636744670925,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.09654131947308102,
                                    0.06033881997742636,
                                    0.5188413530004983,
                                    0.3242785075489944,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.025536822129146135,
                                    0.015960644847781997,
                                    0.5898458503444332,
                                    0.36865668267863877,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699423,
                                    0.0390421655126844,
                                ],
                                [
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                    0.8135836934289296,
                                    0.17559108646359065,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.0882271067960784,
                                    0.1278685362979187,
                                    0.32005093866965756,
                                    0.46385341823634535,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.015752568383009095,
                                    0.022830374192410626,
                                    0.3925254770827269,
                                    0.5688915803418534,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862289,
                                    0.009833417785021968,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.00048399041334210995,
                                    0.7783433102466403,
                                    0.21945613442633646,
                                ],
                                [
                                    0.012033973112045182,
                                    0.24449882055993738,
                                    0.03487610391862289,
                                    0.7085911024093945,
                                ],
                                [
                                    0.06845582777773254,
                                    0.18807696589425002,
                                    0.19839437409261415,
                                    0.5450728322354033,
                                ],
                                [
                                    0.0017165649136811048,
                                    0.034876103918622836,
                                    0.04519351211698697,
                                    0.9182138190507091,
                                ],
                                [
                                    0.00976476106487505,
                                    0.026827907767428893,
                                    0.25708544080547163,
                                    0.7063218903622244,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.8985469834806652,
                                    0.009833417785021958,
                                    0.09062779641185491,
                                    0.0009918023224579212,
                                ],
                                [
                                    0.9088643916790292,
                                    0.044733343199418525,
                                    0.04422553129030271,
                                    0.002176733831249494,
                                ],
                                [
                                    0.9109628362543533,
                                    0.04263489862409449,
                                    0.04432764204200188,
                                    0.002074623079550319,
                                ],
                                [
                                    0.8985469834806652,
                                    0.044225531290302704,
                                    0.054542939488666765,
                                    0.002684545740365311,
                                ],
                                [
                                    0.9006216065602155,
                                    0.04215090821075239,
                                    0.05466887173613966,
                                    0.0025586134928924226,
                                ],
                                [
                                    0.9125841127032176,
                                    0.051331030373594266,
                                    0.034163242868201375,
                                    0.001921614054986758,
                                ],
                                [
                                    0.6941076326169691,
                                    0.03904216551268439,
                                    0.25263972295445,
                                    0.014210478915896635,
                                ],
                                [
                                    0.7350714121846401,
                                    0.2205165964369233,
                                    0.034163242868201375,
                                    0.010248748510235129,
                                ],
                                [
                                    0.7454158627100369,
                                    0.2101721459115265,
                                    0.03464401245028445,
                                    0.009767978928152054,
                                ],
                                [
                                    0.694107632616969,
                                    0.20822773157601343,
                                    0.07512702243587252,
                                    0.022537613371145005,
                                ],
                                [
                                    0.703875611545121,
                                    0.1984597526478614,
                                    0.07618426361520035,
                                    0.021480372191817178,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.4215599302747463,
                                    0.05498503120991964,
                                    0.46305739725167444,
                                    0.06039764126365958,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.5017329803406373,
                                    0.4567695526824345,
                                    0.02172205817469669,
                                    0.019775408802231387,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.44133533907697775,
                                    0.401784521472515,
                                    0.08211969943835627,
                                    0.07476044001215103,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                ],
                                [
                                    0.18089795932699423,
                                    0.0390421655126844,
                                    0.6415893401544284,
                                    0.13847053500589301,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.256554335855344,
                                    0.7048627215692365,
                                    0.010295866015002729,
                                    0.028287076560416922,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.2091850358874112,
                                    0.5747193210185917,
                                    0.0576651659829355,
                                    0.15843047711106154,
                                ],
                                [
                                    0.7783433102466403,
                                    0.21945613442633646,
                                    0.001716564913681105,
                                    0.0004839904133421044,
                                ],
                                [
                                    0.03487610391862287,
                                    0.009833417785021965,
                                    0.7451837712416985,
                                    0.2101067070546566,
                                ],
                                [
                                    0.04519351211698697,
                                    0.9182138190507091,
                                    0.0017165649136811055,
                                    0.03487610391862285,
                                ],
                                [
                                    0.08826699309927963,
                                    0.8751403380684164,
                                    0.003352605635033287,
                                    0.03324006319727067,
                                ],
                                [
                                    0.03487610391862289,
                                    0.7085911024093945,
                                    0.012033973112045179,
                                    0.24449882055993732,
                                ],
                                [
                                    0.06811616711589358,
                                    0.6753510392121238,
                                    0.023503431618419324,
                                    0.23302936205356317,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7355306983915094,
                                    0.036202042313563526,
                                    0.21755922457782245,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7372289389851062,
                                    0.034503801719966753,
                                    0.2180615393112489,
                                    0.010205719983678054,
                                ],
                                [
                                    0.7252132901931454,
                                    0.035694230404447705,
                                    0.2278766327761865,
                                    0.011215846626220312,
                                ],
                                [
                                    0.7268877092909685,
                                    0.03401981130662465,
                                    0.22840276900538667,
                                    0.010689710397020158,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.560211195688866,
                                    0.031510758845398154,
                                    0.386536159882553,
                                    0.02174188558318287,
                                ],
                                [
                                    0.6011749752565371,
                                    0.1803485446572143,
                                    0.1680596797963044,
                                    0.05041680028994414,
                                ],
                                [
                                    0.6096351393787759,
                                    0.17188838053497552,
                                    0.1704247357815455,
                                    0.048051744304703055,
                                ],
                                [
                                    0.5602111956888659,
                                    0.1680596797963044,
                                    0.20902345936397557,
                                    0.06270566515085402,
                                ],
                                [
                                    0.5680948882138599,
                                    0.16017598727131035,
                                    0.2119649869464614,
                                    0.05976413756836819,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.3402391523967764,
                                    0.04437817512964435,
                                    0.5443781751296444,
                                    0.07100449734393487,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.416597438508218,
                                    0.3792635387589141,
                                    0.10685760000711604,
                                    0.0972814227257519,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.3561997972445584,
                                    0.32427850754899445,
                                    0.1672552412707756,
                                    0.15226645393567154,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.21620161583352268,
                                    0.59399681878699,
                                    0.05064858603682399,
                                    0.13915297934266332,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.16883231586558992,
                                    0.46385341823634535,
                                    0.09801788600475676,
                                    0.26929637989330796,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.03846575718504431,
                                    0.7815234566441468,
                                    0.008444319845623766,
                                    0.17156646632518516,
                                ],
                                [
                                    0.0751270827374952,
                                    0.7448621310916959,
                                    0.016492515996817718,
                                    0.1635182701739912,
                                ],
                                [
                                    0.02814834898668023,
                                    0.5719007400028322,
                                    0.018761728043987843,
                                    0.3811891829664997,
                                ],
                                [
                                    0.05497625675410915,
                                    0.5450728322354034,
                                    0.03664334198020376,
                                    0.3633075690302838,
                                ],
                                [
                                    0.5177885225070362,
                                    0.005666516008297848,
                                    0.47138625738548395,
                                    0.005158704099182031,
                                ],
                                [
                                    0.47138625738548395,
                                    0.005158704099182031,
                                    0.5177885225070362,
                                    0.005666516008297848,
                                ],
                                [
                                    0.481703665583848,
                                    0.023708944469891916,
                                    0.47138625738548395,
                                    0.023201132560776102,
                                ],
                                [
                                    0.48281585399524646,
                                    0.02259675605849346,
                                    0.4724746243011087,
                                    0.022112765645151352,
                                ],
                                [
                                    0.47138625738548395,
                                    0.023201132560776102,
                                    0.481703665583848,
                                    0.023708944469891916,
                                ],
                                [
                                    0.4724746243011087,
                                    0.022112765645151352,
                                    0.48281585399524646,
                                    0.02259675605849346,
                                ],
                                [
                                    0.5826119178288338,
                                    0.03277075464474545,
                                    0.36413543774258517,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3641354377425853,
                                    0.02048188978383558,
                                    0.5826119178288337,
                                    0.032770754644745444,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403416,
                                    0.36413543774258517,
                                    0.10923824004312428,
                                ],
                                [
                                    0.41080006316261863,
                                    0.11582625905167185,
                                    0.36925981199770275,
                                    0.10411386578800672,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312428,
                                    0.40509921731025633,
                                    0.12152710490403416,
                                ],
                                [
                                    0.36925981199770275,
                                    0.10411386578800672,
                                    0.41080006316261863,
                                    0.11582625905167185,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.2211543318816052,
                                    0.028845668118394806,
                                    0.6634629956448156,
                                    0.08653700435518441,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.29192633988949684,
                                    0.26576499634729284,
                                    0.23152869862583722,
                                    0.21077996513737315,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.23152869862583725,
                                    0.21077996513737318,
                                    0.2919263398894968,
                                    0.2657649963472928,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974368,
                                    0.020481889783835576,
                                ],
                                [
                                    0.09490078268974368,
                                    0.020481889783835576,
                                    0.727586516791679,
                                    0.15703081073474182,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.15710975091913976,
                                    0.431646599340149,
                                    0.10974045095120696,
                                    0.3015031987895044,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.10974045095120695,
                                    0.3015031987895043,
                                    0.15710975091913976,
                                    0.431646599340149,
                                ],
                                [
                                    0.7617635407441694,
                                    0.21478142074049653,
                                    0.018296334416152,
                                    0.005158704099182037,
                                ],
                                [
                                    0.018296334416152,
                                    0.005158704099182037,
                                    0.7617635407441694,
                                    0.21478142074049653,
                                ],
                                [
                                    0.028613742614516074,
                                    0.5813563198053232,
                                    0.018296334416152,
                                    0.3717336031640087,
                                ],
                                [
                                    0.055885212358849475,
                                    0.5540848500609898,
                                    0.03573438637546344,
                                    0.35429555120469725,
                                ],
                                [
                                    0.018296334416152003,
                                    0.3717336031640088,
                                    0.02861374261451607,
                                    0.5813563198053231,
                                ],
                                [
                                    0.035734386375463445,
                                    0.35429555120469736,
                                    0.05588521235884947,
                                    0.5540848500609897,
                                ],
                                [
                                    0.2639614896993748,
                                    0.0028887121709719418,
                                    0.7252132901931454,
                                    0.007936507936507938,
                                ],
                                [
                                    0.2175592245778225,
                                    0.0023809002618561236,
                                    0.7716155553146976,
                                    0.008444319845623756,
                                ],
                                [
                                    0.22787663277618653,
                                    0.011215846626220312,
                                    0.7252132901931454,
                                    0.035694230404447705,
                                ],
                                [
                                    0.2284027690053867,
                                    0.01068971039702016,
                                    0.7268877092909685,
                                    0.03401981130662465,
                                ],
                                [
                                    0.21755922457782245,
                                    0.010708034717104494,
                                    0.7355306983915094,
                                    0.036202042313563526,
                                ],
                                [
                                    0.21806153931124891,
                                    0.010205719983678056,
                                    0.7372289389851062,
                                    0.034503801719966753,
                                ],
                                [
                                    0.38653615988255313,
                                    0.021741885583182876,
                                    0.5602111956888659,
                                    0.03151075884539815,
                                ],
                                [
                                    0.16805967979630448,
                                    0.009453020722272998,
                                    0.7786876757751144,
                                    0.04379962370630803,
                                ],
                                [
                                    0.20902345936397562,
                                    0.06270566515085403,
                                    0.5602111956888659,
                                    0.1680596797963044,
                                ],
                                [
                                    0.21196498694646146,
                                    0.059764137568368195,
                                    0.5680948882138599,
                                    0.16017598727131035,
                                ],
                                [
                                    0.16805967979630448,
                                    0.050416800289944164,
                                    0.6011749752565371,
                                    0.18034854465721428,
                                ],
                                [
                                    0.17042473578154557,
                                    0.048051744304703076,
                                    0.6096351393787758,
                                    0.1718883805349755,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.10206951136643398,
                                    0.01331316110714526,
                                    0.7825478161599868,
                                    0.10206951136643397,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.16725524127077565,
                                    0.1522664539356716,
                                    0.35619979724455836,
                                    0.3242785075489944,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.10685760000711607,
                                    0.09728142272575192,
                                    0.41659743850821795,
                                    0.37926353875891405,
                                ],
                                [
                                    0.6764853578082433,
                                    0.14600194167317923,
                                    0.14600194167317931,
                                    0.03151075884539816,
                                ],
                                [
                                    0.04379962370630803,
                                    0.009453020722272993,
                                    0.7786876757751146,
                                    0.1680596797963044,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.09801788600475676,
                                    0.26929637989330796,
                                    0.16883231586558992,
                                    0.46385341823634535,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.050648586036824005,
                                    0.13915297934266332,
                                    0.21620161583352268,
                                    0.59399681878699,
                                ],
                                [
                                    0.7519115261736411,
                                    0.2120036169031706,
                                    0.028148348986680227,
                                    0.007936507936507946,
                                ],
                                [
                                    0.008444319845623757,
                                    0.002380900261856124,
                                    0.7716155553146976,
                                    0.21755922457782245,
                                ],
                                [
                                    0.018761728043987846,
                                    0.3811891829664998,
                                    0.028148348986680227,
                                    0.5719007400028322,
                                ],
                                [
                                    0.03664334198020377,
                                    0.3633075690302839,
                                    0.054976256754109144,
                                    0.5450728322354033,
                                ],
                                [
                                    0.008444319845623775,
                                    0.17156646632518535,
                                    0.038465757185044296,
                                    0.7815234566441466,
                                ],
                                [
                                    0.016492515996817735,
                                    0.1635182701739914,
                                    0.07512708273749517,
                                    0.7448621310916957,
                                ],
                                [
                                    0.09062779641185499,
                                    0.0009918023224579223,
                                    0.8985469834806651,
                                    0.009833417785021958,
                                ],
                                [
                                    0.04422553129030273,
                                    0.00048399041334210415,
                                    0.9449492486022174,
                                    0.010341229694137775,
                                ],
                                [
                                    0.05454293948866678,
                                    0.0026845457403653116,
                                    0.8985469834806652,
                                    0.044225531290302704,
                                ],
                                [
                                    0.05466887173613967,
                                    0.0025586134928924234,
                                    0.9006216065602155,
                                    0.04215090821075239,
                                ],
                                [
                                    0.04422553129030271,
                                    0.0021767338312494943,
                                    0.9088643916790292,
                                    0.044733343199418525,
                                ],
                                [
                                    0.04432764204200189,
                                    0.0020746230795503193,
                                    0.9109628362543533,
                                    0.04263489862409449,
                                ],
                                [
                                    0.25263972295445003,
                                    0.01421047891589664,
                                    0.694107632616969,
                                    0.039042165512684385,
                                ],
                                [
                                    0.03416324286820143,
                                    0.0019216140549867611,
                                    0.9125841127032176,
                                    0.051331030373594266,
                                ],
                                [
                                    0.07512702243587255,
                                    0.022537613371145012,
                                    0.694107632616969,
                                    0.20822773157601343,
                                ],
                                [
                                    0.07618426361520038,
                                    0.021480372191817185,
                                    0.703875611545121,
                                    0.1984597526478614,
                                ],
                                [
                                    0.0341632428682014,
                                    0.010248748510235136,
                                    0.7350714121846401,
                                    0.2205165964369233,
                                ],
                                [
                                    0.03464401245028448,
                                    0.009767978928152062,
                                    0.7454158627100369,
                                    0.2101721459115265,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.020748733488464063,
                                    0.0027063050268699733,
                                    0.8638685940379567,
                                    0.11267636744670925,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.08211969943835631,
                                    0.07476044001215107,
                                    0.4413353390769777,
                                    0.4017845214725149,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.021722058174696718,
                                    0.019775408802231415,
                                    0.5017329803406373,
                                    0.4567695526824345,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699423,
                                    0.0390421655126844,
                                ],
                                [
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                    0.8135836934289296,
                                    0.17559108646359065,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.057665165982935515,
                                    0.1584304771110616,
                                    0.2091850358874112,
                                    0.5747193210185917,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.010295866015002746,
                                    0.028287076560416975,
                                    0.25655433585534393,
                                    0.7048627215692364,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862289,
                                    0.009833417785021968,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.00048399041334210995,
                                    0.7783433102466403,
                                    0.21945613442633646,
                                ],
                                [
                                    0.012033973112045182,
                                    0.24449882055993738,
                                    0.03487610391862289,
                                    0.7085911024093945,
                                ],
                                [
                                    0.023503431618419328,
                                    0.23302936205356323,
                                    0.06811616711589358,
                                    0.6753510392121238,
                                ],
                                [
                                    0.0017165649136811048,
                                    0.034876103918622836,
                                    0.04519351211698697,
                                    0.9182138190507091,
                                ],
                                [
                                    0.0033526056350332858,
                                    0.03324006319727066,
                                    0.08826699309927963,
                                    0.8751403380684164,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.8870743039674259,
                                    0.021306097298261256,
                                    0.08947065751724008,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359526,
                                    0.04366085815008366,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9520904523038476,
                                    0.0020997483289959466,
                                    0.045708992369129155,
                                    0.00010080699802726039,
                                ],
                                [
                                    0.8870743039674259,
                                    0.043660858150083665,
                                    0.06601561900190606,
                                    0.003249218880584358,
                                ],
                                [
                                    0.9286870278984641,
                                    0.002048134219045494,
                                    0.06911241677451271,
                                    0.00015242110797771314,
                                ],
                                [
                                    0.8526960378308568,
                                    0.11121910524595503,
                                    0.03192128969556395,
                                    0.004163567227624184,
                                ],
                                [
                                    0.6485570150979889,
                                    0.08459278303166452,
                                    0.23606031242843187,
                                    0.030789889441914697,
                                ],
                                [
                                    0.7373133653572775,
                                    0.2211891676657943,
                                    0.03192128969556395,
                                    0.009576177281364125,
                                ],
                                [
                                    0.9481265321295201,
                                    0.010376000893551755,
                                    0.04104824776299995,
                                    0.00044921921392812407,
                                ],
                                [
                                    0.6485570150979889,
                                    0.19456284545150382,
                                    0.12067763995485266,
                                    0.036202499495654634,
                                ],
                                [
                                    0.8339929024820567,
                                    0.009126958067436,
                                    0.1551818774104634,
                                    0.001698262040043879,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.3574087211134995,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.1308637596288335,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.9421876119592986,
                                    0.022629830267700306,
                                    0.03435734952536731,
                                    0.0008252082476337027,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.6980513715881322,
                                    0.016766070638866804,
                                    0.2784935898965338,
                                    0.006688967876467205,
                                ],
                                [
                                    0.6087210195937236,
                                    0.3804537602987966,
                                    0.006661652879855697,
                                    0.004163567227624186,
                                ],
                                [
                                    0.13534734180801408,
                                    0.08459278303166454,
                                    0.4800353306655652,
                                    0.3000245444947562,
                                ],
                                [
                                    0.2241036920673028,
                                    0.7470286593636232,
                                    0.006661652879855697,
                                    0.022205995689218255,
                                ],
                                [
                                    0.9360891794760617,
                                    0.03504317195486423,
                                    0.02782596360075004,
                                    0.0010416849683239102,
                                ],
                                [
                                    0.13534734180801408,
                                    0.4511676820964912,
                                    0.09541800313914443,
                                    0.3180669729563503,
                                ],
                                [
                                    0.5653507131836109,
                                    0.021164310720894343,
                                    0.3985644298932009,
                                    0.014920546202293794,
                                ],
                                [
                                    0.522303146741872,
                                    0.4754962979311048,
                                    0.0011518917734620576,
                                    0.001048663553561152,
                                ],
                                [
                                    0.023403424405383573,
                                    0.021306097298261266,
                                    0.5000516141099505,
                                    0.4552388641864047,
                                ],
                                [
                                    0.04575818525720601,
                                    0.9296864985639484,
                                    0.0011518917734620578,
                                    0.023403424405383556,
                                ],
                                [
                                    0.9318330185591475,
                                    0.04361166526200685,
                                    0.023457459737207653,
                                    0.0010978564416379585,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.4765941543727428,
                                    0.022305567963745596,
                                    0.4786963239236124,
                                    0.022403953739899216,
                                ],
                                [
                                    0.7617635407441694,
                                    0.01829633441615198,
                                    0.21478142074049653,
                                    0.005158704099182031,
                                ],
                                [
                                    0.7159537413770131,
                                    0.017196056752640375,
                                    0.26059122010765295,
                                    0.006258981762693634,
                                ],
                                [
                                    0.7383085022288354,
                                    0.036338762877746046,
                                    0.21478142074049653,
                                    0.01057131415292197,
                                ],
                                [
                                    0.7729426109407872,
                                    0.0017046541657942463,
                                    0.22485683373218954,
                                    0.0004959011612289606,
                                ],
                                [
                                    0.7159537413770131,
                                    0.03523848521423444,
                                    0.23713618159231892,
                                    0.011671591816433574,
                                ],
                                [
                                    0.7495391865354037,
                                    0.0016530400558437937,
                                    0.2482602581375731,
                                    0.0005475152711794134,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.523447494058811,
                                    0.06827446047545313,
                                    0.3611698334676098,
                                    0.047108211998126086,
                                ],
                                [
                                    0.6122038443180997,
                                    0.18365713294903238,
                                    0.15703081073474184,
                                    0.047108211998126086,
                                ],
                                [
                                    0.7872456070132614,
                                    0.008615370253870746,
                                    0.2019291728792588,
                                    0.002209849853609134,
                                ],
                                [
                                    0.523447494058811,
                                    0.15703081073474184,
                                    0.24578716099403053,
                                    0.0737345342124166,
                                ],
                                [
                                    0.6731119773657979,
                                    0.00736632742775499,
                                    0.31606280252672225,
                                    0.0034588926797248887,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.2884629956448156,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.1538456681183948,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.8075304103146022,
                                    0.019395580975029053,
                                    0.16901455117006386,
                                    0.004059457540304954,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.5633941699434356,
                                    0.013531821346195553,
                                    0.41315079154123036,
                                    0.009923217169138457,
                                ],
                                [
                                    0.5826119178288338,
                                    0.36413543774258517,
                                    0.032770754644745465,
                                    0.02048188978383558,
                                ],
                                [
                                    0.10923824004312432,
                                    0.06827446047545316,
                                    0.5061444324304549,
                                    0.3163428670509676,
                                ],
                                [
                                    0.19799459030241304,
                                    0.6599964150097172,
                                    0.03277075464474546,
                                    0.10923824004312427,
                                ],
                                [
                                    0.8270305226440596,
                                    0.030960482668070572,
                                    0.13688462043275215,
                                    0.0051243742551175635,
                                ],
                                [
                                    0.10923824004312431,
                                    0.36413543774258517,
                                    0.12152710490403419,
                                    0.40509921731025633,
                                ],
                                [
                                    0.4562920563516088,
                                    0.017081621434100688,
                                    0.5076230867252031,
                                    0.019003235489087448,
                                ],
                                [
                                    0.5177885225070362,
                                    0.47138625738548395,
                                    0.005666516008297856,
                                    0.005158704099182037,
                                ],
                                [
                                    0.018888800170547792,
                                    0.0171960567526404,
                                    0.5045662383447862,
                                    0.45934890473202555,
                                ],
                                [
                                    0.041243561022370215,
                                    0.8379611564503106,
                                    0.005666516008297855,
                                    0.1151287665190213,
                                ],
                                [
                                    0.839895895074889,
                                    0.03930882239779173,
                                    0.11539458322146608,
                                    0.0054006993058530834,
                                ],
                                [
                                    0.018888800170547785,
                                    0.38377095581746706,
                                    0.02802127686012029,
                                    0.5693189671518649,
                                ],
                                [
                                    0.38465703088848435,
                                    0.018002725099530475,
                                    0.5706334474078708,
                                    0.026706796604114336,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.4877223419105772,
                                    0.02400517734708981,
                                    0.46536758105875475,
                                    0.022904899683578207,
                                ],
                                [
                                    0.5106014345391802,
                                    0.00112608471848683,
                                    0.4871980101337966,
                                    0.001074470608536377,
                                ],
                                [
                                    0.46536758105875475,
                                    0.022904899683578207,
                                    0.4877223419105772,
                                    0.02400517734708981,
                                ],
                                [
                                    0.4871980101337966,
                                    0.001074470608536377,
                                    0.5106014345391802,
                                    0.00112608471848683,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3402391523967765,
                                    0.044378175129644364,
                                    0.5443781751296443,
                                    0.07100449734393485,
                                ],
                                [
                                    0.4289955026560652,
                                    0.1286958335807245,
                                    0.3402391523967764,
                                    0.10206951136643397,
                                ],
                                [
                                    0.5516542047699918,
                                    0.006037131466797818,
                                    0.4375205751225283,
                                    0.004788088640682062,
                                ],
                                [
                                    0.34023915239677643,
                                    0.10206951136643398,
                                    0.42899550265606506,
                                    0.12869583358072448,
                                ],
                                [
                                    0.43752057512252834,
                                    0.004788088640682062,
                                    0.5516542047699917,
                                    0.006037131466797817,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.6103406009279162,
                                    0.014659399072083756,
                                    0.36620436055674976,
                                    0.008795639443250253,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.36620436055674976,
                                    0.008795639443250253,
                                    0.6103406009279162,
                                    0.014659399072083756,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.1597608476032236,
                                    0.5325478161599867,
                                    0.0710044973439349,
                                    0.23668683889285475,
                                ],
                                [
                                    0.6673268046846312,
                                    0.024981859078579007,
                                    0.29658833839218046,
                                    0.011102997844609127,
                                ],
                                [
                                    0.07100449734393491,
                                    0.23668683889285477,
                                    0.1597608476032236,
                                    0.5325478161599867,
                                ],
                                [
                                    0.2965883383921805,
                                    0.011102997844609129,
                                    0.6673268046846312,
                                    0.024981859078579007,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.034632418941245253,
                                    0.7036400618010877,
                                    0.012277658089422822,
                                    0.2494498611682442,
                                ],
                                [
                                    0.7052646712413799,
                                    0.033007809500953035,
                                    0.25002580705497524,
                                    0.01170171220269178,
                                ],
                                [
                                    0.012277658089422822,
                                    0.2494498611682442,
                                    0.034632418941245253,
                                    0.7036400618010877,
                                ],
                                [
                                    0.25002580705497524,
                                    0.01170171220269178,
                                    0.7052646712413799,
                                    0.033007809500953035,
                                ],
                                [
                                    0.26059122010765307,
                                    0.006258981762693637,
                                    0.715953741377013,
                                    0.01719605675264037,
                                ],
                                [
                                    0.21478142074049658,
                                    0.0051587040991820324,
                                    0.7617635407441694,
                                    0.01829633441615198,
                                ],
                                [
                                    0.237136181592319,
                                    0.011671591816433577,
                                    0.715953741377013,
                                    0.03523848521423444,
                                ],
                                [
                                    0.2482602581375732,
                                    0.0005475152711794136,
                                    0.7495391865354036,
                                    0.0016530400558437935,
                                ],
                                [
                                    0.21478142074049658,
                                    0.010571314152921974,
                                    0.7383085022288354,
                                    0.036338762877746046,
                                ],
                                [
                                    0.2248568337321896,
                                    0.0004959011612289607,
                                    0.7729426109407872,
                                    0.0017046541657942463,
                                ],
                                [
                                    0.3611698334676099,
                                    0.0471082119981261,
                                    0.5234474940588109,
                                    0.06827446047545312,
                                ],
                                [
                                    0.1570308107347419,
                                    0.020481889783835583,
                                    0.7275865167916789,
                                    0.09490078268974364,
                                ],
                                [
                                    0.2457871609940306,
                                    0.07373453421241662,
                                    0.5234474940588109,
                                    0.15703081073474182,
                                ],
                                [
                                    0.31606280252672236,
                                    0.00345889267972489,
                                    0.6731119773657978,
                                    0.007366327427754989,
                                ],
                                [
                                    0.15703081073474187,
                                    0.0471082119981261,
                                    0.6122038443180996,
                                    0.18365713294903235,
                                ],
                                [
                                    0.20192917287925885,
                                    0.0022098498536091346,
                                    0.7872456070132613,
                                    0.008615370253870745,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.08653700435518444,
                                    0.028845668118394813,
                                    0.6634629956448156,
                                    0.2211543318816052,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.41315079154123036,
                                    0.009923217169138457,
                                    0.5633941699434356,
                                    0.013531821346195553,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.16901455117006386,
                                    0.004059457540304954,
                                    0.8075304103146022,
                                    0.019395580975029053,
                                ],
                                [
                                    0.5061444324304549,
                                    0.3163428670509676,
                                    0.10923824004312431,
                                    0.06827446047545314,
                                ],
                                [
                                    0.03277075464474545,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.36413543774258517,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.5076230867252031,
                                    0.019003235489087448,
                                    0.4562920563516088,
                                    0.017081621434100688,
                                ],
                                [
                                    0.032770754644745465,
                                    0.1092382400431243,
                                    0.19799459030241304,
                                    0.6599964150097172,
                                ],
                                [
                                    0.13688462043275218,
                                    0.005124374255117564,
                                    0.8270305226440596,
                                    0.030960482668070572,
                                ],
                                [
                                    0.5045662383447862,
                                    0.45934890473202555,
                                    0.018888800170547785,
                                    0.017196056752640392,
                                ],
                                [
                                    0.00566651600829785,
                                    0.0051587040991820324,
                                    0.5177885225070362,
                                    0.47138625738548395,
                                ],
                                [
                                    0.02802127686012029,
                                    0.5693189671518649,
                                    0.018888800170547785,
                                    0.38377095581746706,
                                ],
                                [
                                    0.5706334474078708,
                                    0.026706796604114336,
                                    0.38465703088848435,
                                    0.018002725099530475,
                                ],
                                [
                                    0.005666516008297856,
                                    0.11512876651902133,
                                    0.041243561022370215,
                                    0.8379611564503106,
                                ],
                                [
                                    0.1153945832214661,
                                    0.005400699305853084,
                                    0.839895895074889,
                                    0.03930882239779173,
                                ],
                                [
                                    0.08947065751724015,
                                    0.0021489412170727566,
                                    0.8870743039674258,
                                    0.021306097298261252,
                                ],
                                [
                                    0.043660858150083685,
                                    0.0010486635535611516,
                                    0.9328841033345823,
                                    0.02240637496177286,
                                ],
                                [
                                    0.06601561900190613,
                                    0.0032492188805843614,
                                    0.8870743039674258,
                                    0.04366085815008366,
                                ],
                                [
                                    0.06911241677451278,
                                    0.00015242110797771327,
                                    0.928687027898464,
                                    0.0020481342190454936,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727566,
                                    0.9094290648192482,
                                    0.04476113581359526,
                                ],
                                [
                                    0.045708992369129196,
                                    0.00010080699802726048,
                                    0.9520904523038476,
                                    0.0020997483289959466,
                                ],
                                [
                                    0.23606031242843198,
                                    0.03078988944191471,
                                    0.6485570150979888,
                                    0.08459278303166451,
                                ],
                                [
                                    0.031921289695564,
                                    0.004163567227624191,
                                    0.8526960378308568,
                                    0.11121910524595503,
                                ],
                                [
                                    0.12067763995485271,
                                    0.036202499495654655,
                                    0.6485570150979888,
                                    0.1945628454515038,
                                ],
                                [
                                    0.1551818774104635,
                                    0.00169826204004388,
                                    0.8339929024820566,
                                    0.009126958067435999,
                                ],
                                [
                                    0.031921289695563994,
                                    0.009576177281364137,
                                    0.7373133653572775,
                                    0.2211891676657943,
                                ],
                                [
                                    0.041048247763000006,
                                    0.00044921921392812467,
                                    0.9481265321295201,
                                    0.010376000893551755,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.017591278886500528,
                                    0.005863759628833509,
                                    0.7324087211134995,
                                    0.2441362403711665,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.27849358989653383,
                                    0.006688967876467206,
                                    0.6980513715881321,
                                    0.016766070638866804,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.03435734952536735,
                                    0.0008252082476337037,
                                    0.9421876119592986,
                                    0.022629830267700306,
                                ],
                                [
                                    0.4800353306655652,
                                    0.3000245444947562,
                                    0.13534734180801408,
                                    0.08459278303166454,
                                ],
                                [
                                    0.006661652879855697,
                                    0.004163567227624186,
                                    0.6087210195937236,
                                    0.3804537602987966,
                                ],
                                [
                                    0.09541800313914443,
                                    0.3180669729563503,
                                    0.13534734180801408,
                                    0.4511676820964912,
                                ],
                                [
                                    0.3985644298932009,
                                    0.014920546202293794,
                                    0.5653507131836109,
                                    0.021164310720894343,
                                ],
                                [
                                    0.006661652879855703,
                                    0.022205995689218275,
                                    0.2241036920673028,
                                    0.7470286593636232,
                                ],
                                [
                                    0.027825963600750066,
                                    0.0010416849683239113,
                                    0.9360891794760617,
                                    0.03504317195486423,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.023403424405383583,
                                    0.021306097298261276,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.001048663553561164,
                                    0.522303146741872,
                                    0.4754962979311048,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.4786963239236124,
                                    0.022403953739899216,
                                    0.4765941543727428,
                                    0.022305567963745596,
                                ],
                                [
                                    0.0011518917734620597,
                                    0.023403424405383594,
                                    0.04575818525720601,
                                    0.9296864985639484,
                                ],
                                [
                                    0.023457459737207694,
                                    0.0010978564416379603,
                                    0.9318330185591475,
                                    0.04361166526200685,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.8870743039674259,
                                    0.021306097298261256,
                                    0.08947065751724008,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359526,
                                    0.04366085815008366,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9438608816865927,
                                    0.010329318946250918,
                                    0.045313898205927454,
                                    0.0004959011612289606,
                                ],
                                [
                                    0.8870743039674259,
                                    0.043660858150083665,
                                    0.06601561900190606,
                                    0.003249218880584358,
                                ],
                                [
                                    0.9206597491258166,
                                    0.01007541299169301,
                                    0.06851503076670355,
                                    0.0007498071157868694,
                                ],
                                [
                                    0.8526960378308568,
                                    0.11121910524595503,
                                    0.03192128969556395,
                                    0.004163567227624184,
                                ],
                                [
                                    0.6485570150979889,
                                    0.08459278303166452,
                                    0.23606031242843187,
                                    0.030789889441914697,
                                ],
                                [
                                    0.7373133653572775,
                                    0.2211891676657943,
                                    0.03192128969556395,
                                    0.009576177281364125,
                                ],
                                [
                                    0.9074597384481,
                                    0.05104279457497189,
                                    0.03928761712331894,
                                    0.002209849853609134,
                                ],
                                [
                                    0.6485570150979889,
                                    0.19456284545150382,
                                    0.12067763995485266,
                                    0.036202499495654634,
                                ],
                                [
                                    0.7982214984049758,
                                    0.04489836214451696,
                                    0.14852585716644323,
                                    0.008354282284064072,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.3574087211134995,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.1308637596288335,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.8534942272937247,
                                    0.11132321493327427,
                                    0.031123100232696058,
                                    0.004059457540304955,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.6323398954121195,
                                    0.08247754681487947,
                                    0.25227743211430126,
                                    0.03290512565869976,
                                ],
                                [
                                    0.6087210195937236,
                                    0.3804537602987966,
                                    0.006661652879855697,
                                    0.004163567227624186,
                                ],
                                [
                                    0.13534734180801408,
                                    0.08459278303166454,
                                    0.4800353306655652,
                                    0.3000245444947562,
                                ],
                                [
                                    0.2241036920673028,
                                    0.7470286593636232,
                                    0.006661652879855697,
                                    0.022205995689218255,
                                ],
                                [
                                    0.7987440251674662,
                                    0.17238832626345982,
                                    0.023743274313956387,
                                    0.0051243742551175635,
                                ],
                                [
                                    0.13534734180801408,
                                    0.4511676820964912,
                                    0.09541800313914443,
                                    0.3180669729563503,
                                ],
                                [
                                    0.4824011581164986,
                                    0.10411386578800672,
                                    0.34008614136492404,
                                    0.07339883473057068,
                                ],
                                [
                                    0.522303146741872,
                                    0.4754962979311048,
                                    0.0011518917734620576,
                                    0.001048663553561152,
                                ],
                                [
                                    0.023403424405383573,
                                    0.021306097298261266,
                                    0.5000516141099505,
                                    0.4552388641864047,
                                ],
                                [
                                    0.04575818525720601,
                                    0.9296864985639484,
                                    0.0011518917734620578,
                                    0.023403424405383556,
                                ],
                                [
                                    0.7609052582873288,
                                    0.21453942553382546,
                                    0.01915461687299253,
                                    0.005400699305853083,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.38917165512332014,
                                    0.10972806721316823,
                                    0.39088822003700124,
                                    0.11021205762651033,
                                ],
                                [
                                    0.7617635407441694,
                                    0.01829633441615198,
                                    0.21478142074049653,
                                    0.005158704099182031,
                                ],
                                [
                                    0.7159537413770131,
                                    0.017196056752640375,
                                    0.26059122010765295,
                                    0.006258981762693634,
                                ],
                                [
                                    0.7383085022288354,
                                    0.036338762877746046,
                                    0.21478142074049653,
                                    0.01057131415292197,
                                ],
                                [
                                    0.7662615379561454,
                                    0.008385727150436062,
                                    0.22291324193637468,
                                    0.0024394929570438167,
                                ],
                                [
                                    0.7159537413770131,
                                    0.03523848521423444,
                                    0.23713618159231892,
                                    0.011671591816433574,
                                ],
                                [
                                    0.7430604053953693,
                                    0.008131821195878155,
                                    0.2461143744971508,
                                    0.002693398911601725,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.523447494058811,
                                    0.06827446047545313,
                                    0.3611698334676098,
                                    0.047108211998126086,
                                ],
                                [
                                    0.6122038443180997,
                                    0.18365713294903238,
                                    0.15703081073474184,
                                    0.047108211998126086,
                                ],
                                [
                                    0.7534792756301425,
                                    0.042381701636989594,
                                    0.1932680799412765,
                                    0.010870942791591435,
                                ],
                                [
                                    0.523447494058811,
                                    0.15703081073474184,
                                    0.24578716099403053,
                                    0.0737345342124166,
                                ],
                                [
                                    0.6442410355870182,
                                    0.03623726920653465,
                                    0.30250631998440075,
                                    0.01701537522204637,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.2884629956448156,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.1538456681183948,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.7315130604767698,
                                    0.09541293081286134,
                                    0.15310426704965094,
                                    0.019969741660717882,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.5103587285951646,
                                    0.06656726269446653,
                                    0.3742585989312561,
                                    0.04881540977911269,
                                ],
                                [
                                    0.5826119178288338,
                                    0.36413543774258517,
                                    0.032770754644745465,
                                    0.02048188978383558,
                                ],
                                [
                                    0.10923824004312432,
                                    0.06827446047545316,
                                    0.5061444324304549,
                                    0.3163428670509676,
                                ],
                                [
                                    0.19799459030241304,
                                    0.6599964150097172,
                                    0.03277075464474546,
                                    0.10923824004312427,
                                ],
                                [
                                    0.7056867049385249,
                                    0.15230430037360532,
                                    0.11680059454289766,
                                    0.025208400144972068,
                                ],
                                [
                                    0.10923824004312431,
                                    0.36413543774258517,
                                    0.12152710490403419,
                                    0.40509921731025633,
                                ],
                                [
                                    0.3893438378875573,
                                    0.0840298398981522,
                                    0.43314346159386535,
                                    0.0934828606204252,
                                ],
                                [
                                    0.5177885225070362,
                                    0.47138625738548395,
                                    0.005666516008297856,
                                    0.005158704099182037,
                                ],
                                [
                                    0.018888800170547792,
                                    0.0171960567526404,
                                    0.5045662383447862,
                                    0.45934890473202555,
                                ],
                                [
                                    0.041243561022370215,
                                    0.8379611564503106,
                                    0.005666516008297855,
                                    0.1151287665190213,
                                ],
                                [
                                    0.685832322152105,
                                    0.19337239532057574,
                                    0.09422755300821634,
                                    0.026567729519102818,
                                ],
                                [
                                    0.018888800170547785,
                                    0.38377095581746706,
                                    0.02802127686012029,
                                    0.5693189671518649,
                                ],
                                [
                                    0.3140987189880963,
                                    0.08856103699991849,
                                    0.46596115617222506,
                                    0.13137908783976007,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.4877223419105772,
                                    0.02400517734708981,
                                    0.46536758105875475,
                                    0.022904899683578207,
                                ],
                                [
                                    0.5061879562266481,
                                    0.005539563031018894,
                                    0.482986823665872,
                                    0.005285657076460985,
                                ],
                                [
                                    0.46536758105875475,
                                    0.022904899683578207,
                                    0.4877223419105772,
                                    0.02400517734708981,
                                ],
                                [
                                    0.482986823665872,
                                    0.005285657076460985,
                                    0.5061879562266481,
                                    0.005539563031018894,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3402391523967765,
                                    0.044378175129644364,
                                    0.5443781751296443,
                                    0.07100449734393485,
                                ],
                                [
                                    0.4289955026560652,
                                    0.1286958335807245,
                                    0.3402391523967764,
                                    0.10206951136643397,
                                ],
                                [
                                    0.5279927978072717,
                                    0.029698538429517987,
                                    0.41875455776414733,
                                    0.023554105999063043,
                                ],
                                [
                                    0.34023915239677643,
                                    0.10206951136643398,
                                    0.42899550265606506,
                                    0.12869583358072448,
                                ],
                                [
                                    0.4187545577641474,
                                    0.023554105999063046,
                                    0.5279927978072716,
                                    0.02969853842951798,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.552885829704013,
                                    0.07211417029598702,
                                    0.3317314978224078,
                                    0.043268502177592205,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.3317314978224078,
                                    0.043268502177592205,
                                    0.552885829704013,
                                    0.07211417029598702,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.1597608476032236,
                                    0.5325478161599867,
                                    0.0710044973439349,
                                    0.23668683889285475,
                                ],
                                [
                                    0.569415083266195,
                                    0.12289358049701525,
                                    0.2530722162152275,
                                    0.05461912002156214,
                                ],
                                [
                                    0.07100449734393491,
                                    0.23668683889285477,
                                    0.1597608476032236,
                                    0.5325478161599867,
                                ],
                                [
                                    0.2530722162152275,
                                    0.05461912002156215,
                                    0.569415083266195,
                                    0.12289358049701525,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.034632418941245253,
                                    0.7036400618010877,
                                    0.012277658089422822,
                                    0.2494498611682442,
                                ],
                                [
                                    0.575896739162165,
                                    0.1623757415801679,
                                    0.20416313599815633,
                                    0.05756438325951066,
                                ],
                                [
                                    0.012277658089422822,
                                    0.2494498611682442,
                                    0.034632418941245253,
                                    0.7036400618010877,
                                ],
                                [
                                    0.20416313599815633,
                                    0.05756438325951066,
                                    0.575896739162165,
                                    0.1623757415801679,
                                ],
                                [
                                    0.26059122010765307,
                                    0.006258981762693637,
                                    0.715953741377013,
                                    0.01719605675264037,
                                ],
                                [
                                    0.21478142074049658,
                                    0.0051587040991820324,
                                    0.7617635407441694,
                                    0.01829633441615198,
                                ],
                                [
                                    0.237136181592319,
                                    0.011671591816433577,
                                    0.715953741377013,
                                    0.03523848521423444,
                                ],
                                [
                                    0.24611437449715087,
                                    0.002693398911601726,
                                    0.7430604053953692,
                                    0.008131821195878153,
                                ],
                                [
                                    0.21478142074049658,
                                    0.010571314152921974,
                                    0.7383085022288354,
                                    0.036338762877746046,
                                ],
                                [
                                    0.22291324193637474,
                                    0.002439492957043817,
                                    0.7662615379561454,
                                    0.008385727150436062,
                                ],
                                [
                                    0.3611698334676099,
                                    0.0471082119981261,
                                    0.5234474940588109,
                                    0.06827446047545312,
                                ],
                                [
                                    0.1570308107347419,
                                    0.020481889783835583,
                                    0.7275865167916789,
                                    0.09490078268974364,
                                ],
                                [
                                    0.2457871609940306,
                                    0.07373453421241662,
                                    0.5234474940588109,
                                    0.15703081073474182,
                                ],
                                [
                                    0.30250631998440086,
                                    0.017015375222046377,
                                    0.6442410355870181,
                                    0.036237269206534646,
                                ],
                                [
                                    0.15703081073474187,
                                    0.0471082119981261,
                                    0.6122038443180996,
                                    0.18365713294903235,
                                ],
                                [
                                    0.19326807994127657,
                                    0.010870942791591438,
                                    0.7534792756301424,
                                    0.04238170163698959,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.08653700435518444,
                                    0.028845668118394813,
                                    0.6634629956448156,
                                    0.2211543318816052,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.3742585989312561,
                                    0.04881540977911269,
                                    0.5103587285951646,
                                    0.06656726269446653,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.15310426704965094,
                                    0.019969741660717882,
                                    0.7315130604767698,
                                    0.09541293081286134,
                                ],
                                [
                                    0.5061444324304549,
                                    0.3163428670509676,
                                    0.10923824004312431,
                                    0.06827446047545314,
                                ],
                                [
                                    0.03277075464474545,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.36413543774258517,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.43314346159386535,
                                    0.0934828606204252,
                                    0.3893438378875573,
                                    0.0840298398981522,
                                ],
                                [
                                    0.032770754644745465,
                                    0.1092382400431243,
                                    0.19799459030241304,
                                    0.6599964150097172,
                                ],
                                [
                                    0.11680059454289769,
                                    0.025208400144972075,
                                    0.7056867049385249,
                                    0.15230430037360532,
                                ],
                                [
                                    0.5045662383447862,
                                    0.45934890473202555,
                                    0.018888800170547785,
                                    0.017196056752640392,
                                ],
                                [
                                    0.00566651600829785,
                                    0.0051587040991820324,
                                    0.5177885225070362,
                                    0.47138625738548395,
                                ],
                                [
                                    0.02802127686012029,
                                    0.5693189671518649,
                                    0.018888800170547785,
                                    0.38377095581746706,
                                ],
                                [
                                    0.46596115617222506,
                                    0.13137908783976007,
                                    0.3140987189880963,
                                    0.08856103699991849,
                                ],
                                [
                                    0.005666516008297856,
                                    0.11512876651902133,
                                    0.041243561022370215,
                                    0.8379611564503106,
                                ],
                                [
                                    0.09422755300821636,
                                    0.026567729519102825,
                                    0.685832322152105,
                                    0.19337239532057574,
                                ],
                                [
                                    0.08947065751724015,
                                    0.0021489412170727566,
                                    0.8870743039674258,
                                    0.021306097298261252,
                                ],
                                [
                                    0.043660858150083685,
                                    0.0010486635535611516,
                                    0.9328841033345823,
                                    0.02240637496177286,
                                ],
                                [
                                    0.06601561900190613,
                                    0.0032492188805843614,
                                    0.8870743039674258,
                                    0.04366085815008366,
                                ],
                                [
                                    0.06851503076670362,
                                    0.0007498071157868701,
                                    0.9206597491258165,
                                    0.01007541299169301,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727566,
                                    0.9094290648192482,
                                    0.04476113581359526,
                                ],
                                [
                                    0.045313898205927496,
                                    0.0004959011612289612,
                                    0.9438608816865927,
                                    0.010329318946250918,
                                ],
                                [
                                    0.23606031242843198,
                                    0.03078988944191471,
                                    0.6485570150979888,
                                    0.08459278303166451,
                                ],
                                [
                                    0.031921289695564,
                                    0.004163567227624191,
                                    0.8526960378308568,
                                    0.11121910524595503,
                                ],
                                [
                                    0.12067763995485271,
                                    0.036202499495654655,
                                    0.6485570150979888,
                                    0.1945628454515038,
                                ],
                                [
                                    0.14852585716644331,
                                    0.008354282284064077,
                                    0.7982214984049757,
                                    0.04489836214451695,
                                ],
                                [
                                    0.031921289695563994,
                                    0.009576177281364137,
                                    0.7373133653572775,
                                    0.2211891676657943,
                                ],
                                [
                                    0.039287617123319,
                                    0.002209849853609137,
                                    0.9074597384481,
                                    0.05104279457497189,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.017591278886500528,
                                    0.005863759628833509,
                                    0.7324087211134995,
                                    0.2441362403711665,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.25227743211430126,
                                    0.03290512565869977,
                                    0.6323398954121194,
                                    0.08247754681487945,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.031123100232696096,
                                    0.0040594575403049594,
                                    0.8534942272937247,
                                    0.11132321493327427,
                                ],
                                [
                                    0.4800353306655652,
                                    0.3000245444947562,
                                    0.13534734180801408,
                                    0.08459278303166454,
                                ],
                                [
                                    0.006661652879855697,
                                    0.004163567227624186,
                                    0.6087210195937236,
                                    0.3804537602987966,
                                ],
                                [
                                    0.09541800313914443,
                                    0.3180669729563503,
                                    0.13534734180801408,
                                    0.4511676820964912,
                                ],
                                [
                                    0.34008614136492404,
                                    0.07339883473057068,
                                    0.4824011581164986,
                                    0.10411386578800672,
                                ],
                                [
                                    0.006661652879855703,
                                    0.022205995689218275,
                                    0.2241036920673028,
                                    0.7470286593636232,
                                ],
                                [
                                    0.02374327431395641,
                                    0.005124374255117569,
                                    0.7987440251674662,
                                    0.17238832626345982,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.023403424405383583,
                                    0.021306097298261276,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.001048663553561164,
                                    0.522303146741872,
                                    0.4754962979311048,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.39088822003700124,
                                    0.11021205762651033,
                                    0.38917165512332014,
                                    0.10972806721316823,
                                ],
                                [
                                    0.0011518917734620597,
                                    0.023403424405383594,
                                    0.04575818525720601,
                                    0.9296864985639484,
                                ],
                                [
                                    0.01915461687299256,
                                    0.005400699305853092,
                                    0.7609052582873288,
                                    0.21453942553382546,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.8870743039674259,
                                    0.021306097298261256,
                                    0.08947065751724008,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359526,
                                    0.04366085815008366,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9318096327260459,
                                    0.02238056790679763,
                                    0.04473532875862004,
                                    0.0010744706085363772,
                                ],
                                [
                                    0.8870743039674259,
                                    0.043660858150083665,
                                    0.06601561900190606,
                                    0.003249218880584358,
                                ],
                                [
                                    0.9089047330424678,
                                    0.021830429075041832,
                                    0.06764022844219825,
                                    0.001624609440292179,
                                ],
                                [
                                    0.8526960378308568,
                                    0.11121910524595503,
                                    0.03192128969556395,
                                    0.004163567227624184,
                                ],
                                [
                                    0.6485570150979889,
                                    0.08459278303166452,
                                    0.23606031242843187,
                                    0.030789889441914697,
                                ],
                                [
                                    0.7373133653572775,
                                    0.2211891676657943,
                                    0.03192128969556395,
                                    0.009576177281364125,
                                ],
                                [
                                    0.8479079491901746,
                                    0.11059458383289715,
                                    0.03670937833624601,
                                    0.004788088640682062,
                                ],
                                [
                                    0.6485570150979889,
                                    0.19456284545150382,
                                    0.12067763995485266,
                                    0.036202499495654634,
                                ],
                                [
                                    0.7458384378237408,
                                    0.09728142272575191,
                                    0.13877888970268,
                                    0.018101249747827317,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.3574087211134995,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.1308637596288335,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.7236130816702492,
                                    0.24120436055674974,
                                    0.02638691832975076,
                                    0.008795639443250253,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.5361130816702493,
                                    0.17870436055674976,
                                    0.21388691832975076,
                                    0.07129563944325025,
                                ],
                                [
                                    0.6087210195937236,
                                    0.3804537602987966,
                                    0.006661652879855697,
                                    0.004163567227624186,
                                ],
                                [
                                    0.13534734180801408,
                                    0.08459278303166454,
                                    0.4800353306655652,
                                    0.3000245444947562,
                                ],
                                [
                                    0.2241036920673028,
                                    0.7470286593636232,
                                    0.006661652879855697,
                                    0.022205995689218255,
                                ],
                                [
                                    0.5976180217491144,
                                    0.3735143296818116,
                                    0.017764650724464825,
                                    0.011102997844609127,
                                ],
                                [
                                    0.13534734180801408,
                                    0.4511676820964912,
                                    0.09541800313914443,
                                    0.3180669729563503,
                                ],
                                [
                                    0.3609311828562597,
                                    0.2255838410482456,
                                    0.25445148961731956,
                                    0.15903348647817514,
                                ],
                                [
                                    0.522303146741872,
                                    0.4754962979311048,
                                    0.0011518917734620576,
                                    0.001048663553561152,
                                ],
                                [
                                    0.023403424405383573,
                                    0.021306097298261266,
                                    0.5000516141099505,
                                    0.4552388641864047,
                                ],
                                [
                                    0.04575818525720601,
                                    0.9296864985639484,
                                    0.0011518917734620578,
                                    0.023403424405383556,
                                ],
                                [
                                    0.5106014345391802,
                                    0.4648432492819742,
                                    0.012853603976153835,
                                    0.011701712202691778,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.261151573370936,
                                    0.2377481489655524,
                                    0.26230346514439806,
                                    0.23879681251911355,
                                ],
                                [
                                    0.7617635407441694,
                                    0.01829633441615198,
                                    0.21478142074049653,
                                    0.005158704099182031,
                                ],
                                [
                                    0.7159537413770131,
                                    0.017196056752640375,
                                    0.26059122010765295,
                                    0.006258981762693634,
                                ],
                                [
                                    0.7383085022288354,
                                    0.036338762877746046,
                                    0.21478142074049653,
                                    0.01057131415292197,
                                ],
                                [
                                    0.7564778836677084,
                                    0.018169381438873023,
                                    0.2200670778169575,
                                    0.005285657076460985,
                                ],
                                [
                                    0.7159537413770131,
                                    0.03523848521423444,
                                    0.23713618159231892,
                                    0.011671591816433574,
                                ],
                                [
                                    0.7335729839841303,
                                    0.01761924260711722,
                                    0.24297197750053573,
                                    0.005835795908216787,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.523447494058811,
                                    0.06827446047545313,
                                    0.3611698334676098,
                                    0.047108211998126086,
                                ],
                                [
                                    0.6122038443180997,
                                    0.18365713294903238,
                                    0.15703081073474184,
                                    0.047108211998126086,
                                ],
                                [
                                    0.7040324107926159,
                                    0.09182856647451619,
                                    0.1805849167338049,
                                    0.023554105999063043,
                                ],
                                [
                                    0.523447494058811,
                                    0.15703081073474184,
                                    0.24578716099403053,
                                    0.0737345342124166,
                                ],
                                [
                                    0.601962899426182,
                                    0.07851540536737092,
                                    0.28265442810023883,
                                    0.0368672671062083,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.2884629956448156,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.1538456681183948,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.6201944934672234,
                                    0.2067314978224078,
                                    0.12980550653277662,
                                    0.043268502177592205,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.4326944934672234,
                                    0.1442314978224078,
                                    0.3173055065327766,
                                    0.1057685021775922,
                                ],
                                [
                                    0.5826119178288338,
                                    0.36413543774258517,
                                    0.032770754644745465,
                                    0.02048188978383558,
                                ],
                                [
                                    0.10923824004312432,
                                    0.06827446047545316,
                                    0.5061444324304549,
                                    0.3163428670509676,
                                ],
                                [
                                    0.19799459030241304,
                                    0.6599964150097172,
                                    0.03277075464474546,
                                    0.10923824004312427,
                                ],
                                [
                                    0.5279927978072716,
                                    0.3299982075048586,
                                    0.0873898746663076,
                                    0.054619120021562134,
                                ],
                                [
                                    0.10923824004312431,
                                    0.36413543774258517,
                                    0.12152710490403419,
                                    0.40509921731025633,
                                ],
                                [
                                    0.2913059589144169,
                                    0.18206771887129258,
                                    0.32407671355916234,
                                    0.20254960865512817,
                                ],
                                [
                                    0.5177885225070362,
                                    0.47138625738548395,
                                    0.005666516008297856,
                                    0.005158704099182037,
                                ],
                                [
                                    0.018888800170547792,
                                    0.0171960567526404,
                                    0.5045662383447862,
                                    0.45934890473202555,
                                ],
                                [
                                    0.041243561022370215,
                                    0.8379611564503106,
                                    0.005666516008297855,
                                    0.1151287665190213,
                                ],
                                [
                                    0.46022413924752553,
                                    0.4189805782251553,
                                    0.0632308992678085,
                                    0.05756438325951065,
                                ],
                                [
                                    0.018888800170547785,
                                    0.38377095581746706,
                                    0.02802127686012029,
                                    0.5693189671518649,
                                ],
                                [
                                    0.2107742780792813,
                                    0.19188547790873353,
                                    0.3126807604360527,
                                    0.28465948357593246,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.4877223419105772,
                                    0.02400517734708981,
                                    0.46536758105875475,
                                    0.022904899683578207,
                                ],
                                [
                                    0.4997249305841221,
                                    0.012002588673544905,
                                    0.47682003090054387,
                                    0.011452449841789104,
                                ],
                                [
                                    0.46536758105875475,
                                    0.022904899683578207,
                                    0.4877223419105772,
                                    0.02400517734708981,
                                ],
                                [
                                    0.47682003090054387,
                                    0.011452449841789104,
                                    0.4997249305841221,
                                    0.012002588673544905,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3402391523967765,
                                    0.044378175129644364,
                                    0.5443781751296443,
                                    0.07100449734393485,
                                ],
                                [
                                    0.4289955026560652,
                                    0.1286958335807245,
                                    0.3402391523967764,
                                    0.10206951136643397,
                                ],
                                [
                                    0.4933434194464274,
                                    0.06434791679036225,
                                    0.3912739080799934,
                                    0.051034755683216984,
                                ],
                                [
                                    0.34023915239677643,
                                    0.10206951136643398,
                                    0.42899550265606506,
                                    0.12869583358072448,
                                ],
                                [
                                    0.3912739080799934,
                                    0.05103475568321699,
                                    0.49334341944642734,
                                    0.06434791679036224,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [0.46875, 0.15625, 0.28125, 0.09375],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.28125, 0.09375, 0.46875, 0.15625],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.1597608476032236,
                                    0.5325478161599867,
                                    0.0710044973439349,
                                    0.23668683889285475,
                                ],
                                [
                                    0.42603475568321697,
                                    0.26627390807999335,
                                    0.18934791679036225,
                                    0.11834341944642737,
                                ],
                                [
                                    0.07100449734393491,
                                    0.23668683889285477,
                                    0.1597608476032236,
                                    0.5325478161599867,
                                ],
                                [
                                    0.18934791679036228,
                                    0.11834341944642739,
                                    0.42603475568321697,
                                    0.26627390807999335,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.034632418941245253,
                                    0.7036400618010877,
                                    0.012277658089422822,
                                    0.2494498611682442,
                                ],
                                [
                                    0.3864524498417891,
                                    0.35182003090054387,
                                    0.13700258867354492,
                                    0.1247249305841221,
                                ],
                                [
                                    0.012277658089422822,
                                    0.2494498611682442,
                                    0.034632418941245253,
                                    0.7036400618010877,
                                ],
                                [
                                    0.13700258867354492,
                                    0.1247249305841221,
                                    0.3864524498417891,
                                    0.35182003090054387,
                                ],
                                [
                                    0.26059122010765307,
                                    0.006258981762693637,
                                    0.715953741377013,
                                    0.01719605675264037,
                                ],
                                [
                                    0.21478142074049658,
                                    0.0051587040991820324,
                                    0.7617635407441694,
                                    0.01829633441615198,
                                ],
                                [
                                    0.237136181592319,
                                    0.011671591816433577,
                                    0.715953741377013,
                                    0.03523848521423444,
                                ],
                                [
                                    0.2429719775005358,
                                    0.005835795908216789,
                                    0.7335729839841302,
                                    0.01761924260711722,
                                ],
                                [
                                    0.21478142074049658,
                                    0.010571314152921974,
                                    0.7383085022288354,
                                    0.036338762877746046,
                                ],
                                [
                                    0.22006707781695756,
                                    0.005285657076460987,
                                    0.7564778836677084,
                                    0.018169381438873023,
                                ],
                                [
                                    0.3611698334676099,
                                    0.0471082119981261,
                                    0.5234474940588109,
                                    0.06827446047545312,
                                ],
                                [
                                    0.1570308107347419,
                                    0.020481889783835583,
                                    0.7275865167916789,
                                    0.09490078268974364,
                                ],
                                [
                                    0.2457871609940306,
                                    0.07373453421241662,
                                    0.5234474940588109,
                                    0.15703081073474182,
                                ],
                                [
                                    0.28265442810023894,
                                    0.03686726710620831,
                                    0.6019628994261819,
                                    0.07851540536737091,
                                ],
                                [
                                    0.15703081073474187,
                                    0.0471082119981261,
                                    0.6122038443180996,
                                    0.18365713294903235,
                                ],
                                [
                                    0.18058491673380495,
                                    0.02355410599906305,
                                    0.7040324107926158,
                                    0.09182856647451618,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.08653700435518444,
                                    0.028845668118394813,
                                    0.6634629956448156,
                                    0.2211543318816052,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.3173055065327766,
                                    0.1057685021775922,
                                    0.4326944934672234,
                                    0.1442314978224078,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.12980550653277662,
                                    0.043268502177592205,
                                    0.6201944934672234,
                                    0.2067314978224078,
                                ],
                                [
                                    0.5061444324304549,
                                    0.3163428670509676,
                                    0.10923824004312431,
                                    0.06827446047545314,
                                ],
                                [
                                    0.03277075464474545,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.36413543774258517,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.32407671355916234,
                                    0.20254960865512817,
                                    0.2913059589144169,
                                    0.18206771887129258,
                                ],
                                [
                                    0.032770754644745465,
                                    0.1092382400431243,
                                    0.19799459030241304,
                                    0.6599964150097172,
                                ],
                                [
                                    0.08738987466630761,
                                    0.05461912002156215,
                                    0.5279927978072716,
                                    0.3299982075048586,
                                ],
                                [
                                    0.5045662383447862,
                                    0.45934890473202555,
                                    0.018888800170547785,
                                    0.017196056752640392,
                                ],
                                [
                                    0.00566651600829785,
                                    0.0051587040991820324,
                                    0.5177885225070362,
                                    0.47138625738548395,
                                ],
                                [
                                    0.02802127686012029,
                                    0.5693189671518649,
                                    0.018888800170547785,
                                    0.38377095581746706,
                                ],
                                [
                                    0.3126807604360527,
                                    0.28465948357593246,
                                    0.2107742780792813,
                                    0.19188547790873353,
                                ],
                                [
                                    0.005666516008297856,
                                    0.11512876651902133,
                                    0.041243561022370215,
                                    0.8379611564503106,
                                ],
                                [
                                    0.06323089926780852,
                                    0.05756438325951067,
                                    0.46022413924752553,
                                    0.4189805782251553,
                                ],
                                [
                                    0.08947065751724015,
                                    0.0021489412170727566,
                                    0.8870743039674258,
                                    0.021306097298261252,
                                ],
                                [
                                    0.043660858150083685,
                                    0.0010486635535611516,
                                    0.9328841033345823,
                                    0.02240637496177286,
                                ],
                                [
                                    0.06601561900190613,
                                    0.0032492188805843614,
                                    0.8870743039674258,
                                    0.04366085815008366,
                                ],
                                [
                                    0.06764022844219832,
                                    0.0016246094402921807,
                                    0.9089047330424677,
                                    0.02183042907504183,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727566,
                                    0.9094290648192482,
                                    0.04476113581359526,
                                ],
                                [
                                    0.044735328758620074,
                                    0.0010744706085363783,
                                    0.9318096327260459,
                                    0.02238056790679763,
                                ],
                                [
                                    0.23606031242843198,
                                    0.03078988944191471,
                                    0.6485570150979888,
                                    0.08459278303166451,
                                ],
                                [
                                    0.031921289695564,
                                    0.004163567227624191,
                                    0.8526960378308568,
                                    0.11121910524595503,
                                ],
                                [
                                    0.12067763995485271,
                                    0.036202499495654655,
                                    0.6485570150979888,
                                    0.1945628454515038,
                                ],
                                [
                                    0.13877888970268004,
                                    0.018101249747827328,
                                    0.7458384378237407,
                                    0.0972814227257519,
                                ],
                                [
                                    0.031921289695563994,
                                    0.009576177281364137,
                                    0.7373133653572775,
                                    0.2211891676657943,
                                ],
                                [
                                    0.03670937833624606,
                                    0.004788088640682068,
                                    0.8479079491901746,
                                    0.11059458383289715,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.017591278886500528,
                                    0.005863759628833509,
                                    0.7324087211134995,
                                    0.2441362403711665,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.2138869183297508,
                                    0.07129563944325026,
                                    0.5361130816702492,
                                    0.17870436055674974,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.02638691832975079,
                                    0.008795639443250264,
                                    0.7236130816702492,
                                    0.24120436055674974,
                                ],
                                [
                                    0.4800353306655652,
                                    0.3000245444947562,
                                    0.13534734180801408,
                                    0.08459278303166454,
                                ],
                                [
                                    0.006661652879855697,
                                    0.004163567227624186,
                                    0.6087210195937236,
                                    0.3804537602987966,
                                ],
                                [
                                    0.09541800313914443,
                                    0.3180669729563503,
                                    0.13534734180801408,
                                    0.4511676820964912,
                                ],
                                [
                                    0.25445148961731956,
                                    0.15903348647817514,
                                    0.3609311828562597,
                                    0.2255838410482456,
                                ],
                                [
                                    0.006661652879855703,
                                    0.022205995689218275,
                                    0.2241036920673028,
                                    0.7470286593636232,
                                ],
                                [
                                    0.017764650724464842,
                                    0.011102997844609138,
                                    0.5976180217491144,
                                    0.3735143296818116,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.023403424405383583,
                                    0.021306097298261276,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.001048663553561164,
                                    0.522303146741872,
                                    0.4754962979311048,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.26230346514439806,
                                    0.23879681251911355,
                                    0.261151573370936,
                                    0.2377481489655524,
                                ],
                                [
                                    0.0011518917734620597,
                                    0.023403424405383594,
                                    0.04575818525720601,
                                    0.9296864985639484,
                                ],
                                [
                                    0.012853603976153857,
                                    0.011701712202691797,
                                    0.5106014345391802,
                                    0.4648432492819742,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.8870743039674259,
                                    0.021306097298261256,
                                    0.08947065751724008,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359526,
                                    0.04366085815008366,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9197583837654991,
                                    0.03443181686734434,
                                    0.04415675931131262,
                                    0.0016530400558437937,
                                ],
                                [
                                    0.8870743039674259,
                                    0.043660858150083665,
                                    0.06601561900190606,
                                    0.003249218880584358,
                                ],
                                [
                                    0.8971497169591189,
                                    0.033585445158390646,
                                    0.06676542611769293,
                                    0.0024994117647974884,
                                ],
                                [
                                    0.8526960378308568,
                                    0.11121910524595503,
                                    0.03192128969556395,
                                    0.004163567227624184,
                                ],
                                [
                                    0.6485570150979889,
                                    0.08459278303166452,
                                    0.23606031242843187,
                                    0.030789889441914697,
                                ],
                                [
                                    0.7373133653572775,
                                    0.2211891676657943,
                                    0.03192128969556395,
                                    0.009576177281364125,
                                ],
                                [
                                    0.7883561599322495,
                                    0.1701463730908224,
                                    0.03413113954917309,
                                    0.007366327427754989,
                                ],
                                [
                                    0.6485570150979889,
                                    0.19456284545150382,
                                    0.12067763995485266,
                                    0.036202499495654634,
                                ],
                                [
                                    0.6934553772425059,
                                    0.14966448330698684,
                                    0.12903192223891674,
                                    0.027848217211590563,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.3574087211134995,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.1308637596288335,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.5937319360467738,
                                    0.3710855061802252,
                                    0.021650736426805463,
                                    0.01353182134619555,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.43988626792837904,
                                    0.27493117429862,
                                    0.17549640454520027,
                                    0.10968615322780073,
                                ],
                                [
                                    0.6087210195937236,
                                    0.3804537602987966,
                                    0.006661652879855697,
                                    0.004163567227624186,
                                ],
                                [
                                    0.13534734180801408,
                                    0.08459278303166454,
                                    0.4800353306655652,
                                    0.3000245444947562,
                                ],
                                [
                                    0.2241036920673028,
                                    0.7470286593636232,
                                    0.006661652879855697,
                                    0.022205995689218255,
                                ],
                                [
                                    0.3964920183307627,
                                    0.5746403331001633,
                                    0.011786027134973263,
                                    0.017081621434100688,
                                ],
                                [
                                    0.13534734180801408,
                                    0.4511676820964912,
                                    0.09541800313914443,
                                    0.3180669729563503,
                                ],
                                [
                                    0.23946120759602083,
                                    0.3470538163084844,
                                    0.16881683786971516,
                                    0.24466813822577957,
                                ],
                                [
                                    0.522303146741872,
                                    0.4754962979311048,
                                    0.0011518917734620576,
                                    0.001048663553561152,
                                ],
                                [
                                    0.023403424405383573,
                                    0.021306097298261266,
                                    0.5000516141099505,
                                    0.4552388641864047,
                                ],
                                [
                                    0.04575818525720601,
                                    0.9296864985639484,
                                    0.0011518917734620578,
                                    0.023403424405383556,
                                ],
                                [
                                    0.26029761079103153,
                                    0.7151470730301228,
                                    0.006552591079315142,
                                    0.01800272509953047,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.13313149161855184,
                                    0.36576823071793657,
                                    0.13371871025179485,
                                    0.36738156741171674,
                                ],
                                [
                                    0.7617635407441694,
                                    0.01829633441615198,
                                    0.21478142074049653,
                                    0.005158704099182031,
                                ],
                                [
                                    0.7159537413770131,
                                    0.017196056752640375,
                                    0.26059122010765295,
                                    0.006258981762693634,
                                ],
                                [
                                    0.7383085022288354,
                                    0.036338762877746046,
                                    0.21478142074049653,
                                    0.01057131415292197,
                                ],
                                [
                                    0.7466942293792714,
                                    0.02795303572730998,
                                    0.21722091369754035,
                                    0.008131821195878153,
                                ],
                                [
                                    0.7159537413770131,
                                    0.03523848521423444,
                                    0.23713618159231892,
                                    0.011671591816433574,
                                ],
                                [
                                    0.7240855625728911,
                                    0.027106664018356288,
                                    0.23982958050392064,
                                    0.008978192904831848,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.523447494058811,
                                    0.06827446047545313,
                                    0.3611698334676098,
                                    0.047108211998126086,
                                ],
                                [
                                    0.6122038443180997,
                                    0.18365713294903238,
                                    0.15703081073474184,
                                    0.047108211998126086,
                                ],
                                [
                                    0.6545855459550893,
                                    0.14127543131204276,
                                    0.1679017535263333,
                                    0.036237269206534646,
                                ],
                                [
                                    0.523447494058811,
                                    0.15703081073474184,
                                    0.24578716099403053,
                                    0.0737345342124166,
                                ],
                                [
                                    0.5596847632653457,
                                    0.12079354152820718,
                                    0.2628025362160769,
                                    0.056719158990370215,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.2884629956448156,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.1538456681183948,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.508875926457677,
                                    0.31805006483195425,
                                    0.10650674601590229,
                                    0.06656726269446653,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.35503025833928215,
                                    0.22189573295034903,
                                    0.2603524141342971,
                                    0.16272159457607172,
                                ],
                                [
                                    0.5826119178288338,
                                    0.36413543774258517,
                                    0.032770754644745465,
                                    0.02048188978383558,
                                ],
                                [
                                    0.10923824004312432,
                                    0.06827446047545316,
                                    0.5061444324304549,
                                    0.3163428670509676,
                                ],
                                [
                                    0.19799459030241304,
                                    0.6599964150097172,
                                    0.03277075464474546,
                                    0.10923824004312427,
                                ],
                                [
                                    0.35029889067601844,
                                    0.5076921146361119,
                                    0.05797915478971754,
                                    0.0840298398981522,
                                ],
                                [
                                    0.10923824004312431,
                                    0.36413543774258517,
                                    0.12152710490403419,
                                    0.40509921731025633,
                                ],
                                [
                                    0.19326807994127657,
                                    0.28010559784443295,
                                    0.21500996552445942,
                                    0.31161635668983106,
                                ],
                                [
                                    0.5177885225070362,
                                    0.47138625738548395,
                                    0.005666516008297856,
                                    0.005158704099182037,
                                ],
                                [
                                    0.018888800170547792,
                                    0.0171960567526404,
                                    0.5045662383447862,
                                    0.45934890473202555,
                                ],
                                [
                                    0.041243561022370215,
                                    0.8379611564503106,
                                    0.005666516008297855,
                                    0.1151287665190213,
                                ],
                                [
                                    0.234615956342946,
                                    0.6445887611297348,
                                    0.03223424552740068,
                                    0.08856103699991848,
                                ],
                                [
                                    0.018888800170547785,
                                    0.38377095581746706,
                                    0.02802127686012029,
                                    0.5693189671518649,
                                ],
                                [
                                    0.1074498371704663,
                                    0.29520991881754854,
                                    0.1594003646998804,
                                    0.43793987931210476,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.4877223419105772,
                                    0.02400517734708981,
                                    0.46536758105875475,
                                    0.022904899683578207,
                                ],
                                [
                                    0.49326190494159605,
                                    0.018465614316070914,
                                    0.47065323813521576,
                                    0.01761924260711722,
                                ],
                                [
                                    0.46536758105875475,
                                    0.022904899683578207,
                                    0.4877223419105772,
                                    0.02400517734708981,
                                ],
                                [
                                    0.47065323813521576,
                                    0.01761924260711722,
                                    0.49326190494159605,
                                    0.018465614316070914,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3402391523967765,
                                    0.044378175129644364,
                                    0.5443781751296443,
                                    0.07100449734393485,
                                ],
                                [
                                    0.4289955026560652,
                                    0.1286958335807245,
                                    0.3402391523967764,
                                    0.10206951136643397,
                                ],
                                [
                                    0.4586940410855832,
                                    0.0989972951512065,
                                    0.3637932583958395,
                                    0.07851540536737091,
                                ],
                                [
                                    0.34023915239677643,
                                    0.10206951136643398,
                                    0.42899550265606506,
                                    0.12869583358072448,
                                ],
                                [
                                    0.36379325839583954,
                                    0.07851540536737092,
                                    0.4586940410855831,
                                    0.09899729515120648,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.38461417029598705,
                                    0.24038582970401295,
                                    0.2307685021775922,
                                    0.1442314978224078,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.2307685021775922,
                                    0.1442314978224078,
                                    0.38461417029598705,
                                    0.24038582970401295,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.1597608476032236,
                                    0.5325478161599867,
                                    0.0710044973439349,
                                    0.23668683889285475,
                                ],
                                [
                                    0.2826544281002389,
                                    0.40965423566297143,
                                    0.12562361736549704,
                                    0.18206771887129258,
                                ],
                                [
                                    0.07100449734393491,
                                    0.23668683889285477,
                                    0.1597608476032236,
                                    0.5325478161599867,
                                ],
                                [
                                    0.12562361736549707,
                                    0.1820677188712926,
                                    0.2826544281002389,
                                    0.40965423566297143,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.034632418941245253,
                                    0.7036400618010877,
                                    0.012277658089422822,
                                    0.2494498611682442,
                                ],
                                [
                                    0.1970081605214132,
                                    0.5412643202209197,
                                    0.0698420413489335,
                                    0.19188547790873353,
                                ],
                                [
                                    0.012277658089422822,
                                    0.2494498611682442,
                                    0.034632418941245253,
                                    0.7036400618010877,
                                ],
                                [
                                    0.0698420413489335,
                                    0.19188547790873353,
                                    0.1970081605214132,
                                    0.5412643202209197,
                                ],
                                [
                                    0.26059122010765307,
                                    0.006258981762693637,
                                    0.715953741377013,
                                    0.01719605675264037,
                                ],
                                [
                                    0.21478142074049658,
                                    0.0051587040991820324,
                                    0.7617635407441694,
                                    0.01829633441615198,
                                ],
                                [
                                    0.237136181592319,
                                    0.011671591816433577,
                                    0.715953741377013,
                                    0.03523848521423444,
                                ],
                                [
                                    0.23982958050392073,
                                    0.008978192904831851,
                                    0.724085562572891,
                                    0.027106664018356284,
                                ],
                                [
                                    0.21478142074049658,
                                    0.010571314152921974,
                                    0.7383085022288354,
                                    0.036338762877746046,
                                ],
                                [
                                    0.2172209136975404,
                                    0.008131821195878155,
                                    0.7466942293792714,
                                    0.02795303572730998,
                                ],
                                [
                                    0.3611698334676099,
                                    0.0471082119981261,
                                    0.5234474940588109,
                                    0.06827446047545312,
                                ],
                                [
                                    0.1570308107347419,
                                    0.020481889783835583,
                                    0.7275865167916789,
                                    0.09490078268974364,
                                ],
                                [
                                    0.2457871609940306,
                                    0.07373453421241662,
                                    0.5234474940588109,
                                    0.15703081073474182,
                                ],
                                [
                                    0.262802536216077,
                                    0.056719158990370236,
                                    0.5596847632653457,
                                    0.12079354152820716,
                                ],
                                [
                                    0.15703081073474187,
                                    0.0471082119981261,
                                    0.6122038443180996,
                                    0.18365713294903235,
                                ],
                                [
                                    0.16790175352633332,
                                    0.03623726920653466,
                                    0.6545855459550893,
                                    0.14127543131204273,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.08653700435518444,
                                    0.028845668118394813,
                                    0.6634629956448156,
                                    0.2211543318816052,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.2603524141342971,
                                    0.16272159457607172,
                                    0.35503025833928215,
                                    0.22189573295034903,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.10650674601590229,
                                    0.06656726269446653,
                                    0.508875926457677,
                                    0.31805006483195425,
                                ],
                                [
                                    0.5061444324304549,
                                    0.3163428670509676,
                                    0.10923824004312431,
                                    0.06827446047545314,
                                ],
                                [
                                    0.03277075464474545,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.36413543774258517,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.21500996552445942,
                                    0.31161635668983106,
                                    0.19326807994127657,
                                    0.28010559784443295,
                                ],
                                [
                                    0.032770754644745465,
                                    0.1092382400431243,
                                    0.19799459030241304,
                                    0.6599964150097172,
                                ],
                                [
                                    0.05797915478971755,
                                    0.08402983989815221,
                                    0.35029889067601844,
                                    0.5076921146361119,
                                ],
                                [
                                    0.5045662383447862,
                                    0.45934890473202555,
                                    0.018888800170547785,
                                    0.017196056752640392,
                                ],
                                [
                                    0.00566651600829785,
                                    0.0051587040991820324,
                                    0.5177885225070362,
                                    0.47138625738548395,
                                ],
                                [
                                    0.02802127686012029,
                                    0.5693189671518649,
                                    0.018888800170547785,
                                    0.38377095581746706,
                                ],
                                [
                                    0.1594003646998804,
                                    0.43793987931210476,
                                    0.1074498371704663,
                                    0.29520991881754854,
                                ],
                                [
                                    0.005666516008297856,
                                    0.11512876651902133,
                                    0.041243561022370215,
                                    0.8379611564503106,
                                ],
                                [
                                    0.03223424552740069,
                                    0.0885610369999185,
                                    0.234615956342946,
                                    0.6445887611297348,
                                ],
                                [
                                    0.08947065751724015,
                                    0.0021489412170727566,
                                    0.8870743039674258,
                                    0.021306097298261252,
                                ],
                                [
                                    0.043660858150083685,
                                    0.0010486635535611516,
                                    0.9328841033345823,
                                    0.02240637496177286,
                                ],
                                [
                                    0.06601561900190613,
                                    0.0032492188805843614,
                                    0.8870743039674258,
                                    0.04366085815008366,
                                ],
                                [
                                    0.066765426117693,
                                    0.002499411764797491,
                                    0.8971497169591188,
                                    0.033585445158390646,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727566,
                                    0.9094290648192482,
                                    0.04476113581359526,
                                ],
                                [
                                    0.04415675931131266,
                                    0.001653040055843795,
                                    0.9197583837654991,
                                    0.03443181686734434,
                                ],
                                [
                                    0.23606031242843198,
                                    0.03078988944191471,
                                    0.6485570150979888,
                                    0.08459278303166451,
                                ],
                                [
                                    0.031921289695564,
                                    0.004163567227624191,
                                    0.8526960378308568,
                                    0.11121910524595503,
                                ],
                                [
                                    0.12067763995485271,
                                    0.036202499495654655,
                                    0.6485570150979888,
                                    0.1945628454515038,
                                ],
                                [
                                    0.12903192223891682,
                                    0.027848217211590576,
                                    0.6934553772425058,
                                    0.1496644833069868,
                                ],
                                [
                                    0.031921289695563994,
                                    0.009576177281364137,
                                    0.7373133653572775,
                                    0.2211891676657943,
                                ],
                                [
                                    0.034131139549173135,
                                    0.007366327427754999,
                                    0.7883561599322495,
                                    0.1701463730908224,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.017591278886500528,
                                    0.005863759628833509,
                                    0.7324087211134995,
                                    0.2441362403711665,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.1754964045452003,
                                    0.10968615322780076,
                                    0.4398862679283789,
                                    0.27493117429862,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.021650736426805487,
                                    0.013531821346195566,
                                    0.5937319360467738,
                                    0.3710855061802252,
                                ],
                                [
                                    0.4800353306655652,
                                    0.3000245444947562,
                                    0.13534734180801408,
                                    0.08459278303166454,
                                ],
                                [
                                    0.006661652879855697,
                                    0.004163567227624186,
                                    0.6087210195937236,
                                    0.3804537602987966,
                                ],
                                [
                                    0.09541800313914443,
                                    0.3180669729563503,
                                    0.13534734180801408,
                                    0.4511676820964912,
                                ],
                                [
                                    0.16881683786971516,
                                    0.24466813822577957,
                                    0.23946120759602083,
                                    0.3470538163084844,
                                ],
                                [
                                    0.006661652879855703,
                                    0.022205995689218275,
                                    0.2241036920673028,
                                    0.7470286593636232,
                                ],
                                [
                                    0.011786027134973273,
                                    0.017081621434100705,
                                    0.3964920183307627,
                                    0.5746403331001633,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.023403424405383583,
                                    0.021306097298261276,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.001048663553561164,
                                    0.522303146741872,
                                    0.4754962979311048,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.13371871025179485,
                                    0.36738156741171674,
                                    0.13313149161855184,
                                    0.36576823071793657,
                                ],
                                [
                                    0.0011518917734620597,
                                    0.023403424405383594,
                                    0.04575818525720601,
                                    0.9296864985639484,
                                ],
                                [
                                    0.006552591079315153,
                                    0.018002725099530503,
                                    0.26029761079103153,
                                    0.7151470730301228,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.8870743039674259,
                                    0.021306097298261256,
                                    0.08947065751724008,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359526,
                                    0.04366085815008366,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9115288131482442,
                                    0.042661387484599314,
                                    0.04376166514811092,
                                    0.002048134219045494,
                                ],
                                [
                                    0.8870743039674259,
                                    0.043660858150083665,
                                    0.06601561900190606,
                                    0.003249218880584358,
                                ],
                                [
                                    0.8891224381864714,
                                    0.04161272393103817,
                                    0.06616804010988378,
                                    0.003096797772606645,
                                ],
                                [
                                    0.8526960378308568,
                                    0.11121910524595503,
                                    0.03192128969556395,
                                    0.004163567227624184,
                                ],
                                [
                                    0.6485570150979889,
                                    0.08459278303166452,
                                    0.23606031242843187,
                                    0.030789889441914697,
                                ],
                                [
                                    0.7373133653572775,
                                    0.2211891676657943,
                                    0.03192128969556395,
                                    0.009576177281364125,
                                ],
                                [
                                    0.7476893662508293,
                                    0.21081316677224254,
                                    0.03237050890949208,
                                    0.009126958067436,
                                ],
                                [
                                    0.6485570150979889,
                                    0.19456284545150382,
                                    0.12067763995485266,
                                    0.036202499495654634,
                                ],
                                [
                                    0.6576839731654248,
                                    0.1854358873840678,
                                    0.12237590199489654,
                                    0.03450423745561076,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.3574087211134995,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.1308637596288335,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.5050385513811998,
                                    0.45977889084579915,
                                    0.01841648713413421,
                                    0.016766070638866804,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.37417479175236634,
                                    0.3406426504746327,
                                    0.14928024676296772,
                                    0.13590231101003328,
                                ],
                                [
                                    0.6087210195937236,
                                    0.3804537602987966,
                                    0.006661652879855697,
                                    0.004163567227624186,
                                ],
                                [
                                    0.13534734180801408,
                                    0.08459278303166454,
                                    0.4800353306655652,
                                    0.3000245444947562,
                                ],
                                [
                                    0.2241036920673028,
                                    0.7470286593636232,
                                    0.006661652879855697,
                                    0.022205995689218255,
                                ],
                                [
                                    0.2591468640221671,
                                    0.711985487408759,
                                    0.007703337848179608,
                                    0.021164310720894343,
                                ],
                                [
                                    0.13534734180801408,
                                    0.4511676820964912,
                                    0.09541800313914443,
                                    0.3180669729563503,
                                ],
                                [
                                    0.15651165252890845,
                                    0.4300033713755968,
                                    0.11033854934143825,
                                    0.3031464267540565,
                                ],
                                [
                                    0.522303146741872,
                                    0.4754962979311048,
                                    0.0011518917734620576,
                                    0.001048663553561152,
                                ],
                                [
                                    0.023403424405383573,
                                    0.021306097298261266,
                                    0.5000516141099505,
                                    0.4552388641864047,
                                ],
                                [
                                    0.04575818525720601,
                                    0.9296864985639484,
                                    0.0011518917734620578,
                                    0.023403424405383556,
                                ],
                                [
                                    0.0893698505192129,
                                    0.8860748333019415,
                                    0.002249748215100017,
                                    0.022305567963745596,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.045708992369129196,
                                    0.4531907299673592,
                                    0.045910606365183716,
                                    0.4551896712983279,
                                ],
                                [
                                    0.7617635407441694,
                                    0.01829633441615198,
                                    0.21478142074049653,
                                    0.005158704099182031,
                                ],
                                [
                                    0.7159537413770131,
                                    0.017196056752640375,
                                    0.26059122010765295,
                                    0.006258981762693634,
                                ],
                                [
                                    0.7383085022288354,
                                    0.036338762877746046,
                                    0.21478142074049653,
                                    0.01057131415292197,
                                ],
                                [
                                    0.7400131563946296,
                                    0.0346341087119518,
                                    0.2152773219017255,
                                    0.01007541299169301,
                                ],
                                [
                                    0.7159537413770131,
                                    0.03523848521423444,
                                    0.23713618159231892,
                                    0.011671591816433574,
                                ],
                                [
                                    0.7176067814328568,
                                    0.03358544515839065,
                                    0.23768369686349836,
                                    0.011124076545254161,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.523447494058811,
                                    0.06827446047545313,
                                    0.3611698334676098,
                                    0.047108211998126086,
                                ],
                                [
                                    0.6122038443180997,
                                    0.18365713294903238,
                                    0.15703081073474184,
                                    0.047108211998126086,
                                ],
                                [
                                    0.6208192145719704,
                                    0.1750417626951616,
                                    0.15924066058835096,
                                    0.04489836214451695,
                                ],
                                [
                                    0.523447494058811,
                                    0.15703081073474184,
                                    0.24578716099403053,
                                    0.0737345342124166,
                                ],
                                [
                                    0.530813821486566,
                                    0.14966448330698687,
                                    0.2492460536737554,
                                    0.07027564153269171,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.2884629956448156,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.1538456681183948,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.43285857661984467,
                                    0.3940674146697865,
                                    0.09059646189548937,
                                    0.08247754681487945,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.30199481699101116,
                                    0.27493117429862,
                                    0.22146022152432288,
                                    0.20161378718604595,
                                ],
                                [
                                    0.5826119178288338,
                                    0.36413543774258517,
                                    0.032770754644745465,
                                    0.02048188978383558,
                                ],
                                [
                                    0.10923824004312432,
                                    0.06827446047545316,
                                    0.5061444324304549,
                                    0.3163428670509676,
                                ],
                                [
                                    0.19799459030241304,
                                    0.6599964150097172,
                                    0.03277075464474546,
                                    0.10923824004312427,
                                ],
                                [
                                    0.22895507297048365,
                                    0.6290359323416466,
                                    0.03789512889986303,
                                    0.1041138657880067,
                                ],
                                [
                                    0.10923824004312431,
                                    0.36413543774258517,
                                    0.12152710490403419,
                                    0.40509921731025633,
                                ],
                                [
                                    0.12631986147722502,
                                    0.3470538163084845,
                                    0.14053034039312168,
                                    0.38609598182116883,
                                ],
                                [
                                    0.5177885225070362,
                                    0.47138625738548395,
                                    0.005666516008297856,
                                    0.005158704099182037,
                                ],
                                [
                                    0.018888800170547792,
                                    0.0171960567526404,
                                    0.5045662383447862,
                                    0.45934890473202555,
                                ],
                                [
                                    0.041243561022370215,
                                    0.8379611564503106,
                                    0.005666516008297855,
                                    0.1151287665190213,
                                ],
                                [
                                    0.08055238342016197,
                                    0.7986523340525188,
                                    0.011067215314150941,
                                    0.10972806721316822,
                                ],
                                [
                                    0.018888800170547785,
                                    0.38377095581746706,
                                    0.02802127686012029,
                                    0.5693189671518649,
                                ],
                                [
                                    0.036891525270078274,
                                    0.36576823071793657,
                                    0.05472807346423464,
                                    0.5426121705477505,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.4877223419105772,
                                    0.02400517734708981,
                                    0.46536758105875475,
                                    0.022904899683578207,
                                ],
                                [
                                    0.488848426629064,
                                    0.022879092628602982,
                                    0.46644205166729114,
                                    0.02183042907504183,
                                ],
                                [
                                    0.46536758105875475,
                                    0.022904899683578207,
                                    0.4877223419105772,
                                    0.02400517734708981,
                                ],
                                [
                                    0.46644205166729114,
                                    0.02183042907504183,
                                    0.488848426629064,
                                    0.022879092628602982,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3402391523967765,
                                    0.044378175129644364,
                                    0.5443781751296443,
                                    0.07100449734393485,
                                ],
                                [
                                    0.4289955026560652,
                                    0.1286958335807245,
                                    0.3402391523967764,
                                    0.10206951136643397,
                                ],
                                [
                                    0.43503263412286297,
                                    0.12265870211392668,
                                    0.34502724103745847,
                                    0.0972814227257519,
                                ],
                                [
                                    0.34023915239677643,
                                    0.10206951136643398,
                                    0.42899550265606506,
                                    0.12869583358072448,
                                ],
                                [
                                    0.3450272410374585,
                                    0.09728142272575191,
                                    0.43503263412286286,
                                    0.12265870211392665,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.3271593990720838,
                                    0.2978406009279162,
                                    0.19629563944325026,
                                    0.17870436055674974,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [
                                    0.19629563944325026,
                                    0.17870436055674974,
                                    0.3271593990720838,
                                    0.2978406009279162,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.1597608476032236,
                                    0.5325478161599867,
                                    0.0710044973439349,
                                    0.23668683889285475,
                                ],
                                [
                                    0.18474270668180265,
                                    0.5075659570814077,
                                    0.08210749518854403,
                                    0.22558384104824558,
                                ],
                                [
                                    0.07100449734393491,
                                    0.23668683889285477,
                                    0.1597608476032236,
                                    0.5325478161599867,
                                ],
                                [
                                    0.08210749518854404,
                                    0.22558384104824564,
                                    0.18474270668180265,
                                    0.5075659570814077,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.034632418941245253,
                                    0.7036400618010877,
                                    0.012277658089422822,
                                    0.2494498611682442,
                                ],
                                [
                                    0.0676402284421983,
                                    0.6706322523001347,
                                    0.023979370292114607,
                                    0.2377481489655524,
                                ],
                                [
                                    0.012277658089422822,
                                    0.2494498611682442,
                                    0.034632418941245253,
                                    0.7036400618010877,
                                ],
                                [
                                    0.023979370292114607,
                                    0.2377481489655524,
                                    0.0676402284421983,
                                    0.6706322523001347,
                                ],
                                [
                                    0.26059122010765307,
                                    0.006258981762693637,
                                    0.715953741377013,
                                    0.01719605675264037,
                                ],
                                [
                                    0.21478142074049658,
                                    0.0051587040991820324,
                                    0.7617635407441694,
                                    0.01829633441615198,
                                ],
                                [
                                    0.237136181592319,
                                    0.011671591816433577,
                                    0.715953741377013,
                                    0.03523848521423444,
                                ],
                                [
                                    0.23768369686349844,
                                    0.011124076545254165,
                                    0.7176067814328567,
                                    0.033585445158390646,
                                ],
                                [
                                    0.21478142074049658,
                                    0.010571314152921974,
                                    0.7383085022288354,
                                    0.036338762877746046,
                                ],
                                [
                                    0.21527732190172555,
                                    0.010075412991693013,
                                    0.7400131563946296,
                                    0.0346341087119518,
                                ],
                                [
                                    0.3611698334676099,
                                    0.0471082119981261,
                                    0.5234474940588109,
                                    0.06827446047545312,
                                ],
                                [
                                    0.1570308107347419,
                                    0.020481889783835583,
                                    0.7275865167916789,
                                    0.09490078268974364,
                                ],
                                [
                                    0.2457871609940306,
                                    0.07373453421241662,
                                    0.5234474940588109,
                                    0.15703081073474182,
                                ],
                                [
                                    0.2492460536737555,
                                    0.07027564153269172,
                                    0.5308138214865659,
                                    0.14966448330698684,
                                ],
                                [
                                    0.15703081073474187,
                                    0.0471082119981261,
                                    0.6122038443180996,
                                    0.18365713294903235,
                                ],
                                [
                                    0.159240660588351,
                                    0.044898362144516965,
                                    0.6208192145719703,
                                    0.17504176269516158,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.08653700435518444,
                                    0.028845668118394813,
                                    0.6634629956448156,
                                    0.2211543318816052,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.22146022152432288,
                                    0.20161378718604595,
                                    0.30199481699101116,
                                    0.27493117429862,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.09059646189548937,
                                    0.08247754681487945,
                                    0.43285857661984467,
                                    0.3940674146697865,
                                ],
                                [
                                    0.5061444324304549,
                                    0.3163428670509676,
                                    0.10923824004312431,
                                    0.06827446047545314,
                                ],
                                [
                                    0.03277075464474545,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.36413543774258517,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.14053034039312168,
                                    0.38609598182116883,
                                    0.12631986147722502,
                                    0.3470538163084845,
                                ],
                                [
                                    0.032770754644745465,
                                    0.1092382400431243,
                                    0.19799459030241304,
                                    0.6599964150097172,
                                ],
                                [
                                    0.03789512889986304,
                                    0.10411386578800673,
                                    0.22895507297048365,
                                    0.6290359323416466,
                                ],
                                [
                                    0.5045662383447862,
                                    0.45934890473202555,
                                    0.018888800170547785,
                                    0.017196056752640392,
                                ],
                                [
                                    0.00566651600829785,
                                    0.0051587040991820324,
                                    0.5177885225070362,
                                    0.47138625738548395,
                                ],
                                [
                                    0.02802127686012029,
                                    0.5693189671518649,
                                    0.018888800170547785,
                                    0.38377095581746706,
                                ],
                                [
                                    0.05472807346423464,
                                    0.5426121705477505,
                                    0.036891525270078274,
                                    0.36576823071793657,
                                ],
                                [
                                    0.005666516008297856,
                                    0.11512876651902133,
                                    0.041243561022370215,
                                    0.8379611564503106,
                                ],
                                [
                                    0.011067215314150945,
                                    0.10972806721316825,
                                    0.08055238342016197,
                                    0.7986523340525188,
                                ],
                                [
                                    0.08947065751724015,
                                    0.0021489412170727566,
                                    0.8870743039674258,
                                    0.021306097298261252,
                                ],
                                [
                                    0.043660858150083685,
                                    0.0010486635535611516,
                                    0.9328841033345823,
                                    0.02240637496177286,
                                ],
                                [
                                    0.06601561900190613,
                                    0.0032492188805843614,
                                    0.8870743039674258,
                                    0.04366085815008366,
                                ],
                                [
                                    0.06616804010988385,
                                    0.003096797772606648,
                                    0.8891224381864713,
                                    0.04161272393103816,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727566,
                                    0.9094290648192482,
                                    0.04476113581359526,
                                ],
                                [
                                    0.04376166514811096,
                                    0.0020481342190454958,
                                    0.9115288131482442,
                                    0.042661387484599314,
                                ],
                                [
                                    0.23606031242843198,
                                    0.03078988944191471,
                                    0.6485570150979888,
                                    0.08459278303166451,
                                ],
                                [
                                    0.031921289695564,
                                    0.004163567227624191,
                                    0.8526960378308568,
                                    0.11121910524595503,
                                ],
                                [
                                    0.12067763995485271,
                                    0.036202499495654655,
                                    0.6485570150979888,
                                    0.1945628454515038,
                                ],
                                [
                                    0.1223759019948966,
                                    0.03450423745561078,
                                    0.6576839731654248,
                                    0.1854358873840678,
                                ],
                                [
                                    0.031921289695563994,
                                    0.009576177281364137,
                                    0.7373133653572775,
                                    0.2211891676657943,
                                ],
                                [
                                    0.03237050890949212,
                                    0.009126958067436013,
                                    0.7476893662508293,
                                    0.21081316677224254,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.017591278886500528,
                                    0.005863759628833509,
                                    0.7324087211134995,
                                    0.2441362403711665,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.14928024676296775,
                                    0.1359023110100333,
                                    0.3741747917523663,
                                    0.34064265047463266,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.018416487134134234,
                                    0.01676607063886682,
                                    0.5050385513811998,
                                    0.45977889084579915,
                                ],
                                [
                                    0.4800353306655652,
                                    0.3000245444947562,
                                    0.13534734180801408,
                                    0.08459278303166454,
                                ],
                                [
                                    0.006661652879855697,
                                    0.004163567227624186,
                                    0.6087210195937236,
                                    0.3804537602987966,
                                ],
                                [
                                    0.09541800313914443,
                                    0.3180669729563503,
                                    0.13534734180801408,
                                    0.4511676820964912,
                                ],
                                [
                                    0.11033854934143825,
                                    0.3031464267540565,
                                    0.15651165252890845,
                                    0.4300033713755968,
                                ],
                                [
                                    0.006661652879855703,
                                    0.022205995689218275,
                                    0.2241036920673028,
                                    0.7470286593636232,
                                ],
                                [
                                    0.007703337848179616,
                                    0.021164310720894364,
                                    0.2591468640221671,
                                    0.711985487408759,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.023403424405383583,
                                    0.021306097298261276,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.001048663553561164,
                                    0.522303146741872,
                                    0.4754962979311048,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.045910606365183716,
                                    0.4551896712983279,
                                    0.045708992369129196,
                                    0.4531907299673592,
                                ],
                                [
                                    0.0011518917734620597,
                                    0.023403424405383594,
                                    0.04575818525720601,
                                    0.9296864985639484,
                                ],
                                [
                                    0.002249748215100021,
                                    0.022305567963745634,
                                    0.0893698505192129,
                                    0.8860748333019415,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.8756016244541865,
                                    0.03277877681150055,
                                    0.08831351862262524,
                                    0.0033060801116875874,
                                ],
                                [
                                    0.9099937379594674,
                                    0.044788928427772004,
                                    0.043096185009864604,
                                    0.002121148602896015,
                                ],
                                [
                                    0.9526816143045715,
                                    0.0021010520826678612,
                                    0.045117830368405276,
                                    9.950324435534591e-05,
                                ],
                                [
                                    0.8756016244541865,
                                    0.04309618500986461,
                                    0.07748829851514534,
                                    0.0038138920208034043,
                                ],
                                [
                                    0.9166761641055106,
                                    0.0020216453585406692,
                                    0.08112328056746622,
                                    0.00017890996848253778,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.6030063975790088,
                                    0.13014340055064463,
                                    0.21948090190241384,
                                    0.04736929996793276,
                                ],
                                [
                                    0.739555318529915,
                                    0.22186173889466534,
                                    0.02967933652292653,
                                    0.008903606052493122,
                                ],
                                [
                                    0.9510095061628737,
                                    0.010407551261706706,
                                    0.038165273729646475,
                                    0.0004176688457731743,
                                ],
                                [
                                    0.6030063975790086,
                                    0.18089795932699418,
                                    0.16622825747383277,
                                    0.04986738562016427,
                                ],
                                [
                                    0.7754184196992829,
                                    0.008485937206719946,
                                    0.2137563601932371,
                                    0.002339282900759932,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.29325751195225264,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.20132987799400742,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.9483544047246267,
                                    0.022777946706299252,
                                    0.028190556760039193,
                                    0.0006770918090347562,
                                ],
                                [
                                    0.29325751195225264,
                                    0.29325751195225264,
                                    0.20674248804774736,
                                    0.20674248804774736,
                                ],
                                [
                                    0.572758291429003,
                                    0.013756732475502218,
                                    0.40378667005566293,
                                    0.009698306039831791,
                                ],
                                [
                                    0.4038583457585177,
                                    0.5853164341340024,
                                    0.004419699707218271,
                                    0.006405520400261612,
                                ],
                                [
                                    0.08979672428903396,
                                    0.13014340055064466,
                                    0.318481321176702,
                                    0.46157855398361936,
                                ],
                                [
                                    0.22634564523994025,
                                    0.7545020001973315,
                                    0.00441969970721827,
                                    0.014732654855509982,
                                ],
                                [
                                    0.9454538984882218,
                                    0.03539374694904992,
                                    0.018461244588590033,
                                    0.0006911099741382185,
                                ],
                                [
                                    0.08979672428903396,
                                    0.2993289666139738,
                                    0.14096862065812454,
                                    0.4699056884388677,
                                ],
                                [
                                    0.375084146021636,
                                    0.014041544881371765,
                                    0.5888309970551758,
                                    0.02204331204181637,
                                ],
                                [
                                    0.2662629832371037,
                                    0.7315364614358731,
                                    0.0005872186332430102,
                                    0.0016133366937801992,
                                ],
                                [
                                    0.011930744892144272,
                                    0.032778776811500564,
                                    0.2549194569782024,
                                    0.7003710213181528,
                                ],
                                [
                                    0.04632285839742507,
                                    0.9411591780771876,
                                    0.0005872186332430102,
                                    0.011930744892144263,
                                ],
                                [
                                    0.9433321869328917,
                                    0.044149849541721076,
                                    0.011958291363463536,
                                    0.0005596721619237365,
                                ],
                                [
                                    0.01193074489214428,
                                    0.24240149345281517,
                                    0.03497933213852379,
                                    0.7106884295165168,
                                ],
                                [
                                    0.2429611656147389,
                                    0.01137107273022053,
                                    0.7123293126816163,
                                    0.033338448973424285,
                                ],
                                [
                                    0.7519115261736411,
                                    0.028148348986680196,
                                    0.2120036169031706,
                                    0.007936507936507938,
                                ],
                                [
                                    0.7066941925608806,
                                    0.026455605568772807,
                                    0.25722095051593125,
                                    0.009629251354415327,
                                ],
                                [
                                    0.7410863060661613,
                                    0.03647548344192857,
                                    0.2120036169031706,
                                    0.010434593588739449,
                                ],
                                [
                                    0.7758507217700982,
                                    0.001711067737991725,
                                    0.22194872290287856,
                                    0.0004894875890314822,
                                ],
                                [
                                    0.7066941925608805,
                                    0.03478274002402118,
                                    0.24639573040845136,
                                    0.01212733700664684,
                                ],
                                [
                                    0.7398452715710372,
                                    0.001631661013864533,
                                    0.2579541731019395,
                                    0.000568894313158674,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.48668379242875603,
                                    0.1050381621055081,
                                    0.3358035070526666,
                                    0.07247453841306929,
                                ],
                                [
                                    0.6232327133796622,
                                    0.1869657212408504,
                                    0.14600194167317926,
                                    0.043799623706308036,
                                ],
                                [
                                    0.80142785823501,
                                    0.008770576385502696,
                                    0.1877469216575101,
                                    0.002054643721977183,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317926,
                                    0.2825508626240855,
                                    0.08476340327397917,
                                ],
                                [
                                    0.6258367717714194,
                                    0.0068489623305159385,
                                    0.3633380081211008,
                                    0.003976257776963941,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.23668683889285475,
                                    0.147930488633566,
                                    0.3786958335807245,
                                    0.23668683889285475,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.8378667932367241,
                                    0.02012421207540616,
                                    0.13867816824794188,
                                    0.0033308264399278475,
                                ],
                                [
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.26331316110714525,
                                    0.26331316110714525,
                                ],
                                [
                                    0.4622706799411003,
                                    0.011102997844609127,
                                    0.5142742815435656,
                                    0.012352040670724882,
                                ],
                                [
                                    0.38653615988255313,
                                    0.5602111956888659,
                                    0.021741885583182883,
                                    0.03151075884539816,
                                ],
                                [
                                    0.07247453841306935,
                                    0.10503816210550813,
                                    0.33580350705266665,
                                    0.48668379242875587,
                                ],
                                [
                                    0.20902345936397562,
                                    0.6967601166397722,
                                    0.02174188558318288,
                                    0.07247453841306932,
                                ],
                                [
                                    0.8730985052602788,
                                    0.03268507074346894,
                                    0.090816637816533,
                                    0.0033997861797191897,
                                ],
                                [
                                    0.07247453841306935,
                                    0.24158708305641444,
                                    0.15829080653408914,
                                    0.5276475719964271,
                                ],
                                [
                                    0.302728752793693,
                                    0.011332868675790794,
                                    0.6611863902831189,
                                    0.02475198824739734,
                                ],
                                [
                                    0.2639614896993748,
                                    0.7252132901931454,
                                    0.0028887121709719457,
                                    0.007936507936507948,
                                ],
                                [
                                    0.009629251354415346,
                                    0.026455605568772845,
                                    0.25722095051593136,
                                    0.7066941925608805,
                                ],
                                [
                                    0.04402136485969613,
                                    0.8943988562564745,
                                    0.0028887121709719452,
                                    0.058691066712857475,
                                ],
                                [
                                    0.896463901873038,
                                    0.041956319243132596,
                                    0.0588265764233172,
                                    0.00275320246051222,
                                ],
                                [
                                    0.009629251354415346,
                                    0.19564117163210198,
                                    0.03728082567625273,
                                    0.75744875133723,
                                ],
                                [
                                    0.19609288055488527,
                                    0.009177542431632046,
                                    0.7591975977414699,
                                    0.035531979272012765,
                                ],
                                [
                                    0.5045662383447862,
                                    0.018888800170547764,
                                    0.45934890473202555,
                                    0.01719605675264037,
                                ],
                                [
                                    0.45934890473202555,
                                    0.01719605675264037,
                                    0.5045662383447862,
                                    0.018888800170547764,
                                ],
                                [
                                    0.4937410182373064,
                                    0.024301410224287705,
                                    0.45934890473202555,
                                    0.022608666806380313,
                                ],
                                [
                                    0.5169024474360189,
                                    0.0011399810255751995,
                                    0.4808969972369579,
                                    0.0010605743014480075,
                                ],
                                [
                                    0.45934890473202555,
                                    0.022608666806380313,
                                    0.4937410182373064,
                                    0.024301410224287705,
                                ],
                                [
                                    0.4808969972369579,
                                    0.0010605743014480075,
                                    0.5169024474360189,
                                    0.0011399810255751995,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.3163428670509677,
                                    0.06827446047545314,
                                    0.5061444324304549,
                                    0.10923824004312425,
                                ],
                                [
                                    0.4528917880018739,
                                    0.1358645622574148,
                                    0.31634286705096765,
                                    0.09490078268974365,
                                ],
                                [
                                    0.5823829331780555,
                                    0.006373417081233319,
                                    0.4067918467144648,
                                    0.00445180302624656,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974364,
                                    0.4528917880018739,
                                    0.1358645622574148,
                                ],
                                [
                                    0.4067918467144647,
                                    0.00445180302624656,
                                    0.5823829331780555,
                                    0.006373417081233319,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1538456681183948,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.2884629956448156,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.6760705373901448,
                                    0.01623812637306552,
                                    0.30047442409452113,
                                    0.007216912142268488,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.3004744240945212,
                                    0.0072169121422684885,
                                    0.6760705373901448,
                                    0.01623812637306552,
                                ],
                                [
                                    0.3611698334676099,
                                    0.5234474940588109,
                                    0.047108211998126114,
                                    0.06827446047545314,
                                ],
                                [
                                    0.047108211998126114,
                                    0.06827446047545314,
                                    0.3611698334676099,
                                    0.5234474940588109,
                                ],
                                [
                                    0.18365713294903238,
                                    0.6122038443180996,
                                    0.047108211998126114,
                                    0.15703081073474187,
                                ],
                                [
                                    0.7671424477716988,
                                    0.028718529495433145,
                                    0.196772695305113,
                                    0.007366327427754992,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.196772695305113,
                                    0.007366327427754992,
                                    0.7671424477716988,
                                    0.028718529495433145,
                                ],
                                [
                                    0.26059122010765307,
                                    0.715953741377013,
                                    0.006258981762693645,
                                    0.017196056752640392,
                                ],
                                [
                                    0.006258981762693645,
                                    0.017196056752640392,
                                    0.26059122010765307,
                                    0.715953741377013,
                                ],
                                [
                                    0.04065109526797443,
                                    0.8259238037968523,
                                    0.006258981762693645,
                                    0.1271661191724797,
                                ],
                                [
                                    0.8278307498072539,
                                    0.03874414925757268,
                                    0.1274597284891012,
                                    0.005965372446072132,
                                ],
                                [
                                    0.006258981762693645,
                                    0.1271661191724797,
                                    0.04065109526797443,
                                    0.8259238037968523,
                                ],
                                [
                                    0.1274597284891012,
                                    0.005965372446072132,
                                    0.8278307498072539,
                                    0.03874414925757268,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.24639573040845147,
                                    0.012127337006646845,
                                    0.7066941925608804,
                                    0.03478274002402117,
                                ],
                                [
                                    0.25795417310193963,
                                    0.0005688943131586744,
                                    0.7398452715710371,
                                    0.0016316610138645327,
                                ],
                                [
                                    0.2120036169031708,
                                    0.010434593588739457,
                                    0.7410863060661611,
                                    0.03647548344192856,
                                ],
                                [
                                    0.22194872290287876,
                                    0.0004894875890314825,
                                    0.775850721770098,
                                    0.0017110677379917245,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.2825508626240855,
                                    0.08476340327397917,
                                    0.486683792428756,
                                    0.14600194167317926,
                                ],
                                [
                                    0.3633380081211008,
                                    0.003976257776963941,
                                    0.6258367717714194,
                                    0.0068489623305159385,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630804,
                                    0.6232327133796622,
                                    0.1869657212408504,
                                ],
                                [
                                    0.18774692165751014,
                                    0.002054643721977183,
                                    0.80142785823501,
                                    0.008770576385502696,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.5142742815435656,
                                    0.012352040670724882,
                                    0.4622706799411003,
                                    0.011102997844609127,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.1386781682479419,
                                    0.003330826439927848,
                                    0.8378667932367241,
                                    0.02012421207540616,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.021741885583182873,
                                    0.03151075884539815,
                                    0.38653615988255313,
                                    0.5602111956888659,
                                ],
                                [
                                    0.15829080653408914,
                                    0.5276475719964271,
                                    0.07247453841306933,
                                    0.2415870830564144,
                                ],
                                [
                                    0.6611863902831189,
                                    0.02475198824739734,
                                    0.30272875279369293,
                                    0.011332868675790793,
                                ],
                                [
                                    0.021741885583182876,
                                    0.0724745384130693,
                                    0.20902345936397562,
                                    0.6967601166397722,
                                ],
                                [
                                    0.09081663781653299,
                                    0.0033997861797191893,
                                    0.8730985052602788,
                                    0.03268507074346894,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.03728082567625273,
                                    0.7574487513372301,
                                    0.009629251354415343,
                                    0.19564117163210193,
                                ],
                                [
                                    0.75919759774147,
                                    0.03553197927201277,
                                    0.19609288055488522,
                                    0.009177542431632045,
                                ],
                                [
                                    0.0028887121709719483,
                                    0.05869106671285754,
                                    0.04402136485969613,
                                    0.8943988562564744,
                                ],
                                [
                                    0.05882657642331726,
                                    0.0027532024605122227,
                                    0.8964639018730379,
                                    0.04195631924313259,
                                ],
                                [
                                    0.08831351862262532,
                                    0.00330608011168759,
                                    0.8756016244541865,
                                    0.03277877681150054,
                                ],
                                [
                                    0.04309618500986464,
                                    0.0016133366937801986,
                                    0.9208189580669471,
                                    0.034471520229407936,
                                ],
                                [
                                    0.07748829851514548,
                                    0.003813892020803411,
                                    0.8756016244541864,
                                    0.043096185009864604,
                                ],
                                [
                                    0.08112328056746636,
                                    0.0001789099684825381,
                                    0.9166761641055104,
                                    0.002021645358540669,
                                ],
                                [
                                    0.043096185009864785,
                                    0.002121148602896024,
                                    0.9099937379594671,
                                    0.044788928427772,
                                ],
                                [
                                    0.045117830368405464,
                                    9.950324435534633e-05,
                                    0.9526816143045713,
                                    0.002101052082667861,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.02967933652292657,
                                    0.0064055204002616195,
                                    0.7928079629584961,
                                    0.17110718011831577,
                                ],
                                [
                                    0.1662282574738328,
                                    0.049867385620164274,
                                    0.6030063975790086,
                                    0.18089795932699418,
                                ],
                                [
                                    0.21375636019323715,
                                    0.0023392829007599326,
                                    0.7754184196992829,
                                    0.008485937206719946,
                                ],
                                [
                                    0.02967933652292658,
                                    0.008903606052493138,
                                    0.739555318529915,
                                    0.22186173889466532,
                                ],
                                [
                                    0.038165273729646544,
                                    0.0004176688457731751,
                                    0.9510095061628736,
                                    0.010407551261706704,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.014433824284536993,
                                    0.009021214230797044,
                                    0.6009488481890423,
                                    0.3755961132956237,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.40378667005566293,
                                    0.009698306039831791,
                                    0.572758291429003,
                                    0.013756732475502218,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.02819055676003922,
                                    0.0006770918090347568,
                                    0.9483544047246267,
                                    0.022777946706299252,
                                ],
                                [
                                    0.318481321176702,
                                    0.46157855398361936,
                                    0.08979672428903396,
                                    0.13014340055064466,
                                ],
                                [
                                    0.004419699707218271,
                                    0.006405520400261612,
                                    0.4038583457585177,
                                    0.5853164341340024,
                                ],
                                [
                                    0.14096862065812457,
                                    0.4699056884388678,
                                    0.08979672428903394,
                                    0.29932896661397373,
                                ],
                                [
                                    0.5888309970551759,
                                    0.022043312041816372,
                                    0.3750841460216359,
                                    0.014041544881371763,
                                ],
                                [
                                    0.004419699707218292,
                                    0.014732654855510055,
                                    0.22634564523994022,
                                    0.7545020001973315,
                                ],
                                [
                                    0.018461244588590123,
                                    0.0006911099741382219,
                                    0.9454538984882217,
                                    0.03539374694904991,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144277,
                                    0.032778776811500585,
                                ],
                                [
                                    0.000587218633243017,
                                    0.0016133366937802177,
                                    0.2662629832371037,
                                    0.7315364614358731,
                                ],
                                [
                                    0.0349793321385238,
                                    0.7106884295165169,
                                    0.011930744892144277,
                                    0.24240149345281511,
                                ],
                                [
                                    0.7123293126816164,
                                    0.033338448973424285,
                                    0.24296116561473885,
                                    0.011371072730220526,
                                ],
                                [
                                    0.0005872186332430146,
                                    0.011930744892144352,
                                    0.04632285839742506,
                                    0.9411591780771876,
                                ],
                                [
                                    0.011958291363463625,
                                    0.0005596721619237406,
                                    0.9433321869328916,
                                    0.04414984954172107,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.8756016244541865,
                                    0.03277877681150055,
                                    0.08831351862262524,
                                    0.0033060801116875874,
                                ],
                                [
                                    0.9099937379594674,
                                    0.044788928427772004,
                                    0.043096185009864604,
                                    0.002121148602896015,
                                ],
                                [
                                    0.944446933868791,
                                    0.010335732518448397,
                                    0.044727846023729145,
                                    0.0004894875890314822,
                                ],
                                [
                                    0.8756016244541865,
                                    0.04309618500986461,
                                    0.07748829851514534,
                                    0.0038138920208034043,
                                ],
                                [
                                    0.9087527034643432,
                                    0.009945105999707967,
                                    0.08042207642817684,
                                    0.0008801141077719128,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.6030063975790088,
                                    0.13014340055064463,
                                    0.21948090190241384,
                                    0.04736929996793276,
                                ],
                                [
                                    0.739555318529915,
                                    0.22186173889466534,
                                    0.02967933652292653,
                                    0.008903606052493122,
                                ],
                                [
                                    0.9102190567179765,
                                    0.051198000706603845,
                                    0.03652829885344247,
                                    0.002054643721977183,
                                ],
                                [
                                    0.6030063975790086,
                                    0.18089795932699418,
                                    0.16622825747383277,
                                    0.04986738562016427,
                                ],
                                [
                                    0.7421593769216721,
                                    0.04174497998433085,
                                    0.20458797864974687,
                                    0.011507664444250176,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.29325751195225264,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.20132987799400742,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.8590805053972747,
                                    0.11205184603365137,
                                    0.0255368221291461,
                                    0.0033308264399278475,
                                ],
                                [
                                    0.29325751195225264,
                                    0.29325751195225264,
                                    0.20674248804774736,
                                    0.20674248804774736,
                                ],
                                [
                                    0.5188413530004983,
                                    0.06767367090400703,
                                    0.36577597452592253,
                                    0.0477090015695722,
                                ],
                                [
                                    0.4038583457585177,
                                    0.5853164341340024,
                                    0.004419699707218271,
                                    0.006405520400261612,
                                ],
                                [
                                    0.08979672428903396,
                                    0.13014340055064466,
                                    0.318481321176702,
                                    0.46157855398361936,
                                ],
                                [
                                    0.22634564523994025,
                                    0.7545020001973315,
                                    0.00441969970721827,
                                    0.014732654855509982,
                                ],
                                [
                                    0.8067347310984135,
                                    0.1741129143388582,
                                    0.015752568383009063,
                                    0.0033997861797191897,
                                ],
                                [
                                    0.08979672428903396,
                                    0.2993289666139738,
                                    0.14096862065812454,
                                    0.4699056884388677,
                                ],
                                [
                                    0.3200509386696576,
                                    0.06907475223335013,
                                    0.502436360811765,
                                    0.10843794828522726,
                                ],
                                [
                                    0.2662629832371037,
                                    0.7315364614358731,
                                    0.0005872186332430102,
                                    0.0016133366937801992,
                                ],
                                [
                                    0.011930744892144272,
                                    0.032778776811500564,
                                    0.2549194569782024,
                                    0.7003710213181528,
                                ],
                                [
                                    0.04632285839742507,
                                    0.9411591780771876,
                                    0.0005872186332430102,
                                    0.011930744892144263,
                                ],
                                [
                                    0.7702951140954464,
                                    0.21718692237916634,
                                    0.009764761064875054,
                                    0.0027532024605122197,
                                ],
                                [
                                    0.01193074489214428,
                                    0.24240149345281517,
                                    0.03497933213852379,
                                    0.7106884295165168,
                                ],
                                [
                                    0.19839437409261415,
                                    0.05593786425234526,
                                    0.5816655010677072,
                                    0.1640022605873333,
                                ],
                                [
                                    0.7519115261736411,
                                    0.028148348986680196,
                                    0.2120036169031706,
                                    0.007936507936507938,
                                ],
                                [
                                    0.7066941925608806,
                                    0.026455605568772807,
                                    0.25722095051593125,
                                    0.009629251354415327,
                                ],
                                [
                                    0.7410863060661613,
                                    0.03647548344192857,
                                    0.2120036169031706,
                                    0.010434593588739449,
                                ],
                                [
                                    0.769144511989499,
                                    0.008417277518591013,
                                    0.2200302679030212,
                                    0.0024079425888888666,
                                ],
                                [
                                    0.7066941925608805,
                                    0.03478274002402118,
                                    0.24639573040845136,
                                    0.01212733700664684,
                                ],
                                [
                                    0.7334502815850512,
                                    0.008026650999850582,
                                    0.2557244983074689,
                                    0.0027985691076292977,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.48668379242875603,
                                    0.1050381621055081,
                                    0.3358035070526666,
                                    0.07247453841306929,
                                ],
                                [
                                    0.6232327133796622,
                                    0.1869657212408504,
                                    0.14600194167317926,
                                    0.043799623706308036,
                                ],
                                [
                                    0.7670532254650736,
                                    0.04314520915543911,
                                    0.17969413010634538,
                                    0.010107435273141912,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317926,
                                    0.2825508626240855,
                                    0.08476340327397917,
                                ],
                                [
                                    0.5989935456687692,
                                    0.03369218843316612,
                                    0.3477538099026498,
                                    0.019560455995414904,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.23668683889285475,
                                    0.147930488633566,
                                    0.3786958335807245,
                                    0.23668683889285475,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.7589937101609238,
                                    0.09899729515120649,
                                    0.12562361736549701,
                                    0.016385377322372725,
                                ],
                                [
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.26331316110714525,
                                    0.26331316110714525,
                                ],
                                [
                                    0.41875455776414733,
                                    0.05461912002156214,
                                    0.4658627697622734,
                                    0.06076355245201708,
                                ],
                                [
                                    0.38653615988255313,
                                    0.5602111956888659,
                                    0.021741885583182883,
                                    0.03151075884539816,
                                ],
                                [
                                    0.07247453841306935,
                                    0.10503816210550813,
                                    0.33580350705266665,
                                    0.48668379242875587,
                                ],
                                [
                                    0.20902345936397562,
                                    0.6967601166397722,
                                    0.02174188558318288,
                                    0.07247453841306932,
                                ],
                                [
                                    0.7449954873419484,
                                    0.1607880886617994,
                                    0.07749181213947418,
                                    0.016724611856778027,
                                ],
                                [
                                    0.07247453841306935,
                                    0.24158708305641444,
                                    0.15829080653408914,
                                    0.5276475719964271,
                                ],
                                [
                                    0.2583116949131925,
                                    0.055749926556291296,
                                    0.5641756045682301,
                                    0.1217627739622861,
                                ],
                                [
                                    0.2639614896993748,
                                    0.7252132901931454,
                                    0.0028887121709719457,
                                    0.007936507936507948,
                                ],
                                [
                                    0.009629251354415346,
                                    0.026455605568772845,
                                    0.25722095051593136,
                                    0.7066941925608805,
                                ],
                                [
                                    0.04402136485969613,
                                    0.8943988562564745,
                                    0.0028887121709719452,
                                    0.058691066712857475,
                                ],
                                [
                                    0.7320239605318013,
                                    0.20639626058436933,
                                    0.04803591462852017,
                                    0.013543864255309245,
                                ],
                                [
                                    0.009629251354415346,
                                    0.19564117163210198,
                                    0.03728082567625273,
                                    0.75744875133723,
                                ],
                                [
                                    0.16012322052896907,
                                    0.04514720245754825,
                                    0.6199366546313523,
                                    0.17479292238213032,
                                ],
                                [
                                    0.5045662383447862,
                                    0.018888800170547764,
                                    0.45934890473202555,
                                    0.01719605675264037,
                                ],
                                [
                                    0.45934890473202555,
                                    0.01719605675264037,
                                    0.5045662383447862,
                                    0.018888800170547764,
                                ],
                                [
                                    0.4937410182373064,
                                    0.024301410224287705,
                                    0.45934890473202555,
                                    0.022608666806380313,
                                ],
                                [
                                    0.512434505148484,
                                    0.005607923313110155,
                                    0.4767402747440362,
                                    0.005217296794369724,
                                ],
                                [
                                    0.45934890473202555,
                                    0.022608666806380313,
                                    0.4937410182373064,
                                    0.024301410224287705,
                                ],
                                [
                                    0.4767402747440362,
                                    0.005217296794369724,
                                    0.512434505148484,
                                    0.005607923313110155,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.3163428670509677,
                                    0.06827446047545314,
                                    0.5061444324304549,
                                    0.10923824004312425,
                                ],
                                [
                                    0.4528917880018739,
                                    0.1358645622574148,
                                    0.31634286705096765,
                                    0.09490078268974365,
                                ],
                                [
                                    0.5574035176838618,
                                    0.03135283257542701,
                                    0.3893438378875573,
                                    0.021899811853154018,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974364,
                                    0.4528917880018739,
                                    0.1358645622574148,
                                ],
                                [
                                    0.3893438378875572,
                                    0.021899811853154014,
                                    0.5574035176838618,
                                    0.03135283257542701,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1538456681183948,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.2884629956448156,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.6124282399615986,
                                    0.07988042380161178,
                                    0.2721890875648222,
                                    0.03550224867196743,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.27218908756482224,
                                    0.03550224867196744,
                                    0.6124282399615986,
                                    0.07988042380161178,
                                ],
                                [
                                    0.3611698334676099,
                                    0.5234474940588109,
                                    0.047108211998126114,
                                    0.06827446047545314,
                                ],
                                [
                                    0.047108211998126114,
                                    0.06827446047545314,
                                    0.3611698334676099,
                                    0.5234474940588109,
                                ],
                                [
                                    0.18365713294903238,
                                    0.6122038443180996,
                                    0.047108211998126114,
                                    0.15703081073474187,
                                ],
                                [
                                    0.6545855459550893,
                                    0.14127543131204273,
                                    0.16790175352633332,
                                    0.03623726920653466,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.16790175352633332,
                                    0.03623726920653466,
                                    0.6545855459550893,
                                    0.14127543131204273,
                                ],
                                [
                                    0.26059122010765307,
                                    0.715953741377013,
                                    0.006258981762693645,
                                    0.017196056752640392,
                                ],
                                [
                                    0.006258981762693645,
                                    0.017196056752640392,
                                    0.26059122010765307,
                                    0.715953741377013,
                                ],
                                [
                                    0.04065109526797443,
                                    0.8259238037968523,
                                    0.006258981762693645,
                                    0.1271661191724797,
                                ],
                                [
                                    0.6759803075815768,
                                    0.19059459148324984,
                                    0.1040795675787446,
                                    0.029345533356428737,
                                ],
                                [
                                    0.006258981762693645,
                                    0.1271661191724797,
                                    0.04065109526797443,
                                    0.8259238037968523,
                                ],
                                [
                                    0.1040795675787446,
                                    0.029345533356428737,
                                    0.6759803075815768,
                                    0.19059459148324984,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.24639573040845147,
                                    0.012127337006646845,
                                    0.7066941925608804,
                                    0.03478274002402117,
                                ],
                                [
                                    0.255724498307469,
                                    0.002798569107629299,
                                    0.7334502815850511,
                                    0.00802665099985058,
                                ],
                                [
                                    0.2120036169031708,
                                    0.010434593588739457,
                                    0.7410863060661611,
                                    0.03647548344192856,
                                ],
                                [
                                    0.22003026790302138,
                                    0.002407942588888869,
                                    0.7691445119894987,
                                    0.008417277518591011,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.2825508626240855,
                                    0.08476340327397917,
                                    0.486683792428756,
                                    0.14600194167317926,
                                ],
                                [
                                    0.3477538099026498,
                                    0.019560455995414904,
                                    0.5989935456687692,
                                    0.03369218843316612,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630804,
                                    0.6232327133796622,
                                    0.1869657212408504,
                                ],
                                [
                                    0.1796941301063454,
                                    0.010107435273141913,
                                    0.7670532254650736,
                                    0.04314520915543911,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.4658627697622734,
                                    0.06076355245201708,
                                    0.41875455776414733,
                                    0.05461912002156214,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.12562361736549701,
                                    0.01638537732237273,
                                    0.7589937101609238,
                                    0.09899729515120649,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.021741885583182873,
                                    0.03151075884539815,
                                    0.38653615988255313,
                                    0.5602111956888659,
                                ],
                                [
                                    0.15829080653408914,
                                    0.5276475719964271,
                                    0.07247453841306933,
                                    0.2415870830564144,
                                ],
                                [
                                    0.5641756045682301,
                                    0.1217627739622861,
                                    0.25831169491319245,
                                    0.05574992655629128,
                                ],
                                [
                                    0.021741885583182876,
                                    0.0724745384130693,
                                    0.20902345936397562,
                                    0.6967601166397722,
                                ],
                                [
                                    0.07749181213947416,
                                    0.016724611856778024,
                                    0.7449954873419484,
                                    0.1607880886617994,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.03728082567625273,
                                    0.7574487513372301,
                                    0.009629251354415343,
                                    0.19564117163210193,
                                ],
                                [
                                    0.6199366546313524,
                                    0.17479292238213034,
                                    0.16012322052896902,
                                    0.04514720245754823,
                                ],
                                [
                                    0.0028887121709719483,
                                    0.05869106671285754,
                                    0.04402136485969613,
                                    0.8943988562564744,
                                ],
                                [
                                    0.04803591462852022,
                                    0.013543864255309259,
                                    0.7320239605318012,
                                    0.2063962605843693,
                                ],
                                [
                                    0.08831351862262532,
                                    0.00330608011168759,
                                    0.8756016244541865,
                                    0.03277877681150054,
                                ],
                                [
                                    0.04309618500986464,
                                    0.0016133366937801986,
                                    0.9208189580669471,
                                    0.034471520229407936,
                                ],
                                [
                                    0.07748829851514548,
                                    0.003813892020803411,
                                    0.8756016244541864,
                                    0.043096185009864604,
                                ],
                                [
                                    0.08042207642817698,
                                    0.0008801141077719143,
                                    0.9087527034643431,
                                    0.009945105999707965,
                                ],
                                [
                                    0.043096185009864785,
                                    0.002121148602896024,
                                    0.9099937379594671,
                                    0.044788928427772,
                                ],
                                [
                                    0.044727846023729326,
                                    0.0004894875890314841,
                                    0.9444469338687908,
                                    0.010335732518448396,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.02967933652292657,
                                    0.0064055204002616195,
                                    0.7928079629584961,
                                    0.17110718011831577,
                                ],
                                [
                                    0.1662282574738328,
                                    0.049867385620164274,
                                    0.6030063975790086,
                                    0.18089795932699418,
                                ],
                                [
                                    0.20458797864974693,
                                    0.011507664444250179,
                                    0.7421593769216721,
                                    0.04174497998433085,
                                ],
                                [
                                    0.02967933652292658,
                                    0.008903606052493138,
                                    0.739555318529915,
                                    0.22186173889466532,
                                ],
                                [
                                    0.03652829885344253,
                                    0.002054643721977187,
                                    0.9102190567179764,
                                    0.05119800070660384,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.014433824284536993,
                                    0.009021214230797044,
                                    0.6009488481890423,
                                    0.3755961132956237,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.36577597452592253,
                                    0.0477090015695722,
                                    0.5188413530004983,
                                    0.06767367090400703,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.025536822129146125,
                                    0.003330826439927851,
                                    0.8590805053972747,
                                    0.11205184603365137,
                                ],
                                [
                                    0.318481321176702,
                                    0.46157855398361936,
                                    0.08979672428903396,
                                    0.13014340055064466,
                                ],
                                [
                                    0.004419699707218271,
                                    0.006405520400261612,
                                    0.4038583457585177,
                                    0.5853164341340024,
                                ],
                                [
                                    0.14096862065812457,
                                    0.4699056884388678,
                                    0.08979672428903394,
                                    0.29932896661397373,
                                ],
                                [
                                    0.5024363608117651,
                                    0.10843794828522729,
                                    0.32005093866965756,
                                    0.06907475223335012,
                                ],
                                [
                                    0.004419699707218292,
                                    0.014732654855510055,
                                    0.22634564523994022,
                                    0.7545020001973315,
                                ],
                                [
                                    0.01575256838300914,
                                    0.0033997861797192062,
                                    0.8067347310984135,
                                    0.1741129143388582,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144277,
                                    0.032778776811500585,
                                ],
                                [
                                    0.000587218633243017,
                                    0.0016133366937802177,
                                    0.2662629832371037,
                                    0.7315364614358731,
                                ],
                                [
                                    0.0349793321385238,
                                    0.7106884295165169,
                                    0.011930744892144277,
                                    0.24240149345281511,
                                ],
                                [
                                    0.5816655010677073,
                                    0.16400226058733333,
                                    0.19839437409261412,
                                    0.05593786425234525,
                                ],
                                [
                                    0.0005872186332430146,
                                    0.011930744892144352,
                                    0.04632285839742506,
                                    0.9411591780771876,
                                ],
                                [
                                    0.009764761064875125,
                                    0.00275320246051224,
                                    0.7702951140954463,
                                    0.21718692237916631,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.8756016244541865,
                                    0.03277877681150055,
                                    0.08831351862262524,
                                    0.0033060801116875874,
                                ],
                                [
                                    0.9099937379594674,
                                    0.044788928427772004,
                                    0.043096185009864604,
                                    0.002121148602896015,
                                ],
                                [
                                    0.9323882021733534,
                                    0.022394464213886002,
                                    0.04415675931131262,
                                    0.0010605743014480075,
                                ],
                                [
                                    0.8756016244541865,
                                    0.04309618500986461,
                                    0.07748829851514534,
                                    0.0038138920208034043,
                                ],
                                [
                                    0.8971497169591189,
                                    0.021548092504932306,
                                    0.07939524452554705,
                                    0.0019069460104017021,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.6030063975790088,
                                    0.13014340055064463,
                                    0.21948090190241384,
                                    0.04736929996793276,
                                ],
                                [
                                    0.739555318529915,
                                    0.22186173889466534,
                                    0.02967933652292653,
                                    0.008903606052493122,
                                ],
                                [
                                    0.8504861879772477,
                                    0.11093086944733267,
                                    0.03413113954917309,
                                    0.004451803026246561,
                                ],
                                [
                                    0.6030063975790086,
                                    0.18089795932699418,
                                    0.16622825747383277,
                                    0.04986738562016427,
                                ],
                                [
                                    0.6934553772425058,
                                    0.09044897966349709,
                                    0.1911619502839149,
                                    0.024933692810082134,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.29325751195225264,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.20132987799400742,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.7283492635731945,
                                    0.2427830878577315,
                                    0.021650736426805463,
                                    0.007216912142268488,
                                ],
                                [
                                    0.29325751195225264,
                                    0.29325751195225264,
                                    0.20674248804774736,
                                    0.20674248804774736,
                                ],
                                [
                                    0.4398862679283789,
                                    0.14662875597612632,
                                    0.3101137320716211,
                                    0.10337124402387368,
                                ],
                                [
                                    0.4038583457585177,
                                    0.5853164341340024,
                                    0.004419699707218271,
                                    0.006405520400261612,
                                ],
                                [
                                    0.08979672428903396,
                                    0.13014340055064466,
                                    0.318481321176702,
                                    0.46157855398361936,
                                ],
                                [
                                    0.22634564523994025,
                                    0.7545020001973315,
                                    0.00441969970721827,
                                    0.014732654855509982,
                                ],
                                [
                                    0.603596645338606,
                                    0.37725100009866575,
                                    0.011786027134973261,
                                    0.007366327427754991,
                                ],
                                [
                                    0.08979672428903396,
                                    0.2993289666139738,
                                    0.14096862065812454,
                                    0.4699056884388677,
                                ],
                                [
                                    0.23946120759602085,
                                    0.1496644833069869,
                                    0.3759214648775584,
                                    0.23495284421943385,
                                ],
                                [
                                    0.2662629832371037,
                                    0.7315364614358731,
                                    0.0005872186332430102,
                                    0.0016133366937801992,
                                ],
                                [
                                    0.011930744892144272,
                                    0.032778776811500564,
                                    0.2549194569782024,
                                    0.7003710213181528,
                                ],
                                [
                                    0.04632285839742507,
                                    0.9411591780771876,
                                    0.0005872186332430102,
                                    0.011930744892144263,
                                ],
                                [
                                    0.5169024474360189,
                                    0.4705795890385938,
                                    0.006552591079315142,
                                    0.0059653724460721315,
                                ],
                                [
                                    0.01193074489214428,
                                    0.24240149345281517,
                                    0.03497933213852379,
                                    0.7106884295165168,
                                ],
                                [
                                    0.13313149161855187,
                                    0.12120074672640758,
                                    0.39032354689678217,
                                    0.3553442147582584,
                                ],
                                [
                                    0.7519115261736411,
                                    0.028148348986680196,
                                    0.2120036169031706,
                                    0.007936507936507938,
                                ],
                                [
                                    0.7066941925608806,
                                    0.026455605568772807,
                                    0.25722095051593125,
                                    0.009629251354415327,
                                ],
                                [
                                    0.7410863060661613,
                                    0.03647548344192857,
                                    0.2120036169031706,
                                    0.010434593588739449,
                                ],
                                [
                                    0.7593240477871257,
                                    0.018237741720964287,
                                    0.21722091369754035,
                                    0.005217296794369724,
                                ],
                                [
                                    0.7066941925608805,
                                    0.03478274002402118,
                                    0.24639573040845136,
                                    0.01212733700664684,
                                ],
                                [
                                    0.7240855625728911,
                                    0.01739137001201059,
                                    0.2524593989117748,
                                    0.00606366850332342,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.48668379242875603,
                                    0.1050381621055081,
                                    0.3358035070526666,
                                    0.07247453841306929,
                                ],
                                [
                                    0.6232327133796622,
                                    0.1869657212408504,
                                    0.14600194167317926,
                                    0.043799623706308036,
                                ],
                                [
                                    0.7167155740000875,
                                    0.0934828606204252,
                                    0.1679017535263333,
                                    0.021899811853154018,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317926,
                                    0.2825508626240855,
                                    0.08476340327397917,
                                ],
                                [
                                    0.5596847632653457,
                                    0.07300097083658963,
                                    0.3249325642610751,
                                    0.04238170163698959,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.23668683889285475,
                                    0.147930488633566,
                                    0.3786958335807245,
                                    0.23668683889285475,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.6434932539840976,
                                    0.21449775132803256,
                                    0.10650674601590229,
                                    0.03550224867196743,
                                ],
                                [
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.26331316110714525,
                                    0.26331316110714525,
                                ],
                                [
                                    0.35503025833928215,
                                    0.11834341944642737,
                                    0.39496974166071785,
                                    0.13165658055357263,
                                ],
                                [
                                    0.38653615988255313,
                                    0.5602111956888659,
                                    0.021741885583182883,
                                    0.03151075884539816,
                                ],
                                [
                                    0.07247453841306935,
                                    0.10503816210550813,
                                    0.33580350705266665,
                                    0.48668379242875587,
                                ],
                                [
                                    0.20902345936397562,
                                    0.6967601166397722,
                                    0.02174188558318288,
                                    0.07247453841306932,
                                ],
                                [
                                    0.5574035176838618,
                                    0.3483800583198861,
                                    0.05797915478971754,
                                    0.03623726920653466,
                                ],
                                [
                                    0.07247453841306935,
                                    0.24158708305641444,
                                    0.15829080653408914,
                                    0.5276475719964271,
                                ],
                                [
                                    0.19326807994127657,
                                    0.12079354152820722,
                                    0.42211459253230266,
                                    0.26382378599821354,
                                ],
                                [
                                    0.2639614896993748,
                                    0.7252132901931454,
                                    0.0028887121709719457,
                                    0.007936507936507948,
                                ],
                                [
                                    0.009629251354415346,
                                    0.026455605568772845,
                                    0.25722095051593136,
                                    0.7066941925608805,
                                ],
                                [
                                    0.04402136485969613,
                                    0.8943988562564745,
                                    0.0028887121709719452,
                                    0.058691066712857475,
                                ],
                                [
                                    0.49122079298793336,
                                    0.44719942812823726,
                                    0.03223424552740068,
                                    0.029345533356428737,
                                ],
                                [
                                    0.009629251354415346,
                                    0.19564117163210198,
                                    0.03728082567625273,
                                    0.75744875133723,
                                ],
                                [
                                    0.10744983717046633,
                                    0.09782058581605099,
                                    0.4160052013448677,
                                    0.378724375668615,
                                ],
                                [
                                    0.5045662383447862,
                                    0.018888800170547764,
                                    0.45934890473202555,
                                    0.01719605675264037,
                                ],
                                [
                                    0.45934890473202555,
                                    0.01719605675264037,
                                    0.5045662383447862,
                                    0.018888800170547764,
                                ],
                                [
                                    0.4937410182373064,
                                    0.024301410224287705,
                                    0.45934890473202555,
                                    0.022608666806380313,
                                ],
                                [
                                    0.5058917233494502,
                                    0.012150705112143853,
                                    0.47065323813521576,
                                    0.011304333403190156,
                                ],
                                [
                                    0.45934890473202555,
                                    0.022608666806380313,
                                    0.4937410182373064,
                                    0.024301410224287705,
                                ],
                                [
                                    0.47065323813521576,
                                    0.011304333403190156,
                                    0.5058917233494502,
                                    0.012150705112143853,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.3163428670509677,
                                    0.06827446047545314,
                                    0.5061444324304549,
                                    0.10923824004312425,
                                ],
                                [
                                    0.4528917880018739,
                                    0.1358645622574148,
                                    0.31634286705096765,
                                    0.09490078268974365,
                                ],
                                [
                                    0.5208240691305813,
                                    0.0679322811287074,
                                    0.3637932583958395,
                                    0.04745039134487183,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974364,
                                    0.4528917880018739,
                                    0.1358645622574148,
                                ],
                                [
                                    0.3637932583958394,
                                    0.04745039134487182,
                                    0.5208240691305813,
                                    0.0679322811287074,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1538456681183948,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.2884629956448156,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.5192314978224077,
                                    0.17307716594080258,
                                    0.2307685021775922,
                                    0.0769228340591974,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.23076850217759226,
                                    0.07692283405919742,
                                    0.5192314978224077,
                                    0.17307716594080258,
                                ],
                                [
                                    0.3611698334676099,
                                    0.5234474940588109,
                                    0.047108211998126114,
                                    0.06827446047545314,
                                ],
                                [
                                    0.047108211998126114,
                                    0.06827446047545314,
                                    0.3611698334676099,
                                    0.5234474940588109,
                                ],
                                [
                                    0.18365713294903238,
                                    0.6122038443180996,
                                    0.047108211998126114,
                                    0.15703081073474187,
                                ],
                                [
                                    0.4897590551080822,
                                    0.3061019221590498,
                                    0.12562361736549704,
                                    0.07851540536737094,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.12562361736549704,
                                    0.07851540536737094,
                                    0.4897590551080822,
                                    0.3061019221590498,
                                ],
                                [
                                    0.26059122010765307,
                                    0.715953741377013,
                                    0.006258981762693645,
                                    0.017196056752640392,
                                ],
                                [
                                    0.006258981762693645,
                                    0.017196056752640392,
                                    0.26059122010765307,
                                    0.715953741377013,
                                ],
                                [
                                    0.04065109526797443,
                                    0.8259238037968523,
                                    0.006258981762693645,
                                    0.1271661191724797,
                                ],
                                [
                                    0.4536129971664005,
                                    0.41296190189842613,
                                    0.0698420413489335,
                                    0.06358305958623985,
                                ],
                                [
                                    0.006258981762693645,
                                    0.1271661191724797,
                                    0.04065109526797443,
                                    0.8259238037968523,
                                ],
                                [
                                    0.0698420413489335,
                                    0.06358305958623985,
                                    0.4536129971664005,
                                    0.41296190189842613,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.24639573040845147,
                                    0.012127337006646845,
                                    0.7066941925608804,
                                    0.03478274002402117,
                                ],
                                [
                                    0.25245939891177493,
                                    0.006063668503323422,
                                    0.724085562572891,
                                    0.017391370012010587,
                                ],
                                [
                                    0.2120036169031708,
                                    0.010434593588739457,
                                    0.7410863060661611,
                                    0.03647548344192856,
                                ],
                                [
                                    0.2172209136975405,
                                    0.005217296794369729,
                                    0.7593240477871255,
                                    0.01823774172096428,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.2825508626240855,
                                    0.08476340327397917,
                                    0.486683792428756,
                                    0.14600194167317926,
                                ],
                                [
                                    0.3249325642610751,
                                    0.04238170163698959,
                                    0.5596847632653457,
                                    0.07300097083658963,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630804,
                                    0.6232327133796622,
                                    0.1869657212408504,
                                ],
                                [
                                    0.1679017535263333,
                                    0.02189981185315402,
                                    0.7167155740000875,
                                    0.0934828606204252,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.39496974166071785,
                                    0.13165658055357263,
                                    0.35503025833928215,
                                    0.11834341944642737,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.10650674601590232,
                                    0.03550224867196744,
                                    0.6434932539840976,
                                    0.21449775132803256,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.021741885583182873,
                                    0.03151075884539815,
                                    0.38653615988255313,
                                    0.5602111956888659,
                                ],
                                [
                                    0.15829080653408914,
                                    0.5276475719964271,
                                    0.07247453841306933,
                                    0.2415870830564144,
                                ],
                                [
                                    0.42211459253230266,
                                    0.26382378599821354,
                                    0.19326807994127654,
                                    0.1207935415282072,
                                ],
                                [
                                    0.021741885583182876,
                                    0.0724745384130693,
                                    0.20902345936397562,
                                    0.6967601166397722,
                                ],
                                [
                                    0.05797915478971753,
                                    0.03623726920653465,
                                    0.5574035176838618,
                                    0.3483800583198861,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.03728082567625273,
                                    0.7574487513372301,
                                    0.009629251354415343,
                                    0.19564117163210193,
                                ],
                                [
                                    0.41600520134486774,
                                    0.37872437566861505,
                                    0.1074498371704663,
                                    0.09782058581605096,
                                ],
                                [
                                    0.0028887121709719483,
                                    0.05869106671285754,
                                    0.04402136485969613,
                                    0.8943988562564744,
                                ],
                                [
                                    0.032234245527400715,
                                    0.02934553335642877,
                                    0.4912207929879333,
                                    0.4471994281282372,
                                ],
                                [
                                    0.08831351862262532,
                                    0.00330608011168759,
                                    0.8756016244541865,
                                    0.03277877681150054,
                                ],
                                [
                                    0.04309618500986464,
                                    0.0016133366937801986,
                                    0.9208189580669471,
                                    0.034471520229407936,
                                ],
                                [
                                    0.07748829851514548,
                                    0.003813892020803411,
                                    0.8756016244541864,
                                    0.043096185009864604,
                                ],
                                [
                                    0.07939524452554718,
                                    0.0019069460104017054,
                                    0.8971497169591188,
                                    0.021548092504932302,
                                ],
                                [
                                    0.043096185009864785,
                                    0.002121148602896024,
                                    0.9099937379594671,
                                    0.044788928427772,
                                ],
                                [
                                    0.0441567593113128,
                                    0.001060574301448012,
                                    0.9323882021733532,
                                    0.022394464213886,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.02967933652292657,
                                    0.0064055204002616195,
                                    0.7928079629584961,
                                    0.17110718011831577,
                                ],
                                [
                                    0.1662282574738328,
                                    0.049867385620164274,
                                    0.6030063975790086,
                                    0.18089795932699418,
                                ],
                                [
                                    0.19116195028391494,
                                    0.024933692810082137,
                                    0.6934553772425058,
                                    0.09044897966349709,
                                ],
                                [
                                    0.02967933652292658,
                                    0.008903606052493138,
                                    0.739555318529915,
                                    0.22186173889466532,
                                ],
                                [
                                    0.03413113954917315,
                                    0.004451803026246569,
                                    0.8504861879772476,
                                    0.11093086944733266,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.014433824284536993,
                                    0.009021214230797044,
                                    0.6009488481890423,
                                    0.3755961132956237,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.3101137320716211,
                                    0.10337124402387368,
                                    0.4398862679283789,
                                    0.14662875597612632,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.021650736426805484,
                                    0.0072169121422684945,
                                    0.7283492635731945,
                                    0.2427830878577315,
                                ],
                                [
                                    0.318481321176702,
                                    0.46157855398361936,
                                    0.08979672428903396,
                                    0.13014340055064466,
                                ],
                                [
                                    0.004419699707218271,
                                    0.006405520400261612,
                                    0.4038583457585177,
                                    0.5853164341340024,
                                ],
                                [
                                    0.14096862065812457,
                                    0.4699056884388678,
                                    0.08979672428903394,
                                    0.29932896661397373,
                                ],
                                [
                                    0.37592146487755845,
                                    0.2349528442194339,
                                    0.23946120759602083,
                                    0.14966448330698687,
                                ],
                                [
                                    0.004419699707218292,
                                    0.014732654855510055,
                                    0.22634564523994022,
                                    0.7545020001973315,
                                ],
                                [
                                    0.01178602713497332,
                                    0.007366327427755027,
                                    0.6035966453386059,
                                    0.37725100009866575,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144277,
                                    0.032778776811500585,
                                ],
                                [
                                    0.000587218633243017,
                                    0.0016133366937802177,
                                    0.2662629832371037,
                                    0.7315364614358731,
                                ],
                                [
                                    0.0349793321385238,
                                    0.7106884295165169,
                                    0.011930744892144277,
                                    0.24240149345281511,
                                ],
                                [
                                    0.3903235468967822,
                                    0.35534421475825845,
                                    0.13313149161855184,
                                    0.12120074672640756,
                                ],
                                [
                                    0.0005872186332430146,
                                    0.011930744892144352,
                                    0.04632285839742506,
                                    0.9411591780771876,
                                ],
                                [
                                    0.00655259107931519,
                                    0.005965372446072176,
                                    0.5169024474360189,
                                    0.4705795890385938,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.8756016244541865,
                                    0.03277877681150055,
                                    0.08831351862262524,
                                    0.0033060801116875874,
                                ],
                                [
                                    0.9099937379594674,
                                    0.044788928427772004,
                                    0.043096185009864604,
                                    0.002121148602896015,
                                ],
                                [
                                    0.9203294704779158,
                                    0.0344531959093236,
                                    0.04358567259889609,
                                    0.0016316610138645327,
                                ],
                                [
                                    0.8756016244541865,
                                    0.04309618500986461,
                                    0.07748829851514534,
                                    0.0038138920208034043,
                                ],
                                [
                                    0.8855467304538945,
                                    0.033151079010156646,
                                    0.07836841262291726,
                                    0.0029337779130314914,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.6030063975790088,
                                    0.13014340055064463,
                                    0.21948090190241384,
                                    0.04736929996793276,
                                ],
                                [
                                    0.739555318529915,
                                    0.22186173889466534,
                                    0.02967933652292653,
                                    0.008903606052493122,
                                ],
                                [
                                    0.7907533192365189,
                                    0.17066373818806146,
                                    0.03173398024490372,
                                    0.006848962330515938,
                                ],
                                [
                                    0.6030063975790086,
                                    0.18089795932699418,
                                    0.16622825747383277,
                                    0.04986738562016427,
                                ],
                                [
                                    0.6447513775633397,
                                    0.1391529793426633,
                                    0.17773592191808296,
                                    0.03835972117591408,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.29325751195225264,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.20132987799400742,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.5976180217491144,
                                    0.3735143296818116,
                                    0.017764650724464825,
                                    0.011102997844609127,
                                ],
                                [
                                    0.29325751195225264,
                                    0.29325751195225264,
                                    0.20674248804774736,
                                    0.20674248804774736,
                                ],
                                [
                                    0.3609311828562597,
                                    0.2255838410482456,
                                    0.25445148961731956,
                                    0.15903348647817514,
                                ],
                                [
                                    0.4038583457585177,
                                    0.5853164341340024,
                                    0.004419699707218271,
                                    0.006405520400261612,
                                ],
                                [
                                    0.08979672428903396,
                                    0.13014340055064466,
                                    0.318481321176702,
                                    0.46157855398361936,
                                ],
                                [
                                    0.22634564523994025,
                                    0.7545020001973315,
                                    0.00441969970721827,
                                    0.014732654855509982,
                                ],
                                [
                                    0.40045855957879856,
                                    0.5803890858584733,
                                    0.007819485886937462,
                                    0.01133286867579079,
                                ],
                                [
                                    0.08979672428903396,
                                    0.2993289666139738,
                                    0.14096862065812454,
                                    0.4699056884388677,
                                ],
                                [
                                    0.15887147652238412,
                                    0.23025421438062363,
                                    0.24940656894335186,
                                    0.3614677401536404,
                                ],
                                [
                                    0.2662629832371037,
                                    0.7315364614358731,
                                    0.0005872186332430102,
                                    0.0016133366937801992,
                                ],
                                [
                                    0.011930744892144272,
                                    0.032778776811500564,
                                    0.2549194569782024,
                                    0.7003710213181528,
                                ],
                                [
                                    0.04632285839742507,
                                    0.9411591780771876,
                                    0.0005872186332430102,
                                    0.011930744892144263,
                                ],
                                [
                                    0.2635097807765915,
                                    0.7239722556980213,
                                    0.0033404210937552307,
                                    0.009177542431632043,
                                ],
                                [
                                    0.01193074489214428,
                                    0.24240149345281517,
                                    0.03497933213852379,
                                    0.7106884295165168,
                                ],
                                [
                                    0.06786860914448956,
                                    0.18646362920046988,
                                    0.19898159272585714,
                                    0.5466861689291834,
                                ],
                                [
                                    0.7519115261736411,
                                    0.028148348986680196,
                                    0.2120036169031706,
                                    0.007936507936507938,
                                ],
                                [
                                    0.7066941925608806,
                                    0.026455605568772807,
                                    0.25722095051593125,
                                    0.009629251354415327,
                                ],
                                [
                                    0.7410863060661613,
                                    0.03647548344192857,
                                    0.2120036169031706,
                                    0.010434593588739449,
                                ],
                                [
                                    0.7495035835847523,
                                    0.028058205923337555,
                                    0.21441155949205948,
                                    0.00802665099985058,
                                ],
                                [
                                    0.7066941925608805,
                                    0.03478274002402118,
                                    0.24639573040845136,
                                    0.01212733700664684,
                                ],
                                [
                                    0.7147208435607312,
                                    0.026756089024170596,
                                    0.2491942995160807,
                                    0.009328767899017541,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.48668379242875603,
                                    0.1050381621055081,
                                    0.3358035070526666,
                                    0.07247453841306929,
                                ],
                                [
                                    0.6232327133796622,
                                    0.1869657212408504,
                                    0.14600194167317926,
                                    0.043799623706308036,
                                ],
                                [
                                    0.6663779225351014,
                                    0.14382051208541127,
                                    0.15610937694632118,
                                    0.03369218843316612,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317926,
                                    0.2825508626240855,
                                    0.08476340327397917,
                                ],
                                [
                                    0.5203759808619222,
                                    0.11230975324001313,
                                    0.30211131861950047,
                                    0.06520294727856427,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.23668683889285475,
                                    0.147930488633566,
                                    0.3786958335807245,
                                    0.23668683889285475,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.5279927978072716,
                                    0.3299982075048586,
                                    0.0873898746663076,
                                    0.054619120021562134,
                                ],
                                [
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.26331316110714525,
                                    0.26331316110714525,
                                ],
                                [
                                    0.2913059589144169,
                                    0.18206771887129258,
                                    0.32407671355916234,
                                    0.20254960865512817,
                                ],
                                [
                                    0.38653615988255313,
                                    0.5602111956888659,
                                    0.021741885583182883,
                                    0.03151075884539816,
                                ],
                                [
                                    0.07247453841306935,
                                    0.10503816210550813,
                                    0.33580350705266665,
                                    0.48668379242875587,
                                ],
                                [
                                    0.20902345936397562,
                                    0.6967601166397722,
                                    0.02174188558318288,
                                    0.07247453841306932,
                                ],
                                [
                                    0.3698115480257751,
                                    0.5359720279779727,
                                    0.03846649743996092,
                                    0.05574992655629128,
                                ],
                                [
                                    0.07247453841306935,
                                    0.24158708305641444,
                                    0.15829080653408914,
                                    0.5276475719964271,
                                ],
                                [
                                    0.12822446496936066,
                                    0.18583715650012314,
                                    0.2800535804963753,
                                    0.4058847980341409,
                                ],
                                [
                                    0.2639614896993748,
                                    0.7252132901931454,
                                    0.0028887121709719457,
                                    0.007936507936507948,
                                ],
                                [
                                    0.009629251354415346,
                                    0.026455605568772845,
                                    0.25722095051593136,
                                    0.7066941925608805,
                                ],
                                [
                                    0.04402136485969613,
                                    0.8943988562564745,
                                    0.0028887121709719452,
                                    0.058691066712857475,
                                ],
                                [
                                    0.25041762544406554,
                                    0.6880025956721051,
                                    0.016432576426281195,
                                    0.045147202457548226,
                                ],
                                [
                                    0.009629251354415346,
                                    0.19564117163210198,
                                    0.03728082567625273,
                                    0.75744875133723,
                                ],
                                [
                                    0.0547764538119636,
                                    0.1504939691745537,
                                    0.21207374805838308,
                                    0.5826558289550996,
                                ],
                                [
                                    0.5045662383447862,
                                    0.018888800170547764,
                                    0.45934890473202555,
                                    0.01719605675264037,
                                ],
                                [
                                    0.45934890473202555,
                                    0.01719605675264037,
                                    0.5045662383447862,
                                    0.018888800170547764,
                                ],
                                [
                                    0.4937410182373064,
                                    0.024301410224287705,
                                    0.45934890473202555,
                                    0.022608666806380313,
                                ],
                                [
                                    0.49934894155041654,
                                    0.01869348691117755,
                                    0.4645662015263953,
                                    0.017391370012010587,
                                ],
                                [
                                    0.45934890473202555,
                                    0.022608666806380313,
                                    0.4937410182373064,
                                    0.024301410224287705,
                                ],
                                [
                                    0.4645662015263953,
                                    0.017391370012010587,
                                    0.49934894155041654,
                                    0.01869348691117755,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.3163428670509677,
                                    0.06827446047545314,
                                    0.5061444324304549,
                                    0.10923824004312425,
                                ],
                                [
                                    0.4528917880018739,
                                    0.1358645622574148,
                                    0.31634286705096765,
                                    0.09490078268974365,
                                ],
                                [
                                    0.484244620577301,
                                    0.10451172968198778,
                                    0.3382426789041217,
                                    0.07300097083658963,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974364,
                                    0.4528917880018739,
                                    0.1358645622574148,
                                ],
                                [
                                    0.33824267890412163,
                                    0.07300097083658962,
                                    0.484244620577301,
                                    0.10451172968198778,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1538456681183948,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.2884629956448156,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.42603475568321697,
                                    0.26627390807999335,
                                    0.18934791679036225,
                                    0.11834341944642737,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.18934791679036228,
                                    0.11834341944642739,
                                    0.42603475568321697,
                                    0.26627390807999335,
                                ],
                                [
                                    0.3611698334676099,
                                    0.5234474940588109,
                                    0.047108211998126114,
                                    0.06827446047545314,
                                ],
                                [
                                    0.047108211998126114,
                                    0.06827446047545314,
                                    0.3611698334676099,
                                    0.5234474940588109,
                                ],
                                [
                                    0.18365713294903238,
                                    0.6122038443180996,
                                    0.047108211998126114,
                                    0.15703081073474187,
                                ],
                                [
                                    0.3249325642610752,
                                    0.4709284130060568,
                                    0.08334548120466079,
                                    0.1207935415282072,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.08334548120466079,
                                    0.1207935415282072,
                                    0.3249325642610752,
                                    0.4709284130060568,
                                ],
                                [
                                    0.26059122010765307,
                                    0.715953741377013,
                                    0.006258981762693645,
                                    0.017196056752640392,
                                ],
                                [
                                    0.006258981762693645,
                                    0.017196056752640392,
                                    0.26059122010765307,
                                    0.715953741377013,
                                ],
                                [
                                    0.04065109526797443,
                                    0.8259238037968523,
                                    0.006258981762693645,
                                    0.1271661191724797,
                                ],
                                [
                                    0.2312456867512243,
                                    0.6353292123136024,
                                    0.03560451511912239,
                                    0.09782058581605095,
                                ],
                                [
                                    0.006258981762693645,
                                    0.1271661191724797,
                                    0.04065109526797443,
                                    0.8259238037968523,
                                ],
                                [
                                    0.03560451511912239,
                                    0.09782058581605095,
                                    0.2312456867512243,
                                    0.6353292123136024,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.24639573040845147,
                                    0.012127337006646845,
                                    0.7066941925608804,
                                    0.03478274002402117,
                                ],
                                [
                                    0.24919429951608077,
                                    0.009328767899017544,
                                    0.7147208435607311,
                                    0.02675608902417059,
                                ],
                                [
                                    0.2120036169031708,
                                    0.010434593588739457,
                                    0.7410863060661611,
                                    0.03647548344192856,
                                ],
                                [
                                    0.21441155949205967,
                                    0.008026650999850587,
                                    0.7495035835847521,
                                    0.028058205923337548,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.2825508626240855,
                                    0.08476340327397917,
                                    0.486683792428756,
                                    0.14600194167317926,
                                ],
                                [
                                    0.30211131861950047,
                                    0.06520294727856427,
                                    0.5203759808619222,
                                    0.11230975324001313,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630804,
                                    0.6232327133796622,
                                    0.1869657212408504,
                                ],
                                [
                                    0.1561093769463212,
                                    0.033692188433166126,
                                    0.6663779225351014,
                                    0.14382051208541127,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.32407671355916234,
                                    0.20254960865512817,
                                    0.2913059589144169,
                                    0.18206771887129258,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.08738987466630761,
                                    0.05461912002156215,
                                    0.5279927978072716,
                                    0.3299982075048586,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.021741885583182873,
                                    0.03151075884539815,
                                    0.38653615988255313,
                                    0.5602111956888659,
                                ],
                                [
                                    0.15829080653408914,
                                    0.5276475719964271,
                                    0.07247453841306933,
                                    0.2415870830564144,
                                ],
                                [
                                    0.2800535804963753,
                                    0.4058847980341409,
                                    0.12822446496936066,
                                    0.18583715650012309,
                                ],
                                [
                                    0.021741885583182876,
                                    0.0724745384130693,
                                    0.20902345936397562,
                                    0.6967601166397722,
                                ],
                                [
                                    0.03846649743996091,
                                    0.055749926556291275,
                                    0.3698115480257751,
                                    0.5359720279779727,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.03728082567625273,
                                    0.7574487513372301,
                                    0.009629251354415343,
                                    0.19564117163210193,
                                ],
                                [
                                    0.2120737480583831,
                                    0.5826558289550997,
                                    0.05477645381196359,
                                    0.15049396917455368,
                                ],
                                [
                                    0.0028887121709719483,
                                    0.05869106671285754,
                                    0.04402136485969613,
                                    0.8943988562564744,
                                ],
                                [
                                    0.01643257642628121,
                                    0.045147202457548274,
                                    0.2504176254440655,
                                    0.6880025956721051,
                                ],
                                [
                                    0.08831351862262532,
                                    0.00330608011168759,
                                    0.8756016244541865,
                                    0.03277877681150054,
                                ],
                                [
                                    0.04309618500986464,
                                    0.0016133366937801986,
                                    0.9208189580669471,
                                    0.034471520229407936,
                                ],
                                [
                                    0.07748829851514548,
                                    0.003813892020803411,
                                    0.8756016244541864,
                                    0.043096185009864604,
                                ],
                                [
                                    0.0783684126229174,
                                    0.002933777913031496,
                                    0.8855467304538944,
                                    0.03315107901015664,
                                ],
                                [
                                    0.043096185009864785,
                                    0.002121148602896024,
                                    0.9099937379594671,
                                    0.044788928427772,
                                ],
                                [
                                    0.04358567259889627,
                                    0.0016316610138645397,
                                    0.9203294704779156,
                                    0.034453195909323595,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.02967933652292657,
                                    0.0064055204002616195,
                                    0.7928079629584961,
                                    0.17110718011831577,
                                ],
                                [
                                    0.1662282574738328,
                                    0.049867385620164274,
                                    0.6030063975790086,
                                    0.18089795932699418,
                                ],
                                [
                                    0.17773592191808302,
                                    0.038359721175914095,
                                    0.6447513775633397,
                                    0.1391529793426633,
                                ],
                                [
                                    0.02967933652292658,
                                    0.008903606052493138,
                                    0.739555318529915,
                                    0.22186173889466532,
                                ],
                                [
                                    0.03173398024490377,
                                    0.006848962330515951,
                                    0.7907533192365188,
                                    0.17066373818806144,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.014433824284536993,
                                    0.009021214230797044,
                                    0.6009488481890423,
                                    0.3755961132956237,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.25445148961731956,
                                    0.15903348647817514,
                                    0.3609311828562597,
                                    0.2255838410482456,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.017764650724464842,
                                    0.011102997844609138,
                                    0.5976180217491144,
                                    0.3735143296818116,
                                ],
                                [
                                    0.318481321176702,
                                    0.46157855398361936,
                                    0.08979672428903396,
                                    0.13014340055064466,
                                ],
                                [
                                    0.004419699707218271,
                                    0.006405520400261612,
                                    0.4038583457585177,
                                    0.5853164341340024,
                                ],
                                [
                                    0.14096862065812457,
                                    0.4699056884388678,
                                    0.08979672428903394,
                                    0.29932896661397373,
                                ],
                                [
                                    0.2494065689433519,
                                    0.36146774015364047,
                                    0.1588714765223841,
                                    0.2302542143806236,
                                ],
                                [
                                    0.004419699707218292,
                                    0.014732654855510055,
                                    0.22634564523994022,
                                    0.7545020001973315,
                                ],
                                [
                                    0.0078194858869375,
                                    0.011332868675790846,
                                    0.4004585595787985,
                                    0.5803890858584732,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144277,
                                    0.032778776811500585,
                                ],
                                [
                                    0.000587218633243017,
                                    0.0016133366937802177,
                                    0.2662629832371037,
                                    0.7315364614358731,
                                ],
                                [
                                    0.0349793321385238,
                                    0.7106884295165169,
                                    0.011930744892144277,
                                    0.24240149345281511,
                                ],
                                [
                                    0.19898159272585716,
                                    0.5466861689291835,
                                    0.06786860914448954,
                                    0.18646362920046985,
                                ],
                                [
                                    0.0005872186332430146,
                                    0.011930744892144352,
                                    0.04632285839742506,
                                    0.9411591780771876,
                                ],
                                [
                                    0.0033404210937552554,
                                    0.00917754243163211,
                                    0.26350978077659143,
                                    0.7239722556980211,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.8756016244541865,
                                    0.03277877681150055,
                                    0.08831351862262524,
                                    0.0033060801116875874,
                                ],
                                [
                                    0.9099937379594674,
                                    0.044788928427772004,
                                    0.043096185009864604,
                                    0.002121148602896015,
                                ],
                                [
                                    0.9120947900421352,
                                    0.042687876345104146,
                                    0.043195688254219954,
                                    0.0020216453585406692,
                                ],
                                [
                                    0.8756016244541865,
                                    0.04309618500986461,
                                    0.07748829851514534,
                                    0.0038138920208034043,
                                ],
                                [
                                    0.8776232698127272,
                                    0.041074539651323946,
                                    0.07766720848362789,
                                    0.0036349820523208665,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.6030063975790088,
                                    0.13014340055064463,
                                    0.21948090190241384,
                                    0.04736929996793276,
                                ],
                                [
                                    0.739555318529915,
                                    0.22186173889466534,
                                    0.02967933652292653,
                                    0.008903606052493122,
                                ],
                                [
                                    0.7499628697916217,
                                    0.21145418763295862,
                                    0.030097005368699702,
                                    0.008485937206719947,
                                ],
                                [
                                    0.6030063975790086,
                                    0.18089795932699418,
                                    0.16622825747383277,
                                    0.04986738562016427,
                                ],
                                [
                                    0.6114923347857286,
                                    0.17241202212027423,
                                    0.1685675403745927,
                                    0.04752810271940433,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.29325751195225264,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.20132987799400742,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.5083441224217623,
                                    0.4627882290091637,
                                    0.015110916093571732,
                                    0.013756732475502218,
                                ],
                                [
                                    0.29325751195225264,
                                    0.29325751195225264,
                                    0.20674248804774736,
                                    0.20674248804774736,
                                ],
                                [
                                    0.3070142444277549,
                                    0.2795007794767504,
                                    0.21644079408757916,
                                    0.19704418200791557,
                                ],
                                [
                                    0.4038583457585177,
                                    0.5853164341340024,
                                    0.004419699707218271,
                                    0.006405520400261612,
                                ],
                                [
                                    0.08979672428903396,
                                    0.13014340055064466,
                                    0.318481321176702,
                                    0.46157855398361936,
                                ],
                                [
                                    0.22634564523994025,
                                    0.7545020001973315,
                                    0.00441969970721827,
                                    0.014732654855509982,
                                ],
                                [
                                    0.2617393921889902,
                                    0.7191082532482815,
                                    0.0051108096813564895,
                                    0.014041544881371763,
                                ],
                                [
                                    0.08979672428903396,
                                    0.2993289666139738,
                                    0.14096862065812454,
                                    0.4699056884388677,
                                ],
                                [
                                    0.10383826917040574,
                                    0.285287421732602,
                                    0.16301193269994094,
                                    0.4478623763970513,
                                ],
                                [
                                    0.2662629832371037,
                                    0.7315364614358731,
                                    0.0005872186332430102,
                                    0.0016133366937801992,
                                ],
                                [
                                    0.011930744892144272,
                                    0.032778776811500564,
                                    0.2549194569782024,
                                    0.7003710213181528,
                                ],
                                [
                                    0.04632285839742507,
                                    0.9411591780771876,
                                    0.0005872186332430102,
                                    0.011930744892144263,
                                ],
                                [
                                    0.09047270793914616,
                                    0.8970093285354666,
                                    0.0011468907951667471,
                                    0.011371072730220526,
                                ],
                                [
                                    0.01193074489214428,
                                    0.24240149345281517,
                                    0.03497933213852379,
                                    0.7106884295165168,
                                ],
                                [
                                    0.023301817622364815,
                                    0.2310304207225946,
                                    0.0683177811119481,
                                    0.6773499805430925,
                                ],
                                [
                                    0.7519115261736411,
                                    0.028148348986680196,
                                    0.2120036169031706,
                                    0.007936507936507938,
                                ],
                                [
                                    0.7066941925608806,
                                    0.026455605568772807,
                                    0.25722095051593125,
                                    0.009629251354415327,
                                ],
                                [
                                    0.7410863060661613,
                                    0.03647548344192857,
                                    0.2120036169031706,
                                    0.010434593588739449,
                                ],
                                [
                                    0.7427973738041531,
                                    0.034764415703936846,
                                    0.2124931044922021,
                                    0.009945105999707967,
                                ],
                                [
                                    0.7066941925608805,
                                    0.03478274002402118,
                                    0.24639573040845136,
                                    0.01212733700664684,
                                ],
                                [
                                    0.7083258535747451,
                                    0.033151079010156646,
                                    0.24696462472161004,
                                    0.011558442693488165,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.48668379242875603,
                                    0.1050381621055081,
                                    0.3358035070526666,
                                    0.07247453841306929,
                                ],
                                [
                                    0.6232327133796622,
                                    0.1869657212408504,
                                    0.14600194167317926,
                                    0.043799623706308036,
                                ],
                                [
                                    0.632003289765165,
                                    0.1781951448553477,
                                    0.14805658539515645,
                                    0.041744979984330854,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317926,
                                    0.2825508626240855,
                                    0.08476340327397917,
                                ],
                                [
                                    0.49353275475927194,
                                    0.13915297934266332,
                                    0.28652712040104944,
                                    0.08078714549701524,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.23668683889285475,
                                    0.147930488633566,
                                    0.3786958335807245,
                                    0.23668683889285475,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.44911971473147133,
                                    0.4088712905806589,
                                    0.07433532378386272,
                                    0.06767367090400701,
                                ],
                                [
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.26331316110714525,
                                    0.26331316110714525,
                                ],
                                [
                                    0.24778983673746388,
                                    0.2255838410482456,
                                    0.27566520177787013,
                                    0.2509611204364204,
                                ],
                                [
                                    0.38653615988255313,
                                    0.5602111956888659,
                                    0.021741885583182883,
                                    0.03151075884539816,
                                ],
                                [
                                    0.07247453841306935,
                                    0.10503816210550813,
                                    0.33580350705266665,
                                    0.48668379242875587,
                                ],
                                [
                                    0.20902345936397562,
                                    0.6967601166397722,
                                    0.02174188558318288,
                                    0.07247453841306932,
                                ],
                                [
                                    0.2417085301074446,
                                    0.6640750458963032,
                                    0.025141671762902076,
                                    0.06907475223335012,
                                ],
                                [
                                    0.07247453841306935,
                                    0.24158708305641444,
                                    0.15829080653408914,
                                    0.5276475719964271,
                                ],
                                [
                                    0.08380740708886016,
                                    0.23025421438062363,
                                    0.18304279478148652,
                                    0.5028955837490297,
                                ],
                                [
                                    0.2639614896993748,
                                    0.7252132901931454,
                                    0.0028887121709719457,
                                    0.007936507936507948,
                                ],
                                [
                                    0.009629251354415346,
                                    0.026455605568772845,
                                    0.25722095051593136,
                                    0.7066941925608805,
                                ],
                                [
                                    0.04402136485969613,
                                    0.8943988562564745,
                                    0.0028887121709719452,
                                    0.058691066712857475,
                                ],
                                [
                                    0.08597768410282874,
                                    0.8524425370133418,
                                    0.005641914631484167,
                                    0.05593786425234525,
                                ],
                                [
                                    0.009629251354415346,
                                    0.19564117163210198,
                                    0.03728082567625273,
                                    0.75744875133723,
                                ],
                                [
                                    0.0188067937860474,
                                    0.1864636292004699,
                                    0.07281280494826552,
                                    0.7219167720652172,
                                ],
                                [
                                    0.5045662383447862,
                                    0.018888800170547764,
                                    0.45934890473202555,
                                    0.01719605675264037,
                                ],
                                [
                                    0.45934890473202555,
                                    0.01719605675264037,
                                    0.5045662383447862,
                                    0.018888800170547764,
                                ],
                                [
                                    0.4937410182373064,
                                    0.024301410224287705,
                                    0.45934890473202555,
                                    0.022608666806380313,
                                ],
                                [
                                    0.4948809992628816,
                                    0.023161429198712506,
                                    0.46040947903347357,
                                    0.021548092504932306,
                                ],
                                [
                                    0.45934890473202555,
                                    0.022608666806380313,
                                    0.4937410182373064,
                                    0.024301410224287705,
                                ],
                                [
                                    0.46040947903347357,
                                    0.021548092504932306,
                                    0.4948809992628816,
                                    0.023161429198712506,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.3163428670509677,
                                    0.06827446047545314,
                                    0.5061444324304549,
                                    0.10923824004312425,
                                ],
                                [
                                    0.4528917880018739,
                                    0.1358645622574148,
                                    0.31634286705096765,
                                    0.09490078268974365,
                                ],
                                [
                                    0.4592652050831072,
                                    0.1294911451761815,
                                    0.3207946700772142,
                                    0.09044897966349709,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974364,
                                    0.4528917880018739,
                                    0.1358645622574148,
                                ],
                                [
                                    0.3207946700772142,
                                    0.09044897966349708,
                                    0.4592652050831072,
                                    0.1294911451761815,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1538456681183948,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.2884629956448156,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.3623924582546707,
                                    0.3299162055085396,
                                    0.1610625802606633,
                                    0.14662875597612632,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.16106258026066333,
                                    0.14662875597612635,
                                    0.3623924582546707,
                                    0.3299162055085396,
                                ],
                                [
                                    0.3611698334676099,
                                    0.5234474940588109,
                                    0.047108211998126114,
                                    0.06827446047545314,
                                ],
                                [
                                    0.047108211998126114,
                                    0.06827446047545314,
                                    0.3611698334676099,
                                    0.5234474940588109,
                                ],
                                [
                                    0.18365713294903238,
                                    0.6122038443180996,
                                    0.047108211998126114,
                                    0.15703081073474187,
                                ],
                                [
                                    0.21237566244446557,
                                    0.5834853148226664,
                                    0.05447453942588112,
                                    0.14966448330698687,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.05447453942588112,
                                    0.14966448330698687,
                                    0.21237566244446557,
                                    0.5834853148226664,
                                ],
                                [
                                    0.26059122010765307,
                                    0.715953741377013,
                                    0.006258981762693645,
                                    0.017196056752640392,
                                ],
                                [
                                    0.006258981762693645,
                                    0.017196056752640392,
                                    0.26059122010765307,
                                    0.715953741377013,
                                ],
                                [
                                    0.04065109526797443,
                                    0.8259238037968523,
                                    0.006258981762693645,
                                    0.1271661191724797,
                                ],
                                [
                                    0.07939524452554714,
                                    0.7871796545392795,
                                    0.01222435420876578,
                                    0.12120074672640757,
                                ],
                                [
                                    0.006258981762693645,
                                    0.1271661191724797,
                                    0.04065109526797443,
                                    0.8259238037968523,
                                ],
                                [
                                    0.01222435420876578,
                                    0.12120074672640757,
                                    0.07939524452554714,
                                    0.7871796545392795,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.24639573040845147,
                                    0.012127337006646845,
                                    0.7066941925608804,
                                    0.03478274002402117,
                                ],
                                [
                                    0.24696462472161015,
                                    0.01155844269348817,
                                    0.708325853574745,
                                    0.03315107901015664,
                                ],
                                [
                                    0.2120036169031708,
                                    0.010434593588739457,
                                    0.7410863060661611,
                                    0.03647548344192856,
                                ],
                                [
                                    0.21249310449220227,
                                    0.009945105999707975,
                                    0.7427973738041529,
                                    0.03476441570393684,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.2825508626240855,
                                    0.08476340327397917,
                                    0.486683792428756,
                                    0.14600194167317926,
                                ],
                                [
                                    0.28652712040104944,
                                    0.08078714549701524,
                                    0.49353275475927194,
                                    0.13915297934266332,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630804,
                                    0.6232327133796622,
                                    0.1869657212408504,
                                ],
                                [
                                    0.14805658539515648,
                                    0.041744979984330854,
                                    0.632003289765165,
                                    0.1781951448553477,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.27566520177787013,
                                    0.2509611204364204,
                                    0.24778983673746388,
                                    0.2255838410482456,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.07433532378386273,
                                    0.06767367090400703,
                                    0.44911971473147133,
                                    0.4088712905806589,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.021741885583182873,
                                    0.03151075884539815,
                                    0.38653615988255313,
                                    0.5602111956888659,
                                ],
                                [
                                    0.15829080653408914,
                                    0.5276475719964271,
                                    0.07247453841306933,
                                    0.2415870830564144,
                                ],
                                [
                                    0.18304279478148652,
                                    0.5028955837490297,
                                    0.08380740708886014,
                                    0.2302542143806236,
                                ],
                                [
                                    0.021741885583182876,
                                    0.0724745384130693,
                                    0.20902345936397562,
                                    0.6967601166397722,
                                ],
                                [
                                    0.025141671762902072,
                                    0.06907475223335012,
                                    0.2417085301074446,
                                    0.6640750458963032,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.03728082567625273,
                                    0.7574487513372301,
                                    0.009629251354415343,
                                    0.19564117163210193,
                                ],
                                [
                                    0.07281280494826553,
                                    0.7219167720652173,
                                    0.018806793786047393,
                                    0.18646362920046988,
                                ],
                                [
                                    0.0028887121709719483,
                                    0.05869106671285754,
                                    0.04402136485969613,
                                    0.8943988562564744,
                                ],
                                [
                                    0.005641914631484173,
                                    0.05593786425234531,
                                    0.08597768410282874,
                                    0.8524425370133418,
                                ],
                                [
                                    0.08831351862262532,
                                    0.00330608011168759,
                                    0.8756016244541865,
                                    0.03277877681150054,
                                ],
                                [
                                    0.04309618500986464,
                                    0.0016133366937801986,
                                    0.9208189580669471,
                                    0.034471520229407936,
                                ],
                                [
                                    0.07748829851514548,
                                    0.003813892020803411,
                                    0.8756016244541864,
                                    0.043096185009864604,
                                ],
                                [
                                    0.07766720848362801,
                                    0.0036349820523208726,
                                    0.8776232698127271,
                                    0.04107453965132394,
                                ],
                                [
                                    0.043096185009864785,
                                    0.002121148602896024,
                                    0.9099937379594671,
                                    0.044788928427772,
                                ],
                                [
                                    0.043195688254220134,
                                    0.0020216453585406775,
                                    0.912094790042135,
                                    0.04268787634510413,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.02967933652292657,
                                    0.0064055204002616195,
                                    0.7928079629584961,
                                    0.17110718011831577,
                                ],
                                [
                                    0.1662282574738328,
                                    0.049867385620164274,
                                    0.6030063975790086,
                                    0.18089795932699418,
                                ],
                                [
                                    0.16856754037459273,
                                    0.047528102719404344,
                                    0.6114923347857286,
                                    0.17241202212027423,
                                ],
                                [
                                    0.02967933652292658,
                                    0.008903606052493138,
                                    0.739555318529915,
                                    0.22186173889466532,
                                ],
                                [
                                    0.030097005368699758,
                                    0.008485937206719963,
                                    0.7499628697916216,
                                    0.2114541876329586,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.014433824284536993,
                                    0.009021214230797044,
                                    0.6009488481890423,
                                    0.3755961132956237,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.21644079408757916,
                                    0.19704418200791557,
                                    0.3070142444277549,
                                    0.2795007794767504,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.015110916093571746,
                                    0.013756732475502232,
                                    0.5083441224217623,
                                    0.4627882290091637,
                                ],
                                [
                                    0.318481321176702,
                                    0.46157855398361936,
                                    0.08979672428903396,
                                    0.13014340055064466,
                                ],
                                [
                                    0.004419699707218271,
                                    0.006405520400261612,
                                    0.4038583457585177,
                                    0.5853164341340024,
                                ],
                                [
                                    0.14096862065812457,
                                    0.4699056884388678,
                                    0.08979672428903394,
                                    0.29932896661397373,
                                ],
                                [
                                    0.16301193269994096,
                                    0.4478623763970514,
                                    0.10383826917040573,
                                    0.28528742173260196,
                                ],
                                [
                                    0.004419699707218292,
                                    0.014732654855510055,
                                    0.22634564523994022,
                                    0.7545020001973315,
                                ],
                                [
                                    0.005110809681356515,
                                    0.014041544881371831,
                                    0.26173939218899017,
                                    0.7191082532482814,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144277,
                                    0.032778776811500585,
                                ],
                                [
                                    0.000587218633243017,
                                    0.0016133366937802177,
                                    0.2662629832371037,
                                    0.7315364614358731,
                                ],
                                [
                                    0.0349793321385238,
                                    0.7106884295165169,
                                    0.011930744892144277,
                                    0.24240149345281511,
                                ],
                                [
                                    0.06831778111194811,
                                    0.6773499805430926,
                                    0.02330181762236481,
                                    0.23103042072259458,
                                ],
                                [
                                    0.0005872186332430146,
                                    0.011930744892144352,
                                    0.04632285839742506,
                                    0.9411591780771876,
                                ],
                                [
                                    0.0011468907951667554,
                                    0.01137107273022061,
                                    0.09047270793914616,
                                    0.8970093285354664,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.8677671480001333,
                                    0.040613253265553824,
                                    0.08752333029622184,
                                    0.004096268438090988,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979843,
                                    0.042710580372676124,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.9530853076849939,
                                    0.0021019423914603896,
                                    0.0447141369879829,
                                    9.861293556281735e-05,
                                ],
                                [
                                    0.8677671480001333,
                                    0.042710580372676124,
                                    0.08532277496919864,
                                    0.004199496657991894,
                                ],
                                [
                                    0.9084741717575027,
                                    0.0020035566153067744,
                                    0.0893252729154741,
                                    0.00019699871171643263,
                                ],
                                [
                                    0.7519115261736411,
                                    0.2120036169031706,
                                    0.028148348986680196,
                                    0.007936507936507938,
                                ],
                                [
                                    0.5719007400028323,
                                    0.1612490581268211,
                                    0.2081591351574891,
                                    0.058691066712857454,
                                ],
                                [
                                    0.7410863060661613,
                                    0.2223210251015347,
                                    0.0281483489866802,
                                    0.008444319845623756,
                                ],
                                [
                                    0.9529782347546459,
                                    0.01042909641305007,
                                    0.036196545137874146,
                                    0.0003961236944298091,
                                ],
                                [
                                    0.5719007400028322,
                                    0.17156646632518516,
                                    0.19733391505000922,
                                    0.05919887862197327,
                                ],
                                [
                                    0.7354190101768235,
                                    0.008048196151193947,
                                    0.2537557697156966,
                                    0.002777023956285932,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.2494498611682442,
                                    0.22709510031642177,
                                    0.27400517734708985,
                                    0.2494498611682442,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    0.9525655911925514,
                                    0.02287909262860298,
                                    0.023979370292114582,
                                    0.0005759458867310281,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.4871980101337966,
                                    0.011701712202691778,
                                    0.48934695135086936,
                                    0.011753326312642231,
                                ],
                                [
                                    0.2639614896993748,
                                    0.7252132901931454,
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                ],
                                [
                                    0.058691066712857495,
                                    0.16124905812682114,
                                    0.2081591351574892,
                                    0.5719007400028322,
                                ],
                                [
                                    0.22787663277618656,
                                    0.7596054036984262,
                                    0.0028887121709719426,
                                    0.00962925135441533,
                                ],
                                [
                                    0.9518488884742078,
                                    0.035633148000404846,
                                    0.012066254602603986,
                                    0.00045170892278328755,
                                ],
                                [
                                    0.058691066712857495,
                                    0.19564117163210193,
                                    0.172074278234301,
                                    0.5735934834207396,
                                ],
                                [
                                    0.2451546959133274,
                                    0.009177542431632045,
                                    0.7187604471634844,
                                    0.026907314491556093,
                                ],
                                [
                                    0.09141798473825839,
                                    0.9063814599347184,
                                    0.00020161399605452118,
                                    0.0019989413309686884,
                                ],
                                [
                                    0.004096268438090994,
                                    0.040613253265553845,
                                    0.08752333029622192,
                                    0.8677671480001332,
                                ],
                                [
                                    0.046708463034613554,
                                    0.948993654531241,
                                    0.00020161399605452123,
                                    0.0040962684380909916,
                                ],
                                [
                                    0.9511847521301787,
                                    0.044517365435675665,
                                    0.00410572616617637,
                                    0.0001921562679691426,
                                ],
                                [
                                    0.004096268438090996,
                                    0.08322544786207639,
                                    0.04281380859257708,
                                    0.8698644751072555,
                                ],
                                [
                                    0.08341760413004554,
                                    0.0039041121701218484,
                                    0.8718728741663097,
                                    0.04080540953352296,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7003710213181529,
                                    0.03277877681150055,
                                    0.25491945697820234,
                                    0.01193074489214426,
                                ],
                                [
                                    0.7429832159146753,
                                    0.03656884733653024,
                                    0.2101067070546566,
                                    0.010341229694137775,
                                ],
                                [
                                    0.7778366158057263,
                                    0.0017154474454793725,
                                    0.21996282886725052,
                                    0.00048510788154383443,
                                ],
                                [
                                    0.7003710213181528,
                                    0.03447152022940794,
                                    0.2527189016511791,
                                    0.012438556801260077,
                                ],
                                [
                                    0.733225479878235,
                                    0.0016170616693257573,
                                    0.26457396479474177,
                                    0.0005834936576974498,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.46157855398361947,
                                    0.13014340055064466,
                                    0.3184813211767019,
                                    0.0897967242890339,
                                ],
                                [
                                    0.6307641200469485,
                                    0.18922509378224256,
                                    0.13847053500589301,
                                    0.0415402511649159,
                                ],
                                [
                                    0.8111126501037307,
                                    0.008876563725460378,
                                    0.17806212978878944,
                                    0.0019486563820195018,
                                ],
                                [
                                    0.4615785539836194,
                                    0.13847053500589301,
                                    0.3076561010692221,
                                    0.09229480994126542,
                                ],
                                [
                                    0.5935534255259082,
                                    0.0064956634636042536,
                                    0.3956213543666119,
                                    0.004329556643875626,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.20132987799400742,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.29325751195225264,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.8585829369614957,
                                    0.020621780511185083,
                                    0.11796202452317024,
                                    0.002833258004148924,
                                ],
                                [
                                    0.20132987799400742,
                                    0.20132987799400742,
                                    0.2986701220059926,
                                    0.2986701220059926,
                                ],
                                [
                                    0.3932153559027409,
                                    0.009444400085273882,
                                    0.583329605581925,
                                    0.014010638430060127,
                                ],
                                [
                                    0.25263972295445003,
                                    0.694107632616969,
                                    0.014210478915896644,
                                    0.0390421655126844,
                                ],
                                [
                                    0.0473692999679328,
                                    0.1301434005506447,
                                    0.2194809019024139,
                                    0.6030063975790086,
                                ],
                                [
                                    0.21655486603126187,
                                    0.7218653550849088,
                                    0.014210478915896644,
                                    0.04736929996793278,
                                ],
                                [
                                    0.904557461703367,
                                    0.03386275941280359,
                                    0.05935768137344487,
                                    0.002222097510384547,
                                ],
                                [
                                    0.0473692999679328,
                                    0.15790112301858453,
                                    0.1833960449792257,
                                    0.611333532034257,
                                ],
                                [
                                    0.19786326914248653,
                                    0.007407153844030787,
                                    0.7660518739343253,
                                    0.02867770307915735,
                                ],
                                [
                                    0.09062779641185499,
                                    0.8985469834806651,
                                    0.0009918023224579236,
                                    0.00983341778502197,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.0327787768115006,
                                    0.08831351862262532,
                                    0.8756016244541865,
                                ],
                                [
                                    0.045918274708210145,
                                    0.9329390969859458,
                                    0.0009918023224579234,
                                    0.020150825983386036,
                                ],
                                [
                                    0.9350931267896234,
                                    0.04376424490453258,
                                    0.020197351506731735,
                                    0.0009452767991122257,
                                ],
                                [
                                    0.0033060801116875918,
                                    0.0671708903167813,
                                    0.04360399691898048,
                                    0.8859190326525506,
                                ],
                                [
                                    0.06732597878949013,
                                    0.0031509916389787637,
                                    0.8879644995068651,
                                    0.04155853006466605,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.4552388641864047,
                                    0.021306097298261252,
                                    0.5000516141099505,
                                    0.02340342440538356,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889516,
                                    0.4552388641864047,
                                    0.02240637496177286,
                                ],
                                [
                                    0.521205290300234,
                                    0.001149470551588411,
                                    0.4765941543727428,
                                    0.0010510847754347959,
                                ],
                                [
                                    0.4552388641864047,
                                    0.02240637496177286,
                                    0.49785105878292724,
                                    0.02450370206889516,
                                ],
                                [
                                    0.4765941543727428,
                                    0.0010510847754347959,
                                    0.521205290300234,
                                    0.001149470551588411,
                                ],
                                [
                                    0.4800353306655652,
                                    0.13534734180801405,
                                    0.3000245444947562,
                                    0.08459278303166452,
                                ],
                                [
                                    0.3000245444947563,
                                    0.08459278303166454,
                                    0.4800353306655651,
                                    0.13534734180801403,
                                ],
                                [
                                    0.4692101105580853,
                                    0.140759951861754,
                                    0.3000245444947562,
                                    0.09000539308540446,
                                ],
                                [
                                    0.6033670022351713,
                                    0.006603060184668001,
                                    0.3858077776573488,
                                    0.004222159922811878,
                                ],
                                [
                                    0.3000245444947563,
                                    0.09000539308540448,
                                    0.4692101105580852,
                                    0.14075995186175397,
                                ],
                                [
                                    0.3858077776573489,
                                    0.004222159922811879,
                                    0.6033670022351711,
                                    0.0066030601846680005,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1308637596288335,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.3574087211134995,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.7209562712717104,
                                    0.017316209470622606,
                                    0.2555886902129556,
                                    0.006138829044711403,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.2555886902129556,
                                    0.006138829044711403,
                                    0.7209562712717104,
                                    0.017316209470622606,
                                ],
                                [
                                    0.23606031242843198,
                                    0.6485570150979888,
                                    0.030789889441914717,
                                    0.08459278303166454,
                                ],
                                [
                                    0.030789889441914717,
                                    0.08459278303166454,
                                    0.23606031242843198,
                                    0.6485570150979888,
                                ],
                                [
                                    0.1999754555052438,
                                    0.6665994435595829,
                                    0.030789889441914717,
                                    0.10263521149325863,
                                ],
                                [
                                    0.8353046678188462,
                                    0.03127023124598047,
                                    0.12861047525796568,
                                    0.004814625677207665,
                                ],
                                [
                                    0.030789889441914717,
                                    0.10263521149325863,
                                    0.1999754555052438,
                                    0.6665994435595829,
                                ],
                                [
                                    0.12861047525796568,
                                    0.004814625677207665,
                                    0.8353046678188462,
                                    0.03127023124598047,
                                ],
                                [
                                    0.08947065751724015,
                                    0.8870743039674258,
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                    0.08947065751724015,
                                    0.8870743039674258,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                ],
                                [
                                    0.9115288131482442,
                                    0.042661387484599314,
                                    0.04376166514811096,
                                    0.0020481342190454958,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.04376166514811096,
                                    0.0020481342190454958,
                                    0.9115288131482442,
                                    0.042661387484599314,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.21010670705465664,
                                    0.009833417785021961,
                                    0.7451837712416985,
                                    0.03487610391862285,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260083,
                                    0.7003710213181527,
                                    0.034471520229407936,
                                ],
                                [
                                    0.2645739647947419,
                                    0.00058349365769745,
                                    0.7332254798782349,
                                    0.0016170616693257569,
                                ],
                                [
                                    0.2101067070546567,
                                    0.01034122969413778,
                                    0.7429832159146752,
                                    0.036568847336530236,
                                ],
                                [
                                    0.21996282886725063,
                                    0.0004851078815438347,
                                    0.7778366158057262,
                                    0.0017154474454793723,
                                ],
                                [
                                    0.318481321176702,
                                    0.08979672428903393,
                                    0.46157855398361936,
                                    0.13014340055064463,
                                ],
                                [
                                    0.13847053500589307,
                                    0.039042165512684406,
                                    0.6415893401544284,
                                    0.18089795932699415,
                                ],
                                [
                                    0.30765610106922214,
                                    0.09229480994126545,
                                    0.46157855398361936,
                                    0.138470535005893,
                                ],
                                [
                                    0.395621354366612,
                                    0.0043295566438756265,
                                    0.5935534255259081,
                                    0.006495663463604253,
                                ],
                                [
                                    0.13847053500589315,
                                    0.04154025116491595,
                                    0.6307641200469484,
                                    0.1892250937822425,
                                ],
                                [
                                    0.17806212978878963,
                                    0.001948656382019504,
                                    0.8111126501037305,
                                    0.008876563725460375,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.060397641263659596,
                                    0.054985031209919655,
                                    0.46305739725167444,
                                    0.4215599302747463,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.583329605581925,
                                    0.014010638430060127,
                                    0.3932153559027409,
                                    0.009444400085273882,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.11796202452317027,
                                    0.002833258004148925,
                                    0.8585829369614957,
                                    0.020621780511185083,
                                ],
                                [
                                    0.2194809019024139,
                                    0.6030063975790086,
                                    0.04736929996793279,
                                    0.13014340055064466,
                                ],
                                [
                                    0.014210478915896638,
                                    0.039042165512684385,
                                    0.25263972295445003,
                                    0.694107632616969,
                                ],
                                [
                                    0.18339604497922574,
                                    0.6113335320342571,
                                    0.04736929996793279,
                                    0.15790112301858447,
                                ],
                                [
                                    0.7660518739343254,
                                    0.028677703079157353,
                                    0.19786326914248648,
                                    0.007407153844030784,
                                ],
                                [
                                    0.014210478915896657,
                                    0.04736929996793283,
                                    0.21655486603126184,
                                    0.7218653550849087,
                                ],
                                [
                                    0.05935768137344493,
                                    0.002222097510384549,
                                    0.9045574617033669,
                                    0.03386275941280359,
                                ],
                                [
                                    0.08831351862262532,
                                    0.8756016244541865,
                                    0.003306080111687594,
                                    0.032778776811500585,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.00983341778502196,
                                    0.09062779641185499,
                                    0.8985469834806651,
                                ],
                                [
                                    0.04360399691898048,
                                    0.8859190326525506,
                                    0.003306080111687594,
                                    0.06717089031678135,
                                ],
                                [
                                    0.8879644995068651,
                                    0.04155853006466605,
                                    0.06732597878949018,
                                    0.003150991638978766,
                                ],
                                [
                                    0.000991802322457926,
                                    0.02015082598338609,
                                    0.045918274708210145,
                                    0.9329390969859458,
                                ],
                                [
                                    0.020197351506731784,
                                    0.000945276799112228,
                                    0.9350931267896234,
                                    0.04376424490453258,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08532277496919871,
                                    0.0041994966579918976,
                                    0.8677671480001332,
                                    0.04271058037267612,
                                ],
                                [
                                    0.08932527291547418,
                                    0.00019699871171643282,
                                    0.9084741717575026,
                                    0.0020035566153067744,
                                ],
                                [
                                    0.042710580372676187,
                                    0.002102169550869595,
                                    0.9103793425966558,
                                    0.044807907479798424,
                                ],
                                [
                                    0.04471413698798296,
                                    9.861293556281748e-05,
                                    0.9530853076849938,
                                    0.0021019423914603896,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.19733391505000927,
                                    0.05919887862197328,
                                    0.5719007400028322,
                                    0.17156646632518516,
                                ],
                                [
                                    0.25375576971569663,
                                    0.002777023956285933,
                                    0.7354190101768235,
                                    0.008048196151193947,
                                ],
                                [
                                    0.02814834898668019,
                                    0.008444319845623754,
                                    0.7410863060661613,
                                    0.2223210251015347,
                                ],
                                [
                                    0.03619654513787413,
                                    0.0003961236944298089,
                                    0.9529782347546459,
                                    0.01042909641305007,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.48934695135086936,
                                    0.011753326312642231,
                                    0.4871980101337966,
                                    0.011701712202691778,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.023979370292114624,
                                    0.0005759458867310291,
                                    0.9525655911925514,
                                    0.02287909262860298,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.17207427823430102,
                                    0.5735934834207397,
                                    0.05869106671285748,
                                    0.1956411716321019,
                                ],
                                [
                                    0.7187604471634845,
                                    0.026907314491556096,
                                    0.24515469591332734,
                                    0.009177542431632043,
                                ],
                                [
                                    0.002888712170971964,
                                    0.009629251354415402,
                                    0.22787663277618653,
                                    0.7596054036984261,
                                ],
                                [
                                    0.012066254602604074,
                                    0.00045170892278329085,
                                    0.9518488884742078,
                                    0.035633148000404846,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.0019989413309687114,
                                    0.09141798473825839,
                                    0.9063814599347184,
                                ],
                                [
                                    0.04281380859257708,
                                    0.8698644751072555,
                                    0.004096268438090997,
                                    0.0832254478620764,
                                ],
                                [
                                    0.8718728741663097,
                                    0.04080540953352296,
                                    0.08341760413004555,
                                    0.0039041121701218493,
                                ],
                                [
                                    0.0002016139960545219,
                                    0.004096268438091006,
                                    0.046708463034613554,
                                    0.948993654531241,
                                ],
                                [
                                    0.004105726166176385,
                                    0.00019215626796914326,
                                    0.9511847521301787,
                                    0.044517365435675665,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.8677671480001333,
                                    0.040613253265553824,
                                    0.08752333029622184,
                                    0.004096268438090988,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979843,
                                    0.042710580372676124,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.9448471378505183,
                                    0.010340112225936044,
                                    0.04432764204200188,
                                    0.00048510788154383454,
                                ],
                                [
                                    0.8677671480001333,
                                    0.042710580372676124,
                                    0.08532277496919864,
                                    0.004199496657991894,
                                ],
                                [
                                    0.9006216065602155,
                                    0.00985612181259394,
                                    0.0885531733323046,
                                    0.0009690982948859384,
                                ],
                                [
                                    0.7519115261736411,
                                    0.2120036169031706,
                                    0.028148348986680196,
                                    0.007936507936507938,
                                ],
                                [
                                    0.5719007400028323,
                                    0.1612490581268211,
                                    0.2081591351574891,
                                    0.058691066712857454,
                                ],
                                [
                                    0.7410863060661613,
                                    0.2223210251015347,
                                    0.0281483489866802,
                                    0.008444319845623756,
                                ],
                                [
                                    0.9121033431211345,
                                    0.05130398804656153,
                                    0.03464401245028446,
                                    0.001948656382019502,
                                ],
                                [
                                    0.5719007400028322,
                                    0.17156646632518516,
                                    0.19733391505000922,
                                    0.05919887862197327,
                                ],
                                [
                                    0.703875611545121,
                                    0.0395915947828964,
                                    0.24287174402629788,
                                    0.013661049645684625,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.2494498611682442,
                                    0.22709510031642177,
                                    0.27400517734708985,
                                    0.2494498611682442,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    0.862895269351724,
                                    0.1125494144694303,
                                    0.021722058174696687,
                                    0.002833258004148924,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.4413353390769777,
                                    0.05756438325951065,
                                    0.44328198844944305,
                                    0.05781828921406857,
                                ],
                                [
                                    0.2639614896993748,
                                    0.7252132901931454,
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                ],
                                [
                                    0.058691066712857495,
                                    0.16124905812682114,
                                    0.2081591351574892,
                                    0.5719007400028322,
                                ],
                                [
                                    0.22787663277618656,
                                    0.7596054036984262,
                                    0.0028887121709719426,
                                    0.00962925135441533,
                                ],
                                [
                                    0.8121914334664199,
                                    0.17529060300819285,
                                    0.010295866015002727,
                                    0.0022220975103845464,
                                ],
                                [
                                    0.058691066712857495,
                                    0.19564117163210193,
                                    0.172074278234301,
                                    0.5735934834207396,
                                ],
                                [
                                    0.20918503588741122,
                                    0.04514720245754823,
                                    0.6133022635940114,
                                    0.13236549806102918,
                                ],
                                [
                                    0.09141798473825839,
                                    0.9063814599347184,
                                    0.00020161399605452118,
                                    0.0019989413309686884,
                                ],
                                [
                                    0.004096268438090994,
                                    0.040613253265553845,
                                    0.08752333029622192,
                                    0.8677671480001332,
                                ],
                                [
                                    0.046708463034613554,
                                    0.948993654531241,
                                    0.00020161399605452123,
                                    0.0040962684380909916,
                                ],
                                [
                                    0.7767072695252881,
                                    0.21899484804056635,
                                    0.003352605635033287,
                                    0.0009452767991122257,
                                ],
                                [
                                    0.004096268438090996,
                                    0.08322544786207639,
                                    0.04281380859257708,
                                    0.8698644751072555,
                                ],
                                [
                                    0.06811616711589356,
                                    0.01920554918427381,
                                    0.7119437080444279,
                                    0.20073457565540476,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7003710213181529,
                                    0.03277877681150055,
                                    0.25491945697820234,
                                    0.01193074489214426,
                                ],
                                [
                                    0.7429832159146753,
                                    0.03656884733653024,
                                    0.2101067070546566,
                                    0.010341229694137775,
                                ],
                                [
                                    0.7711132405812713,
                                    0.008438822669934377,
                                    0.21806153931124886,
                                    0.0023863974375455013,
                                ],
                                [
                                    0.7003710213181528,
                                    0.03447152022940794,
                                    0.2527189016511791,
                                    0.012438556801260077,
                                ],
                                [
                                    0.7268877092909685,
                                    0.007954832256592274,
                                    0.2622870706015516,
                                    0.0028703878508876055,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.46157855398361947,
                                    0.13014340055064466,
                                    0.3184813211767019,
                                    0.0897967242890339,
                                ],
                                [
                                    0.6307641200469485,
                                    0.18922509378224256,
                                    0.13847053500589301,
                                    0.0415402511649159,
                                ],
                                [
                                    0.7763226197898735,
                                    0.04366659403931761,
                                    0.17042473578154552,
                                    0.009586050389263419,
                                ],
                                [
                                    0.4615785539836194,
                                    0.13847053500589301,
                                    0.3076561010692221,
                                    0.09229480994126542,
                                ],
                                [
                                    0.56809488821386,
                                    0.03195420077565248,
                                    0.378652467357559,
                                    0.021298443652928545,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.20132987799400742,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.29325751195225264,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.7777597275193047,
                                    0.10144498995337609,
                                    0.10685760000711603,
                                    0.013937682520203134,
                                ],
                                [
                                    0.20132987799400742,
                                    0.20132987799400742,
                                    0.2986701220059926,
                                    0.2986701220059926,
                                ],
                                [
                                    0.3561997972445584,
                                    0.046459958743456445,
                                    0.5284175302818623,
                                    0.06892271373012278,
                                ],
                                [
                                    0.25263972295445003,
                                    0.694107632616969,
                                    0.014210478915896644,
                                    0.0390421655126844,
                                ],
                                [
                                    0.0473692999679328,
                                    0.1301434005506447,
                                    0.2194809019024139,
                                    0.6030063975790086,
                                ],
                                [
                                    0.21655486603126187,
                                    0.7218653550849088,
                                    0.014210478915896644,
                                    0.04736929996793278,
                                ],
                                [
                                    0.7718387134445986,
                                    0.16658150767157198,
                                    0.050648586036824,
                                    0.010931192847005429,
                                ],
                                [
                                    0.0473692999679328,
                                    0.15790112301858453,
                                    0.1833960449792257,
                                    0.611333532034257,
                                ],
                                [
                                    0.16883231586558997,
                                    0.036438107120927356,
                                    0.6536549836158326,
                                    0.14107459339765005,
                                ],
                                [
                                    0.09062779641185499,
                                    0.8985469834806651,
                                    0.0009918023224579236,
                                    0.00983341778502197,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.0327787768115006,
                                    0.08831351862262532,
                                    0.8756016244541865,
                                ],
                                [
                                    0.045918274708210145,
                                    0.9329390969859458,
                                    0.0009918023224579234,
                                    0.020150825983386036,
                                ],
                                [
                                    0.7635673591635036,
                                    0.2152900125306523,
                                    0.016492515996817718,
                                    0.004650112309026243,
                                ],
                                [
                                    0.0033060801116875918,
                                    0.0671708903167813,
                                    0.04360399691898048,
                                    0.8859190326525506,
                                ],
                                [
                                    0.05497625675410911,
                                    0.015500713674359784,
                                    0.7250836184062123,
                                    0.20443941116531877,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.4552388641864047,
                                    0.021306097298261252,
                                    0.5000516141099505,
                                    0.02340342440538356,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889516,
                                    0.4552388641864047,
                                    0.02240637496177286,
                                ],
                                [
                                    0.5167001555914115,
                                    0.005654605260410991,
                                    0.4724746243011087,
                                    0.005170614847068888,
                                ],
                                [
                                    0.4552388641864047,
                                    0.02240637496177286,
                                    0.49785105878292724,
                                    0.02450370206889516,
                                ],
                                [
                                    0.4724746243011087,
                                    0.005170614847068888,
                                    0.5167001555914115,
                                    0.005654605260410991,
                                ],
                                [
                                    0.4800353306655652,
                                    0.13534734180801405,
                                    0.3000245444947562,
                                    0.08459278303166452,
                                ],
                                [
                                    0.3000245444947563,
                                    0.08459278303166454,
                                    0.4800353306655651,
                                    0.13534734180801403,
                                ],
                                [
                                    0.4692101105580853,
                                    0.140759951861754,
                                    0.3000245444947562,
                                    0.09000539308540446,
                                ],
                                [
                                    0.5774875435737162,
                                    0.032482518846123076,
                                    0.36925981199770275,
                                    0.02077012558245795,
                                ],
                                [
                                    0.3000245444947563,
                                    0.09000539308540448,
                                    0.4692101105580852,
                                    0.14075995186175397,
                                ],
                                [
                                    0.36925981199770286,
                                    0.020770125582457957,
                                    0.5774875435737161,
                                    0.03248251884612307,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1308637596288335,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.3574087211134995,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.6530886289005835,
                                    0.08518385184174943,
                                    0.23152869862583722,
                                    0.03019882063182979,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.23152869862583722,
                                    0.03019882063182979,
                                    0.6530886289005835,
                                    0.08518385184174943,
                                ],
                                [
                                    0.23606031242843198,
                                    0.6485570150979888,
                                    0.030789889441914717,
                                    0.08459278303166454,
                                ],
                                [
                                    0.030789889441914717,
                                    0.08459278303166454,
                                    0.23606031242843198,
                                    0.6485570150979888,
                                ],
                                [
                                    0.1999754555052438,
                                    0.6665994435595829,
                                    0.030789889441914717,
                                    0.10263521149325863,
                                ],
                                [
                                    0.7127468485302156,
                                    0.15382805053461102,
                                    0.10974045095120696,
                                    0.023684649983966386,
                                ],
                                [
                                    0.030789889441914717,
                                    0.10263521149325863,
                                    0.1999754555052438,
                                    0.6665994435595829,
                                ],
                                [
                                    0.10974045095120696,
                                    0.023684649983966386,
                                    0.7127468485302156,
                                    0.15382805053461102,
                                ],
                                [
                                    0.08947065751724015,
                                    0.8870743039674258,
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                    0.08947065751724015,
                                    0.8870743039674258,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                ],
                                [
                                    0.7443254887848579,
                                    0.20986471184798555,
                                    0.03573438637546344,
                                    0.010075412991693018,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.03573438637546344,
                                    0.010075412991693018,
                                    0.7443254887848579,
                                    0.20986471184798555,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.21010670705465664,
                                    0.009833417785021961,
                                    0.7451837712416985,
                                    0.03487610391862285,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260083,
                                    0.7003710213181527,
                                    0.034471520229407936,
                                ],
                                [
                                    0.2622870706015517,
                                    0.0028703878508876068,
                                    0.7268877092909684,
                                    0.007954832256592272,
                                ],
                                [
                                    0.2101067070546567,
                                    0.01034122969413778,
                                    0.7429832159146752,
                                    0.036568847336530236,
                                ],
                                [
                                    0.21806153931124897,
                                    0.0023863974375455026,
                                    0.7711132405812712,
                                    0.008438822669934377,
                                ],
                                [
                                    0.318481321176702,
                                    0.08979672428903393,
                                    0.46157855398361936,
                                    0.13014340055064463,
                                ],
                                [
                                    0.13847053500589307,
                                    0.039042165512684406,
                                    0.6415893401544284,
                                    0.18089795932699415,
                                ],
                                [
                                    0.30765610106922214,
                                    0.09229480994126545,
                                    0.46157855398361936,
                                    0.138470535005893,
                                ],
                                [
                                    0.3786524673575591,
                                    0.021298443652928552,
                                    0.5680948882138599,
                                    0.031954200775652475,
                                ],
                                [
                                    0.13847053500589315,
                                    0.04154025116491595,
                                    0.6307641200469484,
                                    0.1892250937822425,
                                ],
                                [
                                    0.17042473578154568,
                                    0.00958605038926343,
                                    0.7763226197898733,
                                    0.0436665940393176,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.060397641263659596,
                                    0.054985031209919655,
                                    0.46305739725167444,
                                    0.4215599302747463,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.5284175302818623,
                                    0.06892271373012278,
                                    0.3561997972445584,
                                    0.046459958743456445,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.10685760000711605,
                                    0.013937682520203137,
                                    0.7777597275193047,
                                    0.10144498995337609,
                                ],
                                [
                                    0.2194809019024139,
                                    0.6030063975790086,
                                    0.04736929996793279,
                                    0.13014340055064466,
                                ],
                                [
                                    0.014210478915896638,
                                    0.039042165512684385,
                                    0.25263972295445003,
                                    0.694107632616969,
                                ],
                                [
                                    0.18339604497922574,
                                    0.6113335320342571,
                                    0.04736929996793279,
                                    0.15790112301858447,
                                ],
                                [
                                    0.6536549836158327,
                                    0.14107459339765005,
                                    0.16883231586558992,
                                    0.03643810712092734,
                                ],
                                [
                                    0.014210478915896657,
                                    0.04736929996793283,
                                    0.21655486603126184,
                                    0.7218653550849087,
                                ],
                                [
                                    0.050648586036824046,
                                    0.010931192847005439,
                                    0.7718387134445985,
                                    0.16658150767157195,
                                ],
                                [
                                    0.08831351862262532,
                                    0.8756016244541865,
                                    0.003306080111687594,
                                    0.032778776811500585,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.00983341778502196,
                                    0.09062779641185499,
                                    0.8985469834806651,
                                ],
                                [
                                    0.04360399691898048,
                                    0.8859190326525506,
                                    0.003306080111687594,
                                    0.06717089031678135,
                                ],
                                [
                                    0.7250836184062123,
                                    0.20443941116531877,
                                    0.054976256754109144,
                                    0.015500713674359793,
                                ],
                                [
                                    0.000991802322457926,
                                    0.02015082598338609,
                                    0.045918274708210145,
                                    0.9329390969859458,
                                ],
                                [
                                    0.01649251599681776,
                                    0.004650112309026254,
                                    0.7635673591635036,
                                    0.2152900125306523,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08532277496919871,
                                    0.0041994966579918976,
                                    0.8677671480001332,
                                    0.04271058037267612,
                                ],
                                [
                                    0.08855317333230468,
                                    0.0009690982948859394,
                                    0.9006216065602154,
                                    0.009856121812593939,
                                ],
                                [
                                    0.042710580372676187,
                                    0.002102169550869595,
                                    0.9103793425966558,
                                    0.044807907479798424,
                                ],
                                [
                                    0.044327642042001944,
                                    0.0004851078815438352,
                                    0.9448471378505182,
                                    0.010340112225936044,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.19733391505000927,
                                    0.05919887862197328,
                                    0.5719007400028322,
                                    0.17156646632518516,
                                ],
                                [
                                    0.24287174402629794,
                                    0.013661049645684629,
                                    0.703875611545121,
                                    0.0395915947828964,
                                ],
                                [
                                    0.02814834898668019,
                                    0.008444319845623754,
                                    0.7410863060661613,
                                    0.2223210251015347,
                                ],
                                [
                                    0.034644012450284443,
                                    0.001948656382019501,
                                    0.9121033431211345,
                                    0.05130398804656153,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.44328198844944305,
                                    0.05781828921406857,
                                    0.4413353390769777,
                                    0.05756438325951065,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.021722058174696725,
                                    0.002833258004148929,
                                    0.862895269351724,
                                    0.1125494144694303,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.17207427823430102,
                                    0.5735934834207397,
                                    0.05869106671285748,
                                    0.1956411716321019,
                                ],
                                [
                                    0.6133022635940115,
                                    0.13236549806102918,
                                    0.20918503588741116,
                                    0.04514720245754822,
                                ],
                                [
                                    0.002888712170971964,
                                    0.009629251354415402,
                                    0.22787663277618653,
                                    0.7596054036984261,
                                ],
                                [
                                    0.010295866015002804,
                                    0.002222097510384563,
                                    0.8121914334664199,
                                    0.17529060300819282,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.0019989413309687114,
                                    0.09141798473825839,
                                    0.9063814599347184,
                                ],
                                [
                                    0.04281380859257708,
                                    0.8698644751072555,
                                    0.004096268438090997,
                                    0.0832254478620764,
                                ],
                                [
                                    0.7119437080444279,
                                    0.20073457565540476,
                                    0.06811616711589358,
                                    0.019205549184273814,
                                ],
                                [
                                    0.0002016139960545219,
                                    0.004096268438091006,
                                    0.046708463034613554,
                                    0.948993654531241,
                                ],
                                [
                                    0.0033526056350332988,
                                    0.000945276799112229,
                                    0.7767072695252881,
                                    0.21899484804056635,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.8677671480001333,
                                    0.040613253265553824,
                                    0.08752333029622184,
                                    0.004096268438090988,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979843,
                                    0.042710580372676124,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.9327832963365551,
                                    0.022403953739899216,
                                    0.04376166514811092,
                                    0.0010510847754347959,
                                ],
                                [
                                    0.8677671480001333,
                                    0.042710580372676124,
                                    0.08532277496919864,
                                    0.004199496657991894,
                                ],
                                [
                                    0.8891224381864714,
                                    0.021355290186338062,
                                    0.08742252329819458,
                                    0.002099748328995947,
                                ],
                                [
                                    0.7519115261736411,
                                    0.2120036169031706,
                                    0.028148348986680196,
                                    0.007936507936507938,
                                ],
                                [
                                    0.5719007400028323,
                                    0.1612490581268211,
                                    0.2081591351574891,
                                    0.058691066712857454,
                                ],
                                [
                                    0.7410863060661613,
                                    0.2223210251015347,
                                    0.0281483489866802,
                                    0.008444319845623756,
                                ],
                                [
                                    0.8522468186169286,
                                    0.11116051255076735,
                                    0.03237050890949208,
                                    0.004222159922811878,
                                ],
                                [
                                    0.5719007400028322,
                                    0.17156646632518516,
                                    0.19733391505000922,
                                    0.05919887862197327,
                                ],
                                [
                                    0.6576839731654248,
                                    0.08578323316259258,
                                    0.22693335436099588,
                                    0.029599439310986634,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.2494498611682442,
                                    0.22709510031642177,
                                    0.27400517734708985,
                                    0.2494498611682442,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    0.7315835128658658,
                                    0.2438611709552886,
                                    0.01841648713413421,
                                    0.006138829044711403,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.3741747917523663,
                                    0.1247249305841221,
                                    0.3758252082476337,
                                    0.1252750694158779,
                                ],
                                [
                                    0.2639614896993748,
                                    0.7252132901931454,
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                ],
                                [
                                    0.058691066712857495,
                                    0.16124905812682114,
                                    0.2081591351574892,
                                    0.5719007400028322,
                                ],
                                [
                                    0.22787663277618656,
                                    0.7596054036984262,
                                    0.0028887121709719426,
                                    0.00962925135441533,
                                ],
                                [
                                    0.6076793346253997,
                                    0.3798027018492131,
                                    0.007703337848179608,
                                    0.004814625677207665,
                                ],
                                [
                                    0.058691066712857495,
                                    0.19564117163210193,
                                    0.172074278234301,
                                    0.5735934834207396,
                                ],
                                [
                                    0.15651165252890847,
                                    0.09782058581605096,
                                    0.4588710199446708,
                                    0.2867967417103698,
                                ],
                                [
                                    0.09141798473825839,
                                    0.9063814599347184,
                                    0.00020161399605452118,
                                    0.0019989413309686884,
                                ],
                                [
                                    0.004096268438090994,
                                    0.040613253265553845,
                                    0.08752333029622192,
                                    0.8677671480001332,
                                ],
                                [
                                    0.046708463034613554,
                                    0.948993654531241,
                                    0.00020161399605452123,
                                    0.0040962684380909916,
                                ],
                                [
                                    0.521205290300234,
                                    0.4744968272656205,
                                    0.0022497482151000174,
                                    0.0020481342190454958,
                                ],
                                [
                                    0.004096268438090996,
                                    0.08322544786207639,
                                    0.04281380859257708,
                                    0.8698644751072555,
                                ],
                                [
                                    0.04570899236912919,
                                    0.041612723931038195,
                                    0.47774604614620486,
                                    0.43493223755362775,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7003710213181529,
                                    0.03277877681150055,
                                    0.25491945697820234,
                                    0.01193074489214426,
                                ],
                                [
                                    0.7429832159146753,
                                    0.03656884733653024,
                                    0.2101067070546566,
                                    0.010341229694137775,
                                ],
                                [
                                    0.7612676395829405,
                                    0.01828442366826512,
                                    0.21527732190172547,
                                    0.005170614847068888,
                                ],
                                [
                                    0.7003710213181528,
                                    0.03447152022940794,
                                    0.2527189016511791,
                                    0.012438556801260077,
                                ],
                                [
                                    0.7176067814328568,
                                    0.01723576011470397,
                                    0.2589381800518092,
                                    0.006219278400630039,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.46157855398361947,
                                    0.13014340055064466,
                                    0.3184813211767019,
                                    0.0897967242890339,
                                ],
                                [
                                    0.6307641200469485,
                                    0.18922509378224256,
                                    0.13847053500589301,
                                    0.0415402511649159,
                                ],
                                [
                                    0.7253766669380698,
                                    0.09461254689112128,
                                    0.15924066058835099,
                                    0.02077012558245795,
                                ],
                                [
                                    0.4615785539836194,
                                    0.13847053500589301,
                                    0.3076561010692221,
                                    0.09229480994126542,
                                ],
                                [
                                    0.530813821486566,
                                    0.06923526750294651,
                                    0.3538035060398548,
                                    0.04614740497063271,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.20132987799400742,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.29325751195225264,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.6594035381045106,
                                    0.2198011793681702,
                                    0.09059646189548937,
                                    0.03019882063182979,
                                ],
                                [
                                    0.20132987799400742,
                                    0.20132987799400742,
                                    0.2986701220059926,
                                    0.2986701220059926,
                                ],
                                [
                                    0.30199481699101116,
                                    0.10066493899700371,
                                    0.44800518300898884,
                                    0.1493350610029963,
                                ],
                                [
                                    0.25263972295445003,
                                    0.694107632616969,
                                    0.014210478915896644,
                                    0.0390421655126844,
                                ],
                                [
                                    0.0473692999679328,
                                    0.1301434005506447,
                                    0.2194809019024139,
                                    0.6030063975790086,
                                ],
                                [
                                    0.21655486603126187,
                                    0.7218653550849088,
                                    0.014210478915896644,
                                    0.04736929996793278,
                                ],
                                [
                                    0.5774875435737162,
                                    0.3609326775424544,
                                    0.03789512889986303,
                                    0.02368464998396639,
                                ],
                                [
                                    0.0473692999679328,
                                    0.15790112301858453,
                                    0.1833960449792257,
                                    0.611333532034257,
                                ],
                                [
                                    0.12631986147722507,
                                    0.07895056150929226,
                                    0.4890628109963542,
                                    0.3056667660171285,
                                ],
                                [
                                    0.09062779641185499,
                                    0.8985469834806651,
                                    0.0009918023224579236,
                                    0.00983341778502197,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.0327787768115006,
                                    0.08831351862262532,
                                    0.8756016244541865,
                                ],
                                [
                                    0.045918274708210145,
                                    0.9329390969859458,
                                    0.0009918023224579234,
                                    0.020150825983386036,
                                ],
                                [
                                    0.512387823201183,
                                    0.4664695484929729,
                                    0.011067215314150943,
                                    0.010075412991693018,
                                ],
                                [
                                    0.0033060801116875918,
                                    0.0671708903167813,
                                    0.04360399691898048,
                                    0.8859190326525506,
                                ],
                                [
                                    0.036891525270078246,
                                    0.03358544515839065,
                                    0.4865635132452558,
                                    0.4429595163262753,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.4552388641864047,
                                    0.021306097298261252,
                                    0.5000516141099505,
                                    0.02340342440538356,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889516,
                                    0.4552388641864047,
                                    0.02240637496177286,
                                ],
                                [
                                    0.5101029098173748,
                                    0.01225185103444758,
                                    0.46644205166729114,
                                    0.01120318748088643,
                                ],
                                [
                                    0.4552388641864047,
                                    0.02240637496177286,
                                    0.49785105878292724,
                                    0.02450370206889516,
                                ],
                                [
                                    0.46644205166729114,
                                    0.01120318748088643,
                                    0.5101029098173748,
                                    0.01225185103444758,
                                ],
                                [
                                    0.4800353306655652,
                                    0.13534734180801405,
                                    0.3000245444947562,
                                    0.08459278303166452,
                                ],
                                [
                                    0.3000245444947563,
                                    0.08459278303166454,
                                    0.4800353306655651,
                                    0.13534734180801403,
                                ],
                                [
                                    0.4692101105580853,
                                    0.140759951861754,
                                    0.3000245444947562,
                                    0.09000539308540446,
                                ],
                                [
                                    0.5395900864889623,
                                    0.070379975930877,
                                    0.34502724103745847,
                                    0.04500269654270223,
                                ],
                                [
                                    0.3000245444947563,
                                    0.09000539308540448,
                                    0.4692101105580852,
                                    0.14075995186175397,
                                ],
                                [
                                    0.3450272410374585,
                                    0.04500269654270224,
                                    0.5395900864889622,
                                    0.07037997593087698,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1308637596288335,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.3574087211134995,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.5537043605567498,
                                    0.18456812018558325,
                                    0.19629563944325026,
                                    0.06543187981441675,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.19629563944325026,
                                    0.06543187981441675,
                                    0.5537043605567498,
                                    0.18456812018558325,
                                ],
                                [
                                    0.23606031242843198,
                                    0.6485570150979888,
                                    0.030789889441914717,
                                    0.08459278303166454,
                                ],
                                [
                                    0.030789889441914717,
                                    0.08459278303166454,
                                    0.23606031242843198,
                                    0.6485570150979888,
                                ],
                                [
                                    0.1999754555052438,
                                    0.6665994435595829,
                                    0.030789889441914717,
                                    0.10263521149325863,
                                ],
                                [
                                    0.5332751772850353,
                                    0.33329972177979145,
                                    0.08210749518854403,
                                    0.051317605746629316,
                                ],
                                [
                                    0.030789889441914717,
                                    0.10263521149325863,
                                    0.1999754555052438,
                                    0.6665994435595829,
                                ],
                                [
                                    0.08210749518854403,
                                    0.051317605746629316,
                                    0.5332751772850353,
                                    0.33329972177979145,
                                ],
                                [
                                    0.08947065751724015,
                                    0.8870743039674258,
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                    0.08947065751724015,
                                    0.8870743039674258,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                ],
                                [
                                    0.4994756682232194,
                                    0.4547145324096241,
                                    0.023979370292114607,
                                    0.02183042907504185,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.023979370292114607,
                                    0.02183042907504185,
                                    0.4994756682232194,
                                    0.4547145324096241,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.21010670705465664,
                                    0.009833417785021961,
                                    0.7451837712416985,
                                    0.03487610391862285,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260083,
                                    0.7003710213181527,
                                    0.034471520229407936,
                                ],
                                [
                                    0.2589381800518093,
                                    0.006219278400630041,
                                    0.7176067814328567,
                                    0.017235760114703968,
                                ],
                                [
                                    0.2101067070546567,
                                    0.01034122969413778,
                                    0.7429832159146752,
                                    0.036568847336530236,
                                ],
                                [
                                    0.21527732190172558,
                                    0.00517061484706889,
                                    0.7612676395829404,
                                    0.018284423668265118,
                                ],
                                [
                                    0.318481321176702,
                                    0.08979672428903393,
                                    0.46157855398361936,
                                    0.13014340055064463,
                                ],
                                [
                                    0.13847053500589307,
                                    0.039042165512684406,
                                    0.6415893401544284,
                                    0.18089795932699415,
                                ],
                                [
                                    0.30765610106922214,
                                    0.09229480994126545,
                                    0.46157855398361936,
                                    0.138470535005893,
                                ],
                                [
                                    0.3538035060398549,
                                    0.04614740497063272,
                                    0.5308138214865659,
                                    0.0692352675029465,
                                ],
                                [
                                    0.13847053500589315,
                                    0.04154025116491595,
                                    0.6307641200469484,
                                    0.1892250937822425,
                                ],
                                [
                                    0.15924066058835115,
                                    0.020770125582457975,
                                    0.7253766669380696,
                                    0.09461254689112125,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.060397641263659596,
                                    0.054985031209919655,
                                    0.46305739725167444,
                                    0.4215599302747463,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.44800518300898884,
                                    0.1493350610029963,
                                    0.30199481699101116,
                                    0.10066493899700371,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.0905964618954894,
                                    0.030198820631829798,
                                    0.6594035381045106,
                                    0.2198011793681702,
                                ],
                                [
                                    0.2194809019024139,
                                    0.6030063975790086,
                                    0.04736929996793279,
                                    0.13014340055064466,
                                ],
                                [
                                    0.014210478915896638,
                                    0.039042165512684385,
                                    0.25263972295445003,
                                    0.694107632616969,
                                ],
                                [
                                    0.18339604497922574,
                                    0.6113335320342571,
                                    0.04736929996793279,
                                    0.15790112301858447,
                                ],
                                [
                                    0.48906281099635424,
                                    0.30566676601712855,
                                    0.12631986147722502,
                                    0.07895056150929224,
                                ],
                                [
                                    0.014210478915896657,
                                    0.04736929996793283,
                                    0.21655486603126184,
                                    0.7218653550849087,
                                ],
                                [
                                    0.03789512889986307,
                                    0.023684649983966414,
                                    0.5774875435737162,
                                    0.36093267754245434,
                                ],
                                [
                                    0.08831351862262532,
                                    0.8756016244541865,
                                    0.003306080111687594,
                                    0.032778776811500585,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.00983341778502196,
                                    0.09062779641185499,
                                    0.8985469834806651,
                                ],
                                [
                                    0.04360399691898048,
                                    0.8859190326525506,
                                    0.003306080111687594,
                                    0.06717089031678135,
                                ],
                                [
                                    0.4865635132452558,
                                    0.4429595163262753,
                                    0.03689152527007827,
                                    0.033585445158390674,
                                ],
                                [
                                    0.000991802322457926,
                                    0.02015082598338609,
                                    0.045918274708210145,
                                    0.9329390969859458,
                                ],
                                [
                                    0.01106721531415097,
                                    0.010075412991693044,
                                    0.512387823201183,
                                    0.4664695484929729,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08532277496919871,
                                    0.0041994966579918976,
                                    0.8677671480001332,
                                    0.04271058037267612,
                                ],
                                [
                                    0.08742252329819467,
                                    0.0020997483289959488,
                                    0.8891224381864713,
                                    0.02135529018633806,
                                ],
                                [
                                    0.042710580372676187,
                                    0.002102169550869595,
                                    0.9103793425966558,
                                    0.044807907479798424,
                                ],
                                [
                                    0.04376166514811098,
                                    0.0010510847754347974,
                                    0.932783296336555,
                                    0.022403953739899212,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.19733391505000927,
                                    0.05919887862197328,
                                    0.5719007400028322,
                                    0.17156646632518516,
                                ],
                                [
                                    0.2269333543609959,
                                    0.02959943931098664,
                                    0.6576839731654248,
                                    0.08578323316259258,
                                ],
                                [
                                    0.02814834898668019,
                                    0.008444319845623754,
                                    0.7410863060661613,
                                    0.2223210251015347,
                                ],
                                [
                                    0.032370508909492064,
                                    0.004222159922811877,
                                    0.8522468186169286,
                                    0.11116051255076735,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.3758252082476337,
                                    0.1252750694158779,
                                    0.3741747917523663,
                                    0.1247249305841221,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.01841648713413424,
                                    0.0061388290447114136,
                                    0.7315835128658658,
                                    0.2438611709552886,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.17207427823430102,
                                    0.5735934834207397,
                                    0.05869106671285748,
                                    0.1956411716321019,
                                ],
                                [
                                    0.45887101994467083,
                                    0.28679674171036984,
                                    0.15651165252890845,
                                    0.09782058581605095,
                                ],
                                [
                                    0.002888712170971964,
                                    0.009629251354415402,
                                    0.22787663277618653,
                                    0.7596054036984261,
                                ],
                                [
                                    0.007703337848179665,
                                    0.004814625677207701,
                                    0.6076793346253996,
                                    0.37980270184921305,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.0019989413309687114,
                                    0.09141798473825839,
                                    0.9063814599347184,
                                ],
                                [
                                    0.04281380859257708,
                                    0.8698644751072555,
                                    0.004096268438090997,
                                    0.0832254478620764,
                                ],
                                [
                                    0.47774604614620486,
                                    0.43493223755362775,
                                    0.045708992369129196,
                                    0.0416127239310382,
                                ],
                                [
                                    0.0002016139960545219,
                                    0.004096268438091006,
                                    0.046708463034613554,
                                    0.948993654531241,
                                ],
                                [
                                    0.002249748215100025,
                                    0.002048134219045503,
                                    0.521205290300234,
                                    0.4744968272656205,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.8677671480001333,
                                    0.040613253265553824,
                                    0.08752333029622184,
                                    0.004096268438090988,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979843,
                                    0.042710580372676124,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.9207194548225919,
                                    0.03446779525386238,
                                    0.04319568825421996,
                                    0.0016170616693257573,
                                ],
                                [
                                    0.8677671480001333,
                                    0.042710580372676124,
                                    0.08532277496919864,
                                    0.004199496657991894,
                                ],
                                [
                                    0.8776232698127273,
                                    0.03285445856008218,
                                    0.08629187326408458,
                                    0.0032303983631059552,
                                ],
                                [
                                    0.7519115261736411,
                                    0.2120036169031706,
                                    0.028148348986680196,
                                    0.007936507936507938,
                                ],
                                [
                                    0.5719007400028323,
                                    0.1612490581268211,
                                    0.2081591351574891,
                                    0.058691066712857454,
                                ],
                                [
                                    0.7410863060661613,
                                    0.2223210251015347,
                                    0.0281483489866802,
                                    0.008444319845623756,
                                ],
                                [
                                    0.7923902941127229,
                                    0.17101703705497315,
                                    0.030097005368699706,
                                    0.0064956634636042536,
                                ],
                                [
                                    0.5719007400028322,
                                    0.17156646632518516,
                                    0.19733391505000922,
                                    0.05919887862197327,
                                ],
                                [
                                    0.6114923347857287,
                                    0.13197487154228876,
                                    0.21099496469569387,
                                    0.045537828976288636,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.2494498611682442,
                                    0.22709510031642177,
                                    0.27400517734708985,
                                    0.2494498611682442,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    0.6002717563800075,
                                    0.37517292744114683,
                                    0.01511091609357173,
                                    0.009444400085273882,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.3070142444277549,
                                    0.19188547790873353,
                                    0.30836842804582437,
                                    0.19273184961768722,
                                ],
                                [
                                    0.2639614896993748,
                                    0.7252132901931454,
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                ],
                                [
                                    0.058691066712857495,
                                    0.16124905812682114,
                                    0.2081591351574892,
                                    0.5719007400028322,
                                ],
                                [
                                    0.22787663277618656,
                                    0.7596054036984262,
                                    0.0028887121709719426,
                                    0.00962925135441533,
                                ],
                                [
                                    0.4031672357843795,
                                    0.5843148006902332,
                                    0.00511080968135649,
                                    0.007407153844030783,
                                ],
                                [
                                    0.058691066712857495,
                                    0.19564117163210193,
                                    0.172074278234301,
                                    0.5735934834207396,
                                ],
                                [
                                    0.10383826917040576,
                                    0.15049396917455368,
                                    0.30443977629533026,
                                    0.4412279853597103,
                                ],
                                [
                                    0.09141798473825839,
                                    0.9063814599347184,
                                    0.00020161399605452118,
                                    0.0019989413309686884,
                                ],
                                [
                                    0.004096268438090994,
                                    0.040613253265553845,
                                    0.08752333029622192,
                                    0.8677671480001332,
                                ],
                                [
                                    0.046708463034613554,
                                    0.948993654531241,
                                    0.00020161399605452123,
                                    0.0040962684380909916,
                                ],
                                [
                                    0.2657033110751799,
                                    0.7299988064906745,
                                    0.0011468907951667471,
                                    0.003150991638978766,
                                ],
                                [
                                    0.004096268438090996,
                                    0.08322544786207639,
                                    0.04281380859257708,
                                    0.8698644751072555,
                                ],
                                [
                                    0.02330181762236481,
                                    0.06401989867780257,
                                    0.2435483842479819,
                                    0.6691298994518508,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7003710213181529,
                                    0.03277877681150055,
                                    0.25491945697820234,
                                    0.01193074489214426,
                                ],
                                [
                                    0.7429832159146753,
                                    0.03656884733653024,
                                    0.2101067070546566,
                                    0.010341229694137775,
                                ],
                                [
                                    0.7514220385846098,
                                    0.028130024666595862,
                                    0.21249310449220207,
                                    0.007954832256592272,
                                ],
                                [
                                    0.7003710213181528,
                                    0.03447152022940794,
                                    0.2527189016511791,
                                    0.012438556801260077,
                                ],
                                [
                                    0.7083258535747451,
                                    0.026516687972815665,
                                    0.2555892895020667,
                                    0.009568168950372472,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.46157855398361947,
                                    0.13014340055064466,
                                    0.3184813211767019,
                                    0.0897967242890339,
                                ],
                                [
                                    0.6307641200469485,
                                    0.18922509378224256,
                                    0.13847053500589301,
                                    0.0415402511649159,
                                ],
                                [
                                    0.6744307140862662,
                                    0.14555849974292492,
                                    0.14805658539515645,
                                    0.03195420077565248,
                                ],
                                [
                                    0.4615785539836194,
                                    0.13847053500589301,
                                    0.3076561010692221,
                                    0.09229480994126542,
                                ],
                                [
                                    0.493532754759272,
                                    0.10651633423024053,
                                    0.32895454472215063,
                                    0.07099636628833687,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.20132987799400742,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.29325751195225264,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.5410473486897165,
                                    0.3381573687829643,
                                    0.07433532378386272,
                                    0.046459958743456445,
                                ],
                                [
                                    0.20132987799400742,
                                    0.20132987799400742,
                                    0.2986701220059926,
                                    0.2986701220059926,
                                ],
                                [
                                    0.24778983673746388,
                                    0.15486991925055096,
                                    0.3675928357361154,
                                    0.22974740827586979,
                                ],
                                [
                                    0.25263972295445003,
                                    0.694107632616969,
                                    0.014210478915896644,
                                    0.0390421655126844,
                                ],
                                [
                                    0.0473692999679328,
                                    0.1301434005506447,
                                    0.2194809019024139,
                                    0.6030063975790086,
                                ],
                                [
                                    0.21655486603126187,
                                    0.7218653550849088,
                                    0.014210478915896644,
                                    0.04736929996793278,
                                ],
                                [
                                    0.38313637370283393,
                                    0.5552838474133367,
                                    0.025141671762902076,
                                    0.03643810712092734,
                                ],
                                [
                                    0.0473692999679328,
                                    0.15790112301858453,
                                    0.1833960449792257,
                                    0.611333532034257,
                                ],
                                [
                                    0.08380740708886017,
                                    0.12146301589765715,
                                    0.3244706383768758,
                                    0.4702589386366069,
                                ],
                                [
                                    0.09062779641185499,
                                    0.8985469834806651,
                                    0.0009918023224579236,
                                    0.00983341778502197,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.0327787768115006,
                                    0.08831351862262532,
                                    0.8756016244541865,
                                ],
                                [
                                    0.045918274708210145,
                                    0.9329390969859458,
                                    0.0009918023224579234,
                                    0.020150825983386036,
                                ],
                                [
                                    0.2612082872388625,
                                    0.7176490844552935,
                                    0.0056419146314841675,
                                    0.015500713674359795,
                                ],
                                [
                                    0.0033060801116875918,
                                    0.0671708903167813,
                                    0.04360399691898048,
                                    0.8859190326525506,
                                ],
                                [
                                    0.01880679378604738,
                                    0.05167017664242152,
                                    0.2480434080842993,
                                    0.6814796214872317,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.4552388641864047,
                                    0.021306097298261252,
                                    0.5000516141099505,
                                    0.02340342440538356,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889516,
                                    0.4552388641864047,
                                    0.02240637496177286,
                                ],
                                [
                                    0.5035056640433382,
                                    0.018849096808484168,
                                    0.46040947903347357,
                                    0.017235760114703968,
                                ],
                                [
                                    0.4552388641864047,
                                    0.02240637496177286,
                                    0.49785105878292724,
                                    0.02450370206889516,
                                ],
                                [
                                    0.46040947903347357,
                                    0.017235760114703968,
                                    0.5035056640433382,
                                    0.018849096808484168,
                                ],
                                [
                                    0.4800353306655652,
                                    0.13534734180801405,
                                    0.3000245444947562,
                                    0.08459278303166452,
                                ],
                                [
                                    0.3000245444947563,
                                    0.08459278303166454,
                                    0.4800353306655651,
                                    0.13534734180801403,
                                ],
                                [
                                    0.4692101105580853,
                                    0.140759951861754,
                                    0.3000245444947562,
                                    0.09000539308540446,
                                ],
                                [
                                    0.5016926294042084,
                                    0.10827743301563089,
                                    0.3207946700772142,
                                    0.06923526750294651,
                                ],
                                [
                                    0.3000245444947563,
                                    0.09000539308540448,
                                    0.4692101105580852,
                                    0.14075995186175397,
                                ],
                                [
                                    0.3207946700772143,
                                    0.06923526750294652,
                                    0.5016926294042083,
                                    0.10827743301563088,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1308637596288335,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.3574087211134995,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.4543200922129159,
                                    0.28395238852941707,
                                    0.1610625802606633,
                                    0.10066493899700371,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.1610625802606633,
                                    0.10066493899700371,
                                    0.4543200922129159,
                                    0.28395238852941707,
                                ],
                                [
                                    0.23606031242843198,
                                    0.6485570150979888,
                                    0.030789889441914717,
                                    0.08459278303166454,
                                ],
                                [
                                    0.030789889441914717,
                                    0.08459278303166454,
                                    0.23606031242843198,
                                    0.6485570150979888,
                                ],
                                [
                                    0.1999754555052438,
                                    0.6665994435595829,
                                    0.030789889441914717,
                                    0.10263521149325863,
                                ],
                                [
                                    0.3538035060398549,
                                    0.5127713930249718,
                                    0.05447453942588112,
                                    0.07895056150929224,
                                ],
                                [
                                    0.030789889441914717,
                                    0.10263521149325863,
                                    0.1999754555052438,
                                    0.6665994435595829,
                                ],
                                [
                                    0.05447453942588112,
                                    0.07895056150929224,
                                    0.3538035060398549,
                                    0.5127713930249718,
                                ],
                                [
                                    0.08947065751724015,
                                    0.8870743039674258,
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                    0.08947065751724015,
                                    0.8870743039674258,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                ],
                                [
                                    0.2546258476615809,
                                    0.6995643529712626,
                                    0.01222435420876578,
                                    0.033585445158390674,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.01222435420876578,
                                    0.033585445158390674,
                                    0.2546258476615809,
                                    0.6995643529712626,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.21010670705465664,
                                    0.009833417785021961,
                                    0.7451837712416985,
                                    0.03487610391862285,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260083,
                                    0.7003710213181527,
                                    0.034471520229407936,
                                ],
                                [
                                    0.25558928950206683,
                                    0.009568168950372475,
                                    0.708325853574745,
                                    0.02651668797281566,
                                ],
                                [
                                    0.2101067070546567,
                                    0.01034122969413778,
                                    0.7429832159146752,
                                    0.036568847336530236,
                                ],
                                [
                                    0.21249310449220218,
                                    0.007954832256592277,
                                    0.7514220385846097,
                                    0.02813002466659586,
                                ],
                                [
                                    0.318481321176702,
                                    0.08979672428903393,
                                    0.46157855398361936,
                                    0.13014340055064463,
                                ],
                                [
                                    0.13847053500589307,
                                    0.039042165512684406,
                                    0.6415893401544284,
                                    0.18089795932699415,
                                ],
                                [
                                    0.30765610106922214,
                                    0.09229480994126545,
                                    0.46157855398361936,
                                    0.138470535005893,
                                ],
                                [
                                    0.32895454472215074,
                                    0.07099636628833689,
                                    0.4935327547592719,
                                    0.10651633423024051,
                                ],
                                [
                                    0.13847053500589315,
                                    0.04154025116491595,
                                    0.6307641200469484,
                                    0.1892250937822425,
                                ],
                                [
                                    0.14805658539515662,
                                    0.031954200775652516,
                                    0.674430714086266,
                                    0.1455584997429249,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.060397641263659596,
                                    0.054985031209919655,
                                    0.46305739725167444,
                                    0.4215599302747463,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.3675928357361154,
                                    0.22974740827586979,
                                    0.24778983673746388,
                                    0.15486991925055096,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.07433532378386273,
                                    0.04645995874345646,
                                    0.5410473486897165,
                                    0.3381573687829643,
                                ],
                                [
                                    0.2194809019024139,
                                    0.6030063975790086,
                                    0.04736929996793279,
                                    0.13014340055064466,
                                ],
                                [
                                    0.014210478915896638,
                                    0.039042165512684385,
                                    0.25263972295445003,
                                    0.694107632616969,
                                ],
                                [
                                    0.18339604497922574,
                                    0.6113335320342571,
                                    0.04736929996793279,
                                    0.15790112301858447,
                                ],
                                [
                                    0.32447063837687584,
                                    0.47025893863660695,
                                    0.08380740708886016,
                                    0.12146301589765711,
                                ],
                                [
                                    0.014210478915896657,
                                    0.04736929996793283,
                                    0.21655486603126184,
                                    0.7218653550849087,
                                ],
                                [
                                    0.025141671762902103,
                                    0.036438107120927384,
                                    0.3831363737028339,
                                    0.5552838474133366,
                                ],
                                [
                                    0.08831351862262532,
                                    0.8756016244541865,
                                    0.003306080111687594,
                                    0.032778776811500585,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.00983341778502196,
                                    0.09062779641185499,
                                    0.8985469834806651,
                                ],
                                [
                                    0.04360399691898048,
                                    0.8859190326525506,
                                    0.003306080111687594,
                                    0.06717089031678135,
                                ],
                                [
                                    0.2480434080842993,
                                    0.6814796214872317,
                                    0.018806793786047393,
                                    0.05167017664242155,
                                ],
                                [
                                    0.000991802322457926,
                                    0.02015082598338609,
                                    0.045918274708210145,
                                    0.9329390969859458,
                                ],
                                [
                                    0.005641914631484181,
                                    0.015500713674359833,
                                    0.2612082872388625,
                                    0.7176490844552935,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08532277496919871,
                                    0.0041994966579918976,
                                    0.8677671480001332,
                                    0.04271058037267612,
                                ],
                                [
                                    0.08629187326408466,
                                    0.0032303983631059583,
                                    0.8776232698127272,
                                    0.03285445856008218,
                                ],
                                [
                                    0.042710580372676187,
                                    0.002102169550869595,
                                    0.9103793425966558,
                                    0.044807907479798424,
                                ],
                                [
                                    0.043195688254220016,
                                    0.0016170616693257595,
                                    0.9207194548225918,
                                    0.03446779525386238,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.19733391505000927,
                                    0.05919887862197328,
                                    0.5719007400028322,
                                    0.17156646632518516,
                                ],
                                [
                                    0.21099496469569393,
                                    0.04553782897628865,
                                    0.6114923347857287,
                                    0.13197487154228876,
                                ],
                                [
                                    0.02814834898668019,
                                    0.008444319845623754,
                                    0.7410863060661613,
                                    0.2223210251015347,
                                ],
                                [
                                    0.030097005368699692,
                                    0.006495663463604251,
                                    0.7923902941127229,
                                    0.17101703705497315,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.30836842804582437,
                                    0.19273184961768722,
                                    0.3070142444277549,
                                    0.19188547790873353,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.015110916093571757,
                                    0.009444400085273898,
                                    0.6002717563800075,
                                    0.37517292744114683,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.17207427823430102,
                                    0.5735934834207397,
                                    0.05869106671285748,
                                    0.1956411716321019,
                                ],
                                [
                                    0.30443977629533026,
                                    0.4412279853597104,
                                    0.10383826917040573,
                                    0.15049396917455365,
                                ],
                                [
                                    0.002888712170971964,
                                    0.009629251354415402,
                                    0.22787663277618653,
                                    0.7596054036984261,
                                ],
                                [
                                    0.005110809681356528,
                                    0.007407153844030838,
                                    0.40316723578437946,
                                    0.5843148006902332,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.0019989413309687114,
                                    0.09141798473825839,
                                    0.9063814599347184,
                                ],
                                [
                                    0.04281380859257708,
                                    0.8698644751072555,
                                    0.004096268438090997,
                                    0.0832254478620764,
                                ],
                                [
                                    0.2435483842479819,
                                    0.6691298994518508,
                                    0.023301817622364815,
                                    0.06401989867780258,
                                ],
                                [
                                    0.0002016139960545219,
                                    0.004096268438091006,
                                    0.046708463034613554,
                                    0.948993654531241,
                                ],
                                [
                                    0.0011468907951667513,
                                    0.0031509916389787767,
                                    0.2657033110751799,
                                    0.7299988064906745,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.8677671480001333,
                                    0.040613253265553824,
                                    0.08752333029622184,
                                    0.004096268438090988,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979843,
                                    0.042710580372676124,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.9124812849881163,
                                    0.04270596508833804,
                                    0.042809193308238944,
                                    0.002003556615306775,
                                ],
                                [
                                    0.8677671480001333,
                                    0.042710580372676124,
                                    0.08532277496919864,
                                    0.004199496657991894,
                                ],
                                [
                                    0.8697707046154401,
                                    0.04070702375736935,
                                    0.08551977368091507,
                                    0.0040024979462754615,
                                ],
                                [
                                    0.7519115261736411,
                                    0.2120036169031706,
                                    0.028148348986680196,
                                    0.007936507936507938,
                                ],
                                [
                                    0.5719007400028323,
                                    0.1612490581268211,
                                    0.2081591351574891,
                                    0.058691066712857454,
                                ],
                                [
                                    0.7410863060661613,
                                    0.2223210251015347,
                                    0.0281483489866802,
                                    0.008444319845623756,
                                ],
                                [
                                    0.7515154024792113,
                                    0.2118919286884846,
                                    0.028544472681110006,
                                    0.008048196151193947,
                                ],
                                [
                                    0.5719007400028322,
                                    0.17156646632518516,
                                    0.19733391505000922,
                                    0.05919887862197327,
                                ],
                                [
                                    0.5799489361540262,
                                    0.1635182701739912,
                                    0.20011093900629515,
                                    0.05642185466568733,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.2494498611682442,
                                    0.22709510031642177,
                                    0.27400517734708985,
                                    0.2494498611682442,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    0.5106014345391802,
                                    0.4648432492819742,
                                    0.012853603976153835,
                                    0.011701712202691778,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.261151573370936,
                                    0.2377481489655524,
                                    0.26230346514439806,
                                    0.23879681251911355,
                                ],
                                [
                                    0.2639614896993748,
                                    0.7252132901931454,
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                ],
                                [
                                    0.058691066712857495,
                                    0.16124905812682114,
                                    0.2081591351574892,
                                    0.5719007400028322,
                                ],
                                [
                                    0.22787663277618656,
                                    0.7596054036984262,
                                    0.0028887121709719426,
                                    0.00962925135441533,
                                ],
                                [
                                    0.2635097807765915,
                                    0.7239722556980213,
                                    0.0033404210937552307,
                                    0.009177542431632043,
                                ],
                                [
                                    0.058691066712857495,
                                    0.19564117163210193,
                                    0.172074278234301,
                                    0.5735934834207396,
                                ],
                                [
                                    0.06786860914448956,
                                    0.18646362920046988,
                                    0.19898159272585714,
                                    0.5466861689291834,
                                ],
                                [
                                    0.09141798473825839,
                                    0.9063814599347184,
                                    0.00020161399605452118,
                                    0.0019989413309686884,
                                ],
                                [
                                    0.004096268438090994,
                                    0.040613253265553845,
                                    0.08752333029622192,
                                    0.8677671480001332,
                                ],
                                [
                                    0.046708463034613554,
                                    0.948993654531241,
                                    0.00020161399605452123,
                                    0.0040962684380909916,
                                ],
                                [
                                    0.09122582847028925,
                                    0.9044762890955652,
                                    0.000393770264023664,
                                    0.0039041121701218493,
                                ],
                                [
                                    0.004096268438090996,
                                    0.08322544786207639,
                                    0.04281380859257708,
                                    0.8698644751072555,
                                ],
                                [
                                    0.008000380608212848,
                                    0.07932133569195454,
                                    0.08361921812610007,
                                    0.8290590655737325,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7003710213181529,
                                    0.03277877681150055,
                                    0.25491945697820234,
                                    0.01193074489214426,
                                ],
                                [
                                    0.7429832159146753,
                                    0.03656884733653024,
                                    0.2101067070546566,
                                    0.010341229694137775,
                                ],
                                [
                                    0.7446986633601548,
                                    0.03485339989105087,
                                    0.2105918149362004,
                                    0.00985612181259394,
                                ],
                                [
                                    0.7003710213181528,
                                    0.03447152022940794,
                                    0.2527189016511791,
                                    0.012438556801260077,
                                ],
                                [
                                    0.7019880829874786,
                                    0.032854458560082185,
                                    0.25330239530887655,
                                    0.011855063143562628,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.46157855398361947,
                                    0.13014340055064466,
                                    0.3184813211767019,
                                    0.0897967242890339,
                                ],
                                [
                                    0.6307641200469485,
                                    0.18922509378224256,
                                    0.13847053500589301,
                                    0.0415402511649159,
                                ],
                                [
                                    0.6396406837724089,
                                    0.18034853005678217,
                                    0.1404191913879125,
                                    0.0395915947828964,
                                ],
                                [
                                    0.4615785539836194,
                                    0.13847053500589301,
                                    0.3076561010692221,
                                    0.09229480994126542,
                                ],
                                [
                                    0.46807421744722366,
                                    0.13197487154228876,
                                    0.3119856577130977,
                                    0.0879652532973898,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.20132987799400742,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.29325751195225264,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.46022413924752553,
                                    0.4189805782251553,
                                    0.0632308992678085,
                                    0.05756438325951065,
                                ],
                                [
                                    0.20132987799400742,
                                    0.20132987799400742,
                                    0.2986701220059926,
                                    0.2986701220059926,
                                ],
                                [
                                    0.2107742780792813,
                                    0.19188547790873353,
                                    0.3126807604360527,
                                    0.28465948357593246,
                                ],
                                [
                                    0.25263972295445003,
                                    0.694107632616969,
                                    0.014210478915896644,
                                    0.0390421655126844,
                                ],
                                [
                                    0.0473692999679328,
                                    0.1301434005506447,
                                    0.2194809019024139,
                                    0.6030063975790086,
                                ],
                                [
                                    0.21655486603126187,
                                    0.7218653550849088,
                                    0.014210478915896644,
                                    0.04736929996793278,
                                ],
                                [
                                    0.25041762544406554,
                                    0.6880025956721051,
                                    0.016432576426281195,
                                    0.045147202457548226,
                                ],
                                [
                                    0.0473692999679328,
                                    0.15790112301858453,
                                    0.1833960449792257,
                                    0.611333532034257,
                                ],
                                [
                                    0.0547764538119636,
                                    0.1504939691745537,
                                    0.21207374805838308,
                                    0.5826558289550996,
                                ],
                                [
                                    0.09062779641185499,
                                    0.8985469834806651,
                                    0.0009918023224579236,
                                    0.00983341778502197,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.0327787768115006,
                                    0.08831351862262532,
                                    0.8756016244541865,
                                ],
                                [
                                    0.045918274708210145,
                                    0.9329390969859458,
                                    0.0009918023224579234,
                                    0.020150825983386036,
                                ],
                                [
                                    0.08968251961274276,
                                    0.8891748520814132,
                                    0.0019370791215701498,
                                    0.01920554918427381,
                                ],
                                [
                                    0.0033060801116875918,
                                    0.0671708903167813,
                                    0.04360399691898048,
                                    0.8859190326525506,
                                ],
                                [
                                    0.006457071750666358,
                                    0.06401989867780254,
                                    0.08516252698364656,
                                    0.8443605025878845,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.4552388641864047,
                                    0.021306097298261252,
                                    0.5000516141099505,
                                    0.02340342440538356,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889516,
                                    0.4552388641864047,
                                    0.02240637496177286,
                                ],
                                [
                                    0.49900052933451566,
                                    0.02335423151730675,
                                    0.4562899489618395,
                                    0.021355290186338062,
                                ],
                                [
                                    0.4552388641864047,
                                    0.02240637496177286,
                                    0.49785105878292724,
                                    0.02450370206889516,
                                ],
                                [
                                    0.4562899489618395,
                                    0.021355290186338062,
                                    0.49900052933451566,
                                    0.02335423151730675,
                                ],
                                [
                                    0.4800353306655652,
                                    0.13534734180801405,
                                    0.3000245444947562,
                                    0.08459278303166452,
                                ],
                                [
                                    0.3000245444947563,
                                    0.08459278303166454,
                                    0.4800353306655651,
                                    0.13534734180801403,
                                ],
                                [
                                    0.4692101105580853,
                                    0.140759951861754,
                                    0.3000245444947562,
                                    0.09000539308540446,
                                ],
                                [
                                    0.4758131707427533,
                                    0.13415689167708597,
                                    0.30424670441756807,
                                    0.08578323316259258,
                                ],
                                [
                                    0.3000245444947563,
                                    0.09000539308540448,
                                    0.4692101105580852,
                                    0.14075995186175397,
                                ],
                                [
                                    0.3042467044175682,
                                    0.0857832331625926,
                                    0.4758131707427532,
                                    0.13415689167708597,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1308637596288335,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.3574087211134995,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.3864524498417891,
                                    0.35182003090054387,
                                    0.13700258867354492,
                                    0.1247249305841221,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.13700258867354492,
                                    0.1247249305841221,
                                    0.3864524498417891,
                                    0.35182003090054387,
                                ],
                                [
                                    0.23606031242843198,
                                    0.6485570150979888,
                                    0.030789889441914717,
                                    0.08459278303166454,
                                ],
                                [
                                    0.030789889441914717,
                                    0.08459278303166454,
                                    0.23606031242843198,
                                    0.6485570150979888,
                                ],
                                [
                                    0.1999754555052438,
                                    0.6665994435595829,
                                    0.030789889441914717,
                                    0.10263521149325863,
                                ],
                                [
                                    0.2312456867512243,
                                    0.6353292123136024,
                                    0.03560451511912239,
                                    0.09782058581605095,
                                ],
                                [
                                    0.030789889441914717,
                                    0.10263521149325863,
                                    0.1999754555052438,
                                    0.6665994435595829,
                                ],
                                [
                                    0.03560451511912239,
                                    0.09782058581605095,
                                    0.2312456867512243,
                                    0.6353292123136024,
                                ],
                                [
                                    0.08947065751724015,
                                    0.8870743039674258,
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                    0.08947065751724015,
                                    0.8870743039674258,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                ],
                                [
                                    0.08742252329819465,
                                    0.8667676773346489,
                                    0.004197075436118256,
                                    0.0416127239310382,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.004197075436118256,
                                    0.0416127239310382,
                                    0.08742252329819465,
                                    0.8667676773346489,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.21010670705465664,
                                    0.009833417785021961,
                                    0.7451837712416985,
                                    0.03487610391862285,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260083,
                                    0.7003710213181527,
                                    0.034471520229407936,
                                ],
                                [
                                    0.25330239530887666,
                                    0.011855063143562633,
                                    0.7019880829874785,
                                    0.03285445856008218,
                                ],
                                [
                                    0.2101067070546567,
                                    0.01034122969413778,
                                    0.7429832159146752,
                                    0.036568847336530236,
                                ],
                                [
                                    0.21059181493620052,
                                    0.009856121812593946,
                                    0.7446986633601547,
                                    0.034853399891050865,
                                ],
                                [
                                    0.318481321176702,
                                    0.08979672428903393,
                                    0.46157855398361936,
                                    0.13014340055064463,
                                ],
                                [
                                    0.13847053500589307,
                                    0.039042165512684406,
                                    0.6415893401544284,
                                    0.18089795932699415,
                                ],
                                [
                                    0.30765610106922214,
                                    0.09229480994126545,
                                    0.46157855398361936,
                                    0.138470535005893,
                                ],
                                [
                                    0.3119856577130978,
                                    0.08796525329738981,
                                    0.4680742174472236,
                                    0.13197487154228874,
                                ],
                                [
                                    0.13847053500589315,
                                    0.04154025116491595,
                                    0.6307641200469484,
                                    0.1892250937822425,
                                ],
                                [
                                    0.14041919138791267,
                                    0.03959159478289644,
                                    0.6396406837724087,
                                    0.1803485300567821,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.060397641263659596,
                                    0.054985031209919655,
                                    0.46305739725167444,
                                    0.4215599302747463,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.3126807604360527,
                                    0.28465948357593246,
                                    0.2107742780792813,
                                    0.19188547790873353,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.06323089926780852,
                                    0.05756438325951067,
                                    0.46022413924752553,
                                    0.4189805782251553,
                                ],
                                [
                                    0.2194809019024139,
                                    0.6030063975790086,
                                    0.04736929996793279,
                                    0.13014340055064466,
                                ],
                                [
                                    0.014210478915896638,
                                    0.039042165512684385,
                                    0.25263972295445003,
                                    0.694107632616969,
                                ],
                                [
                                    0.18339604497922574,
                                    0.6113335320342571,
                                    0.04736929996793279,
                                    0.15790112301858447,
                                ],
                                [
                                    0.2120737480583831,
                                    0.5826558289550997,
                                    0.05477645381196359,
                                    0.15049396917455368,
                                ],
                                [
                                    0.014210478915896657,
                                    0.04736929996793283,
                                    0.21655486603126184,
                                    0.7218653550849087,
                                ],
                                [
                                    0.01643257642628121,
                                    0.045147202457548274,
                                    0.2504176254440655,
                                    0.6880025956721051,
                                ],
                                [
                                    0.08831351862262532,
                                    0.8756016244541865,
                                    0.003306080111687594,
                                    0.032778776811500585,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.00983341778502196,
                                    0.09062779641185499,
                                    0.8985469834806651,
                                ],
                                [
                                    0.04360399691898048,
                                    0.8859190326525506,
                                    0.003306080111687594,
                                    0.06717089031678135,
                                ],
                                [
                                    0.08516252698364656,
                                    0.8443605025878845,
                                    0.0064570717506663615,
                                    0.06401989867780258,
                                ],
                                [
                                    0.000991802322457926,
                                    0.02015082598338609,
                                    0.045918274708210145,
                                    0.9329390969859458,
                                ],
                                [
                                    0.0019370791215701545,
                                    0.01920554918427386,
                                    0.08968251961274276,
                                    0.8891748520814132,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08532277496919871,
                                    0.0041994966579918976,
                                    0.8677671480001332,
                                    0.04271058037267612,
                                ],
                                [
                                    0.08551977368091515,
                                    0.004002497946275465,
                                    0.86977070461544,
                                    0.04070702375736934,
                                ],
                                [
                                    0.042710580372676187,
                                    0.002102169550869595,
                                    0.9103793425966558,
                                    0.044807907479798424,
                                ],
                                [
                                    0.042809193308239,
                                    0.0020035566153067774,
                                    0.9124812849881162,
                                    0.04270596508833804,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.19733391505000927,
                                    0.05919887862197328,
                                    0.5719007400028322,
                                    0.17156646632518516,
                                ],
                                [
                                    0.2001109390062952,
                                    0.056421854665687346,
                                    0.5799489361540262,
                                    0.1635182701739912,
                                ],
                                [
                                    0.02814834898668019,
                                    0.008444319845623754,
                                    0.7410863060661613,
                                    0.2223210251015347,
                                ],
                                [
                                    0.028544472681109996,
                                    0.008048196151193943,
                                    0.7515154024792113,
                                    0.2118919286884846,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.26230346514439806,
                                    0.23879681251911355,
                                    0.261151573370936,
                                    0.2377481489655524,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.012853603976153857,
                                    0.011701712202691797,
                                    0.5106014345391802,
                                    0.4648432492819742,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.17207427823430102,
                                    0.5735934834207397,
                                    0.05869106671285748,
                                    0.1956411716321019,
                                ],
                                [
                                    0.19898159272585716,
                                    0.5466861689291835,
                                    0.06786860914448954,
                                    0.18646362920046985,
                                ],
                                [
                                    0.002888712170971964,
                                    0.009629251354415402,
                                    0.22787663277618653,
                                    0.7596054036984261,
                                ],
                                [
                                    0.0033404210937552554,
                                    0.00917754243163211,
                                    0.26350978077659143,
                                    0.7239722556980211,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.0019989413309687114,
                                    0.09141798473825839,
                                    0.9063814599347184,
                                ],
                                [
                                    0.04281380859257708,
                                    0.8698644751072555,
                                    0.004096268438090997,
                                    0.0832254478620764,
                                ],
                                [
                                    0.08361921812610007,
                                    0.8290590655737325,
                                    0.008000380608212848,
                                    0.07932133569195456,
                                ],
                                [
                                    0.0002016139960545219,
                                    0.004096268438091006,
                                    0.046708463034613554,
                                    0.948993654531241,
                                ],
                                [
                                    0.00039377026402366534,
                                    0.0039041121701218627,
                                    0.09122582847028925,
                                    0.9044762890955652,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                1.0383076481051436e-06,
                                1.0383076481051436e-06,
                                1.0383076481051436e-06,
                                1.0383076481051436e-06,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                5.032097903189948e-05,
                                5.032097903189948e-05,
                                5.032097903189948e-05,
                                5.032097903189948e-05,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                0.0005448680648497423,
                                0.0005448680648497423,
                                0.0005448680648497423,
                                0.0005448680648497423,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                0.000410349309969278,
                                0.000410349309969278,
                                0.000410349309969278,
                                0.000410349309969278,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.0975408048944257e-06,
                                2.0975408048944257e-06,
                                2.0975408048944257e-06,
                                2.0975408048944257e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                0.0001016561007272456,
                                0.0001016561007272456,
                                0.0001016561007272456,
                                0.0001016561007272456,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.001100717115386656,
                                0.001100717115386656,
                                0.001100717115386656,
                                0.001100717115386656,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                0.000828968585073613,
                                0.000828968585073613,
                                0.000828968585073613,
                                0.000828968585073613,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                1.0383076481051433e-06,
                                1.0383076481051433e-06,
                                1.0383076481051433e-06,
                                1.0383076481051433e-06,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                5.032097903189947e-05,
                                5.032097903189947e-05,
                                5.032097903189947e-05,
                                5.032097903189947e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.0005448680648497421,
                                0.0005448680648497421,
                                0.0005448680648497421,
                                0.0005448680648497421,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                0.00041034930996927796,
                                0.00041034930996927796,
                                0.00041034930996927796,
                                0.00041034930996927796,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0975408048944253e-06,
                                2.0975408048944253e-06,
                                2.0975408048944253e-06,
                                2.0975408048944253e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                0.00010165610072724557,
                                0.00010165610072724557,
                                0.00010165610072724557,
                                0.00010165610072724557,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0011007171153866557,
                                0.0011007171153866557,
                                0.0011007171153866557,
                                0.0011007171153866557,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.0008289685850736127,
                                0.0008289685850736127,
                                0.0008289685850736127,
                                0.0008289685850736127,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                2.4930969067325767e-06,
                                2.4930969067325767e-06,
                                2.4930969067325767e-06,
                                2.4930969067325767e-06,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                0.00012082649819360602,
                                0.00012082649819360602,
                                0.00012082649819360602,
                                0.00012082649819360602,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.000665593341842671,
                                0.000665593341842671,
                                0.000665593341842671,
                                0.000665593341842671,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                0.0013082913234177575,
                                0.0013082913234177575,
                                0.0013082913234177575,
                                0.0013082913234177575,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                0.0009852962146924848,
                                0.0009852962146924848,
                                0.0009852962146924848,
                                0.0009852962146924848,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0975408048944253e-06,
                                2.0975408048944253e-06,
                                2.0975408048944253e-06,
                                2.0975408048944253e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                0.00010165610072724557,
                                0.00010165610072724557,
                                0.00010165610072724557,
                                0.00010165610072724557,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0005599899427137674,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0011007171153866557,
                                0.0011007171153866557,
                                0.0011007171153866557,
                                0.0011007171153866557,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.0008289685850736127,
                                0.0008289685850736127,
                                0.0008289685850736127,
                                0.0008289685850736127,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                1.0383076481051433e-06,
                                1.0383076481051433e-06,
                                1.0383076481051433e-06,
                                1.0383076481051433e-06,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                5.032097903189947e-05,
                                5.032097903189947e-05,
                                5.032097903189947e-05,
                                5.032097903189947e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.000277201682572717,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.0005448680648497421,
                                0.0005448680648497421,
                                0.0005448680648497421,
                                0.0005448680648497421,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                0.00041034930996927796,
                                0.00041034930996927796,
                                0.00041034930996927796,
                                0.00041034930996927796,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.0975408048944257e-06,
                                2.0975408048944257e-06,
                                2.0975408048944257e-06,
                                2.0975408048944257e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                0.0001016561007272456,
                                0.0001016561007272456,
                                0.0001016561007272456,
                                0.0001016561007272456,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.0005599899427137675,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.001100717115386656,
                                0.001100717115386656,
                                0.001100717115386656,
                                0.001100717115386656,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                0.000828968585073613,
                                0.000828968585073613,
                                0.000828968585073613,
                                0.000828968585073613,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                1.764743847828731e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                8.552728887755485e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.00047114163593104703,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                0.0009260767433204515,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                0.0006974439816085382,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                1.0383076481051436e-06,
                                1.0383076481051436e-06,
                                1.0383076481051436e-06,
                                1.0383076481051436e-06,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                5.032097903189948e-05,
                                5.032097903189948e-05,
                                5.032097903189948e-05,
                                5.032097903189948e-05,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.0002772016825727171,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                0.0005448680648497423,
                                0.0005448680648497423,
                                0.0005448680648497423,
                                0.0005448680648497423,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                0.000410349309969278,
                                0.000410349309969278,
                                0.000410349309969278,
                                0.000410349309969278,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                8.735691958275385e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                4.233702531843374e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00023322071388861364,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                0.0004584190033768263,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                0.00034524306680436533,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                4.3242714280471235e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                2.0957331120127322e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                0.00011544702747238202,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                0.00022692285944199008,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                0.00017089942464136715,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.079410321456972e-06,
                                2.079410321456972e-06,
                                2.079410321456972e-06,
                                2.079410321456972e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                9.729589400942767e-05,
                                9.729589400942767e-05,
                                9.729589400942767e-05,
                                9.729589400942767e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.0009392173722238214,
                                0.0009392173722238214,
                                0.0009392173722238214,
                                0.0009392173722238214,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                0.0006769094277350739,
                                0.0006769094277350739,
                                0.0006769094277350739,
                                0.0006769094277350739,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.001596326563163303,
                                0.001596326563163303,
                                0.001596326563163303,
                                0.001596326563163303,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.001897363239595136,
                                0.001897363239595136,
                                0.001897363239595136,
                                0.001897363239595136,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.001596326563163303,
                                0.001596326563163303,
                                0.001596326563163303,
                                0.001596326563163303,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0794103214569717e-06,
                                2.0794103214569717e-06,
                                2.0794103214569717e-06,
                                2.0794103214569717e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                9.729589400942764e-05,
                                9.729589400942764e-05,
                                9.729589400942764e-05,
                                9.729589400942764e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0009392173722238212,
                                0.0009392173722238212,
                                0.0009392173722238212,
                                0.0009392173722238212,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.0006769094277350737,
                                0.0006769094277350737,
                                0.0006769094277350737,
                                0.0006769094277350737,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.001897363239595136,
                                0.001897363239595136,
                                0.001897363239595136,
                                0.001897363239595136,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.992904992766845e-06,
                                4.992904992766845e-06,
                                4.992904992766845e-06,
                                4.992904992766845e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00023361870909393632,
                                0.00023361870909393632,
                                0.00023361870909393632,
                                0.00023361870909393632,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.001218025925829118,
                                0.001218025925829118,
                                0.001218025925829118,
                                0.001218025925829118,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0022551696789616556,
                                0.0022551696789616556,
                                0.0022551696789616556,
                                0.0022551696789616556,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.0016253379270625744,
                                0.0016253379270625744,
                                0.0016253379270625744,
                                0.0016253379270625744,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.001897363239595136,
                                0.001897363239595136,
                                0.001897363239595136,
                                0.001897363239595136,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0794103214569717e-06,
                                2.0794103214569717e-06,
                                2.0794103214569717e-06,
                                2.0794103214569717e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                9.729589400942764e-05,
                                9.729589400942764e-05,
                                9.729589400942764e-05,
                                9.729589400942764e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0005072749602967512,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0009392173722238212,
                                0.0009392173722238212,
                                0.0009392173722238212,
                                0.0009392173722238212,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.0006769094277350737,
                                0.0006769094277350737,
                                0.0006769094277350737,
                                0.0006769094277350737,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.001596326563163303,
                                0.001596326563163303,
                                0.001596326563163303,
                                0.001596326563163303,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                4.200727989757574e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.00019655263852278912,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.001024773274535186,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.001897363239595136,
                                0.001897363239595136,
                                0.001897363239595136,
                                0.001897363239595136,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                0.0013674609336483208,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                3.5342382179305233e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00016536749072924715,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.0008621821932786175,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.001596326563163303,
                                0.001596326563163303,
                                0.001596326563163303,
                                0.001596326563163303,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                0.0011504988432982925,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                1.7494899566864236e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00042679044109767095,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                0.0007902006366399536,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                0.0005695106123062354,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.079410321456972e-06,
                                2.079410321456972e-06,
                                2.079410321456972e-06,
                                2.079410321456972e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                9.729589400942767e-05,
                                9.729589400942767e-05,
                                9.729589400942767e-05,
                                9.729589400942767e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.0005072749602967513,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.0009392173722238214,
                                0.0009392173722238214,
                                0.0009392173722238214,
                                0.0009392173722238214,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                0.0006769094277350739,
                                0.0006769094277350739,
                                0.0006769094277350739,
                                0.0006769094277350739,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                1.749489956686424e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                8.185887491269851e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.000426790441097671,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                0.0007902006366399537,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                0.0005695106123062355,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                8.660183382711737e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                4.05211167710347e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.0002112663449005865,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                0.00039115871436032145,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                0.0002819145272667869,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                2.4399905569807544e-06,
                                2.4399905569807544e-06,
                                2.4399905569807544e-06,
                                2.4399905569807544e-06,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                0.0008352393016764331,
                                0.0008352393016764331,
                                0.0008352393016764331,
                                0.0008352393016764331,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                2.381385910243316e-06,
                                2.381385910243316e-06,
                                2.439990556980755e-06,
                                2.439990556980755e-06,
                                2.439990556980755e-06,
                                2.439990556980755e-06,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0003132104529203512,
                                0.0003132104529203512,
                                0.0008352393016764332,
                                0.0008352393016764332,
                                0.0008352393016764332,
                                0.0008352393016764332,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                5.717983352428262e-06,
                                5.717983352428262e-06,
                                5.858699896092274e-06,
                                5.858699896092274e-06,
                                5.858699896092274e-06,
                                5.858699896092274e-06,
                                0.00022561143211105526,
                                0.00022561143211105526,
                                0.00025945240613188487,
                                0.00025945240613188487,
                                0.00025945240613188487,
                                0.00025945240613188487,
                                0.000818276043286085,
                                0.000818276043286085,
                                0.0012274140649291276,
                                0.0012274140649291276,
                                0.0012274140649291276,
                                0.0012274140649291276,
                                0.0007520545695267414,
                                0.0007520545695267414,
                                0.0020055062901550807,
                                0.0020055062901550807,
                                0.0020055062901550807,
                                0.0020055062901550807,
                                0.00011617444817545152,
                                0.00011617444817545152,
                                0.0012963547300172188,
                                0.0012963547300172188,
                                0.0012963547300172188,
                                0.0012963547300172188,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                2.381385910243316e-06,
                                2.381385910243316e-06,
                                2.439990556980755e-06,
                                2.439990556980755e-06,
                                2.439990556980755e-06,
                                2.439990556980755e-06,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0003132104529203512,
                                0.0003132104529203512,
                                0.0008352393016764332,
                                0.0008352393016764332,
                                0.0008352393016764332,
                                0.0008352393016764332,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                4.929155406072807e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.00021828754723493958,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0010326718864146988,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                0.0016873115789092538,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                0.0010906743883424522,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                4.147092946921976e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.00018365392708528136,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0008688276071309878,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                0.0014196018124186917,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                0.0009176274007735381,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                2.4399905569807544e-06,
                                2.4399905569807544e-06,
                                2.4399905569807544e-06,
                                2.4399905569807544e-06,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.00010805493235282181,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.0005111848671289691,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                0.0008352393016764331,
                                0.0008352393016764331,
                                0.0008352393016764331,
                                0.0008352393016764331,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                0.0005398967955073307,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                2.0528603372789757e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                9.091087842116608e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.00043008000000000044,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                0.0007027197829281037,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                0.00045423647831345244,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                1.0161902851733789e-06,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                4.500196617886757e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.0002128947156856559,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                0.00034785465121178456,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                0.0002248524597856119,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.02631035310098e-06,
                                2.02631035310098e-06,
                                2.02631035310098e-06,
                                2.02631035310098e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                8.452586283290457e-05,
                                8.452586283290457e-05,
                                8.452586283290457e-05,
                                8.452586283290457e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00046622219363238646,
                                0.00046622219363238646,
                                0.00046622219363238646,
                                0.00046622219363238646,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                0.0002315635288918312,
                                0.0002315635288918312,
                                0.0002315635288918312,
                                0.0002315635288918312,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0263103531009796e-06,
                                2.0263103531009796e-06,
                                2.0263103531009796e-06,
                                2.0263103531009796e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                8.452586283290454e-05,
                                8.452586283290454e-05,
                                8.452586283290454e-05,
                                8.452586283290454e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00046622219363238635,
                                0.00046622219363238635,
                                0.00046622219363238635,
                                0.00046622219363238635,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00023156352889183113,
                                0.00023156352889183113,
                                0.00023156352889183113,
                                0.00023156352889183113,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.8654058193787695e-06,
                                4.8654058193787695e-06,
                                4.8654058193787695e-06,
                                4.8654058193787695e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.0002029563853759429,
                                0.0002029563853759429,
                                0.0002029563853759429,
                                0.0002029563853759429,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0008473178470002798,
                                0.0008473178470002798,
                                0.0008473178470002798,
                                0.0008473178470002798,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.001119453478856852,
                                0.001119453478856852,
                                0.001119453478856852,
                                0.001119453478856852,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.0005560108496223299,
                                0.0005560108496223299,
                                0.0005560108496223299,
                                0.0005560108496223299,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0263103531009796e-06,
                                2.0263103531009796e-06,
                                2.0263103531009796e-06,
                                2.0263103531009796e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                8.452586283290454e-05,
                                8.452586283290454e-05,
                                8.452586283290454e-05,
                                8.452586283290454e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.00035288503970324963,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00046622219363238635,
                                0.00046622219363238635,
                                0.00046622219363238635,
                                0.00046622219363238635,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00023156352889183113,
                                0.00023156352889183113,
                                0.00023156352889183113,
                                0.00023156352889183113,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                4.093457904086378e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.00017075521564777362,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0007128819397267897,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                0.0009418403852422477,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                0.00046779386789875556,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                3.443987661992551e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.0001436631009017457,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.0005997757061152312,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                0.0007924074809960879,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                0.0003935734401447729,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                1.704814857991095e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                0.00039225112856642653,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                0.0001948235343216305,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.02631035310098e-06,
                                2.02631035310098e-06,
                                2.02631035310098e-06,
                                2.02631035310098e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                8.452586283290457e-05,
                                8.452586283290457e-05,
                                8.452586283290457e-05,
                                8.452586283290457e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.0003528850397032497,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00046622219363238646,
                                0.00046622219363238646,
                                0.00046622219363238646,
                                0.00046622219363238646,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                0.0002315635288918312,
                                0.0002315635288918312,
                                0.0002315635288918312,
                                0.0002315635288918312,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                1.7048148579910954e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                7.111494378021954e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.00029689610869737147,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                0.0003922511285664266,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                0.00019482353432163053,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                8.439036330187309e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                3.520274306429322e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00014696710530437225,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                0.00019416897436180935,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                9.643996686262584e-05,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                9.940729222416146e-07,
                                9.940729222416146e-07,
                                9.940729222416146e-07,
                                9.940729222416146e-07,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                3.968295332583568e-05,
                                3.968295332583568e-05,
                                3.968295332583568e-05,
                                3.968295332583568e-05,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                0.00015084123757382707,
                                0.00015084123757382707,
                                0.00015084123757382707,
                                0.00015084123757382707,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                3.935560960194581e-05,
                                3.935560960194581e-05,
                                3.935560960194581e-05,
                                3.935560960194581e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.0081798696635265e-06,
                                2.0081798696635265e-06,
                                2.0081798696635265e-06,
                                2.0081798696635265e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                8.016565611508661e-05,
                                8.016565611508661e-05,
                                8.016565611508661e-05,
                                8.016565611508661e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.0003047224504695519,
                                0.0003047224504695519,
                                0.0003047224504695519,
                                0.0003047224504695519,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                7.950437155329211e-05,
                                7.950437155329211e-05,
                                7.950437155329211e-05,
                                7.950437155329211e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.940729222416144e-07,
                                9.940729222416144e-07,
                                9.940729222416144e-07,
                                9.940729222416144e-07,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.9682953325835676e-05,
                                3.9682953325835676e-05,
                                3.9682953325835676e-05,
                                3.9682953325835676e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.000150841237573827,
                                0.000150841237573827,
                                0.000150841237573827,
                                0.000150841237573827,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                3.9355609601945805e-05,
                                3.9355609601945805e-05,
                                3.9355609601945805e-05,
                                3.9355609601945805e-05,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.008179869663526e-06,
                                2.008179869663526e-06,
                                2.008179869663526e-06,
                                2.008179869663526e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                8.01656561150866e-05,
                                8.01656561150866e-05,
                                8.01656561150866e-05,
                                8.01656561150866e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00030472245046955185,
                                0.00030472245046955185,
                                0.00030472245046955185,
                                0.00030472245046955185,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                7.95043715532921e-05,
                                7.95043715532921e-05,
                                7.95043715532921e-05,
                                7.95043715532921e-05,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                2.386884207228932e-06,
                                2.386884207228932e-06,
                                2.386884207228932e-06,
                                2.386884207228932e-06,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                9.528336651203759e-05,
                                9.528336651203759e-05,
                                9.528336651203759e-05,
                                9.528336651203759e-05,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003567763924152672,
                                0.0003567763924152672,
                                0.0003567763924152672,
                                0.0003567763924152672,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                0.0003621872799351087,
                                0.0003621872799351087,
                                0.0003621872799351087,
                                0.0003621872799351087,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                9.449737632217674e-05,
                                9.449737632217674e-05,
                                9.449737632217674e-05,
                                9.449737632217674e-05,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.008179869663526e-06,
                                2.008179869663526e-06,
                                2.008179869663526e-06,
                                2.008179869663526e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                8.01656561150866e-05,
                                8.01656561150866e-05,
                                8.01656561150866e-05,
                                8.01656561150866e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0003001700572862335,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00030472245046955185,
                                0.00030472245046955185,
                                0.00030472245046955185,
                                0.00030472245046955185,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                7.95043715532921e-05,
                                7.95043715532921e-05,
                                7.95043715532921e-05,
                                7.95043715532921e-05,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.940729222416144e-07,
                                9.940729222416144e-07,
                                9.940729222416144e-07,
                                9.940729222416144e-07,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.9682953325835676e-05,
                                3.9682953325835676e-05,
                                3.9682953325835676e-05,
                                3.9682953325835676e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.0001485877487985948,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.000150841237573827,
                                0.000150841237573827,
                                0.000150841237573827,
                                0.000150841237573827,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                3.9355609601945805e-05,
                                3.9355609601945805e-05,
                                3.9355609601945805e-05,
                                3.9355609601945805e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.0081798696635265e-06,
                                2.0081798696635265e-06,
                                2.0081798696635265e-06,
                                2.0081798696635265e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                8.016565611508661e-05,
                                8.016565611508661e-05,
                                8.016565611508661e-05,
                                8.016565611508661e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00030017005728623353,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.0003047224504695519,
                                0.0003047224504695519,
                                0.0003047224504695519,
                                0.0003047224504695519,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                7.950437155329211e-05,
                                7.950437155329211e-05,
                                7.950437155329211e-05,
                                7.950437155329211e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                1.6895609668487884e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                6.744652981536319e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.00025254491386399544,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                0.0002563750218859287,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                6.689016501932781e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                9.940729222416146e-07,
                                9.940729222416146e-07,
                                9.940729222416146e-07,
                                9.940729222416146e-07,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                3.968295332583568e-05,
                                3.968295332583568e-05,
                                3.968295332583568e-05,
                                3.968295332583568e-05,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00014858774879859482,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                0.00015084123757382707,
                                0.00015084123757382707,
                                0.00015084123757382707,
                                0.00015084123757382707,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                3.935560960194581e-05,
                                3.935560960194581e-05,
                                3.935560960194581e-05,
                                3.935560960194581e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                8.36352775462366e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                3.3386834516894175e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.0001250127363163451,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                0.00012690868534530447,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                3.3111427325047406e-05,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                4.1400457204466483e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                1.6526880213258513e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                6.188279146938743e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                6.282130879052488e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                                1.6390550377400058e-05,
                            ]
                        ),
                    )
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.VertexAdjacentQuadrilaterals:
            match order:
                case 1:
                    return (
                        np.array(
                            [
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                            ]
                        ),
                        np.array(
                            [
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                            ]
                        ),
                        np.array([0.125, 0.125, 0.125, 0.125]),
                    )
                case 2:
                    return (
                        np.array(
                            [
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.9126779572375282,
                                    0.042663844023951264,
                                    0.042663844023951264,
                                    0.00199435471456919,
                                ],
                                [
                                    0.9126779572375282,
                                    0.042663844023951264,
                                    0.042663844023951264,
                                    0.00199435471456919,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.9126779572375282,
                                    0.042663844023951264,
                                    0.042663844023951264,
                                    0.00199435471456919,
                                ],
                                [
                                    0.9126779572375282,
                                    0.042663844023951264,
                                    0.042663844023951264,
                                    0.00199435471456919,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.14287759831802727,
                                    0.2351139337538265,
                                    0.2351139337538265,
                                    0.38689453417431974,
                                ],
                                [
                                    0.14287759831802727,
                                    0.2351139337538265,
                                    0.2351139337538265,
                                    0.38689453417431974,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.14287759831802727,
                                    0.2351139337538265,
                                    0.2351139337538265,
                                    0.38689453417431974,
                                ],
                                [
                                    0.14287759831802727,
                                    0.2351139337538265,
                                    0.2351139337538265,
                                    0.38689453417431974,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.9126779572375282,
                                    0.042663844023951264,
                                    0.042663844023951264,
                                    0.00199435471456919,
                                ],
                                [
                                    0.9126779572375282,
                                    0.042663844023951264,
                                    0.042663844023951264,
                                    0.00199435471456919,
                                ],
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.14287759831802727,
                                    0.2351139337538265,
                                    0.2351139337538265,
                                    0.38689453417431974,
                                ],
                                [
                                    0.14287759831802727,
                                    0.2351139337538265,
                                    0.2351139337538265,
                                    0.38689453417431974,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.9126779572375282,
                                    0.042663844023951264,
                                    0.042663844023951264,
                                    0.00199435471456919,
                                ],
                                [
                                    0.9126779572375282,
                                    0.042663844023951264,
                                    0.042663844023951264,
                                    0.00199435471456919,
                                ],
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.14287759831802727,
                                    0.2351139337538265,
                                    0.2351139337538265,
                                    0.38689453417431974,
                                ],
                                [
                                    0.14287759831802727,
                                    0.2351139337538265,
                                    0.2351139337538265,
                                    0.38689453417431974,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.0005898367398534958,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                                0.030660163260146506,
                            ]
                        ),
                    )
                case 3:
                    return (
                        np.array(
                            [
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                2.1818302718068596e-05,
                                2.1818302718068596e-05,
                                2.1818302718068596e-05,
                                2.1818302718068596e-05,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                3.490928434890974e-05,
                                3.490928434890974e-05,
                                3.490928434890974e-05,
                                3.490928434890974e-05,
                                0.004877305288827922,
                                0.004877305288827922,
                                0.004877305288827922,
                                0.004877305288827922,
                                0.017035659226548823,
                                0.017035659226548823,
                                0.017035659226548823,
                                0.017035659226548823,
                                2.1818302718068596e-05,
                                2.1818302718068596e-05,
                                2.1818302718068596e-05,
                                2.1818302718068596e-05,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                2.1818302718068593e-05,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                0.010647287016593017,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                1.3636439198792873e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                0.006654554385370637,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                8.522774499245549e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                                0.00415909649085665,
                            ]
                        ),
                    )
                case 4:
                    return (
                        np.array(
                            [
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                2.0183059142488954e-06,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.00040629019883990864,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.003399876033455111,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                0.004859095679100511,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                1.0765662920382115e-06,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.00021671557803432592,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0018134971061056799,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                0.0025918462513423684,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                5.742414829043489e-07,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.00011559629520193758,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0009673210792075479,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                0.0013824932527035615,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                3.063009525069556e-07,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                6.165917367646267e-05,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.0005159699825982119,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                                0.000737423214351924,
                            ]
                        ),
                    )
                case 5:
                    return (
                        np.array(
                            [
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                1.1720929347487812e-07,
                                1.1720929347487812e-07,
                                1.1720929347487812e-07,
                                1.1720929347487812e-07,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.001044057697512164,
                                0.001044057697512164,
                                0.001044057697512164,
                                0.001044057697512164,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                2.8143308732802344e-07,
                                2.8143308732802344e-07,
                                2.8143308732802344e-07,
                                2.8143308732802344e-07,
                                6.768194804165923e-05,
                                6.768194804165923e-05,
                                6.768194804165923e-05,
                                6.768194804165923e-05,
                                0.000818276043286085,
                                0.000818276043286085,
                                0.000818276043286085,
                                0.000818276043286085,
                                0.0025069034412566783,
                                0.0025069034412566783,
                                0.0025069034412566783,
                                0.0025069034412566783,
                                0.002360360563683535,
                                0.002360360563683535,
                                0.002360360563683535,
                                0.002360360563683535,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                1.1720929347487812e-07,
                                1.1720929347487812e-07,
                                1.1720929347487812e-07,
                                1.1720929347487812e-07,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.001044057697512164,
                                0.001044057697512164,
                                0.001044057697512164,
                                0.001044057697512164,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                2.367807616799013e-07,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                5.694349360778883e-05,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.0021091567871935014,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                0.001985864481729465,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                1.9921299813752063e-07,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                4.7908808154641816e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.001774516832102004,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                0.0016707861504177304,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                1.6760575625054447e-07,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                4.030757077546653e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014929710330370237,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                0.0014056983173376424,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                8.296684296930565e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                0.0006958373874846587,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                1.1720929347487811e-07,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                2.8187706663360667e-05,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0010440576975121638,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                0.0009830265397787307,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                9.861280366298015e-08,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                2.3715429898905068e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008784069392898217,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                0.0008270590180076121,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                4.881451078588994e-08,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                1.1739419888603266e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.0004348218833621967,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                0.00040940405155782223,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                9.861280366298018e-08,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                2.371542989890507e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008784069392898218,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                0.0008270590180076123,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                8.296684296930566e-08,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                1.9952726981543877e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0007390384198412779,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                0.0006958373874846588,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                4.8814510785889953e-08,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                1.173941988860327e-05,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.00043482188336219687,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                0.0004094040515578223,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                4.106957413803658e-08,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                9.876837188172655e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00036583280848420083,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                0.00034444778360304097,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                2.0329927709840623e-08,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                4.889151890461143e-06,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001810915916823123,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                                0.0001705057499970323,
                            ]
                        ),
                    )
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.Triangle:
            match order:
                case 1:
                    return (
                        np.array(
                            [
                                [0.5, 0.125, 0.375],
                                [0.5625, 0.1875, 0.25],
                                [0.5, 0.3125, 0.1875],
                                [0.625, 0.25, 0.125],
                                [0.5625, 0.25, 0.1875],
                                [0.5, 0.375, 0.125],
                            ]
                        ),
                        np.array(
                            [
                                [0.5625, 0.1875, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.625, 0.25, 0.125],
                                [0.5, 0.3125, 0.1875],
                                [0.5, 0.375, 0.125],
                                [0.5625, 0.25, 0.1875],
                            ]
                        ),
                        np.array([0.015625, 0.015625, 0.015625, 0.015625, 0.015625, 0.015625]),
                    )
                case 2:
                    return (
                        np.array(
                            [
                                [0.7886751345948129, 0.03522081090086451, 0.17610405450432262],
                                [0.790669489309382, 0.042663844023951264, 0.16666666666666669],
                                [0.7886751345948129, 0.1741096997897534, 0.03721516561543372],
                                [0.7981125224324688, 0.16666666666666669, 0.03522081090086453],
                                [0.790669489309382, 0.16666666666666669, 0.042663844023951264],
                                [0.7886751345948129, 0.1761040545043226, 0.03522081090086453],
                                [0.21132486540518713, 0.13144585576580214, 0.6572292788290107],
                                [0.21876789852827383, 0.15922363354357993, 0.6220084679281462],
                                [0.21132486540518713, 0.649786245705924, 0.1388888888888889],
                                [0.24654567630605173, 0.6220084679281461, 0.13144585576580217],
                                [0.21876789852827383, 0.6220084679281462, 0.15922363354357993],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580217],
                                [0.7886751345948129, 0.03522081090086451, 0.17610405450432262],
                                [0.7961181677178996, 0.037215165615433726, 0.16666666666666669],
                                [0.7886751345948129, 0.16866102138123587, 0.042663844023951264],
                                [0.7981125224324688, 0.16666666666666669, 0.03522081090086453],
                                [0.7961181677178997, 0.16666666666666669, 0.03721516561543372],
                                [0.7886751345948129, 0.1761040545043226, 0.03522081090086453],
                                [0.21132486540518713, 0.13144585576580214, 0.6572292788290107],
                                [0.23910264318296492, 0.13888888888888884, 0.6220084679281462],
                                [0.21132486540518713, 0.6294515010512329, 0.15922363354357993],
                                [0.24654567630605173, 0.6220084679281461, 0.13144585576580217],
                                [0.23910264318296504, 0.6220084679281461, 0.1388888888888889],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580217],
                                [0.7886751345948129, 0.009437387837655908, 0.20188747756753123],
                                [0.7961181677178996, 0.037215165615433726, 0.16666666666666669],
                                [0.7886751345948129, 0.19444444444444445, 0.016880420960742677],
                                [0.8238959454956775, 0.16666666666666666, 0.009437387837655933],
                                [0.7961181677178997, 0.16666666666666669, 0.03721516561543371],
                                [0.7886751345948129, 0.2018874775675312, 0.009437387837655933],
                                [0.21132486540518713, 0.035220810900864485, 0.7534543236939484],
                                [0.23910264318296492, 0.13888888888888884, 0.6220084679281462],
                                [0.21132486540518713, 0.7256765459161706, 0.0629985886786423],
                                [0.3427707211709894, 0.6220084679281461, 0.03522081090086452],
                                [0.23910264318296504, 0.6220084679281461, 0.1388888888888889],
                                [0.21132486540518713, 0.7534543236939484, 0.03522081090086452],
                                [0.7886751345948129, 0.009437387837655908, 0.20188747756753123],
                                [0.8164529123725905, 0.01688042096074266, 0.16666666666666669],
                                [0.7886751345948129, 0.1741096997897534, 0.03721516561543372],
                                [0.8238959454956775, 0.16666666666666666, 0.009437387837655933],
                                [0.8164529123725905, 0.16666666666666669, 0.016880420960742673],
                                [0.7886751345948129, 0.2018874775675312, 0.009437387837655933],
                                [0.21132486540518713, 0.035220810900864485, 0.7534543236939484],
                                [0.3149929433932115, 0.06299858867864228, 0.6220084679281462],
                                [0.21132486540518713, 0.649786245705924, 0.1388888888888889],
                                [0.3427707211709894, 0.6220084679281461, 0.03522081090086452],
                                [0.3149929433932115, 0.6220084679281462, 0.06299858867864229],
                                [0.21132486540518713, 0.7534543236939484, 0.03522081090086452],
                                [0.7886751345948129, 0.13144585576580214, 0.07987900963938499],
                                [0.7961181677178996, 0.15922363354357996, 0.044658198738520456],
                                [0.7886751345948129, 0.07243597651629827, 0.13888888888888887],
                                [0.8238959454956774, 0.04465819873852045, 0.13144585576580214],
                                [0.7961181677178996, 0.04465819873852048, 0.15922363354357993],
                                [0.7886751345948129, 0.07987900963938499, 0.13144585576580214],
                                [0.2113248654051872, 0.49056261216234404, 0.29811252243246883],
                                [0.2391026431829648, 0.5942306901503684, 0.16666666666666669],
                                [0.21132486540518713, 0.2703347446546911, 0.5183403899401218],
                                [0.3427707211709894, 0.16666666666666663, 0.490562612162344],
                                [0.23910264318296492, 0.16666666666666663, 0.5942306901503684],
                                [0.21132486540518713, 0.2981125224324689, 0.490562612162344],
                                [0.7886751345948129, 0.13144585576580214, 0.07987900963938499],
                                [0.8164529123725905, 0.1388888888888889, 0.044658198738520456],
                                [0.7886751345948129, 0.05210123186160723, 0.1592236335435799],
                                [0.8238959454956774, 0.04465819873852045, 0.13144585576580214],
                                [0.8164529123725908, 0.04465819873852045, 0.1388888888888889],
                                [0.7886751345948129, 0.07987900963938499, 0.13144585576580214],
                                [0.2113248654051872, 0.49056261216234404, 0.29811252243246883],
                                [0.3149929433932115, 0.5183403899401218, 0.16666666666666669],
                                [0.21132486540518713, 0.19444444444444453, 0.5942306901503683],
                                [0.3427707211709894, 0.16666666666666663, 0.490562612162344],
                                [0.3149929433932115, 0.16666666666666674, 0.5183403899401218],
                                [0.21132486540518713, 0.2981125224324689, 0.490562612162344],
                                [0.7886751345948129, 0.03522081090086451, 0.17610405450432262],
                                [0.8164529123725905, 0.1388888888888889, 0.044658198738520456],
                                [0.7886751345948129, 0.14832627672654486, 0.06299858867864229],
                                [0.920120990360615, 0.04465819873852046, 0.03522081090086451],
                                [0.8164529123725908, 0.04465819873852045, 0.1388888888888889],
                                [0.7886751345948129, 0.17610405450432262, 0.03522081090086451],
                                [0.21132486540518713, 0.13144585576580214, 0.6572292788290107],
                                [0.3149929433932115, 0.5183403899401218, 0.16666666666666669],
                                [0.21132486540518713, 0.5535612008409864, 0.23511393375382647],
                                [0.7018874775675312, 0.16666666666666666, 0.13144585576580212],
                                [0.3149929433932115, 0.16666666666666674, 0.5183403899401218],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580212],
                                [0.7886751345948129, 0.03522081090086451, 0.17610405450432262],
                                [0.8923432125828372, 0.0629985886786423, 0.044658198738520456],
                                [0.7886751345948129, 0.07243597651629824, 0.1388888888888889],
                                [0.920120990360615, 0.04465819873852046, 0.03522081090086451],
                                [0.8923432125828372, 0.04465819873852046, 0.06299858867864229],
                                [0.7886751345948129, 0.17610405450432262, 0.03522081090086451],
                                [0.21132486540518713, 0.13144585576580214, 0.6572292788290107],
                                [0.5982193995795068, 0.2351139337538265, 0.16666666666666669],
                                [0.21132486540518713, 0.2703347446546911, 0.5183403899401218],
                                [0.7018874775675312, 0.16666666666666666, 0.13144585576580212],
                                [0.5982193995795068, 0.1666666666666667, 0.23511393375382647],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580212],
                            ]
                        ),
                        np.array(
                            [
                                [0.790669489309382, 0.042663844023951264, 0.16666666666666669],
                                [0.7886751345948129, 0.03522081090086451, 0.17610405450432262],
                                [0.7981125224324688, 0.16666666666666669, 0.03522081090086453],
                                [0.7886751345948129, 0.1741096997897534, 0.03721516561543372],
                                [0.7886751345948129, 0.1761040545043226, 0.03522081090086453],
                                [0.790669489309382, 0.16666666666666669, 0.042663844023951264],
                                [0.21876789852827383, 0.15922363354357993, 0.6220084679281462],
                                [0.21132486540518713, 0.13144585576580214, 0.6572292788290107],
                                [0.24654567630605173, 0.6220084679281461, 0.13144585576580217],
                                [0.21132486540518713, 0.649786245705924, 0.1388888888888889],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580217],
                                [0.21876789852827383, 0.6220084679281462, 0.15922363354357993],
                                [0.7961181677178996, 0.037215165615433726, 0.16666666666666669],
                                [0.7886751345948129, 0.03522081090086451, 0.17610405450432262],
                                [0.7981125224324688, 0.16666666666666669, 0.03522081090086453],
                                [0.7886751345948129, 0.16866102138123587, 0.042663844023951264],
                                [0.7886751345948129, 0.1761040545043226, 0.03522081090086453],
                                [0.7961181677178997, 0.16666666666666669, 0.03721516561543372],
                                [0.23910264318296492, 0.13888888888888884, 0.6220084679281462],
                                [0.21132486540518713, 0.13144585576580214, 0.6572292788290107],
                                [0.24654567630605173, 0.6220084679281461, 0.13144585576580217],
                                [0.21132486540518713, 0.6294515010512329, 0.15922363354357993],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580217],
                                [0.23910264318296504, 0.6220084679281461, 0.1388888888888889],
                                [0.7961181677178996, 0.037215165615433726, 0.16666666666666669],
                                [0.7886751345948129, 0.009437387837655908, 0.20188747756753123],
                                [0.8238959454956775, 0.16666666666666666, 0.009437387837655933],
                                [0.7886751345948129, 0.19444444444444445, 0.016880420960742677],
                                [0.7886751345948129, 0.2018874775675312, 0.009437387837655933],
                                [0.7961181677178997, 0.16666666666666669, 0.03721516561543371],
                                [0.23910264318296492, 0.13888888888888884, 0.6220084679281462],
                                [0.21132486540518713, 0.035220810900864485, 0.7534543236939484],
                                [0.3427707211709894, 0.6220084679281461, 0.03522081090086452],
                                [0.21132486540518713, 0.7256765459161706, 0.0629985886786423],
                                [0.21132486540518713, 0.7534543236939484, 0.03522081090086452],
                                [0.23910264318296504, 0.6220084679281461, 0.1388888888888889],
                                [0.8164529123725905, 0.01688042096074266, 0.16666666666666669],
                                [0.7886751345948129, 0.009437387837655908, 0.20188747756753123],
                                [0.8238959454956775, 0.16666666666666666, 0.009437387837655933],
                                [0.7886751345948129, 0.1741096997897534, 0.03721516561543372],
                                [0.7886751345948129, 0.2018874775675312, 0.009437387837655933],
                                [0.8164529123725905, 0.16666666666666669, 0.016880420960742673],
                                [0.3149929433932115, 0.06299858867864228, 0.6220084679281462],
                                [0.21132486540518713, 0.035220810900864485, 0.7534543236939484],
                                [0.3427707211709894, 0.6220084679281461, 0.03522081090086452],
                                [0.21132486540518713, 0.649786245705924, 0.1388888888888889],
                                [0.21132486540518713, 0.7534543236939484, 0.03522081090086452],
                                [0.3149929433932115, 0.6220084679281462, 0.06299858867864229],
                                [0.7961181677178996, 0.15922363354357996, 0.044658198738520456],
                                [0.7886751345948129, 0.13144585576580214, 0.07987900963938499],
                                [0.8238959454956774, 0.04465819873852045, 0.13144585576580214],
                                [0.7886751345948129, 0.07243597651629827, 0.13888888888888887],
                                [0.7886751345948129, 0.07987900963938499, 0.13144585576580214],
                                [0.7961181677178996, 0.04465819873852048, 0.15922363354357993],
                                [0.2391026431829648, 0.5942306901503684, 0.16666666666666669],
                                [0.2113248654051872, 0.49056261216234404, 0.29811252243246883],
                                [0.3427707211709894, 0.16666666666666663, 0.490562612162344],
                                [0.21132486540518713, 0.2703347446546911, 0.5183403899401218],
                                [0.21132486540518713, 0.2981125224324689, 0.490562612162344],
                                [0.23910264318296492, 0.16666666666666663, 0.5942306901503684],
                                [0.8164529123725905, 0.1388888888888889, 0.044658198738520456],
                                [0.7886751345948129, 0.13144585576580214, 0.07987900963938499],
                                [0.8238959454956774, 0.04465819873852045, 0.13144585576580214],
                                [0.7886751345948129, 0.05210123186160723, 0.1592236335435799],
                                [0.7886751345948129, 0.07987900963938499, 0.13144585576580214],
                                [0.8164529123725908, 0.04465819873852045, 0.1388888888888889],
                                [0.3149929433932115, 0.5183403899401218, 0.16666666666666669],
                                [0.2113248654051872, 0.49056261216234404, 0.29811252243246883],
                                [0.3427707211709894, 0.16666666666666663, 0.490562612162344],
                                [0.21132486540518713, 0.19444444444444453, 0.5942306901503683],
                                [0.21132486540518713, 0.2981125224324689, 0.490562612162344],
                                [0.3149929433932115, 0.16666666666666674, 0.5183403899401218],
                                [0.8164529123725905, 0.1388888888888889, 0.044658198738520456],
                                [0.7886751345948129, 0.03522081090086451, 0.17610405450432262],
                                [0.920120990360615, 0.04465819873852046, 0.03522081090086451],
                                [0.7886751345948129, 0.14832627672654486, 0.06299858867864229],
                                [0.7886751345948129, 0.17610405450432262, 0.03522081090086451],
                                [0.8164529123725908, 0.04465819873852045, 0.1388888888888889],
                                [0.3149929433932115, 0.5183403899401218, 0.16666666666666669],
                                [0.21132486540518713, 0.13144585576580214, 0.6572292788290107],
                                [0.7018874775675312, 0.16666666666666666, 0.13144585576580212],
                                [0.21132486540518713, 0.5535612008409864, 0.23511393375382647],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580212],
                                [0.3149929433932115, 0.16666666666666674, 0.5183403899401218],
                                [0.8923432125828372, 0.0629985886786423, 0.044658198738520456],
                                [0.7886751345948129, 0.03522081090086451, 0.17610405450432262],
                                [0.920120990360615, 0.04465819873852046, 0.03522081090086451],
                                [0.7886751345948129, 0.07243597651629824, 0.1388888888888889],
                                [0.7886751345948129, 0.17610405450432262, 0.03522081090086451],
                                [0.8923432125828372, 0.04465819873852046, 0.06299858867864229],
                                [0.5982193995795068, 0.2351139337538265, 0.16666666666666669],
                                [0.21132486540518713, 0.13144585576580214, 0.6572292788290107],
                                [0.7018874775675312, 0.16666666666666666, 0.13144585576580212],
                                [0.21132486540518713, 0.2703347446546911, 0.5183403899401218],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580212],
                                [0.5982193995795068, 0.1666666666666667, 0.23511393375382647],
                            ]
                        ),
                        np.array(
                            [
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                            ]
                        ),
                    )
                case 3:
                    return (
                        np.array(
                            [
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.8874596669241483, 0.012540333075851645, 0.09999999999999999],
                                [0.8872983346207417, 0.10127016653792582, 0.011431498841332478],
                                [0.8887298334620742, 0.09999999999999999, 0.011270166537925829],
                                [0.8874596669241483, 0.09999999999999998, 0.012540333075851659],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.5007157494206662, 0.05563508326896288, 0.44364916731037085],
                                [0.5, 0.44928425057933374, 0.050715749420666235],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.5007157494206662, 0.44364916731037085, 0.05563508326896291],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.11397183191718419, 0.09872983346207409, 0.7872983346207417],
                                [0.1127016653792583, 0.7972983346207417, 0.09],
                                [0.12397183191718408, 0.7872983346207417, 0.08872983346207416],
                                [0.11397183191718419, 0.7872983346207416, 0.09872983346207416],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.8880140840414079, 0.011985915958592067, 0.09999999999999999],
                                [0.8872983346207417, 0.10071574942066623, 0.01198591595859207],
                                [0.8887298334620742, 0.09999999999999999, 0.011270166537925829],
                                [0.8880140840414079, 0.09999999999999999, 0.011985915958592068],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.5031754163448146, 0.0531754163448146, 0.44364916731037085],
                                [0.5, 0.4468245836551854, 0.053175416344814576],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.5031754163448146, 0.44364916731037085, 0.05317541634481457],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.11833674864822119, 0.09436491673103709, 0.7872983346207417],
                                [0.1127016653792583, 0.7929334178897046, 0.09436491673103709],
                                [0.12397183191718408, 0.7872983346207417, 0.08872983346207416],
                                [0.11833674864822119, 0.7872983346207417, 0.09436491673103707],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.8885685011586676, 0.011431498841332474, 0.09999999999999999],
                                [0.8872983346207417, 0.10016133230340664, 0.012540333075851659],
                                [0.8887298334620742, 0.09999999999999999, 0.011270166537925829],
                                [0.8885685011586676, 0.09999999999999999, 0.011431498841332478],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.5056350832689629, 0.050715749420666256, 0.44364916731037085],
                                [0.5, 0.44436491673103706, 0.05563508326896291],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.5056350832689629, 0.44364916731037085, 0.050715749420666235],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.1227016653792583, 0.08999999999999997, 0.7872983346207417],
                                [0.1127016653792583, 0.7885685011586675, 0.09872983346207416],
                                [0.12397183191718408, 0.7872983346207417, 0.08872983346207416],
                                [0.1227016653792583, 0.7872983346207417, 0.09],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.8880140840414079, 0.011985915958592067, 0.09999999999999999],
                                [0.8872983346207417, 0.1056350832689629, 0.007066582110295394],
                                [0.8936491673103709, 0.09999999999999998, 0.006350832689629154],
                                [0.8880140840414079, 0.09999999999999999, 0.011985915958592068],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.5031754163448146, 0.0531754163448146, 0.44364916731037085],
                                [0.5, 0.4686491673103709, 0.031350832689629154],
                                [0.5281754163448146, 0.44364916731037085, 0.028175416344814574],
                                [0.5031754163448146, 0.44364916731037085, 0.05317541634481457],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.11833674864822119, 0.09436491673103709, 0.7872983346207417],
                                [0.1127016653792583, 0.8316632513517788, 0.055635083268962916],
                                [0.16270166537925834, 0.7872983346207416, 0.049999999999999996],
                                [0.11833674864822119, 0.7872983346207417, 0.09436491673103707],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.8904737509655563, 0.009526249034443726, 0.09999999999999999],
                                [0.8872983346207417, 0.10317541634481457, 0.009526249034443731],
                                [0.8936491673103709, 0.09999999999999998, 0.006350832689629154],
                                [0.8904737509655563, 0.09999999999999999, 0.009526249034443731],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.5140877081724073, 0.04226312451722186, 0.44364916731037085],
                                [0.5, 0.45773687548277814, 0.04226312451722186],
                                [0.5281754163448146, 0.44364916731037085, 0.028175416344814574],
                                [0.5140877081724073, 0.44364916731037085, 0.04226312451722186],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.13770166537925832, 0.07499999999999996, 0.7872983346207417],
                                [0.1127016653792583, 0.8122983346207417, 0.075],
                                [0.16270166537925834, 0.7872983346207416, 0.049999999999999996],
                                [0.13770166537925832, 0.7872983346207417, 0.075],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.8929334178897046, 0.007066582110295386, 0.09999999999999999],
                                [0.8872983346207417, 0.10071574942066623, 0.011985915958592068],
                                [0.8936491673103709, 0.09999999999999998, 0.006350832689629154],
                                [0.8929334178897046, 0.09999999999999998, 0.007066582110295394],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.525, 0.03135083268962913, 0.44364916731037085],
                                [0.5, 0.4468245836551854, 0.05317541634481457],
                                [0.5281754163448146, 0.44364916731037085, 0.028175416344814574],
                                [0.525, 0.44364916731037085, 0.031350832689629154],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.15706658211029545, 0.055635083268962826, 0.7872983346207417],
                                [0.1127016653792583, 0.7929334178897046, 0.09436491673103707],
                                [0.16270166537925834, 0.7872983346207416, 0.049999999999999996],
                                [0.15706658211029545, 0.7872983346207416, 0.055635083268962916],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.8872983346207417, 0.0014314988413324792, 0.11127016653792582],
                                [0.8885685011586676, 0.011431498841332474, 0.09999999999999999],
                                [0.8872983346207417, 0.10999999999999999, 0.00270166537925831],
                                [0.8985685011586675, 0.09999999999999999, 0.0014314988413324796],
                                [0.8885685011586676, 0.09999999999999999, 0.011431498841332478],
                                [0.8872983346207417, 0.11127016653792582, 0.0014314988413324796],
                                [0.49999999999999994, 0.00635083268962916, 0.49364916731037084],
                                [0.5056350832689629, 0.050715749420666256, 0.44364916731037085],
                                [0.49999999999999994, 0.48801408404140795, 0.011985915958592067],
                                [0.55, 0.44364916731037085, 0.006350832689629153],
                                [0.5056350832689629, 0.44364916731037085, 0.050715749420666235],
                                [0.5, 0.49364916731037084, 0.006350832689629153],
                                [0.1127016653792583, 0.011270166537925785, 0.8760281680828159],
                                [0.1227016653792583, 0.08999999999999997, 0.7872983346207417],
                                [0.1127016653792583, 0.8660281680828159, 0.021270166537925822],
                                [0.2014314988413325, 0.7872983346207417, 0.011270166537925827],
                                [0.1227016653792583, 0.7872983346207417, 0.09],
                                [0.1127016653792583, 0.8760281680828159, 0.011270166537925827],
                                [0.8872983346207417, 0.0014314988413324792, 0.11127016653792582],
                                [0.8929334178897046, 0.007066582110295386, 0.09999999999999999],
                                [0.8872983346207417, 0.1056350832689629, 0.007066582110295394],
                                [0.8985685011586675, 0.09999999999999999, 0.0014314988413324796],
                                [0.8929334178897046, 0.09999999999999998, 0.007066582110295394],
                                [0.8872983346207417, 0.11127016653792582, 0.0014314988413324796],
                                [0.49999999999999994, 0.00635083268962916, 0.49364916731037084],
                                [0.525, 0.03135083268962913, 0.44364916731037085],
                                [0.5, 0.4686491673103709, 0.031350832689629154],
                                [0.55, 0.44364916731037085, 0.006350832689629153],
                                [0.525, 0.44364916731037085, 0.031350832689629154],
                                [0.5, 0.49364916731037084, 0.006350832689629153],
                                [0.1127016653792583, 0.011270166537925785, 0.8760281680828159],
                                [0.15706658211029545, 0.055635083268962826, 0.7872983346207417],
                                [0.1127016653792583, 0.8316632513517788, 0.055635083268962916],
                                [0.2014314988413325, 0.7872983346207417, 0.011270166537925827],
                                [0.15706658211029545, 0.7872983346207416, 0.055635083268962916],
                                [0.1127016653792583, 0.8760281680828159, 0.011270166537925827],
                                [0.8872983346207417, 0.0014314988413324792, 0.11127016653792582],
                                [0.8972983346207417, 0.002701665379258311, 0.09999999999999999],
                                [0.8872983346207417, 0.10127016653792582, 0.011431498841332478],
                                [0.8985685011586675, 0.09999999999999999, 0.0014314988413324796],
                                [0.8972983346207417, 0.09999999999999999, 0.00270166537925831],
                                [0.8872983346207417, 0.11127016653792582, 0.0014314988413324796],
                                [0.49999999999999994, 0.00635083268962916, 0.49364916731037084],
                                [0.5443649167310372, 0.011985915958592053, 0.44364916731037085],
                                [0.5, 0.44928425057933374, 0.050715749420666235],
                                [0.55, 0.44364916731037085, 0.006350832689629153],
                                [0.544364916731037, 0.44364916731037085, 0.011985915958592067],
                                [0.5, 0.49364916731037084, 0.006350832689629153],
                                [0.1127016653792583, 0.011270166537925785, 0.8760281680828159],
                                [0.19143149884133248, 0.021270166537925794, 0.7872983346207417],
                                [0.1127016653792583, 0.7972983346207417, 0.09],
                                [0.2014314988413325, 0.7872983346207417, 0.011270166537925827],
                                [0.19143149884133248, 0.7872983346207417, 0.021270166537925822],
                                [0.1127016653792583, 0.8760281680828159, 0.011270166537925827],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.8880140840414079, 0.05563508326896291, 0.05635083268962915],
                                [0.8872983346207417, 0.06198591595859206, 0.050715749420666235],
                                [0.8936491673103708, 0.05635083268962914, 0.049999999999999996],
                                [0.8880140840414079, 0.05635083268962915, 0.05563508326896291],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.5031754163448146, 0.24682458365518545, 0.25],
                                [0.5, 0.275, 0.225],
                                [0.5281754163448146, 0.25, 0.22182458365518543],
                                [0.5031754163448146, 0.25, 0.24682458365518542],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.11833674864822119, 0.43801408404140796, 0.44364916731037085],
                                [0.11270166537925835, 0.48801408404140795, 0.39928425057933375],
                                [0.1627016653792584, 0.4436491673103708, 0.39364916731037086],
                                [0.11833674864822119, 0.44364916731037085, 0.43801408404140796],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.8904737509655563, 0.05317541634481457, 0.05635083268962915],
                                [0.8872983346207417, 0.05952624903444373, 0.05317541634481457],
                                [0.8936491673103708, 0.05635083268962914, 0.049999999999999996],
                                [0.8904737509655563, 0.05635083268962915, 0.05317541634481457],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.5140877081724073, 0.2359122918275927, 0.25],
                                [0.5, 0.2640877081724073, 0.2359122918275927],
                                [0.5281754163448146, 0.25, 0.22182458365518543],
                                [0.5140877081724073, 0.25, 0.2359122918275927],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.13770166537925832, 0.41864916731037083, 0.44364916731037085],
                                [0.1127016653792583, 0.4686491673103709, 0.41864916731037083],
                                [0.1627016653792584, 0.4436491673103708, 0.39364916731037086],
                                [0.13770166537925832, 0.44364916731037085, 0.41864916731037083],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.8929334178897046, 0.05071574942066623, 0.05635083268962915],
                                [0.8872983346207417, 0.05706658211029539, 0.05563508326896291],
                                [0.8936491673103708, 0.05635083268962914, 0.049999999999999996],
                                [0.8929334178897046, 0.05635083268962914, 0.050715749420666235],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.525, 0.22499999999999998, 0.25],
                                [0.5, 0.25317541634481455, 0.24682458365518542],
                                [0.5281754163448146, 0.25, 0.22182458365518543],
                                [0.525, 0.24999999999999997, 0.225],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.15706658211029545, 0.3992842505793337, 0.44364916731037085],
                                [0.1127016653792583, 0.44928425057933374, 0.43801408404140796],
                                [0.1627016653792584, 0.4436491673103708, 0.39364916731037086],
                                [0.1570665821102955, 0.4436491673103708, 0.39928425057933375],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.8872983346207417, 0.028175416344814574, 0.08452624903444372],
                                [0.8904737509655563, 0.05317541634481457, 0.05635083268962915],
                                [0.8872983346207417, 0.08135083268962914, 0.031350832689629154],
                                [0.9154737509655563, 0.05635083268962915, 0.028175416344814574],
                                [0.8904737509655563, 0.05635083268962915, 0.05317541634481457],
                                [0.8872983346207417, 0.08452624903444372, 0.028175416344814574],
                                [0.5, 0.125, 0.375],
                                [0.5140877081724073, 0.2359122918275927, 0.25],
                                [0.49999999999999994, 0.3609122918275927, 0.1390877081724073],
                                [0.625, 0.25, 0.125],
                                [0.5140877081724073, 0.25, 0.2359122918275927],
                                [0.5, 0.375, 0.125],
                                [0.1127016653792583, 0.22182458365518543, 0.6654737509655563],
                                [0.13770166537925832, 0.41864916731037083, 0.44364916731037085],
                                [0.1127016653792583, 0.6404737509655563, 0.24682458365518542],
                                [0.3345262490344437, 0.44364916731037085, 0.22182458365518543],
                                [0.13770166537925832, 0.44364916731037085, 0.41864916731037083],
                                [0.1127016653792583, 0.6654737509655563, 0.22182458365518543],
                                [0.8872983346207417, 0.028175416344814574, 0.08452624903444372],
                                [0.901386042793149, 0.04226312451722186, 0.05635083268962915],
                                [0.8872983346207417, 0.07043854086203644, 0.04226312451722186],
                                [0.9154737509655563, 0.05635083268962915, 0.028175416344814574],
                                [0.901386042793149, 0.05635083268962915, 0.04226312451722186],
                                [0.8872983346207417, 0.08452624903444372, 0.028175416344814574],
                                [0.5, 0.125, 0.375],
                                [0.5625, 0.1875, 0.25],
                                [0.5, 0.3125, 0.1875],
                                [0.625, 0.25, 0.125],
                                [0.5625, 0.25, 0.1875],
                                [0.5, 0.375, 0.125],
                                [0.1127016653792583, 0.22182458365518543, 0.6654737509655563],
                                [0.22361395720685096, 0.3327368754827782, 0.44364916731037085],
                                [0.1127016653792583, 0.5545614591379635, 0.33273687548277814],
                                [0.3345262490344437, 0.44364916731037085, 0.22182458365518543],
                                [0.2236139572068509, 0.4436491673103709, 0.33273687548277814],
                                [0.1127016653792583, 0.6654737509655563, 0.22182458365518543],
                                [0.8872983346207417, 0.028175416344814574, 0.08452624903444372],
                                [0.9122983346207417, 0.031350832689629154, 0.05635083268962915],
                                [0.8872983346207417, 0.05952624903444373, 0.05317541634481457],
                                [0.9154737509655563, 0.05635083268962915, 0.028175416344814574],
                                [0.9122983346207417, 0.05635083268962915, 0.031350832689629154],
                                [0.8872983346207417, 0.08452624903444372, 0.028175416344814574],
                                [0.5, 0.125, 0.375],
                                [0.6109122918275927, 0.1390877081724073, 0.25],
                                [0.5, 0.2640877081724073, 0.2359122918275927],
                                [0.625, 0.25, 0.125],
                                [0.6109122918275927, 0.25, 0.1390877081724073],
                                [0.5, 0.375, 0.125],
                                [0.1127016653792583, 0.22182458365518543, 0.6654737509655563],
                                [0.3095262490344437, 0.24682458365518545, 0.44364916731037085],
                                [0.1127016653792583, 0.4686491673103709, 0.41864916731037083],
                                [0.3345262490344437, 0.44364916731037085, 0.22182458365518543],
                                [0.3095262490344437, 0.44364916731037085, 0.24682458365518542],
                                [0.1127016653792583, 0.6654737509655563, 0.22182458365518543],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.8929334178897046, 0.05071574942066623, 0.05635083268962915],
                                [0.8872983346207417, 0.10071574942066623, 0.011985915958592068],
                                [0.9372983346207417, 0.056350832689629156, 0.006350832689629154],
                                [0.8929334178897046, 0.05635083268962914, 0.050715749420666235],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.525, 0.22499999999999998, 0.25],
                                [0.5, 0.4468245836551854, 0.05317541634481457],
                                [0.7218245836551854, 0.25, 0.028175416344814574],
                                [0.525, 0.24999999999999997, 0.225],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.15706658211029545, 0.3992842505793337, 0.44364916731037085],
                                [0.1127016653792583, 0.7929334178897046, 0.09436491673103707],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.1570665821102955, 0.4436491673103708, 0.39928425057933375],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.9122983346207417, 0.031350832689629154, 0.05635083268962915],
                                [0.8872983346207417, 0.08135083268962914, 0.031350832689629154],
                                [0.9372983346207417, 0.056350832689629156, 0.006350832689629154],
                                [0.9122983346207417, 0.05635083268962915, 0.031350832689629154],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.6109122918275927, 0.1390877081724073, 0.25],
                                [0.49999999999999994, 0.3609122918275927, 0.1390877081724073],
                                [0.7218245836551854, 0.25, 0.028175416344814574],
                                [0.6109122918275927, 0.25, 0.1390877081724073],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.3095262490344437, 0.24682458365518545, 0.44364916731037085],
                                [0.1127016653792583, 0.6404737509655563, 0.24682458365518542],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.3095262490344437, 0.44364916731037085, 0.24682458365518542],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.9316632513517787, 0.01198591595859208, 0.05635083268962915],
                                [0.8872983346207417, 0.06198591595859206, 0.050715749420666235],
                                [0.9372983346207417, 0.056350832689629156, 0.006350832689629154],
                                [0.9316632513517787, 0.05635083268962916, 0.011985915958592068],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.6968245836551854, 0.0531754163448146, 0.25],
                                [0.5, 0.275, 0.225],
                                [0.7218245836551854, 0.25, 0.028175416344814574],
                                [0.6968245836551854, 0.25, 0.05317541634481457],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.46198591595859206, 0.09436491673103709, 0.44364916731037085],
                                [0.11270166537925835, 0.48801408404140795, 0.39928425057933375],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.46198591595859206, 0.44364916731037085, 0.09436491673103707],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.8872983346207417, 0.08872983346207416, 0.023971831917184137],
                                [0.8885685011586675, 0.09872983346207416, 0.012701665379258308],
                                [0.8872983346207417, 0.022701665379258315, 0.08999999999999998],
                                [0.8985685011586675, 0.012701665379258306, 0.08872983346207416],
                                [0.8885685011586675, 0.012701665379258306, 0.09872983346207416],
                                [0.8872983346207417, 0.023971831917184133, 0.08872983346207416],
                                [0.49999999999999994, 0.39364916731037086, 0.10635083268962914],
                                [0.5056350832689629, 0.43801408404140796, 0.05635083268962915],
                                [0.5, 0.10071574942066625, 0.39928425057933375],
                                [0.55, 0.05635083268962915, 0.39364916731037086],
                                [0.5056350832689629, 0.05635083268962915, 0.43801408404140796],
                                [0.5, 0.10635083268962914, 0.39364916731037086],
                                [0.1127016653792583, 0.6985685011586675, 0.18872983346207414],
                                [0.1227016653792583, 0.7772983346207417, 0.09999999999999999],
                                [0.1127016653792583, 0.17872983346207416, 0.7085685011586675],
                                [0.2014314988413325, 0.09999999999999998, 0.6985685011586675],
                                [0.1227016653792583, 0.09999999999999998, 0.7772983346207417],
                                [0.1127016653792583, 0.18872983346207417, 0.6985685011586675],
                                [0.8872983346207417, 0.08872983346207416, 0.023971831917184137],
                                [0.8929334178897046, 0.09436491673103707, 0.012701665379258308],
                                [0.8872983346207417, 0.018336748648221213, 0.09436491673103709],
                                [0.8985685011586675, 0.012701665379258306, 0.08872983346207416],
                                [0.8929334178897046, 0.012701665379258306, 0.09436491673103707],
                                [0.8872983346207417, 0.023971831917184133, 0.08872983346207416],
                                [0.49999999999999994, 0.39364916731037086, 0.10635083268962914],
                                [0.525, 0.41864916731037083, 0.05635083268962915],
                                [0.49999999999999994, 0.08135083268962912, 0.4186491673103709],
                                [0.55, 0.05635083268962915, 0.39364916731037086],
                                [0.525, 0.05635083268962915, 0.41864916731037083],
                                [0.5, 0.10635083268962914, 0.39364916731037086],
                                [0.1127016653792583, 0.6985685011586675, 0.18872983346207414],
                                [0.15706658211029545, 0.7429334178897046, 0.09999999999999999],
                                [0.1127016653792583, 0.14436491673103702, 0.7429334178897047],
                                [0.2014314988413325, 0.09999999999999998, 0.6985685011586675],
                                [0.15706658211029545, 0.09999999999999998, 0.7429334178897046],
                                [0.1127016653792583, 0.18872983346207417, 0.6985685011586675],
                                [0.8872983346207417, 0.08872983346207416, 0.023971831917184137],
                                [0.8972983346207417, 0.09, 0.012701665379258308],
                                [0.8872983346207417, 0.013971831917184138, 0.09872983346207416],
                                [0.8985685011586675, 0.012701665379258306, 0.08872983346207416],
                                [0.8972983346207417, 0.01270166537925832, 0.08999999999999998],
                                [0.8872983346207417, 0.023971831917184133, 0.08872983346207416],
                                [0.49999999999999994, 0.39364916731037086, 0.10635083268962914],
                                [0.5443649167310372, 0.39928425057933375, 0.05635083268962915],
                                [0.5, 0.06198591595859204, 0.43801408404140796],
                                [0.55, 0.05635083268962915, 0.39364916731037086],
                                [0.5443649167310372, 0.05635083268962915, 0.39928425057933375],
                                [0.5, 0.10635083268962914, 0.39364916731037086],
                                [0.1127016653792583, 0.6985685011586675, 0.18872983346207414],
                                [0.19143149884133248, 0.7085685011586675, 0.09999999999999999],
                                [0.1127016653792583, 0.10999999999999999, 0.7772983346207417],
                                [0.2014314988413325, 0.09999999999999998, 0.6985685011586675],
                                [0.19143149884133248, 0.09999999999999998, 0.7085685011586675],
                                [0.1127016653792583, 0.18872983346207417, 0.6985685011586675],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.8929334178897046, 0.09436491673103707, 0.012701665379258308],
                                [0.8872983346207417, 0.05706658211029539, 0.05563508326896291],
                                [0.9372983346207416, 0.012701665379258313, 0.049999999999999996],
                                [0.8929334178897046, 0.012701665379258306, 0.09436491673103707],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.525, 0.41864916731037083, 0.05635083268962915],
                                [0.5, 0.25317541634481455, 0.24682458365518542],
                                [0.7218245836551854, 0.05635083268962915, 0.22182458365518543],
                                [0.525, 0.05635083268962915, 0.41864916731037083],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.15706658211029545, 0.7429334178897046, 0.09999999999999999],
                                [0.1127016653792583, 0.44928425057933374, 0.43801408404140796],
                                [0.5063508326896292, 0.09999999999999998, 0.39364916731037086],
                                [0.15706658211029545, 0.09999999999999998, 0.7429334178897046],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.9122983346207417, 0.075, 0.012701665379258308],
                                [0.8872983346207417, 0.0377016653792583, 0.075],
                                [0.9372983346207416, 0.012701665379258313, 0.049999999999999996],
                                [0.9122983346207417, 0.012701665379258306, 0.075],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.6109122918275927, 0.33273687548277814, 0.05635083268962915],
                                [0.49999999999999994, 0.16726312451722186, 0.33273687548277814],
                                [0.7218245836551854, 0.05635083268962915, 0.22182458365518543],
                                [0.6109122918275927, 0.05635083268962915, 0.33273687548277814],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.3095262490344437, 0.5904737509655563, 0.09999999999999999],
                                [0.1127016653792583, 0.2968245836551854, 0.5904737509655563],
                                [0.5063508326896292, 0.09999999999999998, 0.39364916731037086],
                                [0.3095262490344437, 0.09999999999999998, 0.5904737509655563],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.9316632513517787, 0.05563508326896292, 0.012701665379258308],
                                [0.8872983346207417, 0.018336748648221227, 0.09436491673103707],
                                [0.9372983346207416, 0.012701665379258313, 0.049999999999999996],
                                [0.9316632513517787, 0.01270166537925832, 0.05563508326896291],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.6968245836551854, 0.24682458365518545, 0.05635083268962915],
                                [0.5, 0.08135083268962917, 0.41864916731037083],
                                [0.7218245836551854, 0.05635083268962915, 0.22182458365518543],
                                [0.6968245836551854, 0.05635083268962918, 0.24682458365518542],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.46198591595859206, 0.43801408404140796, 0.09999999999999999],
                                [0.1127016653792583, 0.14436491673103713, 0.7429334178897046],
                                [0.5063508326896292, 0.09999999999999998, 0.39364916731037086],
                                [0.46198591595859206, 0.09999999999999998, 0.43801408404140796],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.8972983346207417, 0.09, 0.012701665379258308],
                                [0.8872983346207417, 0.09143149884133248, 0.021270166537925825],
                                [0.9760281680828159, 0.01270166537925831, 0.011270166537925827],
                                [0.8972983346207417, 0.01270166537925832, 0.08999999999999998],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925827],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.5443649167310372, 0.39928425057933375, 0.05635083268962915],
                                [0.5, 0.4056350832689629, 0.09436491673103707],
                                [0.8936491673103708, 0.05635083268962915, 0.04999999999999999],
                                [0.5443649167310372, 0.05635083268962915, 0.39928425057933375],
                                [0.49999999999999994, 0.45, 0.04999999999999999],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.19143149884133248, 0.7085685011586675, 0.09999999999999999],
                                [0.1127016653792583, 0.7198386676965933, 0.16745966692414832],
                                [0.8112701665379258, 0.09999999999999999, 0.08872983346207415],
                                [0.19143149884133248, 0.09999999999999998, 0.7085685011586675],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207415],
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.9316632513517787, 0.05563508326896292, 0.012701665379258308],
                                [0.8872983346207417, 0.05706658211029539, 0.05563508326896291],
                                [0.9760281680828159, 0.01270166537925831, 0.011270166537925827],
                                [0.9316632513517787, 0.01270166537925832, 0.05563508326896291],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925827],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.6968245836551854, 0.24682458365518545, 0.05635083268962915],
                                [0.5, 0.25317541634481455, 0.24682458365518542],
                                [0.8936491673103708, 0.05635083268962915, 0.04999999999999999],
                                [0.6968245836551854, 0.05635083268962918, 0.24682458365518542],
                                [0.49999999999999994, 0.45, 0.04999999999999999],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.46198591595859206, 0.43801408404140796, 0.09999999999999999],
                                [0.1127016653792583, 0.44928425057933374, 0.43801408404140796],
                                [0.8112701665379258, 0.09999999999999999, 0.08872983346207415],
                                [0.46198591595859206, 0.09999999999999998, 0.43801408404140796],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207415],
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.9660281680828159, 0.02127016653792583, 0.012701665379258308],
                                [0.8872983346207417, 0.022701665379258315, 0.08999999999999998],
                                [0.9760281680828159, 0.01270166537925831, 0.011270166537925827],
                                [0.9660281680828159, 0.012701665379258306, 0.02127016653792583],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925827],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.8492842505793338, 0.09436491673103709, 0.05635083268962915],
                                [0.5, 0.10071574942066625, 0.39928425057933375],
                                [0.8936491673103708, 0.05635083268962915, 0.04999999999999999],
                                [0.8492842505793338, 0.05635083268962915, 0.09436491673103709],
                                [0.49999999999999994, 0.45, 0.04999999999999999],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.7325403330758516, 0.16745966692414838, 0.09999999999999999],
                                [0.1127016653792583, 0.17872983346207416, 0.7085685011586675],
                                [0.8112701665379258, 0.09999999999999999, 0.08872983346207415],
                                [0.7325403330758516, 0.1, 0.16745966692414835],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207415],
                            ]
                        ),
                        np.array(
                            [
                                [0.8874596669241483, 0.012540333075851645, 0.09999999999999999],
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.8887298334620742, 0.09999999999999999, 0.011270166537925829],
                                [0.8872983346207417, 0.10127016653792582, 0.011431498841332478],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.8874596669241483, 0.09999999999999998, 0.012540333075851659],
                                [0.5007157494206662, 0.05563508326896288, 0.44364916731037085],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.5, 0.44928425057933374, 0.050715749420666235],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.5007157494206662, 0.44364916731037085, 0.05563508326896291],
                                [0.11397183191718419, 0.09872983346207409, 0.7872983346207417],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.12397183191718408, 0.7872983346207417, 0.08872983346207416],
                                [0.1127016653792583, 0.7972983346207417, 0.09],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.11397183191718419, 0.7872983346207416, 0.09872983346207416],
                                [0.8880140840414079, 0.011985915958592067, 0.09999999999999999],
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.8887298334620742, 0.09999999999999999, 0.011270166537925829],
                                [0.8872983346207417, 0.10071574942066623, 0.01198591595859207],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.8880140840414079, 0.09999999999999999, 0.011985915958592068],
                                [0.5031754163448146, 0.0531754163448146, 0.44364916731037085],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.5, 0.4468245836551854, 0.053175416344814576],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.5031754163448146, 0.44364916731037085, 0.05317541634481457],
                                [0.11833674864822119, 0.09436491673103709, 0.7872983346207417],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.12397183191718408, 0.7872983346207417, 0.08872983346207416],
                                [0.1127016653792583, 0.7929334178897046, 0.09436491673103709],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.11833674864822119, 0.7872983346207417, 0.09436491673103707],
                                [0.8885685011586676, 0.011431498841332474, 0.09999999999999999],
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.8887298334620742, 0.09999999999999999, 0.011270166537925829],
                                [0.8872983346207417, 0.10016133230340664, 0.012540333075851659],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.8885685011586676, 0.09999999999999999, 0.011431498841332478],
                                [0.5056350832689629, 0.050715749420666256, 0.44364916731037085],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.5, 0.44436491673103706, 0.05563508326896291],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.5056350832689629, 0.44364916731037085, 0.050715749420666235],
                                [0.1227016653792583, 0.08999999999999997, 0.7872983346207417],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.12397183191718408, 0.7872983346207417, 0.08872983346207416],
                                [0.1127016653792583, 0.7885685011586675, 0.09872983346207416],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.1227016653792583, 0.7872983346207417, 0.09],
                                [0.8880140840414079, 0.011985915958592067, 0.09999999999999999],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.8936491673103709, 0.09999999999999998, 0.006350832689629154],
                                [0.8872983346207417, 0.1056350832689629, 0.007066582110295394],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8880140840414079, 0.09999999999999999, 0.011985915958592068],
                                [0.5031754163448146, 0.0531754163448146, 0.44364916731037085],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.5281754163448146, 0.44364916731037085, 0.028175416344814574],
                                [0.5, 0.4686491673103709, 0.031350832689629154],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.5031754163448146, 0.44364916731037085, 0.05317541634481457],
                                [0.11833674864822119, 0.09436491673103709, 0.7872983346207417],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.16270166537925834, 0.7872983346207416, 0.049999999999999996],
                                [0.1127016653792583, 0.8316632513517788, 0.055635083268962916],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.11833674864822119, 0.7872983346207417, 0.09436491673103707],
                                [0.8904737509655563, 0.009526249034443726, 0.09999999999999999],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.8936491673103709, 0.09999999999999998, 0.006350832689629154],
                                [0.8872983346207417, 0.10317541634481457, 0.009526249034443731],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8904737509655563, 0.09999999999999999, 0.009526249034443731],
                                [0.5140877081724073, 0.04226312451722186, 0.44364916731037085],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.5281754163448146, 0.44364916731037085, 0.028175416344814574],
                                [0.5, 0.45773687548277814, 0.04226312451722186],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.5140877081724073, 0.44364916731037085, 0.04226312451722186],
                                [0.13770166537925832, 0.07499999999999996, 0.7872983346207417],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.16270166537925834, 0.7872983346207416, 0.049999999999999996],
                                [0.1127016653792583, 0.8122983346207417, 0.075],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.13770166537925832, 0.7872983346207417, 0.075],
                                [0.8929334178897046, 0.007066582110295386, 0.09999999999999999],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.8936491673103709, 0.09999999999999998, 0.006350832689629154],
                                [0.8872983346207417, 0.10071574942066623, 0.011985915958592068],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8929334178897046, 0.09999999999999998, 0.007066582110295394],
                                [0.525, 0.03135083268962913, 0.44364916731037085],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.5281754163448146, 0.44364916731037085, 0.028175416344814574],
                                [0.5, 0.4468245836551854, 0.05317541634481457],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.525, 0.44364916731037085, 0.031350832689629154],
                                [0.15706658211029545, 0.055635083268962826, 0.7872983346207417],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.16270166537925834, 0.7872983346207416, 0.049999999999999996],
                                [0.1127016653792583, 0.7929334178897046, 0.09436491673103707],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.15706658211029545, 0.7872983346207416, 0.055635083268962916],
                                [0.8885685011586676, 0.011431498841332474, 0.09999999999999999],
                                [0.8872983346207417, 0.0014314988413324792, 0.11127016653792582],
                                [0.8985685011586675, 0.09999999999999999, 0.0014314988413324796],
                                [0.8872983346207417, 0.10999999999999999, 0.00270166537925831],
                                [0.8872983346207417, 0.11127016653792582, 0.0014314988413324796],
                                [0.8885685011586676, 0.09999999999999999, 0.011431498841332478],
                                [0.5056350832689629, 0.050715749420666256, 0.44364916731037085],
                                [0.49999999999999994, 0.00635083268962916, 0.49364916731037084],
                                [0.55, 0.44364916731037085, 0.006350832689629153],
                                [0.49999999999999994, 0.48801408404140795, 0.011985915958592067],
                                [0.5, 0.49364916731037084, 0.006350832689629153],
                                [0.5056350832689629, 0.44364916731037085, 0.050715749420666235],
                                [0.1227016653792583, 0.08999999999999997, 0.7872983346207417],
                                [0.1127016653792583, 0.011270166537925785, 0.8760281680828159],
                                [0.2014314988413325, 0.7872983346207417, 0.011270166537925827],
                                [0.1127016653792583, 0.8660281680828159, 0.021270166537925822],
                                [0.1127016653792583, 0.8760281680828159, 0.011270166537925827],
                                [0.1227016653792583, 0.7872983346207417, 0.09],
                                [0.8929334178897046, 0.007066582110295386, 0.09999999999999999],
                                [0.8872983346207417, 0.0014314988413324792, 0.11127016653792582],
                                [0.8985685011586675, 0.09999999999999999, 0.0014314988413324796],
                                [0.8872983346207417, 0.1056350832689629, 0.007066582110295394],
                                [0.8872983346207417, 0.11127016653792582, 0.0014314988413324796],
                                [0.8929334178897046, 0.09999999999999998, 0.007066582110295394],
                                [0.525, 0.03135083268962913, 0.44364916731037085],
                                [0.49999999999999994, 0.00635083268962916, 0.49364916731037084],
                                [0.55, 0.44364916731037085, 0.006350832689629153],
                                [0.5, 0.4686491673103709, 0.031350832689629154],
                                [0.5, 0.49364916731037084, 0.006350832689629153],
                                [0.525, 0.44364916731037085, 0.031350832689629154],
                                [0.15706658211029545, 0.055635083268962826, 0.7872983346207417],
                                [0.1127016653792583, 0.011270166537925785, 0.8760281680828159],
                                [0.2014314988413325, 0.7872983346207417, 0.011270166537925827],
                                [0.1127016653792583, 0.8316632513517788, 0.055635083268962916],
                                [0.1127016653792583, 0.8760281680828159, 0.011270166537925827],
                                [0.15706658211029545, 0.7872983346207416, 0.055635083268962916],
                                [0.8972983346207417, 0.002701665379258311, 0.09999999999999999],
                                [0.8872983346207417, 0.0014314988413324792, 0.11127016653792582],
                                [0.8985685011586675, 0.09999999999999999, 0.0014314988413324796],
                                [0.8872983346207417, 0.10127016653792582, 0.011431498841332478],
                                [0.8872983346207417, 0.11127016653792582, 0.0014314988413324796],
                                [0.8972983346207417, 0.09999999999999999, 0.00270166537925831],
                                [0.5443649167310372, 0.011985915958592053, 0.44364916731037085],
                                [0.49999999999999994, 0.00635083268962916, 0.49364916731037084],
                                [0.55, 0.44364916731037085, 0.006350832689629153],
                                [0.5, 0.44928425057933374, 0.050715749420666235],
                                [0.5, 0.49364916731037084, 0.006350832689629153],
                                [0.544364916731037, 0.44364916731037085, 0.011985915958592067],
                                [0.19143149884133248, 0.021270166537925794, 0.7872983346207417],
                                [0.1127016653792583, 0.011270166537925785, 0.8760281680828159],
                                [0.2014314988413325, 0.7872983346207417, 0.011270166537925827],
                                [0.1127016653792583, 0.7972983346207417, 0.09],
                                [0.1127016653792583, 0.8760281680828159, 0.011270166537925827],
                                [0.19143149884133248, 0.7872983346207417, 0.021270166537925822],
                                [0.8880140840414079, 0.05563508326896291, 0.05635083268962915],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.8936491673103708, 0.05635083268962914, 0.049999999999999996],
                                [0.8872983346207417, 0.06198591595859206, 0.050715749420666235],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.8880140840414079, 0.05635083268962915, 0.05563508326896291],
                                [0.5031754163448146, 0.24682458365518545, 0.25],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.5281754163448146, 0.25, 0.22182458365518543],
                                [0.5, 0.275, 0.225],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.5031754163448146, 0.25, 0.24682458365518542],
                                [0.11833674864822119, 0.43801408404140796, 0.44364916731037085],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.1627016653792584, 0.4436491673103708, 0.39364916731037086],
                                [0.11270166537925835, 0.48801408404140795, 0.39928425057933375],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.11833674864822119, 0.44364916731037085, 0.43801408404140796],
                                [0.8904737509655563, 0.05317541634481457, 0.05635083268962915],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.8936491673103708, 0.05635083268962914, 0.049999999999999996],
                                [0.8872983346207417, 0.05952624903444373, 0.05317541634481457],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.8904737509655563, 0.05635083268962915, 0.05317541634481457],
                                [0.5140877081724073, 0.2359122918275927, 0.25],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.5281754163448146, 0.25, 0.22182458365518543],
                                [0.5, 0.2640877081724073, 0.2359122918275927],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.5140877081724073, 0.25, 0.2359122918275927],
                                [0.13770166537925832, 0.41864916731037083, 0.44364916731037085],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.1627016653792584, 0.4436491673103708, 0.39364916731037086],
                                [0.1127016653792583, 0.4686491673103709, 0.41864916731037083],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.13770166537925832, 0.44364916731037085, 0.41864916731037083],
                                [0.8929334178897046, 0.05071574942066623, 0.05635083268962915],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.8936491673103708, 0.05635083268962914, 0.049999999999999996],
                                [0.8872983346207417, 0.05706658211029539, 0.05563508326896291],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.8929334178897046, 0.05635083268962914, 0.050715749420666235],
                                [0.525, 0.22499999999999998, 0.25],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.5281754163448146, 0.25, 0.22182458365518543],
                                [0.5, 0.25317541634481455, 0.24682458365518542],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.525, 0.24999999999999997, 0.225],
                                [0.15706658211029545, 0.3992842505793337, 0.44364916731037085],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.1627016653792584, 0.4436491673103708, 0.39364916731037086],
                                [0.1127016653792583, 0.44928425057933374, 0.43801408404140796],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.1570665821102955, 0.4436491673103708, 0.39928425057933375],
                                [0.8904737509655563, 0.05317541634481457, 0.05635083268962915],
                                [0.8872983346207417, 0.028175416344814574, 0.08452624903444372],
                                [0.9154737509655563, 0.05635083268962915, 0.028175416344814574],
                                [0.8872983346207417, 0.08135083268962914, 0.031350832689629154],
                                [0.8872983346207417, 0.08452624903444372, 0.028175416344814574],
                                [0.8904737509655563, 0.05635083268962915, 0.05317541634481457],
                                [0.5140877081724073, 0.2359122918275927, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.625, 0.25, 0.125],
                                [0.49999999999999994, 0.3609122918275927, 0.1390877081724073],
                                [0.5, 0.375, 0.125],
                                [0.5140877081724073, 0.25, 0.2359122918275927],
                                [0.13770166537925832, 0.41864916731037083, 0.44364916731037085],
                                [0.1127016653792583, 0.22182458365518543, 0.6654737509655563],
                                [0.3345262490344437, 0.44364916731037085, 0.22182458365518543],
                                [0.1127016653792583, 0.6404737509655563, 0.24682458365518542],
                                [0.1127016653792583, 0.6654737509655563, 0.22182458365518543],
                                [0.13770166537925832, 0.44364916731037085, 0.41864916731037083],
                                [0.901386042793149, 0.04226312451722186, 0.05635083268962915],
                                [0.8872983346207417, 0.028175416344814574, 0.08452624903444372],
                                [0.9154737509655563, 0.05635083268962915, 0.028175416344814574],
                                [0.8872983346207417, 0.07043854086203644, 0.04226312451722186],
                                [0.8872983346207417, 0.08452624903444372, 0.028175416344814574],
                                [0.901386042793149, 0.05635083268962915, 0.04226312451722186],
                                [0.5625, 0.1875, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.625, 0.25, 0.125],
                                [0.5, 0.3125, 0.1875],
                                [0.5, 0.375, 0.125],
                                [0.5625, 0.25, 0.1875],
                                [0.22361395720685096, 0.3327368754827782, 0.44364916731037085],
                                [0.1127016653792583, 0.22182458365518543, 0.6654737509655563],
                                [0.3345262490344437, 0.44364916731037085, 0.22182458365518543],
                                [0.1127016653792583, 0.5545614591379635, 0.33273687548277814],
                                [0.1127016653792583, 0.6654737509655563, 0.22182458365518543],
                                [0.2236139572068509, 0.4436491673103709, 0.33273687548277814],
                                [0.9122983346207417, 0.031350832689629154, 0.05635083268962915],
                                [0.8872983346207417, 0.028175416344814574, 0.08452624903444372],
                                [0.9154737509655563, 0.05635083268962915, 0.028175416344814574],
                                [0.8872983346207417, 0.05952624903444373, 0.05317541634481457],
                                [0.8872983346207417, 0.08452624903444372, 0.028175416344814574],
                                [0.9122983346207417, 0.05635083268962915, 0.031350832689629154],
                                [0.6109122918275927, 0.1390877081724073, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.625, 0.25, 0.125],
                                [0.5, 0.2640877081724073, 0.2359122918275927],
                                [0.5, 0.375, 0.125],
                                [0.6109122918275927, 0.25, 0.1390877081724073],
                                [0.3095262490344437, 0.24682458365518545, 0.44364916731037085],
                                [0.1127016653792583, 0.22182458365518543, 0.6654737509655563],
                                [0.3345262490344437, 0.44364916731037085, 0.22182458365518543],
                                [0.1127016653792583, 0.4686491673103709, 0.41864916731037083],
                                [0.1127016653792583, 0.6654737509655563, 0.22182458365518543],
                                [0.3095262490344437, 0.44364916731037085, 0.24682458365518542],
                                [0.8929334178897046, 0.05071574942066623, 0.05635083268962915],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.9372983346207417, 0.056350832689629156, 0.006350832689629154],
                                [0.8872983346207417, 0.10071574942066623, 0.011985915958592068],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8929334178897046, 0.05635083268962914, 0.050715749420666235],
                                [0.525, 0.22499999999999998, 0.25],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.7218245836551854, 0.25, 0.028175416344814574],
                                [0.5, 0.4468245836551854, 0.05317541634481457],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.525, 0.24999999999999997, 0.225],
                                [0.15706658211029545, 0.3992842505793337, 0.44364916731037085],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.1127016653792583, 0.7929334178897046, 0.09436491673103707],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.1570665821102955, 0.4436491673103708, 0.39928425057933375],
                                [0.9122983346207417, 0.031350832689629154, 0.05635083268962915],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.9372983346207417, 0.056350832689629156, 0.006350832689629154],
                                [0.8872983346207417, 0.08135083268962914, 0.031350832689629154],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.9122983346207417, 0.05635083268962915, 0.031350832689629154],
                                [0.6109122918275927, 0.1390877081724073, 0.25],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.7218245836551854, 0.25, 0.028175416344814574],
                                [0.49999999999999994, 0.3609122918275927, 0.1390877081724073],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.6109122918275927, 0.25, 0.1390877081724073],
                                [0.3095262490344437, 0.24682458365518545, 0.44364916731037085],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.1127016653792583, 0.6404737509655563, 0.24682458365518542],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.3095262490344437, 0.44364916731037085, 0.24682458365518542],
                                [0.9316632513517787, 0.01198591595859208, 0.05635083268962915],
                                [0.8872983346207417, 0.00635083268962916, 0.10635083268962914],
                                [0.9372983346207417, 0.056350832689629156, 0.006350832689629154],
                                [0.8872983346207417, 0.06198591595859206, 0.050715749420666235],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.9316632513517787, 0.05635083268962916, 0.011985915958592068],
                                [0.6968245836551854, 0.0531754163448146, 0.25],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.7218245836551854, 0.25, 0.028175416344814574],
                                [0.5, 0.275, 0.225],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.6968245836551854, 0.25, 0.05317541634481457],
                                [0.46198591595859206, 0.09436491673103709, 0.44364916731037085],
                                [0.1127016653792583, 0.050000000000000044, 0.8372983346207417],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.11270166537925835, 0.48801408404140795, 0.39928425057933375],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.46198591595859206, 0.44364916731037085, 0.09436491673103707],
                                [0.8885685011586675, 0.09872983346207416, 0.012701665379258308],
                                [0.8872983346207417, 0.08872983346207416, 0.023971831917184137],
                                [0.8985685011586675, 0.012701665379258306, 0.08872983346207416],
                                [0.8872983346207417, 0.022701665379258315, 0.08999999999999998],
                                [0.8872983346207417, 0.023971831917184133, 0.08872983346207416],
                                [0.8885685011586675, 0.012701665379258306, 0.09872983346207416],
                                [0.5056350832689629, 0.43801408404140796, 0.05635083268962915],
                                [0.49999999999999994, 0.39364916731037086, 0.10635083268962914],
                                [0.55, 0.05635083268962915, 0.39364916731037086],
                                [0.5, 0.10071574942066625, 0.39928425057933375],
                                [0.5, 0.10635083268962914, 0.39364916731037086],
                                [0.5056350832689629, 0.05635083268962915, 0.43801408404140796],
                                [0.1227016653792583, 0.7772983346207417, 0.09999999999999999],
                                [0.1127016653792583, 0.6985685011586675, 0.18872983346207414],
                                [0.2014314988413325, 0.09999999999999998, 0.6985685011586675],
                                [0.1127016653792583, 0.17872983346207416, 0.7085685011586675],
                                [0.1127016653792583, 0.18872983346207417, 0.6985685011586675],
                                [0.1227016653792583, 0.09999999999999998, 0.7772983346207417],
                                [0.8929334178897046, 0.09436491673103707, 0.012701665379258308],
                                [0.8872983346207417, 0.08872983346207416, 0.023971831917184137],
                                [0.8985685011586675, 0.012701665379258306, 0.08872983346207416],
                                [0.8872983346207417, 0.018336748648221213, 0.09436491673103709],
                                [0.8872983346207417, 0.023971831917184133, 0.08872983346207416],
                                [0.8929334178897046, 0.012701665379258306, 0.09436491673103707],
                                [0.525, 0.41864916731037083, 0.05635083268962915],
                                [0.49999999999999994, 0.39364916731037086, 0.10635083268962914],
                                [0.55, 0.05635083268962915, 0.39364916731037086],
                                [0.49999999999999994, 0.08135083268962912, 0.4186491673103709],
                                [0.5, 0.10635083268962914, 0.39364916731037086],
                                [0.525, 0.05635083268962915, 0.41864916731037083],
                                [0.15706658211029545, 0.7429334178897046, 0.09999999999999999],
                                [0.1127016653792583, 0.6985685011586675, 0.18872983346207414],
                                [0.2014314988413325, 0.09999999999999998, 0.6985685011586675],
                                [0.1127016653792583, 0.14436491673103702, 0.7429334178897047],
                                [0.1127016653792583, 0.18872983346207417, 0.6985685011586675],
                                [0.15706658211029545, 0.09999999999999998, 0.7429334178897046],
                                [0.8972983346207417, 0.09, 0.012701665379258308],
                                [0.8872983346207417, 0.08872983346207416, 0.023971831917184137],
                                [0.8985685011586675, 0.012701665379258306, 0.08872983346207416],
                                [0.8872983346207417, 0.013971831917184138, 0.09872983346207416],
                                [0.8872983346207417, 0.023971831917184133, 0.08872983346207416],
                                [0.8972983346207417, 0.01270166537925832, 0.08999999999999998],
                                [0.5443649167310372, 0.39928425057933375, 0.05635083268962915],
                                [0.49999999999999994, 0.39364916731037086, 0.10635083268962914],
                                [0.55, 0.05635083268962915, 0.39364916731037086],
                                [0.5, 0.06198591595859204, 0.43801408404140796],
                                [0.5, 0.10635083268962914, 0.39364916731037086],
                                [0.5443649167310372, 0.05635083268962915, 0.39928425057933375],
                                [0.19143149884133248, 0.7085685011586675, 0.09999999999999999],
                                [0.1127016653792583, 0.6985685011586675, 0.18872983346207414],
                                [0.2014314988413325, 0.09999999999999998, 0.6985685011586675],
                                [0.1127016653792583, 0.10999999999999999, 0.7772983346207417],
                                [0.1127016653792583, 0.18872983346207417, 0.6985685011586675],
                                [0.19143149884133248, 0.09999999999999998, 0.7085685011586675],
                                [0.8929334178897046, 0.09436491673103707, 0.012701665379258308],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.9372983346207416, 0.012701665379258313, 0.049999999999999996],
                                [0.8872983346207417, 0.05706658211029539, 0.05563508326896291],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.8929334178897046, 0.012701665379258306, 0.09436491673103707],
                                [0.525, 0.41864916731037083, 0.05635083268962915],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.7218245836551854, 0.05635083268962915, 0.22182458365518543],
                                [0.5, 0.25317541634481455, 0.24682458365518542],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.525, 0.05635083268962915, 0.41864916731037083],
                                [0.15706658211029545, 0.7429334178897046, 0.09999999999999999],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.5063508326896292, 0.09999999999999998, 0.39364916731037086],
                                [0.1127016653792583, 0.44928425057933374, 0.43801408404140796],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.15706658211029545, 0.09999999999999998, 0.7429334178897046],
                                [0.9122983346207417, 0.075, 0.012701665379258308],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.9372983346207416, 0.012701665379258313, 0.049999999999999996],
                                [0.8872983346207417, 0.0377016653792583, 0.075],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.9122983346207417, 0.012701665379258306, 0.075],
                                [0.6109122918275927, 0.33273687548277814, 0.05635083268962915],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.7218245836551854, 0.05635083268962915, 0.22182458365518543],
                                [0.49999999999999994, 0.16726312451722186, 0.33273687548277814],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.6109122918275927, 0.05635083268962915, 0.33273687548277814],
                                [0.3095262490344437, 0.5904737509655563, 0.09999999999999999],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.5063508326896292, 0.09999999999999998, 0.39364916731037086],
                                [0.1127016653792583, 0.2968245836551854, 0.5904737509655563],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.3095262490344437, 0.09999999999999998, 0.5904737509655563],
                                [0.9316632513517787, 0.05563508326896292, 0.012701665379258308],
                                [0.8872983346207417, 0.04999999999999999, 0.06270166537925831],
                                [0.9372983346207416, 0.012701665379258313, 0.049999999999999996],
                                [0.8872983346207417, 0.018336748648221227, 0.09436491673103707],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.9316632513517787, 0.01270166537925832, 0.05563508326896291],
                                [0.6968245836551854, 0.24682458365518545, 0.05635083268962915],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.7218245836551854, 0.05635083268962915, 0.22182458365518543],
                                [0.5, 0.08135083268962917, 0.41864916731037083],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.6968245836551854, 0.05635083268962918, 0.24682458365518542],
                                [0.46198591595859206, 0.43801408404140796, 0.09999999999999999],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.5063508326896292, 0.09999999999999998, 0.39364916731037086],
                                [0.1127016653792583, 0.14436491673103713, 0.7429334178897046],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.46198591595859206, 0.09999999999999998, 0.43801408404140796],
                                [0.8972983346207417, 0.09, 0.012701665379258308],
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.9760281680828159, 0.01270166537925831, 0.011270166537925827],
                                [0.8872983346207417, 0.09143149884133248, 0.021270166537925825],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925827],
                                [0.8972983346207417, 0.01270166537925832, 0.08999999999999998],
                                [0.5443649167310372, 0.39928425057933375, 0.05635083268962915],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.8936491673103708, 0.05635083268962915, 0.04999999999999999],
                                [0.5, 0.4056350832689629, 0.09436491673103707],
                                [0.49999999999999994, 0.45, 0.04999999999999999],
                                [0.5443649167310372, 0.05635083268962915, 0.39928425057933375],
                                [0.19143149884133248, 0.7085685011586675, 0.09999999999999999],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.8112701665379258, 0.09999999999999999, 0.08872983346207415],
                                [0.1127016653792583, 0.7198386676965933, 0.16745966692414832],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207415],
                                [0.19143149884133248, 0.09999999999999998, 0.7085685011586675],
                                [0.9316632513517787, 0.05563508326896292, 0.012701665379258308],
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.9760281680828159, 0.01270166537925831, 0.011270166537925827],
                                [0.8872983346207417, 0.05706658211029539, 0.05563508326896291],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925827],
                                [0.9316632513517787, 0.01270166537925832, 0.05563508326896291],
                                [0.6968245836551854, 0.24682458365518545, 0.05635083268962915],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.8936491673103708, 0.05635083268962915, 0.04999999999999999],
                                [0.5, 0.25317541634481455, 0.24682458365518542],
                                [0.49999999999999994, 0.45, 0.04999999999999999],
                                [0.6968245836551854, 0.05635083268962918, 0.24682458365518542],
                                [0.46198591595859206, 0.43801408404140796, 0.09999999999999999],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.8112701665379258, 0.09999999999999999, 0.08872983346207415],
                                [0.1127016653792583, 0.44928425057933374, 0.43801408404140796],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207415],
                                [0.46198591595859206, 0.09999999999999998, 0.43801408404140796],
                                [0.9660281680828159, 0.02127016653792583, 0.012701665379258308],
                                [0.8872983346207417, 0.011270166537925827, 0.10143149884133247],
                                [0.9760281680828159, 0.01270166537925831, 0.011270166537925827],
                                [0.8872983346207417, 0.022701665379258315, 0.08999999999999998],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925827],
                                [0.9660281680828159, 0.012701665379258306, 0.02127016653792583],
                                [0.8492842505793338, 0.09436491673103709, 0.05635083268962915],
                                [0.5, 0.04999999999999999, 0.45],
                                [0.8936491673103708, 0.05635083268962915, 0.04999999999999999],
                                [0.5, 0.10071574942066625, 0.39928425057933375],
                                [0.49999999999999994, 0.45, 0.04999999999999999],
                                [0.8492842505793338, 0.05635083268962915, 0.09436491673103709],
                                [0.7325403330758516, 0.16745966692414838, 0.09999999999999999],
                                [0.1127016653792583, 0.08872983346207419, 0.7985685011586675],
                                [0.8112701665379258, 0.09999999999999999, 0.08872983346207415],
                                [0.1127016653792583, 0.17872983346207416, 0.7085685011586675],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207415],
                                [0.7325403330758516, 0.1, 0.16745966692414835],
                            ]
                        ),
                        np.array(
                            [
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                1.9520546912972805e-08,
                                1.9520546912972805e-08,
                                1.9520546912972805e-08,
                                1.9520546912972805e-08,
                                1.9520546912972805e-08,
                                1.9520546912972805e-08,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                1.3856439013413464e-07,
                                1.3856439013413464e-07,
                                1.3856439013413464e-07,
                                1.3856439013413464e-07,
                                1.3856439013413464e-07,
                                1.3856439013413464e-07,
                                1.935934366599346e-05,
                                1.935934366599346e-05,
                                1.935934366599346e-05,
                                1.935934366599346e-05,
                                1.935934366599346e-05,
                                1.935934366599346e-05,
                                6.761913844084301e-05,
                                6.761913844084301e-05,
                                6.761913844084301e-05,
                                6.761913844084301e-05,
                                6.761913844084301e-05,
                                6.761913844084301e-05,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                1.5368494075469554e-07,
                                1.5368494075469554e-07,
                                1.5368494075469554e-07,
                                1.5368494075469554e-07,
                                1.5368494075469554e-07,
                                1.5368494075469554e-07,
                                2.147189174273326e-05,
                                2.147189174273326e-05,
                                2.147189174273326e-05,
                                2.147189174273326e-05,
                                2.147189174273326e-05,
                                2.147189174273326e-05,
                                7.499793615881173e-05,
                                7.499793615881173e-05,
                                7.499793615881173e-05,
                                7.499793615881173e-05,
                                7.499793615881173e-05,
                                7.499793615881173e-05,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                6.147397630187821e-07,
                                6.147397630187821e-07,
                                6.147397630187821e-07,
                                6.147397630187821e-07,
                                6.147397630187821e-07,
                                6.147397630187821e-07,
                                8.588756697093301e-05,
                                8.588756697093301e-05,
                                8.588756697093301e-05,
                                8.588756697093301e-05,
                                8.588756697093301e-05,
                                8.588756697093301e-05,
                                0.0002999917446352469,
                                0.0002999917446352469,
                                0.0002999917446352469,
                                0.0002999917446352469,
                                0.0002999917446352469,
                                0.0002999917446352469,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                4.363660543613718e-06,
                                4.363660543613718e-06,
                                4.363660543613718e-06,
                                4.363660543613718e-06,
                                4.363660543613718e-06,
                                4.363660543613718e-06,
                                0.0006096631611034902,
                                0.0006096631611034902,
                                0.0006096631611034902,
                                0.0006096631611034902,
                                0.0006096631611034902,
                                0.0006096631611034902,
                                0.002129457403318603,
                                0.002129457403318603,
                                0.002129457403318603,
                                0.002129457403318603,
                                0.002129457403318603,
                                0.002129457403318603,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                4.839835916498366e-06,
                                4.839835916498366e-06,
                                4.839835916498366e-06,
                                4.839835916498366e-06,
                                4.839835916498366e-06,
                                4.839835916498366e-06,
                                0.0006761913844084299,
                                0.0006761913844084299,
                                0.0006761913844084299,
                                0.0006761913844084299,
                                0.0006761913844084299,
                                0.0006761913844084299,
                                0.0023618300095130072,
                                0.0023618300095130072,
                                0.0023618300095130072,
                                0.0023618300095130072,
                                0.0023618300095130072,
                                0.0023618300095130072,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                1.2099589791245916e-06,
                                1.2099589791245916e-06,
                                1.2099589791245916e-06,
                                1.2099589791245916e-06,
                                1.2099589791245916e-06,
                                1.2099589791245916e-06,
                                0.00016904784610210754,
                                0.00016904784610210754,
                                0.00016904784610210754,
                                0.00016904784610210754,
                                0.00016904784610210754,
                                0.00016904784610210754,
                                0.0005904575023782519,
                                0.0005904575023782519,
                                0.0005904575023782519,
                                0.0005904575023782519,
                                0.0005904575023782519,
                                0.0005904575023782519,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                8.588756697093304e-06,
                                8.588756697093304e-06,
                                8.588756697093304e-06,
                                8.588756697093304e-06,
                                8.588756697093304e-06,
                                8.588756697093304e-06,
                                0.0011999669785409872,
                                0.0011999669785409872,
                                0.0011999669785409872,
                                0.0011999669785409872,
                                0.0011999669785409872,
                                0.0011999669785409872,
                                0.004191295668196364,
                                0.004191295668196364,
                                0.004191295668196364,
                                0.004191295668196364,
                                0.004191295668196364,
                                0.004191295668196364,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.004648662082867204,
                                0.004648662082867204,
                                0.004648662082867204,
                                0.004648662082867204,
                                0.004648662082867204,
                                0.004648662082867204,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                            ]
                        ),
                    )
                case 4:
                    return (
                        np.array(
                            [
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9305913957263743, 0.004797541060078014, 0.06461106321354769],
                                [0.9305681557970262, 0.06492253899879417, 0.004509305204179541],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9305913957263743, 0.0646110632135477, 0.004797541060078003],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.6701009811507492, 0.022802707318091586, 0.30709631153115907],
                                [0.6699905217924282, 0.3085767555917113, 0.02143272261586052],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.6701009811507495, 0.30709631153115907, 0.02280270731809158],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.3302337345638452, 0.0462944211702877, 0.6234718442658671],
                                [0.33000947820757187, 0.6264774654801465, 0.04351305631228167],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.3302337345638452, 0.6234718442658671, 0.046294421170287654],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.06974331998822025, 0.06429958742830122, 0.8659570925834785],
                                [0.06943184420297377, 0.8701316820730636, 0.06043647372396264],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.06974331998822025, 0.8659570925834785, 0.06429958742830123],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9306786151553474, 0.004710321631104825, 0.06461106321354769],
                                [0.9305681557970262, 0.06483531956982098, 0.00459652463315273],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9306786151553474, 0.0646110632135477, 0.004710321631104814],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.6705155349995692, 0.0223881534692717, 0.30709631153115907],
                                [0.669990521792428, 0.3081622017428915, 0.02184727646468039],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.6705155349995693, 0.30709631153115907, 0.02238815346927171],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.3310753684193043, 0.0454527873148286, 0.6234718442658671],
                                [0.33000947820757187, 0.6256358316246874, 0.04435469016774077],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.3310753684193043, 0.6234718442658671, 0.045452787314828554],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.07091228826352602, 0.06313061915299545, 0.8659570925834785],
                                [0.06943184420297377, 0.8689627137977578, 0.06160544199926842],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.07091228826352602, 0.8659570925834785, 0.06313061915299543],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9307924121532996, 0.004596524633152743, 0.06461106321354769],
                                [0.9305681557970262, 0.0647215225718689, 0.004710321631104814],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9307924121532996, 0.0646110632135477, 0.00459652463315273],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.6710564120041604, 0.021847276464680376, 0.30709631153115907],
                                [0.6699905217924281, 0.3076213247383002, 0.02238815346927171],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.6710564120041604, 0.30709631153115907, 0.02184727646468039],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.33217346556639205, 0.04435469016774085, 0.6234718442658671],
                                [0.33000947820757187, 0.6245377344775995, 0.045452787314828554],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.33217346556639205, 0.6234718442658672, 0.04435469016774077],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.07243746541725304, 0.06160544199926843, 0.8659570925834785],
                                [0.06943184420297377, 0.8674375366440308, 0.06313061915299543],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.07243746541725304, 0.8659570925834785, 0.06160544199926842],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9308796315822727, 0.004509305204179553, 0.06461106321354769],
                                [0.9305681557970262, 0.06463430314289571, 0.004797541060078003],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9308796315822727, 0.0646110632135477, 0.004509305204179541],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.6714709658529803, 0.021432722615860544, 0.30709631153115907],
                                [0.6699905217924282, 0.3072067708894803, 0.02280270731809158],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.6714709658529805, 0.30709631153115907, 0.02143272261586052],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.33301509942185115, 0.04351305631228175, 0.6234718442658671],
                                [0.33000947820757187, 0.6236961006221404, 0.046294421170287654],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.33301509942185115, 0.6234718442658672, 0.04351305631228167],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.07360643369255881, 0.06043647372396266, 0.8659570925834785],
                                [0.06943184420297377, 0.866268568368725, 0.06429958742830123],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.07360643369255881, 0.8659570925834785, 0.06043647372396264],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9306786151553474, 0.004710321631104825, 0.06461106321354769],
                                [0.9305681557970263, 0.06609150727409996, 0.0033403369288737537],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9306786151553474, 0.0646110632135477, 0.004710321631104814],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.6705155349995692, 0.0223881534692717, 0.30709631153115907],
                                [0.6699905217924282, 0.3141328605029841, 0.01587661770458775],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6705155349995693, 0.30709631153115907, 0.02238815346927171],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.3310753684193043, 0.0454527873148286, 0.6234718442658671],
                                [0.33000947820757187, 0.6377575585515814, 0.03223296324084665],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.3310753684193043, 0.6234718442658671, 0.045452787314828554],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.07091228826352602, 0.06313061915299545, 0.8659570925834785],
                                [0.06943184420297377, 0.8857989117804655, 0.04476924401656064],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.07091228826352602, 0.8659570925834785, 0.06313061915299543],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600838],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9310931690041674, 0.004295767782284951, 0.06461106321354769],
                                [0.9305681557970262, 0.06567695342528009, 0.0037548907776936264],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9310931690041674, 0.0646110632135477, 0.0042957677822849415],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.6724859089815427, 0.020417779487298116, 0.30709631153115907],
                                [0.6699905217924282, 0.3121624865210105, 0.01784699168656139],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6724859089815428, 0.3070963115311591, 0.020417779487298063],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.3350756531974233, 0.04145250253670962, 0.6234718442658671],
                                [0.33000947820757187, 0.6337572737734625, 0.03623324801896565],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.3350756531974233, 0.6234718442658672, 0.04145250253670954],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.07646839317479881, 0.05757451424172266, 0.8659570925834785],
                                [0.06943184420297377, 0.8802428068691928, 0.05032534892783341],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.07646839317479881, 0.8659570925834785, 0.05757451424172266],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600838],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9316340460087587, 0.0037548907776936424, 0.06461106321354769],
                                [0.9305681557970263, 0.06513607642068878, 0.0042957677822849415],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9316340460087587, 0.0646110632135477, 0.0037548907776936264],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.6750566967822795, 0.017846991686561398, 0.30709631153115907],
                                [0.6699905217924281, 0.3095916987202738, 0.020417779487298063],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6750566967822795, 0.30709631153115907, 0.01784699168656139],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.3402949077151671, 0.03623324801896577, 0.6234718442658671],
                                [0.33000947820757187, 0.6285380192557186, 0.04145250253670954],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.3402949077151671, 0.6234718442658672, 0.03623324801896565],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.083717558488688, 0.05032534892783347, 0.8659570925834785],
                                [0.06943184420297377, 0.8729936415553036, 0.05757451424172266],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.083717558488688, 0.8659570925834785, 0.05032534892783341],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600838],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9320485998575785, 0.003340336928873769, 0.06461106321354769],
                                [0.9305681557970262, 0.0647215225718689, 0.004710321631104813],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9320485998575786, 0.0646110632135477, 0.0033403369288737537],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.6770270707642532, 0.01587661770458776, 0.30709631153115907],
                                [0.6699905217924281, 0.3076213247383002, 0.022388153469271702],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6770270707642532, 0.30709631153115907, 0.01587661770458775],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.3442951924932861, 0.03223296324084679, 0.6234718442658671],
                                [0.33000947820757187, 0.6245377344775996, 0.04545278731482854],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.3442951924932861, 0.6234718442658672, 0.03223296324084665],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.08927366339996079, 0.04476924401656068, 0.8659570925834785],
                                [0.06943184420297377, 0.8674375366440308, 0.06313061915299543],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.08927366339996079, 0.8659570925834785, 0.04476924401656064],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600838],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9307924121532996, 0.004596524633152743, 0.06461106321354769],
                                [0.9305681557970262, 0.06761668442782696, 0.0018151597751467452],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9307924121532996, 0.0646110632135477, 0.00459652463315273],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.6710564120041604, 0.021847276464680376, 0.30709631153115907],
                                [0.6699905217924281, 0.32138202581687336, 0.008627452390698493],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.6710564120041604, 0.30709631153115907, 0.02184727646468039],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.33217346556639205, 0.04435469016774085, 0.6234718442658671],
                                [0.33000947820757187, 0.6524749299361613, 0.01751559185626684],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.33217346556639205, 0.6234718442658672, 0.04435469016774077],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.07243746541725304, 0.06160544199926843, 0.8659570925834785],
                                [0.06943184420297377, 0.9062402713252077, 0.024327884471818585],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.07243746541725304, 0.8659570925834785, 0.06160544199926842],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9316340460087587, 0.0037548907776936424, 0.06461106321354769],
                                [0.9305681557970262, 0.06677505057236786, 0.002656793630605849],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9316340460087587, 0.0646110632135477, 0.0037548907776936264],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.6750566967822795, 0.017846991686561398, 0.30709631153115907],
                                [0.6699905217924281, 0.3173817410387544, 0.012627737168817495],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.6750566967822795, 0.30709631153115907, 0.01784699168656139],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.3402949077151671, 0.03623324801896577, 0.6234718442658671],
                                [0.33000947820757187, 0.6443534877873862, 0.025637034005041956],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.3402949077151671, 0.6234718442658672, 0.03623324801896565],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.083717558488688, 0.05032534892783347, 0.8659570925834785],
                                [0.06943184420297377, 0.8949601782537726, 0.0356079775432536],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.083717558488688, 0.8659570925834785, 0.05032534892783341],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9327321431558464, 0.0026567936306058637, 0.06461106321354769],
                                [0.9305681557970262, 0.06567695342528009, 0.0037548907776936264],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9327321431558464, 0.0646110632135477, 0.0026567936306058494],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.6802759513000234, 0.012627737168817543, 0.30709631153115907],
                                [0.6699905217924282, 0.3121624865210105, 0.01784699168656139],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.6802759513000234, 0.3070963115311591, 0.012627737168817496],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.35089112172909087, 0.025637034005042025, 0.6234718442658671],
                                [0.33000947820757187, 0.6337572737734625, 0.03623324801896565],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.35089112172909087, 0.6234718442658672, 0.02563703400504196],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.09843492987326785, 0.03560797754325362, 0.8659570925834785],
                                [0.06943184420297377, 0.8802428068691928, 0.05032534892783341],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.09843492987326785, 0.8659570925834785, 0.03560797754325361],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9335737770113055, 0.001815159775146749, 0.06461106321354769],
                                [0.9305681557970262, 0.06483531956982098, 0.00459652463315273],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9335737770113055, 0.06461106321354769, 0.0018151597751467454],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.6842762360781424, 0.008627452390698509, 0.30709631153115907],
                                [0.669990521792428, 0.3081622017428915, 0.02184727646468039],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.6842762360781425, 0.30709631153115907, 0.008627452390698493],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.35901256387786595, 0.017515591856266943, 0.6234718442658671],
                                [0.33000947820757187, 0.6256358316246874, 0.04435469016774077],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.35901256387786595, 0.6234718442658672, 0.01751559185626684],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.10971502294470292, 0.02432788447181855, 0.8659570925834785],
                                [0.06943184420297377, 0.8689627137977578, 0.06160544199926842],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.10971502294470292, 0.8659570925834785, 0.02432788447181859],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.9305681557970262, 0.000334715714594494, 0.06909712848837922],
                                [0.9308796315822727, 0.004509305204179553, 0.06461106321354769],
                                [0.9305681557970263, 0.06878565270313275, 0.0006461914998409584],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9308796315822727, 0.0646110632135477, 0.004509305204179541],
                                [0.9305681557970262, 0.06909712848837923, 0.00033471571459448517],
                                [0.6699905217924281, 0.0015909034188734683, 0.3284185747886984],
                                [0.6714709658529803, 0.021432722615860544, 0.30709631153115907],
                                [0.6699905217924281, 0.32693813072814615, 0.003071347479425725],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6714709658529805, 0.30709631153115907, 0.02143272261586052],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734642],
                                [0.33000947820757187, 0.0032298775705525973, 0.6667606442218755],
                                [0.33301509942185115, 0.04351305631228175, 0.6234718442658671],
                                [0.33000947820757187, 0.6637550230075963, 0.006235498784831829],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.33301509942185115, 0.6234718442658672, 0.04351305631228167],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525595],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.07360643369255881, 0.06043647372396266, 0.8659570925834785],
                                [0.06943184420297377, 0.9219075010326097, 0.008660654764416595],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.07360643369255881, 0.8659570925834785, 0.06043647372396264],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831539],
                                [0.9305681557970262, 0.000334715714594494, 0.06909712848837922],
                                [0.9320485998575785, 0.003340336928873769, 0.06461106321354769],
                                [0.9305681557970262, 0.06761668442782696, 0.0018151597751467456],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9320485998575786, 0.0646110632135477, 0.0033403369288737537],
                                [0.9305681557970262, 0.06909712848837923, 0.00033471571459448517],
                                [0.6699905217924281, 0.0015909034188734683, 0.3284185747886984],
                                [0.6770270707642532, 0.01587661770458776, 0.30709631153115907],
                                [0.6699905217924281, 0.32138202581687336, 0.008627452390698495],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6770270707642532, 0.30709631153115907, 0.01587661770458775],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734642],
                                [0.33000947820757187, 0.0032298775705525973, 0.6667606442218755],
                                [0.3442951924932861, 0.03223296324084679, 0.6234718442658671],
                                [0.33000947820757187, 0.6524749299361613, 0.017515591856266843],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.3442951924932861, 0.6234718442658672, 0.03223296324084665],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525595],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.08927366339996079, 0.04476924401656068, 0.8659570925834785],
                                [0.06943184420297377, 0.9062402713252077, 0.024327884471818592],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.08927366339996079, 0.8659570925834785, 0.04476924401656064],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831539],
                                [0.9305681557970262, 0.000334715714594494, 0.06909712848837922],
                                [0.9335737770113055, 0.001815159775146763, 0.06461106321354769],
                                [0.9305681557970263, 0.06609150727409996, 0.0033403369288737537],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9335737770113055, 0.0646110632135477, 0.0018151597751467458],
                                [0.9305681557970262, 0.06909712848837923, 0.00033471571459448517],
                                [0.6699905217924281, 0.0015909034188734683, 0.3284185747886984],
                                [0.6842762360781424, 0.008627452390698509, 0.30709631153115907],
                                [0.6699905217924282, 0.3141328605029841, 0.01587661770458775],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6842762360781425, 0.30709631153115907, 0.008627452390698495],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734642],
                                [0.33000947820757187, 0.0032298775705525973, 0.6667606442218755],
                                [0.35901256387786595, 0.017515591856266943, 0.6234718442658671],
                                [0.33000947820757187, 0.6377575585515814, 0.03223296324084665],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.35901256387786595, 0.6234718442658672, 0.017515591856266846],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525595],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.10971502294470281, 0.02432788447181866, 0.8659570925834785],
                                [0.06943184420297377, 0.8857989117804655, 0.04476924401656064],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.10971502294470281, 0.8659570925834786, 0.024327884471818596],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831539],
                                [0.9305681557970262, 0.000334715714594494, 0.06909712848837922],
                                [0.9347427452866113, 0.0006461914998409646, 0.06461106321354769],
                                [0.9305681557970262, 0.06492253899879417, 0.004509305204179541],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9347427452866114, 0.06461106321354769, 0.0006461914998409584],
                                [0.9305681557970262, 0.06909712848837923, 0.00033471571459448517],
                                [0.6699905217924281, 0.0015909034188734683, 0.3284185747886984],
                                [0.6898323409894151, 0.0030713474794257234, 0.30709631153115907],
                                [0.6699905217924282, 0.3085767555917113, 0.02143272261586052],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6898323409894151, 0.30709631153115907, 0.003071347479425725],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734642],
                                [0.33000947820757187, 0.0032298775705525973, 0.6667606442218755],
                                [0.370292656949301, 0.006235498784831872, 0.6234718442658671],
                                [0.33000947820757187, 0.6264774654801465, 0.04351305631228167],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.370292656949301, 0.6234718442658671, 0.006235498784831829],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525595],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.1253822526521049, 0.008660654764416575, 0.8659570925834785],
                                [0.06943184420297377, 0.8701316820730636, 0.06043647372396264],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.1253822526521049, 0.8659570925834785, 0.008660654764416595],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831539],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9306786151553476, 0.02280270731809158, 0.046518677526560935],
                                [0.9305681557970263, 0.0479991215871132, 0.021432722615860517],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9306786151553476, 0.046518677526560935, 0.02280270731809158],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.6705155349995693, 0.10838124249969275, 0.22110322250073802],
                                [0.6699905217924281, 0.22813977147256304, 0.10186970673500882],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.6705155349995692, 0.221103222500738, 0.10838124249969278],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.3310753684193043, 0.22003733228900557, 0.44888729929169013],
                                [0.33000947820757187, 0.46317301357740437, 0.20681750821502373],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.33107536841930424, 0.4488872992916901, 0.22003733228900563],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.07091228826352602, 0.3056158674706069, 0.6234718442658671],
                                [0.06943184420297377, 0.6433136634628542, 0.287254492334172],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.07091228826352602, 0.6234718442658671, 0.3056158674706068],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9310931690041674, 0.022388153469271706, 0.046518677526560935],
                                [0.9305681557970262, 0.047584567738293324, 0.021847276464680387],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9310931690041674, 0.046518677526560935, 0.022388153469271706],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.6724859089815428, 0.10641086851771916, 0.22110322250073802],
                                [0.6699905217924281, 0.22616939749058942, 0.10384008071698245],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.6724859089815427, 0.22110322250073805, 0.10641086851771915],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.3350756531974233, 0.2160370475108866, 0.44888729929169013],
                                [0.33000947820757187, 0.4591727287992854, 0.2108177929931427],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.33507565319742333, 0.4488872992916901, 0.21603704751088665],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.07646839317479881, 0.3000597625593341, 0.6234718442658671],
                                [0.06943184420297377, 0.6377575585515816, 0.2928105972454447],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.07646839317479881, 0.6234718442658671, 0.3000597625593341],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9316340460087587, 0.021847276464680397, 0.046518677526560935],
                                [0.9305681557970262, 0.047043690733702015, 0.022388153469271702],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9316340460087587, 0.04651867752656094, 0.021847276464680394],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.6750566967822795, 0.10384008071698245, 0.22110322250073802],
                                [0.6699905217924282, 0.22359860968985273, 0.10641086851771912],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.6750566967822795, 0.221103222500738, 0.10384008071698247],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.3402949077151671, 0.21081779299314274, 0.44888729929169013],
                                [0.33000947820757187, 0.45395347428154154, 0.2160370475108866],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.3402949077151671, 0.44888729929169013, 0.21081779299314274],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.083717558488688, 0.2928105972454449, 0.6234718442658671],
                                [0.06943184420297377, 0.6305083932376923, 0.30005976255933403],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.083717558488688, 0.6234718442658672, 0.2928105972454448],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9320485998575786, 0.021432722615860524, 0.046518677526560935],
                                [0.9305681557970263, 0.046629136884882134, 0.02280270731809158],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9320485998575786, 0.04651867752656094, 0.021432722615860517],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.6770270707642532, 0.10186970673500881, 0.22110322250073802],
                                [0.669990521792428, 0.2216282357078791, 0.10838124249969278],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.6770270707642532, 0.221103222500738, 0.10186970673500882],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.3442951924932861, 0.20681750821502376, 0.44888729929169013],
                                [0.3300094782075718, 0.4499531895034225, 0.22003733228900563],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.3442951924932861, 0.44888729929169013, 0.20681750821502373],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.08927366339996079, 0.2872544923341721, 0.6234718442658671],
                                [0.06943184420297377, 0.6249522883264194, 0.3056158674706068],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.08927366339996079, 0.6234718442658672, 0.287254492334172],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9310931690041674, 0.022388153469271706, 0.046518677526560935],
                                [0.9305681557970263, 0.05355522649838597, 0.01587661770458775],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.9310931690041674, 0.046518677526560935, 0.022388153469271706],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.6724859089815428, 0.10641086851771916, 0.22110322250073802],
                                [0.6699905217924281, 0.2545479319309759, 0.07546154627659593],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.6724859089815427, 0.22110322250073805, 0.10641086851771915],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.3350756531974233, 0.2160370475108866, 0.44888729929169013],
                                [0.33000947820757187, 0.5167872833893199, 0.1532032384031082],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.33507565319742333, 0.4488872992916901, 0.21603704751088665],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.07646839317479881, 0.3000597625593341, 0.6234718442658671],
                                [0.06943184420297377, 0.7177799888219099, 0.21278816697511638],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.07646839317479881, 0.6234718442658671, 0.3000597625593341],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.933063542986141, 0.020417779487298067, 0.046518677526560935],
                                [0.9305681557970263, 0.05158485251641233, 0.017846991686561387],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.933063542986141, 0.04651867752656094, 0.020417779487298063],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.6818510943245104, 0.09704568317475157, 0.22110322250073802],
                                [0.6699905217924282, 0.24518274658800837, 0.0848267316195635],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.6818510943245104, 0.22110322250073802, 0.09704568317475157],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.3540890022948422, 0.19702369841346767, 0.44888729929169013],
                                [0.33000947820757187, 0.497773934291901, 0.17221658750052715],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.3540890022948422, 0.44888729929169013, 0.19702369841346765],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.10287655363321169, 0.2736516021009212, 0.6234718442658671],
                                [0.06943184420297377, 0.691371828363497, 0.23919632743352925],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.10287655363321169, 0.6234718442658671, 0.27365160210092115],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9356343307868777, 0.01784699168656139, 0.046518677526560935],
                                [0.9305681557970263, 0.04901406471567565, 0.020417779487298067],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.9356343307868777, 0.04651867752656094, 0.017846991686561387],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.6940700458796986, 0.08482673161956347, 0.22110322250073802],
                                [0.6699905217924281, 0.23296379503282028, 0.09704568317475158],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.6940700458796986, 0.221103222500738, 0.0848267316195635],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.3788961132077828, 0.17221658750052704, 0.44888729929169013],
                                [0.33000947820757187, 0.47296682337896045, 0.19702369841346767],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.3788961132077828, 0.44888729929169, 0.17221658750052715],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.13733182830060364, 0.23919632743352925, 0.6234718442658671],
                                [0.06943184420297377, 0.656916553696105, 0.2736516021009212],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.13733182830060364, 0.6234718442658671, 0.23919632743352925],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9376047047688514, 0.015876617704587752, 0.046518677526560935],
                                [0.9305681557970263, 0.04704369073370201, 0.022388153469271706],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.9376047047688514, 0.04651867752656094, 0.01587661770458775],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.703435231222666, 0.07546154627659593, 0.22110322250073802],
                                [0.669990521792428, 0.22359860968985273, 0.10641086851771915],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.703435231222666, 0.22110322250073802, 0.07546154627659593],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.39790946230520163, 0.15320323840310823, 0.44888729929169013],
                                [0.3300094782075719, 0.4539534742815415, 0.21603704751088665],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.39790946230520163, 0.44888729929169013, 0.1532032384031082],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.1637399887590164, 0.2127881669751165, 0.6234718442658671],
                                [0.06943184420297377, 0.6305083932376921, 0.3000597625593341],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.1637399887590164, 0.6234718442658672, 0.21278816697511638],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.9305681557970263, 0.007561562178966107, 0.06187028202400761],
                                [0.9316340460087587, 0.021847276464680397, 0.046518677526560935],
                                [0.9305681557970262, 0.06080439181227522, 0.008627452390698493],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9316340460087587, 0.04651867752656094, 0.021847276464680394],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.6699905217924282, 0.03594009661935266, 0.2940693815882192],
                                [0.6750566967822795, 0.10384008071698245, 0.22110322250073802],
                                [0.6699905217924281, 0.28900320659836787, 0.041006271609204024],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.6750566967822795, 0.221103222500738, 0.10384008071698247],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.33000947820757187, 0.07296615908748127, 0.5970243627049469],
                                [0.3402949077151671, 0.21081779299314274, 0.44888729929169013],
                                [0.33000947820757187, 0.5867389331973516, 0.08325158859507649],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.3402949077151671, 0.44888729929169013, 0.21081779299314274],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.06943184420297377, 0.10134469352786779, 0.8292234622691584],
                                [0.083717558488688, 0.2928105972454449, 0.6234718442658671],
                                [0.06943184420297377, 0.8149377479834442, 0.11563040781358203],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.083717558488688, 0.6234718442658672, 0.2928105972454448],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.9305681557970263, 0.007561562178966107, 0.06187028202400761],
                                [0.9356343307868777, 0.01784699168656139, 0.046518677526560935],
                                [0.9305681557970263, 0.05680410703415622, 0.012627737168817495],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9356343307868777, 0.04651867752656094, 0.017846991686561387],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.6699905217924282, 0.03594009661935266, 0.2940693815882192],
                                [0.6940700458796986, 0.08482673161956347, 0.22110322250073802],
                                [0.669990521792428, 0.2699898575009489, 0.06001962070662299],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.6940700458796986, 0.221103222500738, 0.0848267316195635],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.33000947820757187, 0.07296615908748127, 0.5970243627049469],
                                [0.3788961132077828, 0.17221658750052704, 0.44888729929169013],
                                [0.33000947820757187, 0.548137727704736, 0.12185279408769208],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.3788961132077828, 0.44888729929169, 0.17221658750052715],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.06943184420297377, 0.10134469352786779, 0.8292234622691584],
                                [0.13733182830060364, 0.23919632743352925, 0.6234718442658671],
                                [0.06943184420297377, 0.7613234781715287, 0.16924467762549755],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.13733182830060364, 0.6234718442658671, 0.23919632743352925],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.9305681557970263, 0.007561562178966107, 0.06187028202400761],
                                [0.9408535853046216, 0.012627737168817495, 0.046518677526560935],
                                [0.9305681557970263, 0.05158485251641233, 0.017846991686561387],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9408535853046216, 0.046518677526560935, 0.012627737168817495],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.6699905217924282, 0.03594009661935266, 0.2940693815882192],
                                [0.7188771567926391, 0.06001962070662295, 0.22110322250073802],
                                [0.6699905217924282, 0.24518274658800837, 0.0848267316195635],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.718877156792639, 0.221103222500738, 0.06001962070662299],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.33000947820757187, 0.07296615908748127, 0.5970243627049469],
                                [0.42925990662061786, 0.121852794087692, 0.44888729929169013],
                                [0.33000947820757187, 0.497773934291901, 0.17221658750052715],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.4292599066206178, 0.4488872992916901, 0.12185279408769208],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.06943184420297377, 0.10134469352786779, 0.8292234622691584],
                                [0.20728347810863534, 0.16924467762549755, 0.6234718442658671],
                                [0.06943184420297377, 0.691371828363497, 0.23919632743352925],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.20728347810863534, 0.6234718442658671, 0.16924467762549755],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.9305681557970263, 0.007561562178966107, 0.06187028202400761],
                                [0.9448538700827406, 0.008627452390698495, 0.046518677526560935],
                                [0.9305681557970262, 0.047584567738293324, 0.021847276464680394],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9448538700827406, 0.046518677526560935, 0.008627452390698493],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.6699905217924282, 0.03594009661935266, 0.2940693815882192],
                                [0.737890505890058, 0.04100627160920403, 0.22110322250073802],
                                [0.6699905217924281, 0.2261693974905894, 0.10384008071698247],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.737890505890058, 0.22110322250073802, 0.04100627160920403],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.33000947820757187, 0.07296615908748127, 0.5970243627049469],
                                [0.46786111211323334, 0.08325158859507653, 0.44888729929169013],
                                [0.33000947820757187, 0.4591727287992854, 0.21081779299314274],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.46786111211323334, 0.44888729929169013, 0.0832515885950765],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.06943184420297377, 0.10134469352786779, 0.8292234622691584],
                                [0.26089774792055076, 0.11563040781358214, 0.6234718442658671],
                                [0.06943184420297377, 0.6377575585515814, 0.2928105972454448],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.26089774792055076, 0.6234718442658672, 0.11563040781358204],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9320485998575786, 0.021432722615860524, 0.046518677526560935],
                                [0.9305681557970262, 0.06636049672354799, 0.003071347479425723],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9320485998575786, 0.04651867752656094, 0.021432722615860517],
                                [0.9305681557970262, 0.06784094078410025, 0.0015909034188734625],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.6770270707642532, 0.10186970673500881, 0.22110322250073802],
                                [0.6699905217924281, 0.31541136705678074, 0.014598111150791144],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.6770270707642532, 0.221103222500738, 0.10186970673500882],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966112],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.3442951924932861, 0.20681750821502376, 0.44888729929169013],
                                [0.33000947820757187, 0.6403532030092671, 0.029637318783160973],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.3442951924932861, 0.44888729929169013, 0.20681750821502373],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446688],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.08927366339996079, 0.2872544923341721, 0.6234718442658671],
                                [0.06943184420297377, 0.8894040733424998, 0.04116408245452639],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.08927366339996079, 0.6234718442658672, 0.287254492334172],
                                [0.06943184420297377, 0.9092458925394868, 0.021322263257539335],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9376047047688514, 0.015876617704587752, 0.046518677526560935],
                                [0.9305681557970262, 0.06080439181227522, 0.008627452390698493],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9376047047688514, 0.04651867752656094, 0.01587661770458775],
                                [0.9305681557970262, 0.06784094078410025, 0.0015909034188734625],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.703435231222666, 0.07546154627659593, 0.22110322250073802],
                                [0.6699905217924281, 0.28900320659836787, 0.04100627160920403],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.703435231222666, 0.22110322250073802, 0.07546154627659593],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966112],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.39790946230520163, 0.15320323840310823, 0.44888729929169013],
                                [0.33000947820757187, 0.5867389331973516, 0.0832515885950765],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.39790946230520163, 0.44888729929169013, 0.1532032384031082],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446688],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.1637399887590164, 0.2127881669751165, 0.6234718442658671],
                                [0.06943184420297377, 0.8149377479834442, 0.11563040781358204],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.1637399887590164, 0.6234718442658672, 0.21278816697511638],
                                [0.06943184420297377, 0.9092458925394868, 0.021322263257539335],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9448538700827406, 0.008627452390698495, 0.046518677526560935],
                                [0.9305681557970263, 0.05355522649838597, 0.01587661770458775],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9448538700827406, 0.046518677526560935, 0.008627452390698493],
                                [0.9305681557970262, 0.06784094078410025, 0.0015909034188734625],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.737890505890058, 0.04100627160920403, 0.22110322250073802],
                                [0.6699905217924281, 0.2545479319309759, 0.07546154627659593],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.737890505890058, 0.22110322250073802, 0.04100627160920403],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966112],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.46786111211323334, 0.08325158859507653, 0.44888729929169013],
                                [0.33000947820757187, 0.5167872833893199, 0.1532032384031082],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.46786111211323334, 0.44888729929169013, 0.0832515885950765],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446688],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.26089774792055076, 0.11563040781358214, 0.6234718442658671],
                                [0.06943184420297377, 0.7177799888219099, 0.21278816697511638],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.26089774792055076, 0.6234718442658672, 0.11563040781358204],
                                [0.06943184420297377, 0.9092458925394868, 0.021322263257539335],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9504099749940134, 0.0030713474794257234, 0.046518677526560935],
                                [0.9305681557970263, 0.0479991215871132, 0.021432722615860517],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9504099749940134, 0.046518677526560935, 0.0030713474794257243],
                                [0.9305681557970262, 0.06784094078410025, 0.0015909034188734625],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.7642986663484709, 0.014598111150791154, 0.22110322250073802],
                                [0.6699905217924281, 0.22813977147256304, 0.10186970673500882],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.7642986663484709, 0.22110322250073802, 0.014598111150791147],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966112],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.521475381925149, 0.02963731878316095, 0.44888729929169013],
                                [0.33000947820757187, 0.46317301357740437, 0.20681750821502373],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.521475381925149, 0.4488872992916901, 0.029637318783160983],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446688],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.3353640732796065, 0.04116408245452641, 0.6234718442658671],
                                [0.06943184420297377, 0.6433136634628542, 0.287254492334172],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.3353640732796065, 0.6234718442658671, 0.04116408245452641],
                                [0.06943184420297377, 0.9092458925394868, 0.021322263257539335],
                                [0.9305681557970262, 0.043288799956008386, 0.02614304424696533],
                                [0.9307924121532996, 0.046294421170287654, 0.02291316667641278],
                                [0.9305681557970263, 0.025918787890692047, 0.04351305631228167],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9307924121532997, 0.022913166676412786, 0.04629442117028765],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428052],
                                [0.6710564120041606, 0.2200373322890056, 0.10890625570683385],
                                [0.6699905217924281, 0.12319196999254811, 0.20681750821502376],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6710564120041604, 0.10890625570683382, 0.22003733228900563],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.33000947820757187, 0.4177202262625759, 0.25227029552985225],
                                [0.33217346556639205, 0.44672331193286996, 0.22110322250073802],
                                [0.33000947820757187, 0.2501063081710321, 0.41988421362139605],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.332173465566392, 0.22110322250073805, 0.4467233119328699],
                                [0.33000947820757187, 0.25227029552985225, 0.4177202262625759],
                                [0.06943184420297377, 0.5801830443098588, 0.35038511148716744],
                                [0.07243746541725304, 0.6204662230515878, 0.30709631153115907],
                                [0.06943184420297377, 0.34737949027288817, 0.5831886655241381],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.07243746541725304, 0.3070963115311591, 0.6204662230515878],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.9305681557970262, 0.043288799956008386, 0.02614304424696533],
                                [0.9316340460087587, 0.045452787314828554, 0.02291316667641278],
                                [0.9305681557970263, 0.025077154035232946, 0.04435469016774077],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9316340460087588, 0.022913166676412786, 0.04545278731482855],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428052],
                                [0.6750566967822795, 0.21603704751088662, 0.10890625570683385],
                                [0.6699905217924281, 0.11919168521442913, 0.21081779299314274],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6750566967822795, 0.10890625570683385, 0.21603704751088662],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.33000947820757187, 0.4177202262625759, 0.25227029552985225],
                                [0.3402949077151671, 0.4386018697840949, 0.22110322250073802],
                                [0.33000947820757187, 0.241984866022257, 0.42800565577017113],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.3402949077151672, 0.22110322250073805, 0.4386018697840948],
                                [0.33000947820757187, 0.25227029552985225, 0.4177202262625759],
                                [0.06943184420297377, 0.5801830443098588, 0.35038511148716744],
                                [0.083717558488688, 0.6091861299801529, 0.30709631153115907],
                                [0.06943184420297377, 0.3360993972014532, 0.594468758595573],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.083717558488688, 0.3070963115311591, 0.6091861299801529],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.9305681557970262, 0.043288799956008386, 0.02614304424696533],
                                [0.9327321431558465, 0.044354690167740775, 0.02291316667641278],
                                [0.9305681557970263, 0.023979056888145167, 0.04545278731482855],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9327321431558465, 0.022913166676412786, 0.04435469016774077],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428052],
                                [0.6802759513000234, 0.21081779299314277, 0.10890625570683385],
                                [0.6699905217924281, 0.11397243069668525, 0.21603704751088662],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6802759513000234, 0.10890625570683388, 0.21081779299314274],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.33000947820757187, 0.4177202262625759, 0.25227029552985225],
                                [0.35089112172909087, 0.42800565577017113, 0.22110322250073802],
                                [0.3300094782075719, 0.2313886520083333, 0.4386018697840948],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.35089112172909087, 0.221103222500738, 0.42800565577017113],
                                [0.33000947820757187, 0.25227029552985225, 0.4177202262625759],
                                [0.06943184420297377, 0.5801830443098588, 0.35038511148716744],
                                [0.09843492987326785, 0.594468758595573, 0.30709631153115907],
                                [0.06943184420297377, 0.32138202581687336, 0.6091861299801529],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.09843492987326785, 0.3070963115311591, 0.594468758595573],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.9305681557970262, 0.043288799956008386, 0.02614304424696533],
                                [0.9335737770113056, 0.04351305631228166, 0.02291316667641278],
                                [0.9305681557970262, 0.02313742303268606, 0.046294421170287654],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9335737770113056, 0.02291316667641278, 0.04351305631228166],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428052],
                                [0.6842762360781424, 0.20681750821502373, 0.10890625570683385],
                                [0.6699905217924281, 0.10997214591856622, 0.22003733228900565],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6842762360781425, 0.10890625570683388, 0.2068175082150237],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.33000947820757187, 0.4177202262625759, 0.25227029552985225],
                                [0.35901256387786595, 0.41988421362139605, 0.22110322250073802],
                                [0.3300094782075719, 0.2232672098595581, 0.44672331193287],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.3590125638778659, 0.22110322250073805, 0.419884213621396],
                                [0.33000947820757187, 0.25227029552985225, 0.4177202262625759],
                                [0.06943184420297377, 0.5801830443098588, 0.35038511148716744],
                                [0.10971502294470281, 0.5831886655241381, 0.30709631153115907],
                                [0.06943184420297377, 0.3101019327454383, 0.6204662230515879],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.10971502294470292, 0.3070963115311591, 0.583188665524138],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.9316340460087587, 0.045452787314828554, 0.02291316667641278],
                                [0.9305681557970262, 0.03719888096212706, 0.03223296324084665],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9316340460087588, 0.022913166676412786, 0.04545278731482855],
                                [0.9305681557970263, 0.03826477117385945, 0.031167073029114263],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.6750566967822795, 0.21603704751088662, 0.10890625570683385],
                                [0.6699905217924281, 0.17680623980446367, 0.1532032384031082],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.6750566967822795, 0.10890625570683385, 0.21603704751088662],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.3402949077151671, 0.4386018697840949, 0.22110322250073802],
                                [0.3300094782075718, 0.3589548564063995, 0.3110356653860286],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.3402949077151672, 0.22110322250073805, 0.4386018697840948],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.06943184420297377, 0.4177202262625759, 0.5128479295344504],
                                [0.083717558488688, 0.6091861299801529, 0.30709631153115907],
                                [0.06943184420297377, 0.4985622152487361, 0.4320059405482901],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.083717558488688, 0.3070963115311591, 0.6091861299801529],
                                [0.06943184420297377, 0.5128479295344504, 0.4177202262625758],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.9356343307868777, 0.04145250253670955, 0.02291316667641278],
                                [0.9305681557970262, 0.033198596184008056, 0.03623324801896566],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9356343307868777, 0.02291316667641278, 0.04145250253670955],
                                [0.9305681557970263, 0.03826477117385945, 0.031167073029114263],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.6940700458796984, 0.19702369841346765, 0.10890625570683385],
                                [0.6699905217924281, 0.1577928907070447, 0.17221658750052718],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.6940700458796984, 0.10890625570683382, 0.19702369841346767],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.3788961132077828, 0.4000006642914792, 0.22110322250073802],
                                [0.3300094782075719, 0.3203536509137839, 0.3496368708786442],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.3788961132077828, 0.22110322250073788, 0.4000006642914793],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.06943184420297377, 0.4177202262625759, 0.5128479295344504],
                                [0.13733182830060353, 0.5555718601682373, 0.30709631153115907],
                                [0.06943184420297377, 0.4449479454368205, 0.48562021036020575],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.13733182830060364, 0.307096311531159, 0.5555718601682373],
                                [0.06943184420297377, 0.5128479295344504, 0.4177202262625758],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.9408535853046216, 0.03623324801896565, 0.02291316667641278],
                                [0.9305681557970263, 0.027979341666264167, 0.04145250253670955],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9408535853046216, 0.02291316667641278, 0.03623324801896565],
                                [0.9305681557970263, 0.03826477117385945, 0.031167073029114263],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.718877156792639, 0.17221658750052712, 0.10890625570683385],
                                [0.6699905217924281, 0.1329857797941042, 0.19702369841346767],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.7188771567926391, 0.10890625570683382, 0.17221658750052715],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.42925990662061786, 0.34963687087864415, 0.22110322250073802],
                                [0.33000947820757187, 0.26998985750094884, 0.4000006642914793],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.42925990662061786, 0.221103222500738, 0.34963687087864415],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.06943184420297377, 0.4177202262625759, 0.5128479295344504],
                                [0.2072834781086353, 0.4856202103602056, 0.30709631153115907],
                                [0.06943184420297377, 0.3749962956287889, 0.5555718601682373],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.20728347810863534, 0.307096311531159, 0.48562021036020564],
                                [0.06943184420297377, 0.5128479295344504, 0.4177202262625758],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.9448538700827406, 0.03223296324084665, 0.02291316667641278],
                                [0.9305681557970263, 0.023979056888145167, 0.04545278731482855],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9448538700827406, 0.02291316667641278, 0.03223296324084665],
                                [0.9305681557970263, 0.03826477117385945, 0.031167073029114263],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.7378905058900579, 0.1532032384031082, 0.10890625570683385],
                                [0.6699905217924281, 0.11397243069668525, 0.21603704751088662],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.7378905058900579, 0.10890625570683385, 0.1532032384031082],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.46786111211323334, 0.31103566538602867, 0.22110322250073802],
                                [0.3300094782075719, 0.2313886520083333, 0.4386018697840948],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.4678611121132333, 0.22110322250073805, 0.3110356653860286],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.06943184420297377, 0.4177202262625759, 0.5128479295344504],
                                [0.2608977479205507, 0.43200594054829017, 0.30709631153115907],
                                [0.06943184420297377, 0.32138202581687336, 0.6091861299801529],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.26089774792055076, 0.3070963115311591, 0.4320059405482901],
                                [0.06943184420297377, 0.5128479295344504, 0.4177202262625758],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9327321431558465, 0.044354690167740775, 0.02291316667641278],
                                [0.9305681557970263, 0.051916252346706875, 0.01751559185626684],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9327321431558465, 0.022913166676412786, 0.04435469016774077],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446672],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.6802759513000234, 0.21081779299314277, 0.10890625570683385],
                                [0.669990521792428, 0.2467578896124954, 0.08325158859507649],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.6802759513000234, 0.10890625570683388, 0.21081779299314274],
                                [0.6699905217924282, 0.25704331912009065, 0.0729661590874812],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.35089112172909087, 0.42800565577017113, 0.22110322250073802],
                                [0.33000947820757187, 0.5009718148576524, 0.16901870693477575],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.35089112172909087, 0.221103222500738, 0.42800565577017113],
                                [0.33000947820757176, 0.5218534583791714, 0.14813706341325678],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.09843492987326785, 0.594468758595573, 0.30709631153115907],
                                [0.06943184420297377, 0.6958134521234408, 0.2347547036735854],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.09843492987326785, 0.3070963115311591, 0.594468758595573],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9408535853046216, 0.03623324801896565, 0.02291316667641278],
                                [0.9305681557970263, 0.04379481019793176, 0.02563703400504196],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9408535853046216, 0.02291316667641278, 0.03623324801896565],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446672],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.718877156792639, 0.17221658750052712, 0.10890625570683385],
                                [0.669990521792428, 0.2081566841198798, 0.12185279408769208],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.7188771567926391, 0.10890625570683382, 0.17221658750052715],
                                [0.6699905217924282, 0.25704331912009065, 0.0729661590874812],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.42925990662061786, 0.34963687087864415, 0.22110322250073802],
                                [0.33000947820757187, 0.4226030299661254, 0.24738749182630274],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.42925990662061786, 0.221103222500738, 0.34963687087864415],
                                [0.33000947820757176, 0.5218534583791714, 0.14813706341325678],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.2072834781086353, 0.4856202103602056, 0.30709631153115907],
                                [0.06943184420297377, 0.5869649038880733, 0.34360325190895286],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.20728347810863534, 0.307096311531159, 0.48562021036020564],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9514497993185453, 0.025637034005041956, 0.02291316667641278],
                                [0.9305681557970262, 0.03319859618400806, 0.03623324801896565],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9514497993185453, 0.022913166676412775, 0.02563703400504196],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446672],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.769240950205474, 0.12185279408769209, 0.10890625570683385],
                                [0.6699905217924281, 0.15779289070704472, 0.17221658750052715],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.769240950205474, 0.10890625570683386, 0.12185279408769208],
                                [0.6699905217924282, 0.25704331912009065, 0.0729661590874812],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.5315092856729593, 0.24738749182630274, 0.22110322250073802],
                                [0.33000947820757187, 0.320353650913784, 0.34963687087864415],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.5315092856729593, 0.22110322250073802, 0.24738749182630274],
                                [0.33000947820757176, 0.5218534583791714, 0.14813706341325678],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.349300436559888, 0.34360325190895286, 0.30709631153115907],
                                [0.06943184420297377, 0.4449479454368206, 0.48562021036020564],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.349300436559888, 0.30709631153115907, 0.34360325190895286],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9595712414673204, 0.01751559185626684, 0.02291316667641278],
                                [0.9305681557970263, 0.025077154035232953, 0.04435469016774076],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9595712414673204, 0.022913166676412775, 0.017515591856266843],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446672],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.8078421556980896, 0.0832515885950765, 0.10890625570683385],
                                [0.6699905217924281, 0.11919168521442916, 0.2108177929931427],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.8078421556980896, 0.10890625570683383, 0.08325158859507652],
                                [0.6699905217924282, 0.25704331912009065, 0.0729661590874812],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.6098780705644863, 0.16901870693477575, 0.22110322250073802],
                                [0.3300094782075719, 0.24198486602225705, 0.4280056557701711],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.6098780705644862, 0.22110322250073797, 0.1690187069347758],
                                [0.33000947820757176, 0.5218534583791714, 0.14813706341325678],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.4581489847952555, 0.23475470367358536, 0.30709631153115907],
                                [0.06943184420297377, 0.3360993972014533, 0.5944687585955729],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.45814898479525556, 0.307096311531159, 0.23475470367358545],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9335737770113056, 0.043513056312281674, 0.02291316667641278],
                                [0.9305681557970262, 0.06319634541814188, 0.006235498784831829],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9335737770113056, 0.022913166676412793, 0.04351305631228166],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525595],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.6842762360781424, 0.20681750821502373, 0.10890625570683385],
                                [0.6699905217924281, 0.30037215942441087, 0.029637318783160987],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.6842762360781425, 0.10890625570683388, 0.2068175082150237],
                                [0.6699905217924282, 0.31465787371012516, 0.015351604497446703],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.35901256387786595, 0.41988421362139605, 0.22110322250073802],
                                [0.33000947820757187, 0.6098203630930197, 0.06017015869940841],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.3590125638778659, 0.22110322250073805, 0.419884213621396],
                                [0.33000947820757187, 0.6388234487633138, 0.031167073029114322],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.10971502294470281, 0.5831886655241381, 0.30709631153115907],
                                [0.06943184420297377, 0.8469961770992886, 0.08357197869773757],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.10971502294470281, 0.30709631153115924, 0.583188665524138],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600846],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9448538700827406, 0.03223296324084665, 0.02291316667641278],
                                [0.9305681557970263, 0.05191625234670687, 0.017515591856266846],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9448538700827406, 0.02291316667641278, 0.03223296324084665],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525595],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.7378905058900579, 0.1532032384031082, 0.10890625570683385],
                                [0.6699905217924281, 0.24675788961249534, 0.08325158859507653],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.7378905058900579, 0.10890625570683385, 0.1532032384031082],
                                [0.6699905217924282, 0.31465787371012516, 0.015351604497446703],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.46786111211323334, 0.31103566538602867, 0.22110322250073802],
                                [0.33000947820757187, 0.5009718148576523, 0.16901870693477583],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.4678611121132333, 0.22110322250073805, 0.3110356653860286],
                                [0.33000947820757187, 0.6388234487633138, 0.031167073029114322],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.2608977479205507, 0.43200594054829017, 0.30709631153115907],
                                [0.06943184420297377, 0.6958134521234407, 0.2347547036735855],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.26089774792055076, 0.3070963115311591, 0.4320059405482901],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600846],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9595712414673204, 0.017515591856266846, 0.02291316667641278],
                                [0.9305681557970262, 0.03719888096212706, 0.03223296324084665],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9595712414673204, 0.02291316667641278, 0.017515591856266846],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525595],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.8078421556980896, 0.08325158859507653, 0.10890625570683385],
                                [0.6699905217924281, 0.17680623980446367, 0.1532032384031082],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.8078421556980896, 0.10890625570683385, 0.08325158859507653],
                                [0.6699905217924282, 0.31465787371012516, 0.015351604497446703],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.6098780705644862, 0.1690187069347758, 0.22110322250073802],
                                [0.3300094782075718, 0.3589548564063995, 0.3110356653860286],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.6098780705644862, 0.221103222500738, 0.16901870693477583],
                                [0.33000947820757187, 0.6388234487633138, 0.031167073029114322],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.4581489847952554, 0.23475470367358547, 0.30709631153115907],
                                [0.06943184420297377, 0.4985622152487361, 0.4320059405482901],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.45814898479525545, 0.307096311531159, 0.2347547036735855],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600846],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9708513345387554, 0.006235498784831834, 0.02291316667641278],
                                [0.9305681557970263, 0.025918787890692054, 0.04351305631228166],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9708513345387554, 0.02291316667641278, 0.006235498784831832],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525595],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.8614564255100051, 0.029637318783161004, 0.10890625570683385],
                                [0.6699905217924282, 0.12319196999254817, 0.2068175082150237],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.8614564255100051, 0.10890625570683385, 0.029637318783161004],
                                [0.6699905217924282, 0.31465787371012516, 0.015351604497446703],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.7187266187998536, 0.06017015869940842, 0.22110322250073802],
                                [0.3300094782075718, 0.25010630817103213, 0.419884213621396],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.7187266187998536, 0.221103222500738, 0.06017015869940845],
                                [0.33000947820757187, 0.6388234487633138, 0.031167073029114322],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.6093317097711033, 0.08357197869773764, 0.30709631153115907],
                                [0.06943184420297377, 0.3473794902728883, 0.583188665524138],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.6093317097711033, 0.30709631153115907, 0.08357197869773762],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600846],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257549],
                                [0.9308796315822727, 0.06429958742830122, 0.004820780989426019],
                                [0.9305681557970262, 0.008995370479011076, 0.06043647372396264],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9308796315822727, 0.004820780989426024, 0.06429958742830122],
                                [0.9305681557970262, 0.009306846264257547, 0.06012499793871617],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395212],
                                [0.6714709658529805, 0.3056158674706068, 0.022913166676412796],
                                [0.6699905217924281, 0.042754985873399876, 0.287254492334172],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.6714709658529803, 0.0229131666764128, 0.3056158674706068],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256936],
                                [0.33301509942185126, 0.6204662230515878, 0.04651867752656097],
                                [0.33000947820757187, 0.08680185626829007, 0.5831886655241381],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.33301509942185115, 0.046518677526560914, 0.6204662230515879],
                                [0.33000947820757187, 0.08980747748256934, 0.5801830443098588],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226392],
                                [0.07360643369255881, 0.8617825030938935, 0.06461106321354775],
                                [0.06943184420297377, 0.12056147166267883, 0.8100066841343474],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.07360643369255881, 0.0646110632135477, 0.8617825030938935],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257549],
                                [0.9320485998575785, 0.06313061915299543, 0.004820780989426019],
                                [0.9305681557970262, 0.007826402203705292, 0.06160544199926842],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9320485998575785, 0.004820780989426024, 0.06313061915299543],
                                [0.9305681557970262, 0.009306846264257547, 0.06012499793871617],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395212],
                                [0.6770270707642532, 0.30005976255933403, 0.022913166676412796],
                                [0.6699905217924281, 0.03719888096212709, 0.2928105972454448],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.6770270707642532, 0.0229131666764128, 0.30005976255933403],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256936],
                                [0.3442951924932862, 0.6091861299801529, 0.04651867752656097],
                                [0.33000947820757187, 0.07552176319685511, 0.594468758595573],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.3442951924932861, 0.046518677526561025, 0.6091861299801529],
                                [0.33000947820757187, 0.08980747748256934, 0.5801830443098588],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226392],
                                [0.08927366339996079, 0.8461152733864915, 0.06461106321354775],
                                [0.06943184420297377, 0.10489424195527686, 0.8256739138417494],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.08927366339996079, 0.0646110632135477, 0.8461152733864915],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257549],
                                [0.9335737770113055, 0.061605441999268436, 0.004820780989426019],
                                [0.9305681557970262, 0.006301225049978279, 0.06313061915299543],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9335737770113055, 0.004820780989426024, 0.06160544199926843],
                                [0.9305681557970262, 0.009306846264257547, 0.06012499793871617],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395212],
                                [0.6842762360781425, 0.2928105972454448, 0.022913166676412796],
                                [0.6699905217924282, 0.02994971564823784, 0.30005976255933403],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.6842762360781425, 0.0229131666764128, 0.2928105972454448],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256936],
                                [0.35901256387786606, 0.594468758595573, 0.04651867752656097],
                                [0.33000947820757187, 0.06080439181227526, 0.6091861299801529],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.35901256387786595, 0.046518677526560914, 0.5944687585955731],
                                [0.33000947820757187, 0.08980747748256934, 0.5801830443098588],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226392],
                                [0.10971502294470281, 0.8256739138417495, 0.06461106321354775],
                                [0.06943184420297377, 0.08445288241053484, 0.8461152733864914],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.10971502294470281, 0.0646110632135477, 0.8256739138417495],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257549],
                                [0.9347427452866113, 0.06043647372396264, 0.004820780989426019],
                                [0.9305681557970262, 0.0051322567746724945, 0.06429958742830122],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9347427452866113, 0.004820780989426017, 0.06043647372396264],
                                [0.9305681557970262, 0.009306846264257547, 0.06012499793871617],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395212],
                                [0.6898323409894153, 0.287254492334172, 0.022913166676412796],
                                [0.669990521792428, 0.024393610736965055, 0.3056158674706068],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.6898323409894151, 0.0229131666764128, 0.287254492334172],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256936],
                                [0.370292656949301, 0.5831886655241381, 0.04651867752656097],
                                [0.33000947820757187, 0.04952429874084019, 0.6204662230515879],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.370292656949301, 0.046518677526560914, 0.5831886655241381],
                                [0.33000947820757187, 0.08980747748256934, 0.5801830443098588],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226392],
                                [0.1253822526521049, 0.8100066841343474, 0.06461106321354775],
                                [0.06943184420297377, 0.06878565270313275, 0.8617825030938935],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.1253822526521049, 0.0646110632135477, 0.8100066841343474],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.9305681557970262, 0.04328879995600838, 0.026143044246965334],
                                [0.9320485998575785, 0.06313061915299543, 0.004820780989426019],
                                [0.9305681557970262, 0.02466260018641308, 0.044769244016560635],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9320485998575785, 0.004820780989426024, 0.06313061915299543],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428053],
                                [0.6770270707642532, 0.30005976255933403, 0.022913166676412796],
                                [0.669990521792428, 0.11722131123245555, 0.21278816697511632],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.6770270707642532, 0.0229131666764128, 0.30005976255933403],
                                [0.6699905217924281, 0.12425786020428056, 0.2057516180032913],
                                [0.3300094782075718, 0.4177202262625758, 0.2522702955298523],
                                [0.3442951924932862, 0.6091861299801529, 0.04651867752656097],
                                [0.3300094782075718, 0.23798458124413807, 0.43200594054829006],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.3442951924932861, 0.046518677526561025, 0.6091861299801529],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.06943184420297377, 0.5801830443098588, 0.3503851114871675],
                                [0.08927366339996079, 0.8461152733864915, 0.06461106321354775],
                                [0.06943184420297377, 0.33054329229018053, 0.6000248635068457],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.08927366339996079, 0.0646110632135477, 0.8461152733864915],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.9305681557970262, 0.04328879995600838, 0.026143044246965334],
                                [0.9376047047688513, 0.05757451424172267, 0.004820780989426019],
                                [0.9305681557970263, 0.019106495275140314, 0.0503253489278334],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9376047047688513, 0.004820780989426017, 0.05757451424172267],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428053],
                                [0.7034352312226662, 0.27365160210092115, 0.022913166676412796],
                                [0.6699905217924282, 0.09081315077404267, 0.2391963274335292],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.7034352312226659, 0.0229131666764128, 0.27365160210092115],
                                [0.6699905217924281, 0.12425786020428056, 0.2057516180032913],
                                [0.3300094782075718, 0.4177202262625758, 0.2522702955298523],
                                [0.39790946230520174, 0.5555718601682373, 0.04651867752656097],
                                [0.3300094782075718, 0.18437031143222254, 0.4856202103602056],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.39790946230520163, 0.046518677526561025, 0.5555718601682373],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.06943184420297377, 0.5801830443098588, 0.3503851114871675],
                                [0.1637399887590164, 0.7716489480274359, 0.06461106321354775],
                                [0.06943184420297377, 0.2560769669311249, 0.6744911888659013],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.1637399887590164, 0.0646110632135477, 0.7716489480274359],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.9305681557970262, 0.04328879995600838, 0.026143044246965334],
                                [0.9448538700827405, 0.05032534892783341, 0.004820780989426019],
                                [0.9305681557970262, 0.01185732996125105, 0.05757451424172266],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9448538700827405, 0.004820780989426017, 0.05032534892783341],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428053],
                                [0.737890505890058, 0.23919632743352925, 0.022913166676412796],
                                [0.669990521792428, 0.05635787610665072, 0.27365160210092115],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.737890505890058, 0.0229131666764128, 0.23919632743352925],
                                [0.6699905217924281, 0.12425786020428056, 0.2057516180032913],
                                [0.3300094782075718, 0.4177202262625758, 0.2522702955298523],
                                [0.4678611121132334, 0.4856202103602057, 0.04651867752656097],
                                [0.33000947820757187, 0.11441866162419079, 0.5555718601682373],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.46786111211323334, 0.046518677526561025, 0.48562021036020564],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.06943184420297377, 0.5801830443098588, 0.3503851114871675],
                                [0.26089774792055076, 0.6744911888659015, 0.06461106321354775],
                                [0.06943184420297377, 0.15891920776959045, 0.7716489480274358],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.26089774792055076, 0.06461106321354781, 0.6744911888659014],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.9305681557970262, 0.04328879995600838, 0.026143044246965334],
                                [0.9504099749940133, 0.04476924401656064, 0.004820780989426019],
                                [0.9305681557970262, 0.006301225049978279, 0.06313061915299543],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9504099749940133, 0.004820780989426017, 0.04476924401656064],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428053],
                                [0.7642986663484709, 0.21278816697511638, 0.022913166676412796],
                                [0.6699905217924282, 0.02994971564823784, 0.30005976255933403],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.7642986663484708, 0.0229131666764128, 0.21278816697511638],
                                [0.6699905217924281, 0.12425786020428056, 0.2057516180032913],
                                [0.3300094782075718, 0.4177202262625758, 0.2522702955298523],
                                [0.521475381925149, 0.4320059405482901, 0.04651867752656097],
                                [0.33000947820757187, 0.06080439181227526, 0.6091861299801529],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.521475381925149, 0.04651867752656097, 0.4320059405482901],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.06943184420297377, 0.5801830443098588, 0.3503851114871675],
                                [0.3353640732796065, 0.6000248635068458, 0.06461106321354775],
                                [0.06943184420297377, 0.08445288241053484, 0.8461152733864914],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.3353640732796065, 0.0646110632135477, 0.6000248635068458],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9335737770113055, 0.061605441999268436, 0.004820780989426019],
                                [0.9305681557970263, 0.04510395973115512, 0.02432788447181859],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9335737770113055, 0.004820780989426024, 0.06160544199926843],
                                [0.9305681557970263, 0.048109580945434396, 0.02132226325753932],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.6842762360781425, 0.2928105972454448, 0.022913166676412796],
                                [0.6699905217924281, 0.21437907039398985, 0.11563040781358204],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.6842762360781425, 0.0229131666764128, 0.2928105972454448],
                                [0.6699905217924281, 0.2286647846797041, 0.10134469352786776],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.35901256387786606, 0.594468758595573, 0.04651867752656097],
                                [0.33000947820757187, 0.4352358181188427, 0.23475470367358545],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.35901256387786595, 0.046518677526560914, 0.5944687585955731],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329136],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.10971502294470281, 0.8256739138417495, 0.06461106321354775],
                                [0.06943184420297377, 0.6045109287816773, 0.3260572270153489],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.10971502294470281, 0.0646110632135477, 0.8256739138417495],
                                [0.06943184420297377, 0.6447941075234065, 0.2857740482736198],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9448538700827405, 0.05032534892783341, 0.004820780989426019],
                                [0.9305681557970262, 0.033823866659720106, 0.03560797754325361],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9448538700827405, 0.004820780989426017, 0.05032534892783341],
                                [0.9305681557970263, 0.048109580945434396, 0.02132226325753932],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.737890505890058, 0.23919632743352925, 0.022913166676412796],
                                [0.6699905217924281, 0.1607648005820743, 0.16924467762549758],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.737890505890058, 0.0229131666764128, 0.23919632743352925],
                                [0.6699905217924281, 0.2286647846797041, 0.10134469352786776],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.4678611121132334, 0.4856202103602057, 0.04651867752656097],
                                [0.3300094782075718, 0.3263872698834753, 0.34360325190895286],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.46786111211323334, 0.046518677526561025, 0.48562021036020564],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329136],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.26089774792055076, 0.6744911888659015, 0.06461106321354775],
                                [0.06943184420297377, 0.4533282038058294, 0.47723995199119684],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.26089774792055076, 0.06461106321354781, 0.6744911888659014],
                                [0.06943184420297377, 0.6447941075234065, 0.2857740482736198],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9595712414673203, 0.03560797754325361, 0.004820780989426019],
                                [0.9305681557970262, 0.0191064952751403, 0.05032534892783341],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9595712414673203, 0.004820780989426017, 0.03560797754325361],
                                [0.9305681557970263, 0.048109580945434396, 0.02132226325753932],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.8078421556980897, 0.16924467762549758, 0.022913166676412796],
                                [0.6699905217924281, 0.09081315077404262, 0.23919632743352925],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.8078421556980897, 0.0229131666764128, 0.16924467762549758],
                                [0.6699905217924281, 0.2286647846797041, 0.10134469352786776],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.6098780705644862, 0.34360325190895286, 0.04651867752656097],
                                [0.33000947820757187, 0.1843703114322225, 0.48562021036020564],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.6098780705644862, 0.04651867752656097, 0.34360325190895286],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329136],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.4581489847952555, 0.4772399519911968, 0.06461106321354775],
                                [0.06943184420297377, 0.2560769669311248, 0.6744911888659014],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.45814898479525545, 0.0646110632135477, 0.47723995199119684],
                                [0.06943184420297377, 0.6447941075234065, 0.2857740482736198],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9708513345387554, 0.024327884471818592, 0.004820780989426019],
                                [0.9305681557970262, 0.007826402203705292, 0.06160544199926842],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9708513345387554, 0.0048207809894260205, 0.024327884471818592],
                                [0.9305681557970263, 0.048109580945434396, 0.02132226325753932],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.8614564255100052, 0.11563040781358205, 0.022913166676412796],
                                [0.6699905217924281, 0.03719888096212709, 0.2928105972454448],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.8614564255100052, 0.022913166676412786, 0.11563040781358207],
                                [0.6699905217924281, 0.2286647846797041, 0.10134469352786776],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.7187266187998536, 0.23475470367358547, 0.04651867752656097],
                                [0.33000947820757187, 0.07552176319685511, 0.594468758595573],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.7187266187998536, 0.04651867752656094, 0.2347547036735855],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329136],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.6093317097711033, 0.32605722701534895, 0.06461106321354775],
                                [0.06943184420297377, 0.10489424195527686, 0.8256739138417494],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.6093317097711033, 0.06461106321354776, 0.32605722701534895],
                                [0.06943184420297377, 0.6447941075234065, 0.2857740482736198],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9347427452866113, 0.06043647372396264, 0.004820780989426019],
                                [0.9305681557970263, 0.060771189438557124, 0.008660654764416588],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9347427452866113, 0.004820780989426017, 0.06043647372396264],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.6898323409894153, 0.287254492334172, 0.022913166676412796],
                                [0.6699905217924281, 0.28884539575304546, 0.04116408245452638],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.6898323409894151, 0.0229131666764128, 0.287254492334172],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.370292656949301, 0.5831886655241381, 0.04651867752656097],
                                [0.33000947820757187, 0.5864185430946907, 0.0835719786977375],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.370292656949301, 0.046518677526560914, 0.5831886655241381],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.1253822526521049, 0.8100066841343474, 0.06461106321354775],
                                [0.06943184420297377, 0.8144927494091789, 0.11607540638784729],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.1253822526521049, 0.0646110632135477, 0.8100066841343474],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9504099749940133, 0.04476924401656064, 0.004820780989426019],
                                [0.9305681557970263, 0.04510395973115513, 0.024327884471818585],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9504099749940133, 0.004820780989426017, 0.04476924401656064],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.7642986663484709, 0.21278816697511638, 0.022913166676412796],
                                [0.6699905217924281, 0.21437907039398985, 0.11563040781358203],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.7642986663484708, 0.0229131666764128, 0.21278816697511638],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.521475381925149, 0.4320059405482901, 0.04651867752656097],
                                [0.33000947820757187, 0.4352358181188427, 0.23475470367358542],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.521475381925149, 0.04651867752656097, 0.4320059405482901],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.3353640732796065, 0.6000248635068458, 0.06461106321354775],
                                [0.06943184420297377, 0.6045109287816774, 0.32605722701534884],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.3353640732796065, 0.0646110632135477, 0.6000248635068458],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9708513345387554, 0.024327884471818585, 0.004820780989426019],
                                [0.9305681557970262, 0.024662600186413072, 0.04476924401656064],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9708513345387554, 0.004820780989426017, 0.024327884471818585],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.8614564255100052, 0.11563040781358203, 0.022913166676412796],
                                [0.6699905217924281, 0.1172213112324555, 0.21278816697511638],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.8614564255100052, 0.0229131666764128, 0.11563040781358203],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.7187266187998537, 0.23475470367358542, 0.04651867752656097],
                                [0.33000947820757187, 0.23798458124413802, 0.4320059405482901],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.7187266187998536, 0.04651867752656097, 0.23475470367358542],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.6093317097711035, 0.32605722701534884, 0.06461106321354775],
                                [0.06943184420297377, 0.3305432922901804, 0.6000248635068458],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.6093317097711035, 0.06461106321354776, 0.32605722701534884],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9865185642461574, 0.008660654764416588, 0.004820780989426019],
                                [0.9305681557970262, 0.008995370479011076, 0.06043647372396264],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9865185642461574, 0.004820780989426019, 0.008660654764416588],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.9359227508690608, 0.04116408245452638, 0.022913166676412796],
                                [0.6699905217924281, 0.042754985873399876, 0.287254492334172],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.9359227508690608, 0.0229131666764128, 0.04116408245452638],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.8699093437757016, 0.0835719786977375, 0.04651867752656097],
                                [0.33000947820757187, 0.08680185626829007, 0.5831886655241381],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.8699093437757015, 0.04651867752656097, 0.0835719786977375],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.819313530398605, 0.11607540638784729, 0.06461106321354775],
                                [0.06943184420297377, 0.12056147166267883, 0.8100066841343474],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.819313530398605, 0.06461106321354775, 0.11607540638784729],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                            ]
                        ),
                        np.array(
                            [
                                [0.9305913957263743, 0.004797541060078014, 0.06461106321354769],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9305681557970262, 0.06492253899879417, 0.004509305204179541],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9305913957263743, 0.0646110632135477, 0.004797541060078003],
                                [0.6701009811507492, 0.022802707318091586, 0.30709631153115907],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.6699905217924282, 0.3085767555917113, 0.02143272261586052],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.6701009811507495, 0.30709631153115907, 0.02280270731809158],
                                [0.3302337345638452, 0.0462944211702877, 0.6234718442658671],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.33000947820757187, 0.6264774654801465, 0.04351305631228167],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.3302337345638452, 0.6234718442658671, 0.046294421170287654],
                                [0.06974331998822025, 0.06429958742830122, 0.8659570925834785],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.06943184420297377, 0.8701316820730636, 0.06043647372396264],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.06974331998822025, 0.8659570925834785, 0.06429958742830123],
                                [0.9306786151553474, 0.004710321631104825, 0.06461106321354769],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9305681557970262, 0.06483531956982098, 0.00459652463315273],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9306786151553474, 0.0646110632135477, 0.004710321631104814],
                                [0.6705155349995692, 0.0223881534692717, 0.30709631153115907],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.669990521792428, 0.3081622017428915, 0.02184727646468039],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.6705155349995693, 0.30709631153115907, 0.02238815346927171],
                                [0.3310753684193043, 0.0454527873148286, 0.6234718442658671],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.33000947820757187, 0.6256358316246874, 0.04435469016774077],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.3310753684193043, 0.6234718442658671, 0.045452787314828554],
                                [0.07091228826352602, 0.06313061915299545, 0.8659570925834785],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.06943184420297377, 0.8689627137977578, 0.06160544199926842],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.07091228826352602, 0.8659570925834785, 0.06313061915299543],
                                [0.9307924121532996, 0.004596524633152743, 0.06461106321354769],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9305681557970262, 0.0647215225718689, 0.004710321631104814],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9307924121532996, 0.0646110632135477, 0.00459652463315273],
                                [0.6710564120041604, 0.021847276464680376, 0.30709631153115907],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.6699905217924281, 0.3076213247383002, 0.02238815346927171],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.6710564120041604, 0.30709631153115907, 0.02184727646468039],
                                [0.33217346556639205, 0.04435469016774085, 0.6234718442658671],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.33000947820757187, 0.6245377344775995, 0.045452787314828554],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.33217346556639205, 0.6234718442658672, 0.04435469016774077],
                                [0.07243746541725304, 0.06160544199926843, 0.8659570925834785],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.06943184420297377, 0.8674375366440308, 0.06313061915299543],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.07243746541725304, 0.8659570925834785, 0.06160544199926842],
                                [0.9308796315822727, 0.004509305204179553, 0.06461106321354769],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9305681557970262, 0.06463430314289571, 0.004797541060078003],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9308796315822727, 0.0646110632135477, 0.004509305204179541],
                                [0.6714709658529803, 0.021432722615860544, 0.30709631153115907],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.6699905217924282, 0.3072067708894803, 0.02280270731809158],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.6714709658529805, 0.30709631153115907, 0.02143272261586052],
                                [0.33301509942185115, 0.04351305631228175, 0.6234718442658671],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.33000947820757187, 0.6236961006221404, 0.046294421170287654],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.33301509942185115, 0.6234718442658672, 0.04351305631228167],
                                [0.07360643369255881, 0.06043647372396266, 0.8659570925834785],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.06943184420297377, 0.866268568368725, 0.06429958742830123],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.07360643369255881, 0.8659570925834785, 0.06043647372396264],
                                [0.9306786151553474, 0.004710321631104825, 0.06461106321354769],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9305681557970263, 0.06609150727409996, 0.0033403369288737537],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9306786151553474, 0.0646110632135477, 0.004710321631104814],
                                [0.6705155349995692, 0.0223881534692717, 0.30709631153115907],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6699905217924282, 0.3141328605029841, 0.01587661770458775],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6705155349995693, 0.30709631153115907, 0.02238815346927171],
                                [0.3310753684193043, 0.0454527873148286, 0.6234718442658671],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.33000947820757187, 0.6377575585515814, 0.03223296324084665],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.3310753684193043, 0.6234718442658671, 0.045452787314828554],
                                [0.07091228826352602, 0.06313061915299545, 0.8659570925834785],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.06943184420297377, 0.8857989117804655, 0.04476924401656064],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600838],
                                [0.07091228826352602, 0.8659570925834785, 0.06313061915299543],
                                [0.9310931690041674, 0.004295767782284951, 0.06461106321354769],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9305681557970262, 0.06567695342528009, 0.0037548907776936264],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9310931690041674, 0.0646110632135477, 0.0042957677822849415],
                                [0.6724859089815427, 0.020417779487298116, 0.30709631153115907],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6699905217924282, 0.3121624865210105, 0.01784699168656139],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6724859089815428, 0.3070963115311591, 0.020417779487298063],
                                [0.3350756531974233, 0.04145250253670962, 0.6234718442658671],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.33000947820757187, 0.6337572737734625, 0.03623324801896565],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.3350756531974233, 0.6234718442658672, 0.04145250253670954],
                                [0.07646839317479881, 0.05757451424172266, 0.8659570925834785],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.06943184420297377, 0.8802428068691928, 0.05032534892783341],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600838],
                                [0.07646839317479881, 0.8659570925834785, 0.05757451424172266],
                                [0.9316340460087587, 0.0037548907776936424, 0.06461106321354769],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9305681557970263, 0.06513607642068878, 0.0042957677822849415],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9316340460087587, 0.0646110632135477, 0.0037548907776936264],
                                [0.6750566967822795, 0.017846991686561398, 0.30709631153115907],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6699905217924281, 0.3095916987202738, 0.020417779487298063],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6750566967822795, 0.30709631153115907, 0.01784699168656139],
                                [0.3402949077151671, 0.03623324801896577, 0.6234718442658671],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.33000947820757187, 0.6285380192557186, 0.04145250253670954],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.3402949077151671, 0.6234718442658672, 0.03623324801896565],
                                [0.083717558488688, 0.05032534892783347, 0.8659570925834785],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.06943184420297377, 0.8729936415553036, 0.05757451424172266],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600838],
                                [0.083717558488688, 0.8659570925834785, 0.05032534892783341],
                                [0.9320485998575785, 0.003340336928873769, 0.06461106321354769],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9305681557970262, 0.0647215225718689, 0.004710321631104813],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9320485998575786, 0.0646110632135477, 0.0033403369288737537],
                                [0.6770270707642532, 0.01587661770458776, 0.30709631153115907],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6699905217924281, 0.3076213247383002, 0.022388153469271702],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6770270707642532, 0.30709631153115907, 0.01587661770458775],
                                [0.3442951924932861, 0.03223296324084679, 0.6234718442658671],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.33000947820757187, 0.6245377344775996, 0.04545278731482854],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.3442951924932861, 0.6234718442658672, 0.03223296324084665],
                                [0.08927366339996079, 0.04476924401656068, 0.8659570925834785],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.06943184420297377, 0.8674375366440308, 0.06313061915299543],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600838],
                                [0.08927366339996079, 0.8659570925834785, 0.04476924401656064],
                                [0.9307924121532996, 0.004596524633152743, 0.06461106321354769],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9305681557970262, 0.06761668442782696, 0.0018151597751467452],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9307924121532996, 0.0646110632135477, 0.00459652463315273],
                                [0.6710564120041604, 0.021847276464680376, 0.30709631153115907],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.6699905217924281, 0.32138202581687336, 0.008627452390698493],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6710564120041604, 0.30709631153115907, 0.02184727646468039],
                                [0.33217346556639205, 0.04435469016774085, 0.6234718442658671],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.33000947820757187, 0.6524749299361613, 0.01751559185626684],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.33217346556639205, 0.6234718442658672, 0.04435469016774077],
                                [0.07243746541725304, 0.06160544199926843, 0.8659570925834785],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.06943184420297377, 0.9062402713252077, 0.024327884471818585],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.07243746541725304, 0.8659570925834785, 0.06160544199926842],
                                [0.9316340460087587, 0.0037548907776936424, 0.06461106321354769],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9305681557970262, 0.06677505057236786, 0.002656793630605849],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9316340460087587, 0.0646110632135477, 0.0037548907776936264],
                                [0.6750566967822795, 0.017846991686561398, 0.30709631153115907],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.6699905217924281, 0.3173817410387544, 0.012627737168817495],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6750566967822795, 0.30709631153115907, 0.01784699168656139],
                                [0.3402949077151671, 0.03623324801896577, 0.6234718442658671],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.33000947820757187, 0.6443534877873862, 0.025637034005041956],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.3402949077151671, 0.6234718442658672, 0.03623324801896565],
                                [0.083717558488688, 0.05032534892783347, 0.8659570925834785],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.06943184420297377, 0.8949601782537726, 0.0356079775432536],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.083717558488688, 0.8659570925834785, 0.05032534892783341],
                                [0.9327321431558464, 0.0026567936306058637, 0.06461106321354769],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9305681557970262, 0.06567695342528009, 0.0037548907776936264],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9327321431558464, 0.0646110632135477, 0.0026567936306058494],
                                [0.6802759513000234, 0.012627737168817543, 0.30709631153115907],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.6699905217924282, 0.3121624865210105, 0.01784699168656139],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6802759513000234, 0.3070963115311591, 0.012627737168817496],
                                [0.35089112172909087, 0.025637034005042025, 0.6234718442658671],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.33000947820757187, 0.6337572737734625, 0.03623324801896565],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.35089112172909087, 0.6234718442658672, 0.02563703400504196],
                                [0.09843492987326785, 0.03560797754325362, 0.8659570925834785],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.06943184420297377, 0.8802428068691928, 0.05032534892783341],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.09843492987326785, 0.8659570925834785, 0.03560797754325361],
                                [0.9335737770113055, 0.001815159775146749, 0.06461106321354769],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9305681557970262, 0.06483531956982098, 0.00459652463315273],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9335737770113055, 0.06461106321354769, 0.0018151597751467454],
                                [0.6842762360781424, 0.008627452390698509, 0.30709631153115907],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.669990521792428, 0.3081622017428915, 0.02184727646468039],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6842762360781425, 0.30709631153115907, 0.008627452390698493],
                                [0.35901256387786595, 0.017515591856266943, 0.6234718442658671],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.33000947820757187, 0.6256358316246874, 0.04435469016774077],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.35901256387786595, 0.6234718442658672, 0.01751559185626684],
                                [0.10971502294470292, 0.02432788447181855, 0.8659570925834785],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.06943184420297377, 0.8689627137977578, 0.06160544199926842],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.10971502294470292, 0.8659570925834785, 0.02432788447181859],
                                [0.9308796315822727, 0.004509305204179553, 0.06461106321354769],
                                [0.9305681557970262, 0.000334715714594494, 0.06909712848837922],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9305681557970263, 0.06878565270313275, 0.0006461914998409584],
                                [0.9305681557970262, 0.06909712848837923, 0.00033471571459448517],
                                [0.9308796315822727, 0.0646110632135477, 0.004509305204179541],
                                [0.6714709658529803, 0.021432722615860544, 0.30709631153115907],
                                [0.6699905217924281, 0.0015909034188734683, 0.3284185747886984],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6699905217924281, 0.32693813072814615, 0.003071347479425725],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734642],
                                [0.6714709658529805, 0.30709631153115907, 0.02143272261586052],
                                [0.33301509942185115, 0.04351305631228175, 0.6234718442658671],
                                [0.33000947820757187, 0.0032298775705525973, 0.6667606442218755],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.33000947820757187, 0.6637550230075963, 0.006235498784831829],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525595],
                                [0.33301509942185115, 0.6234718442658672, 0.04351305631228167],
                                [0.07360643369255881, 0.06043647372396266, 0.8659570925834785],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.06943184420297377, 0.9219075010326097, 0.008660654764416595],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831539],
                                [0.07360643369255881, 0.8659570925834785, 0.06043647372396264],
                                [0.9320485998575785, 0.003340336928873769, 0.06461106321354769],
                                [0.9305681557970262, 0.000334715714594494, 0.06909712848837922],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9305681557970262, 0.06761668442782696, 0.0018151597751467456],
                                [0.9305681557970262, 0.06909712848837923, 0.00033471571459448517],
                                [0.9320485998575786, 0.0646110632135477, 0.0033403369288737537],
                                [0.6770270707642532, 0.01587661770458776, 0.30709631153115907],
                                [0.6699905217924281, 0.0015909034188734683, 0.3284185747886984],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6699905217924281, 0.32138202581687336, 0.008627452390698495],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734642],
                                [0.6770270707642532, 0.30709631153115907, 0.01587661770458775],
                                [0.3442951924932861, 0.03223296324084679, 0.6234718442658671],
                                [0.33000947820757187, 0.0032298775705525973, 0.6667606442218755],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.33000947820757187, 0.6524749299361613, 0.017515591856266843],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525595],
                                [0.3442951924932861, 0.6234718442658672, 0.03223296324084665],
                                [0.08927366339996079, 0.04476924401656068, 0.8659570925834785],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.06943184420297377, 0.9062402713252077, 0.024327884471818592],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831539],
                                [0.08927366339996079, 0.8659570925834785, 0.04476924401656064],
                                [0.9335737770113055, 0.001815159775146763, 0.06461106321354769],
                                [0.9305681557970262, 0.000334715714594494, 0.06909712848837922],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9305681557970263, 0.06609150727409996, 0.0033403369288737537],
                                [0.9305681557970262, 0.06909712848837923, 0.00033471571459448517],
                                [0.9335737770113055, 0.0646110632135477, 0.0018151597751467458],
                                [0.6842762360781424, 0.008627452390698509, 0.30709631153115907],
                                [0.6699905217924281, 0.0015909034188734683, 0.3284185747886984],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6699905217924282, 0.3141328605029841, 0.01587661770458775],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734642],
                                [0.6842762360781425, 0.30709631153115907, 0.008627452390698495],
                                [0.35901256387786595, 0.017515591856266943, 0.6234718442658671],
                                [0.33000947820757187, 0.0032298775705525973, 0.6667606442218755],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.33000947820757187, 0.6377575585515814, 0.03223296324084665],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525595],
                                [0.35901256387786595, 0.6234718442658672, 0.017515591856266846],
                                [0.10971502294470281, 0.02432788447181866, 0.8659570925834785],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.06943184420297377, 0.8857989117804655, 0.04476924401656064],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831539],
                                [0.10971502294470281, 0.8659570925834786, 0.024327884471818596],
                                [0.9347427452866113, 0.0006461914998409646, 0.06461106321354769],
                                [0.9305681557970262, 0.000334715714594494, 0.06909712848837922],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9305681557970262, 0.06492253899879417, 0.004509305204179541],
                                [0.9305681557970262, 0.06909712848837923, 0.00033471571459448517],
                                [0.9347427452866114, 0.06461106321354769, 0.0006461914998409584],
                                [0.6898323409894151, 0.0030713474794257234, 0.30709631153115907],
                                [0.6699905217924281, 0.0015909034188734683, 0.3284185747886984],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6699905217924282, 0.3085767555917113, 0.02143272261586052],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734642],
                                [0.6898323409894151, 0.30709631153115907, 0.003071347479425725],
                                [0.370292656949301, 0.006235498784831872, 0.6234718442658671],
                                [0.33000947820757187, 0.0032298775705525973, 0.6667606442218755],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.33000947820757187, 0.6264774654801465, 0.04351305631228167],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525595],
                                [0.370292656949301, 0.6234718442658671, 0.006235498784831829],
                                [0.1253822526521049, 0.008660654764416575, 0.8659570925834785],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.06943184420297377, 0.8701316820730636, 0.06043647372396264],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831539],
                                [0.1253822526521049, 0.8659570925834785, 0.008660654764416595],
                                [0.9306786151553476, 0.02280270731809158, 0.046518677526560935],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9305681557970263, 0.0479991215871132, 0.021432722615860517],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.9306786151553476, 0.046518677526560935, 0.02280270731809158],
                                [0.6705155349995693, 0.10838124249969275, 0.22110322250073802],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.6699905217924281, 0.22813977147256304, 0.10186970673500882],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.6705155349995692, 0.221103222500738, 0.10838124249969278],
                                [0.3310753684193043, 0.22003733228900557, 0.44888729929169013],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.33000947820757187, 0.46317301357740437, 0.20681750821502373],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.33107536841930424, 0.4488872992916901, 0.22003733228900563],
                                [0.07091228826352602, 0.3056158674706069, 0.6234718442658671],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.06943184420297377, 0.6433136634628542, 0.287254492334172],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.07091228826352602, 0.6234718442658671, 0.3056158674706068],
                                [0.9310931690041674, 0.022388153469271706, 0.046518677526560935],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9305681557970262, 0.047584567738293324, 0.021847276464680387],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.9310931690041674, 0.046518677526560935, 0.022388153469271706],
                                [0.6724859089815428, 0.10641086851771916, 0.22110322250073802],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.6699905217924281, 0.22616939749058942, 0.10384008071698245],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.6724859089815427, 0.22110322250073805, 0.10641086851771915],
                                [0.3350756531974233, 0.2160370475108866, 0.44888729929169013],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.33000947820757187, 0.4591727287992854, 0.2108177929931427],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.33507565319742333, 0.4488872992916901, 0.21603704751088665],
                                [0.07646839317479881, 0.3000597625593341, 0.6234718442658671],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.06943184420297377, 0.6377575585515816, 0.2928105972454447],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.07646839317479881, 0.6234718442658671, 0.3000597625593341],
                                [0.9316340460087587, 0.021847276464680397, 0.046518677526560935],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9305681557970262, 0.047043690733702015, 0.022388153469271702],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.9316340460087587, 0.04651867752656094, 0.021847276464680394],
                                [0.6750566967822795, 0.10384008071698245, 0.22110322250073802],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.6699905217924282, 0.22359860968985273, 0.10641086851771912],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.6750566967822795, 0.221103222500738, 0.10384008071698247],
                                [0.3402949077151671, 0.21081779299314274, 0.44888729929169013],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.33000947820757187, 0.45395347428154154, 0.2160370475108866],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.3402949077151671, 0.44888729929169013, 0.21081779299314274],
                                [0.083717558488688, 0.2928105972454449, 0.6234718442658671],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.06943184420297377, 0.6305083932376923, 0.30005976255933403],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.083717558488688, 0.6234718442658672, 0.2928105972454448],
                                [0.9320485998575786, 0.021432722615860524, 0.046518677526560935],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9305681557970263, 0.046629136884882134, 0.02280270731809158],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.9320485998575786, 0.04651867752656094, 0.021432722615860517],
                                [0.6770270707642532, 0.10186970673500881, 0.22110322250073802],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.669990521792428, 0.2216282357078791, 0.10838124249969278],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.6770270707642532, 0.221103222500738, 0.10186970673500882],
                                [0.3442951924932861, 0.20681750821502376, 0.44888729929169013],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.3300094782075718, 0.4499531895034225, 0.22003733228900563],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.3442951924932861, 0.44888729929169013, 0.20681750821502373],
                                [0.08927366339996079, 0.2872544923341721, 0.6234718442658671],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.06943184420297377, 0.6249522883264194, 0.3056158674706068],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.08927366339996079, 0.6234718442658672, 0.287254492334172],
                                [0.9310931690041674, 0.022388153469271706, 0.046518677526560935],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.9305681557970263, 0.05355522649838597, 0.01587661770458775],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.9310931690041674, 0.046518677526560935, 0.022388153469271706],
                                [0.6724859089815428, 0.10641086851771916, 0.22110322250073802],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.6699905217924281, 0.2545479319309759, 0.07546154627659593],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.6724859089815427, 0.22110322250073805, 0.10641086851771915],
                                [0.3350756531974233, 0.2160370475108866, 0.44888729929169013],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.33000947820757187, 0.5167872833893199, 0.1532032384031082],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.33507565319742333, 0.4488872992916901, 0.21603704751088665],
                                [0.07646839317479881, 0.3000597625593341, 0.6234718442658671],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.06943184420297377, 0.7177799888219099, 0.21278816697511638],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.07646839317479881, 0.6234718442658671, 0.3000597625593341],
                                [0.933063542986141, 0.020417779487298067, 0.046518677526560935],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.9305681557970263, 0.05158485251641233, 0.017846991686561387],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.933063542986141, 0.04651867752656094, 0.020417779487298063],
                                [0.6818510943245104, 0.09704568317475157, 0.22110322250073802],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.6699905217924282, 0.24518274658800837, 0.0848267316195635],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.6818510943245104, 0.22110322250073802, 0.09704568317475157],
                                [0.3540890022948422, 0.19702369841346767, 0.44888729929169013],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.33000947820757187, 0.497773934291901, 0.17221658750052715],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.3540890022948422, 0.44888729929169013, 0.19702369841346765],
                                [0.10287655363321169, 0.2736516021009212, 0.6234718442658671],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.06943184420297377, 0.691371828363497, 0.23919632743352925],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.10287655363321169, 0.6234718442658671, 0.27365160210092115],
                                [0.9356343307868777, 0.01784699168656139, 0.046518677526560935],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.9305681557970263, 0.04901406471567565, 0.020417779487298067],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.9356343307868777, 0.04651867752656094, 0.017846991686561387],
                                [0.6940700458796986, 0.08482673161956347, 0.22110322250073802],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.6699905217924281, 0.23296379503282028, 0.09704568317475158],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.6940700458796986, 0.221103222500738, 0.0848267316195635],
                                [0.3788961132077828, 0.17221658750052704, 0.44888729929169013],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.33000947820757187, 0.47296682337896045, 0.19702369841346767],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.3788961132077828, 0.44888729929169, 0.17221658750052715],
                                [0.13733182830060364, 0.23919632743352925, 0.6234718442658671],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.06943184420297377, 0.656916553696105, 0.2736516021009212],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.13733182830060364, 0.6234718442658671, 0.23919632743352925],
                                [0.9376047047688514, 0.015876617704587752, 0.046518677526560935],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.9305681557970263, 0.04704369073370201, 0.022388153469271706],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.9376047047688514, 0.04651867752656094, 0.01587661770458775],
                                [0.703435231222666, 0.07546154627659593, 0.22110322250073802],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.669990521792428, 0.22359860968985273, 0.10641086851771915],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.703435231222666, 0.22110322250073802, 0.07546154627659593],
                                [0.39790946230520163, 0.15320323840310823, 0.44888729929169013],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.3300094782075719, 0.4539534742815415, 0.21603704751088665],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.39790946230520163, 0.44888729929169013, 0.1532032384031082],
                                [0.1637399887590164, 0.2127881669751165, 0.6234718442658671],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.06943184420297377, 0.6305083932376921, 0.3000597625593341],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.1637399887590164, 0.6234718442658672, 0.21278816697511638],
                                [0.9316340460087587, 0.021847276464680397, 0.046518677526560935],
                                [0.9305681557970263, 0.007561562178966107, 0.06187028202400761],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9305681557970262, 0.06080439181227522, 0.008627452390698493],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.9316340460087587, 0.04651867752656094, 0.021847276464680394],
                                [0.6750566967822795, 0.10384008071698245, 0.22110322250073802],
                                [0.6699905217924282, 0.03594009661935266, 0.2940693815882192],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.6699905217924281, 0.28900320659836787, 0.041006271609204024],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.6750566967822795, 0.221103222500738, 0.10384008071698247],
                                [0.3402949077151671, 0.21081779299314274, 0.44888729929169013],
                                [0.33000947820757187, 0.07296615908748127, 0.5970243627049469],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.33000947820757187, 0.5867389331973516, 0.08325158859507649],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.3402949077151671, 0.44888729929169013, 0.21081779299314274],
                                [0.083717558488688, 0.2928105972454449, 0.6234718442658671],
                                [0.06943184420297377, 0.10134469352786779, 0.8292234622691584],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.06943184420297377, 0.8149377479834442, 0.11563040781358203],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.083717558488688, 0.6234718442658672, 0.2928105972454448],
                                [0.9356343307868777, 0.01784699168656139, 0.046518677526560935],
                                [0.9305681557970263, 0.007561562178966107, 0.06187028202400761],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9305681557970263, 0.05680410703415622, 0.012627737168817495],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.9356343307868777, 0.04651867752656094, 0.017846991686561387],
                                [0.6940700458796986, 0.08482673161956347, 0.22110322250073802],
                                [0.6699905217924282, 0.03594009661935266, 0.2940693815882192],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.669990521792428, 0.2699898575009489, 0.06001962070662299],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.6940700458796986, 0.221103222500738, 0.0848267316195635],
                                [0.3788961132077828, 0.17221658750052704, 0.44888729929169013],
                                [0.33000947820757187, 0.07296615908748127, 0.5970243627049469],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.33000947820757187, 0.548137727704736, 0.12185279408769208],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.3788961132077828, 0.44888729929169, 0.17221658750052715],
                                [0.13733182830060364, 0.23919632743352925, 0.6234718442658671],
                                [0.06943184420297377, 0.10134469352786779, 0.8292234622691584],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.06943184420297377, 0.7613234781715287, 0.16924467762549755],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.13733182830060364, 0.6234718442658671, 0.23919632743352925],
                                [0.9408535853046216, 0.012627737168817495, 0.046518677526560935],
                                [0.9305681557970263, 0.007561562178966107, 0.06187028202400761],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9305681557970263, 0.05158485251641233, 0.017846991686561387],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.9408535853046216, 0.046518677526560935, 0.012627737168817495],
                                [0.7188771567926391, 0.06001962070662295, 0.22110322250073802],
                                [0.6699905217924282, 0.03594009661935266, 0.2940693815882192],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.6699905217924282, 0.24518274658800837, 0.0848267316195635],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.718877156792639, 0.221103222500738, 0.06001962070662299],
                                [0.42925990662061786, 0.121852794087692, 0.44888729929169013],
                                [0.33000947820757187, 0.07296615908748127, 0.5970243627049469],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.33000947820757187, 0.497773934291901, 0.17221658750052715],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.4292599066206178, 0.4488872992916901, 0.12185279408769208],
                                [0.20728347810863534, 0.16924467762549755, 0.6234718442658671],
                                [0.06943184420297377, 0.10134469352786779, 0.8292234622691584],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.06943184420297377, 0.691371828363497, 0.23919632743352925],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.20728347810863534, 0.6234718442658671, 0.16924467762549755],
                                [0.9448538700827406, 0.008627452390698495, 0.046518677526560935],
                                [0.9305681557970263, 0.007561562178966107, 0.06187028202400761],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9305681557970262, 0.047584567738293324, 0.021847276464680394],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.9448538700827406, 0.046518677526560935, 0.008627452390698493],
                                [0.737890505890058, 0.04100627160920403, 0.22110322250073802],
                                [0.6699905217924282, 0.03594009661935266, 0.2940693815882192],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.6699905217924281, 0.2261693974905894, 0.10384008071698247],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.737890505890058, 0.22110322250073802, 0.04100627160920403],
                                [0.46786111211323334, 0.08325158859507653, 0.44888729929169013],
                                [0.33000947820757187, 0.07296615908748127, 0.5970243627049469],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.33000947820757187, 0.4591727287992854, 0.21081779299314274],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.46786111211323334, 0.44888729929169013, 0.0832515885950765],
                                [0.26089774792055076, 0.11563040781358214, 0.6234718442658671],
                                [0.06943184420297377, 0.10134469352786779, 0.8292234622691584],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.06943184420297377, 0.6377575585515814, 0.2928105972454448],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.26089774792055076, 0.6234718442658672, 0.11563040781358204],
                                [0.9320485998575786, 0.021432722615860524, 0.046518677526560935],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9305681557970262, 0.06636049672354799, 0.003071347479425723],
                                [0.9305681557970262, 0.06784094078410025, 0.0015909034188734625],
                                [0.9320485998575786, 0.04651867752656094, 0.021432722615860517],
                                [0.6770270707642532, 0.10186970673500881, 0.22110322250073802],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.6699905217924281, 0.31541136705678074, 0.014598111150791144],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966112],
                                [0.6770270707642532, 0.221103222500738, 0.10186970673500882],
                                [0.3442951924932861, 0.20681750821502376, 0.44888729929169013],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.33000947820757187, 0.6403532030092671, 0.029637318783160973],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446688],
                                [0.3442951924932861, 0.44888729929169013, 0.20681750821502373],
                                [0.08927366339996079, 0.2872544923341721, 0.6234718442658671],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.06943184420297377, 0.8894040733424998, 0.04116408245452639],
                                [0.06943184420297377, 0.9092458925394868, 0.021322263257539335],
                                [0.08927366339996079, 0.6234718442658672, 0.287254492334172],
                                [0.9376047047688514, 0.015876617704587752, 0.046518677526560935],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9305681557970262, 0.06080439181227522, 0.008627452390698493],
                                [0.9305681557970262, 0.06784094078410025, 0.0015909034188734625],
                                [0.9376047047688514, 0.04651867752656094, 0.01587661770458775],
                                [0.703435231222666, 0.07546154627659593, 0.22110322250073802],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.6699905217924281, 0.28900320659836787, 0.04100627160920403],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966112],
                                [0.703435231222666, 0.22110322250073802, 0.07546154627659593],
                                [0.39790946230520163, 0.15320323840310823, 0.44888729929169013],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.33000947820757187, 0.5867389331973516, 0.0832515885950765],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446688],
                                [0.39790946230520163, 0.44888729929169013, 0.1532032384031082],
                                [0.1637399887590164, 0.2127881669751165, 0.6234718442658671],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.06943184420297377, 0.8149377479834442, 0.11563040781358204],
                                [0.06943184420297377, 0.9092458925394868, 0.021322263257539335],
                                [0.1637399887590164, 0.6234718442658672, 0.21278816697511638],
                                [0.9448538700827406, 0.008627452390698495, 0.046518677526560935],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9305681557970263, 0.05355522649838597, 0.01587661770458775],
                                [0.9305681557970262, 0.06784094078410025, 0.0015909034188734625],
                                [0.9448538700827406, 0.046518677526560935, 0.008627452390698493],
                                [0.737890505890058, 0.04100627160920403, 0.22110322250073802],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.6699905217924281, 0.2545479319309759, 0.07546154627659593],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966112],
                                [0.737890505890058, 0.22110322250073802, 0.04100627160920403],
                                [0.46786111211323334, 0.08325158859507653, 0.44888729929169013],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.33000947820757187, 0.5167872833893199, 0.1532032384031082],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446688],
                                [0.46786111211323334, 0.44888729929169013, 0.0832515885950765],
                                [0.26089774792055076, 0.11563040781358214, 0.6234718442658671],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.06943184420297377, 0.7177799888219099, 0.21278816697511638],
                                [0.06943184420297377, 0.9092458925394868, 0.021322263257539335],
                                [0.26089774792055076, 0.6234718442658672, 0.11563040781358204],
                                [0.9504099749940134, 0.0030713474794257234, 0.046518677526560935],
                                [0.9305681557970262, 0.0015909034188734683, 0.06784094078410025],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9305681557970263, 0.0479991215871132, 0.021432722615860517],
                                [0.9305681557970262, 0.06784094078410025, 0.0015909034188734625],
                                [0.9504099749940134, 0.046518677526560935, 0.0030713474794257243],
                                [0.7642986663484709, 0.014598111150791154, 0.22110322250073802],
                                [0.669990521792428, 0.007561562178966141, 0.32244791602860573],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.6699905217924281, 0.22813977147256304, 0.10186970673500882],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966112],
                                [0.7642986663484709, 0.22110322250073802, 0.014598111150791147],
                                [0.521475381925149, 0.02963731878316095, 0.44888729929169013],
                                [0.33000947820757187, 0.01535160449744677, 0.6546389172949814],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.33000947820757187, 0.46317301357740437, 0.20681750821502373],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446688],
                                [0.521475381925149, 0.4488872992916901, 0.029637318783160983],
                                [0.3353640732796065, 0.04116408245452641, 0.6234718442658671],
                                [0.06943184420297377, 0.021322263257539387, 0.9092458925394868],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.06943184420297377, 0.6433136634628542, 0.287254492334172],
                                [0.06943184420297377, 0.9092458925394868, 0.021322263257539335],
                                [0.3353640732796065, 0.6234718442658671, 0.04116408245452641],
                                [0.9307924121532996, 0.046294421170287654, 0.02291316667641278],
                                [0.9305681557970262, 0.043288799956008386, 0.02614304424696533],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9305681557970263, 0.025918787890692047, 0.04351305631228167],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.9307924121532997, 0.022913166676412786, 0.04629442117028765],
                                [0.6710564120041606, 0.2200373322890056, 0.10890625570683385],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428052],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6699905217924281, 0.12319196999254811, 0.20681750821502376],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.6710564120041604, 0.10890625570683382, 0.22003733228900563],
                                [0.33217346556639205, 0.44672331193286996, 0.22110322250073802],
                                [0.33000947820757187, 0.4177202262625759, 0.25227029552985225],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.33000947820757187, 0.2501063081710321, 0.41988421362139605],
                                [0.33000947820757187, 0.25227029552985225, 0.4177202262625759],
                                [0.332173465566392, 0.22110322250073805, 0.4467233119328699],
                                [0.07243746541725304, 0.6204662230515878, 0.30709631153115907],
                                [0.06943184420297377, 0.5801830443098588, 0.35038511148716744],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.06943184420297377, 0.34737949027288817, 0.5831886655241381],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.07243746541725304, 0.3070963115311591, 0.6204662230515878],
                                [0.9316340460087587, 0.045452787314828554, 0.02291316667641278],
                                [0.9305681557970262, 0.043288799956008386, 0.02614304424696533],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9305681557970263, 0.025077154035232946, 0.04435469016774077],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.9316340460087588, 0.022913166676412786, 0.04545278731482855],
                                [0.6750566967822795, 0.21603704751088662, 0.10890625570683385],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428052],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6699905217924281, 0.11919168521442913, 0.21081779299314274],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.6750566967822795, 0.10890625570683385, 0.21603704751088662],
                                [0.3402949077151671, 0.4386018697840949, 0.22110322250073802],
                                [0.33000947820757187, 0.4177202262625759, 0.25227029552985225],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.33000947820757187, 0.241984866022257, 0.42800565577017113],
                                [0.33000947820757187, 0.25227029552985225, 0.4177202262625759],
                                [0.3402949077151672, 0.22110322250073805, 0.4386018697840948],
                                [0.083717558488688, 0.6091861299801529, 0.30709631153115907],
                                [0.06943184420297377, 0.5801830443098588, 0.35038511148716744],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.06943184420297377, 0.3360993972014532, 0.594468758595573],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.083717558488688, 0.3070963115311591, 0.6091861299801529],
                                [0.9327321431558465, 0.044354690167740775, 0.02291316667641278],
                                [0.9305681557970262, 0.043288799956008386, 0.02614304424696533],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9305681557970263, 0.023979056888145167, 0.04545278731482855],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.9327321431558465, 0.022913166676412786, 0.04435469016774077],
                                [0.6802759513000234, 0.21081779299314277, 0.10890625570683385],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428052],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6699905217924281, 0.11397243069668525, 0.21603704751088662],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.6802759513000234, 0.10890625570683388, 0.21081779299314274],
                                [0.35089112172909087, 0.42800565577017113, 0.22110322250073802],
                                [0.33000947820757187, 0.4177202262625759, 0.25227029552985225],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.3300094782075719, 0.2313886520083333, 0.4386018697840948],
                                [0.33000947820757187, 0.25227029552985225, 0.4177202262625759],
                                [0.35089112172909087, 0.221103222500738, 0.42800565577017113],
                                [0.09843492987326785, 0.594468758595573, 0.30709631153115907],
                                [0.06943184420297377, 0.5801830443098588, 0.35038511148716744],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.06943184420297377, 0.32138202581687336, 0.6091861299801529],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.09843492987326785, 0.3070963115311591, 0.594468758595573],
                                [0.9335737770113056, 0.04351305631228166, 0.02291316667641278],
                                [0.9305681557970262, 0.043288799956008386, 0.02614304424696533],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9305681557970262, 0.02313742303268606, 0.046294421170287654],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.9335737770113056, 0.02291316667641278, 0.04351305631228166],
                                [0.6842762360781424, 0.20681750821502373, 0.10890625570683385],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428052],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6699905217924281, 0.10997214591856622, 0.22003733228900565],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.6842762360781425, 0.10890625570683388, 0.2068175082150237],
                                [0.35901256387786595, 0.41988421362139605, 0.22110322250073802],
                                [0.33000947820757187, 0.4177202262625759, 0.25227029552985225],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.3300094782075719, 0.2232672098595581, 0.44672331193287],
                                [0.33000947820757187, 0.25227029552985225, 0.4177202262625759],
                                [0.3590125638778659, 0.22110322250073805, 0.419884213621396],
                                [0.10971502294470281, 0.5831886655241381, 0.30709631153115907],
                                [0.06943184420297377, 0.5801830443098588, 0.35038511148716744],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.06943184420297377, 0.3101019327454383, 0.6204662230515879],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.10971502294470292, 0.3070963115311591, 0.583188665524138],
                                [0.9316340460087587, 0.045452787314828554, 0.02291316667641278],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9305681557970262, 0.03719888096212706, 0.03223296324084665],
                                [0.9305681557970263, 0.03826477117385945, 0.031167073029114263],
                                [0.9316340460087588, 0.022913166676412786, 0.04545278731482855],
                                [0.6750566967822795, 0.21603704751088662, 0.10890625570683385],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.6699905217924281, 0.17680623980446367, 0.1532032384031082],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.6750566967822795, 0.10890625570683385, 0.21603704751088662],
                                [0.3402949077151671, 0.4386018697840949, 0.22110322250073802],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.3300094782075718, 0.3589548564063995, 0.3110356653860286],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.3402949077151672, 0.22110322250073805, 0.4386018697840948],
                                [0.083717558488688, 0.6091861299801529, 0.30709631153115907],
                                [0.06943184420297377, 0.4177202262625759, 0.5128479295344504],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.06943184420297377, 0.4985622152487361, 0.4320059405482901],
                                [0.06943184420297377, 0.5128479295344504, 0.4177202262625758],
                                [0.083717558488688, 0.3070963115311591, 0.6091861299801529],
                                [0.9356343307868777, 0.04145250253670955, 0.02291316667641278],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9305681557970262, 0.033198596184008056, 0.03623324801896566],
                                [0.9305681557970263, 0.03826477117385945, 0.031167073029114263],
                                [0.9356343307868777, 0.02291316667641278, 0.04145250253670955],
                                [0.6940700458796984, 0.19702369841346765, 0.10890625570683385],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.6699905217924281, 0.1577928907070447, 0.17221658750052718],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.6940700458796984, 0.10890625570683382, 0.19702369841346767],
                                [0.3788961132077828, 0.4000006642914792, 0.22110322250073802],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.3300094782075719, 0.3203536509137839, 0.3496368708786442],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.3788961132077828, 0.22110322250073788, 0.4000006642914793],
                                [0.13733182830060353, 0.5555718601682373, 0.30709631153115907],
                                [0.06943184420297377, 0.4177202262625759, 0.5128479295344504],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.06943184420297377, 0.4449479454368205, 0.48562021036020575],
                                [0.06943184420297377, 0.5128479295344504, 0.4177202262625758],
                                [0.13733182830060364, 0.307096311531159, 0.5555718601682373],
                                [0.9408535853046216, 0.03623324801896565, 0.02291316667641278],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9305681557970263, 0.027979341666264167, 0.04145250253670955],
                                [0.9305681557970263, 0.03826477117385945, 0.031167073029114263],
                                [0.9408535853046216, 0.02291316667641278, 0.03623324801896565],
                                [0.718877156792639, 0.17221658750052712, 0.10890625570683385],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.6699905217924281, 0.1329857797941042, 0.19702369841346767],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.7188771567926391, 0.10890625570683382, 0.17221658750052715],
                                [0.42925990662061786, 0.34963687087864415, 0.22110322250073802],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.33000947820757187, 0.26998985750094884, 0.4000006642914793],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.42925990662061786, 0.221103222500738, 0.34963687087864415],
                                [0.2072834781086353, 0.4856202103602056, 0.30709631153115907],
                                [0.06943184420297377, 0.4177202262625759, 0.5128479295344504],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.06943184420297377, 0.3749962956287889, 0.5555718601682373],
                                [0.06943184420297377, 0.5128479295344504, 0.4177202262625758],
                                [0.20728347810863534, 0.307096311531159, 0.48562021036020564],
                                [0.9448538700827406, 0.03223296324084665, 0.02291316667641278],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9305681557970263, 0.023979056888145167, 0.04545278731482855],
                                [0.9305681557970263, 0.03826477117385945, 0.031167073029114263],
                                [0.9448538700827406, 0.02291316667641278, 0.03223296324084665],
                                [0.7378905058900579, 0.1532032384031082, 0.10890625570683385],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.6699905217924281, 0.11397243069668525, 0.21603704751088662],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.7378905058900579, 0.10890625570683385, 0.1532032384031082],
                                [0.46786111211323334, 0.31103566538602867, 0.22110322250073802],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.3300094782075719, 0.2313886520083333, 0.4386018697840948],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.4678611121132333, 0.22110322250073805, 0.3110356653860286],
                                [0.2608977479205507, 0.43200594054829017, 0.30709631153115907],
                                [0.06943184420297377, 0.4177202262625759, 0.5128479295344504],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.06943184420297377, 0.32138202581687336, 0.6091861299801529],
                                [0.06943184420297377, 0.5128479295344504, 0.4177202262625758],
                                [0.26089774792055076, 0.3070963115311591, 0.4320059405482901],
                                [0.9327321431558465, 0.044354690167740775, 0.02291316667641278],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9305681557970263, 0.051916252346706875, 0.01751559185626684],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446672],
                                [0.9327321431558465, 0.022913166676412786, 0.04435469016774077],
                                [0.6802759513000234, 0.21081779299314277, 0.10890625570683385],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.669990521792428, 0.2467578896124954, 0.08325158859507649],
                                [0.6699905217924282, 0.25704331912009065, 0.0729661590874812],
                                [0.6802759513000234, 0.10890625570683388, 0.21081779299314274],
                                [0.35089112172909087, 0.42800565577017113, 0.22110322250073802],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.33000947820757187, 0.5009718148576524, 0.16901870693477575],
                                [0.33000947820757176, 0.5218534583791714, 0.14813706341325678],
                                [0.35089112172909087, 0.221103222500738, 0.42800565577017113],
                                [0.09843492987326785, 0.594468758595573, 0.30709631153115907],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.06943184420297377, 0.6958134521234408, 0.2347547036735854],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.09843492987326785, 0.3070963115311591, 0.594468758595573],
                                [0.9408535853046216, 0.03623324801896565, 0.02291316667641278],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9305681557970263, 0.04379481019793176, 0.02563703400504196],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446672],
                                [0.9408535853046216, 0.02291316667641278, 0.03623324801896565],
                                [0.718877156792639, 0.17221658750052712, 0.10890625570683385],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.669990521792428, 0.2081566841198798, 0.12185279408769208],
                                [0.6699905217924282, 0.25704331912009065, 0.0729661590874812],
                                [0.7188771567926391, 0.10890625570683382, 0.17221658750052715],
                                [0.42925990662061786, 0.34963687087864415, 0.22110322250073802],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.33000947820757187, 0.4226030299661254, 0.24738749182630274],
                                [0.33000947820757176, 0.5218534583791714, 0.14813706341325678],
                                [0.42925990662061786, 0.221103222500738, 0.34963687087864415],
                                [0.2072834781086353, 0.4856202103602056, 0.30709631153115907],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.06943184420297377, 0.5869649038880733, 0.34360325190895286],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.20728347810863534, 0.307096311531159, 0.48562021036020564],
                                [0.9514497993185453, 0.025637034005041956, 0.02291316667641278],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9305681557970262, 0.03319859618400806, 0.03623324801896565],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446672],
                                [0.9514497993185453, 0.022913166676412775, 0.02563703400504196],
                                [0.769240950205474, 0.12185279408769209, 0.10890625570683385],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.6699905217924281, 0.15779289070704472, 0.17221658750052715],
                                [0.6699905217924282, 0.25704331912009065, 0.0729661590874812],
                                [0.769240950205474, 0.10890625570683386, 0.12185279408769208],
                                [0.5315092856729593, 0.24738749182630274, 0.22110322250073802],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.33000947820757187, 0.320353650913784, 0.34963687087864415],
                                [0.33000947820757176, 0.5218534583791714, 0.14813706341325678],
                                [0.5315092856729593, 0.22110322250073802, 0.24738749182630274],
                                [0.349300436559888, 0.34360325190895286, 0.30709631153115907],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.06943184420297377, 0.4449479454368206, 0.48562021036020564],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.349300436559888, 0.30709631153115907, 0.34360325190895286],
                                [0.9595712414673204, 0.01751559185626684, 0.02291316667641278],
                                [0.9305681557970263, 0.015351604497446672, 0.05408023970552704],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9305681557970263, 0.025077154035232953, 0.04435469016774076],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446672],
                                [0.9595712414673204, 0.022913166676412775, 0.017515591856266843],
                                [0.8078421556980896, 0.0832515885950765, 0.10890625570683385],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.6699905217924281, 0.11919168521442916, 0.2108177929931427],
                                [0.6699905217924282, 0.25704331912009065, 0.0729661590874812],
                                [0.8078421556980896, 0.10890625570683383, 0.08325158859507652],
                                [0.6098780705644863, 0.16901870693477575, 0.22110322250073802],
                                [0.33000947820757187, 0.14813706341325683, 0.5218534583791713],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.3300094782075719, 0.24198486602225705, 0.4280056557701711],
                                [0.33000947820757176, 0.5218534583791714, 0.14813706341325678],
                                [0.6098780705644862, 0.22110322250073797, 0.1690187069347758],
                                [0.4581489847952555, 0.23475470367358536, 0.30709631153115907],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.06943184420297377, 0.3360993972014533, 0.5944687585955729],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.45814898479525556, 0.307096311531159, 0.23475470367358545],
                                [0.9335737770113056, 0.043513056312281674, 0.02291316667641278],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9305681557970262, 0.06319634541814188, 0.006235498784831829],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525595],
                                [0.9335737770113056, 0.022913166676412793, 0.04351305631228166],
                                [0.6842762360781424, 0.20681750821502373, 0.10890625570683385],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.6699905217924281, 0.30037215942441087, 0.029637318783160987],
                                [0.6699905217924282, 0.31465787371012516, 0.015351604497446703],
                                [0.6842762360781425, 0.10890625570683388, 0.2068175082150237],
                                [0.35901256387786595, 0.41988421362139605, 0.22110322250073802],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.33000947820757187, 0.6098203630930197, 0.06017015869940841],
                                [0.33000947820757187, 0.6388234487633138, 0.031167073029114322],
                                [0.3590125638778659, 0.22110322250073805, 0.419884213621396],
                                [0.10971502294470281, 0.5831886655241381, 0.30709631153115907],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.06943184420297377, 0.8469961770992886, 0.08357197869773757],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600846],
                                [0.10971502294470281, 0.30709631153115924, 0.583188665524138],
                                [0.9448538700827406, 0.03223296324084665, 0.02291316667641278],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9305681557970263, 0.05191625234670687, 0.017515591856266846],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525595],
                                [0.9448538700827406, 0.02291316667641278, 0.03223296324084665],
                                [0.7378905058900579, 0.1532032384031082, 0.10890625570683385],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.6699905217924281, 0.24675788961249534, 0.08325158859507653],
                                [0.6699905217924282, 0.31465787371012516, 0.015351604497446703],
                                [0.7378905058900579, 0.10890625570683385, 0.1532032384031082],
                                [0.46786111211323334, 0.31103566538602867, 0.22110322250073802],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.33000947820757187, 0.5009718148576523, 0.16901870693477583],
                                [0.33000947820757187, 0.6388234487633138, 0.031167073029114322],
                                [0.4678611121132333, 0.22110322250073805, 0.3110356653860286],
                                [0.2608977479205507, 0.43200594054829017, 0.30709631153115907],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.06943184420297377, 0.6958134521234407, 0.2347547036735855],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600846],
                                [0.26089774792055076, 0.3070963115311591, 0.4320059405482901],
                                [0.9595712414673204, 0.017515591856266846, 0.02291316667641278],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9305681557970262, 0.03719888096212706, 0.03223296324084665],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525595],
                                [0.9595712414673204, 0.02291316667641278, 0.017515591856266846],
                                [0.8078421556980896, 0.08325158859507653, 0.10890625570683385],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.6699905217924281, 0.17680623980446367, 0.1532032384031082],
                                [0.6699905217924282, 0.31465787371012516, 0.015351604497446703],
                                [0.8078421556980896, 0.10890625570683385, 0.08325158859507653],
                                [0.6098780705644862, 0.1690187069347758, 0.22110322250073802],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.3300094782075718, 0.3589548564063995, 0.3110356653860286],
                                [0.33000947820757187, 0.6388234487633138, 0.031167073029114322],
                                [0.6098780705644862, 0.221103222500738, 0.16901870693477583],
                                [0.4581489847952554, 0.23475470367358547, 0.30709631153115907],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.06943184420297377, 0.4985622152487361, 0.4320059405482901],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600846],
                                [0.45814898479525545, 0.307096311531159, 0.2347547036735855],
                                [0.9708513345387554, 0.006235498784831834, 0.02291316667641278],
                                [0.9305681557970262, 0.0032298775705525556, 0.06620196663242116],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9305681557970263, 0.025918787890692054, 0.04351305631228166],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525595],
                                [0.9708513345387554, 0.02291316667641278, 0.006235498784831832],
                                [0.8614564255100051, 0.029637318783161004, 0.10890625570683385],
                                [0.6699905217924282, 0.015351604497446714, 0.31465787371012516],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.6699905217924282, 0.12319196999254817, 0.2068175082150237],
                                [0.6699905217924282, 0.31465787371012516, 0.015351604497446703],
                                [0.8614564255100051, 0.10890625570683385, 0.029637318783161004],
                                [0.7187266187998536, 0.06017015869940842, 0.22110322250073802],
                                [0.33000947820757187, 0.031167073029114367, 0.6388234487633138],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.3300094782075718, 0.25010630817103213, 0.419884213621396],
                                [0.33000947820757187, 0.6388234487633138, 0.031167073029114322],
                                [0.7187266187998536, 0.221103222500738, 0.06017015869940845],
                                [0.6093317097711033, 0.08357197869773764, 0.30709631153115907],
                                [0.06943184420297377, 0.04328879995600843, 0.8872793558410178],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.06943184420297377, 0.3473794902728883, 0.583188665524138],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600846],
                                [0.6093317097711033, 0.30709631153115907, 0.08357197869773762],
                                [0.9308796315822727, 0.06429958742830122, 0.004820780989426019],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257549],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9305681557970262, 0.008995370479011076, 0.06043647372396264],
                                [0.9305681557970262, 0.009306846264257547, 0.06012499793871617],
                                [0.9308796315822727, 0.004820780989426024, 0.06429958742830122],
                                [0.6714709658529805, 0.3056158674706068, 0.022913166676412796],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395212],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.6699905217924281, 0.042754985873399876, 0.287254492334172],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.6714709658529803, 0.0229131666764128, 0.3056158674706068],
                                [0.33301509942185126, 0.6204662230515878, 0.04651867752656097],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256936],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.33000947820757187, 0.08680185626829007, 0.5831886655241381],
                                [0.33000947820757187, 0.08980747748256934, 0.5801830443098588],
                                [0.33301509942185115, 0.046518677526560914, 0.6204662230515879],
                                [0.07360643369255881, 0.8617825030938935, 0.06461106321354775],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226392],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.06943184420297377, 0.12056147166267883, 0.8100066841343474],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.07360643369255881, 0.0646110632135477, 0.8617825030938935],
                                [0.9320485998575785, 0.06313061915299543, 0.004820780989426019],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257549],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9305681557970262, 0.007826402203705292, 0.06160544199926842],
                                [0.9305681557970262, 0.009306846264257547, 0.06012499793871617],
                                [0.9320485998575785, 0.004820780989426024, 0.06313061915299543],
                                [0.6770270707642532, 0.30005976255933403, 0.022913166676412796],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395212],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.6699905217924281, 0.03719888096212709, 0.2928105972454448],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.6770270707642532, 0.0229131666764128, 0.30005976255933403],
                                [0.3442951924932862, 0.6091861299801529, 0.04651867752656097],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256936],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.33000947820757187, 0.07552176319685511, 0.594468758595573],
                                [0.33000947820757187, 0.08980747748256934, 0.5801830443098588],
                                [0.3442951924932861, 0.046518677526561025, 0.6091861299801529],
                                [0.08927366339996079, 0.8461152733864915, 0.06461106321354775],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226392],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.06943184420297377, 0.10489424195527686, 0.8256739138417494],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.08927366339996079, 0.0646110632135477, 0.8461152733864915],
                                [0.9335737770113055, 0.061605441999268436, 0.004820780989426019],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257549],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9305681557970262, 0.006301225049978279, 0.06313061915299543],
                                [0.9305681557970262, 0.009306846264257547, 0.06012499793871617],
                                [0.9335737770113055, 0.004820780989426024, 0.06160544199926843],
                                [0.6842762360781425, 0.2928105972454448, 0.022913166676412796],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395212],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.6699905217924282, 0.02994971564823784, 0.30005976255933403],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.6842762360781425, 0.0229131666764128, 0.2928105972454448],
                                [0.35901256387786606, 0.594468758595573, 0.04651867752656097],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256936],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.33000947820757187, 0.06080439181227526, 0.6091861299801529],
                                [0.33000947820757187, 0.08980747748256934, 0.5801830443098588],
                                [0.35901256387786595, 0.046518677526560914, 0.5944687585955731],
                                [0.10971502294470281, 0.8256739138417495, 0.06461106321354775],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226392],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.06943184420297377, 0.08445288241053484, 0.8461152733864914],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.10971502294470281, 0.0646110632135477, 0.8256739138417495],
                                [0.9347427452866113, 0.06043647372396264, 0.004820780989426019],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257549],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9305681557970262, 0.0051322567746724945, 0.06429958742830122],
                                [0.9305681557970262, 0.009306846264257547, 0.06012499793871617],
                                [0.9347427452866113, 0.004820780989426017, 0.06043647372396264],
                                [0.6898323409894153, 0.287254492334172, 0.022913166676412796],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395212],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.669990521792428, 0.024393610736965055, 0.3056158674706068],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.6898323409894151, 0.0229131666764128, 0.287254492334172],
                                [0.370292656949301, 0.5831886655241381, 0.04651867752656097],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256936],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.33000947820757187, 0.04952429874084019, 0.6204662230515879],
                                [0.33000947820757187, 0.08980747748256934, 0.5801830443098588],
                                [0.370292656949301, 0.046518677526560914, 0.5831886655241381],
                                [0.1253822526521049, 0.8100066841343474, 0.06461106321354775],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226392],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.06943184420297377, 0.06878565270313275, 0.8617825030938935],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.1253822526521049, 0.0646110632135477, 0.8100066841343474],
                                [0.9320485998575785, 0.06313061915299543, 0.004820780989426019],
                                [0.9305681557970262, 0.04328879995600838, 0.026143044246965334],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9305681557970262, 0.02466260018641308, 0.044769244016560635],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.9320485998575785, 0.004820780989426024, 0.06313061915299543],
                                [0.6770270707642532, 0.30005976255933403, 0.022913166676412796],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428053],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.669990521792428, 0.11722131123245555, 0.21278816697511632],
                                [0.6699905217924281, 0.12425786020428056, 0.2057516180032913],
                                [0.6770270707642532, 0.0229131666764128, 0.30005976255933403],
                                [0.3442951924932862, 0.6091861299801529, 0.04651867752656097],
                                [0.3300094782075718, 0.4177202262625758, 0.2522702955298523],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.3300094782075718, 0.23798458124413807, 0.43200594054829006],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.3442951924932861, 0.046518677526561025, 0.6091861299801529],
                                [0.08927366339996079, 0.8461152733864915, 0.06461106321354775],
                                [0.06943184420297377, 0.5801830443098588, 0.3503851114871675],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.06943184420297377, 0.33054329229018053, 0.6000248635068457],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.08927366339996079, 0.0646110632135477, 0.8461152733864915],
                                [0.9376047047688513, 0.05757451424172267, 0.004820780989426019],
                                [0.9305681557970262, 0.04328879995600838, 0.026143044246965334],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9305681557970263, 0.019106495275140314, 0.0503253489278334],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.9376047047688513, 0.004820780989426017, 0.05757451424172267],
                                [0.7034352312226662, 0.27365160210092115, 0.022913166676412796],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428053],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.6699905217924282, 0.09081315077404267, 0.2391963274335292],
                                [0.6699905217924281, 0.12425786020428056, 0.2057516180032913],
                                [0.7034352312226659, 0.0229131666764128, 0.27365160210092115],
                                [0.39790946230520174, 0.5555718601682373, 0.04651867752656097],
                                [0.3300094782075718, 0.4177202262625758, 0.2522702955298523],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.3300094782075718, 0.18437031143222254, 0.4856202103602056],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.39790946230520163, 0.046518677526561025, 0.5555718601682373],
                                [0.1637399887590164, 0.7716489480274359, 0.06461106321354775],
                                [0.06943184420297377, 0.5801830443098588, 0.3503851114871675],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.06943184420297377, 0.2560769669311249, 0.6744911888659013],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.1637399887590164, 0.0646110632135477, 0.7716489480274359],
                                [0.9448538700827405, 0.05032534892783341, 0.004820780989426019],
                                [0.9305681557970262, 0.04328879995600838, 0.026143044246965334],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9305681557970262, 0.01185732996125105, 0.05757451424172266],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.9448538700827405, 0.004820780989426017, 0.05032534892783341],
                                [0.737890505890058, 0.23919632743352925, 0.022913166676412796],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428053],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.669990521792428, 0.05635787610665072, 0.27365160210092115],
                                [0.6699905217924281, 0.12425786020428056, 0.2057516180032913],
                                [0.737890505890058, 0.0229131666764128, 0.23919632743352925],
                                [0.4678611121132334, 0.4856202103602057, 0.04651867752656097],
                                [0.3300094782075718, 0.4177202262625758, 0.2522702955298523],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.33000947820757187, 0.11441866162419079, 0.5555718601682373],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.46786111211323334, 0.046518677526561025, 0.48562021036020564],
                                [0.26089774792055076, 0.6744911888659015, 0.06461106321354775],
                                [0.06943184420297377, 0.5801830443098588, 0.3503851114871675],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.06943184420297377, 0.15891920776959045, 0.7716489480274358],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.26089774792055076, 0.06461106321354781, 0.6744911888659014],
                                [0.9504099749940133, 0.04476924401656064, 0.004820780989426019],
                                [0.9305681557970262, 0.04328879995600838, 0.026143044246965334],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9305681557970262, 0.006301225049978279, 0.06313061915299543],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.9504099749940133, 0.004820780989426017, 0.04476924401656064],
                                [0.7642986663484709, 0.21278816697511638, 0.022913166676412796],
                                [0.6699905217924281, 0.20575161800329134, 0.12425786020428053],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.6699905217924282, 0.02994971564823784, 0.30005976255933403],
                                [0.6699905217924281, 0.12425786020428056, 0.2057516180032913],
                                [0.7642986663484708, 0.0229131666764128, 0.21278816697511638],
                                [0.521475381925149, 0.4320059405482901, 0.04651867752656097],
                                [0.3300094782075718, 0.4177202262625758, 0.2522702955298523],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.33000947820757187, 0.06080439181227526, 0.6091861299801529],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.521475381925149, 0.04651867752656097, 0.4320059405482901],
                                [0.3353640732796065, 0.6000248635068458, 0.06461106321354775],
                                [0.06943184420297377, 0.5801830443098588, 0.3503851114871675],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.06943184420297377, 0.08445288241053484, 0.8461152733864914],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.3353640732796065, 0.0646110632135477, 0.6000248635068458],
                                [0.9335737770113055, 0.061605441999268436, 0.004820780989426019],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9305681557970263, 0.04510395973115512, 0.02432788447181859],
                                [0.9305681557970263, 0.048109580945434396, 0.02132226325753932],
                                [0.9335737770113055, 0.004820780989426024, 0.06160544199926843],
                                [0.6842762360781425, 0.2928105972454448, 0.022913166676412796],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.6699905217924281, 0.21437907039398985, 0.11563040781358204],
                                [0.6699905217924281, 0.2286647846797041, 0.10134469352786776],
                                [0.6842762360781425, 0.0229131666764128, 0.2928105972454448],
                                [0.35901256387786606, 0.594468758595573, 0.04651867752656097],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.33000947820757187, 0.4352358181188427, 0.23475470367358545],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329136],
                                [0.35901256387786595, 0.046518677526560914, 0.5944687585955731],
                                [0.10971502294470281, 0.8256739138417495, 0.06461106321354775],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.06943184420297377, 0.6045109287816773, 0.3260572270153489],
                                [0.06943184420297377, 0.6447941075234065, 0.2857740482736198],
                                [0.10971502294470281, 0.0646110632135477, 0.8256739138417495],
                                [0.9448538700827405, 0.05032534892783341, 0.004820780989426019],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9305681557970262, 0.033823866659720106, 0.03560797754325361],
                                [0.9305681557970263, 0.048109580945434396, 0.02132226325753932],
                                [0.9448538700827405, 0.004820780989426017, 0.05032534892783341],
                                [0.737890505890058, 0.23919632743352925, 0.022913166676412796],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.6699905217924281, 0.1607648005820743, 0.16924467762549758],
                                [0.6699905217924281, 0.2286647846797041, 0.10134469352786776],
                                [0.737890505890058, 0.0229131666764128, 0.23919632743352925],
                                [0.4678611121132334, 0.4856202103602057, 0.04651867752656097],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.3300094782075718, 0.3263872698834753, 0.34360325190895286],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329136],
                                [0.46786111211323334, 0.046518677526561025, 0.48562021036020564],
                                [0.26089774792055076, 0.6744911888659015, 0.06461106321354775],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.06943184420297377, 0.4533282038058294, 0.47723995199119684],
                                [0.06943184420297377, 0.6447941075234065, 0.2857740482736198],
                                [0.26089774792055076, 0.06461106321354781, 0.6744911888659014],
                                [0.9595712414673203, 0.03560797754325361, 0.004820780989426019],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9305681557970262, 0.0191064952751403, 0.05032534892783341],
                                [0.9305681557970263, 0.048109580945434396, 0.02132226325753932],
                                [0.9595712414673203, 0.004820780989426017, 0.03560797754325361],
                                [0.8078421556980897, 0.16924467762549758, 0.022913166676412796],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.6699905217924281, 0.09081315077404262, 0.23919632743352925],
                                [0.6699905217924281, 0.2286647846797041, 0.10134469352786776],
                                [0.8078421556980897, 0.0229131666764128, 0.16924467762549758],
                                [0.6098780705644862, 0.34360325190895286, 0.04651867752656097],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.33000947820757187, 0.1843703114322225, 0.48562021036020564],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329136],
                                [0.6098780705644862, 0.04651867752656097, 0.34360325190895286],
                                [0.4581489847952555, 0.4772399519911968, 0.06461106321354775],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.06943184420297377, 0.2560769669311248, 0.6744911888659014],
                                [0.06943184420297377, 0.6447941075234065, 0.2857740482736198],
                                [0.45814898479525545, 0.0646110632135477, 0.47723995199119684],
                                [0.9708513345387554, 0.024327884471818592, 0.004820780989426019],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9305681557970262, 0.007826402203705292, 0.06160544199926842],
                                [0.9305681557970263, 0.048109580945434396, 0.02132226325753932],
                                [0.9708513345387554, 0.0048207809894260205, 0.024327884471818592],
                                [0.8614564255100052, 0.11563040781358205, 0.022913166676412796],
                                [0.6699905217924281, 0.10134469352786776, 0.2286647846797041],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.6699905217924281, 0.03719888096212709, 0.2928105972454448],
                                [0.6699905217924281, 0.2286647846797041, 0.10134469352786776],
                                [0.8614564255100052, 0.022913166676412786, 0.11563040781358207],
                                [0.7187266187998536, 0.23475470367358547, 0.04651867752656097],
                                [0.3300094782075718, 0.2057516180032914, 0.46423890378913674],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.33000947820757187, 0.07552176319685511, 0.594468758595573],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329136],
                                [0.7187266187998536, 0.04651867752656094, 0.2347547036735855],
                                [0.6093317097711033, 0.32605722701534895, 0.06461106321354775],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.06943184420297377, 0.10489424195527686, 0.8256739138417494],
                                [0.06943184420297377, 0.6447941075234065, 0.2857740482736198],
                                [0.6093317097711033, 0.06461106321354776, 0.32605722701534895],
                                [0.9347427452866113, 0.06043647372396264, 0.004820780989426019],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9305681557970263, 0.060771189438557124, 0.008660654764416588],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9347427452866113, 0.004820780989426017, 0.06043647372396264],
                                [0.6898323409894153, 0.287254492334172, 0.022913166676412796],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.6699905217924281, 0.28884539575304546, 0.04116408245452638],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.6898323409894151, 0.0229131666764128, 0.287254492334172],
                                [0.370292656949301, 0.5831886655241381, 0.04651867752656097],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.33000947820757187, 0.5864185430946907, 0.0835719786977375],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.370292656949301, 0.046518677526560914, 0.5831886655241381],
                                [0.1253822526521049, 0.8100066841343474, 0.06461106321354775],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.06943184420297377, 0.8144927494091789, 0.11607540638784729],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.1253822526521049, 0.0646110632135477, 0.8100066841343474],
                                [0.9504099749940133, 0.04476924401656064, 0.004820780989426019],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9305681557970263, 0.04510395973115513, 0.024327884471818585],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9504099749940133, 0.004820780989426017, 0.04476924401656064],
                                [0.7642986663484709, 0.21278816697511638, 0.022913166676412796],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.6699905217924281, 0.21437907039398985, 0.11563040781358203],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.7642986663484708, 0.0229131666764128, 0.21278816697511638],
                                [0.521475381925149, 0.4320059405482901, 0.04651867752656097],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.33000947820757187, 0.4352358181188427, 0.23475470367358542],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.521475381925149, 0.04651867752656097, 0.4320059405482901],
                                [0.3353640732796065, 0.6000248635068458, 0.06461106321354775],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.06943184420297377, 0.6045109287816774, 0.32605722701534884],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.3353640732796065, 0.0646110632135477, 0.6000248635068458],
                                [0.9708513345387554, 0.024327884471818585, 0.004820780989426019],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9305681557970262, 0.024662600186413072, 0.04476924401656064],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9708513345387554, 0.004820780989426017, 0.024327884471818585],
                                [0.8614564255100052, 0.11563040781358203, 0.022913166676412796],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.6699905217924281, 0.1172213112324555, 0.21278816697511638],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.8614564255100052, 0.0229131666764128, 0.11563040781358203],
                                [0.7187266187998537, 0.23475470367358542, 0.04651867752656097],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.33000947820757187, 0.23798458124413802, 0.4320059405482901],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.7187266187998536, 0.04651867752656097, 0.23475470367358542],
                                [0.6093317097711035, 0.32605722701534884, 0.06461106321354775],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.06943184420297377, 0.3305432922901804, 0.6000248635068458],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.6093317097711035, 0.06461106321354776, 0.32605722701534884],
                                [0.9865185642461574, 0.008660654764416588, 0.004820780989426019],
                                [0.9305681557970262, 0.00448606527483153, 0.06494577892814218],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9305681557970262, 0.008995370479011076, 0.06043647372396264],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9865185642461574, 0.004820780989426019, 0.008660654764416588],
                                [0.9359227508690608, 0.04116408245452638, 0.022913166676412796],
                                [0.669990521792428, 0.02132226325753933, 0.30868721495003254],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.6699905217924281, 0.042754985873399876, 0.287254492334172],
                                [0.6699905217924282, 0.30868721495003254, 0.02132226325753932],
                                [0.9359227508690608, 0.0229131666764128, 0.04116408245452638],
                                [0.8699093437757016, 0.0835719786977375, 0.04651867752656097],
                                [0.33000947820757187, 0.04328879995600843, 0.6267017218364197],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.33000947820757187, 0.08680185626829007, 0.5831886655241381],
                                [0.33000947820757187, 0.6267017218364197, 0.043288799956008386],
                                [0.8699093437757015, 0.04651867752656097, 0.0835719786977375],
                                [0.819313530398605, 0.11607540638784729, 0.06461106321354775],
                                [0.06943184420297377, 0.060124997938716174, 0.8704431578583101],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.06943184420297377, 0.12056147166267883, 0.8100066841343474],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.819313530398605, 0.06461106321354775, 0.11607540638784729],
                            ]
                        ),
                        np.array(
                            [
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                            ]
                        ),
                    )
                case 5:
                    return (
                        np.array(
                            [
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9530947654130792, 0.002195712883275913, 0.04470952170364481],
                                [0.9530899229693319, 0.044807907479798424, 0.0021021695508695918],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9530947654130792, 0.044709521703644804, 0.002195712883275917],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.7692584765486152, 0.010801398611706148, 0.21994012483967856],
                                [0.7692346550528416, 0.22042411525302066, 0.010341229694137775],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7692584765486153, 0.21994012483967854, 0.010801398611706165],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.5000516141099505, 0.023403424405383566, 0.47654496148466596],
                                [0.49999999999999994, 0.47759362503822717, 0.02240637496177286],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5000516141099505, 0.47654496148466596, 0.023403424405383556],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.2308447516712857, 0.036005450199060984, 0.7331497981296533],
                                [0.2307653449471585, 0.7347631348234336, 0.03447152022940794],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.2308447516712857, 0.7331497981296533, 0.03600545019906094],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.047008462806821694, 0.04461113592749122, 0.9083804012656871],
                                [0.046910077030668074, 0.9103793425966558, 0.042710580372676124],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.047008462806821694, 0.9083804012656871, 0.04461113592749119],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9531137444651057, 0.002176733831249493, 0.04470952170364481],
                                [0.9530899229693319, 0.044788928427772004, 0.002121148602896015],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9531137444651057, 0.04470952170364481, 0.002176733831249494],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.7693518404432169, 0.010708034717104492, 0.21994012483967856],
                                [0.7692346550528415, 0.220330751358419, 0.010434593588739449],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7693518404432169, 0.21994012483967856, 0.010708034717104494],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.5002539059545579, 0.023201132560776105, 0.47654496148466596],
                                [0.5, 0.4773913331936197, 0.022608666806380313],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.500253905954558, 0.47654496148466596, 0.023201132560776102],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.23115597146589895, 0.035694230404447747, 0.7331497981296533],
                                [0.2307653449471585, 0.7344519150288203, 0.03478274002402117],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.23115597146589895, 0.7331497981296533, 0.035694230404447705],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.0473940674440102, 0.04422553129030271, 0.9083804012656871],
                                [0.046910077030668074, 0.9099937379594674, 0.043096185009864604],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.0473940674440102, 0.9083804012656871, 0.04422553129030271],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9531415370792824, 0.002148941217072757, 0.04470952170364481],
                                [0.9530899229693319, 0.04476113581359526, 0.0021489412170727544],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9531415370792824, 0.04470952170364481, 0.0021489412170727544],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.7694885610073994, 0.010571314152921979, 0.21994012483967856],
                                [0.7692346550528415, 0.22019403079423647, 0.01057131415292197],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7694885610073994, 0.21994012483967856, 0.01057131415292197],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.5005501388317558, 0.022904899683578228, 0.47654496148466596],
                                [0.5, 0.47709510031642177, 0.022904899683578207],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5005501388317558, 0.47654496148466596, 0.022904899683578207],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.23161171665611224, 0.03523848521423445, 0.7331497981296533],
                                [0.2307653449471585, 0.733996169838607, 0.03523848521423444],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.23161171665611224, 0.7331497981296533, 0.03523848521423444],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.04795874058422922, 0.04366085815008369, 0.9083804012656871],
                                [0.046910077030668074, 0.9094290648192482, 0.04366085815008366],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.04795874058422922, 0.9083804012656871, 0.04366085815008366],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9531693296934591, 0.002121148602896014, 0.04470952170364481],
                                [0.9530899229693319, 0.044733343199418525, 0.002176733831249494],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9531693296934591, 0.04470952170364481, 0.002121148602896015],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.7696252815715819, 0.010434593588739466, 0.21994012483967856],
                                [0.7692346550528416, 0.22005731023005395, 0.010708034717104494],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7696252815715819, 0.2199401248396786, 0.010434593588739449],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.5008463717089537, 0.02260866680638035, 0.47654496148466596],
                                [0.5, 0.4767988674392239, 0.023201132560776102],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5008463717089537, 0.476544961484666, 0.022608666806380313],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.23206746184632543, 0.034782740024021264, 0.7331497981296533],
                                [0.2307653449471585, 0.7335404246483938, 0.035694230404447705],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.23206746184632543, 0.7331497981296534, 0.03478274002402117],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.04852341372444824, 0.043096185009864674, 0.9083804012656871],
                                [0.046910077030668074, 0.9088643916790292, 0.04422553129030271],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.04852341372444824, 0.9083804012656872, 0.043096185009864604],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9531883087454855, 0.002102169550869594, 0.04470952170364481],
                                [0.953089922969332, 0.0447143641473921, 0.002195712883275917],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9531883087454855, 0.04470952170364481, 0.0021021695508695918],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.7697186454661836, 0.010341229694137782, 0.21994012483967856],
                                [0.7692346550528416, 0.21996394633545227, 0.010801398611706165],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7697186454661837, 0.21994012483967856, 0.010341229694137775],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.5010486635535611, 0.02240637496177289, 0.47654496148466596],
                                [0.5, 0.47659657559461643, 0.023403424405383556],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5010486635535611, 0.476544961484666, 0.02240637496177286],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.23237868164093867, 0.034471520229408026, 0.7331497981296533],
                                [0.2307653449471585, 0.7332292048537805, 0.03600545019906094],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.23237868164093867, 0.7331497981296534, 0.03447152022940794],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.04890901836163675, 0.042710580372676166, 0.9083804012656871],
                                [0.046910077030668074, 0.9084787870418407, 0.04461113592749119],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.04890901836163675, 0.9083804012656871, 0.042710580372676124],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9531137444651057, 0.002176733831249493, 0.04470952170364481],
                                [0.9530899229693319, 0.04519351211698692, 0.001716564913681103],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.9531137444651057, 0.04470952170364481, 0.002176733831249494],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.7693518404432169, 0.010708034717104492, 0.21994012483967856],
                                [0.7692346550528415, 0.2223210251015347, 0.008444319845623754],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7693518404432169, 0.21994012483967856, 0.010708034717104494],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.5002539059545579, 0.023201132560776105, 0.47654496148466596],
                                [0.5, 0.48170366558384803, 0.018296334416151975],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.500253905954558, 0.47654496148466596, 0.023201132560776102],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.23115597146589895, 0.035694230404447747, 0.7331497981296533],
                                [0.2307653449471585, 0.7410863060661613, 0.028148348986680193],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.23115597146589895, 0.7331497981296533, 0.035694230404447705],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.0473940674440102, 0.04422553129030271, 0.9083804012656871],
                                [0.046910077030668074, 0.9182138190507091, 0.03487610391862284],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.0473940674440102, 0.9083804012656871, 0.04422553129030271],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9532071083597073, 0.0020833699366478164, 0.04470952170364481],
                                [0.9530899229693319, 0.04510014822238524, 0.0018099288082827761],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.9532071083597073, 0.044709521703644804, 0.0020833699366478203],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.7698111266500862, 0.010248748510235134, 0.21994012483967856],
                                [0.7692346550528416, 0.22186173889466532, 0.00890360605249312],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7698111266500862, 0.21994012483967856, 0.010248748510235129],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.5012490428261158, 0.022205995689218272, 0.47654496148466596],
                                [0.5, 0.4807085287122902, 0.019291471287709822],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5012490428261158, 0.47654496148466596, 0.022205995689218255],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.2326869590021453, 0.03416324286820138, 0.7331497981296533],
                                [0.2307653449471585, 0.739555318529915, 0.029679336522926522],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.2326869590021453, 0.7331497981296533, 0.034163242868201375],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.049290977292524185, 0.04232862144178873, 0.9083804012656871],
                                [0.046910077030668074, 0.9163169092021951, 0.03677301376713687],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.049290977292524185, 0.9083804012656871, 0.042328621441788686],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9533438289238899, 0.0019466493724652964, 0.04470952170364481],
                                [0.953089922969332, 0.04496342765820272, 0.0019466493724652984],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.9533438289238899, 0.04470952170364481, 0.0019466493724652984],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.7704836978789573, 0.009576177281364118, 0.21994012483967856],
                                [0.7692346550528415, 0.22118916766579433, 0.009576177281364125],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7704836978789573, 0.21994012483967856, 0.009576177281364125],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.50270630502687, 0.020748733488464066, 0.47654496148466596],
                                [0.5, 0.47925126651153593, 0.02074873348846404],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.50270630502687, 0.47654496148466596, 0.02074873348846404],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.23492891217478273, 0.03192128969556396, 0.7331497981296533],
                                [0.2307653449471585, 0.7373133653572775, 0.03192128969556395],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.23492891217478273, 0.7331497981296533, 0.03192128969556395],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.05206878112985014, 0.039550817604462774, 0.9083804012656871],
                                [0.046910077030668074, 0.9135391053648692, 0.039550817604462774],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.05206878112985014, 0.9083804012656871, 0.039550817604462774],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9534805494880724, 0.0018099288082827764, 0.04470952170364481],
                                [0.953089922969332, 0.044826707094020195, 0.0020833699366478203],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.9534805494880724, 0.04470952170364481, 0.0018099288082827766],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.7711562691078282, 0.00890360605249313, 0.21994012483967856],
                                [0.7692346550528415, 0.2205165964369233, 0.010248748510235127],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7711562691078284, 0.21994012483967856, 0.008903606052493122],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.5041635672276241, 0.01929147128770986, 0.47654496148466596],
                                [0.5, 0.47779400431078173, 0.02220599568921825],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5041635672276241, 0.476544961484666, 0.019291471287709826],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.23717086534742005, 0.029679336522926647, 0.7331497981296533],
                                [0.2307653449471585, 0.7350714121846401, 0.034163242868201375],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.23717086534742005, 0.7331497981296534, 0.02967933652292653],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.05484658496717598, 0.03677301376713693, 0.9083804012656871],
                                [0.046910077030668074, 0.9107613015275432, 0.04232862144178868],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.05484658496717598, 0.9083804012656871, 0.036773013767136875],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.953573913382674, 0.0017165649136811068, 0.04470952170364481],
                                [0.9530899229693319, 0.044733343199418525, 0.0021767338312494934],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.953573913382674, 0.04470952170364481, 0.0017165649136811033],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.7716155553146976, 0.008444319845623771, 0.21994012483967856],
                                [0.7692346550528416, 0.22005731023005395, 0.010708034717104492],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7716155553146976, 0.2199401248396786, 0.008444319845623756],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.5051587040991821, 0.018296334416152027, 0.47654496148466596],
                                [0.5, 0.4767988674392239, 0.0232011325607761],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5051587040991821, 0.476544961484666, 0.01829633441615198],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.2387018528836664, 0.028148348986680283, 0.7331497981296533],
                                [0.2307653449471585, 0.7335404246483938, 0.035694230404447705],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.2387018528836664, 0.7331497981296534, 0.0281483489866802],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.056743494815689965, 0.03487610391862295, 0.9083804012656871],
                                [0.046910077030668074, 0.9088643916790292, 0.044225531290302704],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.056743494815689965, 0.9083804012656872, 0.03487610391862285],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9531415370792824, 0.002148941217072757, 0.04470952170364481],
                                [0.9530899229693319, 0.045758185257205965, 0.0011518917734620563],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9531415370792824, 0.04470952170364481, 0.0021489412170727544],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7694885610073994, 0.010571314152921979, 0.21994012483967856],
                                [0.7692346550528416, 0.2250988289388606, 0.005666516008297848],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7694885610073994, 0.21994012483967856, 0.01057131415292197],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.5005501388317558, 0.022904899683578228, 0.47654496148466596],
                                [0.5, 0.4877223419105772, 0.012277658089422806],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.5005501388317558, 0.47654496148466596, 0.022904899683578207],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.23161171665611224, 0.03523848521423445, 0.7331497981296533],
                                [0.2307653449471585, 0.7503458548822938, 0.018888800170547764],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.23161171665611224, 0.7331497981296533, 0.03523848521423444],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.04795874058422922, 0.04366085815008369, 0.9083804012656871],
                                [0.046910077030668074, 0.9296864985639484, 0.023403424405383556],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.04795874058422922, 0.9083804012656871, 0.04366085815008366],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9533438289238899, 0.0019466493724652964, 0.04470952170364481],
                                [0.953089922969332, 0.045555893412598504, 0.0013541836180695124],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9533438289238899, 0.04470952170364481, 0.0019466493724652984],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7704836978789573, 0.009576177281364118, 0.21994012483967856],
                                [0.7692346550528416, 0.22410369206730274, 0.006661652879855695],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7704836978789573, 0.21994012483967856, 0.009576177281364125],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.50270630502687, 0.020748733488464066, 0.47654496148466596],
                                [0.5, 0.485566175715463, 0.014433824284536975],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.50270630502687, 0.47654496148466596, 0.02074873348846404],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.23492891217478273, 0.03192128969556396, 0.7331497981296533],
                                [0.2307653449471585, 0.7470286593636233, 0.022205995689218255],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.23492891217478273, 0.7331497981296533, 0.03192128969556395],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.05206878112985014, 0.039550817604462774, 0.9083804012656871],
                                [0.046910077030668074, 0.9255764580183274, 0.027513464951004436],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.05206878112985014, 0.9083804012656871, 0.039550817604462774],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9536400618010877, 0.0016504164952674052, 0.04470952170364481],
                                [0.9530899229693319, 0.04525966053540061, 0.0016504164952674055],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9536400618010877, 0.04470952170364481, 0.0016504164952674055],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7719409600797115, 0.008118915080609912, 0.21994012483967856],
                                [0.7692346550528415, 0.22264642986654853, 0.00811891508060991],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7719409600797116, 0.21994012483967856, 0.00811891508060991],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.5058637596288336, 0.017591278886500528, 0.47654496148466596],
                                [0.5, 0.4824087211134995, 0.017591278886500507],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.5058637596288336, 0.47654496148466596, 0.017591278886500507],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.23978655917795555, 0.027063642692391143, 0.7331497981296533],
                                [0.2307653449471585, 0.7421710123604504, 0.0270636426923911],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.23978655917795555, 0.7331497981296533, 0.0270636426923911],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.05808745745657928, 0.03353214127773363, 0.9083804012656871],
                                [0.046910077030668074, 0.9195577816915983, 0.03353214127773361],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.05808745745657928, 0.9083804012656871, 0.03353214127773361],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9539362946782857, 0.001354183618069514, 0.04470952170364481],
                                [0.953089922969332, 0.04496342765820272, 0.0019466493724652984],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9539362946782857, 0.04470952170364481, 0.0013541836180695124],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7733982222804657, 0.0066616528798556784, 0.21994012483967856],
                                [0.7692346550528415, 0.22118916766579433, 0.009576177281364125],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7733982222804658, 0.21994012483967854, 0.006661652879855695],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.509021214230797, 0.014433824284536989, 0.47654496148466596],
                                [0.5, 0.47925126651153593, 0.02074873348846404],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.509021214230797, 0.47654496148466596, 0.014433824284536975],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.24464420618112837, 0.022205995689218327, 0.7331497981296533],
                                [0.2307653449471585, 0.7373133653572775, 0.03192128969556395],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.24464420618112837, 0.7331497981296534, 0.022205995689218255],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.06410613378330843, 0.027513464951004485, 0.9083804012656871],
                                [0.046910077030668074, 0.9135391053648692, 0.039550817604462774],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.06410613378330843, 0.9083804012656871, 0.027513464951004436],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9541385865228931, 0.0011518917734620535, 0.04470952170364481],
                                [0.9530899229693319, 0.04476113581359526, 0.0021489412170727544],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9541385865228931, 0.04470952170364481, 0.0011518917734620563],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7743933591520236, 0.005666516008297845, 0.21994012483967856],
                                [0.7692346550528415, 0.22019403079423647, 0.01057131415292197],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7743933591520236, 0.21994012483967856, 0.005666516008297848],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.5111773804259112, 0.012277658089422827, 0.47654496148466596],
                                [0.5, 0.47709510031642177, 0.022904899683578207],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.5111773804259112, 0.47654496148466596, 0.012277658089422806],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.24796140169979886, 0.018888800170547837, 0.7331497981296533],
                                [0.2307653449471585, 0.733996169838607, 0.03523848521423444],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.24796140169979886, 0.7331497981296534, 0.018888800170547764],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.06821617432892935, 0.023403424405383566, 0.9083804012656871],
                                [0.046910077030668074, 0.9094290648192482, 0.04366085815008366],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.06821617432892935, 0.9083804012656871, 0.023403424405383556],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9531693296934591, 0.002121148602896014, 0.04470952170364481],
                                [0.953089922969332, 0.04632285839742501, 0.0005872186332430095],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.9531693296934591, 0.04470952170364481, 0.002121148602896015],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.7696252815715819, 0.010434593588739466, 0.21994012483967856],
                                [0.7692346550528415, 0.2278766327761865, 0.0028887121709719413],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7696252815715819, 0.2199401248396786, 0.010434593588739449],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5008463717089537, 0.02260866680638035, 0.47654496148466596],
                                [0.49999999999999994, 0.4937410182373064, 0.006258981762693636],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.5008463717089537, 0.476544961484666, 0.022608666806380313],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.23206746184632543, 0.034782740024021264, 0.7331497981296533],
                                [0.2307653449471585, 0.7596054036984262, 0.00962925135441533],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.23206746184632543, 0.7331497981296534, 0.03478274002402117],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.04852341372444824, 0.043096185009864674, 0.9083804012656871],
                                [0.046910077030668074, 0.9411591780771876, 0.011930744892144261],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.04852341372444824, 0.9083804012656872, 0.043096185009864604],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9534805494880724, 0.0018099288082827764, 0.04470952170364481],
                                [0.953089922969332, 0.04601163860281177, 0.0008984384278562483],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.9534805494880724, 0.04470952170364481, 0.0018099288082827766],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.7711562691078282, 0.00890360605249313, 0.21994012483967856],
                                [0.7692346550528416, 0.2263456452399402, 0.004419699707218268],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7711562691078284, 0.21994012483967856, 0.008903606052493122],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5041635672276241, 0.01929147128770986, 0.47654496148466596],
                                [0.49999999999999994, 0.4904238227186359, 0.009576177281364125],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.5041635672276241, 0.476544961484666, 0.019291471287709826],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.23717086534742005, 0.029679336522926647, 0.7331497981296533],
                                [0.2307653449471585, 0.7545020001973315, 0.01473265485550998],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.23717086534742005, 0.7331497981296534, 0.02967933652292653],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.05484658496717598, 0.03677301376713693, 0.9083804012656871],
                                [0.046910077030668074, 0.9348360068344599, 0.018253916134872],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.05484658496717598, 0.9083804012656871, 0.036773013767136875],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9539362946782857, 0.001354183618069514, 0.04470952170364481],
                                [0.953089922969332, 0.045555893412598504, 0.0013541836180695124],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.9539362946782857, 0.04470952170364481, 0.0013541836180695124],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.7733982222804657, 0.0066616528798556784, 0.21994012483967856],
                                [0.7692346550528416, 0.22410369206730274, 0.006661652879855695],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7733982222804658, 0.21994012483967854, 0.006661652879855695],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.509021214230797, 0.014433824284536989, 0.47654496148466596],
                                [0.5, 0.485566175715463, 0.014433824284536975],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.509021214230797, 0.47654496148466596, 0.014433824284536975],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.24464420618112837, 0.022205995689218327, 0.7331497981296533],
                                [0.2307653449471585, 0.7470286593636233, 0.022205995689218255],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.24464420618112837, 0.7331497981296534, 0.022205995689218255],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.06410613378330843, 0.027513464951004485, 0.9083804012656871],
                                [0.046910077030668074, 0.9255764580183274, 0.027513464951004436],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.06410613378330843, 0.9083804012656871, 0.027513464951004436],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9543920398684989, 0.0008984384278562518, 0.04470952170364481],
                                [0.9530899229693319, 0.04510014822238524, 0.0018099288082827766],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.954392039868499, 0.04470952170364481, 0.0008984384278562485],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.775640175453103, 0.004419699707218283, 0.21994012483967856],
                                [0.7692346550528416, 0.22186173889466532, 0.008903606052493122],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7756401754531033, 0.21994012483967856, 0.004419699707218269],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5138788612339699, 0.009576177281364173, 0.47654496148466596],
                                [0.5, 0.4807085287122902, 0.019291471287709826],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.5138788612339698, 0.476544961484666, 0.009576177281364126],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.2521175470148366, 0.014732654855510119, 0.7331497981296533],
                                [0.2307653449471585, 0.739555318529915, 0.02967933652292653],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.2521175470148366, 0.7331497981296534, 0.014732654855509982],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.07336568259944087, 0.01825391613487204, 0.9083804012656871],
                                [0.046910077030668074, 0.916316909202195, 0.036773013767136875],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.07336568259944087, 0.9083804012656871, 0.018253916134872004],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9547032596631122, 0.000587218633243014, 0.04470952170364481],
                                [0.9530899229693319, 0.044788928427772004, 0.002121148602896015],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.9547032596631122, 0.04470952170364482, 0.0005872186332430097],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.7771711629893494, 0.0028887121709719465, 0.21994012483967856],
                                [0.7692346550528415, 0.220330751358419, 0.010434593588739449],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7771711629893494, 0.21994012483967856, 0.002888712170971942],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5171960567526404, 0.006258981762693683, 0.47654496148466596],
                                [0.5, 0.4773913331936197, 0.022608666806380313],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.5171960567526404, 0.476544961484666, 0.006258981762693638],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.2572209505159313, 0.009629251354415391, 0.7331497981296533],
                                [0.2307653449471585, 0.7344519150288203, 0.03478274002402117],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.2572209505159313, 0.7331497981296534, 0.009629251354415332],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.07968885384216862, 0.011930744892144296, 0.9083804012656871],
                                [0.046910077030668074, 0.9099937379594674, 0.043096185009864604],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.07968885384216862, 0.9083804012656871, 0.011930744892144265],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.9530899229693319, 0.00010322821990090686, 0.04680684881076711],
                                [0.9531883087454855, 0.002102169550869594, 0.04470952170364481],
                                [0.9530899229693319, 0.0467084630346135, 0.00020161399605452077],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9531883087454855, 0.04470952170364481, 0.0021021695508695918],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.7692346550528415, 0.0005078119091158351, 0.2302575330380426],
                                [0.7697186454661836, 0.010341229694137782, 0.21994012483967856],
                                [0.7692346550528416, 0.2297735426247005, 0.0009918023224579214],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7697186454661837, 0.21994012483967856, 0.010341229694137775],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158174],
                                [0.5, 0.0011002776635116174, 0.4988997223364884],
                                [0.5010486635535611, 0.02240637496177289, 0.47654496148466596],
                                [0.5, 0.49785105878292724, 0.0021489412170727544],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5010486635535611, 0.476544961484666, 0.02240637496177286],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.2307653449471585, 0.001692743417907372, 0.7675419116349341],
                                [0.23237868164093867, 0.034471520229408026, 0.7331497981296533],
                                [0.2307653449471585, 0.765928574941154, 0.0033060801116875874],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.23237868164093867, 0.7331497981296534, 0.03447152022940794],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.046910077030668074, 0.002097327107122293, 0.9509925958622096],
                                [0.04890901836163675, 0.042710580372676166, 0.9083804012656871],
                                [0.046910077030668074, 0.948993654531241, 0.004096268438090988],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.04890901836163675, 0.9083804012656871, 0.042710580372676124],
                                [0.046910077030668074, 0.9509925958622096, 0.0020973271071223014],
                                [0.9530899229693319, 0.00010322821990090686, 0.04680684881076711],
                                [0.953573913382674, 0.0017165649136811068, 0.04470952170364481],
                                [0.953089922969332, 0.04632285839742501, 0.0005872186332430094],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.953573913382674, 0.04470952170364481, 0.0017165649136811033],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.7692346550528415, 0.0005078119091158351, 0.2302575330380426],
                                [0.7716155553146976, 0.008444319845623771, 0.21994012483967856],
                                [0.7692346550528415, 0.2278766327761865, 0.0028887121709719405],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7716155553146976, 0.2199401248396786, 0.008444319845623756],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158174],
                                [0.5, 0.0011002776635116174, 0.4988997223364884],
                                [0.5051587040991821, 0.018296334416152027, 0.47654496148466596],
                                [0.49999999999999994, 0.4937410182373064, 0.006258981762693634],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5051587040991821, 0.476544961484666, 0.01829633441615198],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.2307653449471585, 0.001692743417907372, 0.7675419116349341],
                                [0.2387018528836664, 0.028148348986680283, 0.7331497981296533],
                                [0.2307653449471585, 0.7596054036984262, 0.009629251354415327],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.2387018528836664, 0.7331497981296534, 0.0281483489866802],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.046910077030668074, 0.002097327107122293, 0.9509925958622096],
                                [0.056743494815689965, 0.03487610391862295, 0.9083804012656871],
                                [0.046910077030668074, 0.9411591780771876, 0.011930744892144258],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.056743494815689965, 0.9083804012656872, 0.03487610391862285],
                                [0.046910077030668074, 0.9509925958622096, 0.0020973271071223014],
                                [0.9530899229693319, 0.00010322821990090686, 0.04680684881076711],
                                [0.9541385865228931, 0.0011518917734620535, 0.04470952170364481],
                                [0.9530899229693319, 0.045758185257205965, 0.0011518917734620563],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9541385865228931, 0.04470952170364481, 0.0011518917734620563],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.7692346550528415, 0.0005078119091158351, 0.2302575330380426],
                                [0.7743933591520236, 0.005666516008297845, 0.21994012483967856],
                                [0.7692346550528416, 0.2250988289388606, 0.005666516008297848],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7743933591520236, 0.21994012483967856, 0.005666516008297848],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158174],
                                [0.5, 0.0011002776635116174, 0.4988997223364884],
                                [0.5111773804259112, 0.012277658089422827, 0.47654496148466596],
                                [0.5, 0.4877223419105772, 0.012277658089422806],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5111773804259112, 0.47654496148466596, 0.012277658089422806],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.2307653449471585, 0.001692743417907372, 0.7675419116349341],
                                [0.24796140169979886, 0.018888800170547837, 0.7331497981296533],
                                [0.2307653449471585, 0.7503458548822938, 0.018888800170547764],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.24796140169979886, 0.7331497981296534, 0.018888800170547764],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.046910077030668074, 0.002097327107122293, 0.9509925958622096],
                                [0.06821617432892935, 0.023403424405383566, 0.9083804012656871],
                                [0.046910077030668074, 0.9296864985639484, 0.023403424405383556],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.06821617432892935, 0.9083804012656871, 0.023403424405383556],
                                [0.046910077030668074, 0.9509925958622096, 0.0020973271071223014],
                                [0.9530899229693319, 0.00010322821990090686, 0.04680684881076711],
                                [0.9547032596631122, 0.000587218633243014, 0.04470952170364481],
                                [0.9530899229693319, 0.04519351211698691, 0.0017165649136811033],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9547032596631122, 0.04470952170364482, 0.0005872186332430094],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.7692346550528415, 0.0005078119091158351, 0.2302575330380426],
                                [0.7771711629893494, 0.0028887121709719465, 0.21994012483967856],
                                [0.7692346550528415, 0.2223210251015347, 0.008444319845623756],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7771711629893494, 0.21994012483967856, 0.0028887121709719405],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158174],
                                [0.5, 0.0011002776635116174, 0.4988997223364884],
                                [0.5171960567526404, 0.006258981762693683, 0.47654496148466596],
                                [0.5, 0.48170366558384803, 0.01829633441615198],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5171960567526404, 0.476544961484666, 0.006258981762693634],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.2307653449471585, 0.001692743417907372, 0.7675419116349341],
                                [0.2572209505159313, 0.009629251354415391, 0.7331497981296533],
                                [0.2307653449471585, 0.7410863060661613, 0.0281483489866802],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.2572209505159313, 0.7331497981296534, 0.009629251354415327],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.046910077030668074, 0.002097327107122293, 0.9509925958622096],
                                [0.07968885384216862, 0.011930744892144296, 0.9083804012656871],
                                [0.046910077030668074, 0.9182138190507091, 0.03487610391862285],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.07968885384216862, 0.9083804012656871, 0.011930744892144258],
                                [0.046910077030668074, 0.9509925958622096, 0.0020973271071223014],
                                [0.9530899229693319, 0.00010322821990090686, 0.04680684881076711],
                                [0.9550888643003006, 0.0002016139960545199, 0.04470952170364481],
                                [0.9530899229693319, 0.044807907479798424, 0.0021021695508695918],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9550888643003006, 0.04470952170364481, 0.00020161399605452102],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.7692346550528415, 0.0005078119091158351, 0.2302575330380426],
                                [0.7790680728378635, 0.0009918023224579076, 0.21994012483967856],
                                [0.7692346550528416, 0.22042411525302066, 0.010341229694137774],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7790680728378636, 0.21994012483967854, 0.0009918023224579225],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158174],
                                [0.5, 0.0011002776635116174, 0.4988997223364884],
                                [0.5213060972982613, 0.002148941217072764, 0.47654496148466596],
                                [0.49999999999999994, 0.47759362503822717, 0.022406374961772856],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5213060972982613, 0.47654496148466596, 0.002148941217072757],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.2307653449471585, 0.001692743417907372, 0.7675419116349341],
                                [0.26354412175865904, 0.003306080111687648, 0.7331497981296533],
                                [0.2307653449471585, 0.7347631348234336, 0.034471520229407936],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.26354412175865904, 0.7331497981296534, 0.0033060801116875913],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.046910077030668074, 0.002097327107122293, 0.9509925958622096],
                                [0.08752333029622195, 0.004096268438090966, 0.9083804012656871],
                                [0.046910077030668074, 0.9103793425966558, 0.04271058037267612],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.08752333029622195, 0.9083804012656871, 0.004096268438090992],
                                [0.046910077030668074, 0.9509925958622096, 0.0020973271071223014],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9531137444651057, 0.010801398611706169, 0.036084856923188136],
                                [0.953089922969332, 0.03656884733653024, 0.010341229694137775],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.9531137444651057, 0.036084856923188136, 0.010801398611706167],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.7693518404432169, 0.05313545903820566, 0.1775127005185774],
                                [0.7692346550528415, 0.17989360078043354, 0.0508717441667249],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7693518404432169, 0.17751270051857743, 0.05313545903820564],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.5002539059545579, 0.11512876651902132, 0.38461732752642075],
                                [0.5, 0.3897760316256028, 0.11022396837439719],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.500253905954558, 0.38461732752642075, 0.11512876651902132],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.23115597146589895, 0.17712207399983704, 0.591721954534264],
                                [0.2307653449471585, 0.599658462470772, 0.16957619258206946],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.23115597146589906, 0.591721954534264, 0.17712207399983698],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.0473940674440102, 0.2194561344263365, 0.7331497981296533],
                                [0.046910077030668074, 0.7429832159146753, 0.2101067070546566],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.0473940674440102, 0.7331497981296533, 0.21945613442633646],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9532071083597073, 0.010708034717104492, 0.036084856923188136],
                                [0.953089922969332, 0.036475483441928566, 0.010434593588739449],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.9532071083597073, 0.036084856923188136, 0.010708034717104494],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.7698111266500863, 0.0526761728313363, 0.1775127005185774],
                                [0.7692346550528415, 0.17943431457356418, 0.051331030373594266],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7698111266500862, 0.17751270051857743, 0.05267617283133628],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.5012490428261158, 0.11413362964746349, 0.38461732752642075],
                                [0.5, 0.388780894754045, 0.11121910524595503],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5012490428261158, 0.38461732752642075, 0.11413362964746347],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.2326869590021453, 0.17559108646359067, 0.591721954534264],
                                [0.2307653449471585, 0.5981274749345257, 0.1711071801183158],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.2326869590021453, 0.591721954534264, 0.17559108646359065],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.049290977292524185, 0.2175592245778225, 0.7331497981296533],
                                [0.046910077030668074, 0.7410863060661613, 0.2120036169031706],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.049290977292524296, 0.7331497981296533, 0.21755922457782245],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9533438289238898, 0.010571314152921972, 0.036084856923188136],
                                [0.9530899229693319, 0.036338762877746046, 0.01057131415292197],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.9533438289238898, 0.036084856923188136, 0.01057131415292197],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.7704836978789573, 0.05200360160246528, 0.1775127005185774],
                                [0.7692346550528415, 0.1787617433446932, 0.05200360160246527],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7704836978789573, 0.17751270051857743, 0.05200360160246527],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.50270630502687, 0.11267636744670928, 0.38461732752642075],
                                [0.5, 0.3873236325532907, 0.11267636744670925],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.50270630502687, 0.38461732752642075, 0.11267636744670925],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.23492891217478273, 0.17334913329095325, 0.591721954534264],
                                [0.2307653449471585, 0.5958855217618882, 0.17334913329095322],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.23492891217478273, 0.591721954534264, 0.17334913329095322],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.05206878112985014, 0.21478142074049655, 0.7331497981296533],
                                [0.046910077030668074, 0.7383085022288354, 0.21478142074049653],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.05206878112985014, 0.7331497981296533, 0.21478142074049653],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9534805494880724, 0.010434593588739452, 0.036084856923188136],
                                [0.953089922969332, 0.036202042313563526, 0.010708034717104494],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.9534805494880725, 0.036084856923188136, 0.010434593588739449],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.7711562691078283, 0.051331030373594294, 0.1775127005185774],
                                [0.7692346550528415, 0.17808917211582218, 0.05267617283133628],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7711562691078282, 0.17751270051857743, 0.051331030373594266],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.5041635672276241, 0.11121910524595507, 0.38461732752642075],
                                [0.5, 0.3858663703525365, 0.11413362964746347],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5041635672276241, 0.3846173275264208, 0.11121910524595503],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.23717086534742005, 0.17110718011831594, 0.591721954534264],
                                [0.2307653449471585, 0.5936435685892508, 0.17559108646359065],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.23717086534742005, 0.5917219545342641, 0.1711071801183158],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.05484658496717598, 0.2120036169031707, 0.7331497981296533],
                                [0.046910077030668074, 0.7355306983915095, 0.21755922457782245],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.05484658496717598, 0.7331497981296534, 0.2120036169031706],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.953573913382674, 0.010341229694137782, 0.036084856923188136],
                                [0.953089922969332, 0.03610867841896185, 0.010801398611706167],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.953573913382674, 0.03608485692318814, 0.010341229694137775],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.7716155553146977, 0.050871744166724936, 0.1775127005185774],
                                [0.7692346550528416, 0.1776298859089528, 0.05313545903820564],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7716155553146977, 0.17751270051857743, 0.0508717441667249],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.5051587040991821, 0.11022396837439724, 0.38461732752642075],
                                [0.5, 0.3848712334809787, 0.11512876651902132],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5051587040991821, 0.3846173275264208, 0.11022396837439719],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.2387018528836664, 0.16957619258206957, 0.591721954534264],
                                [0.2307653449471585, 0.5921125810530046, 0.17712207399983698],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.2387018528836664, 0.5917219545342641, 0.16957619258206946],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.056743494815689965, 0.21010670705465673, 0.7331497981296533],
                                [0.046910077030668074, 0.7336337885429954, 0.21945613442633646],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.056743494815689965, 0.7331497981296534, 0.2101067070546566],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9532071083597073, 0.010708034717104492, 0.036084856923188136],
                                [0.9530899229693319, 0.03846575718504426, 0.008444319845623756],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9532071083597073, 0.036084856923188136, 0.010708034717104494],
                                [0.953089922969332, 0.03858294257541965, 0.00832713445524837],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.7698111266500863, 0.0526761728313363, 0.1775127005185774],
                                [0.7692346550528415, 0.18922509378224256, 0.0415402511649159],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7698111266500862, 0.17751270051857743, 0.05267617283133628],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.5012490428261158, 0.11413362964746349, 0.38461732752642075],
                                [0.5, 0.40999460691459555, 0.09000539308540446],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5012490428261158, 0.38461732752642075, 0.11413362964746347],
                                [0.5, 0.41124364974071126, 0.08875635025928871],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.2326869590021453, 0.17559108646359067, 0.591721954534264],
                                [0.2307653449471585, 0.6307641200469485, 0.13847053500589301],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.2326869590021453, 0.591721954534264, 0.17559108646359065],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090626],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.049290977292524185, 0.2175592245778225, 0.7331497981296533],
                                [0.046910077030668074, 0.7815234566441468, 0.17156646632518516],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.049290977292524296, 0.7331497981296533, 0.21755922457782245],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9536663945665766, 0.010248748510235134, 0.036084856923188136],
                                [0.953089922969332, 0.038006470978174896, 0.008903606052493122],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9536663945665766, 0.03608485692318814, 0.010248748510235127],
                                [0.953089922969332, 0.03858294257541965, 0.00832713445524837],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.7720704991914784, 0.050416800289944164, 0.1775127005185774],
                                [0.7692346550528415, 0.18696572124085042, 0.043799623706308036],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7720704991914784, 0.17751270051857743, 0.05041680028994414],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.5061444324304549, 0.10923824004312432, 0.38461732752642075],
                                [0.5, 0.40509921731025633, 0.09490078268974365],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5061444324304549, 0.3846173275264208, 0.10923824004312428],
                                [0.5, 0.41124364974071126, 0.08875635025928871],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.24021836566943144, 0.16805967979630454, 0.591721954534264],
                                [0.2307653449471585, 0.6232327133796622, 0.14600194167317926],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.24021836566943144, 0.5917219545342641, 0.1680596797963044],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090626],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.05862247029433321, 0.2082277315760135, 0.7331497981296533],
                                [0.046910077030668074, 0.7721919636423378, 0.18089795932699418],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.05862247029433321, 0.7331497981296533, 0.20822773157601343],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9543389657954476, 0.009576177281364125, 0.036084856923188136],
                                [0.9530899229693319, 0.037333899749303893, 0.009576177281364125],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9543389657954477, 0.036084856923188136, 0.009576177281364125],
                                [0.953089922969332, 0.03858294257541965, 0.00832713445524837],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.7753790874832965, 0.04710821199812612, 0.1775127005185774],
                                [0.7692346550528415, 0.18365713294903235, 0.047108211998126086],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7753790874832964, 0.17751270051857743, 0.047108211998126086],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.5133131611071453, 0.102069511366434, 0.38461732752642075],
                                [0.5, 0.39793048863356606, 0.10206951136643397],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5133131611071453, 0.38461732752642075, 0.10206951136643397],
                                [0.5, 0.41124364974071126, 0.08875635025928871],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.2512472347309941, 0.1570308107347419, 0.591721954534264],
                                [0.2307653449471585, 0.6122038443180997, 0.15703081073474184],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.2512472347309942, 0.591721954534264, 0.15703081073474184],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090626],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.07228735641884287, 0.19456284545150382, 0.7331497981296533],
                                [0.046910077030668074, 0.7585270775178281, 0.1945628454515038],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.07228735641884287, 0.7331497981296533, 0.1945628454515038],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9550115370243187, 0.008903606052493122, 0.036084856923188136],
                                [0.9530899229693319, 0.03666132852043289, 0.010248748510235127],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9550115370243188, 0.036084856923188136, 0.008903606052493122],
                                [0.953089922969332, 0.03858294257541965, 0.00832713445524837],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.7786876757751146, 0.04379962370630805, 0.1775127005185774],
                                [0.7692346550528416, 0.1803485446572143, 0.05041680028994414],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7786876757751144, 0.17751270051857743, 0.043799623706308036],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.5204818897838356, 0.09490078268974367, 0.38461732752642075],
                                [0.49999999999999994, 0.39076175995687573, 0.10923824004312428],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5204818897838356, 0.38461732752642075, 0.09490078268974365],
                                [0.5, 0.41124364974071126, 0.08875635025928871],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.2622761037925566, 0.14600194167317937, 0.591721954534264],
                                [0.2307653449471585, 0.6011749752565371, 0.1680596797963044],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.2622761037925566, 0.5917219545342641, 0.14600194167317926],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090626],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.08595224254335243, 0.18089795932699426, 0.7331497981296533],
                                [0.046910077030668074, 0.7448621913933184, 0.20822773157601343],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.08595224254335243, 0.7331497981296534, 0.18089795932699418],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.955470823231188, 0.008444319845623757, 0.036084856923188136],
                                [0.953089922969332, 0.036202042313563526, 0.010708034717104494],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9554708232311881, 0.036084856923188136, 0.008444319845623756],
                                [0.953089922969332, 0.03858294257541965, 0.00832713445524837],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.7809470483165066, 0.04154025116491594, 0.1775127005185774],
                                [0.7692346550528415, 0.17808917211582218, 0.05267617283133628],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7809470483165066, 0.17751270051857743, 0.0415402511649159],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.5253772793881748, 0.0900053930854045, 0.38461732752642075],
                                [0.5, 0.3858663703525365, 0.11413362964746347],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5253772793881748, 0.3846173275264208, 0.09000539308540446],
                                [0.5, 0.41124364974071126, 0.08875635025928871],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.26980751045984286, 0.13847053500589313, 0.591721954534264],
                                [0.2307653449471585, 0.5936435685892508, 0.17559108646359065],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.26980751045984286, 0.5917219545342641, 0.13847053500589301],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090626],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.09528373554516145, 0.17156646632518524, 0.7331497981296533],
                                [0.046910077030668074, 0.7355306983915095, 0.21755922457782245],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.09528373554516145, 0.7331497981296534, 0.17156646632518516],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9533438289238898, 0.010571314152921972, 0.036084856923188136],
                                [0.953089922969332, 0.04124356102237017, 0.005666516008297848],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.9533438289238898, 0.036084856923188136, 0.01057131415292197],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7704836978789573, 0.05200360160246528, 0.1775127005185774],
                                [0.7692346550528416, 0.20288997990675217, 0.027875365040406268],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7704836978789573, 0.17751270051857743, 0.05200360160246527],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.50270630502687, 0.11267636744670928, 0.38461732752642075],
                                [0.5, 0.4396023587363404, 0.06039764126365958],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.50270630502687, 0.38461732752642075, 0.11267636744670925],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.23492891217478273, 0.17334913329095325, 0.591721954534264],
                                [0.2307653449471585, 0.6763147375659286, 0.09291991748691289],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.23492891217478273, 0.591721954534264, 0.17334913329095322],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.05206878112985014, 0.21478142074049655, 0.7331497981296533],
                                [0.046910077030668074, 0.8379611564503107, 0.1151287665190213],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.05206878112985014, 0.7331497981296533, 0.21478142074049653],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9543389657954476, 0.009576177281364125, 0.036084856923188136],
                                [0.953089922969332, 0.040248424150812326, 0.006661652879855695],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.9543389657954477, 0.036084856923188136, 0.009576177281364125],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7753790874832965, 0.04710821199812612, 0.1775127005185774],
                                [0.7692346550528415, 0.197994590302413, 0.03277075464474545],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7753790874832964, 0.17751270051857743, 0.047108211998126086],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.5133131611071453, 0.102069511366434, 0.38461732752642075],
                                [0.5, 0.4289955026560651, 0.07100449734393487],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5133131611071453, 0.38461732752642075, 0.10206951136643397],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.2512472347309941, 0.1570308107347419, 0.591721954534264],
                                [0.2307653449471585, 0.6599964150097173, 0.10923824004312427],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.2512472347309942, 0.591721954534264, 0.15703081073474184],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.07228735641884287, 0.19456284545150382, 0.7331497981296533],
                                [0.046910077030668074, 0.8177425811613179, 0.13534734180801403],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.07228735641884287, 0.7331497981296533, 0.1945628454515038],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9557962279962019, 0.008118915080609912, 0.036084856923188136],
                                [0.9530899229693319, 0.038791161950058106, 0.008118915080609908],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.955796227996202, 0.036084856923188136, 0.008118915080609908],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7825478161599868, 0.03993948332143579, 0.1775127005185774],
                                [0.7692346550528416, 0.19082586162572268, 0.039939483321435765],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7825478161599868, 0.17751270051857743, 0.039939483321435765],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.5288456681183948, 0.08653700435518447, 0.38461732752642075],
                                [0.5, 0.4134629956448156, 0.08653700435518441],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5288456681183948, 0.3846173275264208, 0.08653700435518441],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.27514352007680287, 0.1331345253889331, 0.591721954534264],
                                [0.2307653449471585, 0.6361001296639084, 0.13313452538893306],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.27514352007680287, 0.591721954534264, 0.13313452538893306],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.10189510824058767, 0.16495509362975902, 0.7331497981296533],
                                [0.046910077030668074, 0.788134829339573, 0.1649550936297589],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.10189510824058767, 0.7331497981296534, 0.1649550936297589],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9572534901969562, 0.006661652879855699, 0.036084856923188136],
                                [0.9530899229693319, 0.037333899749303893, 0.009576177281364125],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.9572534901969563, 0.036084856923188136, 0.006661652879855696],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7897165448366772, 0.032770754644745465, 0.1775127005185774],
                                [0.7692346550528415, 0.18365713294903235, 0.047108211998126086],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7897165448366772, 0.1775127005185774, 0.03277075464474546],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.5443781751296444, 0.07100449734393488, 0.38461732752642075],
                                [0.5, 0.39793048863356606, 0.10206951136643397],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5443781751296444, 0.38461732752642075, 0.07100449734393488],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.29903980542261166, 0.10923824004312432, 0.591721954534264],
                                [0.2307653449471585, 0.6122038443180997, 0.15703081073474184],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.29903980542261166, 0.591721954534264, 0.1092382400431243],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.13150286006233258, 0.1353473418080141, 0.7331497981296533],
                                [0.046910077030668074, 0.7585270775178281, 0.1945628454515038],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.1315028600623327, 0.7331497981296533, 0.13534734180801405],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.958248627068514, 0.005666516008297852, 0.036084856923188136],
                                [0.9530899229693319, 0.036338762877746046, 0.01057131415292197],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.958248627068514, 0.036084856923188136, 0.005666516008297848],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7946119344410163, 0.027875365040406275, 0.1775127005185774],
                                [0.7692346550528415, 0.1787617433446932, 0.05200360160246527],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7946119344410164, 0.1775127005185774, 0.027875365040406268],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.5549850312099196, 0.060397641263659596, 0.38461732752642075],
                                [0.5, 0.3873236325532907, 0.11267636744670925],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5549850312099197, 0.38461732752642075, 0.06039764126365958],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.315358127978823, 0.09291991748691297, 0.591721954534264],
                                [0.2307653449471585, 0.5958855217618882, 0.17334913329095322],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.315358127978823, 0.5917219545342641, 0.09291991748691289],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.15172143535132532, 0.11512876651902137, 0.7331497981296533],
                                [0.046910077030668074, 0.7383085022288354, 0.21478142074049653],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.15172143535132532, 0.7331497981296534, 0.1151287665190213],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.9530899229693319, 0.002498085652231516, 0.0444119913784365],
                                [0.9534805494880724, 0.010434593588739452, 0.036084856923188136],
                                [0.9530899229693319, 0.04402136485969608, 0.0028887121709719418],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.9534805494880725, 0.036084856923188136, 0.010434593588739449],
                                [0.9530899229693319, 0.04441199137843651, 0.002498085652231511],
                                [0.7692346550528415, 0.01228886486090991, 0.21847648008624854],
                                [0.7711562691078283, 0.051331030373594294, 0.1775127005185774],
                                [0.7692346550528415, 0.2165548660312618, 0.014210478915896638],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.7711562691078282, 0.17751270051857743, 0.051331030373594266],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909882],
                                [0.5, 0.026626322214290565, 0.47337367778570943],
                                [0.5041635672276241, 0.11121910524595507, 0.38461732752642075],
                                [0.49999999999999994, 0.4692101105580853, 0.030789889441914707],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5041635672276241, 0.3846173275264208, 0.11121910524595503],
                                [0.5, 0.4733736777857095, 0.026626322214290524],
                                [0.2307653449471585, 0.04096377956767128, 0.7282708754851702],
                                [0.23717086534742005, 0.17110718011831594, 0.591721954534264],
                                [0.2307653449471585, 0.7218653550849087, 0.04736929996793277],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.23717086534742005, 0.5917219545342641, 0.1711071801183158],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671166],
                                [0.046910077030668074, 0.0507545587763496, 0.9023353641929823],
                                [0.05484658496717598, 0.2120036169031707, 0.7331497981296533],
                                [0.046910077030668074, 0.8943988562564744, 0.05869106671285747],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.05484658496717598, 0.7331497981296534, 0.2120036169031706],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634953],
                                [0.9530899229693319, 0.002498085652231516, 0.0444119913784365],
                                [0.9550115370243187, 0.008903606052493122, 0.036084856923188136],
                                [0.953089922969332, 0.04249037732344975, 0.004419699707218268],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.9550115370243188, 0.036084856923188136, 0.008903606052493122],
                                [0.9530899229693319, 0.04441199137843651, 0.002498085652231511],
                                [0.7692346550528415, 0.01228886486090991, 0.21847648008624854],
                                [0.7786876757751146, 0.04379962370630805, 0.1775127005185774],
                                [0.7692346550528415, 0.20902345936397557, 0.021741885583182873],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.7786876757751144, 0.17751270051857743, 0.043799623706308036],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909882],
                                [0.5, 0.026626322214290565, 0.47337367778570943],
                                [0.5204818897838356, 0.09490078268974367, 0.38461732752642075],
                                [0.5, 0.4528917880018739, 0.04710821199812609],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5204818897838356, 0.38461732752642075, 0.09490078268974365],
                                [0.5, 0.4733736777857095, 0.026626322214290524],
                                [0.2307653449471585, 0.04096377956767128, 0.7282708754851702],
                                [0.2622761037925566, 0.14600194167317937, 0.591721954534264],
                                [0.2307653449471585, 0.6967601166397722, 0.0724745384130693],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.2622761037925566, 0.5917219545342641, 0.14600194167317926],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671166],
                                [0.046910077030668074, 0.0507545587763496, 0.9023353641929823],
                                [0.08595224254335243, 0.18089795932699426, 0.7331497981296533],
                                [0.046910077030668074, 0.863293198680298, 0.08979672428903392],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.08595224254335243, 0.7331497981296534, 0.18089795932699418],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634953],
                                [0.9530899229693319, 0.002498085652231516, 0.0444119913784365],
                                [0.9572534901969562, 0.006661652879855699, 0.036084856923188136],
                                [0.953089922969332, 0.040248424150812326, 0.006661652879855696],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.9572534901969563, 0.036084856923188136, 0.006661652879855696],
                                [0.9530899229693319, 0.04441199137843651, 0.002498085652231511],
                                [0.7692346550528415, 0.01228886486090991, 0.21847648008624854],
                                [0.7897165448366772, 0.032770754644745465, 0.1775127005185774],
                                [0.7692346550528416, 0.19799459030241298, 0.03277075464474546],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.7897165448366772, 0.1775127005185774, 0.03277075464474546],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909882],
                                [0.5, 0.026626322214290565, 0.47337367778570943],
                                [0.5443781751296444, 0.07100449734393488, 0.38461732752642075],
                                [0.5, 0.4289955026560651, 0.07100449734393488],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5443781751296444, 0.38461732752642075, 0.07100449734393488],
                                [0.5, 0.4733736777857095, 0.026626322214290524],
                                [0.2307653449471585, 0.04096377956767128, 0.7282708754851702],
                                [0.29903980542261166, 0.10923824004312432, 0.591721954534264],
                                [0.2307653449471585, 0.6599964150097172, 0.1092382400431243],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.29903980542261166, 0.591721954534264, 0.1092382400431243],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671166],
                                [0.046910077030668074, 0.0507545587763496, 0.9023353641929823],
                                [0.13150286006233258, 0.1353473418080141, 0.7331497981296533],
                                [0.046910077030668074, 0.8177425811613179, 0.13534734180801405],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.1315028600623327, 0.7331497981296533, 0.13534734180801405],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634953],
                                [0.9530899229693319, 0.002498085652231516, 0.0444119913784365],
                                [0.9594954433695936, 0.004419699707218276, 0.036084856923188136],
                                [0.953089922969332, 0.038006470978174896, 0.00890360605249312],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.9594954433695936, 0.03608485692318814, 0.00441969970721827],
                                [0.9530899229693319, 0.04441199137843651, 0.002498085652231511],
                                [0.7692346550528415, 0.01228886486090991, 0.21847648008624854],
                                [0.8007454138982397, 0.021741885583182907, 0.1775127005185774],
                                [0.7692346550528415, 0.18696572124085042, 0.04379962370630803],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.8007454138982397, 0.17751270051857743, 0.02174188558318288],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909882],
                                [0.5, 0.026626322214290565, 0.47337367778570943],
                                [0.568274460475453, 0.04710821199812615, 0.38461732752642075],
                                [0.5, 0.40509921731025633, 0.09490078268974364],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.568274460475453, 0.3846173275264208, 0.04710821199812611],
                                [0.5, 0.4733736777857095, 0.026626322214290524],
                                [0.2307653449471585, 0.04096377956767128, 0.7282708754851702],
                                [0.3358035070526666, 0.07247453841306939, 0.591721954534264],
                                [0.2307653449471585, 0.6232327133796622, 0.14600194167317923],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.3358035070526666, 0.591721954534264, 0.07247453841306933],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671166],
                                [0.046910077030668074, 0.0507545587763496, 0.9023353641929823],
                                [0.17705347758131262, 0.08979672428903407, 0.7331497981296533],
                                [0.046910077030668074, 0.7721919636423378, 0.18089795932699415],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.17705347758131262, 0.7331497981296534, 0.08979672428903394],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634953],
                                [0.9530899229693319, 0.002498085652231516, 0.0444119913784365],
                                [0.9610264309058398, 0.0028887121709719465, 0.036084856923188136],
                                [0.953089922969332, 0.036475483441928566, 0.010434593588739449],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.9610264309058398, 0.03608485692318814, 0.002888712170971942],
                                [0.9530899229693319, 0.04441199137843651, 0.002498085652231511],
                                [0.7692346550528415, 0.01228886486090991, 0.21847648008624854],
                                [0.808276820565526, 0.014210478915896663, 0.1775127005185774],
                                [0.7692346550528415, 0.17943431457356418, 0.051331030373594266],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.808276820565526, 0.17751270051857743, 0.014210478915896642],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909882],
                                [0.5, 0.026626322214290565, 0.47337367778570943],
                                [0.5845927830316645, 0.030789889441914742, 0.38461732752642075],
                                [0.5, 0.388780894754045, 0.11121910524595503],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5845927830316645, 0.38461732752642075, 0.030789889441914714],
                                [0.5, 0.4733736777857095, 0.026626322214290524],
                                [0.2307653449471585, 0.04096377956767128, 0.7282708754851702],
                                [0.36090874549780316, 0.04736929996793282, 0.591721954534264],
                                [0.2307653449471585, 0.5981274749345257, 0.1711071801183158],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.36090874549780316, 0.591721954534264, 0.047369299967932786],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671166],
                                [0.046910077030668074, 0.0507545587763496, 0.9023353641929823],
                                [0.20815913515748918, 0.05869106671285751, 0.7331497981296533],
                                [0.046910077030668074, 0.7410863060661613, 0.2120036169031706],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.20815913515748918, 0.7331497981296533, 0.05869106671285748],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634953],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.953573913382674, 0.010341229694137782, 0.036084856923188136],
                                [0.953089922969332, 0.0459182747082101, 0.0009918023224579214],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.953573913382674, 0.03608485692318814, 0.010341229694137775],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.7716155553146977, 0.050871744166724936, 0.1775127005185774],
                                [0.7692346550528415, 0.2258863590330708, 0.004878985914087634],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.7716155553146977, 0.17751270051857743, 0.0508717441667249],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5051587040991821, 0.11022396837439724, 0.38461732752642075],
                                [0.49999999999999994, 0.48942868584707805, 0.010571314152921972],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.5051587040991821, 0.3846173275264208, 0.11022396837439719],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.2387018528836664, 0.16957619258206957, 0.591721954534264],
                                [0.2307653449471585, 0.7529710126610852, 0.01626364239175631],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.2387018528836664, 0.5917219545342641, 0.16957619258206946],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.056743494815689965, 0.21010670705465673, 0.7331497981296533],
                                [0.046910077030668074, 0.9329390969859459, 0.020150825983386023],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.056743494815689965, 0.7331497981296534, 0.2101067070546566],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.955470823231188, 0.008444319845623757, 0.036084856923188136],
                                [0.9530899229693319, 0.04402136485969608, 0.002888712170971941],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.9554708232311881, 0.036084856923188136, 0.008444319845623756],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.7809470483165066, 0.04154025116491594, 0.1775127005185774],
                                [0.7692346550528415, 0.2165548660312618, 0.014210478915896635],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.7809470483165066, 0.17751270051857743, 0.0415402511649159],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5253772793881748, 0.0900053930854045, 0.38461732752642075],
                                [0.49999999999999994, 0.4692101105580853, 0.0307898894419147],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.5253772793881748, 0.3846173275264208, 0.09000539308540446],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.26980751045984286, 0.13847053500589313, 0.591721954534264],
                                [0.2307653449471585, 0.7218653550849088, 0.04736929996793276],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.26980751045984286, 0.5917219545342641, 0.13847053500589301],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.09528373554516145, 0.17156646632518524, 0.7331497981296533],
                                [0.046910077030668074, 0.8943988562564744, 0.058691066712857454],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.09528373554516145, 0.7331497981296534, 0.17156646632518516],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.958248627068514, 0.005666516008297852, 0.036084856923188136],
                                [0.953089922969332, 0.04124356102237017, 0.005666516008297848],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.958248627068514, 0.036084856923188136, 0.005666516008297848],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.7946119344410163, 0.027875365040406275, 0.1775127005185774],
                                [0.7692346550528416, 0.20288997990675217, 0.027875365040406268],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.7946119344410164, 0.1775127005185774, 0.027875365040406268],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5549850312099196, 0.060397641263659596, 0.38461732752642075],
                                [0.5, 0.4396023587363404, 0.06039764126365958],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.5549850312099197, 0.38461732752642075, 0.06039764126365958],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.315358127978823, 0.09291991748691297, 0.591721954534264],
                                [0.2307653449471585, 0.6763147375659286, 0.09291991748691289],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.315358127978823, 0.5917219545342641, 0.09291991748691289],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.15172143535132532, 0.11512876651902137, 0.7331497981296533],
                                [0.046910077030668074, 0.8379611564503107, 0.1151287665190213],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.15172143535132532, 0.7331497981296534, 0.1151287665190213],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9610264309058398, 0.0028887121709719465, 0.036084856923188136],
                                [0.9530899229693319, 0.03846575718504426, 0.008444319845623756],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.9610264309058398, 0.03608485692318814, 0.002888712170971941],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.808276820565526, 0.014210478915896663, 0.1775127005185774],
                                [0.7692346550528415, 0.18922509378224256, 0.0415402511649159],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.808276820565526, 0.17751270051857743, 0.014210478915896635],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5845927830316645, 0.030789889441914742, 0.38461732752642075],
                                [0.5, 0.40999460691459555, 0.09000539308540446],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.5845927830316644, 0.3846173275264208, 0.0307898894419147],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.36090874549780316, 0.04736929996793282, 0.591721954534264],
                                [0.2307653449471585, 0.6307641200469485, 0.13847053500589301],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.36090874549780316, 0.5917219545342641, 0.04736929996793276],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.20815913515748918, 0.05869106671285751, 0.7331497981296533],
                                [0.046910077030668074, 0.7815234566441468, 0.17156646632518516],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.20815913515748918, 0.7331497981296533, 0.058691066712857454],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9629233407543539, 0.0009918023224579284, 0.036084856923188136],
                                [0.953089922969332, 0.03656884733653024, 0.010341229694137775],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.9629233407543539, 0.03608485692318814, 0.000991802322457922],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.817608313567335, 0.004878985914087669, 0.1775127005185774],
                                [0.7692346550528415, 0.17989360078043354, 0.0508717441667249],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.8176083135673349, 0.17751270051857743, 0.004878985914087637],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.6048113583206572, 0.010571314152922007, 0.38461732752642075],
                                [0.5, 0.3897760316256028, 0.11022396837439719],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.6048113583206572, 0.38461732752642075, 0.010571314152921979],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.3920144030739796, 0.016263642391756372, 0.591721954534264],
                                [0.2307653449471585, 0.599658462470772, 0.16957619258206946],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.3920144030739796, 0.591721954534264, 0.01626364239175632],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.24669937588696056, 0.020150825983386134, 0.7331497981296533],
                                [0.046910077030668074, 0.7429832159146753, 0.2101067070546566],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.24669937588696056, 0.7331497981296534, 0.020150825983386033],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9531415370792824, 0.02340342440538356, 0.02345503851533401],
                                [0.9530899229693319, 0.02450370206889516, 0.02240637496177286],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9531415370792824, 0.023455038515334013, 0.023403424405383556],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7694885610073994, 0.11512876651902132, 0.11538267247357922],
                                [0.7692346550528415, 0.12054137657276126, 0.11022396837439719],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7694885610073995, 0.11538267247357924, 0.1151287665190213],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5005501388317558, 0.2494498611682442, 0.25],
                                [0.5, 0.2611773804259112, 0.2388226195740888],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.5005501388317558, 0.25, 0.2494498611682442],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.23161171665611224, 0.383770955817467, 0.38461732752642075],
                                [0.23076534494715856, 0.40181338427906116, 0.36742127077378034],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.2316117166561122, 0.3846173275264207, 0.38377095581746706],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.04795874058422922, 0.4754962979311048, 0.47654496148466596],
                                [0.046910077030668074, 0.49785105878292724, 0.4552388641864047],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.04795874058422922, 0.47654496148466596, 0.4754962979311048],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9533438289238899, 0.0232011325607761, 0.02345503851533401],
                                [0.953089922969332, 0.024301410224287705, 0.022608666806380313],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9533438289238899, 0.023455038515334006, 0.023201132560776102],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7704836978789573, 0.11413362964746346, 0.11538267247357922],
                                [0.7692346550528416, 0.11954623970120341, 0.11121910524595503],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7704836978789573, 0.11538267247357921, 0.11413362964746347],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.50270630502687, 0.24729369497313003, 0.25],
                                [0.5, 0.25902121423079705, 0.24097878576920295],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.50270630502687, 0.25, 0.24729369497313003],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.23492891217478273, 0.3804537602987965, 0.38461732752642075],
                                [0.23076534494715845, 0.39849618876039067, 0.37073846629245083],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.2349289121747828, 0.3846173275264207, 0.3804537602987966],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.05206878112985014, 0.4713862573854839, 0.47654496148466596],
                                [0.04691007703066802, 0.4937410182373064, 0.45934890473202555],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.052068781129850195, 0.4765449614846659, 0.47138625738548395],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9536400618010877, 0.022904899683578207, 0.02345503851533401],
                                [0.9530899229693319, 0.02400517734708981, 0.022904899683578207],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9536400618010877, 0.02345503851533401, 0.022904899683578207],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7719409600797115, 0.11267636744670925, 0.11538267247357922],
                                [0.7692346550528415, 0.1180889775004492, 0.11267636744670925],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7719409600797115, 0.11538267247357922, 0.11267636744670925],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5058637596288336, 0.2441362403711665, 0.25],
                                [0.5, 0.2558637596288335, 0.2441362403711665],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.5058637596288336, 0.25, 0.2441362403711665],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.23978655917795555, 0.3755961132956237, 0.38461732752642075],
                                [0.2307653449471585, 0.3936385417572178, 0.3755961132956237],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.23978655917795555, 0.38461732752642075, 0.3755961132956237],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.05808745745657928, 0.46536758105875475, 0.47654496148466596],
                                [0.046910077030668074, 0.4877223419105772, 0.46536758105875475],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.05808745745657928, 0.47654496148466596, 0.46536758105875475],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9539362946782857, 0.022608666806380316, 0.02345503851533401],
                                [0.953089922969332, 0.023708944469891916, 0.023201132560776102],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9539362946782857, 0.023455038515334013, 0.022608666806380313],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7733982222804657, 0.11121910524595502, 0.11538267247357922],
                                [0.7692346550528416, 0.11663171529969497, 0.11413362964746347],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7733982222804657, 0.11538267247357921, 0.11121910524595503],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.509021214230797, 0.24097878576920295, 0.25],
                                [0.5, 0.25270630502686997, 0.24729369497313003],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.509021214230797, 0.25, 0.24097878576920295],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.24464420618112837, 0.3707384662924509, 0.38461732752642075],
                                [0.23076534494715856, 0.3887808947540449, 0.3804537602987966],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.2446442061811283, 0.3846173275264208, 0.37073846629245083],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.06410613378330843, 0.4593489047320256, 0.47654496148466596],
                                [0.04691007703066813, 0.481703665583848, 0.47138625738548395],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.06410613378330837, 0.476544961484666, 0.45934890473202555],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9541385865228931, 0.022406374961772856, 0.02345503851533401],
                                [0.9530899229693319, 0.023506652625284463, 0.023403424405383556],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9541385865228931, 0.023455038515334006, 0.02240637496177286],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7743933591520236, 0.11022396837439719, 0.11538267247357922],
                                [0.7692346550528416, 0.11563657842813714, 0.1151287665190213],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7743933591520236, 0.11538267247357922, 0.11022396837439719],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5111773804259112, 0.2388226195740888, 0.25],
                                [0.5, 0.2505501388317558, 0.2494498611682442],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.5111773804259112, 0.25, 0.2388226195740888],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.24796140169979886, 0.3674212707737804, 0.38461732752642075],
                                [0.23076534494715845, 0.38546369923537444, 0.38377095581746706],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.2479614016997989, 0.3846173275264208, 0.36742127077378034],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.06821617432892935, 0.4552388641864047, 0.47654496148466596],
                                [0.046910077030668074, 0.4775936250382271, 0.4754962979311048],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.06821617432892935, 0.47654496148466596, 0.4552388641864047],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9533438289238899, 0.0232011325607761, 0.02345503851533401],
                                [0.953089922969332, 0.02861374261451604, 0.01829633441615198],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.9533438289238899, 0.023455038515334006, 0.023201132560776102],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.7704836978789573, 0.11413362964746346, 0.11538267247357922],
                                [0.7692346550528415, 0.140759951861754, 0.09000539308540446],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7704836978789573, 0.11538267247357921, 0.11413362964746347],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.50270630502687, 0.24729369497313003, 0.25],
                                [0.49999999999999994, 0.30498503120991965, 0.19501496879008035],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.50270630502687, 0.25, 0.24729369497313003],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.23492891217478273, 0.3804537602987965, 0.38461732752642075],
                                [0.23076534494715845, 0.4692101105580853, 0.3000245444947562],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.2349289121747828, 0.3846173275264207, 0.3804537602987966],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.05206878112985014, 0.4713862573854839, 0.47654496148466596],
                                [0.046910077030668074, 0.5813563198053232, 0.3717336031640087],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.052068781129850195, 0.4765449614846659, 0.47138625738548395],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9543389657954477, 0.02220599568921825, 0.02345503851533401],
                                [0.953089922969332, 0.027618605742958196, 0.019291471287709822],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.9543389657954477, 0.023455038515334006, 0.022205995689218255],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.7753790874832964, 0.1092382400431243, 0.11538267247357922],
                                [0.7692346550528415, 0.1358645622574148, 0.09490078268974364],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7753790874832964, 0.11538267247357924, 0.10923824004312428],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5133131611071453, 0.23668683889285475, 0.25],
                                [0.5, 0.29437817512964437, 0.20562182487035563],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5133131611071453, 0.25, 0.23668683889285475],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.2512472347309941, 0.36413543774258517, 0.38461732752642075],
                                [0.2307653449471585, 0.4528917880018739, 0.3163428670509676],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.2512472347309941, 0.38461732752642075, 0.36413543774258517],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.07228735641884287, 0.45116768209649116, 0.47654496148466596],
                                [0.046910077030668074, 0.5611377445163306, 0.3919521784530014],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.07228735641884293, 0.4765449614846659, 0.4511676820964912],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9557962279962019, 0.02074873348846404, 0.02345503851533401],
                                [0.9530899229693319, 0.02616134354220398, 0.02074873348846404],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.9557962279962019, 0.02345503851533401, 0.02074873348846404],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.7825478161599868, 0.10206951136643397, 0.11538267247357922],
                                [0.7692346550528416, 0.12869583358072448, 0.10206951136643397],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7825478161599868, 0.11538267247357922, 0.10206951136643397],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5288456681183948, 0.22115433188160522, 0.25],
                                [0.5, 0.27884566811839484, 0.2211543318816052],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5288456681183948, 0.25, 0.2211543318816052],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.27514352007680287, 0.3402391523967764, 0.38461732752642075],
                                [0.2307653449471585, 0.4289955026560651, 0.3402391523967764],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.27514352007680287, 0.38461732752642075, 0.3402391523967764],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.10189510824058767, 0.42155993027474636, 0.47654496148466596],
                                [0.046910077030668074, 0.5315299926945856, 0.4215599302747463],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.10189510824058762, 0.476544961484666, 0.4215599302747463],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9572534901969562, 0.019291471287709826, 0.02345503851533401],
                                [0.953089922969332, 0.024704081341449767, 0.02220599568921825],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.9572534901969562, 0.02345503851533401, 0.019291471287709826],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.7897165448366771, 0.09490078268974364, 0.11538267247357922],
                                [0.7692346550528416, 0.12152710490403418, 0.10923824004312427],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7897165448366771, 0.11538267247357921, 0.09490078268974365],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5443781751296444, 0.20562182487035563, 0.25],
                                [0.5, 0.2633131611071453, 0.23668683889285472],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5443781751296444, 0.24999999999999997, 0.20562182487035566],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.29903980542261166, 0.3163428670509676, 0.38461732752642075],
                                [0.23076534494715845, 0.4050992173102564, 0.3641354377425851],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.2990398054226117, 0.3846173275264207, 0.31634286705096765],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.13150286006233258, 0.39195217845300145, 0.47654496148466596],
                                [0.046910077030668074, 0.5019222408728408, 0.45116768209649116],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.13150286006233258, 0.47654496148466596, 0.39195217845300145],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.958248627068514, 0.01829633441615198, 0.02345503851533401],
                                [0.953089922969332, 0.023708944469891916, 0.023201132560776102],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.958248627068514, 0.02345503851533401, 0.01829633441615198],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.7946119344410163, 0.09000539308540445, 0.11538267247357922],
                                [0.7692346550528416, 0.11663171529969497, 0.11413362964746347],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7946119344410163, 0.11538267247357921, 0.09000539308540446],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5549850312099196, 0.19501496879008035, 0.25],
                                [0.5, 0.25270630502686997, 0.24729369497313003],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5549850312099196, 0.25, 0.19501496879008035],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.315358127978823, 0.30002454449475624, 0.38461732752642075],
                                [0.23076534494715856, 0.3887808947540449, 0.3804537602987966],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.31535812797882296, 0.3846173275264208, 0.3000245444947562],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.15172143535132532, 0.3717336031640087, 0.47654496148466596],
                                [0.04691007703066813, 0.481703665583848, 0.47138625738548395],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.15172143535132532, 0.47654496148466596, 0.3717336031640087],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.9536400618010877, 0.022904899683578207, 0.02345503851533401],
                                [0.9530899229693319, 0.03463241894124521, 0.012277658089422806],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9536400618010877, 0.02345503851533401, 0.022904899683578207],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.7692346550528415, 0.057691336236789625, 0.17307400871036882],
                                [0.7719409600797115, 0.11267636744670925, 0.11538267247357922],
                                [0.7692346550528416, 0.17036770368349885, 0.06039764126365958],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.7719409600797115, 0.11538267247357922, 0.11267636744670925],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.5, 0.125, 0.375],
                                [0.5058637596288336, 0.2441362403711665, 0.25],
                                [0.49999999999999994, 0.3691362403711665, 0.1308637596288335],
                                [0.625, 0.25, 0.125],
                                [0.5058637596288336, 0.25, 0.2441362403711665],
                                [0.5, 0.375, 0.125],
                                [0.2307653449471585, 0.19230866376321032, 0.5769259912896312],
                                [0.23978655917795555, 0.3755961132956237, 0.38461732752642075],
                                [0.2307653449471585, 0.5679047770588341, 0.20132987799400742],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.23978655917795555, 0.38461732752642075, 0.3755961132956237],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.05808745745657928, 0.46536758105875475, 0.47654496148466596],
                                [0.046910077030668074, 0.7036400618010877, 0.2494498611682442],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.05808745745657928, 0.47654496148466596, 0.46536758105875475],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.9557962279962019, 0.02074873348846404, 0.02345503851533401],
                                [0.9530899229693319, 0.03247625274613104, 0.014433824284536975],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9557962279962019, 0.02345503851533401, 0.02074873348846404],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.7692346550528415, 0.057691336236789625, 0.17307400871036882],
                                [0.7825478161599868, 0.10206951136643397, 0.11538267247357922],
                                [0.7692346550528415, 0.15976084760322357, 0.07100449734393487],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.7825478161599868, 0.11538267247357922, 0.10206951136643397],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.5, 0.125, 0.375],
                                [0.5288456681183948, 0.22115433188160522, 0.25],
                                [0.5, 0.34615433188160516, 0.1538456681183948],
                                [0.625, 0.25, 0.125],
                                [0.5288456681183948, 0.25, 0.2211543318816052],
                                [0.5, 0.375, 0.125],
                                [0.2307653449471585, 0.19230866376321032, 0.5769259912896312],
                                [0.27514352007680287, 0.3402391523967764, 0.38461732752642075],
                                [0.2307653449471585, 0.5325478161599868, 0.23668683889285475],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.27514352007680287, 0.38461732752642075, 0.3402391523967764],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.10189510824058767, 0.42155993027474636, 0.47654496148466596],
                                [0.046910077030668074, 0.6598324110170792, 0.29325751195225264],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.10189510824058762, 0.476544961484666, 0.4215599302747463],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.9589536825981655, 0.017591278886500507, 0.02345503851533401],
                                [0.953089922969332, 0.02931879814416751, 0.017591278886500507],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9589536825981655, 0.02345503851533401, 0.017591278886500507],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.7692346550528415, 0.057691336236789625, 0.17307400871036882],
                                [0.7980803231712363, 0.08653700435518441, 0.11538267247357922],
                                [0.7692346550528415, 0.14422834059197404, 0.08653700435518441],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.7980803231712363, 0.11538267247357922, 0.08653700435518441],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.5, 0.125, 0.375],
                                [0.5625, 0.1875, 0.25],
                                [0.5, 0.3125, 0.1875],
                                [0.625, 0.25, 0.125],
                                [0.5625, 0.25, 0.1875],
                                [0.5, 0.375, 0.125],
                                [0.2307653449471585, 0.19230866376321032, 0.5769259912896312],
                                [0.32691967682876366, 0.2884629956448156, 0.38461732752642075],
                                [0.2307653449471585, 0.4807716594080259, 0.2884629956448156],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.32691967682876366, 0.38461732752642075, 0.2884629956448156],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.1660463174018345, 0.35740872111349953, 0.47654496148466596],
                                [0.046910077030668074, 0.5956812018558324, 0.3574087211134995],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.16604631740183445, 0.476544961484666, 0.3574087211134995],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.962111137200129, 0.014433824284536975, 0.02345503851533401],
                                [0.9530899229693319, 0.02616134354220398, 0.02074873348846404],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.962111137200129, 0.02345503851533401, 0.014433824284536975],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.7692346550528415, 0.057691336236789625, 0.17307400871036882],
                                [0.8136128301824859, 0.07100449734393488, 0.11538267247357922],
                                [0.7692346550528416, 0.12869583358072448, 0.10206951136643397],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.8136128301824859, 0.11538267247357924, 0.07100449734393487],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.5, 0.125, 0.375],
                                [0.5961543318816052, 0.15384566811839484, 0.25],
                                [0.5, 0.27884566811839484, 0.2211543318816052],
                                [0.625, 0.25, 0.125],
                                [0.5961543318816052, 0.25, 0.1538456681183948],
                                [0.5, 0.375, 0.125],
                                [0.2307653449471585, 0.19230866376321032, 0.5769259912896312],
                                [0.37869583358072445, 0.2366868388928548, 0.38461732752642075],
                                [0.2307653449471585, 0.4289955026560651, 0.3402391523967764],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.3786958335807245, 0.3846173275264208, 0.23668683889285475],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.23019752656308134, 0.2932575119522527, 0.47654496148466596],
                                [0.046910077030668074, 0.5315299926945856, 0.4215599302747463],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.2301975265630813, 0.476544961484666, 0.29325751195225264],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.9642673033952431, 0.012277658089422806, 0.02345503851533401],
                                [0.9530899229693319, 0.02400517734708981, 0.022904899683578207],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9642673033952431, 0.02345503851533401, 0.012277658089422806],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.7692346550528415, 0.057691336236789625, 0.17307400871036882],
                                [0.8242196862627611, 0.060397641263659596, 0.11538267247357922],
                                [0.7692346550528415, 0.1180889775004492, 0.11267636744670925],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.8242196862627612, 0.11538267247357924, 0.06039764126365958],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.5, 0.125, 0.375],
                                [0.6191362403711664, 0.1308637596288335, 0.25],
                                [0.5, 0.2558637596288335, 0.2441362403711665],
                                [0.625, 0.25, 0.125],
                                [0.6191362403711664, 0.25, 0.1308637596288335],
                                [0.5, 0.375, 0.125],
                                [0.2307653449471585, 0.19230866376321032, 0.5769259912896312],
                                [0.4140527944795719, 0.20132987799400737, 0.38461732752642075],
                                [0.2307653449471585, 0.3936385417572178, 0.3755961132956237],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.41405279447957194, 0.3846173275264207, 0.20132987799400742],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.27400517734708985, 0.2494498611682442, 0.47654496148466596],
                                [0.046910077030668074, 0.4877223419105772, 0.46536758105875475],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.27400517734708985, 0.47654496148466596, 0.2494498611682442],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9539362946782857, 0.022608666806380316, 0.02345503851533401],
                                [0.9530899229693319, 0.040651095267974384, 0.006258981762693636],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.9539362946782857, 0.023455038515334013, 0.022608666806380313],
                                [0.9530899229693319, 0.04149746697692808, 0.005412610053739941],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7733982222804657, 0.11121910524595502, 0.11538267247357922],
                                [0.7692346550528415, 0.19997545550524373, 0.030789889441914704],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.7733982222804657, 0.11538267247357921, 0.11121910524595503],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.509021214230797, 0.24097878576920295, 0.25],
                                [0.5, 0.4332874495324133, 0.06671255046758666],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.509021214230797, 0.25, 0.24097878576920295],
                                [0.49999999999999994, 0.4423086637632104, 0.057691336236789625],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.24464420618112837, 0.3707384662924509, 0.38461732752642075],
                                [0.2307653449471585, 0.6665994435595829, 0.1026352114932586],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.2446442061811283, 0.3846173275264208, 0.37073846629245083],
                                [0.2307653449471585, 0.6804783047935528, 0.08875635025928873],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.06410613378330843, 0.4593489047320256, 0.47654496148466596],
                                [0.046910077030668074, 0.8259238037968523, 0.12716611917247966],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.06410613378330837, 0.476544961484666, 0.45934890473202555],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983931],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9572534901969562, 0.019291471287709826, 0.02345503851533401],
                                [0.9530899229693319, 0.037333899749303893, 0.009576177281364125],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.9572534901969562, 0.02345503851533401, 0.019291471287709826],
                                [0.9530899229693319, 0.04149746697692808, 0.005412610053739941],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7897165448366771, 0.09490078268974364, 0.11538267247357922],
                                [0.7692346550528415, 0.18365713294903235, 0.047108211998126086],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.7897165448366771, 0.11538267247357921, 0.09490078268974365],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.5443781751296444, 0.20562182487035563, 0.25],
                                [0.5, 0.39793048863356606, 0.10206951136643397],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.5443781751296444, 0.24999999999999997, 0.20562182487035566],
                                [0.49999999999999994, 0.4423086637632104, 0.057691336236789625],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.29903980542261166, 0.3163428670509676, 0.38461732752642075],
                                [0.2307653449471585, 0.6122038443180997, 0.15703081073474184],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.2990398054226117, 0.3846173275264207, 0.31634286705096765],
                                [0.2307653449471585, 0.6804783047935528, 0.08875635025928873],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.13150286006233258, 0.39195217845300145, 0.47654496148466596],
                                [0.046910077030668074, 0.7585270775178281, 0.1945628454515038],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.13150286006233258, 0.47654496148466596, 0.39195217845300145],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983931],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.962111137200129, 0.014433824284536975, 0.02345503851533401],
                                [0.9530899229693319, 0.03247625274613104, 0.014433824284536975],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.962111137200129, 0.02345503851533401, 0.014433824284536975],
                                [0.9530899229693319, 0.04149746697692808, 0.005412610053739941],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.8136128301824859, 0.07100449734393488, 0.11538267247357922],
                                [0.7692346550528415, 0.15976084760322357, 0.07100449734393487],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.8136128301824859, 0.11538267247357924, 0.07100449734393487],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.5961543318816052, 0.15384566811839484, 0.25],
                                [0.5, 0.34615433188160516, 0.1538456681183948],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.5961543318816052, 0.25, 0.1538456681183948],
                                [0.49999999999999994, 0.4423086637632104, 0.057691336236789625],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.37869583358072445, 0.2366868388928548, 0.38461732752642075],
                                [0.2307653449471585, 0.5325478161599868, 0.23668683889285475],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.3786958335807245, 0.3846173275264208, 0.23668683889285475],
                                [0.2307653449471585, 0.6804783047935528, 0.08875635025928873],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.23019752656308134, 0.2932575119522527, 0.47654496148466596],
                                [0.046910077030668074, 0.6598324110170792, 0.29325751195225264],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.2301975265630813, 0.476544961484666, 0.29325751195225264],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983931],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9669687842033018, 0.009576177281364125, 0.02345503851533401],
                                [0.953089922969332, 0.027618605742958196, 0.019291471287709822],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.9669687842033018, 0.02345503851533401, 0.009576177281364126],
                                [0.9530899229693319, 0.04149746697692808, 0.005412610053739941],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.8375091155282947, 0.04710821199812609, 0.11538267247357922],
                                [0.7692346550528415, 0.1358645622574148, 0.09490078268974364],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.8375091155282947, 0.11538267247357922, 0.0471082119981261],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.647930488633566, 0.102069511366434, 0.25],
                                [0.5, 0.29437817512964437, 0.20562182487035563],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.647930488633566, 0.25, 0.102069511366434],
                                [0.49999999999999994, 0.4423086637632104, 0.057691336236789625],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.45835186173883735, 0.1570308107347419, 0.38461732752642075],
                                [0.2307653449471585, 0.4528917880018739, 0.3163428670509676],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.45835186173883735, 0.38461732752642075, 0.15703081073474187],
                                [0.2307653449471585, 0.6804783047935528, 0.08875635025928873],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.3288921930638302, 0.19456284545150382, 0.47654496148466596],
                                [0.046910077030668074, 0.5611377445163306, 0.3919521784530014],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.3288921930638302, 0.47654496148466596, 0.19456284545150385],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983931],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9702859797219723, 0.006258981762693638, 0.02345503851533401],
                                [0.953089922969332, 0.024301410224287705, 0.022608666806380313],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.9702859797219723, 0.02345503851533401, 0.006258981762693637],
                                [0.9530899229693319, 0.04149746697692808, 0.005412610053739941],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.853827438084506, 0.030789889441914714, 0.11538267247357922],
                                [0.7692346550528416, 0.11954623970120341, 0.11121910524595503],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.853827438084506, 0.11538267247357922, 0.03078988944191471],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.6832874495324133, 0.06671255046758667, 0.25],
                                [0.5, 0.25902121423079705, 0.24097878576920295],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.6832874495324133, 0.25, 0.06671255046758667],
                                [0.49999999999999994, 0.4423086637632104, 0.057691336236789625],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.5127474609803206, 0.1026352114932586, 0.38461732752642075],
                                [0.23076534494715845, 0.39849618876039067, 0.37073846629245083],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.5127474609803206, 0.38461732752642075, 0.10263521149325863],
                                [0.2307653449471585, 0.6804783047935528, 0.08875635025928873],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.3962889193428544, 0.12716611917247966, 0.47654496148466596],
                                [0.04691007703066802, 0.4937410182373064, 0.45934890473202555],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.3962889193428544, 0.47654496148466596, 0.1271661191724797],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983931],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9541385865228931, 0.022406374961772856, 0.02345503851533401],
                                [0.9530899229693319, 0.04476113581359526, 0.0021489412170727557],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9541385865228931, 0.023455038515334006, 0.02240637496177286],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7743933591520236, 0.11022396837439719, 0.11538267247357922],
                                [0.7692346550528415, 0.22019403079423647, 0.010571314152921977],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.7743933591520236, 0.11538267247357922, 0.11022396837439719],
                                [0.7692346550528415, 0.2253527348934185, 0.0054126100537399465],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.5111773804259112, 0.2388226195740888, 0.25],
                                [0.5, 0.47709510031642177, 0.02290489968357822],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.5111773804259112, 0.25, 0.2388226195740888],
                                [0.5, 0.488272480742333, 0.011727519257667018],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.24796140169979886, 0.3674212707737804, 0.38461732752642075],
                                [0.2307653449471585, 0.733996169838607, 0.03523848521423446],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.2479614016997989, 0.3846173275264208, 0.36742127077378034],
                                [0.2307653449471585, 0.7511922265912474, 0.01804242846159409],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.06821617432892935, 0.4552388641864047, 0.47654496148466596],
                                [0.046910077030668074, 0.9094290648192482, 0.043660858150083685],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.06821617432892935, 0.47654496148466596, 0.4552388641864047],
                                [0.046910077030668074, 0.9307351621175095, 0.02235476085182243],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.958248627068514, 0.01829633441615198, 0.02345503851533401],
                                [0.9530899229693319, 0.040651095267974384, 0.006258981762693636],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.958248627068514, 0.02345503851533401, 0.01829633441615198],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7946119344410163, 0.09000539308540445, 0.11538267247357922],
                                [0.7692346550528415, 0.19997545550524373, 0.030789889441914704],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.7946119344410163, 0.11538267247357921, 0.09000539308540446],
                                [0.7692346550528415, 0.2253527348934185, 0.0054126100537399465],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.5549850312099196, 0.19501496879008035, 0.25],
                                [0.5, 0.4332874495324133, 0.06671255046758666],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.5549850312099196, 0.25, 0.19501496879008035],
                                [0.5, 0.488272480742333, 0.011727519257667018],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.315358127978823, 0.30002454449475624, 0.38461732752642075],
                                [0.2307653449471585, 0.6665994435595829, 0.1026352114932586],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.31535812797882296, 0.3846173275264208, 0.3000245444947562],
                                [0.2307653449471585, 0.7511922265912474, 0.01804242846159409],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.15172143535132532, 0.3717336031640087, 0.47654496148466596],
                                [0.046910077030668074, 0.8259238037968523, 0.12716611917247966],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.15172143535132532, 0.47654496148466596, 0.3717336031640087],
                                [0.046910077030668074, 0.9307351621175095, 0.02235476085182243],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9642673033952431, 0.012277658089422806, 0.02345503851533401],
                                [0.9530899229693319, 0.03463241894124521, 0.012277658089422806],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9642673033952431, 0.02345503851533401, 0.012277658089422806],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.8242196862627611, 0.060397641263659596, 0.11538267247357922],
                                [0.7692346550528416, 0.17036770368349885, 0.06039764126365958],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.8242196862627612, 0.11538267247357924, 0.06039764126365958],
                                [0.7692346550528415, 0.2253527348934185, 0.0054126100537399465],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.6191362403711664, 0.1308637596288335, 0.25],
                                [0.49999999999999994, 0.3691362403711665, 0.1308637596288335],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.6191362403711664, 0.25, 0.1308637596288335],
                                [0.5, 0.488272480742333, 0.011727519257667018],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.4140527944795719, 0.20132987799400737, 0.38461732752642075],
                                [0.2307653449471585, 0.5679047770588341, 0.20132987799400742],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.41405279447957194, 0.3846173275264207, 0.20132987799400742],
                                [0.2307653449471585, 0.7511922265912474, 0.01804242846159409],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.27400517734708985, 0.2494498611682442, 0.47654496148466596],
                                [0.046910077030668074, 0.7036400618010877, 0.2494498611682442],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.27400517734708985, 0.47654496148466596, 0.2494498611682442],
                                [0.046910077030668074, 0.9307351621175095, 0.02235476085182243],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9702859797219723, 0.006258981762693638, 0.02345503851533401],
                                [0.953089922969332, 0.02861374261451604, 0.01829633441615198],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9702859797219723, 0.02345503851533401, 0.006258981762693637],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.853827438084506, 0.030789889441914714, 0.11538267247357922],
                                [0.7692346550528415, 0.140759951861754, 0.09000539308540446],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.853827438084506, 0.11538267247357922, 0.03078988944191471],
                                [0.7692346550528415, 0.2253527348934185, 0.0054126100537399465],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.6832874495324133, 0.06671255046758667, 0.25],
                                [0.49999999999999994, 0.30498503120991965, 0.19501496879008035],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.6832874495324133, 0.25, 0.06671255046758667],
                                [0.5, 0.488272480742333, 0.011727519257667018],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.5127474609803206, 0.1026352114932586, 0.38461732752642075],
                                [0.23076534494715845, 0.4692101105580853, 0.3000245444947562],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.5127474609803206, 0.38461732752642075, 0.10263521149325863],
                                [0.2307653449471585, 0.7511922265912474, 0.01804242846159409],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.3962889193428544, 0.12716611917247966, 0.47654496148466596],
                                [0.046910077030668074, 0.5813563198053232, 0.3717336031640087],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.3962889193428544, 0.47654496148466596, 0.1271661191724797],
                                [0.046910077030668074, 0.9307351621175095, 0.02235476085182243],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9743960202675932, 0.002148941217072757, 0.02345503851533401],
                                [0.9530899229693319, 0.02450370206889516, 0.02240637496177286],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9743960202675932, 0.02345503851533401, 0.0021489412170727566],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.8740460133734987, 0.010571314152921979, 0.11538267247357922],
                                [0.7692346550528415, 0.12054137657276126, 0.11022396837439719],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.8740460133734987, 0.11538267247357922, 0.01057131415292198],
                                [0.7692346550528415, 0.2253527348934185, 0.0054126100537399465],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.7270951003164218, 0.022904899683578228, 0.25],
                                [0.5, 0.2611773804259112, 0.2388226195740888],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.7270951003164218, 0.25, 0.022904899683578228],
                                [0.5, 0.488272480742333, 0.011727519257667018],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.5801441872593448, 0.03523848521423445, 0.38461732752642075],
                                [0.23076534494715856, 0.40181338427906116, 0.36742127077378034],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.5801441872593448, 0.38461732752642075, 0.03523848521423447],
                                [0.2307653449471585, 0.7511922265912474, 0.01804242846159409],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.47979418036525034, 0.04366085815008369, 0.47654496148466596],
                                [0.046910077030668074, 0.49785105878292724, 0.4552388641864047],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.47979418036525034, 0.47654496148466596, 0.0436608581500837],
                                [0.046910077030668074, 0.9307351621175095, 0.02235476085182243],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9531693296934591, 0.03600545019906094, 0.010825220107479883],
                                [0.953089922969332, 0.012438556801260083, 0.034471520229407936],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.9531693296934591, 0.010825220107479883, 0.03600545019906094],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.769625281571582, 0.17712207399983698, 0.05325264442858104],
                                [0.7692346550528415, 0.061189152365088983, 0.16957619258206946],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.769625281571582, 0.05325264442858105, 0.17712207399983698],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5008463717089537, 0.38377095581746706, 0.11538267247357925],
                                [0.5, 0.13257872922621966, 0.36742127077378034],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5008463717089536, 0.11538267247357925, 0.38377095581746706],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.23206746184632543, 0.5904198376350971, 0.17751270051857745],
                                [0.2307653449471585, 0.20396830608735028, 0.5652663489654912],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.23206746184632543, 0.17751270051857748, 0.5904198376350971],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.04852341372444824, 0.7315364614358731, 0.21994012483967862],
                                [0.046910077030668074, 0.2527189016511793, 0.7003710213181527],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.04852341372444824, 0.21994012483967862, 0.7315364614358731],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9534805494880724, 0.035694230404447705, 0.010825220107479883],
                                [0.953089922969332, 0.012127337006646845, 0.03478274002402117],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.9534805494880724, 0.010825220107479883, 0.035694230404447705],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.7711562691078283, 0.17559108646359065, 0.05325264442858104],
                                [0.7692346550528416, 0.059658164828842675, 0.17110718011831577],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7711562691078283, 0.05325264442858105, 0.17559108646359065],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5041635672276241, 0.3804537602987966, 0.11538267247357925],
                                [0.49999999999999994, 0.12926153370754917, 0.37073846629245083],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5041635672276242, 0.11538267247357925, 0.3804537602987966],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.23717086534742005, 0.5853164341340025, 0.17751270051857745],
                                [0.2307653449471585, 0.19886490258625567, 0.5703697524665858],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.23717086534742005, 0.17751270051857748, 0.5853164341340025],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.05484658496717598, 0.7252132901931454, 0.21994012483967862],
                                [0.046910077030668074, 0.24639573040845153, 0.7066941925608804],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.05484658496717598, 0.21994012483967862, 0.7252132901931454],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9539362946782857, 0.03523848521423444, 0.010825220107479883],
                                [0.9530899229693319, 0.011671591816433576, 0.03523848521423444],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.9539362946782857, 0.010825220107479883, 0.03523848521423444],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.7733982222804658, 0.1733491332909532, 0.05325264442858104],
                                [0.7692346550528415, 0.057416211656205224, 0.17334913329095322],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7733982222804657, 0.05325264442858102, 0.17334913329095322],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.509021214230797, 0.3755961132956237, 0.11538267247357925],
                                [0.5, 0.1244038867043763, 0.3755961132956237],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.509021214230797, 0.11538267247357925, 0.3755961132956237],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.24464420618112837, 0.5778430933002942, 0.17751270051857745],
                                [0.2307653449471585, 0.19139156175254735, 0.5778430933002942],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.24464420618112837, 0.17751270051857748, 0.5778430933002942],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.06410613378330843, 0.715953741377013, 0.21994012483967862],
                                [0.046910077030668074, 0.23713618159231897, 0.715953741377013],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.06410613378330843, 0.21994012483967862, 0.715953741377013],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.954392039868499, 0.03478274002402118, 0.010825220107479883],
                                [0.9530899229693319, 0.01121584662622032, 0.0356942304044477],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.954392039868499, 0.010825220107479883, 0.03478274002402118],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.7756401754531032, 0.1711071801183158, 0.05325264442858104],
                                [0.7692346550528416, 0.05517425848356783, 0.17559108646359062],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7756401754531032, 0.05325264442858105, 0.1711071801183158],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5138788612339699, 0.3707384662924509, 0.11538267247357925],
                                [0.5, 0.11954623970120348, 0.3804537602987965],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5138788612339699, 0.11538267247357925, 0.3707384662924509],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.2521175470148366, 0.5703697524665859, 0.17751270051857745],
                                [0.2307653449471585, 0.18391822091883914, 0.5853164341340024],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.2521175470148366, 0.17751270051857748, 0.5703697524665859],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.07336568259944087, 0.7066941925608805, 0.21994012483967862],
                                [0.046910077030668074, 0.22787663277618664, 0.7252132901931453],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.07336568259944087, 0.21994012483967862, 0.7066941925608805],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9547032596631122, 0.03447152022940794, 0.010825220107479883],
                                [0.9530899229693319, 0.010904626831607075, 0.03600545019906094],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.9547032596631122, 0.010825220107479883, 0.03447152022940794],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.7771711629893495, 0.16957619258206946, 0.05325264442858104],
                                [0.7692346550528416, 0.05364327094732149, 0.17712207399983695],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7771711629893495, 0.05325264442858102, 0.1695761925820695],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5171960567526404, 0.3674212707737804, 0.11538267247357925],
                                [0.5, 0.11622904418253299, 0.383770955817467],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5171960567526404, 0.11538267247357925, 0.3674212707737804],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.2572209505159313, 0.5652663489654912, 0.17751270051857745],
                                [0.2307653449471585, 0.17881481741774452, 0.590419837635097],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.2572209505159313, 0.17751270051857748, 0.5652663489654912],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.07968885384216862, 0.7003710213181528, 0.21994012483967862],
                                [0.046910077030668074, 0.2215534615334589, 0.731536461435873],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.07968885384216862, 0.21994012483967862, 0.7003710213181528],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.953089922969332, 0.02775772246793977, 0.01915235456272825],
                                [0.9534805494880724, 0.035694230404447705, 0.010825220107479883],
                                [0.953089922969332, 0.01876172804398782, 0.0281483489866802],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9534805494880724, 0.010825220107479883, 0.035694230404447705],
                                [0.953089922969332, 0.01915235456272825, 0.02775772246793977],
                                [0.7692346550528415, 0.13654892095090626, 0.09421642399625217],
                                [0.7711562691078283, 0.17559108646359065, 0.05325264442858104],
                                [0.7692346550528415, 0.09229480994126543, 0.13847053500589301],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.7711562691078283, 0.05325264442858105, 0.17559108646359065],
                                [0.7692346550528415, 0.09421642399625219, 0.13654892095090626],
                                [0.5, 0.29586097726713206, 0.20413902273286794],
                                [0.5041635672276241, 0.3804537602987966, 0.11538267247357925],
                                [0.5, 0.19997545550524376, 0.30002454449475624],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5041635672276242, 0.11538267247357925, 0.3804537602987966],
                                [0.49999999999999994, 0.20413902273286794, 0.29586097726713206],
                                [0.2307653449471585, 0.4551730335833578, 0.3140616214694837],
                                [0.23717086534742005, 0.5853164341340025, 0.17751270051857745],
                                [0.23076534494715845, 0.3076561010692221, 0.4615785539836194],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.23717086534742005, 0.17751270051857748, 0.5853164341340025],
                                [0.2307653449471585, 0.3140616214694837, 0.4551730335833578],
                                [0.046910077030668074, 0.5639642320663243, 0.3891256909030076],
                                [0.05484658496717598, 0.7252132901931454, 0.21994012483967862],
                                [0.046910077030668074, 0.38118918296649973, 0.5719007400028322],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.05484658496717598, 0.21994012483967862, 0.7252132901931454],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.953089922969332, 0.02775772246793977, 0.01915235456272825],
                                [0.9550115370243187, 0.034163242868201375, 0.010825220107479883],
                                [0.9530899229693319, 0.01723074050774149, 0.02967933652292653],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9550115370243187, 0.010825220107479883, 0.034163242868201375],
                                [0.953089922969332, 0.01915235456272825, 0.02775772246793977],
                                [0.7692346550528415, 0.13654892095090626, 0.09421642399625217],
                                [0.7786876757751146, 0.1680596797963044, 0.05325264442858104],
                                [0.7692346550528415, 0.08476340327397919, 0.14600194167317926],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.7786876757751146, 0.05325264442858105, 0.1680596797963044],
                                [0.7692346550528415, 0.09421642399625219, 0.13654892095090626],
                                [0.5, 0.29586097726713206, 0.20413902273286794],
                                [0.5204818897838356, 0.36413543774258517, 0.11538267247357925],
                                [0.5, 0.18365713294903235, 0.31634286705096765],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5204818897838356, 0.11538267247357925, 0.36413543774258517],
                                [0.49999999999999994, 0.20413902273286794, 0.29586097726713206],
                                [0.2307653449471585, 0.4551730335833578, 0.3140616214694837],
                                [0.2622761037925566, 0.5602111956888659, 0.17751270051857745],
                                [0.23076534494715856, 0.2825508626240855, 0.486683792428756],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.2622761037925566, 0.17751270051857748, 0.5602111956888659],
                                [0.2307653449471585, 0.3140616214694837, 0.4551730335833578],
                                [0.046910077030668074, 0.5639642320663243, 0.3891256909030076],
                                [0.08595224254335243, 0.694107632616969, 0.21994012483967862],
                                [0.046910077030668074, 0.35008352539032317, 0.6030063975790088],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.08595224254335243, 0.21994012483967862, 0.694107632616969],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.953089922969332, 0.02775772246793977, 0.01915235456272825],
                                [0.9572534901969562, 0.03192128969556395, 0.010825220107479883],
                                [0.9530899229693319, 0.014988787335104066, 0.03192128969556395],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9572534901969562, 0.010825220107479883, 0.03192128969556395],
                                [0.953089922969332, 0.01915235456272825, 0.02775772246793977],
                                [0.7692346550528415, 0.13654892095090626, 0.09421642399625217],
                                [0.7897165448366772, 0.15703081073474182, 0.05325264442858104],
                                [0.7692346550528416, 0.0737345342124166, 0.15703081073474184],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.7897165448366772, 0.05325264442858105, 0.15703081073474182],
                                [0.7692346550528415, 0.09421642399625219, 0.13654892095090626],
                                [0.5, 0.29586097726713206, 0.20413902273286794],
                                [0.5443781751296444, 0.3402391523967764, 0.11538267247357925],
                                [0.49999999999999994, 0.15976084760322357, 0.34023915239677643],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5443781751296444, 0.11538267247357925, 0.3402391523967764],
                                [0.49999999999999994, 0.20413902273286794, 0.29586097726713206],
                                [0.2307653449471585, 0.4551730335833578, 0.3140616214694837],
                                [0.29903980542261166, 0.5234474940588109, 0.17751270051857745],
                                [0.2307653449471585, 0.24578716099403053, 0.523447494058811],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.29903980542261166, 0.17751270051857748, 0.5234474940588109],
                                [0.2307653449471585, 0.3140616214694837, 0.4551730335833578],
                                [0.046910077030668074, 0.5639642320663243, 0.3891256909030076],
                                [0.13150286006233258, 0.6485570150979888, 0.21994012483967862],
                                [0.046910077030668074, 0.304532907871343, 0.6485570150979889],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.13150286006233258, 0.21994012483967862, 0.6485570150979888],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.953089922969332, 0.02775772246793977, 0.01915235456272825],
                                [0.9594954433695936, 0.02967933652292653, 0.010825220107479883],
                                [0.9530899229693319, 0.012746834162466643, 0.034163242868201375],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9594954433695936, 0.010825220107479883, 0.02967933652292653],
                                [0.953089922969332, 0.01915235456272825, 0.02775772246793977],
                                [0.7692346550528415, 0.13654892095090626, 0.09421642399625217],
                                [0.8007454138982397, 0.14600194167317926, 0.05325264442858104],
                                [0.7692346550528415, 0.06270566515085405, 0.1680596797963044],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.8007454138982397, 0.05325264442858105, 0.14600194167317926],
                                [0.7692346550528415, 0.09421642399625219, 0.13654892095090626],
                                [0.5, 0.29586097726713206, 0.20413902273286794],
                                [0.568274460475453, 0.31634286705096765, 0.11538267247357925],
                                [0.5, 0.13586456225741483, 0.36413543774258517],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5682744604754532, 0.11538267247357925, 0.31634286705096765],
                                [0.49999999999999994, 0.20413902273286794, 0.29586097726713206],
                                [0.2307653449471585, 0.4551730335833578, 0.3140616214694837],
                                [0.3358035070526666, 0.4866837924287559, 0.17751270051857745],
                                [0.2307653449471585, 0.2090234593639756, 0.5602111956888659],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.33580350705266665, 0.17751270051857743, 0.486683792428756],
                                [0.2307653449471585, 0.3140616214694837, 0.4551730335833578],
                                [0.046910077030668074, 0.5639642320663243, 0.3891256909030076],
                                [0.17705347758131262, 0.6030063975790088, 0.21994012483967862],
                                [0.046910077030668074, 0.258982290352363, 0.694107632616969],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.17705347758131262, 0.21994012483967862, 0.6030063975790088],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.953089922969332, 0.02775772246793977, 0.01915235456272825],
                                [0.96102643090584, 0.0281483489866802, 0.010825220107479883],
                                [0.9530899229693319, 0.011215846626220313, 0.035694230404447705],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.96102643090584, 0.010825220107479883, 0.0281483489866802],
                                [0.953089922969332, 0.01915235456272825, 0.02775772246793977],
                                [0.7692346550528415, 0.13654892095090626, 0.09421642399625217],
                                [0.808276820565526, 0.13847053500589301, 0.05325264442858104],
                                [0.7692346550528415, 0.0551742584835678, 0.17559108646359065],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.808276820565526, 0.05325264442858105, 0.13847053500589301],
                                [0.7692346550528415, 0.09421642399625219, 0.13654892095090626],
                                [0.5, 0.29586097726713206, 0.20413902273286794],
                                [0.5845927830316645, 0.30002454449475624, 0.11538267247357925],
                                [0.5, 0.11954623970120343, 0.3804537602987966],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5845927830316645, 0.11538267247357925, 0.30002454449475624],
                                [0.49999999999999994, 0.20413902273286794, 0.29586097726713206],
                                [0.2307653449471585, 0.4551730335833578, 0.3140616214694837],
                                [0.36090874549780316, 0.46157855398361936, 0.17751270051857745],
                                [0.2307653449471585, 0.18391822091883903, 0.5853164341340025],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.3609087454978031, 0.17751270051857743, 0.4615785539836194],
                                [0.2307653449471585, 0.3140616214694837, 0.4551730335833578],
                                [0.046910077030668074, 0.5639642320663243, 0.3891256909030076],
                                [0.20815913515748918, 0.5719007400028322, 0.21994012483967862],
                                [0.046910077030668074, 0.22787663277618653, 0.7252132901931454],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.20815913515748918, 0.21994012483967862, 0.5719007400028322],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9539362946782857, 0.03523848521423444, 0.010825220107479883],
                                [0.953089922969332, 0.028021276860120254, 0.018888800170547764],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.9539362946782857, 0.010825220107479883, 0.03523848521423444],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.7733982222804658, 0.1733491332909532, 0.05325264442858104],
                                [0.7692346550528416, 0.13784542746024556, 0.09291991748691289],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.7733982222804657, 0.05325264442858102, 0.17334913329095322],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.509021214230797, 0.3755961132956237, 0.11538267247357925],
                                [0.5, 0.2986701220059926, 0.20132987799400742],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.509021214230797, 0.11538267247357925, 0.3755961132956237],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.24464420618112837, 0.5778430933002942, 0.17751270051857745],
                                [0.23076534494715856, 0.45949481655173957, 0.3097398385011019],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.24464420618112837, 0.17751270051857748, 0.5778430933002942],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.06410613378330843, 0.715953741377013, 0.21994012483967862],
                                [0.046910077030668074, 0.5693189671518648, 0.38377095581746706],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.06410613378330843, 0.21994012483967862, 0.715953741377013],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9572534901969562, 0.03192128969556395, 0.010825220107479883],
                                [0.953089922969332, 0.024704081341449767, 0.02220599568921825],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.9572534901969562, 0.010825220107479883, 0.03192128969556395],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.7897165448366772, 0.15703081073474182, 0.05325264442858104],
                                [0.7692346550528416, 0.12152710490403418, 0.10923824004312427],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.7897165448366772, 0.05325264442858105, 0.15703081073474182],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5443781751296444, 0.3402391523967764, 0.11538267247357925],
                                [0.5, 0.2633131611071453, 0.23668683889285472],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.5443781751296444, 0.11538267247357925, 0.3402391523967764],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.29903980542261166, 0.5234474940588109, 0.17751270051857745],
                                [0.23076534494715845, 0.4050992173102564, 0.3641354377425851],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.29903980542261166, 0.17751270051857748, 0.5234474940588109],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.13150286006233258, 0.6485570150979888, 0.21994012483967862],
                                [0.046910077030668074, 0.5019222408728408, 0.45116768209649116],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.13150286006233258, 0.21994012483967862, 0.6485570150979888],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.962111137200129, 0.0270636426923911, 0.010825220107479883],
                                [0.9530899229693319, 0.019846434338276913, 0.027063642692391105],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.962111137200129, 0.01082522010747988, 0.027063642692391105],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.8136128301824859, 0.13313452538893306, 0.05325264442858104],
                                [0.7692346550528415, 0.09763081955822539, 0.13313452538893306],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.8136128301824859, 0.05325264442858105, 0.13313452538893306],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5961543318816052, 0.2884629956448156, 0.11538267247357925],
                                [0.5, 0.2115370043551844, 0.2884629956448156],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.5961543318816052, 0.11538267247357925, 0.2884629956448156],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.37869583358072445, 0.44379146590069807, 0.17751270051857745],
                                [0.2307653449471585, 0.32544318915214343, 0.44379146590069807],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.37869583358072445, 0.17751270051857748, 0.44379146590069807],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.23019752656308134, 0.54986234859724, 0.21994012483967862],
                                [0.046910077030668074, 0.4032275743720919, 0.54986234859724],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.23019752656308134, 0.21994012483967862, 0.54986234859724],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9669687842033019, 0.02220599568921825, 0.010825220107479883],
                                [0.9530899229693319, 0.014988787335104066, 0.03192128969556395],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.9669687842033019, 0.01082522010747988, 0.022205995689218255],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.8375091155282948, 0.10923824004312427, 0.05325264442858104],
                                [0.7692346550528416, 0.07373453421241663, 0.15703081073474182],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.8375091155282947, 0.053252644428581034, 0.10923824004312428],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.647930488633566, 0.23668683889285475, 0.11538267247357925],
                                [0.5, 0.15976084760322362, 0.3402391523967764],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.6479304886335661, 0.11538267247357925, 0.23668683889285475],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.45835186173883735, 0.36413543774258517, 0.17751270051857745],
                                [0.2307653449471585, 0.24578716099403064, 0.5234474940588109],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.45835186173883735, 0.17751270051857748, 0.36413543774258517],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.3288921930638302, 0.45116768209649116, 0.21994012483967862],
                                [0.046910077030668074, 0.30453290787134313, 0.6485570150979888],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.3288921930638303, 0.21994012483967856, 0.4511676820964912],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9702859797219724, 0.018888800170547764, 0.010825220107479883],
                                [0.9530899229693319, 0.011671591816433576, 0.03523848521423444],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.9702859797219724, 0.010825220107479883, 0.018888800170547764],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.8538274380845061, 0.09291991748691289, 0.05325264442858104],
                                [0.7692346550528415, 0.057416211656205224, 0.17334913329095322],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.8538274380845061, 0.05325264442858105, 0.09291991748691289],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.6832874495324133, 0.20132987799400742, 0.11538267247357925],
                                [0.5, 0.1244038867043763, 0.3755961132956237],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.6832874495324134, 0.11538267247357925, 0.20132987799400742],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.5127474609803206, 0.30973983850110187, 0.17751270051857745],
                                [0.2307653449471585, 0.19139156175254735, 0.5778430933002942],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.5127474609803206, 0.17751270051857743, 0.3097398385011019],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.3962889193428544, 0.383770955817467, 0.21994012483967862],
                                [0.046910077030668074, 0.23713618159231897, 0.715953741377013],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.3962889193428543, 0.21994012483967856, 0.38377095581746706],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.954392039868499, 0.03478274002402118, 0.010825220107479883],
                                [0.953089922969332, 0.03728082567625269, 0.00962925135441533],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.954392039868499, 0.010825220107479883, 0.03478274002402118],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248372],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.7756401754531032, 0.1711071801183158, 0.05325264442858104],
                                [0.7692346550528415, 0.18339604497922568, 0.04736929996793277],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.7756401754531032, 0.05325264442858105, 0.1711071801183158],
                                [0.7692346550528415, 0.18980156537948728, 0.040963779567671166],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.5138788612339699, 0.3707384662924509, 0.11538267247357925],
                                [0.5, 0.3973647885067414, 0.10263521149325862],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.5138788612339699, 0.11538267247357925, 0.3707384662924509],
                                [0.5, 0.41124364974071126, 0.08875635025928874],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.2521175470148366, 0.5703697524665859, 0.17751270051857745],
                                [0.2307653449471585, 0.611333532034257, 0.15790112301858444],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.2521175470148366, 0.17751270051857748, 0.5703697524665859],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090632],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.07336568259944087, 0.7066941925608805, 0.21994012483967862],
                                [0.046910077030668074, 0.75744875133723, 0.1956411716321019],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.07336568259944087, 0.21994012483967862, 0.7066941925608805],
                                [0.046910077030668074, 0.7839043569060028, 0.1691855660633291],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9594954433695936, 0.02967933652292653, 0.010825220107479883],
                                [0.9530899229693319, 0.03217742217515804, 0.01473265485550998],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.9594954433695936, 0.010825220107479883, 0.02967933652292653],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248372],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.8007454138982397, 0.14600194167317926, 0.05325264442858104],
                                [0.7692346550528416, 0.15829080653408914, 0.0724745384130693],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.8007454138982397, 0.05325264442858105, 0.14600194167317926],
                                [0.7692346550528415, 0.18980156537948728, 0.040963779567671166],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.568274460475453, 0.31634286705096765, 0.11538267247357925],
                                [0.5, 0.34296918926525816, 0.15703081073474184],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.5682744604754532, 0.11538267247357925, 0.31634286705096765],
                                [0.5, 0.41124364974071126, 0.08875635025928874],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.3358035070526666, 0.4866837924287559, 0.17751270051857745],
                                [0.2307653449471585, 0.5276475719964271, 0.24158708305641435],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.33580350705266665, 0.17751270051857743, 0.486683792428756],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090632],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.17705347758131262, 0.6030063975790088, 0.21994012483967862],
                                [0.046910077030668074, 0.6537609563553582, 0.2993289666139737],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.17705347758131262, 0.21994012483967862, 0.6030063975790088],
                                [0.046910077030668074, 0.7839043569060028, 0.1691855660633291],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9669687842033019, 0.02220599568921825, 0.010825220107479883],
                                [0.953089922969332, 0.024704081341449764, 0.022205995689218255],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.9669687842033019, 0.01082522010747988, 0.022205995689218255],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248372],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.8375091155282948, 0.10923824004312427, 0.05325264442858104],
                                [0.7692346550528415, 0.12152710490403416, 0.10923824004312428],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.8375091155282947, 0.053252644428581034, 0.10923824004312428],
                                [0.7692346550528415, 0.18980156537948728, 0.040963779567671166],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.647930488633566, 0.23668683889285475, 0.11538267247357925],
                                [0.5, 0.26331316110714525, 0.23668683889285475],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.6479304886335661, 0.11538267247357925, 0.23668683889285475],
                                [0.5, 0.41124364974071126, 0.08875635025928874],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.45835186173883735, 0.36413543774258517, 0.17751270051857745],
                                [0.2307653449471585, 0.40509921731025633, 0.36413543774258517],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.45835186173883735, 0.17751270051857748, 0.36413543774258517],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090632],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.3288921930638302, 0.45116768209649116, 0.21994012483967862],
                                [0.046910077030668074, 0.5019222408728408, 0.4511676820964912],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.3288921930638303, 0.21994012483967856, 0.4511676820964912],
                                [0.046910077030668074, 0.7839043569060028, 0.1691855660633291],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9744421250370101, 0.014732654855509984, 0.010825220107479883],
                                [0.9530899229693319, 0.017230740507741496, 0.029679336522926522],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.9744421250370101, 0.010825220107479883, 0.014732654855509984],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248372],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.8742728171583496, 0.07247453841306933, 0.05325264442858104],
                                [0.7692346550528415, 0.08476340327397922, 0.14600194167317923],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.8742728171583497, 0.05325264442858106, 0.07247453841306932],
                                [0.7692346550528415, 0.18980156537948728, 0.040963779567671166],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.7275865167916789, 0.1570308107347419, 0.11538267247357925],
                                [0.5, 0.1836571329490324, 0.3163428670509676],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.7275865167916789, 0.11538267247357928, 0.15703081073474187],
                                [0.5, 0.41124364974071126, 0.08875635025928874],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.5809002164250081, 0.24158708305641444, 0.17751270051857745],
                                [0.2307653449471585, 0.2825508626240856, 0.4866837924287559],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.5809002164250081, 0.17751270051857748, 0.2415870830564144],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090632],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.4807309085463476, 0.2993289666139738, 0.21994012483967862],
                                [0.046910077030668074, 0.3500835253903233, 0.6030063975790086],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.48073090854634754, 0.21994012483967867, 0.29932896661397373],
                                [0.046910077030668074, 0.7839043569060028, 0.1691855660633291],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9795455285381048, 0.009629251354415332, 0.010825220107479883],
                                [0.953089922969332, 0.012127337006646845, 0.03478274002402117],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.9795455285381048, 0.010825220107479881, 0.009629251354415334],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248372],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.8993780556034862, 0.047369299967932786, 0.05325264442858104],
                                [0.7692346550528416, 0.059658164828842675, 0.17110718011831577],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.8993780556034862, 0.053252644428581034, 0.04736929996793279],
                                [0.7692346550528415, 0.18980156537948728, 0.040963779567671166],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.7819821160331621, 0.10263521149325866, 0.11538267247357925],
                                [0.49999999999999994, 0.12926153370754917, 0.37073846629245083],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.781982116033162, 0.11538267247357925, 0.10263521149325866],
                                [0.5, 0.41124364974071126, 0.08875635025928874],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.664586176462838, 0.15790112301858453, 0.17751270051857745],
                                [0.2307653449471585, 0.19886490258625567, 0.5703697524665858],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.664586176462838, 0.17751270051857745, 0.15790112301858453],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090632],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.5844187035282193, 0.19564117163210198, 0.21994012483967862],
                                [0.046910077030668074, 0.24639573040845153, 0.7066941925608804],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.5844187035282193, 0.21994012483967862, 0.19564117163210198],
                                [0.046910077030668074, 0.7839043569060028, 0.1691855660633291],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9547032596631122, 0.03447152022940794, 0.010825220107479883],
                                [0.953089922969332, 0.043603996918980426, 0.003306080111687589],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.9547032596631122, 0.010825220107479883, 0.03447152022940794],
                                [0.953089922969332, 0.045217333612760625, 0.001692743417907392],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.7771711629893495, 0.16957619258206946, 0.05325264442858104],
                                [0.7692346550528415, 0.21450170255540213, 0.016263642391756317],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.7771711629893495, 0.05325264442858102, 0.1695761925820695],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248382],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.5171960567526404, 0.3674212707737804, 0.11538267247357925],
                                [0.5, 0.46476151478576555, 0.03523848521423446],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.5171960567526404, 0.11538267247357925, 0.3674212707737804],
                                [0.5, 0.4819575715384059, 0.018042428461594096],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.2572209505159313, 0.5652663489654912, 0.17751270051857745],
                                [0.2307653449471585, 0.7150213270161289, 0.0542133280367126],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.2572209505159313, 0.17751270051857748, 0.5652663489654912],
                                [0.2307653449471585, 0.7414769325849017, 0.027757722467939807],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.07968885384216862, 0.7003710213181528, 0.21994012483967862],
                                [0.046910077030668074, 0.8859190326525506, 0.06717089031678133],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.07968885384216862, 0.21994012483967862, 0.7003710213181528],
                                [0.046910077030668074, 0.9186978094640511, 0.0343921135052808],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.96102643090584, 0.0281483489866802, 0.010825220107479883],
                                [0.953089922969332, 0.03728082567625269, 0.009629251354415329],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.96102643090584, 0.010825220107479883, 0.0281483489866802],
                                [0.953089922969332, 0.045217333612760625, 0.001692743417907392],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.808276820565526, 0.13847053500589301, 0.05325264442858104],
                                [0.7692346550528416, 0.18339604497922568, 0.047369299967932765],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.808276820565526, 0.05325264442858105, 0.13847053500589301],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248382],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.5845927830316645, 0.30002454449475624, 0.11538267247357925],
                                [0.5, 0.3973647885067414, 0.1026352114932586],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.5845927830316645, 0.11538267247357925, 0.30002454449475624],
                                [0.5, 0.4819575715384059, 0.018042428461594096],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.36090874549780316, 0.46157855398361936, 0.17751270051857745],
                                [0.2307653449471585, 0.611333532034257, 0.15790112301858444],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.3609087454978031, 0.17751270051857743, 0.4615785539836194],
                                [0.2307653449471585, 0.7414769325849017, 0.027757722467939807],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.20815913515748918, 0.5719007400028322, 0.21994012483967862],
                                [0.046910077030668074, 0.7574487513372301, 0.19564117163210187],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.20815913515748918, 0.21994012483967862, 0.5719007400028322],
                                [0.046910077030668074, 0.9186978094640511, 0.0343921135052808],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9702859797219724, 0.018888800170547764, 0.010825220107479883],
                                [0.953089922969332, 0.028021276860120254, 0.018888800170547764],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.9702859797219724, 0.010825220107479883, 0.018888800170547764],
                                [0.953089922969332, 0.045217333612760625, 0.001692743417907392],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.8538274380845061, 0.09291991748691289, 0.05325264442858104],
                                [0.7692346550528416, 0.13784542746024556, 0.09291991748691289],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.8538274380845061, 0.05325264442858105, 0.09291991748691289],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248382],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.6832874495324133, 0.20132987799400742, 0.11538267247357925],
                                [0.5, 0.2986701220059926, 0.20132987799400742],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.6832874495324134, 0.11538267247357925, 0.20132987799400742],
                                [0.5, 0.4819575715384059, 0.018042428461594096],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.5127474609803206, 0.30973983850110187, 0.17751270051857745],
                                [0.23076534494715856, 0.45949481655173957, 0.3097398385011019],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.5127474609803206, 0.17751270051857743, 0.3097398385011019],
                                [0.2307653449471585, 0.7414769325849017, 0.027757722467939807],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.3962889193428544, 0.383770955817467, 0.21994012483967862],
                                [0.046910077030668074, 0.5693189671518648, 0.38377095581746706],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.3962889193428543, 0.21994012483967856, 0.38377095581746706],
                                [0.046910077030668074, 0.9186978094640511, 0.0343921135052808],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9795455285381048, 0.009629251354415329, 0.010825220107479883],
                                [0.953089922969332, 0.01876172804398782, 0.0281483489866802],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.9795455285381048, 0.010825220107479883, 0.009629251354415329],
                                [0.953089922969332, 0.045217333612760625, 0.001692743417907392],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.8993780556034863, 0.04736929996793276, 0.05325264442858104],
                                [0.7692346550528415, 0.09229480994126543, 0.13847053500589301],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.8993780556034863, 0.053252644428581034, 0.047369299967932765],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248382],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.7819821160331621, 0.1026352114932586, 0.11538267247357925],
                                [0.5, 0.19997545550524376, 0.30002454449475624],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.7819821160331621, 0.11538267247357925, 0.1026352114932586],
                                [0.5, 0.4819575715384059, 0.018042428461594096],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.6645861764628381, 0.15790112301858442, 0.17751270051857745],
                                [0.23076534494715845, 0.3076561010692221, 0.4615785539836194],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.664586176462838, 0.17751270051857743, 0.15790112301858444],
                                [0.2307653449471585, 0.7414769325849017, 0.027757722467939807],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.5844187035282196, 0.19564117163210187, 0.21994012483967862],
                                [0.046910077030668074, 0.38118918296649973, 0.5719007400028322],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.5844187035282196, 0.21994012483967862, 0.19564117163210187],
                                [0.046910077030668074, 0.9186978094640511, 0.0343921135052808],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9858686997808326, 0.0033060801116875926, 0.010825220107479883],
                                [0.953089922969332, 0.012438556801260083, 0.034471520229407936],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.9858686997808325, 0.010825220107479883, 0.003306080111687593],
                                [0.953089922969332, 0.045217333612760625, 0.001692743417907392],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.9304837131796626, 0.016263642391756337, 0.05325264442858104],
                                [0.7692346550528415, 0.061189152365088983, 0.16957619258206946],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.9304837131796626, 0.05325264442858104, 0.016263642391756337],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248382],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.8493788423121862, 0.035238485214234505, 0.11538267247357925],
                                [0.5, 0.13257872922621966, 0.36742127077378034],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.8493788423121863, 0.11538267247357925, 0.035238485214234505],
                                [0.5, 0.4819575715384059, 0.018042428461594096],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.7682739714447099, 0.054213328036712666, 0.17751270051857745],
                                [0.2307653449471585, 0.20396830608735028, 0.5652663489654912],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.7682739714447099, 0.17751270051857745, 0.05421332803671267],
                                [0.2307653449471585, 0.7414769325849017, 0.027757722467939807],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.71288898484354, 0.06717089031678142, 0.21994012483967862],
                                [0.046910077030668074, 0.2527189016511793, 0.7003710213181527],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.71288898484354, 0.21994012483967862, 0.06717089031678142],
                                [0.046910077030668074, 0.9186978094640511, 0.0343921135052808],
                                [0.9530899229693319, 0.042612194596522504, 0.0042978824341455115],
                                [0.9531883087454855, 0.0446111359274912, 0.0022005553270232096],
                                [0.9530899229693319, 0.004199496657991901, 0.04271058037267612],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9531883087454855, 0.002200555327023214, 0.04461113592749119],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.7692346550528416, 0.2096227166413145, 0.021142628305843954],
                                [0.7697186454661836, 0.21945613442633646, 0.010825220107479893],
                                [0.7692346550528415, 0.020658637892501858, 0.2101067070546566],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7697186454661836, 0.010825220107479883, 0.21945613442633646],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.5, 0.45419020063284354, 0.04580979936715644],
                                [0.5010486635535611, 0.4754962979311048, 0.023455038515334037],
                                [0.5, 0.04476113581359531, 0.4552388641864047],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5010486635535611, 0.023455038515334037, 0.4754962979311048],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.2307653449471585, 0.6987576846243726, 0.07047697042846893],
                                [0.23237868164093867, 0.7315364614358731, 0.03608485692318818],
                                [0.2307653449471585, 0.06886363373468873, 0.7003710213181528],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.23237868164093867, 0.03608485692318819, 0.7315364614358731],
                                [0.2307653449471585, 0.0704769704284689, 0.6987576846243726],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016737],
                                [0.04890901836163675, 0.9063814599347184, 0.04470952170364486],
                                [0.046910077030668074, 0.08532277496919871, 0.8677671480001332],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.04890901836163675, 0.04470952170364484, 0.9063814599347184],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.9530899229693319, 0.042612194596522504, 0.0042978824341455115],
                                [0.953573913382674, 0.04422553129030271, 0.0022005553270232096],
                                [0.953089922969332, 0.003813892020803414, 0.043096185009864604],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.953573913382674, 0.002200555327023214, 0.044225531290302704],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.7692346550528416, 0.2096227166413145, 0.021142628305843954],
                                [0.7716155553146977, 0.21755922457782245, 0.010825220107479893],
                                [0.7692346550528415, 0.018761728043987846, 0.2120036169031706],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7716155553146977, 0.010825220107479883, 0.21755922457782245],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.5, 0.45419020063284354, 0.04580979936715644],
                                [0.5051587040991821, 0.47138625738548395, 0.023455038515334037],
                                [0.49999999999999994, 0.040651095267974446, 0.45934890473202555],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5051587040991821, 0.023455038515334037, 0.47138625738548395],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.2307653449471585, 0.6987576846243726, 0.07047697042846893],
                                [0.2387018528836664, 0.7252132901931454, 0.03608485692318818],
                                [0.2307653449471585, 0.06254046249196099, 0.7066941925608805],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.2387018528836664, 0.03608485692318819, 0.7252132901931454],
                                [0.2307653449471585, 0.0704769704284689, 0.6987576846243726],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016737],
                                [0.056743494815689965, 0.8985469834806652, 0.04470952170364486],
                                [0.046910077030668074, 0.07748829851514549, 0.8756016244541864],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.056743494815689965, 0.04470952170364484, 0.8985469834806652],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.9530899229693319, 0.042612194596522504, 0.0042978824341455115],
                                [0.9541385865228931, 0.04366085815008366, 0.0022005553270232096],
                                [0.9530899229693319, 0.0032492188805843605, 0.04366085815008366],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9541385865228931, 0.002200555327023207, 0.04366085815008366],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.7692346550528416, 0.2096227166413145, 0.021142628305843954],
                                [0.7743933591520236, 0.21478142074049653, 0.010825220107479893],
                                [0.7692346550528415, 0.01598392420666192, 0.21478142074049653],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7743933591520236, 0.010825220107479883, 0.21478142074049653],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.5, 0.45419020063284354, 0.04580979936715644],
                                [0.5111773804259112, 0.46536758105875475, 0.023455038515334037],
                                [0.5, 0.03463241894124525, 0.46536758105875475],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5111773804259112, 0.023455038515334037, 0.46536758105875475],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.2307653449471585, 0.6987576846243726, 0.07047697042846893],
                                [0.24796140169979886, 0.715953741377013, 0.03608485692318818],
                                [0.2307653449471585, 0.053280913675828545, 0.715953741377013],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.24796140169979886, 0.03608485692318819, 0.715953741377013],
                                [0.2307653449471585, 0.0704769704284689, 0.6987576846243726],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016737],
                                [0.06821617432892935, 0.8870743039674258, 0.04470952170364486],
                                [0.046910077030668074, 0.06601561900190611, 0.8870743039674258],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.06821617432892935, 0.04470952170364484, 0.8870743039674258],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.9530899229693319, 0.042612194596522504, 0.0042978824341455115],
                                [0.9547032596631122, 0.04309618500986462, 0.0022005553270232096],
                                [0.9530899229693319, 0.002684545740365314, 0.044225531290302704],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9547032596631122, 0.002200555327023214, 0.04309618500986461],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.7692346550528416, 0.2096227166413145, 0.021142628305843954],
                                [0.7771711629893495, 0.21200361690317063, 0.010825220107479893],
                                [0.7692346550528416, 0.013206120369336022, 0.21755922457782242],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7771711629893495, 0.010825220107479883, 0.21200361690317063],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.5, 0.45419020063284354, 0.04580979936715644],
                                [0.5171960567526404, 0.4593489047320256, 0.023455038515334037],
                                [0.5, 0.028613742614516102, 0.4713862573854839],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5171960567526404, 0.023455038515334037, 0.4593489047320256],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.2307653449471585, 0.6987576846243726, 0.07047697042846893],
                                [0.2572209505159313, 0.7066941925608805, 0.03608485692318818],
                                [0.2307653449471585, 0.04402136485969621, 0.7252132901931453],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.2572209505159313, 0.03608485692318819, 0.7066941925608805],
                                [0.2307653449471585, 0.0704769704284689, 0.6987576846243726],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016737],
                                [0.07968885384216862, 0.8756016244541865, 0.04470952170364486],
                                [0.046910077030668074, 0.05454293948866684, 0.8985469834806651],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.07968885384216862, 0.04470952170364484, 0.8756016244541865],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.9530899229693319, 0.042612194596522504, 0.0042978824341455115],
                                [0.9550888643003006, 0.042710580372676124, 0.0022005553270232096],
                                [0.9530899229693319, 0.002298941103176827, 0.04461113592749119],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9550888643003006, 0.002200555327023214, 0.04271058037267612],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.7692346550528416, 0.2096227166413145, 0.021142628305843954],
                                [0.7790680728378635, 0.2101067070546566, 0.010825220107479893],
                                [0.7692346550528415, 0.011309210520821983, 0.21945613442633646],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7790680728378635, 0.010825220107479883, 0.2101067070546566],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.5, 0.45419020063284354, 0.04580979936715644],
                                [0.5213060972982613, 0.4552388641864047, 0.023455038515334037],
                                [0.5, 0.024503702068895183, 0.4754962979311048],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5213060972982613, 0.023455038515334037, 0.4552388641864047],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.2307653449471585, 0.6987576846243726, 0.07047697042846893],
                                [0.26354412175865904, 0.7003710213181528, 0.03608485692318818],
                                [0.2307653449471585, 0.037698193616968356, 0.7315364614358731],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.26354412175865904, 0.03608485692318819, 0.7003710213181528],
                                [0.2307653449471585, 0.0704769704284689, 0.6987576846243726],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016737],
                                [0.08752333029622195, 0.8677671480001332, 0.04470952170364486],
                                [0.046910077030668074, 0.04670846303461351, 0.9063814599347184],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.08752333029622195, 0.04470952170364484, 0.8677671480001332],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.953573913382674, 0.04422553129030271, 0.0022005553270232096],
                                [0.953089922969332, 0.012033973112045175, 0.03487610391862284],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.953573913382674, 0.002200555327023214, 0.044225531290302704],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.7716155553146977, 0.21755922457782245, 0.010825220107479893],
                                [0.7692346550528415, 0.059198878621973317, 0.17156646632518513],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.7716155553146977, 0.010825220107479883, 0.21755922457782245],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5051587040991821, 0.47138625738548395, 0.023455038515334037],
                                [0.5, 0.12826639683599134, 0.37173360316400866],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5051587040991821, 0.023455038515334037, 0.47138625738548395],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.2387018528836664, 0.7252132901931454, 0.03608485692318818],
                                [0.2307653449471585, 0.1973339150500093, 0.5719007400028322],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.2387018528836664, 0.03608485692318819, 0.7252132901931454],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.056743494815689965, 0.8985469834806652, 0.04470952170364486],
                                [0.046910077030668074, 0.24449882055993744, 0.7085911024093945],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.056743494815689965, 0.04470952170364484, 0.8985469834806652],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.955470823231188, 0.042328621441788686, 0.0022005553270232096],
                                [0.953089922969332, 0.01013706326353115, 0.03677301376713687],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.955470823231188, 0.002200555327023207, 0.042328621441788686],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.7809470483165066, 0.20822773157601346, 0.010825220107479893],
                                [0.7692346550528415, 0.049867385620164295, 0.18089795932699415],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.7809470483165066, 0.01082522010747991, 0.20822773157601343],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5253772793881748, 0.4511676820964912, 0.023455038515334037],
                                [0.5, 0.1080478215469986, 0.3919521784530014],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5253772793881748, 0.023455038515334037, 0.4511676820964912],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.26980751045984286, 0.694107632616969, 0.03608485692318818],
                                [0.2307653449471585, 0.16622825747383285, 0.6030063975790086],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.26980751045984286, 0.03608485692318819, 0.694107632616969],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.09528373554516145, 0.8600067427511937, 0.04470952170364486],
                                [0.046910077030668074, 0.20595857983046606, 0.7471313431388659],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.09528373554516145, 0.04470952170364484, 0.8600067427511937],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.958248627068514, 0.03955081760446278, 0.0022005553270232096],
                                [0.9530899229693319, 0.007359259426205245, 0.039550817604462774],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.958248627068514, 0.002200555327023214, 0.039550817604462774],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.7946119344410163, 0.1945628454515038, 0.010825220107479893],
                                [0.7692346550528415, 0.036202499495654655, 0.1945628454515038],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.7946119344410163, 0.010825220107479883, 0.1945628454515038],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5549850312099196, 0.4215599302747463, 0.023455038515334037],
                                [0.49999999999999994, 0.07844006972525369, 0.4215599302747463],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5549850312099196, 0.023455038515334037, 0.4215599302747463],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.315358127978823, 0.6485570150979888, 0.03608485692318818],
                                [0.2307653449471585, 0.1206776399548527, 0.6485570150979888],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.315358127978823, 0.03608485692318819, 0.6485570150979888],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.15172143535132532, 0.8035690429450298, 0.04470952170364486],
                                [0.046910077030668074, 0.14952088002430208, 0.8035690429450298],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.15172143535132532, 0.04470952170364484, 0.8035690429450298],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9610264309058398, 0.036773013767136875, 0.0022005553270232096],
                                [0.9530899229693319, 0.004581455588879339, 0.04232862144178868],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.96102643090584, 0.002200555327023214, 0.03677301376713687],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.808276820565526, 0.18089795932699418, 0.010825220107479893],
                                [0.7692346550528416, 0.022537613371145043, 0.2082277315760134],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.808276820565526, 0.010825220107479883, 0.18089795932699418],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5845927830316645, 0.39195217845300145, 0.023455038515334037],
                                [0.5, 0.04883231790350884, 0.45116768209649116],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5845927830316645, 0.023455038515334037, 0.39195217845300145],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.36090874549780316, 0.6030063975790086, 0.03608485692318818],
                                [0.2307653449471585, 0.07512702243587266, 0.6941076326169688],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.36090874549780316, 0.03608485692318819, 0.6030063975790086],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.20815913515748918, 0.747131343138866, 0.04470952170364486],
                                [0.046910077030668074, 0.09308318021813833, 0.8600067427511936],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.20815913515748918, 0.04470952170364484, 0.747131343138866],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9629233407543539, 0.03487610391862286, 0.0022005553270232096],
                                [0.9530899229693319, 0.002684545740365314, 0.044225531290302704],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.9629233407543539, 0.002200555327023214, 0.03487610391862285],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.8176083135673349, 0.17156646632518519, 0.010825220107479893],
                                [0.7692346550528416, 0.013206120369336022, 0.21755922457782242],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.817608313567335, 0.01082522010747991, 0.17156646632518516],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.6048113583206572, 0.3717336031640087, 0.023455038515334037],
                                [0.5, 0.028613742614516102, 0.4713862573854839],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.6048113583206572, 0.023455038515334037, 0.3717336031640087],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.3920144030739796, 0.5719007400028322, 0.03608485692318818],
                                [0.2307653449471585, 0.04402136485969621, 0.7252132901931453],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.3920144030739796, 0.03608485692318819, 0.5719007400028322],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.24669937588696056, 0.7085911024093946, 0.04470952170364486],
                                [0.046910077030668074, 0.05454293948866684, 0.8985469834806651],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.24669937588696056, 0.04470952170364495, 0.7085911024093945],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9541385865228931, 0.04366085815008366, 0.0022005553270232096],
                                [0.9530899229693319, 0.023506652625284463, 0.023403424405383556],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9541385865228931, 0.002200555327023207, 0.04366085815008366],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7743933591520236, 0.21478142074049653, 0.010825220107479893],
                                [0.7692346550528416, 0.11563657842813714, 0.1151287665190213],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.7743933591520236, 0.010825220107479883, 0.21478142074049653],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5111773804259112, 0.46536758105875475, 0.023455038515334037],
                                [0.5, 0.2505501388317558, 0.2494498611682442],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.5111773804259112, 0.023455038515334037, 0.46536758105875475],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.24796140169979886, 0.715953741377013, 0.03608485692318818],
                                [0.23076534494715845, 0.38546369923537444, 0.38377095581746706],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.24796140169979886, 0.03608485692318819, 0.715953741377013],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.06821617432892935, 0.8870743039674258, 0.04470952170364486],
                                [0.046910077030668074, 0.4775936250382271, 0.4754962979311048],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.06821617432892935, 0.04470952170364484, 0.8870743039674258],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.958248627068514, 0.03955081760446278, 0.0022005553270232096],
                                [0.9530899229693319, 0.019396612079663582, 0.027513464951004436],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.958248627068514, 0.002200555327023214, 0.039550817604462774],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7946119344410163, 0.1945628454515038, 0.010825220107479893],
                                [0.7692346550528416, 0.09541800313914439, 0.13534734180801405],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.7946119344410163, 0.010825220107479883, 0.1945628454515038],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5549850312099196, 0.4215599302747463, 0.023455038515334037],
                                [0.49999999999999994, 0.20674248804774736, 0.29325751195225264],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.5549850312099196, 0.023455038515334037, 0.4215599302747463],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.315358127978823, 0.6485570150979888, 0.03608485692318818],
                                [0.23076534494715856, 0.3180669729563503, 0.4511676820964912],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.315358127978823, 0.03608485692318819, 0.6485570150979888],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.15172143535132532, 0.8035690429450298, 0.04470952170364486],
                                [0.046910077030668074, 0.39408836401583114, 0.5590015589535008],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.15172143535132532, 0.04470952170364484, 0.8035690429450298],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9642673033952431, 0.03353214127773361, 0.0022005553270232096],
                                [0.9530899229693319, 0.01337793575293441, 0.03353214127773361],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9642673033952431, 0.002200555327023207, 0.03353214127773361],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.8242196862627612, 0.16495509362975894, 0.010825220107479893],
                                [0.7692346550528415, 0.06581025131739954, 0.1649550936297589],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.8242196862627612, 0.01082522010747991, 0.1649550936297589],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.6191362403711664, 0.3574087211134995, 0.023455038515334037],
                                [0.49999999999999994, 0.14259127888650053, 0.3574087211134995],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.6191362403711664, 0.023455038515334037, 0.3574087211134995],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.4140527944795719, 0.5498623485972399, 0.03608485692318818],
                                [0.2307653449471585, 0.21937230645560146, 0.54986234859724],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.4140527944795719, 0.03608485692318808, 0.54986234859724],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.27400517734708985, 0.6812853009492653, 0.04470952170364486],
                                [0.046910077030668074, 0.2718046220200666, 0.6812853009492653],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.27400517734708985, 0.04470952170364484, 0.6812853009492653],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9702859797219723, 0.027513464951004436, 0.0022005553270232096],
                                [0.9530899229693319, 0.007359259426205245, 0.039550817604462774],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9702859797219723, 0.0022005553270232105, 0.027513464951004436],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.8538274380845061, 0.13534734180801405, 0.010825220107479893],
                                [0.7692346550528415, 0.036202499495654655, 0.1945628454515038],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.8538274380845061, 0.010825220107479883, 0.13534734180801405],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.6832874495324133, 0.29325751195225264, 0.023455038515334037],
                                [0.49999999999999994, 0.07844006972525369, 0.4215599302747463],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.6832874495324133, 0.023455038515334037, 0.29325751195225264],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5127474609803206, 0.45116768209649116, 0.03608485692318818],
                                [0.2307653449471585, 0.1206776399548527, 0.6485570150979888],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.5127474609803206, 0.036084856923188136, 0.4511676820964912],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.3962889193428544, 0.5590015589535008, 0.04470952170364486],
                                [0.046910077030668074, 0.14952088002430208, 0.8035690429450298],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.3962889193428544, 0.04470952170364484, 0.5590015589535008],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9743960202675932, 0.023403424405383556, 0.0022005553270232096],
                                [0.9530899229693319, 0.0032492188805843605, 0.04366085815008366],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9743960202675932, 0.0022005553270232105, 0.023403424405383556],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.8740460133734989, 0.1151287665190213, 0.010825220107479893],
                                [0.7692346550528415, 0.01598392420666192, 0.21478142074049653],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.8740460133734989, 0.010825220107479896, 0.1151287665190213],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.7270951003164218, 0.2494498611682442, 0.023455038515334037],
                                [0.5, 0.03463241894124525, 0.46536758105875475],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.7270951003164218, 0.023455038515334037, 0.2494498611682442],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5801441872593448, 0.383770955817467, 0.03608485692318818],
                                [0.2307653449471585, 0.053280913675828545, 0.715953741377013],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.5801441872593447, 0.036084856923188136, 0.38377095581746706],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.47979418036525034, 0.4754962979311048, 0.04470952170364486],
                                [0.046910077030668074, 0.06601561900190611, 0.8870743039674258],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.47979418036525034, 0.04470952170364484, 0.4754962979311048],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9547032596631122, 0.04309618500986462, 0.0022005553270232096],
                                [0.9530899229693319, 0.03497933213852376, 0.011930744892144263],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.9547032596631122, 0.002200555327023214, 0.04309618500986461],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364065],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.7771711629893495, 0.21200361690317063, 0.010825220107479893],
                                [0.7692346550528415, 0.172074278234301, 0.05869106671285747],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.7771711629893495, 0.010825220107479883, 0.21200361690317063],
                                [0.7692346550528416, 0.1800107861708089, 0.05075455877634953],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.5171960567526404, 0.4593489047320256, 0.023455038515334037],
                                [0.5, 0.37283388082752034, 0.1271661191724797],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.5171960567526404, 0.023455038515334037, 0.4593489047320256],
                                [0.5, 0.3900299375801607, 0.10997006241983931],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.2572209505159313, 0.7066941925608805, 0.03608485692318818],
                                [0.2307653449471585, 0.5735934834207396, 0.1956411716321019],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.2572209505159313, 0.03608485692318819, 0.7066941925608805],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332907],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.07968885384216862, 0.8756016244541865, 0.04470952170364486],
                                [0.046910077030668074, 0.7106884295165168, 0.24240149345281511],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.07968885384216862, 0.04470952170364484, 0.8756016244541865],
                                [0.046910077030668074, 0.7434672063280174, 0.20962271664131454],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9610264309058398, 0.036773013767136875, 0.0022005553270232096],
                                [0.9530899229693319, 0.028656160895796017, 0.018253916134872],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.96102643090584, 0.002200555327023214, 0.03677301376713687],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364065],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.808276820565526, 0.18089795932699418, 0.010825220107479893],
                                [0.7692346550528415, 0.14096862065812454, 0.08979672428903392],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.808276820565526, 0.010825220107479883, 0.18089795932699418],
                                [0.7692346550528416, 0.1800107861708089, 0.05075455877634953],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.5845927830316645, 0.39195217845300145, 0.023455038515334037],
                                [0.5, 0.3054371545484962, 0.19456284545150382],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.5845927830316645, 0.023455038515334037, 0.39195217845300145],
                                [0.5, 0.3900299375801607, 0.10997006241983931],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.36090874549780316, 0.6030063975790086, 0.03608485692318818],
                                [0.2307653449471585, 0.4699056884388678, 0.2993289666139737],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.36090874549780316, 0.03608485692318819, 0.6030063975790086],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332907],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.20815913515748918, 0.747131343138866, 0.04470952170364486],
                                [0.046910077030668074, 0.5822181482011963, 0.3708717747681356],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.20815913515748918, 0.04470952170364484, 0.747131343138866],
                                [0.046910077030668074, 0.7434672063280174, 0.20962271664131454],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9702859797219723, 0.027513464951004436, 0.0022005553270232096],
                                [0.9530899229693319, 0.019396612079663582, 0.027513464951004436],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.9702859797219723, 0.0022005553270232105, 0.027513464951004436],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364065],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.8538274380845061, 0.13534734180801405, 0.010825220107479893],
                                [0.7692346550528416, 0.09541800313914439, 0.13534734180801405],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.8538274380845061, 0.010825220107479883, 0.13534734180801405],
                                [0.7692346550528416, 0.1800107861708089, 0.05075455877634953],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.6832874495324133, 0.29325751195225264, 0.023455038515334037],
                                [0.49999999999999994, 0.20674248804774736, 0.29325751195225264],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.6832874495324133, 0.023455038515334037, 0.29325751195225264],
                                [0.5, 0.3900299375801607, 0.10997006241983931],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.5127474609803206, 0.45116768209649116, 0.03608485692318818],
                                [0.23076534494715856, 0.3180669729563503, 0.4511676820964912],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.5127474609803206, 0.036084856923188136, 0.4511676820964912],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332907],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.3962889193428544, 0.5590015589535008, 0.04470952170364486],
                                [0.046910077030668074, 0.39408836401583114, 0.5590015589535008],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.3962889193428544, 0.04470952170364484, 0.5590015589535008],
                                [0.046910077030668074, 0.7434672063280174, 0.20962271664131454],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9795455285381047, 0.018253916134872, 0.0022005553270232096],
                                [0.953089922969332, 0.01013706326353115, 0.03677301376713687],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.9795455285381047, 0.0022005553270232105, 0.018253916134872],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364065],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.8993780556034863, 0.0897967242890339, 0.010825220107479893],
                                [0.7692346550528416, 0.04986738562016427, 0.18089795932699418],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.8993780556034862, 0.010825220107479883, 0.08979672428903392],
                                [0.7692346550528416, 0.1800107861708089, 0.05075455877634953],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.7819821160331621, 0.19456284545150382, 0.023455038515334037],
                                [0.5, 0.10804782154699855, 0.39195217845300145],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.7819821160331621, 0.023455038515334037, 0.19456284545150382],
                                [0.5, 0.3900299375801607, 0.10997006241983931],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.6645861764628381, 0.2993289666139737, 0.03608485692318818],
                                [0.2307653449471585, 0.16622825747383285, 0.6030063975790086],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.6645861764628381, 0.03608485692318819, 0.2993289666139737],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332907],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.5844187035282196, 0.37087177476813565, 0.04470952170364486],
                                [0.046910077030668074, 0.20595857983046595, 0.747131343138866],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.5844187035282196, 0.044709521703644894, 0.3708717747681356],
                                [0.046910077030668074, 0.7434672063280174, 0.20962271664131454],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9858686997808325, 0.011930744892144265, 0.0022005553270232096],
                                [0.953089922969332, 0.003813892020803414, 0.043096185009864604],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.9858686997808325, 0.0022005553270232105, 0.011930744892144265],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364065],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.9304837131796626, 0.05869106671285748, 0.010825220107479893],
                                [0.7692346550528415, 0.018761728043987846, 0.2120036169031706],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.9304837131796626, 0.010825220107479896, 0.05869106671285748],
                                [0.7692346550528416, 0.1800107861708089, 0.05075455877634953],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.8493788423121862, 0.12716611917247972, 0.023455038515334037],
                                [0.49999999999999994, 0.040651095267974446, 0.45934890473202555],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.8493788423121862, 0.023455038515334037, 0.12716611917247972],
                                [0.5, 0.3900299375801607, 0.10997006241983931],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.7682739714447099, 0.19564117163210193, 0.03608485692318818],
                                [0.2307653449471585, 0.06254046249196099, 0.7066941925608805],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.7682739714447099, 0.03608485692318819, 0.19564117163210193],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332907],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.71288898484354, 0.24240149345281517, 0.04470952170364486],
                                [0.046910077030668074, 0.07748829851514549, 0.8756016244541864],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.71288898484354, 0.04470952170364487, 0.24240149345281517],
                                [0.046910077030668074, 0.7434672063280174, 0.20962271664131454],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9550888643003006, 0.042710580372676124, 0.0022005553270232096],
                                [0.953089922969332, 0.04281380859257703, 0.004096268438090989],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9550888643003006, 0.002200555327023214, 0.04271058037267612],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122303],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.7790680728378635, 0.2101067070546566, 0.010825220107479893],
                                [0.7692346550528415, 0.21061451896377242, 0.020150825983386026],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.7790680728378635, 0.010825220107479883, 0.2101067070546566],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364068],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.5213060972982613, 0.4552388641864047, 0.023455038515334037],
                                [0.5, 0.4563391418499163, 0.04366085815008367],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.5213060972982613, 0.023455038515334037, 0.4552388641864047],
                                [0.5, 0.4776452391481776, 0.02235476085182242],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.26354412175865904, 0.7003710213181528, 0.03608485692318818],
                                [0.2307653449471585, 0.7020637647360601, 0.0671708903167813],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.26354412175865904, 0.03608485692318819, 0.7003710213181528],
                                [0.2307653449471585, 0.7348425415475607, 0.03439211350528077],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.08752333029622195, 0.8677671480001332, 0.04470952170364486],
                                [0.046910077030668074, 0.8698644751072556, 0.08322544786207635],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.08752333029622195, 0.04470952170364484, 0.8677671480001332],
                                [0.046910077030668074, 0.9104777283728094, 0.04261219459652253],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9629233407543539, 0.03487610391862286, 0.0022005553270232096],
                                [0.9530899229693319, 0.03497933213852376, 0.01193074489214426],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9629233407543539, 0.002200555327023214, 0.03487610391862285],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122303],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.8176083135673349, 0.17156646632518519, 0.010825220107479893],
                                [0.7692346550528415, 0.172074278234301, 0.05869106671285746],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.817608313567335, 0.01082522010747991, 0.17156646632518516],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364068],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.6048113583206572, 0.3717336031640087, 0.023455038515334037],
                                [0.5, 0.37283388082752034, 0.12716611917247966],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.6048113583206572, 0.023455038515334037, 0.3717336031640087],
                                [0.5, 0.4776452391481776, 0.02235476085182242],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.3920144030739796, 0.5719007400028322, 0.03608485692318818],
                                [0.2307653449471585, 0.5735934834207397, 0.19564117163210185],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.3920144030739796, 0.03608485692318819, 0.5719007400028322],
                                [0.2307653449471585, 0.7348425415475607, 0.03439211350528077],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.24669937588696056, 0.7085911024093946, 0.04470952170364486],
                                [0.046910077030668074, 0.7106884295165169, 0.24240149345281506],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.24669937588696056, 0.04470952170364495, 0.7085911024093945],
                                [0.046910077030668074, 0.9104777283728094, 0.04261219459652253],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9743960202675932, 0.023403424405383556, 0.0022005553270232096],
                                [0.9530899229693319, 0.023506652625284463, 0.023403424405383556],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9743960202675932, 0.0022005553270232105, 0.023403424405383556],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122303],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.8740460133734989, 0.1151287665190213, 0.010825220107479893],
                                [0.7692346550528416, 0.11563657842813714, 0.1151287665190213],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.8740460133734989, 0.010825220107479896, 0.1151287665190213],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364068],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.7270951003164218, 0.2494498611682442, 0.023455038515334037],
                                [0.5, 0.2505501388317558, 0.2494498611682442],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.7270951003164218, 0.023455038515334037, 0.2494498611682442],
                                [0.5, 0.4776452391481776, 0.02235476085182242],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.5801441872593448, 0.383770955817467, 0.03608485692318818],
                                [0.23076534494715845, 0.38546369923537444, 0.38377095581746706],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.5801441872593447, 0.036084856923188136, 0.38377095581746706],
                                [0.2307653449471585, 0.7348425415475607, 0.03439211350528077],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.47979418036525034, 0.4754962979311048, 0.04470952170364486],
                                [0.046910077030668074, 0.4775936250382271, 0.4754962979311048],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.47979418036525034, 0.04470952170364484, 0.4754962979311048],
                                [0.046910077030668074, 0.9104777283728094, 0.04261219459652253],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9858686997808325, 0.011930744892144261, 0.0022005553270232096],
                                [0.953089922969332, 0.012033973112045168, 0.03487610391862285],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9858686997808325, 0.0022005553270232105, 0.01193074489214426],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122303],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.9304837131796626, 0.058691066712857454, 0.010825220107479893],
                                [0.7692346550528416, 0.05919887862197329, 0.17156646632518516],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.9304837131796626, 0.01082522010747989, 0.05869106671285746],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364068],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.8493788423121863, 0.12716611917247966, 0.023455038515334037],
                                [0.5, 0.12826639683599128, 0.3717336031640087],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.8493788423121863, 0.023455038515334037, 0.12716611917247966],
                                [0.5, 0.4776452391481776, 0.02235476085182242],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.76827397144471, 0.19564117163210187, 0.03608485692318818],
                                [0.2307653449471585, 0.1973339150500093, 0.5719007400028322],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.76827397144471, 0.03608485692318819, 0.19564117163210185],
                                [0.2307653449471585, 0.7348425415475607, 0.03439211350528077],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.7128889848435401, 0.24240149345281506, 0.04470952170364486],
                                [0.046910077030668074, 0.24449882055993744, 0.7085911024093945],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.7128889848435401, 0.04470952170364487, 0.24240149345281506],
                                [0.046910077030668074, 0.9104777283728094, 0.04261219459652253],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9937031762348858, 0.0040962684380909916, 0.0022005553270232096],
                                [0.9530899229693319, 0.004199496657991901, 0.04271058037267612],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9937031762348858, 0.0022005553270232105, 0.004096268438090991],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122303],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.9690239539091341, 0.020150825983386033, 0.010825220107479893],
                                [0.7692346550528415, 0.020658637892501858, 0.2101067070546566],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.9690239539091341, 0.01082522010747989, 0.020150825983386036],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364068],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.9328841033345823, 0.04366085815008369, 0.023455038515334037],
                                [0.5, 0.04476113581359531, 0.4552388641864047],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.9328841033345823, 0.023455038515334037, 0.04366085815008369],
                                [0.5, 0.4776452391481776, 0.02235476085182242],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.8967442527600304, 0.06717089031678135, 0.03608485692318818],
                                [0.2307653449471585, 0.06886363373468873, 0.7003710213181528],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.8967442527600304, 0.03608485692318818, 0.06717089031678135],
                                [0.2307653449471585, 0.7348425415475607, 0.03439211350528077],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.8720650304342787, 0.08322544786207639, 0.04470952170364486],
                                [0.046910077030668074, 0.08532277496919871, 0.8677671480001332],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.8720650304342787, 0.04470952170364487, 0.08322544786207639],
                                [0.046910077030668074, 0.9104777283728094, 0.04261219459652253],
                            ]
                        ),
                        np.array(
                            [
                                [0.9530947654130792, 0.002195712883275913, 0.04470952170364481],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9530899229693319, 0.044807907479798424, 0.0021021695508695918],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.9530947654130792, 0.044709521703644804, 0.002195712883275917],
                                [0.7692584765486152, 0.010801398611706148, 0.21994012483967856],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7692346550528416, 0.22042411525302066, 0.010341229694137775],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7692584765486153, 0.21994012483967854, 0.010801398611706165],
                                [0.5000516141099505, 0.023403424405383566, 0.47654496148466596],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.49999999999999994, 0.47759362503822717, 0.02240637496177286],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5000516141099505, 0.47654496148466596, 0.023403424405383556],
                                [0.2308447516712857, 0.036005450199060984, 0.7331497981296533],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.2307653449471585, 0.7347631348234336, 0.03447152022940794],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.2308447516712857, 0.7331497981296533, 0.03600545019906094],
                                [0.047008462806821694, 0.04461113592749122, 0.9083804012656871],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.046910077030668074, 0.9103793425966558, 0.042710580372676124],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.047008462806821694, 0.9083804012656871, 0.04461113592749119],
                                [0.9531137444651057, 0.002176733831249493, 0.04470952170364481],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9530899229693319, 0.044788928427772004, 0.002121148602896015],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.9531137444651057, 0.04470952170364481, 0.002176733831249494],
                                [0.7693518404432169, 0.010708034717104492, 0.21994012483967856],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7692346550528415, 0.220330751358419, 0.010434593588739449],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7693518404432169, 0.21994012483967856, 0.010708034717104494],
                                [0.5002539059545579, 0.023201132560776105, 0.47654496148466596],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5, 0.4773913331936197, 0.022608666806380313],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.500253905954558, 0.47654496148466596, 0.023201132560776102],
                                [0.23115597146589895, 0.035694230404447747, 0.7331497981296533],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.2307653449471585, 0.7344519150288203, 0.03478274002402117],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.23115597146589895, 0.7331497981296533, 0.035694230404447705],
                                [0.0473940674440102, 0.04422553129030271, 0.9083804012656871],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.046910077030668074, 0.9099937379594674, 0.043096185009864604],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.0473940674440102, 0.9083804012656871, 0.04422553129030271],
                                [0.9531415370792824, 0.002148941217072757, 0.04470952170364481],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9530899229693319, 0.04476113581359526, 0.0021489412170727544],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.9531415370792824, 0.04470952170364481, 0.0021489412170727544],
                                [0.7694885610073994, 0.010571314152921979, 0.21994012483967856],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7692346550528415, 0.22019403079423647, 0.01057131415292197],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7694885610073994, 0.21994012483967856, 0.01057131415292197],
                                [0.5005501388317558, 0.022904899683578228, 0.47654496148466596],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5, 0.47709510031642177, 0.022904899683578207],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5005501388317558, 0.47654496148466596, 0.022904899683578207],
                                [0.23161171665611224, 0.03523848521423445, 0.7331497981296533],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.2307653449471585, 0.733996169838607, 0.03523848521423444],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.23161171665611224, 0.7331497981296533, 0.03523848521423444],
                                [0.04795874058422922, 0.04366085815008369, 0.9083804012656871],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.046910077030668074, 0.9094290648192482, 0.04366085815008366],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.04795874058422922, 0.9083804012656871, 0.04366085815008366],
                                [0.9531693296934591, 0.002121148602896014, 0.04470952170364481],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9530899229693319, 0.044733343199418525, 0.002176733831249494],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.9531693296934591, 0.04470952170364481, 0.002121148602896015],
                                [0.7696252815715819, 0.010434593588739466, 0.21994012483967856],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7692346550528416, 0.22005731023005395, 0.010708034717104494],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7696252815715819, 0.2199401248396786, 0.010434593588739449],
                                [0.5008463717089537, 0.02260866680638035, 0.47654496148466596],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5, 0.4767988674392239, 0.023201132560776102],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5008463717089537, 0.476544961484666, 0.022608666806380313],
                                [0.23206746184632543, 0.034782740024021264, 0.7331497981296533],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.2307653449471585, 0.7335404246483938, 0.035694230404447705],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.23206746184632543, 0.7331497981296534, 0.03478274002402117],
                                [0.04852341372444824, 0.043096185009864674, 0.9083804012656871],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.046910077030668074, 0.9088643916790292, 0.04422553129030271],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.04852341372444824, 0.9083804012656872, 0.043096185009864604],
                                [0.9531883087454855, 0.002102169550869594, 0.04470952170364481],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.953089922969332, 0.0447143641473921, 0.002195712883275917],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.9531883087454855, 0.04470952170364481, 0.0021021695508695918],
                                [0.7697186454661836, 0.010341229694137782, 0.21994012483967856],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7692346550528416, 0.21996394633545227, 0.010801398611706165],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7697186454661837, 0.21994012483967856, 0.010341229694137775],
                                [0.5010486635535611, 0.02240637496177289, 0.47654496148466596],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5, 0.47659657559461643, 0.023403424405383556],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5010486635535611, 0.476544961484666, 0.02240637496177286],
                                [0.23237868164093867, 0.034471520229408026, 0.7331497981296533],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.2307653449471585, 0.7332292048537805, 0.03600545019906094],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.23237868164093867, 0.7331497981296534, 0.03447152022940794],
                                [0.04890901836163675, 0.042710580372676166, 0.9083804012656871],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.046910077030668074, 0.9084787870418407, 0.04461113592749119],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.04890901836163675, 0.9083804012656871, 0.042710580372676124],
                                [0.9531137444651057, 0.002176733831249493, 0.04470952170364481],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.9530899229693319, 0.04519351211698692, 0.001716564913681103],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9531137444651057, 0.04470952170364481, 0.002176733831249494],
                                [0.7693518404432169, 0.010708034717104492, 0.21994012483967856],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7692346550528415, 0.2223210251015347, 0.008444319845623754],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7693518404432169, 0.21994012483967856, 0.010708034717104494],
                                [0.5002539059545579, 0.023201132560776105, 0.47654496148466596],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5, 0.48170366558384803, 0.018296334416151975],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.500253905954558, 0.47654496148466596, 0.023201132560776102],
                                [0.23115597146589895, 0.035694230404447747, 0.7331497981296533],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.2307653449471585, 0.7410863060661613, 0.028148348986680193],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.23115597146589895, 0.7331497981296533, 0.035694230404447705],
                                [0.0473940674440102, 0.04422553129030271, 0.9083804012656871],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.046910077030668074, 0.9182138190507091, 0.03487610391862284],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.0473940674440102, 0.9083804012656871, 0.04422553129030271],
                                [0.9532071083597073, 0.0020833699366478164, 0.04470952170364481],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.9530899229693319, 0.04510014822238524, 0.0018099288082827761],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9532071083597073, 0.044709521703644804, 0.0020833699366478203],
                                [0.7698111266500862, 0.010248748510235134, 0.21994012483967856],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7692346550528416, 0.22186173889466532, 0.00890360605249312],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7698111266500862, 0.21994012483967856, 0.010248748510235129],
                                [0.5012490428261158, 0.022205995689218272, 0.47654496148466596],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5, 0.4807085287122902, 0.019291471287709822],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5012490428261158, 0.47654496148466596, 0.022205995689218255],
                                [0.2326869590021453, 0.03416324286820138, 0.7331497981296533],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.2307653449471585, 0.739555318529915, 0.029679336522926522],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2326869590021453, 0.7331497981296533, 0.034163242868201375],
                                [0.049290977292524185, 0.04232862144178873, 0.9083804012656871],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.046910077030668074, 0.9163169092021951, 0.03677301376713687],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.049290977292524185, 0.9083804012656871, 0.042328621441788686],
                                [0.9533438289238899, 0.0019466493724652964, 0.04470952170364481],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.953089922969332, 0.04496342765820272, 0.0019466493724652984],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9533438289238899, 0.04470952170364481, 0.0019466493724652984],
                                [0.7704836978789573, 0.009576177281364118, 0.21994012483967856],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7692346550528415, 0.22118916766579433, 0.009576177281364125],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7704836978789573, 0.21994012483967856, 0.009576177281364125],
                                [0.50270630502687, 0.020748733488464066, 0.47654496148466596],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5, 0.47925126651153593, 0.02074873348846404],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.50270630502687, 0.47654496148466596, 0.02074873348846404],
                                [0.23492891217478273, 0.03192128969556396, 0.7331497981296533],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.2307653449471585, 0.7373133653572775, 0.03192128969556395],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.23492891217478273, 0.7331497981296533, 0.03192128969556395],
                                [0.05206878112985014, 0.039550817604462774, 0.9083804012656871],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.046910077030668074, 0.9135391053648692, 0.039550817604462774],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.05206878112985014, 0.9083804012656871, 0.039550817604462774],
                                [0.9534805494880724, 0.0018099288082827764, 0.04470952170364481],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.953089922969332, 0.044826707094020195, 0.0020833699366478203],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9534805494880724, 0.04470952170364481, 0.0018099288082827766],
                                [0.7711562691078282, 0.00890360605249313, 0.21994012483967856],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7692346550528415, 0.2205165964369233, 0.010248748510235127],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7711562691078284, 0.21994012483967856, 0.008903606052493122],
                                [0.5041635672276241, 0.01929147128770986, 0.47654496148466596],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5, 0.47779400431078173, 0.02220599568921825],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5041635672276241, 0.476544961484666, 0.019291471287709826],
                                [0.23717086534742005, 0.029679336522926647, 0.7331497981296533],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.2307653449471585, 0.7350714121846401, 0.034163242868201375],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.23717086534742005, 0.7331497981296534, 0.02967933652292653],
                                [0.05484658496717598, 0.03677301376713693, 0.9083804012656871],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.046910077030668074, 0.9107613015275432, 0.04232862144178868],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.05484658496717598, 0.9083804012656871, 0.036773013767136875],
                                [0.953573913382674, 0.0017165649136811068, 0.04470952170364481],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.9530899229693319, 0.044733343199418525, 0.0021767338312494934],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.953573913382674, 0.04470952170364481, 0.0017165649136811033],
                                [0.7716155553146976, 0.008444319845623771, 0.21994012483967856],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7692346550528416, 0.22005731023005395, 0.010708034717104492],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7716155553146976, 0.2199401248396786, 0.008444319845623756],
                                [0.5051587040991821, 0.018296334416152027, 0.47654496148466596],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5, 0.4767988674392239, 0.0232011325607761],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5051587040991821, 0.476544961484666, 0.01829633441615198],
                                [0.2387018528836664, 0.028148348986680283, 0.7331497981296533],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.2307653449471585, 0.7335404246483938, 0.035694230404447705],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2387018528836664, 0.7331497981296534, 0.0281483489866802],
                                [0.056743494815689965, 0.03487610391862295, 0.9083804012656871],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.046910077030668074, 0.9088643916790292, 0.044225531290302704],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.056743494815689965, 0.9083804012656872, 0.03487610391862285],
                                [0.9531415370792824, 0.002148941217072757, 0.04470952170364481],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9530899229693319, 0.045758185257205965, 0.0011518917734620563],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9531415370792824, 0.04470952170364481, 0.0021489412170727544],
                                [0.7694885610073994, 0.010571314152921979, 0.21994012483967856],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7692346550528416, 0.2250988289388606, 0.005666516008297848],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7694885610073994, 0.21994012483967856, 0.01057131415292197],
                                [0.5005501388317558, 0.022904899683578228, 0.47654496148466596],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.5, 0.4877223419105772, 0.012277658089422806],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5005501388317558, 0.47654496148466596, 0.022904899683578207],
                                [0.23161171665611224, 0.03523848521423445, 0.7331497981296533],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.2307653449471585, 0.7503458548822938, 0.018888800170547764],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.23161171665611224, 0.7331497981296533, 0.03523848521423444],
                                [0.04795874058422922, 0.04366085815008369, 0.9083804012656871],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.046910077030668074, 0.9296864985639484, 0.023403424405383556],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.04795874058422922, 0.9083804012656871, 0.04366085815008366],
                                [0.9533438289238899, 0.0019466493724652964, 0.04470952170364481],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.953089922969332, 0.045555893412598504, 0.0013541836180695124],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9533438289238899, 0.04470952170364481, 0.0019466493724652984],
                                [0.7704836978789573, 0.009576177281364118, 0.21994012483967856],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7692346550528416, 0.22410369206730274, 0.006661652879855695],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7704836978789573, 0.21994012483967856, 0.009576177281364125],
                                [0.50270630502687, 0.020748733488464066, 0.47654496148466596],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.5, 0.485566175715463, 0.014433824284536975],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.50270630502687, 0.47654496148466596, 0.02074873348846404],
                                [0.23492891217478273, 0.03192128969556396, 0.7331497981296533],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.2307653449471585, 0.7470286593636233, 0.022205995689218255],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.23492891217478273, 0.7331497981296533, 0.03192128969556395],
                                [0.05206878112985014, 0.039550817604462774, 0.9083804012656871],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.046910077030668074, 0.9255764580183274, 0.027513464951004436],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.05206878112985014, 0.9083804012656871, 0.039550817604462774],
                                [0.9536400618010877, 0.0016504164952674052, 0.04470952170364481],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9530899229693319, 0.04525966053540061, 0.0016504164952674055],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9536400618010877, 0.04470952170364481, 0.0016504164952674055],
                                [0.7719409600797115, 0.008118915080609912, 0.21994012483967856],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7692346550528415, 0.22264642986654853, 0.00811891508060991],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7719409600797116, 0.21994012483967856, 0.00811891508060991],
                                [0.5058637596288336, 0.017591278886500528, 0.47654496148466596],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.5, 0.4824087211134995, 0.017591278886500507],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5058637596288336, 0.47654496148466596, 0.017591278886500507],
                                [0.23978655917795555, 0.027063642692391143, 0.7331497981296533],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.2307653449471585, 0.7421710123604504, 0.0270636426923911],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.23978655917795555, 0.7331497981296533, 0.0270636426923911],
                                [0.05808745745657928, 0.03353214127773363, 0.9083804012656871],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.046910077030668074, 0.9195577816915983, 0.03353214127773361],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.05808745745657928, 0.9083804012656871, 0.03353214127773361],
                                [0.9539362946782857, 0.001354183618069514, 0.04470952170364481],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.953089922969332, 0.04496342765820272, 0.0019466493724652984],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9539362946782857, 0.04470952170364481, 0.0013541836180695124],
                                [0.7733982222804657, 0.0066616528798556784, 0.21994012483967856],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7692346550528415, 0.22118916766579433, 0.009576177281364125],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7733982222804658, 0.21994012483967854, 0.006661652879855695],
                                [0.509021214230797, 0.014433824284536989, 0.47654496148466596],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.5, 0.47925126651153593, 0.02074873348846404],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.509021214230797, 0.47654496148466596, 0.014433824284536975],
                                [0.24464420618112837, 0.022205995689218327, 0.7331497981296533],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.2307653449471585, 0.7373133653572775, 0.03192128969556395],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.24464420618112837, 0.7331497981296534, 0.022205995689218255],
                                [0.06410613378330843, 0.027513464951004485, 0.9083804012656871],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.046910077030668074, 0.9135391053648692, 0.039550817604462774],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.06410613378330843, 0.9083804012656871, 0.027513464951004436],
                                [0.9541385865228931, 0.0011518917734620535, 0.04470952170364481],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9530899229693319, 0.04476113581359526, 0.0021489412170727544],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9541385865228931, 0.04470952170364481, 0.0011518917734620563],
                                [0.7743933591520236, 0.005666516008297845, 0.21994012483967856],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7692346550528415, 0.22019403079423647, 0.01057131415292197],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7743933591520236, 0.21994012483967856, 0.005666516008297848],
                                [0.5111773804259112, 0.012277658089422827, 0.47654496148466596],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.5, 0.47709510031642177, 0.022904899683578207],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5111773804259112, 0.47654496148466596, 0.012277658089422806],
                                [0.24796140169979886, 0.018888800170547837, 0.7331497981296533],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.2307653449471585, 0.733996169838607, 0.03523848521423444],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.24796140169979886, 0.7331497981296534, 0.018888800170547764],
                                [0.06821617432892935, 0.023403424405383566, 0.9083804012656871],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.046910077030668074, 0.9094290648192482, 0.04366085815008366],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.06821617432892935, 0.9083804012656871, 0.023403424405383556],
                                [0.9531693296934591, 0.002121148602896014, 0.04470952170364481],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.953089922969332, 0.04632285839742501, 0.0005872186332430095],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.9531693296934591, 0.04470952170364481, 0.002121148602896015],
                                [0.7696252815715819, 0.010434593588739466, 0.21994012483967856],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7692346550528415, 0.2278766327761865, 0.0028887121709719413],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.7696252815715819, 0.2199401248396786, 0.010434593588739449],
                                [0.5008463717089537, 0.02260866680638035, 0.47654496148466596],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.49999999999999994, 0.4937410182373064, 0.006258981762693636],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.5008463717089537, 0.476544961484666, 0.022608666806380313],
                                [0.23206746184632543, 0.034782740024021264, 0.7331497981296533],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.2307653449471585, 0.7596054036984262, 0.00962925135441533],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.23206746184632543, 0.7331497981296534, 0.03478274002402117],
                                [0.04852341372444824, 0.043096185009864674, 0.9083804012656871],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.046910077030668074, 0.9411591780771876, 0.011930744892144261],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.04852341372444824, 0.9083804012656872, 0.043096185009864604],
                                [0.9534805494880724, 0.0018099288082827764, 0.04470952170364481],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.953089922969332, 0.04601163860281177, 0.0008984384278562483],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.9534805494880724, 0.04470952170364481, 0.0018099288082827766],
                                [0.7711562691078282, 0.00890360605249313, 0.21994012483967856],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7692346550528416, 0.2263456452399402, 0.004419699707218268],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.7711562691078284, 0.21994012483967856, 0.008903606052493122],
                                [0.5041635672276241, 0.01929147128770986, 0.47654496148466596],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.49999999999999994, 0.4904238227186359, 0.009576177281364125],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.5041635672276241, 0.476544961484666, 0.019291471287709826],
                                [0.23717086534742005, 0.029679336522926647, 0.7331497981296533],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.2307653449471585, 0.7545020001973315, 0.01473265485550998],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.23717086534742005, 0.7331497981296534, 0.02967933652292653],
                                [0.05484658496717598, 0.03677301376713693, 0.9083804012656871],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.046910077030668074, 0.9348360068344599, 0.018253916134872],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.05484658496717598, 0.9083804012656871, 0.036773013767136875],
                                [0.9539362946782857, 0.001354183618069514, 0.04470952170364481],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.953089922969332, 0.045555893412598504, 0.0013541836180695124],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.9539362946782857, 0.04470952170364481, 0.0013541836180695124],
                                [0.7733982222804657, 0.0066616528798556784, 0.21994012483967856],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7692346550528416, 0.22410369206730274, 0.006661652879855695],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.7733982222804658, 0.21994012483967854, 0.006661652879855695],
                                [0.509021214230797, 0.014433824284536989, 0.47654496148466596],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.5, 0.485566175715463, 0.014433824284536975],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.509021214230797, 0.47654496148466596, 0.014433824284536975],
                                [0.24464420618112837, 0.022205995689218327, 0.7331497981296533],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.2307653449471585, 0.7470286593636233, 0.022205995689218255],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.24464420618112837, 0.7331497981296534, 0.022205995689218255],
                                [0.06410613378330843, 0.027513464951004485, 0.9083804012656871],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.046910077030668074, 0.9255764580183274, 0.027513464951004436],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.06410613378330843, 0.9083804012656871, 0.027513464951004436],
                                [0.9543920398684989, 0.0008984384278562518, 0.04470952170364481],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.9530899229693319, 0.04510014822238524, 0.0018099288082827766],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.954392039868499, 0.04470952170364481, 0.0008984384278562485],
                                [0.775640175453103, 0.004419699707218283, 0.21994012483967856],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7692346550528416, 0.22186173889466532, 0.008903606052493122],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.7756401754531033, 0.21994012483967856, 0.004419699707218269],
                                [0.5138788612339699, 0.009576177281364173, 0.47654496148466596],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.5, 0.4807085287122902, 0.019291471287709826],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.5138788612339698, 0.476544961484666, 0.009576177281364126],
                                [0.2521175470148366, 0.014732654855510119, 0.7331497981296533],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.2307653449471585, 0.739555318529915, 0.02967933652292653],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.2521175470148366, 0.7331497981296534, 0.014732654855509982],
                                [0.07336568259944087, 0.01825391613487204, 0.9083804012656871],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.046910077030668074, 0.916316909202195, 0.036773013767136875],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.07336568259944087, 0.9083804012656871, 0.018253916134872004],
                                [0.9547032596631122, 0.000587218633243014, 0.04470952170364481],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.9530899229693319, 0.044788928427772004, 0.002121148602896015],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.9547032596631122, 0.04470952170364482, 0.0005872186332430097],
                                [0.7771711629893494, 0.0028887121709719465, 0.21994012483967856],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7692346550528415, 0.220330751358419, 0.010434593588739449],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.7771711629893494, 0.21994012483967856, 0.002888712170971942],
                                [0.5171960567526404, 0.006258981762693683, 0.47654496148466596],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.5, 0.4773913331936197, 0.022608666806380313],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.5171960567526404, 0.476544961484666, 0.006258981762693638],
                                [0.2572209505159313, 0.009629251354415391, 0.7331497981296533],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.2307653449471585, 0.7344519150288203, 0.03478274002402117],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.2572209505159313, 0.7331497981296534, 0.009629251354415332],
                                [0.07968885384216862, 0.011930744892144296, 0.9083804012656871],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.046910077030668074, 0.9099937379594674, 0.043096185009864604],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.07968885384216862, 0.9083804012656871, 0.011930744892144265],
                                [0.9531883087454855, 0.002102169550869594, 0.04470952170364481],
                                [0.9530899229693319, 0.00010322821990090686, 0.04680684881076711],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9530899229693319, 0.0467084630346135, 0.00020161399605452077],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.9531883087454855, 0.04470952170364481, 0.0021021695508695918],
                                [0.7697186454661836, 0.010341229694137782, 0.21994012483967856],
                                [0.7692346550528415, 0.0005078119091158351, 0.2302575330380426],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7692346550528416, 0.2297735426247005, 0.0009918023224579214],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158174],
                                [0.7697186454661837, 0.21994012483967856, 0.010341229694137775],
                                [0.5010486635535611, 0.02240637496177289, 0.47654496148466596],
                                [0.5, 0.0011002776635116174, 0.4988997223364884],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5, 0.49785105878292724, 0.0021489412170727544],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.5010486635535611, 0.476544961484666, 0.02240637496177286],
                                [0.23237868164093867, 0.034471520229408026, 0.7331497981296533],
                                [0.2307653449471585, 0.001692743417907372, 0.7675419116349341],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.2307653449471585, 0.765928574941154, 0.0033060801116875874],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.23237868164093867, 0.7331497981296534, 0.03447152022940794],
                                [0.04890901836163675, 0.042710580372676166, 0.9083804012656871],
                                [0.046910077030668074, 0.002097327107122293, 0.9509925958622096],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.046910077030668074, 0.948993654531241, 0.004096268438090988],
                                [0.046910077030668074, 0.9509925958622096, 0.0020973271071223014],
                                [0.04890901836163675, 0.9083804012656871, 0.042710580372676124],
                                [0.953573913382674, 0.0017165649136811068, 0.04470952170364481],
                                [0.9530899229693319, 0.00010322821990090686, 0.04680684881076711],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.953089922969332, 0.04632285839742501, 0.0005872186332430094],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.953573913382674, 0.04470952170364481, 0.0017165649136811033],
                                [0.7716155553146976, 0.008444319845623771, 0.21994012483967856],
                                [0.7692346550528415, 0.0005078119091158351, 0.2302575330380426],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7692346550528415, 0.2278766327761865, 0.0028887121709719405],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158174],
                                [0.7716155553146976, 0.2199401248396786, 0.008444319845623756],
                                [0.5051587040991821, 0.018296334416152027, 0.47654496148466596],
                                [0.5, 0.0011002776635116174, 0.4988997223364884],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.49999999999999994, 0.4937410182373064, 0.006258981762693634],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.5051587040991821, 0.476544961484666, 0.01829633441615198],
                                [0.2387018528836664, 0.028148348986680283, 0.7331497981296533],
                                [0.2307653449471585, 0.001692743417907372, 0.7675419116349341],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.2307653449471585, 0.7596054036984262, 0.009629251354415327],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.2387018528836664, 0.7331497981296534, 0.0281483489866802],
                                [0.056743494815689965, 0.03487610391862295, 0.9083804012656871],
                                [0.046910077030668074, 0.002097327107122293, 0.9509925958622096],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.046910077030668074, 0.9411591780771876, 0.011930744892144258],
                                [0.046910077030668074, 0.9509925958622096, 0.0020973271071223014],
                                [0.056743494815689965, 0.9083804012656872, 0.03487610391862285],
                                [0.9541385865228931, 0.0011518917734620535, 0.04470952170364481],
                                [0.9530899229693319, 0.00010322821990090686, 0.04680684881076711],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9530899229693319, 0.045758185257205965, 0.0011518917734620563],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.9541385865228931, 0.04470952170364481, 0.0011518917734620563],
                                [0.7743933591520236, 0.005666516008297845, 0.21994012483967856],
                                [0.7692346550528415, 0.0005078119091158351, 0.2302575330380426],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7692346550528416, 0.2250988289388606, 0.005666516008297848],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158174],
                                [0.7743933591520236, 0.21994012483967856, 0.005666516008297848],
                                [0.5111773804259112, 0.012277658089422827, 0.47654496148466596],
                                [0.5, 0.0011002776635116174, 0.4988997223364884],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5, 0.4877223419105772, 0.012277658089422806],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.5111773804259112, 0.47654496148466596, 0.012277658089422806],
                                [0.24796140169979886, 0.018888800170547837, 0.7331497981296533],
                                [0.2307653449471585, 0.001692743417907372, 0.7675419116349341],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.2307653449471585, 0.7503458548822938, 0.018888800170547764],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.24796140169979886, 0.7331497981296534, 0.018888800170547764],
                                [0.06821617432892935, 0.023403424405383566, 0.9083804012656871],
                                [0.046910077030668074, 0.002097327107122293, 0.9509925958622096],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.046910077030668074, 0.9296864985639484, 0.023403424405383556],
                                [0.046910077030668074, 0.9509925958622096, 0.0020973271071223014],
                                [0.06821617432892935, 0.9083804012656871, 0.023403424405383556],
                                [0.9547032596631122, 0.000587218633243014, 0.04470952170364481],
                                [0.9530899229693319, 0.00010322821990090686, 0.04680684881076711],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9530899229693319, 0.04519351211698691, 0.0017165649136811033],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.9547032596631122, 0.04470952170364482, 0.0005872186332430094],
                                [0.7771711629893494, 0.0028887121709719465, 0.21994012483967856],
                                [0.7692346550528415, 0.0005078119091158351, 0.2302575330380426],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7692346550528415, 0.2223210251015347, 0.008444319845623756],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158174],
                                [0.7771711629893494, 0.21994012483967856, 0.0028887121709719405],
                                [0.5171960567526404, 0.006258981762693683, 0.47654496148466596],
                                [0.5, 0.0011002776635116174, 0.4988997223364884],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5, 0.48170366558384803, 0.01829633441615198],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.5171960567526404, 0.476544961484666, 0.006258981762693634],
                                [0.2572209505159313, 0.009629251354415391, 0.7331497981296533],
                                [0.2307653449471585, 0.001692743417907372, 0.7675419116349341],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.2307653449471585, 0.7410863060661613, 0.0281483489866802],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.2572209505159313, 0.7331497981296534, 0.009629251354415327],
                                [0.07968885384216862, 0.011930744892144296, 0.9083804012656871],
                                [0.046910077030668074, 0.002097327107122293, 0.9509925958622096],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.046910077030668074, 0.9182138190507091, 0.03487610391862285],
                                [0.046910077030668074, 0.9509925958622096, 0.0020973271071223014],
                                [0.07968885384216862, 0.9083804012656871, 0.011930744892144258],
                                [0.9550888643003006, 0.0002016139960545199, 0.04470952170364481],
                                [0.9530899229693319, 0.00010322821990090686, 0.04680684881076711],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9530899229693319, 0.044807907479798424, 0.0021021695508695918],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.9550888643003006, 0.04470952170364481, 0.00020161399605452102],
                                [0.7790680728378635, 0.0009918023224579076, 0.21994012483967856],
                                [0.7692346550528415, 0.0005078119091158351, 0.2302575330380426],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7692346550528416, 0.22042411525302066, 0.010341229694137774],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158174],
                                [0.7790680728378636, 0.21994012483967854, 0.0009918023224579225],
                                [0.5213060972982613, 0.002148941217072764, 0.47654496148466596],
                                [0.5, 0.0011002776635116174, 0.4988997223364884],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.49999999999999994, 0.47759362503822717, 0.022406374961772856],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.5213060972982613, 0.47654496148466596, 0.002148941217072757],
                                [0.26354412175865904, 0.003306080111687648, 0.7331497981296533],
                                [0.2307653449471585, 0.001692743417907372, 0.7675419116349341],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.2307653449471585, 0.7347631348234336, 0.034471520229407936],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.26354412175865904, 0.7331497981296534, 0.0033060801116875913],
                                [0.08752333029622195, 0.004096268438090966, 0.9083804012656871],
                                [0.046910077030668074, 0.002097327107122293, 0.9509925958622096],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.046910077030668074, 0.9103793425966558, 0.04271058037267612],
                                [0.046910077030668074, 0.9509925958622096, 0.0020973271071223014],
                                [0.08752333029622195, 0.9083804012656871, 0.004096268438090992],
                                [0.9531137444651057, 0.010801398611706169, 0.036084856923188136],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.953089922969332, 0.03656884733653024, 0.010341229694137775],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9531137444651057, 0.036084856923188136, 0.010801398611706167],
                                [0.7693518404432169, 0.05313545903820566, 0.1775127005185774],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7692346550528415, 0.17989360078043354, 0.0508717441667249],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.7693518404432169, 0.17751270051857743, 0.05313545903820564],
                                [0.5002539059545579, 0.11512876651902132, 0.38461732752642075],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5, 0.3897760316256028, 0.11022396837439719],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.500253905954558, 0.38461732752642075, 0.11512876651902132],
                                [0.23115597146589895, 0.17712207399983704, 0.591721954534264],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.2307653449471585, 0.599658462470772, 0.16957619258206946],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.23115597146589906, 0.591721954534264, 0.17712207399983698],
                                [0.0473940674440102, 0.2194561344263365, 0.7331497981296533],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.046910077030668074, 0.7429832159146753, 0.2101067070546566],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.0473940674440102, 0.7331497981296533, 0.21945613442633646],
                                [0.9532071083597073, 0.010708034717104492, 0.036084856923188136],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.953089922969332, 0.036475483441928566, 0.010434593588739449],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9532071083597073, 0.036084856923188136, 0.010708034717104494],
                                [0.7698111266500863, 0.0526761728313363, 0.1775127005185774],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7692346550528415, 0.17943431457356418, 0.051331030373594266],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.7698111266500862, 0.17751270051857743, 0.05267617283133628],
                                [0.5012490428261158, 0.11413362964746349, 0.38461732752642075],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5, 0.388780894754045, 0.11121910524595503],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5012490428261158, 0.38461732752642075, 0.11413362964746347],
                                [0.2326869590021453, 0.17559108646359067, 0.591721954534264],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.2307653449471585, 0.5981274749345257, 0.1711071801183158],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.2326869590021453, 0.591721954534264, 0.17559108646359065],
                                [0.049290977292524185, 0.2175592245778225, 0.7331497981296533],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.046910077030668074, 0.7410863060661613, 0.2120036169031706],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.049290977292524296, 0.7331497981296533, 0.21755922457782245],
                                [0.9533438289238898, 0.010571314152921972, 0.036084856923188136],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.9530899229693319, 0.036338762877746046, 0.01057131415292197],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9533438289238898, 0.036084856923188136, 0.01057131415292197],
                                [0.7704836978789573, 0.05200360160246528, 0.1775127005185774],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7692346550528415, 0.1787617433446932, 0.05200360160246527],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.7704836978789573, 0.17751270051857743, 0.05200360160246527],
                                [0.50270630502687, 0.11267636744670928, 0.38461732752642075],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5, 0.3873236325532907, 0.11267636744670925],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.50270630502687, 0.38461732752642075, 0.11267636744670925],
                                [0.23492891217478273, 0.17334913329095325, 0.591721954534264],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.2307653449471585, 0.5958855217618882, 0.17334913329095322],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.23492891217478273, 0.591721954534264, 0.17334913329095322],
                                [0.05206878112985014, 0.21478142074049655, 0.7331497981296533],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.046910077030668074, 0.7383085022288354, 0.21478142074049653],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.05206878112985014, 0.7331497981296533, 0.21478142074049653],
                                [0.9534805494880724, 0.010434593588739452, 0.036084856923188136],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.953089922969332, 0.036202042313563526, 0.010708034717104494],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9534805494880725, 0.036084856923188136, 0.010434593588739449],
                                [0.7711562691078283, 0.051331030373594294, 0.1775127005185774],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7692346550528415, 0.17808917211582218, 0.05267617283133628],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.7711562691078282, 0.17751270051857743, 0.051331030373594266],
                                [0.5041635672276241, 0.11121910524595507, 0.38461732752642075],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5, 0.3858663703525365, 0.11413362964746347],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5041635672276241, 0.3846173275264208, 0.11121910524595503],
                                [0.23717086534742005, 0.17110718011831594, 0.591721954534264],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.2307653449471585, 0.5936435685892508, 0.17559108646359065],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.23717086534742005, 0.5917219545342641, 0.1711071801183158],
                                [0.05484658496717598, 0.2120036169031707, 0.7331497981296533],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.046910077030668074, 0.7355306983915095, 0.21755922457782245],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.05484658496717598, 0.7331497981296534, 0.2120036169031706],
                                [0.953573913382674, 0.010341229694137782, 0.036084856923188136],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.953089922969332, 0.03610867841896185, 0.010801398611706167],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.953573913382674, 0.03608485692318814, 0.010341229694137775],
                                [0.7716155553146977, 0.050871744166724936, 0.1775127005185774],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7692346550528416, 0.1776298859089528, 0.05313545903820564],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.7716155553146977, 0.17751270051857743, 0.0508717441667249],
                                [0.5051587040991821, 0.11022396837439724, 0.38461732752642075],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5, 0.3848712334809787, 0.11512876651902132],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5051587040991821, 0.3846173275264208, 0.11022396837439719],
                                [0.2387018528836664, 0.16957619258206957, 0.591721954534264],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.2307653449471585, 0.5921125810530046, 0.17712207399983698],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.2387018528836664, 0.5917219545342641, 0.16957619258206946],
                                [0.056743494815689965, 0.21010670705465673, 0.7331497981296533],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.046910077030668074, 0.7336337885429954, 0.21945613442633646],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.056743494815689965, 0.7331497981296534, 0.2101067070546566],
                                [0.9532071083597073, 0.010708034717104492, 0.036084856923188136],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9530899229693319, 0.03846575718504426, 0.008444319845623756],
                                [0.953089922969332, 0.03858294257541965, 0.00832713445524837],
                                [0.9532071083597073, 0.036084856923188136, 0.010708034717104494],
                                [0.7698111266500863, 0.0526761728313363, 0.1775127005185774],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7692346550528415, 0.18922509378224256, 0.0415402511649159],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.7698111266500862, 0.17751270051857743, 0.05267617283133628],
                                [0.5012490428261158, 0.11413362964746349, 0.38461732752642075],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5, 0.40999460691459555, 0.09000539308540446],
                                [0.5, 0.41124364974071126, 0.08875635025928871],
                                [0.5012490428261158, 0.38461732752642075, 0.11413362964746347],
                                [0.2326869590021453, 0.17559108646359067, 0.591721954534264],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.2307653449471585, 0.6307641200469485, 0.13847053500589301],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090626],
                                [0.2326869590021453, 0.591721954534264, 0.17559108646359065],
                                [0.049290977292524185, 0.2175592245778225, 0.7331497981296533],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.046910077030668074, 0.7815234566441468, 0.17156646632518516],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.049290977292524296, 0.7331497981296533, 0.21755922457782245],
                                [0.9536663945665766, 0.010248748510235134, 0.036084856923188136],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.953089922969332, 0.038006470978174896, 0.008903606052493122],
                                [0.953089922969332, 0.03858294257541965, 0.00832713445524837],
                                [0.9536663945665766, 0.03608485692318814, 0.010248748510235127],
                                [0.7720704991914784, 0.050416800289944164, 0.1775127005185774],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7692346550528415, 0.18696572124085042, 0.043799623706308036],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.7720704991914784, 0.17751270051857743, 0.05041680028994414],
                                [0.5061444324304549, 0.10923824004312432, 0.38461732752642075],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5, 0.40509921731025633, 0.09490078268974365],
                                [0.5, 0.41124364974071126, 0.08875635025928871],
                                [0.5061444324304549, 0.3846173275264208, 0.10923824004312428],
                                [0.24021836566943144, 0.16805967979630454, 0.591721954534264],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.2307653449471585, 0.6232327133796622, 0.14600194167317926],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090626],
                                [0.24021836566943144, 0.5917219545342641, 0.1680596797963044],
                                [0.05862247029433321, 0.2082277315760135, 0.7331497981296533],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.046910077030668074, 0.7721919636423378, 0.18089795932699418],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.05862247029433321, 0.7331497981296533, 0.20822773157601343],
                                [0.9543389657954476, 0.009576177281364125, 0.036084856923188136],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9530899229693319, 0.037333899749303893, 0.009576177281364125],
                                [0.953089922969332, 0.03858294257541965, 0.00832713445524837],
                                [0.9543389657954477, 0.036084856923188136, 0.009576177281364125],
                                [0.7753790874832965, 0.04710821199812612, 0.1775127005185774],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7692346550528415, 0.18365713294903235, 0.047108211998126086],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.7753790874832964, 0.17751270051857743, 0.047108211998126086],
                                [0.5133131611071453, 0.102069511366434, 0.38461732752642075],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5, 0.39793048863356606, 0.10206951136643397],
                                [0.5, 0.41124364974071126, 0.08875635025928871],
                                [0.5133131611071453, 0.38461732752642075, 0.10206951136643397],
                                [0.2512472347309941, 0.1570308107347419, 0.591721954534264],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.2307653449471585, 0.6122038443180997, 0.15703081073474184],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090626],
                                [0.2512472347309942, 0.591721954534264, 0.15703081073474184],
                                [0.07228735641884287, 0.19456284545150382, 0.7331497981296533],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.046910077030668074, 0.7585270775178281, 0.1945628454515038],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.07228735641884287, 0.7331497981296533, 0.1945628454515038],
                                [0.9550115370243187, 0.008903606052493122, 0.036084856923188136],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9530899229693319, 0.03666132852043289, 0.010248748510235127],
                                [0.953089922969332, 0.03858294257541965, 0.00832713445524837],
                                [0.9550115370243188, 0.036084856923188136, 0.008903606052493122],
                                [0.7786876757751146, 0.04379962370630805, 0.1775127005185774],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7692346550528416, 0.1803485446572143, 0.05041680028994414],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.7786876757751144, 0.17751270051857743, 0.043799623706308036],
                                [0.5204818897838356, 0.09490078268974367, 0.38461732752642075],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.49999999999999994, 0.39076175995687573, 0.10923824004312428],
                                [0.5, 0.41124364974071126, 0.08875635025928871],
                                [0.5204818897838356, 0.38461732752642075, 0.09490078268974365],
                                [0.2622761037925566, 0.14600194167317937, 0.591721954534264],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.2307653449471585, 0.6011749752565371, 0.1680596797963044],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090626],
                                [0.2622761037925566, 0.5917219545342641, 0.14600194167317926],
                                [0.08595224254335243, 0.18089795932699426, 0.7331497981296533],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.046910077030668074, 0.7448621913933184, 0.20822773157601343],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.08595224254335243, 0.7331497981296534, 0.18089795932699418],
                                [0.955470823231188, 0.008444319845623757, 0.036084856923188136],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.953089922969332, 0.036202042313563526, 0.010708034717104494],
                                [0.953089922969332, 0.03858294257541965, 0.00832713445524837],
                                [0.9554708232311881, 0.036084856923188136, 0.008444319845623756],
                                [0.7809470483165066, 0.04154025116491594, 0.1775127005185774],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7692346550528415, 0.17808917211582218, 0.05267617283133628],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.7809470483165066, 0.17751270051857743, 0.0415402511649159],
                                [0.5253772793881748, 0.0900053930854045, 0.38461732752642075],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5, 0.3858663703525365, 0.11413362964746347],
                                [0.5, 0.41124364974071126, 0.08875635025928871],
                                [0.5253772793881748, 0.3846173275264208, 0.09000539308540446],
                                [0.26980751045984286, 0.13847053500589313, 0.591721954534264],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.2307653449471585, 0.5936435685892508, 0.17559108646359065],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090626],
                                [0.26980751045984286, 0.5917219545342641, 0.13847053500589301],
                                [0.09528373554516145, 0.17156646632518524, 0.7331497981296533],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.046910077030668074, 0.7355306983915095, 0.21755922457782245],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.09528373554516145, 0.7331497981296534, 0.17156646632518516],
                                [0.9533438289238898, 0.010571314152921972, 0.036084856923188136],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.953089922969332, 0.04124356102237017, 0.005666516008297848],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9533438289238898, 0.036084856923188136, 0.01057131415292197],
                                [0.7704836978789573, 0.05200360160246528, 0.1775127005185774],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7692346550528416, 0.20288997990675217, 0.027875365040406268],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7704836978789573, 0.17751270051857743, 0.05200360160246527],
                                [0.50270630502687, 0.11267636744670928, 0.38461732752642075],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5, 0.4396023587363404, 0.06039764126365958],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.50270630502687, 0.38461732752642075, 0.11267636744670925],
                                [0.23492891217478273, 0.17334913329095325, 0.591721954534264],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.2307653449471585, 0.6763147375659286, 0.09291991748691289],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.23492891217478273, 0.591721954534264, 0.17334913329095322],
                                [0.05206878112985014, 0.21478142074049655, 0.7331497981296533],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.046910077030668074, 0.8379611564503107, 0.1151287665190213],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.05206878112985014, 0.7331497981296533, 0.21478142074049653],
                                [0.9543389657954476, 0.009576177281364125, 0.036084856923188136],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.953089922969332, 0.040248424150812326, 0.006661652879855695],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9543389657954477, 0.036084856923188136, 0.009576177281364125],
                                [0.7753790874832965, 0.04710821199812612, 0.1775127005185774],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7692346550528415, 0.197994590302413, 0.03277075464474545],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7753790874832964, 0.17751270051857743, 0.047108211998126086],
                                [0.5133131611071453, 0.102069511366434, 0.38461732752642075],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5, 0.4289955026560651, 0.07100449734393487],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5133131611071453, 0.38461732752642075, 0.10206951136643397],
                                [0.2512472347309941, 0.1570308107347419, 0.591721954534264],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.2307653449471585, 0.6599964150097173, 0.10923824004312427],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.2512472347309942, 0.591721954534264, 0.15703081073474184],
                                [0.07228735641884287, 0.19456284545150382, 0.7331497981296533],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.046910077030668074, 0.8177425811613179, 0.13534734180801403],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.07228735641884287, 0.7331497981296533, 0.1945628454515038],
                                [0.9557962279962019, 0.008118915080609912, 0.036084856923188136],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.9530899229693319, 0.038791161950058106, 0.008118915080609908],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.955796227996202, 0.036084856923188136, 0.008118915080609908],
                                [0.7825478161599868, 0.03993948332143579, 0.1775127005185774],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7692346550528416, 0.19082586162572268, 0.039939483321435765],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7825478161599868, 0.17751270051857743, 0.039939483321435765],
                                [0.5288456681183948, 0.08653700435518447, 0.38461732752642075],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5, 0.4134629956448156, 0.08653700435518441],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5288456681183948, 0.3846173275264208, 0.08653700435518441],
                                [0.27514352007680287, 0.1331345253889331, 0.591721954534264],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.2307653449471585, 0.6361001296639084, 0.13313452538893306],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.27514352007680287, 0.591721954534264, 0.13313452538893306],
                                [0.10189510824058767, 0.16495509362975902, 0.7331497981296533],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.046910077030668074, 0.788134829339573, 0.1649550936297589],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.10189510824058767, 0.7331497981296534, 0.1649550936297589],
                                [0.9572534901969562, 0.006661652879855699, 0.036084856923188136],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.9530899229693319, 0.037333899749303893, 0.009576177281364125],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9572534901969563, 0.036084856923188136, 0.006661652879855696],
                                [0.7897165448366772, 0.032770754644745465, 0.1775127005185774],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7692346550528415, 0.18365713294903235, 0.047108211998126086],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7897165448366772, 0.1775127005185774, 0.03277075464474546],
                                [0.5443781751296444, 0.07100449734393488, 0.38461732752642075],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5, 0.39793048863356606, 0.10206951136643397],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5443781751296444, 0.38461732752642075, 0.07100449734393488],
                                [0.29903980542261166, 0.10923824004312432, 0.591721954534264],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.2307653449471585, 0.6122038443180997, 0.15703081073474184],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.29903980542261166, 0.591721954534264, 0.1092382400431243],
                                [0.13150286006233258, 0.1353473418080141, 0.7331497981296533],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.046910077030668074, 0.7585270775178281, 0.1945628454515038],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.1315028600623327, 0.7331497981296533, 0.13534734180801405],
                                [0.958248627068514, 0.005666516008297852, 0.036084856923188136],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.9530899229693319, 0.036338762877746046, 0.01057131415292197],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.958248627068514, 0.036084856923188136, 0.005666516008297848],
                                [0.7946119344410163, 0.027875365040406275, 0.1775127005185774],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7692346550528415, 0.1787617433446932, 0.05200360160246527],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7946119344410164, 0.1775127005185774, 0.027875365040406268],
                                [0.5549850312099196, 0.060397641263659596, 0.38461732752642075],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5, 0.3873236325532907, 0.11267636744670925],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5549850312099197, 0.38461732752642075, 0.06039764126365958],
                                [0.315358127978823, 0.09291991748691297, 0.591721954534264],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.2307653449471585, 0.5958855217618882, 0.17334913329095322],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.315358127978823, 0.5917219545342641, 0.09291991748691289],
                                [0.15172143535132532, 0.11512876651902137, 0.7331497981296533],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.046910077030668074, 0.7383085022288354, 0.21478142074049653],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.15172143535132532, 0.7331497981296534, 0.1151287665190213],
                                [0.9534805494880724, 0.010434593588739452, 0.036084856923188136],
                                [0.9530899229693319, 0.002498085652231516, 0.0444119913784365],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.9530899229693319, 0.04402136485969608, 0.0028887121709719418],
                                [0.9530899229693319, 0.04441199137843651, 0.002498085652231511],
                                [0.9534805494880725, 0.036084856923188136, 0.010434593588739449],
                                [0.7711562691078283, 0.051331030373594294, 0.1775127005185774],
                                [0.7692346550528415, 0.01228886486090991, 0.21847648008624854],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.7692346550528415, 0.2165548660312618, 0.014210478915896638],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909882],
                                [0.7711562691078282, 0.17751270051857743, 0.051331030373594266],
                                [0.5041635672276241, 0.11121910524595507, 0.38461732752642075],
                                [0.5, 0.026626322214290565, 0.47337367778570943],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.49999999999999994, 0.4692101105580853, 0.030789889441914707],
                                [0.5, 0.4733736777857095, 0.026626322214290524],
                                [0.5041635672276241, 0.3846173275264208, 0.11121910524595503],
                                [0.23717086534742005, 0.17110718011831594, 0.591721954534264],
                                [0.2307653449471585, 0.04096377956767128, 0.7282708754851702],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.2307653449471585, 0.7218653550849087, 0.04736929996793277],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671166],
                                [0.23717086534742005, 0.5917219545342641, 0.1711071801183158],
                                [0.05484658496717598, 0.2120036169031707, 0.7331497981296533],
                                [0.046910077030668074, 0.0507545587763496, 0.9023353641929823],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.046910077030668074, 0.8943988562564744, 0.05869106671285747],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634953],
                                [0.05484658496717598, 0.7331497981296534, 0.2120036169031706],
                                [0.9550115370243187, 0.008903606052493122, 0.036084856923188136],
                                [0.9530899229693319, 0.002498085652231516, 0.0444119913784365],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.953089922969332, 0.04249037732344975, 0.004419699707218268],
                                [0.9530899229693319, 0.04441199137843651, 0.002498085652231511],
                                [0.9550115370243188, 0.036084856923188136, 0.008903606052493122],
                                [0.7786876757751146, 0.04379962370630805, 0.1775127005185774],
                                [0.7692346550528415, 0.01228886486090991, 0.21847648008624854],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.7692346550528415, 0.20902345936397557, 0.021741885583182873],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909882],
                                [0.7786876757751144, 0.17751270051857743, 0.043799623706308036],
                                [0.5204818897838356, 0.09490078268974367, 0.38461732752642075],
                                [0.5, 0.026626322214290565, 0.47337367778570943],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5, 0.4528917880018739, 0.04710821199812609],
                                [0.5, 0.4733736777857095, 0.026626322214290524],
                                [0.5204818897838356, 0.38461732752642075, 0.09490078268974365],
                                [0.2622761037925566, 0.14600194167317937, 0.591721954534264],
                                [0.2307653449471585, 0.04096377956767128, 0.7282708754851702],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.2307653449471585, 0.6967601166397722, 0.0724745384130693],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671166],
                                [0.2622761037925566, 0.5917219545342641, 0.14600194167317926],
                                [0.08595224254335243, 0.18089795932699426, 0.7331497981296533],
                                [0.046910077030668074, 0.0507545587763496, 0.9023353641929823],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.046910077030668074, 0.863293198680298, 0.08979672428903392],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634953],
                                [0.08595224254335243, 0.7331497981296534, 0.18089795932699418],
                                [0.9572534901969562, 0.006661652879855699, 0.036084856923188136],
                                [0.9530899229693319, 0.002498085652231516, 0.0444119913784365],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.953089922969332, 0.040248424150812326, 0.006661652879855696],
                                [0.9530899229693319, 0.04441199137843651, 0.002498085652231511],
                                [0.9572534901969563, 0.036084856923188136, 0.006661652879855696],
                                [0.7897165448366772, 0.032770754644745465, 0.1775127005185774],
                                [0.7692346550528415, 0.01228886486090991, 0.21847648008624854],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.7692346550528416, 0.19799459030241298, 0.03277075464474546],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909882],
                                [0.7897165448366772, 0.1775127005185774, 0.03277075464474546],
                                [0.5443781751296444, 0.07100449734393488, 0.38461732752642075],
                                [0.5, 0.026626322214290565, 0.47337367778570943],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5, 0.4289955026560651, 0.07100449734393488],
                                [0.5, 0.4733736777857095, 0.026626322214290524],
                                [0.5443781751296444, 0.38461732752642075, 0.07100449734393488],
                                [0.29903980542261166, 0.10923824004312432, 0.591721954534264],
                                [0.2307653449471585, 0.04096377956767128, 0.7282708754851702],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.2307653449471585, 0.6599964150097172, 0.1092382400431243],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671166],
                                [0.29903980542261166, 0.591721954534264, 0.1092382400431243],
                                [0.13150286006233258, 0.1353473418080141, 0.7331497981296533],
                                [0.046910077030668074, 0.0507545587763496, 0.9023353641929823],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.046910077030668074, 0.8177425811613179, 0.13534734180801405],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634953],
                                [0.1315028600623327, 0.7331497981296533, 0.13534734180801405],
                                [0.9594954433695936, 0.004419699707218276, 0.036084856923188136],
                                [0.9530899229693319, 0.002498085652231516, 0.0444119913784365],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.953089922969332, 0.038006470978174896, 0.00890360605249312],
                                [0.9530899229693319, 0.04441199137843651, 0.002498085652231511],
                                [0.9594954433695936, 0.03608485692318814, 0.00441969970721827],
                                [0.8007454138982397, 0.021741885583182907, 0.1775127005185774],
                                [0.7692346550528415, 0.01228886486090991, 0.21847648008624854],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.7692346550528415, 0.18696572124085042, 0.04379962370630803],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909882],
                                [0.8007454138982397, 0.17751270051857743, 0.02174188558318288],
                                [0.568274460475453, 0.04710821199812615, 0.38461732752642075],
                                [0.5, 0.026626322214290565, 0.47337367778570943],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5, 0.40509921731025633, 0.09490078268974364],
                                [0.5, 0.4733736777857095, 0.026626322214290524],
                                [0.568274460475453, 0.3846173275264208, 0.04710821199812611],
                                [0.3358035070526666, 0.07247453841306939, 0.591721954534264],
                                [0.2307653449471585, 0.04096377956767128, 0.7282708754851702],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.2307653449471585, 0.6232327133796622, 0.14600194167317923],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671166],
                                [0.3358035070526666, 0.591721954534264, 0.07247453841306933],
                                [0.17705347758131262, 0.08979672428903407, 0.7331497981296533],
                                [0.046910077030668074, 0.0507545587763496, 0.9023353641929823],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.046910077030668074, 0.7721919636423378, 0.18089795932699415],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634953],
                                [0.17705347758131262, 0.7331497981296534, 0.08979672428903394],
                                [0.9610264309058398, 0.0028887121709719465, 0.036084856923188136],
                                [0.9530899229693319, 0.002498085652231516, 0.0444119913784365],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.953089922969332, 0.036475483441928566, 0.010434593588739449],
                                [0.9530899229693319, 0.04441199137843651, 0.002498085652231511],
                                [0.9610264309058398, 0.03608485692318814, 0.002888712170971942],
                                [0.808276820565526, 0.014210478915896663, 0.1775127005185774],
                                [0.7692346550528415, 0.01228886486090991, 0.21847648008624854],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.7692346550528415, 0.17943431457356418, 0.051331030373594266],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909882],
                                [0.808276820565526, 0.17751270051857743, 0.014210478915896642],
                                [0.5845927830316645, 0.030789889441914742, 0.38461732752642075],
                                [0.5, 0.026626322214290565, 0.47337367778570943],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5, 0.388780894754045, 0.11121910524595503],
                                [0.5, 0.4733736777857095, 0.026626322214290524],
                                [0.5845927830316645, 0.38461732752642075, 0.030789889441914714],
                                [0.36090874549780316, 0.04736929996793282, 0.591721954534264],
                                [0.2307653449471585, 0.04096377956767128, 0.7282708754851702],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.2307653449471585, 0.5981274749345257, 0.1711071801183158],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671166],
                                [0.36090874549780316, 0.591721954534264, 0.047369299967932786],
                                [0.20815913515748918, 0.05869106671285751, 0.7331497981296533],
                                [0.046910077030668074, 0.0507545587763496, 0.9023353641929823],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.046910077030668074, 0.7410863060661613, 0.2120036169031706],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634953],
                                [0.20815913515748918, 0.7331497981296533, 0.05869106671285748],
                                [0.953573913382674, 0.010341229694137782, 0.036084856923188136],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.953089922969332, 0.0459182747082101, 0.0009918023224579214],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.953573913382674, 0.03608485692318814, 0.010341229694137775],
                                [0.7716155553146977, 0.050871744166724936, 0.1775127005185774],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.7692346550528415, 0.2258863590330708, 0.004878985914087634],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.7716155553146977, 0.17751270051857743, 0.0508717441667249],
                                [0.5051587040991821, 0.11022396837439724, 0.38461732752642075],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.49999999999999994, 0.48942868584707805, 0.010571314152921972],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.5051587040991821, 0.3846173275264208, 0.11022396837439719],
                                [0.2387018528836664, 0.16957619258206957, 0.591721954534264],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.2307653449471585, 0.7529710126610852, 0.01626364239175631],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.2387018528836664, 0.5917219545342641, 0.16957619258206946],
                                [0.056743494815689965, 0.21010670705465673, 0.7331497981296533],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.046910077030668074, 0.9329390969859459, 0.020150825983386023],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.056743494815689965, 0.7331497981296534, 0.2101067070546566],
                                [0.955470823231188, 0.008444319845623757, 0.036084856923188136],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.9530899229693319, 0.04402136485969608, 0.002888712170971941],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.9554708232311881, 0.036084856923188136, 0.008444319845623756],
                                [0.7809470483165066, 0.04154025116491594, 0.1775127005185774],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.7692346550528415, 0.2165548660312618, 0.014210478915896635],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.7809470483165066, 0.17751270051857743, 0.0415402511649159],
                                [0.5253772793881748, 0.0900053930854045, 0.38461732752642075],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.49999999999999994, 0.4692101105580853, 0.0307898894419147],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.5253772793881748, 0.3846173275264208, 0.09000539308540446],
                                [0.26980751045984286, 0.13847053500589313, 0.591721954534264],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.2307653449471585, 0.7218653550849088, 0.04736929996793276],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.26980751045984286, 0.5917219545342641, 0.13847053500589301],
                                [0.09528373554516145, 0.17156646632518524, 0.7331497981296533],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.046910077030668074, 0.8943988562564744, 0.058691066712857454],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.09528373554516145, 0.7331497981296534, 0.17156646632518516],
                                [0.958248627068514, 0.005666516008297852, 0.036084856923188136],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.953089922969332, 0.04124356102237017, 0.005666516008297848],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.958248627068514, 0.036084856923188136, 0.005666516008297848],
                                [0.7946119344410163, 0.027875365040406275, 0.1775127005185774],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.7692346550528416, 0.20288997990675217, 0.027875365040406268],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.7946119344410164, 0.1775127005185774, 0.027875365040406268],
                                [0.5549850312099196, 0.060397641263659596, 0.38461732752642075],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.5, 0.4396023587363404, 0.06039764126365958],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.5549850312099197, 0.38461732752642075, 0.06039764126365958],
                                [0.315358127978823, 0.09291991748691297, 0.591721954534264],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.2307653449471585, 0.6763147375659286, 0.09291991748691289],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.315358127978823, 0.5917219545342641, 0.09291991748691289],
                                [0.15172143535132532, 0.11512876651902137, 0.7331497981296533],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.046910077030668074, 0.8379611564503107, 0.1151287665190213],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.15172143535132532, 0.7331497981296534, 0.1151287665190213],
                                [0.9610264309058398, 0.0028887121709719465, 0.036084856923188136],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.9530899229693319, 0.03846575718504426, 0.008444319845623756],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.9610264309058398, 0.03608485692318814, 0.002888712170971941],
                                [0.808276820565526, 0.014210478915896663, 0.1775127005185774],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.7692346550528415, 0.18922509378224256, 0.0415402511649159],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.808276820565526, 0.17751270051857743, 0.014210478915896635],
                                [0.5845927830316645, 0.030789889441914742, 0.38461732752642075],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.5, 0.40999460691459555, 0.09000539308540446],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.5845927830316644, 0.3846173275264208, 0.0307898894419147],
                                [0.36090874549780316, 0.04736929996793282, 0.591721954534264],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.2307653449471585, 0.6307641200469485, 0.13847053500589301],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.36090874549780316, 0.5917219545342641, 0.04736929996793276],
                                [0.20815913515748918, 0.05869106671285751, 0.7331497981296533],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.046910077030668074, 0.7815234566441468, 0.17156646632518516],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.20815913515748918, 0.7331497981296533, 0.058691066712857454],
                                [0.9629233407543539, 0.0009918023224579284, 0.036084856923188136],
                                [0.9530899229693319, 0.0005078119091158143, 0.046402265121552204],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.953089922969332, 0.03656884733653024, 0.010341229694137775],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158176],
                                [0.9629233407543539, 0.03608485692318814, 0.000991802322457922],
                                [0.817608313567335, 0.004878985914087669, 0.1775127005185774],
                                [0.7692346550528415, 0.002498085652231502, 0.22826725929492694],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.7692346550528415, 0.17989360078043354, 0.0508717441667249],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.8176083135673349, 0.17751270051857743, 0.004878985914087637],
                                [0.6048113583206572, 0.010571314152922007, 0.38461732752642075],
                                [0.5, 0.005412610053739941, 0.49458738994626006],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.5, 0.3897760316256028, 0.11022396837439719],
                                [0.5, 0.49458738994626006, 0.005412610053739941],
                                [0.6048113583206572, 0.38461732752642075, 0.010571314152921979],
                                [0.3920144030739796, 0.016263642391756372, 0.591721954534264],
                                [0.2307653449471585, 0.008327134455248353, 0.7609075205975931],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.2307653449471585, 0.599658462470772, 0.16957619258206946],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248372],
                                [0.3920144030739796, 0.591721954534264, 0.01626364239175632],
                                [0.24669937588696056, 0.020150825983386134, 0.7331497981296533],
                                [0.046910077030668074, 0.01031740819836402, 0.9427725147709679],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.046910077030668074, 0.7429832159146753, 0.2101067070546566],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364065],
                                [0.24669937588696056, 0.7331497981296534, 0.020150825983386033],
                                [0.9531415370792824, 0.02340342440538356, 0.02345503851533401],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9530899229693319, 0.02450370206889516, 0.02240637496177286],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9531415370792824, 0.023455038515334013, 0.023403424405383556],
                                [0.7694885610073994, 0.11512876651902132, 0.11538267247357922],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7692346550528415, 0.12054137657276126, 0.11022396837439719],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7694885610073995, 0.11538267247357924, 0.1151287665190213],
                                [0.5005501388317558, 0.2494498611682442, 0.25],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.5, 0.2611773804259112, 0.2388226195740888],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5005501388317558, 0.25, 0.2494498611682442],
                                [0.23161171665611224, 0.383770955817467, 0.38461732752642075],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.23076534494715856, 0.40181338427906116, 0.36742127077378034],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2316117166561122, 0.3846173275264207, 0.38377095581746706],
                                [0.04795874058422922, 0.4754962979311048, 0.47654496148466596],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.046910077030668074, 0.49785105878292724, 0.4552388641864047],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.04795874058422922, 0.47654496148466596, 0.4754962979311048],
                                [0.9533438289238899, 0.0232011325607761, 0.02345503851533401],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.953089922969332, 0.024301410224287705, 0.022608666806380313],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9533438289238899, 0.023455038515334006, 0.023201132560776102],
                                [0.7704836978789573, 0.11413362964746346, 0.11538267247357922],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7692346550528416, 0.11954623970120341, 0.11121910524595503],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7704836978789573, 0.11538267247357921, 0.11413362964746347],
                                [0.50270630502687, 0.24729369497313003, 0.25],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.5, 0.25902121423079705, 0.24097878576920295],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.50270630502687, 0.25, 0.24729369497313003],
                                [0.23492891217478273, 0.3804537602987965, 0.38461732752642075],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.23076534494715845, 0.39849618876039067, 0.37073846629245083],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2349289121747828, 0.3846173275264207, 0.3804537602987966],
                                [0.05206878112985014, 0.4713862573854839, 0.47654496148466596],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.04691007703066802, 0.4937410182373064, 0.45934890473202555],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.052068781129850195, 0.4765449614846659, 0.47138625738548395],
                                [0.9536400618010877, 0.022904899683578207, 0.02345503851533401],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9530899229693319, 0.02400517734708981, 0.022904899683578207],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9536400618010877, 0.02345503851533401, 0.022904899683578207],
                                [0.7719409600797115, 0.11267636744670925, 0.11538267247357922],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7692346550528415, 0.1180889775004492, 0.11267636744670925],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7719409600797115, 0.11538267247357922, 0.11267636744670925],
                                [0.5058637596288336, 0.2441362403711665, 0.25],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.5, 0.2558637596288335, 0.2441362403711665],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5058637596288336, 0.25, 0.2441362403711665],
                                [0.23978655917795555, 0.3755961132956237, 0.38461732752642075],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.2307653449471585, 0.3936385417572178, 0.3755961132956237],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.23978655917795555, 0.38461732752642075, 0.3755961132956237],
                                [0.05808745745657928, 0.46536758105875475, 0.47654496148466596],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.046910077030668074, 0.4877223419105772, 0.46536758105875475],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.05808745745657928, 0.47654496148466596, 0.46536758105875475],
                                [0.9539362946782857, 0.022608666806380316, 0.02345503851533401],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.953089922969332, 0.023708944469891916, 0.023201132560776102],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9539362946782857, 0.023455038515334013, 0.022608666806380313],
                                [0.7733982222804657, 0.11121910524595502, 0.11538267247357922],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7692346550528416, 0.11663171529969497, 0.11413362964746347],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7733982222804657, 0.11538267247357921, 0.11121910524595503],
                                [0.509021214230797, 0.24097878576920295, 0.25],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.5, 0.25270630502686997, 0.24729369497313003],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.509021214230797, 0.25, 0.24097878576920295],
                                [0.24464420618112837, 0.3707384662924509, 0.38461732752642075],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.23076534494715856, 0.3887808947540449, 0.3804537602987966],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2446442061811283, 0.3846173275264208, 0.37073846629245083],
                                [0.06410613378330843, 0.4593489047320256, 0.47654496148466596],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.04691007703066813, 0.481703665583848, 0.47138625738548395],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.06410613378330837, 0.476544961484666, 0.45934890473202555],
                                [0.9541385865228931, 0.022406374961772856, 0.02345503851533401],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9530899229693319, 0.023506652625284463, 0.023403424405383556],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9541385865228931, 0.023455038515334006, 0.02240637496177286],
                                [0.7743933591520236, 0.11022396837439719, 0.11538267247357922],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7692346550528416, 0.11563657842813714, 0.1151287665190213],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7743933591520236, 0.11538267247357922, 0.11022396837439719],
                                [0.5111773804259112, 0.2388226195740888, 0.25],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.5, 0.2505501388317558, 0.2494498611682442],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5111773804259112, 0.25, 0.2388226195740888],
                                [0.24796140169979886, 0.3674212707737804, 0.38461732752642075],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.23076534494715845, 0.38546369923537444, 0.38377095581746706],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2479614016997989, 0.3846173275264208, 0.36742127077378034],
                                [0.06821617432892935, 0.4552388641864047, 0.47654496148466596],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.046910077030668074, 0.4775936250382271, 0.4754962979311048],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.06821617432892935, 0.47654496148466596, 0.4552388641864047],
                                [0.9533438289238899, 0.0232011325607761, 0.02345503851533401],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.953089922969332, 0.02861374261451604, 0.01829633441615198],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9533438289238899, 0.023455038515334006, 0.023201132560776102],
                                [0.7704836978789573, 0.11413362964746346, 0.11538267247357922],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7692346550528415, 0.140759951861754, 0.09000539308540446],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7704836978789573, 0.11538267247357921, 0.11413362964746347],
                                [0.50270630502687, 0.24729369497313003, 0.25],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.49999999999999994, 0.30498503120991965, 0.19501496879008035],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.50270630502687, 0.25, 0.24729369497313003],
                                [0.23492891217478273, 0.3804537602987965, 0.38461732752642075],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.23076534494715845, 0.4692101105580853, 0.3000245444947562],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2349289121747828, 0.3846173275264207, 0.3804537602987966],
                                [0.05206878112985014, 0.4713862573854839, 0.47654496148466596],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.046910077030668074, 0.5813563198053232, 0.3717336031640087],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.052068781129850195, 0.4765449614846659, 0.47138625738548395],
                                [0.9543389657954477, 0.02220599568921825, 0.02345503851533401],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.953089922969332, 0.027618605742958196, 0.019291471287709822],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9543389657954477, 0.023455038515334006, 0.022205995689218255],
                                [0.7753790874832964, 0.1092382400431243, 0.11538267247357922],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7692346550528415, 0.1358645622574148, 0.09490078268974364],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7753790874832964, 0.11538267247357924, 0.10923824004312428],
                                [0.5133131611071453, 0.23668683889285475, 0.25],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5, 0.29437817512964437, 0.20562182487035563],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5133131611071453, 0.25, 0.23668683889285475],
                                [0.2512472347309941, 0.36413543774258517, 0.38461732752642075],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.2307653449471585, 0.4528917880018739, 0.3163428670509676],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2512472347309941, 0.38461732752642075, 0.36413543774258517],
                                [0.07228735641884287, 0.45116768209649116, 0.47654496148466596],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.046910077030668074, 0.5611377445163306, 0.3919521784530014],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.07228735641884293, 0.4765449614846659, 0.4511676820964912],
                                [0.9557962279962019, 0.02074873348846404, 0.02345503851533401],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.9530899229693319, 0.02616134354220398, 0.02074873348846404],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9557962279962019, 0.02345503851533401, 0.02074873348846404],
                                [0.7825478161599868, 0.10206951136643397, 0.11538267247357922],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7692346550528416, 0.12869583358072448, 0.10206951136643397],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7825478161599868, 0.11538267247357922, 0.10206951136643397],
                                [0.5288456681183948, 0.22115433188160522, 0.25],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5, 0.27884566811839484, 0.2211543318816052],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5288456681183948, 0.25, 0.2211543318816052],
                                [0.27514352007680287, 0.3402391523967764, 0.38461732752642075],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.2307653449471585, 0.4289955026560651, 0.3402391523967764],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.27514352007680287, 0.38461732752642075, 0.3402391523967764],
                                [0.10189510824058767, 0.42155993027474636, 0.47654496148466596],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.046910077030668074, 0.5315299926945856, 0.4215599302747463],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.10189510824058762, 0.476544961484666, 0.4215599302747463],
                                [0.9572534901969562, 0.019291471287709826, 0.02345503851533401],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.953089922969332, 0.024704081341449767, 0.02220599568921825],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9572534901969562, 0.02345503851533401, 0.019291471287709826],
                                [0.7897165448366771, 0.09490078268974364, 0.11538267247357922],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7692346550528416, 0.12152710490403418, 0.10923824004312427],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7897165448366771, 0.11538267247357921, 0.09490078268974365],
                                [0.5443781751296444, 0.20562182487035563, 0.25],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5, 0.2633131611071453, 0.23668683889285472],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5443781751296444, 0.24999999999999997, 0.20562182487035566],
                                [0.29903980542261166, 0.3163428670509676, 0.38461732752642075],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.23076534494715845, 0.4050992173102564, 0.3641354377425851],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2990398054226117, 0.3846173275264207, 0.31634286705096765],
                                [0.13150286006233258, 0.39195217845300145, 0.47654496148466596],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.046910077030668074, 0.5019222408728408, 0.45116768209649116],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.13150286006233258, 0.47654496148466596, 0.39195217845300145],
                                [0.958248627068514, 0.01829633441615198, 0.02345503851533401],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.953089922969332, 0.023708944469891916, 0.023201132560776102],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.958248627068514, 0.02345503851533401, 0.01829633441615198],
                                [0.7946119344410163, 0.09000539308540445, 0.11538267247357922],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7692346550528416, 0.11663171529969497, 0.11413362964746347],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7946119344410163, 0.11538267247357921, 0.09000539308540446],
                                [0.5549850312099196, 0.19501496879008035, 0.25],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5, 0.25270630502686997, 0.24729369497313003],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5549850312099196, 0.25, 0.19501496879008035],
                                [0.315358127978823, 0.30002454449475624, 0.38461732752642075],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.23076534494715856, 0.3887808947540449, 0.3804537602987966],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.31535812797882296, 0.3846173275264208, 0.3000245444947562],
                                [0.15172143535132532, 0.3717336031640087, 0.47654496148466596],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.04691007703066813, 0.481703665583848, 0.47138625738548395],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.15172143535132532, 0.47654496148466596, 0.3717336031640087],
                                [0.9536400618010877, 0.022904899683578207, 0.02345503851533401],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9530899229693319, 0.03463241894124521, 0.012277658089422806],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.9536400618010877, 0.02345503851533401, 0.022904899683578207],
                                [0.7719409600797115, 0.11267636744670925, 0.11538267247357922],
                                [0.7692346550528415, 0.057691336236789625, 0.17307400871036882],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.7692346550528416, 0.17036770368349885, 0.06039764126365958],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.7719409600797115, 0.11538267247357922, 0.11267636744670925],
                                [0.5058637596288336, 0.2441362403711665, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.625, 0.25, 0.125],
                                [0.49999999999999994, 0.3691362403711665, 0.1308637596288335],
                                [0.5, 0.375, 0.125],
                                [0.5058637596288336, 0.25, 0.2441362403711665],
                                [0.23978655917795555, 0.3755961132956237, 0.38461732752642075],
                                [0.2307653449471585, 0.19230866376321032, 0.5769259912896312],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.2307653449471585, 0.5679047770588341, 0.20132987799400742],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.23978655917795555, 0.38461732752642075, 0.3755961132956237],
                                [0.05808745745657928, 0.46536758105875475, 0.47654496148466596],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.046910077030668074, 0.7036400618010877, 0.2494498611682442],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.05808745745657928, 0.47654496148466596, 0.46536758105875475],
                                [0.9557962279962019, 0.02074873348846404, 0.02345503851533401],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9530899229693319, 0.03247625274613104, 0.014433824284536975],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.9557962279962019, 0.02345503851533401, 0.02074873348846404],
                                [0.7825478161599868, 0.10206951136643397, 0.11538267247357922],
                                [0.7692346550528415, 0.057691336236789625, 0.17307400871036882],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.7692346550528415, 0.15976084760322357, 0.07100449734393487],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.7825478161599868, 0.11538267247357922, 0.10206951136643397],
                                [0.5288456681183948, 0.22115433188160522, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.625, 0.25, 0.125],
                                [0.5, 0.34615433188160516, 0.1538456681183948],
                                [0.5, 0.375, 0.125],
                                [0.5288456681183948, 0.25, 0.2211543318816052],
                                [0.27514352007680287, 0.3402391523967764, 0.38461732752642075],
                                [0.2307653449471585, 0.19230866376321032, 0.5769259912896312],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.2307653449471585, 0.5325478161599868, 0.23668683889285475],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.27514352007680287, 0.38461732752642075, 0.3402391523967764],
                                [0.10189510824058767, 0.42155993027474636, 0.47654496148466596],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.046910077030668074, 0.6598324110170792, 0.29325751195225264],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.10189510824058762, 0.476544961484666, 0.4215599302747463],
                                [0.9589536825981655, 0.017591278886500507, 0.02345503851533401],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.953089922969332, 0.02931879814416751, 0.017591278886500507],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.9589536825981655, 0.02345503851533401, 0.017591278886500507],
                                [0.7980803231712363, 0.08653700435518441, 0.11538267247357922],
                                [0.7692346550528415, 0.057691336236789625, 0.17307400871036882],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.7692346550528415, 0.14422834059197404, 0.08653700435518441],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.7980803231712363, 0.11538267247357922, 0.08653700435518441],
                                [0.5625, 0.1875, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.625, 0.25, 0.125],
                                [0.5, 0.3125, 0.1875],
                                [0.5, 0.375, 0.125],
                                [0.5625, 0.25, 0.1875],
                                [0.32691967682876366, 0.2884629956448156, 0.38461732752642075],
                                [0.2307653449471585, 0.19230866376321032, 0.5769259912896312],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.2307653449471585, 0.4807716594080259, 0.2884629956448156],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.32691967682876366, 0.38461732752642075, 0.2884629956448156],
                                [0.1660463174018345, 0.35740872111349953, 0.47654496148466596],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.046910077030668074, 0.5956812018558324, 0.3574087211134995],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.16604631740183445, 0.476544961484666, 0.3574087211134995],
                                [0.962111137200129, 0.014433824284536975, 0.02345503851533401],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9530899229693319, 0.02616134354220398, 0.02074873348846404],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.962111137200129, 0.02345503851533401, 0.014433824284536975],
                                [0.8136128301824859, 0.07100449734393488, 0.11538267247357922],
                                [0.7692346550528415, 0.057691336236789625, 0.17307400871036882],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.7692346550528416, 0.12869583358072448, 0.10206951136643397],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.8136128301824859, 0.11538267247357924, 0.07100449734393487],
                                [0.5961543318816052, 0.15384566811839484, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.625, 0.25, 0.125],
                                [0.5, 0.27884566811839484, 0.2211543318816052],
                                [0.5, 0.375, 0.125],
                                [0.5961543318816052, 0.25, 0.1538456681183948],
                                [0.37869583358072445, 0.2366868388928548, 0.38461732752642075],
                                [0.2307653449471585, 0.19230866376321032, 0.5769259912896312],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.2307653449471585, 0.4289955026560651, 0.3402391523967764],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.3786958335807245, 0.3846173275264208, 0.23668683889285475],
                                [0.23019752656308134, 0.2932575119522527, 0.47654496148466596],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.046910077030668074, 0.5315299926945856, 0.4215599302747463],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.2301975265630813, 0.476544961484666, 0.29325751195225264],
                                [0.9642673033952431, 0.012277658089422806, 0.02345503851533401],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9530899229693319, 0.02400517734708981, 0.022904899683578207],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.9642673033952431, 0.02345503851533401, 0.012277658089422806],
                                [0.8242196862627611, 0.060397641263659596, 0.11538267247357922],
                                [0.7692346550528415, 0.057691336236789625, 0.17307400871036882],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.7692346550528415, 0.1180889775004492, 0.11267636744670925],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.8242196862627612, 0.11538267247357924, 0.06039764126365958],
                                [0.6191362403711664, 0.1308637596288335, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.625, 0.25, 0.125],
                                [0.5, 0.2558637596288335, 0.2441362403711665],
                                [0.5, 0.375, 0.125],
                                [0.6191362403711664, 0.25, 0.1308637596288335],
                                [0.4140527944795719, 0.20132987799400737, 0.38461732752642075],
                                [0.2307653449471585, 0.19230866376321032, 0.5769259912896312],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.2307653449471585, 0.3936385417572178, 0.3755961132956237],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.41405279447957194, 0.3846173275264207, 0.20132987799400742],
                                [0.27400517734708985, 0.2494498611682442, 0.47654496148466596],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.046910077030668074, 0.4877223419105772, 0.46536758105875475],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.27400517734708985, 0.47654496148466596, 0.2494498611682442],
                                [0.9539362946782857, 0.022608666806380316, 0.02345503851533401],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.9530899229693319, 0.040651095267974384, 0.006258981762693636],
                                [0.9530899229693319, 0.04149746697692808, 0.005412610053739941],
                                [0.9539362946782857, 0.023455038515334013, 0.022608666806380313],
                                [0.7733982222804657, 0.11121910524595502, 0.11538267247357922],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.7692346550528415, 0.19997545550524373, 0.030789889441914704],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.7733982222804657, 0.11538267247357921, 0.11121910524595503],
                                [0.509021214230797, 0.24097878576920295, 0.25],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.5, 0.4332874495324133, 0.06671255046758666],
                                [0.49999999999999994, 0.4423086637632104, 0.057691336236789625],
                                [0.509021214230797, 0.25, 0.24097878576920295],
                                [0.24464420618112837, 0.3707384662924509, 0.38461732752642075],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.2307653449471585, 0.6665994435595829, 0.1026352114932586],
                                [0.2307653449471585, 0.6804783047935528, 0.08875635025928873],
                                [0.2446442061811283, 0.3846173275264208, 0.37073846629245083],
                                [0.06410613378330843, 0.4593489047320256, 0.47654496148466596],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.046910077030668074, 0.8259238037968523, 0.12716611917247966],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983931],
                                [0.06410613378330837, 0.476544961484666, 0.45934890473202555],
                                [0.9572534901969562, 0.019291471287709826, 0.02345503851533401],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.9530899229693319, 0.037333899749303893, 0.009576177281364125],
                                [0.9530899229693319, 0.04149746697692808, 0.005412610053739941],
                                [0.9572534901969562, 0.02345503851533401, 0.019291471287709826],
                                [0.7897165448366771, 0.09490078268974364, 0.11538267247357922],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.7692346550528415, 0.18365713294903235, 0.047108211998126086],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.7897165448366771, 0.11538267247357921, 0.09490078268974365],
                                [0.5443781751296444, 0.20562182487035563, 0.25],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.5, 0.39793048863356606, 0.10206951136643397],
                                [0.49999999999999994, 0.4423086637632104, 0.057691336236789625],
                                [0.5443781751296444, 0.24999999999999997, 0.20562182487035566],
                                [0.29903980542261166, 0.3163428670509676, 0.38461732752642075],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.2307653449471585, 0.6122038443180997, 0.15703081073474184],
                                [0.2307653449471585, 0.6804783047935528, 0.08875635025928873],
                                [0.2990398054226117, 0.3846173275264207, 0.31634286705096765],
                                [0.13150286006233258, 0.39195217845300145, 0.47654496148466596],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.046910077030668074, 0.7585270775178281, 0.1945628454515038],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983931],
                                [0.13150286006233258, 0.47654496148466596, 0.39195217845300145],
                                [0.962111137200129, 0.014433824284536975, 0.02345503851533401],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.9530899229693319, 0.03247625274613104, 0.014433824284536975],
                                [0.9530899229693319, 0.04149746697692808, 0.005412610053739941],
                                [0.962111137200129, 0.02345503851533401, 0.014433824284536975],
                                [0.8136128301824859, 0.07100449734393488, 0.11538267247357922],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.7692346550528415, 0.15976084760322357, 0.07100449734393487],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.8136128301824859, 0.11538267247357924, 0.07100449734393487],
                                [0.5961543318816052, 0.15384566811839484, 0.25],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.5, 0.34615433188160516, 0.1538456681183948],
                                [0.49999999999999994, 0.4423086637632104, 0.057691336236789625],
                                [0.5961543318816052, 0.25, 0.1538456681183948],
                                [0.37869583358072445, 0.2366868388928548, 0.38461732752642075],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.2307653449471585, 0.5325478161599868, 0.23668683889285475],
                                [0.2307653449471585, 0.6804783047935528, 0.08875635025928873],
                                [0.3786958335807245, 0.3846173275264208, 0.23668683889285475],
                                [0.23019752656308134, 0.2932575119522527, 0.47654496148466596],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.046910077030668074, 0.6598324110170792, 0.29325751195225264],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983931],
                                [0.2301975265630813, 0.476544961484666, 0.29325751195225264],
                                [0.9669687842033018, 0.009576177281364125, 0.02345503851533401],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.953089922969332, 0.027618605742958196, 0.019291471287709822],
                                [0.9530899229693319, 0.04149746697692808, 0.005412610053739941],
                                [0.9669687842033018, 0.02345503851533401, 0.009576177281364126],
                                [0.8375091155282947, 0.04710821199812609, 0.11538267247357922],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.7692346550528415, 0.1358645622574148, 0.09490078268974364],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.8375091155282947, 0.11538267247357922, 0.0471082119981261],
                                [0.647930488633566, 0.102069511366434, 0.25],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.5, 0.29437817512964437, 0.20562182487035563],
                                [0.49999999999999994, 0.4423086637632104, 0.057691336236789625],
                                [0.647930488633566, 0.25, 0.102069511366434],
                                [0.45835186173883735, 0.1570308107347419, 0.38461732752642075],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.2307653449471585, 0.4528917880018739, 0.3163428670509676],
                                [0.2307653449471585, 0.6804783047935528, 0.08875635025928873],
                                [0.45835186173883735, 0.38461732752642075, 0.15703081073474187],
                                [0.3288921930638302, 0.19456284545150382, 0.47654496148466596],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.046910077030668074, 0.5611377445163306, 0.3919521784530014],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983931],
                                [0.3288921930638302, 0.47654496148466596, 0.19456284545150385],
                                [0.9702859797219723, 0.006258981762693638, 0.02345503851533401],
                                [0.9530899229693319, 0.005412610053739941, 0.04149746697692808],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.953089922969332, 0.024301410224287705, 0.022608666806380313],
                                [0.9530899229693319, 0.04149746697692808, 0.005412610053739941],
                                [0.9702859797219723, 0.02345503851533401, 0.006258981762693637],
                                [0.853827438084506, 0.030789889441914714, 0.11538267247357922],
                                [0.7692346550528416, 0.02662632221429051, 0.20413902273286794],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.7692346550528416, 0.11954623970120341, 0.11121910524595503],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.853827438084506, 0.11538267247357922, 0.03078988944191471],
                                [0.6832874495324133, 0.06671255046758667, 0.25],
                                [0.5, 0.057691336236789625, 0.4423086637632104],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.5, 0.25902121423079705, 0.24097878576920295],
                                [0.49999999999999994, 0.4423086637632104, 0.057691336236789625],
                                [0.6832874495324133, 0.25, 0.06671255046758667],
                                [0.5127474609803206, 0.1026352114932586, 0.38461732752642075],
                                [0.2307653449471585, 0.08875635025928874, 0.6804783047935528],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.23076534494715845, 0.39849618876039067, 0.37073846629245083],
                                [0.2307653449471585, 0.6804783047935528, 0.08875635025928873],
                                [0.5127474609803206, 0.38461732752642075, 0.10263521149325863],
                                [0.3962889193428544, 0.12716611917247966, 0.47654496148466596],
                                [0.046910077030668074, 0.10997006241983931, 0.8431198605494926],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.04691007703066802, 0.4937410182373064, 0.45934890473202555],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983931],
                                [0.3962889193428544, 0.47654496148466596, 0.1271661191724797],
                                [0.9541385865228931, 0.022406374961772856, 0.02345503851533401],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9530899229693319, 0.04476113581359526, 0.0021489412170727557],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.9541385865228931, 0.023455038515334006, 0.02240637496177286],
                                [0.7743933591520236, 0.11022396837439719, 0.11538267247357922],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.7692346550528415, 0.22019403079423647, 0.010571314152921977],
                                [0.7692346550528415, 0.2253527348934185, 0.0054126100537399465],
                                [0.7743933591520236, 0.11538267247357922, 0.11022396837439719],
                                [0.5111773804259112, 0.2388226195740888, 0.25],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.5, 0.47709510031642177, 0.02290489968357822],
                                [0.5, 0.488272480742333, 0.011727519257667018],
                                [0.5111773804259112, 0.25, 0.2388226195740888],
                                [0.24796140169979886, 0.3674212707737804, 0.38461732752642075],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.2307653449471585, 0.733996169838607, 0.03523848521423446],
                                [0.2307653449471585, 0.7511922265912474, 0.01804242846159409],
                                [0.2479614016997989, 0.3846173275264208, 0.36742127077378034],
                                [0.06821617432892935, 0.4552388641864047, 0.47654496148466596],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.046910077030668074, 0.9094290648192482, 0.043660858150083685],
                                [0.046910077030668074, 0.9307351621175095, 0.02235476085182243],
                                [0.06821617432892935, 0.47654496148466596, 0.4552388641864047],
                                [0.958248627068514, 0.01829633441615198, 0.02345503851533401],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9530899229693319, 0.040651095267974384, 0.006258981762693636],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.958248627068514, 0.02345503851533401, 0.01829633441615198],
                                [0.7946119344410163, 0.09000539308540445, 0.11538267247357922],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.7692346550528415, 0.19997545550524373, 0.030789889441914704],
                                [0.7692346550528415, 0.2253527348934185, 0.0054126100537399465],
                                [0.7946119344410163, 0.11538267247357921, 0.09000539308540446],
                                [0.5549850312099196, 0.19501496879008035, 0.25],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.5, 0.4332874495324133, 0.06671255046758666],
                                [0.5, 0.488272480742333, 0.011727519257667018],
                                [0.5549850312099196, 0.25, 0.19501496879008035],
                                [0.315358127978823, 0.30002454449475624, 0.38461732752642075],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.2307653449471585, 0.6665994435595829, 0.1026352114932586],
                                [0.2307653449471585, 0.7511922265912474, 0.01804242846159409],
                                [0.31535812797882296, 0.3846173275264208, 0.3000245444947562],
                                [0.15172143535132532, 0.3717336031640087, 0.47654496148466596],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.046910077030668074, 0.8259238037968523, 0.12716611917247966],
                                [0.046910077030668074, 0.9307351621175095, 0.02235476085182243],
                                [0.15172143535132532, 0.47654496148466596, 0.3717336031640087],
                                [0.9642673033952431, 0.012277658089422806, 0.02345503851533401],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9530899229693319, 0.03463241894124521, 0.012277658089422806],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.9642673033952431, 0.02345503851533401, 0.012277658089422806],
                                [0.8242196862627611, 0.060397641263659596, 0.11538267247357922],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.7692346550528416, 0.17036770368349885, 0.06039764126365958],
                                [0.7692346550528415, 0.2253527348934185, 0.0054126100537399465],
                                [0.8242196862627612, 0.11538267247357924, 0.06039764126365958],
                                [0.6191362403711664, 0.1308637596288335, 0.25],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.49999999999999994, 0.3691362403711665, 0.1308637596288335],
                                [0.5, 0.488272480742333, 0.011727519257667018],
                                [0.6191362403711664, 0.25, 0.1308637596288335],
                                [0.4140527944795719, 0.20132987799400737, 0.38461732752642075],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.2307653449471585, 0.5679047770588341, 0.20132987799400742],
                                [0.2307653449471585, 0.7511922265912474, 0.01804242846159409],
                                [0.41405279447957194, 0.3846173275264207, 0.20132987799400742],
                                [0.27400517734708985, 0.2494498611682442, 0.47654496148466596],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.046910077030668074, 0.7036400618010877, 0.2494498611682442],
                                [0.046910077030668074, 0.9307351621175095, 0.02235476085182243],
                                [0.27400517734708985, 0.47654496148466596, 0.2494498611682442],
                                [0.9702859797219723, 0.006258981762693638, 0.02345503851533401],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.953089922969332, 0.02861374261451604, 0.01829633441615198],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.9702859797219723, 0.02345503851533401, 0.006258981762693637],
                                [0.853827438084506, 0.030789889441914714, 0.11538267247357922],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.7692346550528415, 0.140759951861754, 0.09000539308540446],
                                [0.7692346550528415, 0.2253527348934185, 0.0054126100537399465],
                                [0.853827438084506, 0.11538267247357922, 0.03078988944191471],
                                [0.6832874495324133, 0.06671255046758667, 0.25],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.49999999999999994, 0.30498503120991965, 0.19501496879008035],
                                [0.5, 0.488272480742333, 0.011727519257667018],
                                [0.6832874495324133, 0.25, 0.06671255046758667],
                                [0.5127474609803206, 0.1026352114932586, 0.38461732752642075],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.23076534494715845, 0.4692101105580853, 0.3000245444947562],
                                [0.2307653449471585, 0.7511922265912474, 0.01804242846159409],
                                [0.5127474609803206, 0.38461732752642075, 0.10263521149325863],
                                [0.3962889193428544, 0.12716611917247966, 0.47654496148466596],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.046910077030668074, 0.5813563198053232, 0.3717336031640087],
                                [0.046910077030668074, 0.9307351621175095, 0.02235476085182243],
                                [0.3962889193428544, 0.47654496148466596, 0.1271661191724797],
                                [0.9743960202675932, 0.002148941217072757, 0.02345503851533401],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9530899229693319, 0.02450370206889516, 0.02240637496177286],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.9743960202675932, 0.02345503851533401, 0.0021489412170727566],
                                [0.8740460133734987, 0.010571314152921979, 0.11538267247357922],
                                [0.7692346550528415, 0.005412610053739941, 0.2253527348934185],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.7692346550528415, 0.12054137657276126, 0.11022396837439719],
                                [0.7692346550528415, 0.2253527348934185, 0.0054126100537399465],
                                [0.8740460133734987, 0.11538267247357922, 0.01057131415292198],
                                [0.7270951003164218, 0.022904899683578228, 0.25],
                                [0.5, 0.011727519257667018, 0.488272480742333],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.5, 0.2611773804259112, 0.2388226195740888],
                                [0.5, 0.488272480742333, 0.011727519257667018],
                                [0.7270951003164218, 0.25, 0.022904899683578228],
                                [0.5801441872593448, 0.03523848521423445, 0.38461732752642075],
                                [0.2307653449471585, 0.018042428461594096, 0.7511922265912474],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.23076534494715856, 0.40181338427906116, 0.36742127077378034],
                                [0.2307653449471585, 0.7511922265912474, 0.01804242846159409],
                                [0.5801441872593448, 0.38461732752642075, 0.03523848521423447],
                                [0.47979418036525034, 0.04366085815008369, 0.47654496148466596],
                                [0.046910077030668074, 0.02235476085182242, 0.9307351621175095],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.046910077030668074, 0.49785105878292724, 0.4552388641864047],
                                [0.046910077030668074, 0.9307351621175095, 0.02235476085182243],
                                [0.47979418036525034, 0.47654496148466596, 0.0436608581500837],
                                [0.9531693296934591, 0.03600545019906094, 0.010825220107479883],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.953089922969332, 0.012438556801260083, 0.034471520229407936],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.9531693296934591, 0.010825220107479883, 0.03600545019906094],
                                [0.769625281571582, 0.17712207399983698, 0.05325264442858104],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7692346550528415, 0.061189152365088983, 0.16957619258206946],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.769625281571582, 0.05325264442858105, 0.17712207399983698],
                                [0.5008463717089537, 0.38377095581746706, 0.11538267247357925],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5, 0.13257872922621966, 0.36742127077378034],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5008463717089536, 0.11538267247357925, 0.38377095581746706],
                                [0.23206746184632543, 0.5904198376350971, 0.17751270051857745],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.2307653449471585, 0.20396830608735028, 0.5652663489654912],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.23206746184632543, 0.17751270051857748, 0.5904198376350971],
                                [0.04852341372444824, 0.7315364614358731, 0.21994012483967862],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.046910077030668074, 0.2527189016511793, 0.7003710213181527],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.04852341372444824, 0.21994012483967862, 0.7315364614358731],
                                [0.9534805494880724, 0.035694230404447705, 0.010825220107479883],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.953089922969332, 0.012127337006646845, 0.03478274002402117],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.9534805494880724, 0.010825220107479883, 0.035694230404447705],
                                [0.7711562691078283, 0.17559108646359065, 0.05325264442858104],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7692346550528416, 0.059658164828842675, 0.17110718011831577],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7711562691078283, 0.05325264442858105, 0.17559108646359065],
                                [0.5041635672276241, 0.3804537602987966, 0.11538267247357925],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.49999999999999994, 0.12926153370754917, 0.37073846629245083],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5041635672276242, 0.11538267247357925, 0.3804537602987966],
                                [0.23717086534742005, 0.5853164341340025, 0.17751270051857745],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.2307653449471585, 0.19886490258625567, 0.5703697524665858],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.23717086534742005, 0.17751270051857748, 0.5853164341340025],
                                [0.05484658496717598, 0.7252132901931454, 0.21994012483967862],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.046910077030668074, 0.24639573040845153, 0.7066941925608804],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.05484658496717598, 0.21994012483967862, 0.7252132901931454],
                                [0.9539362946782857, 0.03523848521423444, 0.010825220107479883],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.9530899229693319, 0.011671591816433576, 0.03523848521423444],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.9539362946782857, 0.010825220107479883, 0.03523848521423444],
                                [0.7733982222804658, 0.1733491332909532, 0.05325264442858104],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7692346550528415, 0.057416211656205224, 0.17334913329095322],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7733982222804657, 0.05325264442858102, 0.17334913329095322],
                                [0.509021214230797, 0.3755961132956237, 0.11538267247357925],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5, 0.1244038867043763, 0.3755961132956237],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.509021214230797, 0.11538267247357925, 0.3755961132956237],
                                [0.24464420618112837, 0.5778430933002942, 0.17751270051857745],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.2307653449471585, 0.19139156175254735, 0.5778430933002942],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.24464420618112837, 0.17751270051857748, 0.5778430933002942],
                                [0.06410613378330843, 0.715953741377013, 0.21994012483967862],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.046910077030668074, 0.23713618159231897, 0.715953741377013],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.06410613378330843, 0.21994012483967862, 0.715953741377013],
                                [0.954392039868499, 0.03478274002402118, 0.010825220107479883],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.9530899229693319, 0.01121584662622032, 0.0356942304044477],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.954392039868499, 0.010825220107479883, 0.03478274002402118],
                                [0.7756401754531032, 0.1711071801183158, 0.05325264442858104],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7692346550528416, 0.05517425848356783, 0.17559108646359062],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7756401754531032, 0.05325264442858105, 0.1711071801183158],
                                [0.5138788612339699, 0.3707384662924509, 0.11538267247357925],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5, 0.11954623970120348, 0.3804537602987965],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5138788612339699, 0.11538267247357925, 0.3707384662924509],
                                [0.2521175470148366, 0.5703697524665859, 0.17751270051857745],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.2307653449471585, 0.18391822091883914, 0.5853164341340024],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.2521175470148366, 0.17751270051857748, 0.5703697524665859],
                                [0.07336568259944087, 0.7066941925608805, 0.21994012483967862],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.046910077030668074, 0.22787663277618664, 0.7252132901931453],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.07336568259944087, 0.21994012483967862, 0.7066941925608805],
                                [0.9547032596631122, 0.03447152022940794, 0.010825220107479883],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.9530899229693319, 0.010904626831607075, 0.03600545019906094],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.9547032596631122, 0.010825220107479883, 0.03447152022940794],
                                [0.7771711629893495, 0.16957619258206946, 0.05325264442858104],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7692346550528416, 0.05364327094732149, 0.17712207399983695],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7771711629893495, 0.05325264442858102, 0.1695761925820695],
                                [0.5171960567526404, 0.3674212707737804, 0.11538267247357925],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5, 0.11622904418253299, 0.383770955817467],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5171960567526404, 0.11538267247357925, 0.3674212707737804],
                                [0.2572209505159313, 0.5652663489654912, 0.17751270051857745],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.2307653449471585, 0.17881481741774452, 0.590419837635097],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.2572209505159313, 0.17751270051857748, 0.5652663489654912],
                                [0.07968885384216862, 0.7003710213181528, 0.21994012483967862],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.046910077030668074, 0.2215534615334589, 0.731536461435873],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.07968885384216862, 0.21994012483967862, 0.7003710213181528],
                                [0.9534805494880724, 0.035694230404447705, 0.010825220107479883],
                                [0.953089922969332, 0.02775772246793977, 0.01915235456272825],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.953089922969332, 0.01876172804398782, 0.0281483489866802],
                                [0.953089922969332, 0.01915235456272825, 0.02775772246793977],
                                [0.9534805494880724, 0.010825220107479883, 0.035694230404447705],
                                [0.7711562691078283, 0.17559108646359065, 0.05325264442858104],
                                [0.7692346550528415, 0.13654892095090626, 0.09421642399625217],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.7692346550528415, 0.09229480994126543, 0.13847053500589301],
                                [0.7692346550528415, 0.09421642399625219, 0.13654892095090626],
                                [0.7711562691078283, 0.05325264442858105, 0.17559108646359065],
                                [0.5041635672276241, 0.3804537602987966, 0.11538267247357925],
                                [0.5, 0.29586097726713206, 0.20413902273286794],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5, 0.19997545550524376, 0.30002454449475624],
                                [0.49999999999999994, 0.20413902273286794, 0.29586097726713206],
                                [0.5041635672276242, 0.11538267247357925, 0.3804537602987966],
                                [0.23717086534742005, 0.5853164341340025, 0.17751270051857745],
                                [0.2307653449471585, 0.4551730335833578, 0.3140616214694837],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.23076534494715845, 0.3076561010692221, 0.4615785539836194],
                                [0.2307653449471585, 0.3140616214694837, 0.4551730335833578],
                                [0.23717086534742005, 0.17751270051857748, 0.5853164341340025],
                                [0.05484658496717598, 0.7252132901931454, 0.21994012483967862],
                                [0.046910077030668074, 0.5639642320663243, 0.3891256909030076],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.046910077030668074, 0.38118918296649973, 0.5719007400028322],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.05484658496717598, 0.21994012483967862, 0.7252132901931454],
                                [0.9550115370243187, 0.034163242868201375, 0.010825220107479883],
                                [0.953089922969332, 0.02775772246793977, 0.01915235456272825],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9530899229693319, 0.01723074050774149, 0.02967933652292653],
                                [0.953089922969332, 0.01915235456272825, 0.02775772246793977],
                                [0.9550115370243187, 0.010825220107479883, 0.034163242868201375],
                                [0.7786876757751146, 0.1680596797963044, 0.05325264442858104],
                                [0.7692346550528415, 0.13654892095090626, 0.09421642399625217],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.7692346550528415, 0.08476340327397919, 0.14600194167317926],
                                [0.7692346550528415, 0.09421642399625219, 0.13654892095090626],
                                [0.7786876757751146, 0.05325264442858105, 0.1680596797963044],
                                [0.5204818897838356, 0.36413543774258517, 0.11538267247357925],
                                [0.5, 0.29586097726713206, 0.20413902273286794],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5, 0.18365713294903235, 0.31634286705096765],
                                [0.49999999999999994, 0.20413902273286794, 0.29586097726713206],
                                [0.5204818897838356, 0.11538267247357925, 0.36413543774258517],
                                [0.2622761037925566, 0.5602111956888659, 0.17751270051857745],
                                [0.2307653449471585, 0.4551730335833578, 0.3140616214694837],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.23076534494715856, 0.2825508626240855, 0.486683792428756],
                                [0.2307653449471585, 0.3140616214694837, 0.4551730335833578],
                                [0.2622761037925566, 0.17751270051857748, 0.5602111956888659],
                                [0.08595224254335243, 0.694107632616969, 0.21994012483967862],
                                [0.046910077030668074, 0.5639642320663243, 0.3891256909030076],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.046910077030668074, 0.35008352539032317, 0.6030063975790088],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.08595224254335243, 0.21994012483967862, 0.694107632616969],
                                [0.9572534901969562, 0.03192128969556395, 0.010825220107479883],
                                [0.953089922969332, 0.02775772246793977, 0.01915235456272825],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9530899229693319, 0.014988787335104066, 0.03192128969556395],
                                [0.953089922969332, 0.01915235456272825, 0.02775772246793977],
                                [0.9572534901969562, 0.010825220107479883, 0.03192128969556395],
                                [0.7897165448366772, 0.15703081073474182, 0.05325264442858104],
                                [0.7692346550528415, 0.13654892095090626, 0.09421642399625217],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.7692346550528416, 0.0737345342124166, 0.15703081073474184],
                                [0.7692346550528415, 0.09421642399625219, 0.13654892095090626],
                                [0.7897165448366772, 0.05325264442858105, 0.15703081073474182],
                                [0.5443781751296444, 0.3402391523967764, 0.11538267247357925],
                                [0.5, 0.29586097726713206, 0.20413902273286794],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.49999999999999994, 0.15976084760322357, 0.34023915239677643],
                                [0.49999999999999994, 0.20413902273286794, 0.29586097726713206],
                                [0.5443781751296444, 0.11538267247357925, 0.3402391523967764],
                                [0.29903980542261166, 0.5234474940588109, 0.17751270051857745],
                                [0.2307653449471585, 0.4551730335833578, 0.3140616214694837],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.2307653449471585, 0.24578716099403053, 0.523447494058811],
                                [0.2307653449471585, 0.3140616214694837, 0.4551730335833578],
                                [0.29903980542261166, 0.17751270051857748, 0.5234474940588109],
                                [0.13150286006233258, 0.6485570150979888, 0.21994012483967862],
                                [0.046910077030668074, 0.5639642320663243, 0.3891256909030076],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.046910077030668074, 0.304532907871343, 0.6485570150979889],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.13150286006233258, 0.21994012483967862, 0.6485570150979888],
                                [0.9594954433695936, 0.02967933652292653, 0.010825220107479883],
                                [0.953089922969332, 0.02775772246793977, 0.01915235456272825],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9530899229693319, 0.012746834162466643, 0.034163242868201375],
                                [0.953089922969332, 0.01915235456272825, 0.02775772246793977],
                                [0.9594954433695936, 0.010825220107479883, 0.02967933652292653],
                                [0.8007454138982397, 0.14600194167317926, 0.05325264442858104],
                                [0.7692346550528415, 0.13654892095090626, 0.09421642399625217],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.7692346550528415, 0.06270566515085405, 0.1680596797963044],
                                [0.7692346550528415, 0.09421642399625219, 0.13654892095090626],
                                [0.8007454138982397, 0.05325264442858105, 0.14600194167317926],
                                [0.568274460475453, 0.31634286705096765, 0.11538267247357925],
                                [0.5, 0.29586097726713206, 0.20413902273286794],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5, 0.13586456225741483, 0.36413543774258517],
                                [0.49999999999999994, 0.20413902273286794, 0.29586097726713206],
                                [0.5682744604754532, 0.11538267247357925, 0.31634286705096765],
                                [0.3358035070526666, 0.4866837924287559, 0.17751270051857745],
                                [0.2307653449471585, 0.4551730335833578, 0.3140616214694837],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.2307653449471585, 0.2090234593639756, 0.5602111956888659],
                                [0.2307653449471585, 0.3140616214694837, 0.4551730335833578],
                                [0.33580350705266665, 0.17751270051857743, 0.486683792428756],
                                [0.17705347758131262, 0.6030063975790088, 0.21994012483967862],
                                [0.046910077030668074, 0.5639642320663243, 0.3891256909030076],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.046910077030668074, 0.258982290352363, 0.694107632616969],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.17705347758131262, 0.21994012483967862, 0.6030063975790088],
                                [0.96102643090584, 0.0281483489866802, 0.010825220107479883],
                                [0.953089922969332, 0.02775772246793977, 0.01915235456272825],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9530899229693319, 0.011215846626220313, 0.035694230404447705],
                                [0.953089922969332, 0.01915235456272825, 0.02775772246793977],
                                [0.96102643090584, 0.010825220107479883, 0.0281483489866802],
                                [0.808276820565526, 0.13847053500589301, 0.05325264442858104],
                                [0.7692346550528415, 0.13654892095090626, 0.09421642399625217],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.7692346550528415, 0.0551742584835678, 0.17559108646359065],
                                [0.7692346550528415, 0.09421642399625219, 0.13654892095090626],
                                [0.808276820565526, 0.05325264442858105, 0.13847053500589301],
                                [0.5845927830316645, 0.30002454449475624, 0.11538267247357925],
                                [0.5, 0.29586097726713206, 0.20413902273286794],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5, 0.11954623970120343, 0.3804537602987966],
                                [0.49999999999999994, 0.20413902273286794, 0.29586097726713206],
                                [0.5845927830316645, 0.11538267247357925, 0.30002454449475624],
                                [0.36090874549780316, 0.46157855398361936, 0.17751270051857745],
                                [0.2307653449471585, 0.4551730335833578, 0.3140616214694837],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.2307653449471585, 0.18391822091883903, 0.5853164341340025],
                                [0.2307653449471585, 0.3140616214694837, 0.4551730335833578],
                                [0.3609087454978031, 0.17751270051857743, 0.4615785539836194],
                                [0.20815913515748918, 0.5719007400028322, 0.21994012483967862],
                                [0.046910077030668074, 0.5639642320663243, 0.3891256909030076],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.046910077030668074, 0.22787663277618653, 0.7252132901931454],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.20815913515748918, 0.21994012483967862, 0.5719007400028322],
                                [0.9539362946782857, 0.03523848521423444, 0.010825220107479883],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.953089922969332, 0.028021276860120254, 0.018888800170547764],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9539362946782857, 0.010825220107479883, 0.03523848521423444],
                                [0.7733982222804658, 0.1733491332909532, 0.05325264442858104],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.7692346550528416, 0.13784542746024556, 0.09291991748691289],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7733982222804657, 0.05325264442858102, 0.17334913329095322],
                                [0.509021214230797, 0.3755961132956237, 0.11538267247357925],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.5, 0.2986701220059926, 0.20132987799400742],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.509021214230797, 0.11538267247357925, 0.3755961132956237],
                                [0.24464420618112837, 0.5778430933002942, 0.17751270051857745],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.23076534494715856, 0.45949481655173957, 0.3097398385011019],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.24464420618112837, 0.17751270051857748, 0.5778430933002942],
                                [0.06410613378330843, 0.715953741377013, 0.21994012483967862],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.046910077030668074, 0.5693189671518648, 0.38377095581746706],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.06410613378330843, 0.21994012483967862, 0.715953741377013],
                                [0.9572534901969562, 0.03192128969556395, 0.010825220107479883],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.953089922969332, 0.024704081341449767, 0.02220599568921825],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9572534901969562, 0.010825220107479883, 0.03192128969556395],
                                [0.7897165448366772, 0.15703081073474182, 0.05325264442858104],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.7692346550528416, 0.12152710490403418, 0.10923824004312427],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7897165448366772, 0.05325264442858105, 0.15703081073474182],
                                [0.5443781751296444, 0.3402391523967764, 0.11538267247357925],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.5, 0.2633131611071453, 0.23668683889285472],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5443781751296444, 0.11538267247357925, 0.3402391523967764],
                                [0.29903980542261166, 0.5234474940588109, 0.17751270051857745],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.23076534494715845, 0.4050992173102564, 0.3641354377425851],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.29903980542261166, 0.17751270051857748, 0.5234474940588109],
                                [0.13150286006233258, 0.6485570150979888, 0.21994012483967862],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.046910077030668074, 0.5019222408728408, 0.45116768209649116],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.13150286006233258, 0.21994012483967862, 0.6485570150979888],
                                [0.962111137200129, 0.0270636426923911, 0.010825220107479883],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.9530899229693319, 0.019846434338276913, 0.027063642692391105],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.962111137200129, 0.01082522010747988, 0.027063642692391105],
                                [0.8136128301824859, 0.13313452538893306, 0.05325264442858104],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.7692346550528415, 0.09763081955822539, 0.13313452538893306],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.8136128301824859, 0.05325264442858105, 0.13313452538893306],
                                [0.5961543318816052, 0.2884629956448156, 0.11538267247357925],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.5, 0.2115370043551844, 0.2884629956448156],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5961543318816052, 0.11538267247357925, 0.2884629956448156],
                                [0.37869583358072445, 0.44379146590069807, 0.17751270051857745],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.2307653449471585, 0.32544318915214343, 0.44379146590069807],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.37869583358072445, 0.17751270051857748, 0.44379146590069807],
                                [0.23019752656308134, 0.54986234859724, 0.21994012483967862],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.046910077030668074, 0.4032275743720919, 0.54986234859724],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.23019752656308134, 0.21994012483967862, 0.54986234859724],
                                [0.9669687842033019, 0.02220599568921825, 0.010825220107479883],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.9530899229693319, 0.014988787335104066, 0.03192128969556395],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9669687842033019, 0.01082522010747988, 0.022205995689218255],
                                [0.8375091155282948, 0.10923824004312427, 0.05325264442858104],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.7692346550528416, 0.07373453421241663, 0.15703081073474182],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.8375091155282947, 0.053252644428581034, 0.10923824004312428],
                                [0.647930488633566, 0.23668683889285475, 0.11538267247357925],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.5, 0.15976084760322362, 0.3402391523967764],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.6479304886335661, 0.11538267247357925, 0.23668683889285475],
                                [0.45835186173883735, 0.36413543774258517, 0.17751270051857745],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.2307653449471585, 0.24578716099403064, 0.5234474940588109],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.45835186173883735, 0.17751270051857748, 0.36413543774258517],
                                [0.3288921930638302, 0.45116768209649116, 0.21994012483967862],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.046910077030668074, 0.30453290787134313, 0.6485570150979888],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.3288921930638303, 0.21994012483967856, 0.4511676820964912],
                                [0.9702859797219724, 0.018888800170547764, 0.010825220107479883],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.9530899229693319, 0.011671591816433576, 0.03523848521423444],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9702859797219724, 0.010825220107479883, 0.018888800170547764],
                                [0.8538274380845061, 0.09291991748691289, 0.05325264442858104],
                                [0.7692346550528415, 0.08875635025928871, 0.14200899468786973],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.7692346550528415, 0.057416211656205224, 0.17334913329095322],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.8538274380845061, 0.05325264442858105, 0.09291991748691289],
                                [0.6832874495324133, 0.20132987799400742, 0.11538267247357925],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.5, 0.1244038867043763, 0.3755961132956237],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.6832874495324134, 0.11538267247357925, 0.20132987799400742],
                                [0.5127474609803206, 0.30973983850110187, 0.17751270051857745],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.2307653449471585, 0.19139156175254735, 0.5778430933002942],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.5127474609803206, 0.17751270051857743, 0.3097398385011019],
                                [0.3962889193428544, 0.383770955817467, 0.21994012483967862],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.046910077030668074, 0.23713618159231897, 0.715953741377013],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.3962889193428543, 0.21994012483967856, 0.38377095581746706],
                                [0.954392039868499, 0.03478274002402118, 0.010825220107479883],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.953089922969332, 0.03728082567625269, 0.00962925135441533],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248372],
                                [0.954392039868499, 0.010825220107479883, 0.03478274002402118],
                                [0.7756401754531032, 0.1711071801183158, 0.05325264442858104],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.7692346550528415, 0.18339604497922568, 0.04736929996793277],
                                [0.7692346550528415, 0.18980156537948728, 0.040963779567671166],
                                [0.7756401754531032, 0.05325264442858105, 0.1711071801183158],
                                [0.5138788612339699, 0.3707384662924509, 0.11538267247357925],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.5, 0.3973647885067414, 0.10263521149325862],
                                [0.5, 0.41124364974071126, 0.08875635025928874],
                                [0.5138788612339699, 0.11538267247357925, 0.3707384662924509],
                                [0.2521175470148366, 0.5703697524665859, 0.17751270051857745],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.2307653449471585, 0.611333532034257, 0.15790112301858444],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090632],
                                [0.2521175470148366, 0.17751270051857748, 0.5703697524665859],
                                [0.07336568259944087, 0.7066941925608805, 0.21994012483967862],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.046910077030668074, 0.75744875133723, 0.1956411716321019],
                                [0.046910077030668074, 0.7839043569060028, 0.1691855660633291],
                                [0.07336568259944087, 0.21994012483967862, 0.7066941925608805],
                                [0.9594954433695936, 0.02967933652292653, 0.010825220107479883],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.9530899229693319, 0.03217742217515804, 0.01473265485550998],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248372],
                                [0.9594954433695936, 0.010825220107479883, 0.02967933652292653],
                                [0.8007454138982397, 0.14600194167317926, 0.05325264442858104],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.7692346550528416, 0.15829080653408914, 0.0724745384130693],
                                [0.7692346550528415, 0.18980156537948728, 0.040963779567671166],
                                [0.8007454138982397, 0.05325264442858105, 0.14600194167317926],
                                [0.568274460475453, 0.31634286705096765, 0.11538267247357925],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.5, 0.34296918926525816, 0.15703081073474184],
                                [0.5, 0.41124364974071126, 0.08875635025928874],
                                [0.5682744604754532, 0.11538267247357925, 0.31634286705096765],
                                [0.3358035070526666, 0.4866837924287559, 0.17751270051857745],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.2307653449471585, 0.5276475719964271, 0.24158708305641435],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090632],
                                [0.33580350705266665, 0.17751270051857743, 0.486683792428756],
                                [0.17705347758131262, 0.6030063975790088, 0.21994012483967862],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.046910077030668074, 0.6537609563553582, 0.2993289666139737],
                                [0.046910077030668074, 0.7839043569060028, 0.1691855660633291],
                                [0.17705347758131262, 0.21994012483967862, 0.6030063975790088],
                                [0.9669687842033019, 0.02220599568921825, 0.010825220107479883],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.953089922969332, 0.024704081341449764, 0.022205995689218255],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248372],
                                [0.9669687842033019, 0.01082522010747988, 0.022205995689218255],
                                [0.8375091155282948, 0.10923824004312427, 0.05325264442858104],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.7692346550528415, 0.12152710490403416, 0.10923824004312428],
                                [0.7692346550528415, 0.18980156537948728, 0.040963779567671166],
                                [0.8375091155282947, 0.053252644428581034, 0.10923824004312428],
                                [0.647930488633566, 0.23668683889285475, 0.11538267247357925],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.5, 0.26331316110714525, 0.23668683889285475],
                                [0.5, 0.41124364974071126, 0.08875635025928874],
                                [0.6479304886335661, 0.11538267247357925, 0.23668683889285475],
                                [0.45835186173883735, 0.36413543774258517, 0.17751270051857745],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.2307653449471585, 0.40509921731025633, 0.36413543774258517],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090632],
                                [0.45835186173883735, 0.17751270051857748, 0.36413543774258517],
                                [0.3288921930638302, 0.45116768209649116, 0.21994012483967862],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.046910077030668074, 0.5019222408728408, 0.4511676820964912],
                                [0.046910077030668074, 0.7839043569060028, 0.1691855660633291],
                                [0.3288921930638303, 0.21994012483967856, 0.4511676820964912],
                                [0.9744421250370101, 0.014732654855509984, 0.010825220107479883],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.9530899229693319, 0.017230740507741496, 0.029679336522926522],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248372],
                                [0.9744421250370101, 0.010825220107479883, 0.014732654855509984],
                                [0.8742728171583496, 0.07247453841306933, 0.05325264442858104],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.7692346550528415, 0.08476340327397922, 0.14600194167317923],
                                [0.7692346550528415, 0.18980156537948728, 0.040963779567671166],
                                [0.8742728171583497, 0.05325264442858106, 0.07247453841306932],
                                [0.7275865167916789, 0.1570308107347419, 0.11538267247357925],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.5, 0.1836571329490324, 0.3163428670509676],
                                [0.5, 0.41124364974071126, 0.08875635025928874],
                                [0.7275865167916789, 0.11538267247357928, 0.15703081073474187],
                                [0.5809002164250081, 0.24158708305641444, 0.17751270051857745],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.2307653449471585, 0.2825508626240856, 0.4866837924287559],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090632],
                                [0.5809002164250081, 0.17751270051857748, 0.2415870830564144],
                                [0.4807309085463476, 0.2993289666139738, 0.21994012483967862],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.046910077030668074, 0.3500835253903233, 0.6030063975790086],
                                [0.046910077030668074, 0.7839043569060028, 0.1691855660633291],
                                [0.48073090854634754, 0.21994012483967867, 0.29932896661397373],
                                [0.9795455285381048, 0.009629251354415332, 0.010825220107479883],
                                [0.953089922969332, 0.008327134455248374, 0.038582942575419645],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.953089922969332, 0.012127337006646845, 0.03478274002402117],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248372],
                                [0.9795455285381048, 0.010825220107479881, 0.009629251354415334],
                                [0.8993780556034862, 0.047369299967932786, 0.05325264442858104],
                                [0.7692346550528415, 0.040963779567671166, 0.18980156537948728],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.7692346550528416, 0.059658164828842675, 0.17110718011831577],
                                [0.7692346550528415, 0.18980156537948728, 0.040963779567671166],
                                [0.8993780556034862, 0.053252644428581034, 0.04736929996793279],
                                [0.7819821160331621, 0.10263521149325866, 0.11538267247357925],
                                [0.5, 0.08875635025928874, 0.41124364974071126],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.49999999999999994, 0.12926153370754917, 0.37073846629245083],
                                [0.5, 0.41124364974071126, 0.08875635025928874],
                                [0.781982116033162, 0.11538267247357925, 0.10263521149325866],
                                [0.664586176462838, 0.15790112301858453, 0.17751270051857745],
                                [0.2307653449471585, 0.13654892095090632, 0.6326857341019352],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.2307653449471585, 0.19886490258625567, 0.5703697524665858],
                                [0.2307653449471585, 0.6326857341019352, 0.13654892095090632],
                                [0.664586176462838, 0.17751270051857745, 0.15790112301858453],
                                [0.5844187035282193, 0.19564117163210198, 0.21994012483967862],
                                [0.046910077030668074, 0.16918556606332913, 0.7839043569060028],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.046910077030668074, 0.24639573040845153, 0.7066941925608804],
                                [0.046910077030668074, 0.7839043569060028, 0.1691855660633291],
                                [0.5844187035282193, 0.21994012483967862, 0.19564117163210198],
                                [0.9547032596631122, 0.03447152022940794, 0.010825220107479883],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.953089922969332, 0.043603996918980426, 0.003306080111687589],
                                [0.953089922969332, 0.045217333612760625, 0.001692743417907392],
                                [0.9547032596631122, 0.010825220107479883, 0.03447152022940794],
                                [0.7771711629893495, 0.16957619258206946, 0.05325264442858104],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.7692346550528415, 0.21450170255540213, 0.016263642391756317],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248382],
                                [0.7771711629893495, 0.05325264442858102, 0.1695761925820695],
                                [0.5171960567526404, 0.3674212707737804, 0.11538267247357925],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.5, 0.46476151478576555, 0.03523848521423446],
                                [0.5, 0.4819575715384059, 0.018042428461594096],
                                [0.5171960567526404, 0.11538267247357925, 0.3674212707737804],
                                [0.2572209505159313, 0.5652663489654912, 0.17751270051857745],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.2307653449471585, 0.7150213270161289, 0.0542133280367126],
                                [0.2307653449471585, 0.7414769325849017, 0.027757722467939807],
                                [0.2572209505159313, 0.17751270051857748, 0.5652663489654912],
                                [0.07968885384216862, 0.7003710213181528, 0.21994012483967862],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.046910077030668074, 0.8859190326525506, 0.06717089031678133],
                                [0.046910077030668074, 0.9186978094640511, 0.0343921135052808],
                                [0.07968885384216862, 0.21994012483967862, 0.7003710213181528],
                                [0.96102643090584, 0.0281483489866802, 0.010825220107479883],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.953089922969332, 0.03728082567625269, 0.009629251354415329],
                                [0.953089922969332, 0.045217333612760625, 0.001692743417907392],
                                [0.96102643090584, 0.010825220107479883, 0.0281483489866802],
                                [0.808276820565526, 0.13847053500589301, 0.05325264442858104],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.7692346550528416, 0.18339604497922568, 0.047369299967932765],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248382],
                                [0.808276820565526, 0.05325264442858105, 0.13847053500589301],
                                [0.5845927830316645, 0.30002454449475624, 0.11538267247357925],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.5, 0.3973647885067414, 0.1026352114932586],
                                [0.5, 0.4819575715384059, 0.018042428461594096],
                                [0.5845927830316645, 0.11538267247357925, 0.30002454449475624],
                                [0.36090874549780316, 0.46157855398361936, 0.17751270051857745],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.2307653449471585, 0.611333532034257, 0.15790112301858444],
                                [0.2307653449471585, 0.7414769325849017, 0.027757722467939807],
                                [0.3609087454978031, 0.17751270051857743, 0.4615785539836194],
                                [0.20815913515748918, 0.5719007400028322, 0.21994012483967862],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.046910077030668074, 0.7574487513372301, 0.19564117163210187],
                                [0.046910077030668074, 0.9186978094640511, 0.0343921135052808],
                                [0.20815913515748918, 0.21994012483967862, 0.5719007400028322],
                                [0.9702859797219724, 0.018888800170547764, 0.010825220107479883],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.953089922969332, 0.028021276860120254, 0.018888800170547764],
                                [0.953089922969332, 0.045217333612760625, 0.001692743417907392],
                                [0.9702859797219724, 0.010825220107479883, 0.018888800170547764],
                                [0.8538274380845061, 0.09291991748691289, 0.05325264442858104],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.7692346550528416, 0.13784542746024556, 0.09291991748691289],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248382],
                                [0.8538274380845061, 0.05325264442858105, 0.09291991748691289],
                                [0.6832874495324133, 0.20132987799400742, 0.11538267247357925],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.5, 0.2986701220059926, 0.20132987799400742],
                                [0.5, 0.4819575715384059, 0.018042428461594096],
                                [0.6832874495324134, 0.11538267247357925, 0.20132987799400742],
                                [0.5127474609803206, 0.30973983850110187, 0.17751270051857745],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.23076534494715856, 0.45949481655173957, 0.3097398385011019],
                                [0.2307653449471585, 0.7414769325849017, 0.027757722467939807],
                                [0.5127474609803206, 0.17751270051857743, 0.3097398385011019],
                                [0.3962889193428544, 0.383770955817467, 0.21994012483967862],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.046910077030668074, 0.5693189671518648, 0.38377095581746706],
                                [0.046910077030668074, 0.9186978094640511, 0.0343921135052808],
                                [0.3962889193428543, 0.21994012483967856, 0.38377095581746706],
                                [0.9795455285381048, 0.009629251354415329, 0.010825220107479883],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.953089922969332, 0.01876172804398782, 0.0281483489866802],
                                [0.953089922969332, 0.045217333612760625, 0.001692743417907392],
                                [0.9795455285381048, 0.010825220107479883, 0.009629251354415329],
                                [0.8993780556034863, 0.04736929996793276, 0.05325264442858104],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.7692346550528415, 0.09229480994126543, 0.13847053500589301],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248382],
                                [0.8993780556034863, 0.053252644428581034, 0.047369299967932765],
                                [0.7819821160331621, 0.1026352114932586, 0.11538267247357925],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.5, 0.19997545550524376, 0.30002454449475624],
                                [0.5, 0.4819575715384059, 0.018042428461594096],
                                [0.7819821160331621, 0.11538267247357925, 0.1026352114932586],
                                [0.6645861764628381, 0.15790112301858442, 0.17751270051857745],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.23076534494715845, 0.3076561010692221, 0.4615785539836194],
                                [0.2307653449471585, 0.7414769325849017, 0.027757722467939807],
                                [0.664586176462838, 0.17751270051857743, 0.15790112301858444],
                                [0.5844187035282196, 0.19564117163210187, 0.21994012483967862],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.046910077030668074, 0.38118918296649973, 0.5719007400028322],
                                [0.046910077030668074, 0.9186978094640511, 0.0343921135052808],
                                [0.5844187035282196, 0.21994012483967862, 0.19564117163210187],
                                [0.9858686997808326, 0.0033060801116875926, 0.010825220107479883],
                                [0.953089922969332, 0.0016927434179073927, 0.045217333612760625],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.953089922969332, 0.012438556801260083, 0.034471520229407936],
                                [0.953089922969332, 0.045217333612760625, 0.001692743417907392],
                                [0.9858686997808325, 0.010825220107479883, 0.003306080111687593],
                                [0.9304837131796626, 0.016263642391756337, 0.05325264442858104],
                                [0.7692346550528416, 0.00832713445524838, 0.22243821049191007],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.7692346550528415, 0.061189152365088983, 0.16957619258206946],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248382],
                                [0.9304837131796626, 0.05325264442858104, 0.016263642391756337],
                                [0.8493788423121862, 0.035238485214234505, 0.11538267247357925],
                                [0.5, 0.018042428461594096, 0.4819575715384059],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.5, 0.13257872922621966, 0.36742127077378034],
                                [0.5, 0.4819575715384059, 0.018042428461594096],
                                [0.8493788423121863, 0.11538267247357925, 0.035238485214234505],
                                [0.7682739714447099, 0.054213328036712666, 0.17751270051857745],
                                [0.2307653449471585, 0.027757722467939838, 0.7414769325849017],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.2307653449471585, 0.20396830608735028, 0.5652663489654912],
                                [0.2307653449471585, 0.7414769325849017, 0.027757722467939807],
                                [0.7682739714447099, 0.17751270051857745, 0.05421332803671267],
                                [0.71288898484354, 0.06717089031678142, 0.21994012483967862],
                                [0.046910077030668074, 0.03439211350528082, 0.9186978094640511],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.046910077030668074, 0.2527189016511793, 0.7003710213181527],
                                [0.046910077030668074, 0.9186978094640511, 0.0343921135052808],
                                [0.71288898484354, 0.21994012483967862, 0.06717089031678142],
                                [0.9531883087454855, 0.0446111359274912, 0.0022005553270232096],
                                [0.9530899229693319, 0.042612194596522504, 0.0042978824341455115],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9530899229693319, 0.004199496657991901, 0.04271058037267612],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.9531883087454855, 0.002200555327023214, 0.04461113592749119],
                                [0.7697186454661836, 0.21945613442633646, 0.010825220107479893],
                                [0.7692346550528416, 0.2096227166413145, 0.021142628305843954],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7692346550528415, 0.020658637892501858, 0.2101067070546566],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.7697186454661836, 0.010825220107479883, 0.21945613442633646],
                                [0.5010486635535611, 0.4754962979311048, 0.023455038515334037],
                                [0.5, 0.45419020063284354, 0.04580979936715644],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5, 0.04476113581359531, 0.4552388641864047],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.5010486635535611, 0.023455038515334037, 0.4754962979311048],
                                [0.23237868164093867, 0.7315364614358731, 0.03608485692318818],
                                [0.2307653449471585, 0.6987576846243726, 0.07047697042846893],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.2307653449471585, 0.06886363373468873, 0.7003710213181528],
                                [0.2307653449471585, 0.0704769704284689, 0.6987576846243726],
                                [0.23237868164093867, 0.03608485692318819, 0.7315364614358731],
                                [0.04890901836163675, 0.9063814599347184, 0.04470952170364486],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016737],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.046910077030668074, 0.08532277496919871, 0.8677671480001332],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.04890901836163675, 0.04470952170364484, 0.9063814599347184],
                                [0.953573913382674, 0.04422553129030271, 0.0022005553270232096],
                                [0.9530899229693319, 0.042612194596522504, 0.0042978824341455115],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.953089922969332, 0.003813892020803414, 0.043096185009864604],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.953573913382674, 0.002200555327023214, 0.044225531290302704],
                                [0.7716155553146977, 0.21755922457782245, 0.010825220107479893],
                                [0.7692346550528416, 0.2096227166413145, 0.021142628305843954],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7692346550528415, 0.018761728043987846, 0.2120036169031706],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.7716155553146977, 0.010825220107479883, 0.21755922457782245],
                                [0.5051587040991821, 0.47138625738548395, 0.023455038515334037],
                                [0.5, 0.45419020063284354, 0.04580979936715644],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.49999999999999994, 0.040651095267974446, 0.45934890473202555],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.5051587040991821, 0.023455038515334037, 0.47138625738548395],
                                [0.2387018528836664, 0.7252132901931454, 0.03608485692318818],
                                [0.2307653449471585, 0.6987576846243726, 0.07047697042846893],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.2307653449471585, 0.06254046249196099, 0.7066941925608805],
                                [0.2307653449471585, 0.0704769704284689, 0.6987576846243726],
                                [0.2387018528836664, 0.03608485692318819, 0.7252132901931454],
                                [0.056743494815689965, 0.8985469834806652, 0.04470952170364486],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016737],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.046910077030668074, 0.07748829851514549, 0.8756016244541864],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.056743494815689965, 0.04470952170364484, 0.8985469834806652],
                                [0.9541385865228931, 0.04366085815008366, 0.0022005553270232096],
                                [0.9530899229693319, 0.042612194596522504, 0.0042978824341455115],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9530899229693319, 0.0032492188805843605, 0.04366085815008366],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.9541385865228931, 0.002200555327023207, 0.04366085815008366],
                                [0.7743933591520236, 0.21478142074049653, 0.010825220107479893],
                                [0.7692346550528416, 0.2096227166413145, 0.021142628305843954],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7692346550528415, 0.01598392420666192, 0.21478142074049653],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.7743933591520236, 0.010825220107479883, 0.21478142074049653],
                                [0.5111773804259112, 0.46536758105875475, 0.023455038515334037],
                                [0.5, 0.45419020063284354, 0.04580979936715644],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5, 0.03463241894124525, 0.46536758105875475],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.5111773804259112, 0.023455038515334037, 0.46536758105875475],
                                [0.24796140169979886, 0.715953741377013, 0.03608485692318818],
                                [0.2307653449471585, 0.6987576846243726, 0.07047697042846893],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.2307653449471585, 0.053280913675828545, 0.715953741377013],
                                [0.2307653449471585, 0.0704769704284689, 0.6987576846243726],
                                [0.24796140169979886, 0.03608485692318819, 0.715953741377013],
                                [0.06821617432892935, 0.8870743039674258, 0.04470952170364486],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016737],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.046910077030668074, 0.06601561900190611, 0.8870743039674258],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.06821617432892935, 0.04470952170364484, 0.8870743039674258],
                                [0.9547032596631122, 0.04309618500986462, 0.0022005553270232096],
                                [0.9530899229693319, 0.042612194596522504, 0.0042978824341455115],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9530899229693319, 0.002684545740365314, 0.044225531290302704],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.9547032596631122, 0.002200555327023214, 0.04309618500986461],
                                [0.7771711629893495, 0.21200361690317063, 0.010825220107479893],
                                [0.7692346550528416, 0.2096227166413145, 0.021142628305843954],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7692346550528416, 0.013206120369336022, 0.21755922457782242],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.7771711629893495, 0.010825220107479883, 0.21200361690317063],
                                [0.5171960567526404, 0.4593489047320256, 0.023455038515334037],
                                [0.5, 0.45419020063284354, 0.04580979936715644],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5, 0.028613742614516102, 0.4713862573854839],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.5171960567526404, 0.023455038515334037, 0.4593489047320256],
                                [0.2572209505159313, 0.7066941925608805, 0.03608485692318818],
                                [0.2307653449471585, 0.6987576846243726, 0.07047697042846893],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.2307653449471585, 0.04402136485969621, 0.7252132901931453],
                                [0.2307653449471585, 0.0704769704284689, 0.6987576846243726],
                                [0.2572209505159313, 0.03608485692318819, 0.7066941925608805],
                                [0.07968885384216862, 0.8756016244541865, 0.04470952170364486],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016737],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.046910077030668074, 0.05454293948866684, 0.8985469834806651],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.07968885384216862, 0.04470952170364484, 0.8756016244541865],
                                [0.9550888643003006, 0.042710580372676124, 0.0022005553270232096],
                                [0.9530899229693319, 0.042612194596522504, 0.0042978824341455115],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9530899229693319, 0.002298941103176827, 0.04461113592749119],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.9550888643003006, 0.002200555327023214, 0.04271058037267612],
                                [0.7790680728378635, 0.2101067070546566, 0.010825220107479893],
                                [0.7692346550528416, 0.2096227166413145, 0.021142628305843954],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7692346550528415, 0.011309210520821983, 0.21945613442633646],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.7790680728378635, 0.010825220107479883, 0.2101067070546566],
                                [0.5213060972982613, 0.4552388641864047, 0.023455038515334037],
                                [0.5, 0.45419020063284354, 0.04580979936715644],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5, 0.024503702068895183, 0.4754962979311048],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.5213060972982613, 0.023455038515334037, 0.4552388641864047],
                                [0.26354412175865904, 0.7003710213181528, 0.03608485692318818],
                                [0.2307653449471585, 0.6987576846243726, 0.07047697042846893],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.2307653449471585, 0.037698193616968356, 0.7315364614358731],
                                [0.2307653449471585, 0.0704769704284689, 0.6987576846243726],
                                [0.26354412175865904, 0.03608485692318819, 0.7003710213181528],
                                [0.08752333029622195, 0.8677671480001332, 0.04470952170364486],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016737],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.046910077030668074, 0.04670846303461351, 0.9063814599347184],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.08752333029622195, 0.04470952170364484, 0.8677671480001332],
                                [0.953573913382674, 0.04422553129030271, 0.0022005553270232096],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.953089922969332, 0.012033973112045175, 0.03487610391862284],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.953573913382674, 0.002200555327023214, 0.044225531290302704],
                                [0.7716155553146977, 0.21755922457782245, 0.010825220107479893],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.7692346550528415, 0.059198878621973317, 0.17156646632518513],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7716155553146977, 0.010825220107479883, 0.21755922457782245],
                                [0.5051587040991821, 0.47138625738548395, 0.023455038515334037],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5, 0.12826639683599134, 0.37173360316400866],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5051587040991821, 0.023455038515334037, 0.47138625738548395],
                                [0.2387018528836664, 0.7252132901931454, 0.03608485692318818],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.2307653449471585, 0.1973339150500093, 0.5719007400028322],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.2387018528836664, 0.03608485692318819, 0.7252132901931454],
                                [0.056743494815689965, 0.8985469834806652, 0.04470952170364486],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.046910077030668074, 0.24449882055993744, 0.7085911024093945],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.056743494815689965, 0.04470952170364484, 0.8985469834806652],
                                [0.955470823231188, 0.042328621441788686, 0.0022005553270232096],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.953089922969332, 0.01013706326353115, 0.03677301376713687],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.955470823231188, 0.002200555327023207, 0.042328621441788686],
                                [0.7809470483165066, 0.20822773157601346, 0.010825220107479893],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.7692346550528415, 0.049867385620164295, 0.18089795932699415],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7809470483165066, 0.01082522010747991, 0.20822773157601343],
                                [0.5253772793881748, 0.4511676820964912, 0.023455038515334037],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5, 0.1080478215469986, 0.3919521784530014],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5253772793881748, 0.023455038515334037, 0.4511676820964912],
                                [0.26980751045984286, 0.694107632616969, 0.03608485692318818],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.2307653449471585, 0.16622825747383285, 0.6030063975790086],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.26980751045984286, 0.03608485692318819, 0.694107632616969],
                                [0.09528373554516145, 0.8600067427511937, 0.04470952170364486],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.046910077030668074, 0.20595857983046606, 0.7471313431388659],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.09528373554516145, 0.04470952170364484, 0.8600067427511937],
                                [0.958248627068514, 0.03955081760446278, 0.0022005553270232096],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.9530899229693319, 0.007359259426205245, 0.039550817604462774],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.958248627068514, 0.002200555327023214, 0.039550817604462774],
                                [0.7946119344410163, 0.1945628454515038, 0.010825220107479893],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.7692346550528415, 0.036202499495654655, 0.1945628454515038],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7946119344410163, 0.010825220107479883, 0.1945628454515038],
                                [0.5549850312099196, 0.4215599302747463, 0.023455038515334037],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.49999999999999994, 0.07844006972525369, 0.4215599302747463],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5549850312099196, 0.023455038515334037, 0.4215599302747463],
                                [0.315358127978823, 0.6485570150979888, 0.03608485692318818],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.2307653449471585, 0.1206776399548527, 0.6485570150979888],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.315358127978823, 0.03608485692318819, 0.6485570150979888],
                                [0.15172143535132532, 0.8035690429450298, 0.04470952170364486],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.046910077030668074, 0.14952088002430208, 0.8035690429450298],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.15172143535132532, 0.04470952170364484, 0.8035690429450298],
                                [0.9610264309058398, 0.036773013767136875, 0.0022005553270232096],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.9530899229693319, 0.004581455588879339, 0.04232862144178868],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.96102643090584, 0.002200555327023214, 0.03677301376713687],
                                [0.808276820565526, 0.18089795932699418, 0.010825220107479893],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.7692346550528416, 0.022537613371145043, 0.2082277315760134],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.808276820565526, 0.010825220107479883, 0.18089795932699418],
                                [0.5845927830316645, 0.39195217845300145, 0.023455038515334037],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5, 0.04883231790350884, 0.45116768209649116],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5845927830316645, 0.023455038515334037, 0.39195217845300145],
                                [0.36090874549780316, 0.6030063975790086, 0.03608485692318818],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.2307653449471585, 0.07512702243587266, 0.6941076326169688],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.36090874549780316, 0.03608485692318819, 0.6030063975790086],
                                [0.20815913515748918, 0.747131343138866, 0.04470952170364486],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.046910077030668074, 0.09308318021813833, 0.8600067427511936],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.20815913515748918, 0.04470952170364484, 0.747131343138866],
                                [0.9629233407543539, 0.03487610391862286, 0.0022005553270232096],
                                [0.953089922969332, 0.03439211350528075, 0.012517963525387272],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.9530899229693319, 0.002684545740365314, 0.044225531290302704],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.9629233407543539, 0.002200555327023214, 0.03487610391862285],
                                [0.8176083135673349, 0.17156646632518519, 0.010825220107479893],
                                [0.7692346550528416, 0.16918556606332905, 0.06157977888382941],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.7692346550528416, 0.013206120369336022, 0.21755922457782242],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.817608313567335, 0.01082522010747991, 0.17156646632518516],
                                [0.6048113583206572, 0.3717336031640087, 0.023455038515334037],
                                [0.5, 0.36657489906482665, 0.13342510093517332],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5, 0.028613742614516102, 0.4713862573854839],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.6048113583206572, 0.023455038515334037, 0.3717336031640087],
                                [0.3920144030739796, 0.5719007400028322, 0.03608485692318818],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.2307653449471585, 0.04402136485969621, 0.7252132901931453],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.3920144030739796, 0.03608485692318819, 0.5719007400028322],
                                [0.24669937588696056, 0.7085911024093946, 0.04470952170364486],
                                [0.046910077030668074, 0.6987576846243726, 0.2543322383449593],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.046910077030668074, 0.05454293948866684, 0.8985469834806651],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.24669937588696056, 0.04470952170364495, 0.7085911024093945],
                                [0.9541385865228931, 0.04366085815008366, 0.0022005553270232096],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9530899229693319, 0.023506652625284463, 0.023403424405383556],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9541385865228931, 0.002200555327023207, 0.04366085815008366],
                                [0.7743933591520236, 0.21478142074049653, 0.010825220107479893],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.7692346550528416, 0.11563657842813714, 0.1151287665190213],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7743933591520236, 0.010825220107479883, 0.21478142074049653],
                                [0.5111773804259112, 0.46536758105875475, 0.023455038515334037],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.5, 0.2505501388317558, 0.2494498611682442],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5111773804259112, 0.023455038515334037, 0.46536758105875475],
                                [0.24796140169979886, 0.715953741377013, 0.03608485692318818],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.23076534494715845, 0.38546369923537444, 0.38377095581746706],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.24796140169979886, 0.03608485692318819, 0.715953741377013],
                                [0.06821617432892935, 0.8870743039674258, 0.04470952170364486],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.046910077030668074, 0.4775936250382271, 0.4754962979311048],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.06821617432892935, 0.04470952170364484, 0.8870743039674258],
                                [0.958248627068514, 0.03955081760446278, 0.0022005553270232096],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9530899229693319, 0.019396612079663582, 0.027513464951004436],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.958248627068514, 0.002200555327023214, 0.039550817604462774],
                                [0.7946119344410163, 0.1945628454515038, 0.010825220107479893],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.7692346550528416, 0.09541800313914439, 0.13534734180801405],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7946119344410163, 0.010825220107479883, 0.1945628454515038],
                                [0.5549850312099196, 0.4215599302747463, 0.023455038515334037],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.49999999999999994, 0.20674248804774736, 0.29325751195225264],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5549850312099196, 0.023455038515334037, 0.4215599302747463],
                                [0.315358127978823, 0.6485570150979888, 0.03608485692318818],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.23076534494715856, 0.3180669729563503, 0.4511676820964912],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.315358127978823, 0.03608485692318819, 0.6485570150979888],
                                [0.15172143535132532, 0.8035690429450298, 0.04470952170364486],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.046910077030668074, 0.39408836401583114, 0.5590015589535008],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.15172143535132532, 0.04470952170364484, 0.8035690429450298],
                                [0.9642673033952431, 0.03353214127773361, 0.0022005553270232096],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9530899229693319, 0.01337793575293441, 0.03353214127773361],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9642673033952431, 0.002200555327023207, 0.03353214127773361],
                                [0.8242196862627612, 0.16495509362975894, 0.010825220107479893],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.7692346550528415, 0.06581025131739954, 0.1649550936297589],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.8242196862627612, 0.01082522010747991, 0.1649550936297589],
                                [0.6191362403711664, 0.3574087211134995, 0.023455038515334037],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.49999999999999994, 0.14259127888650053, 0.3574087211134995],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.6191362403711664, 0.023455038515334037, 0.3574087211134995],
                                [0.4140527944795719, 0.5498623485972399, 0.03608485692318818],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.2307653449471585, 0.21937230645560146, 0.54986234859724],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.4140527944795719, 0.03608485692318808, 0.54986234859724],
                                [0.27400517734708985, 0.6812853009492653, 0.04470952170364486],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.046910077030668074, 0.2718046220200666, 0.6812853009492653],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.27400517734708985, 0.04470952170364484, 0.6812853009492653],
                                [0.9702859797219723, 0.027513464951004436, 0.0022005553270232096],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9530899229693319, 0.007359259426205245, 0.039550817604462774],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9702859797219723, 0.0022005553270232105, 0.027513464951004436],
                                [0.8538274380845061, 0.13534734180801405, 0.010825220107479893],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.7692346550528415, 0.036202499495654655, 0.1945628454515038],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.8538274380845061, 0.010825220107479883, 0.13534734180801405],
                                [0.6832874495324133, 0.29325751195225264, 0.023455038515334037],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.49999999999999994, 0.07844006972525369, 0.4215599302747463],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.6832874495324133, 0.023455038515334037, 0.29325751195225264],
                                [0.5127474609803206, 0.45116768209649116, 0.03608485692318818],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.2307653449471585, 0.1206776399548527, 0.6485570150979888],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.5127474609803206, 0.036084856923188136, 0.4511676820964912],
                                [0.3962889193428544, 0.5590015589535008, 0.04470952170364486],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.046910077030668074, 0.14952088002430208, 0.8035690429450298],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.3962889193428544, 0.04470952170364484, 0.5590015589535008],
                                [0.9743960202675932, 0.023403424405383556, 0.0022005553270232096],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9530899229693319, 0.0032492188805843605, 0.04366085815008366],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9743960202675932, 0.0022005553270232105, 0.023403424405383556],
                                [0.8740460133734989, 0.1151287665190213, 0.010825220107479893],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.7692346550528415, 0.01598392420666192, 0.21478142074049653],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.8740460133734989, 0.010825220107479896, 0.1151287665190213],
                                [0.7270951003164218, 0.2494498611682442, 0.023455038515334037],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.5, 0.03463241894124525, 0.46536758105875475],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.7270951003164218, 0.023455038515334037, 0.2494498611682442],
                                [0.5801441872593448, 0.383770955817467, 0.03608485692318818],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.2307653449471585, 0.053280913675828545, 0.715953741377013],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.5801441872593447, 0.036084856923188136, 0.38377095581746706],
                                [0.47979418036525034, 0.4754962979311048, 0.04470952170364486],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.046910077030668074, 0.06601561900190611, 0.8870743039674258],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.47979418036525034, 0.04470952170364484, 0.4754962979311048],
                                [0.9547032596631122, 0.04309618500986462, 0.0022005553270232096],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.9530899229693319, 0.03497933213852376, 0.011930744892144263],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364065],
                                [0.9547032596631122, 0.002200555327023214, 0.04309618500986461],
                                [0.7771711629893495, 0.21200361690317063, 0.010825220107479893],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.7692346550528415, 0.172074278234301, 0.05869106671285747],
                                [0.7692346550528416, 0.1800107861708089, 0.05075455877634953],
                                [0.7771711629893495, 0.010825220107479883, 0.21200361690317063],
                                [0.5171960567526404, 0.4593489047320256, 0.023455038515334037],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.5, 0.37283388082752034, 0.1271661191724797],
                                [0.5, 0.3900299375801607, 0.10997006241983931],
                                [0.5171960567526404, 0.023455038515334037, 0.4593489047320256],
                                [0.2572209505159313, 0.7066941925608805, 0.03608485692318818],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.2307653449471585, 0.5735934834207396, 0.1956411716321019],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332907],
                                [0.2572209505159313, 0.03608485692318819, 0.7066941925608805],
                                [0.07968885384216862, 0.8756016244541865, 0.04470952170364486],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.046910077030668074, 0.7106884295165168, 0.24240149345281511],
                                [0.046910077030668074, 0.7434672063280174, 0.20962271664131454],
                                [0.07968885384216862, 0.04470952170364484, 0.8756016244541865],
                                [0.9610264309058398, 0.036773013767136875, 0.0022005553270232096],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.9530899229693319, 0.028656160895796017, 0.018253916134872],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364065],
                                [0.96102643090584, 0.002200555327023214, 0.03677301376713687],
                                [0.808276820565526, 0.18089795932699418, 0.010825220107479893],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.7692346550528415, 0.14096862065812454, 0.08979672428903392],
                                [0.7692346550528416, 0.1800107861708089, 0.05075455877634953],
                                [0.808276820565526, 0.010825220107479883, 0.18089795932699418],
                                [0.5845927830316645, 0.39195217845300145, 0.023455038515334037],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.5, 0.3054371545484962, 0.19456284545150382],
                                [0.5, 0.3900299375801607, 0.10997006241983931],
                                [0.5845927830316645, 0.023455038515334037, 0.39195217845300145],
                                [0.36090874549780316, 0.6030063975790086, 0.03608485692318818],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.2307653449471585, 0.4699056884388678, 0.2993289666139737],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332907],
                                [0.36090874549780316, 0.03608485692318819, 0.6030063975790086],
                                [0.20815913515748918, 0.747131343138866, 0.04470952170364486],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.046910077030668074, 0.5822181482011963, 0.3708717747681356],
                                [0.046910077030668074, 0.7434672063280174, 0.20962271664131454],
                                [0.20815913515748918, 0.04470952170364484, 0.747131343138866],
                                [0.9702859797219723, 0.027513464951004436, 0.0022005553270232096],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.9530899229693319, 0.019396612079663582, 0.027513464951004436],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364065],
                                [0.9702859797219723, 0.0022005553270232105, 0.027513464951004436],
                                [0.8538274380845061, 0.13534734180801405, 0.010825220107479893],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.7692346550528416, 0.09541800313914439, 0.13534734180801405],
                                [0.7692346550528416, 0.1800107861708089, 0.05075455877634953],
                                [0.8538274380845061, 0.010825220107479883, 0.13534734180801405],
                                [0.6832874495324133, 0.29325751195225264, 0.023455038515334037],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.49999999999999994, 0.20674248804774736, 0.29325751195225264],
                                [0.5, 0.3900299375801607, 0.10997006241983931],
                                [0.6832874495324133, 0.023455038515334037, 0.29325751195225264],
                                [0.5127474609803206, 0.45116768209649116, 0.03608485692318818],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.23076534494715856, 0.3180669729563503, 0.4511676820964912],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332907],
                                [0.5127474609803206, 0.036084856923188136, 0.4511676820964912],
                                [0.3962889193428544, 0.5590015589535008, 0.04470952170364486],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.046910077030668074, 0.39408836401583114, 0.5590015589535008],
                                [0.046910077030668074, 0.7434672063280174, 0.20962271664131454],
                                [0.3962889193428544, 0.04470952170364484, 0.5590015589535008],
                                [0.9795455285381047, 0.018253916134872, 0.0022005553270232096],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.953089922969332, 0.01013706326353115, 0.03677301376713687],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364065],
                                [0.9795455285381047, 0.0022005553270232105, 0.018253916134872],
                                [0.8993780556034863, 0.0897967242890339, 0.010825220107479893],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.7692346550528416, 0.04986738562016427, 0.18089795932699418],
                                [0.7692346550528416, 0.1800107861708089, 0.05075455877634953],
                                [0.8993780556034862, 0.010825220107479883, 0.08979672428903392],
                                [0.7819821160331621, 0.19456284545150382, 0.023455038515334037],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.5, 0.10804782154699855, 0.39195217845300145],
                                [0.5, 0.3900299375801607, 0.10997006241983931],
                                [0.7819821160331621, 0.023455038515334037, 0.19456284545150382],
                                [0.6645861764628381, 0.2993289666139737, 0.03608485692318818],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.2307653449471585, 0.16622825747383285, 0.6030063975790086],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332907],
                                [0.6645861764628381, 0.03608485692318819, 0.2993289666139737],
                                [0.5844187035282196, 0.37087177476813565, 0.04470952170364486],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.046910077030668074, 0.20595857983046595, 0.747131343138866],
                                [0.046910077030668074, 0.7434672063280174, 0.20962271664131454],
                                [0.5844187035282196, 0.044709521703644894, 0.3708717747681356],
                                [0.9858686997808325, 0.011930744892144265, 0.0022005553270232096],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.953089922969332, 0.003813892020803414, 0.043096185009864604],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364065],
                                [0.9858686997808325, 0.0022005553270232105, 0.011930744892144265],
                                [0.9304837131796626, 0.05869106671285748, 0.010825220107479893],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.7692346550528415, 0.018761728043987846, 0.2120036169031706],
                                [0.7692346550528416, 0.1800107861708089, 0.05075455877634953],
                                [0.9304837131796626, 0.010825220107479896, 0.05869106671285748],
                                [0.8493788423121862, 0.12716611917247972, 0.023455038515334037],
                                [0.5, 0.10997006241983931, 0.3900299375801607],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.49999999999999994, 0.040651095267974446, 0.45934890473202555],
                                [0.5, 0.3900299375801607, 0.10997006241983931],
                                [0.8493788423121862, 0.023455038515334037, 0.12716611917247972],
                                [0.7682739714447099, 0.19564117163210193, 0.03608485692318818],
                                [0.2307653449471585, 0.16918556606332913, 0.6000490889895124],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.2307653449471585, 0.06254046249196099, 0.7066941925608805],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332907],
                                [0.7682739714447099, 0.03608485692318819, 0.19564117163210193],
                                [0.71288898484354, 0.24240149345281517, 0.04470952170364486],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.046910077030668074, 0.07748829851514549, 0.8756016244541864],
                                [0.046910077030668074, 0.7434672063280174, 0.20962271664131454],
                                [0.71288898484354, 0.04470952170364487, 0.24240149345281517],
                                [0.9550888643003006, 0.042710580372676124, 0.0022005553270232096],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.953089922969332, 0.04281380859257703, 0.004096268438090989],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122303],
                                [0.9550888643003006, 0.002200555327023214, 0.04271058037267612],
                                [0.7790680728378635, 0.2101067070546566, 0.010825220107479893],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.7692346550528415, 0.21061451896377242, 0.020150825983386026],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364068],
                                [0.7790680728378635, 0.010825220107479883, 0.2101067070546566],
                                [0.5213060972982613, 0.4552388641864047, 0.023455038515334037],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.5, 0.4563391418499163, 0.04366085815008367],
                                [0.5, 0.4776452391481776, 0.02235476085182242],
                                [0.5213060972982613, 0.023455038515334037, 0.4552388641864047],
                                [0.26354412175865904, 0.7003710213181528, 0.03608485692318818],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.2307653449471585, 0.7020637647360601, 0.0671708903167813],
                                [0.2307653449471585, 0.7348425415475607, 0.03439211350528077],
                                [0.26354412175865904, 0.03608485692318819, 0.7003710213181528],
                                [0.08752333029622195, 0.8677671480001332, 0.04470952170364486],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.046910077030668074, 0.8698644751072556, 0.08322544786207635],
                                [0.046910077030668074, 0.9104777283728094, 0.04261219459652253],
                                [0.08752333029622195, 0.04470952170364484, 0.8677671480001332],
                                [0.9629233407543539, 0.03487610391862286, 0.0022005553270232096],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9530899229693319, 0.03497933213852376, 0.01193074489214426],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122303],
                                [0.9629233407543539, 0.002200555327023214, 0.03487610391862285],
                                [0.8176083135673349, 0.17156646632518519, 0.010825220107479893],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.7692346550528415, 0.172074278234301, 0.05869106671285746],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364068],
                                [0.817608313567335, 0.01082522010747991, 0.17156646632518516],
                                [0.6048113583206572, 0.3717336031640087, 0.023455038515334037],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.5, 0.37283388082752034, 0.12716611917247966],
                                [0.5, 0.4776452391481776, 0.02235476085182242],
                                [0.6048113583206572, 0.023455038515334037, 0.3717336031640087],
                                [0.3920144030739796, 0.5719007400028322, 0.03608485692318818],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.2307653449471585, 0.5735934834207397, 0.19564117163210185],
                                [0.2307653449471585, 0.7348425415475607, 0.03439211350528077],
                                [0.3920144030739796, 0.03608485692318819, 0.5719007400028322],
                                [0.24669937588696056, 0.7085911024093946, 0.04470952170364486],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.046910077030668074, 0.7106884295165169, 0.24240149345281506],
                                [0.046910077030668074, 0.9104777283728094, 0.04261219459652253],
                                [0.24669937588696056, 0.04470952170364495, 0.7085911024093945],
                                [0.9743960202675932, 0.023403424405383556, 0.0022005553270232096],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9530899229693319, 0.023506652625284463, 0.023403424405383556],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122303],
                                [0.9743960202675932, 0.0022005553270232105, 0.023403424405383556],
                                [0.8740460133734989, 0.1151287665190213, 0.010825220107479893],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.7692346550528416, 0.11563657842813714, 0.1151287665190213],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364068],
                                [0.8740460133734989, 0.010825220107479896, 0.1151287665190213],
                                [0.7270951003164218, 0.2494498611682442, 0.023455038515334037],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.5, 0.2505501388317558, 0.2494498611682442],
                                [0.5, 0.4776452391481776, 0.02235476085182242],
                                [0.7270951003164218, 0.023455038515334037, 0.2494498611682442],
                                [0.5801441872593448, 0.383770955817467, 0.03608485692318818],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.23076534494715845, 0.38546369923537444, 0.38377095581746706],
                                [0.2307653449471585, 0.7348425415475607, 0.03439211350528077],
                                [0.5801441872593447, 0.036084856923188136, 0.38377095581746706],
                                [0.47979418036525034, 0.4754962979311048, 0.04470952170364486],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.046910077030668074, 0.4775936250382271, 0.4754962979311048],
                                [0.046910077030668074, 0.9104777283728094, 0.04261219459652253],
                                [0.47979418036525034, 0.04470952170364484, 0.4754962979311048],
                                [0.9858686997808325, 0.011930744892144261, 0.0022005553270232096],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.953089922969332, 0.012033973112045168, 0.03487610391862285],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122303],
                                [0.9858686997808325, 0.0022005553270232105, 0.01193074489214426],
                                [0.9304837131796626, 0.058691066712857454, 0.010825220107479893],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.7692346550528416, 0.05919887862197329, 0.17156646632518516],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364068],
                                [0.9304837131796626, 0.01082522010747989, 0.05869106671285746],
                                [0.8493788423121863, 0.12716611917247966, 0.023455038515334037],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.5, 0.12826639683599128, 0.3717336031640087],
                                [0.5, 0.4776452391481776, 0.02235476085182242],
                                [0.8493788423121863, 0.023455038515334037, 0.12716611917247966],
                                [0.76827397144471, 0.19564117163210187, 0.03608485692318818],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.2307653449471585, 0.1973339150500093, 0.5719007400028322],
                                [0.2307653449471585, 0.7348425415475607, 0.03439211350528077],
                                [0.76827397144471, 0.03608485692318819, 0.19564117163210185],
                                [0.7128889848435401, 0.24240149345281506, 0.04470952170364486],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.046910077030668074, 0.24449882055993744, 0.7085911024093945],
                                [0.046910077030668074, 0.9104777283728094, 0.04261219459652253],
                                [0.7128889848435401, 0.04470952170364487, 0.24240149345281506],
                                [0.9937031762348858, 0.0040962684380909916, 0.0022005553270232096],
                                [0.953089922969332, 0.0020973271071223, 0.04481274992354572],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9530899229693319, 0.004199496657991901, 0.04271058037267612],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122303],
                                [0.9937031762348858, 0.0022005553270232105, 0.004096268438090991],
                                [0.9690239539091341, 0.020150825983386033, 0.010825220107479893],
                                [0.7692346550528415, 0.010317408198364075, 0.22044793674879437],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.7692346550528415, 0.020658637892501858, 0.2101067070546566],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364068],
                                [0.9690239539091341, 0.01082522010747989, 0.020150825983386036],
                                [0.9328841033345823, 0.04366085815008369, 0.023455038515334037],
                                [0.5, 0.02235476085182242, 0.4776452391481776],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.5, 0.04476113581359531, 0.4552388641864047],
                                [0.5, 0.4776452391481776, 0.02235476085182242],
                                [0.9328841033345823, 0.023455038515334037, 0.04366085815008369],
                                [0.8967442527600304, 0.06717089031678135, 0.03608485692318818],
                                [0.2307653449471585, 0.03439211350528082, 0.7348425415475607],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.2307653449471585, 0.06886363373468873, 0.7003710213181528],
                                [0.2307653449471585, 0.7348425415475607, 0.03439211350528077],
                                [0.8967442527600304, 0.03608485692318818, 0.06717089031678135],
                                [0.8720650304342787, 0.08322544786207639, 0.04470952170364486],
                                [0.046910077030668074, 0.042612194596522546, 0.9104777283728094],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.046910077030668074, 0.08532277496919871, 0.8677671480001332],
                                [0.046910077030668074, 0.9104777283728094, 0.04261219459652253],
                                [0.8720650304342787, 0.04470952170364487, 0.08322544786207639],
                            ]
                        ),
                        np.array(
                            [
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                5.039035053760971e-12,
                                5.039035053760971e-12,
                                5.039035053760971e-12,
                                5.039035053760971e-12,
                                5.039035053760971e-12,
                                5.039035053760971e-12,
                                1.2118394177698019e-09,
                                1.2118394177698019e-09,
                                1.2118394177698019e-09,
                                1.2118394177698019e-09,
                                1.2118394177698019e-09,
                                1.2118394177698019e-09,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                4.488588899343874e-08,
                                4.488588899343874e-08,
                                4.488588899343874e-08,
                                4.488588899343874e-08,
                                4.488588899343874e-08,
                                4.488588899343874e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                5.0076756091361244e-11,
                                5.0076756091361244e-11,
                                5.0076756091361244e-11,
                                5.0076756091361244e-11,
                                5.0076756091361244e-11,
                                5.0076756091361244e-11,
                                1.2042977732465322e-08,
                                1.2042977732465322e-08,
                                1.2042977732465322e-08,
                                1.2042977732465322e-08,
                                1.2042977732465322e-08,
                                1.2042977732465322e-08,
                                1.4559983058168736e-07,
                                1.4559983058168736e-07,
                                1.4559983058168736e-07,
                                1.4559983058168736e-07,
                                1.4559983058168736e-07,
                                1.4559983058168736e-07,
                                4.460655048213463e-07,
                                4.460655048213463e-07,
                                4.460655048213463e-07,
                                4.460655048213463e-07,
                                4.460655048213463e-07,
                                4.460655048213463e-07,
                                4.1999041888589887e-07,
                                4.1999041888589887e-07,
                                4.1999041888589887e-07,
                                4.1999041888589887e-07,
                                4.1999041888589887e-07,
                                4.1999041888589887e-07,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                1.2896276756638474e-10,
                                1.2896276756638474e-10,
                                1.2896276756638474e-10,
                                1.2896276756638474e-10,
                                1.2896276756638474e-10,
                                1.2896276756638474e-10,
                                3.1014304027312935e-08,
                                3.1014304027312935e-08,
                                3.1014304027312935e-08,
                                3.1014304027312935e-08,
                                3.1014304027312935e-08,
                                3.1014304027312935e-08,
                                3.7496352748476776e-07,
                                3.7496352748476776e-07,
                                3.7496352748476776e-07,
                                3.7496352748476776e-07,
                                3.7496352748476776e-07,
                                3.7496352748476776e-07,
                                1.1487533639899882e-06,
                                1.1487533639899882e-06,
                                1.1487533639899882e-06,
                                1.1487533639899882e-06,
                                1.1487533639899882e-06,
                                1.1487533639899882e-06,
                                1.0816021443576382e-06,
                                1.0816021443576382e-06,
                                1.0816021443576382e-06,
                                1.0816021443576382e-06,
                                1.0816021443576382e-06,
                                1.0816021443576382e-06,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.6692617432190342e-10,
                                1.6692617432190342e-10,
                                1.6692617432190342e-10,
                                1.6692617432190342e-10,
                                1.6692617432190342e-10,
                                1.6692617432190342e-10,
                                4.014413786421567e-08,
                                4.014413786421567e-08,
                                4.014413786421567e-08,
                                4.014413786421567e-08,
                                4.014413786421567e-08,
                                4.014413786421567e-08,
                                4.853433927824073e-07,
                                4.853433927824073e-07,
                                4.853433927824073e-07,
                                4.853433927824073e-07,
                                4.853433927824073e-07,
                                4.853433927824073e-07,
                                1.4869175647270216e-06,
                                1.4869175647270216e-06,
                                1.4869175647270216e-06,
                                1.4869175647270216e-06,
                                1.4869175647270216e-06,
                                1.4869175647270216e-06,
                                1.3999987089533349e-06,
                                1.3999987089533349e-06,
                                1.3999987089533349e-06,
                                1.3999987089533349e-06,
                                1.3999987089533349e-06,
                                1.3999987089533349e-06,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                1.0237999669216095e-10,
                                1.0237999669216095e-10,
                                1.0237999669216095e-10,
                                1.0237999669216095e-10,
                                1.0237999669216095e-10,
                                1.0237999669216095e-10,
                                2.4621403554258304e-08,
                                2.4621403554258304e-08,
                                2.4621403554258304e-08,
                                2.4621403554258304e-08,
                                2.4621403554258304e-08,
                                2.4621403554258304e-08,
                                2.976732387804145e-07,
                                2.976732387804145e-07,
                                2.976732387804145e-07,
                                2.976732387804145e-07,
                                2.976732387804145e-07,
                                2.976732387804145e-07,
                                9.119637227455072e-07,
                                9.119637227455072e-07,
                                9.119637227455072e-07,
                                9.119637227455072e-07,
                                9.119637227455072e-07,
                                9.119637227455072e-07,
                                8.58654215097917e-07,
                                8.58654215097917e-07,
                                8.58654215097917e-07,
                                8.58654215097917e-07,
                                8.58654215097917e-07,
                                8.58654215097917e-07,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                2.4634322995681364e-10,
                                2.4634322995681364e-10,
                                2.4634322995681364e-10,
                                2.4634322995681364e-10,
                                2.4634322995681364e-10,
                                2.4634322995681364e-10,
                                5.924317516695693e-08,
                                5.924317516695693e-08,
                                5.924317516695693e-08,
                                5.924317516695693e-08,
                                5.924317516695693e-08,
                                5.924317516695693e-08,
                                7.162511182078193e-07,
                                7.162511182078193e-07,
                                7.162511182078193e-07,
                                7.162511182078193e-07,
                                7.162511182078193e-07,
                                7.162511182078193e-07,
                                2.194335771860499e-06,
                                2.194335771860499e-06,
                                2.194335771860499e-06,
                                2.194335771860499e-06,
                                2.194335771860499e-06,
                                2.194335771860499e-06,
                                2.066064266433498e-06,
                                2.066064266433498e-06,
                                2.066064266433498e-06,
                                2.066064266433498e-06,
                                2.066064266433498e-06,
                                2.066064266433498e-06,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                2.4481016126486817e-09,
                                2.4481016126486817e-09,
                                2.4481016126486817e-09,
                                2.4481016126486817e-09,
                                2.4481016126486817e-09,
                                2.4481016126486817e-09,
                                5.887448690596504e-07,
                                5.887448690596504e-07,
                                5.887448690596504e-07,
                                5.887448690596504e-07,
                                5.887448690596504e-07,
                                5.887448690596504e-07,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                2.1806797543111425e-05,
                                2.1806797543111425e-05,
                                2.1806797543111425e-05,
                                2.1806797543111425e-05,
                                2.1806797543111425e-05,
                                2.1806797543111425e-05,
                                2.053206521396333e-05,
                                2.053206521396333e-05,
                                2.053206521396333e-05,
                                2.053206521396333e-05,
                                2.053206521396333e-05,
                                2.053206521396333e-05,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                6.304600854634184e-09,
                                6.304600854634184e-09,
                                6.304600854634184e-09,
                                6.304600854634184e-09,
                                6.304600854634184e-09,
                                6.304600854634184e-09,
                                1.5161958088083776e-06,
                                1.5161958088083776e-06,
                                1.5161958088083776e-06,
                                1.5161958088083776e-06,
                                1.5161958088083776e-06,
                                1.5161958088083776e-06,
                                1.8330836259544657e-05,
                                1.8330836259544657e-05,
                                1.8330836259544657e-05,
                                1.8330836259544657e-05,
                                1.8330836259544657e-05,
                                1.8330836259544657e-05,
                                5.6159088216271936e-05,
                                5.6159088216271936e-05,
                                5.6159088216271936e-05,
                                5.6159088216271936e-05,
                                5.6159088216271936e-05,
                                5.6159088216271936e-05,
                                5.2876267564443766e-05,
                                5.2876267564443766e-05,
                                5.2876267564443766e-05,
                                5.2876267564443766e-05,
                                5.2876267564443766e-05,
                                5.2876267564443766e-05,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                8.160517342720278e-09,
                                8.160517342720278e-09,
                                8.160517342720278e-09,
                                8.160517342720278e-09,
                                8.160517342720278e-09,
                                8.160517342720278e-09,
                                1.9625258565965933e-06,
                                1.9625258565965933e-06,
                                1.9625258565965933e-06,
                                1.9625258565965933e-06,
                                1.9625258565965933e-06,
                                1.9625258565965933e-06,
                                2.3726975053880647e-05,
                                2.3726975053880647e-05,
                                2.3726975053880647e-05,
                                2.3726975053880647e-05,
                                2.3726975053880647e-05,
                                2.3726975053880647e-05,
                                7.26909163493486e-05,
                                7.26909163493486e-05,
                                7.26909163493486e-05,
                                7.26909163493486e-05,
                                7.26909163493486e-05,
                                7.26909163493486e-05,
                                6.844171557042976e-05,
                                6.844171557042976e-05,
                                6.844171557042976e-05,
                                6.844171557042976e-05,
                                6.844171557042976e-05,
                                6.844171557042976e-05,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                5.005049339613342e-09,
                                5.005049339613342e-09,
                                5.005049339613342e-09,
                                5.005049339613342e-09,
                                5.005049339613342e-09,
                                5.005049339613342e-09,
                                1.203666180710374e-06,
                                1.203666180710374e-06,
                                1.203666180710374e-06,
                                1.203666180710374e-06,
                                1.203666180710374e-06,
                                1.203666180710374e-06,
                                1.4552347092354948e-05,
                                1.4552347092354948e-05,
                                1.4552347092354948e-05,
                                1.4552347092354948e-05,
                                1.4552347092354948e-05,
                                1.4552347092354948e-05,
                                4.4583156629738534e-05,
                                4.4583156629738534e-05,
                                4.4583156629738534e-05,
                                4.4583156629738534e-05,
                                4.4583156629738534e-05,
                                4.4583156629738534e-05,
                                4.1977015540977266e-05,
                                4.1977015540977266e-05,
                                4.1977015540977266e-05,
                                4.1977015540977266e-05,
                                4.1977015540977266e-05,
                                4.1977015540977266e-05,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                1.3745742464041767e-09,
                                1.3745742464041767e-09,
                                1.3745742464041767e-09,
                                1.3745742464041767e-09,
                                1.3745742464041767e-09,
                                1.3745742464041767e-09,
                                3.305718727240308e-07,
                                3.305718727240308e-07,
                                3.305718727240308e-07,
                                3.305718727240308e-07,
                                3.305718727240308e-07,
                                3.305718727240308e-07,
                                3.996620248988623e-06,
                                3.996620248988623e-06,
                                3.996620248988623e-06,
                                3.996620248988623e-06,
                                3.996620248988623e-06,
                                3.996620248988623e-06,
                                1.2244206753689373e-05,
                                1.2244206753689373e-05,
                                1.2244206753689373e-05,
                                1.2244206753689373e-05,
                                1.2244206753689373e-05,
                                1.2244206753689373e-05,
                                1.1528462676052824e-05,
                                1.1528462676052824e-05,
                                1.1528462676052824e-05,
                                1.1528462676052824e-05,
                                1.1528462676052824e-05,
                                1.1528462676052824e-05,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                1.3660198536478334e-08,
                                1.3660198536478334e-08,
                                1.3660198536478334e-08,
                                1.3660198536478334e-08,
                                1.3660198536478334e-08,
                                1.3660198536478334e-08,
                                3.2851462362244253e-06,
                                3.2851462362244253e-06,
                                3.2851462362244253e-06,
                                3.2851462362244253e-06,
                                3.2851462362244253e-06,
                                3.2851462362244253e-06,
                                3.971748068095347e-05,
                                3.971748068095347e-05,
                                3.971748068095347e-05,
                                3.971748068095347e-05,
                                3.971748068095347e-05,
                                3.971748068095347e-05,
                                0.0001216800733860872,
                                0.0001216800733860872,
                                0.0001216800733860872,
                                0.0001216800733860872,
                                0.0001216800733860872,
                                0.0001216800733860872,
                                0.0001145671755361525,
                                0.0001145671755361525,
                                0.0001145671755361525,
                                0.0001145671755361525,
                                0.0001145671755361525,
                                0.0001145671755361525,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                3.517913591600293e-08,
                                3.517913591600293e-08,
                                3.517913591600293e-08,
                                3.517913591600293e-08,
                                3.517913591600293e-08,
                                3.517913591600293e-08,
                                8.460243505207404e-06,
                                8.460243505207404e-06,
                                8.460243505207404e-06,
                                8.460243505207404e-06,
                                8.460243505207404e-06,
                                8.460243505207404e-06,
                                0.00010228450541076063,
                                0.00010228450541076063,
                                0.00010228450541076063,
                                0.00010228450541076063,
                                0.00010228450541076063,
                                0.00010228450541076063,
                                0.0003133629301570848,
                                0.0003133629301570848,
                                0.0003133629301570848,
                                0.0003133629301570848,
                                0.0003133629301570848,
                                0.0003133629301570848,
                                0.00029504507046044186,
                                0.00029504507046044186,
                                0.00029504507046044186,
                                0.00029504507046044186,
                                0.00029504507046044186,
                                0.00029504507046044186,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                4.5534991883496985e-08,
                                4.5534991883496985e-08,
                                4.5534991883496985e-08,
                                4.5534991883496985e-08,
                                4.5534991883496985e-08,
                                4.5534991883496985e-08,
                                1.0950727165722781e-05,
                                1.0950727165722781e-05,
                                1.0950727165722781e-05,
                                1.0950727165722781e-05,
                                1.0950727165722781e-05,
                                1.0950727165722781e-05,
                                0.000132394500388163,
                                0.000132394500388163,
                                0.000132394500388163,
                                0.000132394500388163,
                                0.000132394500388163,
                                0.000132394500388163,
                                0.0004056091234122881,
                                0.0004056091234122881,
                                0.0004056091234122881,
                                0.0004056091234122881,
                                0.0004056091234122881,
                                0.0004056091234122881,
                                0.00038189894489621366,
                                0.00038189894489621366,
                                0.00038189894489621366,
                                0.00038189894489621366,
                                0.00038189894489621366,
                                0.00038189894489621366,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                2.792774912231535e-08,
                                2.792774912231535e-08,
                                2.792774912231535e-08,
                                2.792774912231535e-08,
                                2.792774912231535e-08,
                                2.792774912231535e-08,
                                6.716354793116135e-06,
                                6.716354793116135e-06,
                                6.716354793116135e-06,
                                6.716354793116135e-06,
                                6.716354793116135e-06,
                                6.716354793116135e-06,
                                8.120085760583956e-05,
                                8.120085760583956e-05,
                                8.120085760583956e-05,
                                8.120085760583956e-05,
                                8.120085760583956e-05,
                                8.120085760583956e-05,
                                0.0002487702176243516,
                                0.0002487702176243516,
                                0.0002487702176243516,
                                0.0002487702176243516,
                                0.0002487702176243516,
                                0.0002487702176243516,
                                0.00023422817226862984,
                                0.00023422817226862984,
                                0.00023422817226862984,
                                0.00023422817226862984,
                                0.00023422817226862984,
                                0.00023422817226862984,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                2.7372668358624376e-09,
                                2.7372668358624376e-09,
                                2.7372668358624376e-09,
                                2.7372668358624376e-09,
                                2.7372668358624376e-09,
                                2.7372668358624376e-09,
                                6.582863213416877e-07,
                                6.582863213416877e-07,
                                6.582863213416877e-07,
                                6.582863213416877e-07,
                                6.582863213416877e-07,
                                6.582863213416877e-07,
                                7.958694186007699e-06,
                                7.958694186007699e-06,
                                7.958694186007699e-06,
                                7.958694186007699e-06,
                                7.958694186007699e-06,
                                7.958694186007699e-06,
                                2.4382576034719288e-05,
                                2.4382576034719288e-05,
                                2.4382576034719288e-05,
                                2.4382576034719288e-05,
                                2.4382576034719288e-05,
                                2.4382576034719288e-05,
                                2.29572746864621e-05,
                                2.29572746864621e-05,
                                2.29572746864621e-05,
                                2.29572746864621e-05,
                                2.29572746864621e-05,
                                2.29572746864621e-05,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                2.7202319935073337e-08,
                                2.7202319935073337e-08,
                                2.7202319935073337e-08,
                                2.7202319935073337e-08,
                                2.7202319935073337e-08,
                                2.7202319935073337e-08,
                                6.541896057560317e-06,
                                6.541896057560317e-06,
                                6.541896057560317e-06,
                                6.541896057560317e-06,
                                6.541896057560317e-06,
                                6.541896057560317e-06,
                                7.909164816406286e-05,
                                7.909164816406286e-05,
                                7.909164816406286e-05,
                                7.909164816406286e-05,
                                7.909164816406286e-05,
                                7.909164816406286e-05,
                                0.0002423083586327491,
                                0.0002423083586327491,
                                0.0002423083586327491,
                                0.0002423083586327491,
                                0.0002423083586327491,
                                0.0002423083586327491,
                                0.00022814404597925966,
                                0.00022814404597925966,
                                0.00022814404597925966,
                                0.00022814404597925966,
                                0.00022814404597925966,
                                0.00022814404597925966,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                7.005418754867148e-08,
                                7.005418754867148e-08,
                                7.005418754867148e-08,
                                7.005418754867148e-08,
                                7.005418754867148e-08,
                                7.005418754867148e-08,
                                1.684735766780509e-05,
                                1.684735766780509e-05,
                                1.684735766780509e-05,
                                1.684735766780509e-05,
                                1.684735766780509e-05,
                                1.684735766780509e-05,
                                0.00020368487567396374,
                                0.00020368487567396374,
                                0.00020368487567396374,
                                0.00020368487567396374,
                                0.00020368487567396374,
                                0.00020368487567396374,
                                0.0006240171882686737,
                                0.0006240171882686737,
                                0.0006240171882686737,
                                0.0006240171882686737,
                                0.0006240171882686737,
                                0.0006240171882686737,
                                0.0005875398062845661,
                                0.0005875398062845661,
                                0.0005875398062845661,
                                0.0005875398062845661,
                                0.0005875398062845661,
                                0.0005875398062845661,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                9.067638469149107e-08,
                                9.067638469149107e-08,
                                9.067638469149107e-08,
                                9.067638469149107e-08,
                                9.067638469149107e-08,
                                9.067638469149107e-08,
                                2.180679754311142e-05,
                                2.180679754311142e-05,
                                2.180679754311142e-05,
                                2.180679754311142e-05,
                                2.180679754311142e-05,
                                2.180679754311142e-05,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.000807712209612599,
                                0.000807712209612599,
                                0.000807712209612599,
                                0.000807712209612599,
                                0.000807712209612599,
                                0.000807712209612599,
                                0.0007604968005546987,
                                0.0007604968005546987,
                                0.0007604968005546987,
                                0.0007604968005546987,
                                0.0007604968005546987,
                                0.0007604968005546987,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                5.5614094089699824e-08,
                                5.5614094089699824e-08,
                                5.5614094089699824e-08,
                                5.5614094089699824e-08,
                                5.5614094089699824e-08,
                                5.5614094089699824e-08,
                                1.3374654211058743e-05,
                                1.3374654211058743e-05,
                                1.3374654211058743e-05,
                                1.3374654211058743e-05,
                                1.3374654211058743e-05,
                                1.3374654211058743e-05,
                                0.00016169982461805668,
                                0.00016169982461805668,
                                0.00016169982461805668,
                                0.00016169982461805668,
                                0.00016169982461805668,
                                0.00016169982461805668,
                                0.0004953900949583146,
                                0.0004953900949583146,
                                0.0004953900949583146,
                                0.0004953900949583146,
                                0.0004953900949583146,
                                0.0004953900949583146,
                                0.0004664317039641913,
                                0.0004664317039641913,
                                0.0004664317039641913,
                                0.0004664317039641913,
                                0.0004664317039641913,
                                0.0004664317039641913,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                2.0800934327423893e-09,
                                2.0800934327423893e-09,
                                2.0800934327423893e-09,
                                2.0800934327423893e-09,
                                2.0800934327423893e-09,
                                2.0800934327423893e-09,
                                5.002424447434491e-07,
                                5.002424447434491e-07,
                                5.002424447434491e-07,
                                5.002424447434491e-07,
                                5.002424447434491e-07,
                                5.002424447434491e-07,
                                6.047940702245669e-06,
                                6.047940702245669e-06,
                                6.047940702245669e-06,
                                6.047940702245669e-06,
                                6.047940702245669e-06,
                                6.047940702245669e-06,
                                1.8528714708656345e-05,
                                1.8528714708656345e-05,
                                1.8528714708656345e-05,
                                1.8528714708656345e-05,
                                1.8528714708656345e-05,
                                1.8528714708656345e-05,
                                1.7445605113586656e-05,
                                1.7445605113586656e-05,
                                1.7445605113586656e-05,
                                1.7445605113586656e-05,
                                1.7445605113586656e-05,
                                1.7445605113586656e-05,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                2.0671483799450473e-08,
                                2.0671483799450473e-08,
                                2.0671483799450473e-08,
                                2.0671483799450473e-08,
                                2.0671483799450473e-08,
                                2.0671483799450473e-08,
                                4.9712928417251355e-06,
                                4.9712928417251355e-06,
                                4.9712928417251355e-06,
                                4.9712928417251355e-06,
                                4.9712928417251355e-06,
                                4.9712928417251355e-06,
                                6.010302531539775e-05,
                                6.010302531539775e-05,
                                6.010302531539775e-05,
                                6.010302531539775e-05,
                                6.010302531539775e-05,
                                6.010302531539775e-05,
                                0.00018413404893051464,
                                0.00018413404893051464,
                                0.00018413404893051464,
                                0.00018413404893051464,
                                0.00018413404893051464,
                                0.00018413404893051464,
                                0.00017337035817745355,
                                0.00017337035817745355,
                                0.00017337035817745355,
                                0.00017337035817745355,
                                0.00017337035817745355,
                                0.00017337035817745355,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                5.3235312519388725e-08,
                                5.3235312519388725e-08,
                                5.3235312519388725e-08,
                                5.3235312519388725e-08,
                                5.3235312519388725e-08,
                                5.3235312519388725e-08,
                                1.2802580144811521e-05,
                                1.2802580144811521e-05,
                                1.2802580144811521e-05,
                                1.2802580144811521e-05,
                                1.2802580144811521e-05,
                                1.2802580144811521e-05,
                                0.00015478343824118664,
                                0.00015478343824118664,
                                0.00015478343824118664,
                                0.00015478343824118664,
                                0.00015478343824118664,
                                0.00015478343824118664,
                                0.0004742007751053144,
                                0.0004742007751053144,
                                0.0004742007751053144,
                                0.0004742007751053144,
                                0.0004742007751053144,
                                0.0004742007751053144,
                                0.00044648102132951165,
                                0.00044648102132951165,
                                0.00044648102132951165,
                                0.00044648102132951165,
                                0.00044648102132951165,
                                0.00044648102132951165,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                6.890645436186187e-08,
                                6.890645436186187e-08,
                                6.890645436186187e-08,
                                6.890645436186187e-08,
                                6.890645436186187e-08,
                                6.890645436186187e-08,
                                1.6571338886030526e-05,
                                1.6571338886030526e-05,
                                1.6571338886030526e-05,
                                1.6571338886030526e-05,
                                1.6571338886030526e-05,
                                1.6571338886030526e-05,
                                0.0002003478033355003,
                                0.0002003478033355003,
                                0.0002003478033355003,
                                0.0002003478033355003,
                                0.0002003478033355003,
                                0.0002003478033355003,
                                0.0006137935990561377,
                                0.0006137935990561377,
                                0.0006137935990561377,
                                0.0006137935990561377,
                                0.0006137935990561377,
                                0.0006137935990561377,
                                0.0005779138444707065,
                                0.0005779138444707065,
                                0.0005779138444707065,
                                0.0005779138444707065,
                                0.0005779138444707065,
                                0.0005779138444707065,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                1.0163616504292376e-05,
                                1.0163616504292376e-05,
                                1.0163616504292376e-05,
                                1.0163616504292376e-05,
                                1.0163616504292376e-05,
                                1.0163616504292376e-05,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.0003764549621789978,
                                0.0003764549621789978,
                                0.0003764549621789978,
                                0.0003764549621789978,
                                0.0003764549621789978,
                                0.0003764549621789978,
                                0.000354449011520306,
                                0.000354449011520306,
                                0.000354449011520306,
                                0.000354449011520306,
                                0.000354449011520306,
                                0.000354449011520306,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                            ]
                        ),
                    )
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.EdgeAdjacentTriangleAndQuadrilateral:
            match order:
                case 1:
                    return (
                        np.array(
                            [
                                [0.5, 0.25, 0.25],
                                [0.25, 0.5, 0.25],
                                [0.25, 0.25, 0.5],
                                [0.5, 0.375, 0.125],
                                [0.375, 0.5, 0.125],
                                [0.375, 0.375, 0.25],
                            ]
                        ),
                        np.array(
                            [
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [0.25, 0.25, 0.25, 0.25],
                            ]
                        ),
                        np.array([0.125, 0.125, 0.125, 0.09375, 0.09375, 0.09375]),
                    )
                case 2:
                    return (
                        np.array(
                            [
                                [0.6666666666666665, 0.16666666666666669, 0.16666666666666669],
                                [0.6220084679281461, 0.33333333333333337, 0.044658198738520456],
                                [0.6220084679281461, 0.16666666666666669, 0.21132486540518713],
                                [0.7628917115316043, 0.2018874775675312, 0.03522081090086452],
                                [0.7534543236939484, 0.2371082884683957, 0.009437387837655933],
                                [0.7534543236939483, 0.2018874775675312, 0.044658198738520456],
                                [0.33333333333333337, 0.044658198738520394, 0.6220084679281462],
                                [0.16666666666666652, 0.6666666666666667, 0.16666666666666669],
                                [0.16666666666666663, 0.044658198738520505, 0.7886751345948129],
                                [0.6924500897298752, 0.17610405450432262, 0.13144585576580217],
                                [0.6572292788290108, 0.30754991027012474, 0.03522081090086453],
                                [0.6572292788290106, 0.1761040545043226, 0.16666666666666669],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.16666666666666663, 0.7886751345948129, 0.044658198738520456],
                                [0.16666666666666663, 0.6220084679281462, 0.21132486540518713],
                                [0.21132486540518713, 0.7534543236939484, 0.03522081090086452],
                                [0.20188747756753123, 0.7886751345948129, 0.009437387837655933],
                                [0.20188747756753123, 0.7534543236939483, 0.044658198738520456],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.044658198738520394, 0.7886751345948129, 0.16666666666666669],
                                [0.044658198738520394, 0.16666666666666674, 0.7886751345948129],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580217],
                                [0.17610405450432265, 0.7886751345948129, 0.03522081090086453],
                                [0.17610405450432265, 0.6572292788290106, 0.16666666666666669],
                                [0.6666666666666665, 0.16666666666666669, 0.16666666666666669],
                                [0.6220084679281461, 0.33333333333333337, 0.044658198738520456],
                                [0.6220084679281461, 0.16666666666666669, 0.21132486540518713],
                                [0.7886751345948129, 0.2018874775675312, 0.009437387837655933],
                                [0.7534543236939484, 0.21132486540518713, 0.03522081090086452],
                                [0.7534543236939483, 0.2018874775675312, 0.044658198738520456],
                                [0.33333333333333337, 0.044658198738520394, 0.6220084679281462],
                                [0.16666666666666652, 0.6666666666666667, 0.16666666666666669],
                                [0.16666666666666663, 0.044658198738520505, 0.7886751345948129],
                                [0.7886751345948129, 0.1761040545043226, 0.03522081090086453],
                                [0.6572292788290107, 0.2113248654051871, 0.13144585576580217],
                                [0.6572292788290106, 0.1761040545043226, 0.16666666666666669],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.16666666666666663, 0.7886751345948129, 0.044658198738520456],
                                [0.16666666666666663, 0.6220084679281462, 0.21132486540518713],
                                [0.2371082884683957, 0.7534543236939484, 0.009437387837655933],
                                [0.20188747756753123, 0.7628917115316043, 0.03522081090086452],
                                [0.20188747756753123, 0.7534543236939483, 0.044658198738520456],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.044658198738520394, 0.7886751345948129, 0.16666666666666669],
                                [0.044658198738520394, 0.16666666666666674, 0.7886751345948129],
                                [0.3075499102701248, 0.6572292788290107, 0.03522081090086453],
                                [0.17610405450432265, 0.6924500897298752, 0.13144585576580217],
                                [0.17610405450432265, 0.6572292788290106, 0.16666666666666669],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.6220084679281461, 0.21132486540518713, 0.16666666666666669],
                                [0.6220084679281461, 0.16666666666666669, 0.21132486540518713],
                                [0.6924500897298752, 0.17610405450432262, 0.13144585576580217],
                                [0.6572292788290108, 0.30754991027012474, 0.03522081090086453],
                                [0.6572292788290106, 0.1761040545043226, 0.16666666666666669],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.16666666666666663, 0.21132486540518713, 0.6220084679281462],
                                [0.16666666666666663, 0.044658198738520505, 0.7886751345948129],
                                [0.42955837819827103, 0.07987900963938488, 0.4905626121623441],
                                [0.2981125224324688, 0.5704416218017291, 0.13144585576580217],
                                [0.2981125224324688, 0.07987900963938499, 0.6220084679281462],
                                [0.33333333333333337, 0.6220084679281461, 0.044658198738520456],
                                [0.16666666666666652, 0.6666666666666667, 0.16666666666666669],
                                [0.16666666666666663, 0.6220084679281462, 0.21132486540518713],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580217],
                                [0.17610405450432265, 0.7886751345948129, 0.03522081090086453],
                                [0.17610405450432265, 0.6572292788290106, 0.16666666666666669],
                                [0.6666666666666665, 0.16666666666666669, 0.16666666666666669],
                                [0.044658198738520394, 0.33333333333333337, 0.6220084679281462],
                                [0.044658198738520394, 0.16666666666666674, 0.7886751345948129],
                                [0.21132486540518713, 0.2981125224324688, 0.4905626121623441],
                                [0.07987900963938499, 0.7886751345948129, 0.13144585576580217],
                                [0.07987900963938499, 0.2981125224324688, 0.6220084679281462],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.6220084679281461, 0.21132486540518713, 0.16666666666666669],
                                [0.6220084679281461, 0.16666666666666669, 0.21132486540518713],
                                [0.7886751345948129, 0.1761040545043226, 0.03522081090086453],
                                [0.6572292788290107, 0.2113248654051871, 0.13144585576580217],
                                [0.6572292788290106, 0.1761040545043226, 0.16666666666666669],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.16666666666666663, 0.21132486540518713, 0.6220084679281462],
                                [0.16666666666666663, 0.044658198738520505, 0.7886751345948129],
                                [0.7886751345948129, 0.07987900963938496, 0.13144585576580217],
                                [0.2981125224324688, 0.21132486540518713, 0.4905626121623441],
                                [0.2981125224324688, 0.07987900963938499, 0.6220084679281462],
                                [0.33333333333333337, 0.6220084679281461, 0.044658198738520456],
                                [0.16666666666666652, 0.6666666666666667, 0.16666666666666669],
                                [0.16666666666666663, 0.6220084679281462, 0.21132486540518713],
                                [0.3075499102701248, 0.6572292788290107, 0.03522081090086453],
                                [0.17610405450432265, 0.6924500897298752, 0.13144585576580217],
                                [0.17610405450432265, 0.6572292788290106, 0.16666666666666669],
                                [0.6666666666666665, 0.16666666666666669, 0.16666666666666669],
                                [0.044658198738520394, 0.33333333333333337, 0.6220084679281462],
                                [0.044658198738520394, 0.16666666666666674, 0.7886751345948129],
                                [0.5704416218017291, 0.2981125224324688, 0.13144585576580217],
                                [0.07987900963938499, 0.4295583781982709, 0.4905626121623441],
                                [0.07987900963938499, 0.2981125224324688, 0.6220084679281462],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.5942306901503683,
                                    0.027777777777777776,
                                    0.3611111111111111,
                                    0.016880420960742677,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.6368945341743196,
                                    0.02977213249234697,
                                    0.31844726708715987,
                                    0.014886066246173488,
                                ],
                                [
                                    0.5942306901503684,
                                    0.15922363354357993,
                                    0.19444444444444445,
                                    0.0521012318616072,
                                ],
                                [
                                    0.6294515010512329,
                                    0.16866102138123587,
                                    0.15922363354357993,
                                    0.042663844023951264,
                                ],
                                [
                                    0.6016737232734551,
                                    0.16121798825814912,
                                    0.1870014113213577,
                                    0.05010687714703801,
                                ],
                                [
                                    0.13888888888888884,
                                    0.027777777777777776,
                                    0.6944444444444444,
                                    0.13888888888888892,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.2777777777777778,
                                    0.055555555555555566,
                                    0.5555555555555555,
                                    0.11111111111111112,
                                ],
                                [
                                    0.1388888888888889,
                                    0.5183403899401218,
                                    0.07243597651629824,
                                    0.27033474465469104,
                                ],
                                [
                                    0.1741096997897534,
                                    0.6497862457059239,
                                    0.03721516561543371,
                                    0.1388888888888889,
                                ],
                                [
                                    0.14633192201197565,
                                    0.5461181677178996,
                                    0.0649929433932115,
                                    0.2425569668769133,
                                ],
                                [
                                    0.15922363354357988,
                                    0.007443033123086741,
                                    0.7961181677178996,
                                    0.03721516561543371,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.2018874775675312,
                                    0.009437387837655933,
                                    0.7534543236939483,
                                    0.03522081090086452,
                                ],
                                [
                                    0.15922363354357996,
                                    0.04266384402395127,
                                    0.6294515010512329,
                                    0.16866102138123587,
                                ],
                                [
                                    0.1944444444444445,
                                    0.052101231861607214,
                                    0.5942306901503683,
                                    0.1592236335435799,
                                ],
                                [
                                    0.6220084679281462,
                                    0.16666666666666669,
                                    0.16666666666666669,
                                    0.044658198738520456,
                                ],
                                [
                                    0.03721516561543366,
                                    0.0074430331230867335,
                                    0.7961181677178996,
                                    0.15922363354357996,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.037215165615433726,
                                    0.13888888888888892,
                                    0.1741096997897534,
                                    0.6497862457059239,
                                ],
                                [
                                    0.07243597651629827,
                                    0.27033474465469115,
                                    0.13888888888888887,
                                    0.5183403899401218,
                                ],
                                [
                                    0.16666666666666669,
                                    0.6220084679281462,
                                    0.044658198738520456,
                                    0.16666666666666669,
                                ],
                                [
                                    0.5183403899401218,
                                    0.10366807798802437,
                                    0.3149929433932115,
                                    0.06299858867864232,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.5555555555555555,
                                    0.11111111111111112,
                                    0.2777777777777778,
                                    0.055555555555555566,
                                ],
                                [
                                    0.5942306901503684,
                                    0.15922363354357993,
                                    0.19444444444444445,
                                    0.0521012318616072,
                                ],
                                [
                                    0.6294515010512329,
                                    0.16866102138123587,
                                    0.15922363354357993,
                                    0.042663844023951264,
                                ],
                                [
                                    0.6220084679281462,
                                    0.16666666666666669,
                                    0.16666666666666669,
                                    0.044658198738520456,
                                ],
                                [
                                    0.06299858867864228,
                                    0.10366807798802435,
                                    0.3149929433932115,
                                    0.5183403899401219,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.1259971773572846,
                                    0.20733615597604876,
                                    0.25199435471456916,
                                    0.41467231195209747,
                                ],
                                [
                                    0.1388888888888889,
                                    0.5183403899401218,
                                    0.07243597651629824,
                                    0.27033474465469104,
                                ],
                                [
                                    0.1741096997897534,
                                    0.6497862457059239,
                                    0.03721516561543371,
                                    0.1388888888888889,
                                ],
                                [
                                    0.16666666666666669,
                                    0.6220084679281462,
                                    0.044658198738520456,
                                    0.16666666666666669,
                                ],
                                [
                                    0.13888888888888884,
                                    0.027777777777777776,
                                    0.6944444444444444,
                                    0.13888888888888892,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.15922363354357996,
                                    0.04266384402395127,
                                    0.6294515010512329,
                                    0.16866102138123587,
                                ],
                                [
                                    0.1944444444444445,
                                    0.052101231861607214,
                                    0.5942306901503683,
                                    0.1592236335435799,
                                ],
                                [
                                    0.6423432125828372,
                                    0.17211534507518422,
                                    0.14633192201197565,
                                    0.039209520330002905,
                                ],
                                [
                                    0.016880420960742652,
                                    0.02777777777777774,
                                    0.3611111111111111,
                                    0.5942306901503684,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.037215165615433726,
                                    0.13888888888888892,
                                    0.1741096997897534,
                                    0.6497862457059239,
                                ],
                                [
                                    0.07243597651629827,
                                    0.27033474465469115,
                                    0.13888888888888887,
                                    0.5183403899401218,
                                ],
                                [
                                    0.18700141132135772,
                                    0.6978987681383928,
                                    0.02432345408382942,
                                    0.09077636645642008,
                                ],
                                [
                                    0.5942306901503683,
                                    0.027777777777777776,
                                    0.3611111111111111,
                                    0.016880420960742677,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.5183403899401218,
                                    0.1388888888888889,
                                    0.27033474465469104,
                                    0.07243597651629824,
                                ],
                                [
                                    0.6497862457059239,
                                    0.1741096997897534,
                                    0.1388888888888889,
                                    0.03721516561543371,
                                ],
                                [
                                    0.09077636645642007,
                                    0.024323454083829413,
                                    0.6978987681383928,
                                    0.18700141132135772,
                                ],
                                [
                                    0.13888888888888884,
                                    0.027777777777777776,
                                    0.6944444444444444,
                                    0.13888888888888892,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.06299858867864229,
                                    0.23511393375382647,
                                    0.14832627672654483,
                                    0.5535612008409864,
                                ],
                                [
                                    0.19444444444444445,
                                    0.7256765459161706,
                                    0.016880420960742677,
                                    0.0629985886786423,
                                ],
                                [
                                    -0.03123210147172612,
                                    -0.11655978951962859,
                                    0.24255696687691325,
                                    0.9052349241144414,
                                ],
                                [
                                    0.15922363354357988,
                                    0.007443033123086741,
                                    0.7961181677178996,
                                    0.03721516561543371,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.31844726708715987,
                                    0.014886066246173488,
                                    0.6368945341743196,
                                    0.02977213249234697,
                                ],
                                [
                                    0.13888888888888892,
                                    0.037215165615433726,
                                    0.6497862457059239,
                                    0.1741096997897534,
                                ],
                                [
                                    0.27033474465469115,
                                    0.07243597651629827,
                                    0.5183403899401218,
                                    0.13888888888888887,
                                ],
                                [
                                    0.16666666666666669,
                                    0.044658198738520456,
                                    0.6220084679281462,
                                    0.16666666666666669,
                                ],
                                [
                                    0.03721516561543366,
                                    0.0074430331230867335,
                                    0.7961181677178996,
                                    0.15922363354357996,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.5555555555555555,
                                    0.11111111111111112,
                                    0.2777777777777778,
                                    0.055555555555555566,
                                ],
                                [
                                    0.01688042096074268,
                                    0.06299858867864232,
                                    0.19444444444444445,
                                    0.7256765459161706,
                                ],
                                [
                                    0.14832627672654483,
                                    0.5535612008409864,
                                    0.06299858867864229,
                                    0.23511393375382647,
                                ],
                                [
                                    0.044658198738520456,
                                    0.16666666666666669,
                                    0.16666666666666669,
                                    0.6220084679281462,
                                ],
                                [
                                    0.5183403899401218,
                                    0.10366807798802437,
                                    0.3149929433932115,
                                    0.06299858867864232,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.5183403899401218,
                                    0.1388888888888889,
                                    0.27033474465469104,
                                    0.07243597651629824,
                                ],
                                [
                                    0.6497862457059239,
                                    0.1741096997897534,
                                    0.1388888888888889,
                                    0.03721516561543371,
                                ],
                                [
                                    0.16666666666666669,
                                    0.044658198738520456,
                                    0.6220084679281462,
                                    0.16666666666666669,
                                ],
                                [
                                    0.06299858867864228,
                                    0.10366807798802435,
                                    0.3149929433932115,
                                    0.5183403899401219,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.2981125224324688,
                                    0.4905626121623441,
                                    0.07987900963938498,
                                    0.13144585576580217,
                                ],
                                [
                                    0.06299858867864229,
                                    0.23511393375382647,
                                    0.14832627672654483,
                                    0.5535612008409864,
                                ],
                                [
                                    0.19444444444444445,
                                    0.7256765459161706,
                                    0.016880420960742677,
                                    0.0629985886786423,
                                ],
                                [
                                    0.044658198738520456,
                                    0.16666666666666669,
                                    0.16666666666666669,
                                    0.6220084679281462,
                                ],
                                [
                                    0.13888888888888884,
                                    0.027777777777777776,
                                    0.6944444444444444,
                                    0.13888888888888892,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.2777777777777778,
                                    0.055555555555555566,
                                    0.5555555555555555,
                                    0.11111111111111112,
                                ],
                                [
                                    0.13888888888888892,
                                    0.037215165615433726,
                                    0.6497862457059239,
                                    0.1741096997897534,
                                ],
                                [
                                    0.27033474465469115,
                                    0.07243597651629827,
                                    0.5183403899401218,
                                    0.13888888888888887,
                                ],
                                [
                                    0.2425569668769133,
                                    0.0649929433932115,
                                    0.5461181677178996,
                                    0.14633192201197565,
                                ],
                                [
                                    0.016880420960742652,
                                    0.02777777777777774,
                                    0.3611111111111111,
                                    0.5942306901503684,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.25199435471456916,
                                    0.41467231195209747,
                                    0.1259971773572846,
                                    0.20733615597604876,
                                ],
                                [
                                    0.01688042096074268,
                                    0.06299858867864232,
                                    0.19444444444444445,
                                    0.7256765459161706,
                                ],
                                [
                                    0.14832627672654483,
                                    0.5535612008409864,
                                    0.06299858867864229,
                                    0.23511393375382647,
                                ],
                                [
                                    0.12054849894876704,
                                    0.44989312285296196,
                                    0.09077636645642008,
                                    0.3387820117418509,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0005634956935018373,
                                0.0005634956935018373,
                                0.0005634956935018373,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.0068461383211355295,
                                0.0068461383211355295,
                                0.0068461383211355295,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0005634956935018373,
                                0.0005634956935018373,
                                0.0005634956935018373,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.0068461383211355295,
                                0.0068461383211355295,
                                0.0068461383211355295,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0005634956935018373,
                                0.0005634956935018373,
                                0.0005634956935018373,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.0068461383211355295,
                                0.0068461383211355295,
                                0.0068461383211355295,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0005634956935018373,
                                0.0005634956935018373,
                                0.0005634956935018373,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.0068461383211355295,
                                0.0068461383211355295,
                                0.0068461383211355295,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0018344172344200269,
                                0.0018344172344200269,
                                0.0018344172344200269,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.01158928208427594,
                                0.01158928208427594,
                                0.01158928208427594,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0018344172344200269,
                                0.0018344172344200269,
                                0.0018344172344200269,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.01158928208427594,
                                0.01158928208427594,
                                0.01158928208427594,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0018344172344200269,
                                0.0018344172344200269,
                                0.0018344172344200269,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.01158928208427594,
                                0.01158928208427594,
                                0.01158928208427594,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0022013006813040325,
                                0.0018344172344200269,
                                0.0018344172344200269,
                                0.0018344172344200269,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.008215365985362636,
                                0.01158928208427594,
                                0.01158928208427594,
                                0.01158928208427594,
                            ]
                        ),
                    )
                case 3:
                    return (
                        np.array(
                            [
                                [0.8, 0.09999999999999999, 0.09999999999999999],
                                [0.7872983346207417, 0.19999999999999996, 0.012701665379258308],
                                [0.7872983346207417, 0.09999999999999998, 0.1127016653792583],
                                [0.8774596669241483, 0.11127016653792582, 0.011270166537925829],
                                [0.8760281680828158, 0.12254033307585165, 0.0014314988413324798],
                                [0.8760281680828159, 0.11127016653792582, 0.012701665379258308],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.44364916731037085, 0.5, 0.05635083268962915],
                                [0.44364916731037085, 0.05635083268962915, 0.5],
                                [0.8436491673103708, 0.10635083268962914, 0.049999999999999996],
                                [0.8372983346207418, 0.15635083268962913, 0.006350832689629154],
                                [0.8372983346207417, 0.10635083268962914, 0.05635083268962915],
                                [0.19999999999999996, 0.01270166537925832, 0.7872983346207417],
                                [0.09999999999999998, 0.8, 0.09999999999999999],
                                [0.09999999999999998, 0.01270166537925832, 0.8872983346207417],
                                [0.8098386676965933, 0.10143149884133248, 0.08872983346207416],
                                [0.7985685011586676, 0.19016133230340662, 0.011270166537925829],
                                [0.7985685011586675, 0.10143149884133247, 0.09999999999999999],
                                [0.45635083268962917, 0.44364916731037085, 0.09999999999999999],
                                [0.44364916731037085, 0.5436491673103708, 0.012701665379258308],
                                [0.44364916731037085, 0.44364916731037085, 0.1127016653792583],
                                [0.4950806661517034, 0.49364916731037084, 0.011270166537925829],
                                [0.4936491673103709, 0.5049193338482966, 0.0014314988413324798],
                                [0.4936491673103709, 0.4936491673103708, 0.012701665379258308],
                                [0.30635083268962915, 0.25, 0.44364916731037085],
                                [0.25, 0.6936491673103709, 0.05635083268962915],
                                [0.25, 0.25, 0.5],
                                [0.4781754163448145, 0.4718245836551855, 0.049999999999999996],
                                [0.4718245836551854, 0.5218245836551855, 0.006350832689629154],
                                [0.4718245836551854, 0.4718245836551854, 0.05635083268962915],
                                [0.15635083268962913, 0.05635083268962915, 0.7872983346207417],
                                [0.05635083268962915, 0.8436491673103709, 0.09999999999999999],
                                [0.05635083268962915, 0.05635083268962915, 0.8872983346207417],
                                [0.46127016653792585, 0.44999999999999996, 0.08872983346207416],
                                [0.44999999999999996, 0.5387298334620743, 0.011270166537925829],
                                [0.44999999999999996, 0.45000000000000007, 0.09999999999999999],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.09999999999999998, 0.8872983346207417, 0.012701665379258308],
                                [0.09999999999999998, 0.7872983346207417, 0.1127016653792583],
                                [0.1127016653792583, 0.8760281680828159, 0.011270166537925829],
                                [0.11127016653792576, 0.8872983346207417, 0.0014314988413324798],
                                [0.11127016653792576, 0.8760281680828159, 0.012701665379258308],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.05635083268962915, 0.8872983346207417, 0.05635083268962915],
                                [0.05635083268962915, 0.44364916731037085, 0.5],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.1063508326896292, 0.8872983346207417, 0.006350832689629154],
                                [0.1063508326896292, 0.8372983346207417, 0.05635083268962915],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.01270166537925832, 0.8872983346207417, 0.09999999999999999],
                                [0.01270166537925832, 0.09999999999999998, 0.8872983346207417],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.10143149884133251, 0.8872983346207417, 0.011270166537925829],
                                [0.10143149884133251, 0.7985685011586675, 0.09999999999999999],
                                [0.8, 0.09999999999999999, 0.09999999999999999],
                                [0.7872983346207417, 0.19999999999999996, 0.012701665379258308],
                                [0.7872983346207417, 0.09999999999999998, 0.1127016653792583],
                                [0.882379000772445, 0.11127016653792582, 0.006350832689629154],
                                [0.8760281680828159, 0.11762099922755496, 0.006350832689629154],
                                [0.8760281680828159, 0.11127016653792582, 0.012701665379258308],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.44364916731037085, 0.5, 0.05635083268962915],
                                [0.44364916731037085, 0.05635083268962915, 0.5],
                                [0.8654737509655563, 0.10635083268962914, 0.028175416344814574],
                                [0.8372983346207417, 0.1345262490344437, 0.028175416344814574],
                                [0.8372983346207417, 0.10635083268962914, 0.05635083268962915],
                                [0.19999999999999996, 0.01270166537925832, 0.7872983346207417],
                                [0.09999999999999998, 0.8, 0.09999999999999999],
                                [0.09999999999999998, 0.01270166537925832, 0.8872983346207417],
                                [0.8485685011586674, 0.10143149884133248, 0.049999999999999996],
                                [0.7985685011586675, 0.15143149884133247, 0.049999999999999996],
                                [0.7985685011586675, 0.10143149884133247, 0.09999999999999999],
                                [0.45635083268962917, 0.44364916731037085, 0.09999999999999999],
                                [0.44364916731037085, 0.5436491673103708, 0.012701665379258308],
                                [0.44364916731037085, 0.44364916731037085, 0.1127016653792583],
                                [0.5, 0.49364916731037084, 0.006350832689629154],
                                [0.49364916731037095, 0.49999999999999994, 0.006350832689629154],
                                [0.4936491673103709, 0.4936491673103708, 0.012701665379258308],
                                [0.30635083268962915, 0.25, 0.44364916731037085],
                                [0.25, 0.6936491673103709, 0.05635083268962915],
                                [0.25, 0.25, 0.5],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.4718245836551854, 0.5, 0.028175416344814574],
                                [0.4718245836551854, 0.4718245836551854, 0.05635083268962915],
                                [0.15635083268962913, 0.05635083268962915, 0.7872983346207417],
                                [0.05635083268962915, 0.8436491673103709, 0.09999999999999999],
                                [0.05635083268962915, 0.05635083268962915, 0.8872983346207417],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.44999999999999996, 0.5, 0.049999999999999996],
                                [0.44999999999999996, 0.45000000000000007, 0.09999999999999999],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.09999999999999998, 0.8872983346207417, 0.012701665379258308],
                                [0.09999999999999998, 0.7872983346207417, 0.1127016653792583],
                                [0.11762099922755498, 0.8760281680828159, 0.006350832689629154],
                                [0.11127016653792576, 0.8823790007724451, 0.006350832689629154],
                                [0.11127016653792576, 0.8760281680828159, 0.012701665379258308],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.05635083268962915, 0.8872983346207417, 0.05635083268962915],
                                [0.05635083268962915, 0.44364916731037085, 0.5],
                                [0.13452624903444377, 0.8372983346207417, 0.028175416344814574],
                                [0.1063508326896292, 0.8654737509655562, 0.028175416344814574],
                                [0.1063508326896292, 0.8372983346207417, 0.05635083268962915],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.01270166537925832, 0.8872983346207417, 0.09999999999999999],
                                [0.01270166537925832, 0.09999999999999998, 0.8872983346207417],
                                [0.15143149884133245, 0.7985685011586675, 0.049999999999999996],
                                [0.10143149884133251, 0.8485685011586674, 0.049999999999999996],
                                [0.10143149884133251, 0.7985685011586675, 0.09999999999999999],
                                [0.8, 0.09999999999999999, 0.09999999999999999],
                                [0.7872983346207417, 0.19999999999999996, 0.012701665379258308],
                                [0.7872983346207417, 0.09999999999999998, 0.1127016653792583],
                                [0.8872983346207417, 0.11127016653792582, 0.0014314988413324798],
                                [0.8760281680828159, 0.1127016653792583, 0.011270166537925829],
                                [0.8760281680828159, 0.11127016653792582, 0.012701665379258308],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.44364916731037085, 0.5, 0.05635083268962915],
                                [0.44364916731037085, 0.05635083268962915, 0.5],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8372983346207417, 0.1127016653792583, 0.049999999999999996],
                                [0.8372983346207417, 0.10635083268962914, 0.05635083268962915],
                                [0.19999999999999996, 0.01270166537925832, 0.7872983346207417],
                                [0.09999999999999998, 0.8, 0.09999999999999999],
                                [0.09999999999999998, 0.01270166537925832, 0.8872983346207417],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.7985685011586675, 0.1127016653792583, 0.08872983346207416],
                                [0.7985685011586675, 0.10143149884133247, 0.09999999999999999],
                                [0.45635083268962917, 0.44364916731037085, 0.09999999999999999],
                                [0.44364916731037085, 0.5436491673103708, 0.012701665379258308],
                                [0.44364916731037085, 0.44364916731037085, 0.1127016653792583],
                                [0.5049193338482967, 0.49364916731037084, 0.0014314988413324798],
                                [0.49364916731037095, 0.49508066615170326, 0.011270166537925829],
                                [0.4936491673103709, 0.4936491673103708, 0.012701665379258308],
                                [0.30635083268962915, 0.25, 0.44364916731037085],
                                [0.25, 0.6936491673103709, 0.05635083268962915],
                                [0.25, 0.25, 0.5],
                                [0.5218245836551855, 0.4718245836551854, 0.006350832689629154],
                                [0.47182458365518537, 0.4781754163448146, 0.049999999999999996],
                                [0.4718245836551854, 0.4718245836551854, 0.05635083268962915],
                                [0.15635083268962913, 0.05635083268962915, 0.7872983346207417],
                                [0.05635083268962915, 0.8436491673103709, 0.09999999999999999],
                                [0.05635083268962915, 0.05635083268962915, 0.8872983346207417],
                                [0.5387298334620743, 0.45, 0.011270166537925829],
                                [0.44999999999999996, 0.46127016653792585, 0.08872983346207416],
                                [0.44999999999999996, 0.45000000000000007, 0.09999999999999999],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.09999999999999998, 0.8872983346207417, 0.012701665379258308],
                                [0.09999999999999998, 0.7872983346207417, 0.1127016653792583],
                                [0.12254033307585166, 0.8760281680828158, 0.0014314988413324798],
                                [0.11127016653792576, 0.8774596669241485, 0.011270166537925829],
                                [0.11127016653792576, 0.8760281680828159, 0.012701665379258308],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.05635083268962915, 0.8872983346207417, 0.05635083268962915],
                                [0.05635083268962915, 0.44364916731037085, 0.5],
                                [0.15635083268962913, 0.8372983346207418, 0.006350832689629154],
                                [0.1063508326896292, 0.8436491673103708, 0.049999999999999996],
                                [0.1063508326896292, 0.8372983346207417, 0.05635083268962915],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.01270166537925832, 0.8872983346207417, 0.09999999999999999],
                                [0.01270166537925832, 0.09999999999999998, 0.8872983346207417],
                                [0.1901613323034066, 0.7985685011586676, 0.011270166537925829],
                                [0.10143149884133251, 0.8098386676965933, 0.08872983346207416],
                                [0.10143149884133251, 0.7985685011586675, 0.09999999999999999],
                                [0.8436491673103709, 0.09999999999999998, 0.05635083268962915],
                                [0.7872983346207417, 0.15635083268962913, 0.05635083268962915],
                                [0.7872983346207417, 0.09999999999999998, 0.1127016653792583],
                                [0.8436491673103708, 0.10635083268962914, 0.049999999999999996],
                                [0.8372983346207418, 0.15635083268962913, 0.006350832689629154],
                                [0.8372983346207417, 0.10635083268962914, 0.05635083268962915],
                                [0.6936491673103709, 0.05635083268962915, 0.25],
                                [0.44364916731037085, 0.30635083268962915, 0.25],
                                [0.44364916731037085, 0.05635083268962915, 0.5],
                                [0.6936491673103709, 0.08452624903444372, 0.22182458365518543],
                                [0.6654737509655563, 0.30635083268962915, 0.028175416344814574],
                                [0.6654737509655563, 0.08452624903444372, 0.25],
                                [0.5436491673103708, 0.01270166537925832, 0.44364916731037085],
                                [0.09999999999999998, 0.45635083268962917, 0.44364916731037085],
                                [0.09999999999999998, 0.01270166537925832, 0.8872983346207417],
                                [0.5436491673103709, 0.06270166537925831, 0.39364916731037086],
                                [0.49364916731037084, 0.4563508326896291, 0.049999999999999996],
                                [0.4936491673103709, 0.06270166537925825, 0.44364916731037085],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.44364916731037085, 0.5, 0.05635083268962915],
                                [0.44364916731037085, 0.44364916731037085, 0.1127016653792583],
                                [0.4781754163448145, 0.4718245836551855, 0.049999999999999996],
                                [0.4718245836551854, 0.5218245836551855, 0.006350832689629154],
                                [0.4718245836551854, 0.4718245836551854, 0.05635083268962915],
                                [0.5, 0.25, 0.25],
                                [0.25, 0.5, 0.25],
                                [0.25, 0.25, 0.5],
                                [0.4031754163448146, 0.375, 0.22182458365518543],
                                [0.375, 0.5968245836551854, 0.028175416344814574],
                                [0.375, 0.375, 0.25],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.05635083268962915, 0.5, 0.44364916731037085],
                                [0.05635083268962915, 0.05635083268962915, 0.8872983346207417],
                                [0.32817541634481456, 0.27817541634481463, 0.39364916731037086],
                                [0.2781754163448146, 0.6718245836551854, 0.049999999999999996],
                                [0.2781754163448146, 0.2781754163448146, 0.44364916731037085],
                                [0.15635083268962913, 0.7872983346207417, 0.05635083268962915],
                                [0.09999999999999998, 0.8436491673103709, 0.05635083268962915],
                                [0.09999999999999998, 0.7872983346207417, 0.1127016653792583],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.1063508326896292, 0.8872983346207417, 0.006350832689629154],
                                [0.1063508326896292, 0.8372983346207417, 0.05635083268962915],
                                [0.30635083268962915, 0.44364916731037085, 0.25],
                                [0.05635083268962915, 0.6936491673103709, 0.25],
                                [0.05635083268962915, 0.44364916731037085, 0.5],
                                [0.1127016653792583, 0.6654737509655563, 0.22182458365518543],
                                [0.08452624903444372, 0.8872983346207417, 0.028175416344814574],
                                [0.08452624903444372, 0.6654737509655563, 0.25],
                                [0.45635083268962917, 0.09999999999999998, 0.44364916731037085],
                                [0.01270166537925832, 0.5436491673103708, 0.44364916731037085],
                                [0.01270166537925832, 0.09999999999999998, 0.8872983346207417],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.06270166537925825, 0.8872983346207417, 0.049999999999999996],
                                [0.06270166537925825, 0.4936491673103709, 0.44364916731037085],
                                [0.8436491673103709, 0.09999999999999998, 0.05635083268962915],
                                [0.7872983346207417, 0.15635083268962913, 0.05635083268962915],
                                [0.7872983346207417, 0.09999999999999998, 0.1127016653792583],
                                [0.8654737509655563, 0.10635083268962914, 0.028175416344814574],
                                [0.8372983346207417, 0.1345262490344437, 0.028175416344814574],
                                [0.8372983346207417, 0.10635083268962914, 0.05635083268962915],
                                [0.6936491673103709, 0.05635083268962915, 0.25],
                                [0.44364916731037085, 0.30635083268962915, 0.25],
                                [0.44364916731037085, 0.05635083268962915, 0.5],
                                [0.7904737509655563, 0.08452624903444372, 0.125],
                                [0.6654737509655563, 0.20952624903444372, 0.125],
                                [0.6654737509655563, 0.08452624903444372, 0.25],
                                [0.5436491673103708, 0.01270166537925832, 0.44364916731037085],
                                [0.09999999999999998, 0.45635083268962917, 0.44364916731037085],
                                [0.09999999999999998, 0.01270166537925832, 0.8872983346207417],
                                [0.7154737509655562, 0.06270166537925831, 0.22182458365518543],
                                [0.4936491673103709, 0.2845262490344437, 0.22182458365518543],
                                [0.4936491673103709, 0.06270166537925825, 0.44364916731037085],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.44364916731037085, 0.5, 0.05635083268962915],
                                [0.44364916731037085, 0.44364916731037085, 0.1127016653792583],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.4718245836551854, 0.5, 0.028175416344814574],
                                [0.4718245836551854, 0.4718245836551854, 0.05635083268962915],
                                [0.5, 0.25, 0.25],
                                [0.25, 0.5, 0.25],
                                [0.25, 0.25, 0.5],
                                [0.5, 0.375, 0.125],
                                [0.375, 0.5, 0.125],
                                [0.375, 0.375, 0.25],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.05635083268962915, 0.5, 0.44364916731037085],
                                [0.05635083268962915, 0.05635083268962915, 0.8872983346207417],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.2781754163448146, 0.5, 0.22182458365518543],
                                [0.2781754163448146, 0.2781754163448146, 0.44364916731037085],
                                [0.15635083268962913, 0.7872983346207417, 0.05635083268962915],
                                [0.09999999999999998, 0.8436491673103709, 0.05635083268962915],
                                [0.09999999999999998, 0.7872983346207417, 0.1127016653792583],
                                [0.13452624903444377, 0.8372983346207417, 0.028175416344814574],
                                [0.1063508326896292, 0.8654737509655562, 0.028175416344814574],
                                [0.1063508326896292, 0.8372983346207417, 0.05635083268962915],
                                [0.30635083268962915, 0.44364916731037085, 0.25],
                                [0.05635083268962915, 0.6936491673103709, 0.25],
                                [0.05635083268962915, 0.44364916731037085, 0.5],
                                [0.20952624903444372, 0.6654737509655563, 0.125],
                                [0.08452624903444372, 0.7904737509655563, 0.125],
                                [0.08452624903444372, 0.6654737509655563, 0.25],
                                [0.45635083268962917, 0.09999999999999998, 0.44364916731037085],
                                [0.01270166537925832, 0.5436491673103708, 0.44364916731037085],
                                [0.01270166537925832, 0.09999999999999998, 0.8872983346207417],
                                [0.2845262490344438, 0.4936491673103708, 0.22182458365518543],
                                [0.06270166537925825, 0.7154737509655563, 0.22182458365518543],
                                [0.06270166537925825, 0.4936491673103709, 0.44364916731037085],
                                [0.8436491673103709, 0.09999999999999998, 0.05635083268962915],
                                [0.7872983346207417, 0.15635083268962913, 0.05635083268962915],
                                [0.7872983346207417, 0.09999999999999998, 0.1127016653792583],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8372983346207417, 0.1127016653792583, 0.049999999999999996],
                                [0.8372983346207417, 0.10635083268962914, 0.05635083268962915],
                                [0.6936491673103709, 0.05635083268962915, 0.25],
                                [0.44364916731037085, 0.30635083268962915, 0.25],
                                [0.44364916731037085, 0.05635083268962915, 0.5],
                                [0.8872983346207417, 0.08452624903444372, 0.028175416344814574],
                                [0.6654737509655563, 0.1127016653792583, 0.22182458365518543],
                                [0.6654737509655563, 0.08452624903444372, 0.25],
                                [0.5436491673103708, 0.01270166537925832, 0.44364916731037085],
                                [0.09999999999999998, 0.45635083268962917, 0.44364916731037085],
                                [0.09999999999999998, 0.01270166537925832, 0.8872983346207417],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.49364916731037095, 0.11270166537925824, 0.39364916731037086],
                                [0.4936491673103709, 0.06270166537925825, 0.44364916731037085],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.44364916731037085, 0.5, 0.05635083268962915],
                                [0.44364916731037085, 0.44364916731037085, 0.1127016653792583],
                                [0.5218245836551855, 0.4718245836551854, 0.006350832689629154],
                                [0.47182458365518537, 0.4781754163448146, 0.049999999999999996],
                                [0.4718245836551854, 0.4718245836551854, 0.05635083268962915],
                                [0.5, 0.25, 0.25],
                                [0.25, 0.5, 0.25],
                                [0.25, 0.25, 0.5],
                                [0.5968245836551854, 0.375, 0.028175416344814574],
                                [0.375, 0.4031754163448146, 0.22182458365518543],
                                [0.375, 0.375, 0.25],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.05635083268962915, 0.5, 0.44364916731037085],
                                [0.05635083268962915, 0.05635083268962915, 0.8872983346207417],
                                [0.6718245836551854, 0.2781754163448146, 0.049999999999999996],
                                [0.27817541634481463, 0.32817541634481456, 0.39364916731037086],
                                [0.2781754163448146, 0.2781754163448146, 0.44364916731037085],
                                [0.15635083268962913, 0.7872983346207417, 0.05635083268962915],
                                [0.09999999999999998, 0.8436491673103709, 0.05635083268962915],
                                [0.09999999999999998, 0.7872983346207417, 0.1127016653792583],
                                [0.15635083268962913, 0.8372983346207418, 0.006350832689629154],
                                [0.1063508326896292, 0.8436491673103708, 0.049999999999999996],
                                [0.1063508326896292, 0.8372983346207417, 0.05635083268962915],
                                [0.30635083268962915, 0.44364916731037085, 0.25],
                                [0.05635083268962915, 0.6936491673103709, 0.25],
                                [0.05635083268962915, 0.44364916731037085, 0.5],
                                [0.30635083268962915, 0.6654737509655563, 0.028175416344814574],
                                [0.08452624903444372, 0.6936491673103709, 0.22182458365518543],
                                [0.08452624903444372, 0.6654737509655563, 0.25],
                                [0.45635083268962917, 0.09999999999999998, 0.44364916731037085],
                                [0.01270166537925832, 0.5436491673103708, 0.44364916731037085],
                                [0.01270166537925832, 0.09999999999999998, 0.8872983346207417],
                                [0.4563508326896291, 0.49364916731037084, 0.049999999999999996],
                                [0.06270166537925825, 0.5436491673103709, 0.39364916731037086],
                                [0.06270166537925825, 0.4936491673103709, 0.44364916731037085],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.7872983346207417, 0.11270166537925828, 0.09999999999999999],
                                [0.7872983346207417, 0.09999999999999998, 0.1127016653792583],
                                [0.8098386676965933, 0.10143149884133248, 0.08872983346207416],
                                [0.7985685011586676, 0.19016133230340662, 0.011270166537925829],
                                [0.7985685011586675, 0.10143149884133247, 0.09999999999999999],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.44364916731037085, 0.1127016653792583, 0.44364916731037085],
                                [0.44364916731037085, 0.05635083268962915, 0.5],
                                [0.5436491673103709, 0.06270166537925831, 0.39364916731037086],
                                [0.49364916731037084, 0.4563508326896291, 0.049999999999999996],
                                [0.4936491673103709, 0.06270166537925825, 0.44364916731037085],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.09999999999999998, 0.1127016653792583, 0.7872983346207417],
                                [0.09999999999999998, 0.01270166537925832, 0.8872983346207417],
                                [0.27745966692414825, 0.023971831917184216, 0.6985685011586675],
                                [0.18872983346207417, 0.7225403330758516, 0.08872983346207416],
                                [0.18872983346207417, 0.023971831917184105, 0.7872983346207417],
                                [0.5436491673103708, 0.44364916731037085, 0.012701665379258308],
                                [0.44364916731037085, 0.45635083268962917, 0.09999999999999999],
                                [0.44364916731037085, 0.44364916731037085, 0.1127016653792583],
                                [0.46127016653792585, 0.44999999999999996, 0.08872983346207416],
                                [0.44999999999999996, 0.5387298334620743, 0.011270166537925829],
                                [0.44999999999999996, 0.45000000000000007, 0.09999999999999999],
                                [0.6936491673103709, 0.25, 0.05635083268962915],
                                [0.25, 0.30635083268962915, 0.44364916731037085],
                                [0.25, 0.25, 0.5],
                                [0.32817541634481456, 0.27817541634481463, 0.39364916731037086],
                                [0.2781754163448146, 0.6718245836551854, 0.049999999999999996],
                                [0.2781754163448146, 0.2781754163448146, 0.44364916731037085],
                                [0.8436491673103709, 0.056350832689629135, 0.09999999999999999],
                                [0.05635083268962915, 0.15635083268962913, 0.7872983346207417],
                                [0.05635083268962915, 0.05635083268962915, 0.8872983346207417],
                                [0.19508066615170327, 0.1063508326896292, 0.6985685011586675],
                                [0.1063508326896292, 0.8049193338482966, 0.08872983346207416],
                                [0.1063508326896292, 0.10635083268962908, 0.7872983346207417],
                                [0.19999999999999996, 0.7872983346207417, 0.012701665379258308],
                                [0.09999999999999998, 0.8, 0.09999999999999999],
                                [0.09999999999999998, 0.7872983346207417, 0.1127016653792583],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.10143149884133251, 0.8872983346207417, 0.011270166537925829],
                                [0.10143149884133251, 0.7985685011586675, 0.09999999999999999],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.05635083268962915, 0.5, 0.44364916731037085],
                                [0.05635083268962915, 0.44364916731037085, 0.5],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.06270166537925825, 0.8872983346207417, 0.049999999999999996],
                                [0.06270166537925825, 0.4936491673103709, 0.44364916731037085],
                                [0.8, 0.09999999999999996, 0.09999999999999999],
                                [0.01270166537925832, 0.19999999999999996, 0.7872983346207417],
                                [0.01270166537925832, 0.09999999999999998, 0.8872983346207417],
                                [0.1127016653792583, 0.18872983346207417, 0.6985685011586675],
                                [0.023971831917184105, 0.8872983346207417, 0.08872983346207416],
                                [0.023971831917184105, 0.18872983346207417, 0.7872983346207417],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.7872983346207417, 0.11270166537925828, 0.09999999999999999],
                                [0.7872983346207417, 0.09999999999999998, 0.1127016653792583],
                                [0.8485685011586674, 0.10143149884133248, 0.049999999999999996],
                                [0.7985685011586675, 0.15143149884133247, 0.049999999999999996],
                                [0.7985685011586675, 0.10143149884133247, 0.09999999999999999],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.44364916731037085, 0.1127016653792583, 0.44364916731037085],
                                [0.44364916731037085, 0.05635083268962915, 0.5],
                                [0.7154737509655562, 0.06270166537925831, 0.22182458365518543],
                                [0.4936491673103709, 0.2845262490344437, 0.22182458365518543],
                                [0.4936491673103709, 0.06270166537925825, 0.44364916731037085],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.09999999999999998, 0.1127016653792583, 0.7872983346207417],
                                [0.09999999999999998, 0.01270166537925832, 0.8872983346207417],
                                [0.582379000772445, 0.02397183191718416, 0.39364916731037086],
                                [0.18872983346207423, 0.41762099922755497, 0.39364916731037086],
                                [0.18872983346207417, 0.023971831917184105, 0.7872983346207417],
                                [0.5436491673103708, 0.44364916731037085, 0.012701665379258308],
                                [0.44364916731037085, 0.45635083268962917, 0.09999999999999999],
                                [0.44364916731037085, 0.44364916731037085, 0.1127016653792583],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.44999999999999996, 0.5, 0.049999999999999996],
                                [0.44999999999999996, 0.45000000000000007, 0.09999999999999999],
                                [0.6936491673103709, 0.25, 0.05635083268962915],
                                [0.25, 0.30635083268962915, 0.44364916731037085],
                                [0.25, 0.25, 0.5],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.2781754163448146, 0.5, 0.22182458365518543],
                                [0.2781754163448146, 0.2781754163448146, 0.44364916731037085],
                                [0.8436491673103709, 0.056350832689629135, 0.09999999999999999],
                                [0.05635083268962915, 0.15635083268962913, 0.7872983346207417],
                                [0.05635083268962915, 0.05635083268962915, 0.8872983346207417],
                                [0.5, 0.10635083268962914, 0.39364916731037086],
                                [0.10635083268962925, 0.49999999999999994, 0.39364916731037086],
                                [0.1063508326896292, 0.10635083268962908, 0.7872983346207417],
                                [0.19999999999999996, 0.7872983346207417, 0.012701665379258308],
                                [0.09999999999999998, 0.8, 0.09999999999999999],
                                [0.09999999999999998, 0.7872983346207417, 0.1127016653792583],
                                [0.15143149884133245, 0.7985685011586675, 0.049999999999999996],
                                [0.10143149884133251, 0.8485685011586674, 0.049999999999999996],
                                [0.10143149884133251, 0.7985685011586675, 0.09999999999999999],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.05635083268962915, 0.5, 0.44364916731037085],
                                [0.05635083268962915, 0.44364916731037085, 0.5],
                                [0.2845262490344438, 0.4936491673103708, 0.22182458365518543],
                                [0.06270166537925825, 0.7154737509655563, 0.22182458365518543],
                                [0.06270166537925825, 0.4936491673103709, 0.44364916731037085],
                                [0.8, 0.09999999999999996, 0.09999999999999999],
                                [0.01270166537925832, 0.19999999999999996, 0.7872983346207417],
                                [0.01270166537925832, 0.09999999999999998, 0.8872983346207417],
                                [0.4176209992275551, 0.18872983346207411, 0.39364916731037086],
                                [0.023971831917184216, 0.582379000772445, 0.39364916731037086],
                                [0.023971831917184105, 0.18872983346207417, 0.7872983346207417],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.7872983346207417, 0.11270166537925828, 0.09999999999999999],
                                [0.7872983346207417, 0.09999999999999998, 0.1127016653792583],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.7985685011586675, 0.1127016653792583, 0.08872983346207416],
                                [0.7985685011586675, 0.10143149884133247, 0.09999999999999999],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.44364916731037085, 0.1127016653792583, 0.44364916731037085],
                                [0.44364916731037085, 0.05635083268962915, 0.5],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.49364916731037095, 0.11270166537925824, 0.39364916731037086],
                                [0.4936491673103709, 0.06270166537925825, 0.44364916731037085],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.09999999999999998, 0.1127016653792583, 0.7872983346207417],
                                [0.09999999999999998, 0.01270166537925832, 0.8872983346207417],
                                [0.8872983346207417, 0.023971831917184133, 0.08872983346207416],
                                [0.18872983346207417, 0.1127016653792583, 0.6985685011586675],
                                [0.18872983346207417, 0.023971831917184105, 0.7872983346207417],
                                [0.5436491673103708, 0.44364916731037085, 0.012701665379258308],
                                [0.44364916731037085, 0.45635083268962917, 0.09999999999999999],
                                [0.44364916731037085, 0.44364916731037085, 0.1127016653792583],
                                [0.5387298334620743, 0.45, 0.011270166537925829],
                                [0.44999999999999996, 0.46127016653792585, 0.08872983346207416],
                                [0.44999999999999996, 0.45000000000000007, 0.09999999999999999],
                                [0.6936491673103709, 0.25, 0.05635083268962915],
                                [0.25, 0.30635083268962915, 0.44364916731037085],
                                [0.25, 0.25, 0.5],
                                [0.6718245836551854, 0.2781754163448146, 0.049999999999999996],
                                [0.27817541634481463, 0.32817541634481456, 0.39364916731037086],
                                [0.2781754163448146, 0.2781754163448146, 0.44364916731037085],
                                [0.8436491673103709, 0.056350832689629135, 0.09999999999999999],
                                [0.05635083268962915, 0.15635083268962913, 0.7872983346207417],
                                [0.05635083268962915, 0.05635083268962915, 0.8872983346207417],
                                [0.8049193338482967, 0.10635083268962911, 0.08872983346207416],
                                [0.1063508326896292, 0.19508066615170327, 0.6985685011586675],
                                [0.1063508326896292, 0.10635083268962908, 0.7872983346207417],
                                [0.19999999999999996, 0.7872983346207417, 0.012701665379258308],
                                [0.09999999999999998, 0.8, 0.09999999999999999],
                                [0.09999999999999998, 0.7872983346207417, 0.1127016653792583],
                                [0.1901613323034066, 0.7985685011586676, 0.011270166537925829],
                                [0.10143149884133251, 0.8098386676965933, 0.08872983346207416],
                                [0.10143149884133251, 0.7985685011586675, 0.09999999999999999],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.05635083268962915, 0.5, 0.44364916731037085],
                                [0.05635083268962915, 0.44364916731037085, 0.5],
                                [0.4563508326896291, 0.49364916731037084, 0.049999999999999996],
                                [0.06270166537925825, 0.5436491673103709, 0.39364916731037086],
                                [0.06270166537925825, 0.4936491673103709, 0.44364916731037085],
                                [0.8, 0.09999999999999996, 0.09999999999999999],
                                [0.01270166537925832, 0.19999999999999996, 0.7872983346207417],
                                [0.01270166537925832, 0.09999999999999998, 0.8872983346207417],
                                [0.7225403330758517, 0.1887298334620741, 0.08872983346207416],
                                [0.023971831917184105, 0.27745966692414836, 0.6985685011586675],
                                [0.023971831917184105, 0.18872983346207417, 0.7872983346207417],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.7772983346207417,
                                    0.009999999999999998,
                                    0.20999999999999996,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7898386676965934,
                                    0.010161332303406647,
                                    0.19745966692414832,
                                    0.0025403330758516614,
                                ],
                                [
                                    0.7772983346207417,
                                    0.09872983346207416,
                                    0.10999999999999999,
                                    0.013971831917184138,
                                ],
                                [
                                    0.7885685011586675,
                                    0.10016133230340664,
                                    0.09872983346207416,
                                    0.012540333075851659,
                                ],
                                [
                                    0.7785685011586675,
                                    0.0988911657654808,
                                    0.10872983346207415,
                                    0.01381049961377749,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.41864916731037083,
                                    0.41864916731037083,
                                    0.08135083268962914,
                                    0.08135083268962914,
                                ],
                                [
                                    0.4468245836551854,
                                    0.4468245836551854,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                ],
                                [
                                    0.42182458365518544,
                                    0.42182458365518544,
                                    0.07817541634481456,
                                    0.07817541634481456,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.17999999999999997,
                                    0.019999999999999993,
                                    0.7200000000000001,
                                    0.08,
                                ],
                                [
                                    0.08999999999999998,
                                    0.7085685011586675,
                                    0.022701665379258308,
                                    0.17872983346207416,
                                ],
                                [
                                    0.10127016653792581,
                                    0.7972983346207416,
                                    0.011431498841332478,
                                    0.09,
                                ],
                                [
                                    0.09127016653792583,
                                    0.7185685011586675,
                                    0.021431498841332476,
                                    0.16872983346207418,
                                ],
                                [
                                    0.43801408404140796,
                                    0.005635083268962914,
                                    0.5492842505793337,
                                    0.0070665821102953935,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.4505544171172596,
                                    0.005796415572369563,
                                    0.536743917503482,
                                    0.006905249806888745,
                                ],
                                [
                                    0.43801408404140796,
                                    0.055635083268962916,
                                    0.44928425057933374,
                                    0.05706658211029538,
                                ],
                                [
                                    0.44928425057933374,
                                    0.05706658211029538,
                                    0.43801408404140796,
                                    0.05563508326896291,
                                ],
                                [
                                    0.7829334178897046,
                                    0.0994455828827404,
                                    0.10436491673103708,
                                    0.0132560824965179,
                                ],
                                [
                                    0.2359122918275927,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.04226312451722186,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.2890877081724073,
                                    0.017263124517221864,
                                    0.6545614591379636,
                                    0.03908770817240728,
                                ],
                                [
                                    0.2359122918275927,
                                    0.2359122918275927,
                                    0.2640877081724073,
                                    0.2640877081724073,
                                ],
                                [
                                    0.2640877081724073,
                                    0.2640877081724073,
                                    0.2359122918275927,
                                    0.2359122918275927,
                                ],
                                [
                                    0.43273687548277817,
                                    0.43273687548277817,
                                    0.06726312451722186,
                                    0.06726312451722186,
                                ],
                                [
                                    0.050715749420666235,
                                    0.005635083268962914,
                                    0.8492842505793338,
                                    0.09436491673103707,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.14071574942066623,
                                    0.015635083268962912,
                                    0.7592842505793338,
                                    0.08436491673103708,
                                ],
                                [
                                    0.05071574942066623,
                                    0.3992842505793337,
                                    0.06198591595859207,
                                    0.488014084041408,
                                ],
                                [
                                    0.06198591595859207,
                                    0.488014084041408,
                                    0.050715749420666235,
                                    0.39928425057933375,
                                ],
                                [
                                    0.0956350832689629,
                                    0.7529334178897047,
                                    0.017066582110295395,
                                    0.1343649167310371,
                                ],
                                [
                                    0.09872983346207415,
                                    0.0012701665379258305,
                                    0.8885685011586675,
                                    0.011431498841332478,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                    0.8760281680828159,
                                    0.011270166537925829,
                                ],
                                [
                                    0.0987298334620741,
                                    0.012540333075851654,
                                    0.7885685011586676,
                                    0.10016133230340664,
                                ],
                                [
                                    0.10999999999999995,
                                    0.013971831917184135,
                                    0.7772983346207417,
                                    0.09872983346207416,
                                ],
                                [
                                    0.7872983346207417,
                                    0.09999999999999999,
                                    0.09999999999999999,
                                    0.012701665379258308,
                                ],
                                [
                                    0.05317541634481457,
                                    0.003175416344814577,
                                    0.8904737509655563,
                                    0.05317541634481457,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.10635083268962914,
                                    0.006350832689629154,
                                    0.8372983346207417,
                                    0.049999999999999996,
                                ],
                                [
                                    0.0531754163448146,
                                    0.0531754163448146,
                                    0.4468245836551854,
                                    0.4468245836551854,
                                ],
                                [
                                    0.08135083268962917,
                                    0.08135083268962917,
                                    0.41864916731037083,
                                    0.41864916731037083,
                                ],
                                [
                                    0.44364916731037085,
                                    0.44364916731037085,
                                    0.05635083268962915,
                                    0.05635083268962915,
                                ],
                                [
                                    0.011431498841332488,
                                    0.001270166537925832,
                                    0.8885685011586675,
                                    0.09872983346207416,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.011431498841332483,
                                    0.09000000000000002,
                                    0.10127016653792581,
                                    0.7972983346207416,
                                ],
                                [
                                    0.022701665379258308,
                                    0.1787298334620742,
                                    0.08999999999999998,
                                    0.7085685011586675,
                                ],
                                [
                                    0.09999999999999999,
                                    0.7872983346207417,
                                    0.012701665379258308,
                                    0.09999999999999999,
                                ],
                                [
                                    0.7429334178897047,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.011985915958592068,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7549193338482967,
                                    0.04508066615170332,
                                    0.18872983346207414,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7772983346207417,
                                    0.09872983346207416,
                                    0.10999999999999999,
                                    0.013971831917184138,
                                ],
                                [
                                    0.7885685011586675,
                                    0.10016133230340664,
                                    0.09872983346207416,
                                    0.012540333075851659,
                                ],
                                [
                                    0.7829334178897046,
                                    0.0994455828827404,
                                    0.10436491673103708,
                                    0.0132560824965179,
                                ],
                                [
                                    0.33273687548277814,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.1390877081724073,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.41864916731037083,
                                    0.41864916731037083,
                                    0.08135083268962914,
                                    0.08135083268962914,
                                ],
                                [
                                    0.4468245836551854,
                                    0.4468245836551854,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                ],
                                [
                                    0.43273687548277817,
                                    0.43273687548277817,
                                    0.06726312451722186,
                                    0.06726312451722186,
                                ],
                                [
                                    0.0556350832689629,
                                    0.044364916731037075,
                                    0.5007157494206662,
                                    0.39928425057933375,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.1112701665379258,
                                    0.08872983346207415,
                                    0.44508066615170333,
                                    0.3549193338482967,
                                ],
                                [
                                    0.08999999999999998,
                                    0.7085685011586675,
                                    0.022701665379258308,
                                    0.17872983346207416,
                                ],
                                [
                                    0.10127016653792581,
                                    0.7972983346207416,
                                    0.011431498841332478,
                                    0.09,
                                ],
                                [
                                    0.0956350832689629,
                                    0.7529334178897047,
                                    0.017066582110295395,
                                    0.1343649167310371,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.43063508326896294,
                                    0.025715749420666238,
                                    0.5130140840414079,
                                    0.03063508326896291,
                                ],
                                [
                                    0.43801408404140796,
                                    0.055635083268962916,
                                    0.44928425057933374,
                                    0.05706658211029538,
                                ],
                                [
                                    0.44928425057933374,
                                    0.05706658211029538,
                                    0.43801408404140796,
                                    0.05563508326896291,
                                ],
                                [
                                    0.7872983346207417,
                                    0.09999999999999999,
                                    0.09999999999999999,
                                    0.012701665379258308,
                                ],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.22976312451722186,
                                    0.07658770817240729,
                                    0.5202368754827782,
                                    0.1734122918275927,
                                ],
                                [
                                    0.2359122918275927,
                                    0.2359122918275927,
                                    0.2640877081724073,
                                    0.2640877081724073,
                                ],
                                [
                                    0.2640877081724073,
                                    0.2640877081724073,
                                    0.2359122918275927,
                                    0.2359122918275927,
                                ],
                                [
                                    0.44364916731037085,
                                    0.44364916731037085,
                                    0.05635083268962915,
                                    0.05635083268962915,
                                ],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.08698591595859205,
                                    0.06936491673103708,
                                    0.4693649167310371,
                                    0.3742842505793338,
                                ],
                                [
                                    0.05071574942066623,
                                    0.3992842505793337,
                                    0.06198591595859207,
                                    0.488014084041408,
                                ],
                                [
                                    0.06198591595859207,
                                    0.488014084041408,
                                    0.050715749420666235,
                                    0.39928425057933375,
                                ],
                                [
                                    0.09999999999999999,
                                    0.7872983346207417,
                                    0.012701665379258308,
                                    0.09999999999999999,
                                ],
                                [
                                    0.09436491673103706,
                                    0.0056350832689629135,
                                    0.8492842505793338,
                                    0.050715749420666235,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.10635083268962914,
                                    0.006350832689629154,
                                    0.8372983346207417,
                                    0.049999999999999996,
                                ],
                                [
                                    0.0987298334620741,
                                    0.012540333075851654,
                                    0.7885685011586676,
                                    0.10016133230340664,
                                ],
                                [
                                    0.10999999999999995,
                                    0.013971831917184135,
                                    0.7772983346207417,
                                    0.09872983346207416,
                                ],
                                [
                                    0.7916632513517788,
                                    0.10055441711725958,
                                    0.0956350832689629,
                                    0.012147248261998717,
                                ],
                                [
                                    0.04226312451722186,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.2359122918275927,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.08452624903444372,
                                    0.028175416344814574,
                                    0.6654737509655563,
                                    0.22182458365518543,
                                ],
                                [
                                    0.0531754163448146,
                                    0.0531754163448146,
                                    0.4468245836551854,
                                    0.4468245836551854,
                                ],
                                [
                                    0.08135083268962917,
                                    0.08135083268962917,
                                    0.41864916731037083,
                                    0.41864916731037083,
                                ],
                                [
                                    0.45456145913796353,
                                    0.45456145913796353,
                                    0.04543854086203644,
                                    0.04543854086203644,
                                ],
                                [
                                    0.0070665821102954005,
                                    0.00563508326896292,
                                    0.5492842505793337,
                                    0.43801408404140796,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.011431498841332483,
                                    0.09000000000000002,
                                    0.10127016653792581,
                                    0.7972983346207416,
                                ],
                                [
                                    0.022701665379258308,
                                    0.1787298334620742,
                                    0.08999999999999998,
                                    0.7085685011586675,
                                ],
                                [
                                    0.10436491673103707,
                                    0.8216632513517788,
                                    0.008336748648221223,
                                    0.0656350832689629,
                                ],
                                [
                                    0.7085685011586675,
                                    0.07872983346207417,
                                    0.19143149884133245,
                                    0.021270166537925825,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [0.7200000000000001, 0.08, 0.18, 0.019999999999999997],
                                [
                                    0.7772983346207417,
                                    0.09872983346207416,
                                    0.10999999999999999,
                                    0.013971831917184138,
                                ],
                                [
                                    0.7885685011586675,
                                    0.10016133230340664,
                                    0.09872983346207416,
                                    0.012540333075851659,
                                ],
                                [
                                    0.7872983346207417,
                                    0.09999999999999999,
                                    0.09999999999999999,
                                    0.012701665379258308,
                                ],
                                [
                                    0.24682458365518542,
                                    0.19682458365518543,
                                    0.3095262490344437,
                                    0.24682458365518542,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.41864916731037083,
                                    0.41864916731037083,
                                    0.08135083268962914,
                                    0.08135083268962914,
                                ],
                                [
                                    0.4468245836551854,
                                    0.4468245836551854,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                ],
                                [
                                    0.44364916731037085,
                                    0.44364916731037085,
                                    0.05635083268962915,
                                    0.05635083268962915,
                                ],
                                [
                                    0.021270166537925822,
                                    0.07872983346207416,
                                    0.19143149884133245,
                                    0.7085685011586675,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.042540333075851644,
                                    0.1574596669241483,
                                    0.17016133230340663,
                                    0.6298386676965935,
                                ],
                                [
                                    0.08999999999999998,
                                    0.7085685011586675,
                                    0.022701665379258308,
                                    0.17872983346207416,
                                ],
                                [
                                    0.10127016653792581,
                                    0.7972983346207416,
                                    0.011431498841332478,
                                    0.09,
                                ],
                                [
                                    0.09999999999999999,
                                    0.7872983346207417,
                                    0.012701665379258308,
                                    0.09999999999999999,
                                ],
                                [
                                    0.39928425057933375,
                                    0.04436491673103708,
                                    0.5007157494206662,
                                    0.05563508326896291,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.41071574942066624,
                                    0.045635083268962914,
                                    0.4892842505793338,
                                    0.05436491673103708,
                                ],
                                [
                                    0.43801408404140796,
                                    0.055635083268962916,
                                    0.44928425057933374,
                                    0.05706658211029538,
                                ],
                                [
                                    0.44928425057933374,
                                    0.05706658211029538,
                                    0.43801408404140796,
                                    0.05563508326896291,
                                ],
                                [
                                    0.7916632513517788,
                                    0.10055441711725958,
                                    0.0956350832689629,
                                    0.012147248261998717,
                                ],
                                [
                                    0.1390877081724073,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.33273687548277814,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.17043854086203644,
                                    0.1359122918275927,
                                    0.38591229182759273,
                                    0.3077368754827781,
                                ],
                                [
                                    0.2359122918275927,
                                    0.2359122918275927,
                                    0.2640877081724073,
                                    0.2640877081724073,
                                ],
                                [
                                    0.2640877081724073,
                                    0.2640877081724073,
                                    0.2359122918275927,
                                    0.2359122918275927,
                                ],
                                [
                                    0.45456145913796353,
                                    0.45456145913796353,
                                    0.04543854086203644,
                                    0.04543854086203644,
                                ],
                                [
                                    0.011985915958592068,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.7429334178897047,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.03325608249651789,
                                    0.12309475019311124,
                                    0.17944558288274037,
                                    0.6642035844276305,
                                ],
                                [
                                    0.05071574942066623,
                                    0.3992842505793337,
                                    0.06198591595859207,
                                    0.488014084041408,
                                ],
                                [
                                    0.06198591595859207,
                                    0.488014084041408,
                                    0.050715749420666235,
                                    0.39928425057933375,
                                ],
                                [
                                    0.10436491673103707,
                                    0.8216632513517788,
                                    0.008336748648221223,
                                    0.0656350832689629,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.0987298334620741,
                                    0.012540333075851654,
                                    0.7885685011586676,
                                    0.10016133230340664,
                                ],
                                [
                                    0.10999999999999995,
                                    0.013971831917184135,
                                    0.7772983346207417,
                                    0.09872983346207416,
                                ],
                                [
                                    0.7960281680828158,
                                    0.10110883423451918,
                                    0.09127016653792583,
                                    0.011592831144739127,
                                ],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.0531754163448146,
                                    0.0531754163448146,
                                    0.4468245836551854,
                                    0.4468245836551854,
                                ],
                                [
                                    0.08135083268962917,
                                    0.08135083268962917,
                                    0.41864916731037083,
                                    0.41864916731037083,
                                ],
                                [
                                    0.46547375096555627,
                                    0.46547375096555627,
                                    0.03452624903444373,
                                    0.03452624903444373,
                                ],
                                [
                                    0.002701665379258313,
                                    0.010000000000000007,
                                    0.20999999999999996,
                                    0.7772983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.011431498841332483,
                                    0.09000000000000002,
                                    0.10127016653792581,
                                    0.7972983346207416,
                                ],
                                [
                                    0.022701665379258308,
                                    0.1787298334620742,
                                    0.08999999999999998,
                                    0.7085685011586675,
                                ],
                                [
                                    0.10872983346207415,
                                    0.8560281680828159,
                                    0.003971831917184141,
                                    0.03127016653792582,
                                ],
                                [
                                    0.7772983346207417,
                                    0.009999999999999998,
                                    0.20999999999999996,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8329334178897047,
                                    0.010715749420666238,
                                    0.15436491673103706,
                                    0.0019859159585920703,
                                ],
                                [
                                    0.7429334178897046,
                                    0.09436491673103707,
                                    0.14436491673103707,
                                    0.018336748648221223,
                                ],
                                [
                                    0.7929334178897046,
                                    0.10071574942066622,
                                    0.09436491673103707,
                                    0.011985915958592068,
                                ],
                                [
                                    0.4049193338482967,
                                    0.051431498841332475,
                                    0.482379000772445,
                                    0.06127016653792582,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.6545614591379636,
                                    0.03908770817240728,
                                    0.2890877081724073,
                                    0.017263124517221864,
                                ],
                                [
                                    0.33273687548277814,
                                    0.33273687548277814,
                                    0.16726312451722186,
                                    0.16726312451722186,
                                ],
                                [
                                    0.45773687548277814,
                                    0.45773687548277814,
                                    0.04226312451722186,
                                    0.04226312451722186,
                                ],
                                [
                                    0.15317541634481457,
                                    0.15317541634481457,
                                    0.3468245836551854,
                                    0.3468245836551854,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.4892842505793338,
                                    0.05436491673103708,
                                    0.41071574942066624,
                                    0.045635083268962914,
                                ],
                                [
                                    0.055635083268962916,
                                    0.43801408404140796,
                                    0.05706658211029538,
                                    0.44928425057933374,
                                ],
                                [
                                    0.10563508326896291,
                                    0.8316632513517789,
                                    0.007066582110295394,
                                    0.055635083268962916,
                                ],
                                [
                                    0.01762099922755498,
                                    0.13872983346207415,
                                    0.09508066615170331,
                                    0.7485685011586676,
                                ],
                                [
                                    0.43801408404140796,
                                    0.005635083268962914,
                                    0.5492842505793337,
                                    0.0070665821102953935,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.49364916731037084,
                                    0.006350832689629154,
                                    0.49364916731037084,
                                    0.006350832689629154,
                                ],
                                [
                                    0.41864916731037083,
                                    0.05317541634481457,
                                    0.4686491673103709,
                                    0.05952624903444373,
                                ],
                                [
                                    0.4686491673103709,
                                    0.05952624903444373,
                                    0.41864916731037083,
                                    0.05317541634481457,
                                ],
                                [
                                    0.4242842505793337,
                                    0.05389116576548081,
                                    0.463014084041408,
                                    0.05881049961377749,
                                ],
                                [
                                    0.2359122918275927,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.04226312451722186,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.2015877081724073,
                                    0.2015877081724073,
                                    0.2984122918275927,
                                    0.2984122918275927,
                                ],
                                [
                                    0.050715749420666235,
                                    0.005635083268962914,
                                    0.8492842505793338,
                                    0.09436491673103707,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [0.45, 0.049999999999999996, 0.45, 0.049999999999999996],
                                [
                                    0.031350832689629154,
                                    0.24682458365518542,
                                    0.08135083268962914,
                                    0.6404737509655563,
                                ],
                                [
                                    0.08135083268962914,
                                    0.6404737509655563,
                                    0.031350832689629154,
                                    0.24682458365518542,
                                ],
                                [
                                    0.03698591595859206,
                                    0.29118950038622243,
                                    0.07571574942066624,
                                    0.5961088342345192,
                                ],
                                [
                                    0.09872983346207415,
                                    0.0012701665379258305,
                                    0.8885685011586675,
                                    0.011431498841332478,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.15436491673103706,
                                    0.0019859159585920703,
                                    0.8329334178897047,
                                    0.010715749420666238,
                                ],
                                [
                                    0.09436491673103711,
                                    0.011985915958592074,
                                    0.7929334178897046,
                                    0.10071574942066622,
                                ],
                                [
                                    0.1443649167310371,
                                    0.018336748648221227,
                                    0.7429334178897046,
                                    0.09436491673103707,
                                ],
                                [
                                    0.44364916731037085,
                                    0.05635083268962915,
                                    0.44364916731037085,
                                    0.05635083268962915,
                                ],
                                [
                                    0.05317541634481457,
                                    0.003175416344814577,
                                    0.8904737509655563,
                                    0.05317541634481457,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.2890877081724073,
                                    0.017263124517221864,
                                    0.6545614591379636,
                                    0.03908770817240728,
                                ],
                                [
                                    0.04226312451722186,
                                    0.04226312451722186,
                                    0.45773687548277814,
                                    0.45773687548277814,
                                ],
                                [
                                    0.16726312451722186,
                                    0.16726312451722186,
                                    0.33273687548277814,
                                    0.33273687548277814,
                                ],
                                [0.25, 0.25, 0.25, 0.25],
                                [
                                    0.011431498841332488,
                                    0.001270166537925832,
                                    0.8885685011586675,
                                    0.09872983346207416,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.41071574942066624,
                                    0.045635083268962914,
                                    0.4892842505793338,
                                    0.05436491673103708,
                                ],
                                [
                                    0.007066582110295388,
                                    0.05563508326896287,
                                    0.10563508326896291,
                                    0.8316632513517789,
                                ],
                                [
                                    0.05706658211029538,
                                    0.44928425057933374,
                                    0.05563508326896291,
                                    0.43801408404140796,
                                ],
                                [
                                    0.05635083268962915,
                                    0.44364916731037085,
                                    0.05635083268962915,
                                    0.44364916731037085,
                                ],
                                [
                                    0.7429334178897047,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.011985915958592068,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7961088342345192,
                                    0.047540333075851655,
                                    0.14754033307585163,
                                    0.00881049961377749,
                                ],
                                [
                                    0.7429334178897046,
                                    0.09436491673103707,
                                    0.14436491673103707,
                                    0.018336748648221223,
                                ],
                                [
                                    0.7929334178897046,
                                    0.10071574942066622,
                                    0.09436491673103707,
                                    0.011985915958592068,
                                ],
                                [
                                    0.4242842505793337,
                                    0.05389116576548081,
                                    0.463014084041408,
                                    0.05881049961377749,
                                ],
                                [
                                    0.33273687548277814,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.1390877081724073,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.5202368754827782,
                                    0.1734122918275927,
                                    0.22976312451722186,
                                    0.07658770817240729,
                                ],
                                [
                                    0.33273687548277814,
                                    0.33273687548277814,
                                    0.16726312451722186,
                                    0.16726312451722186,
                                ],
                                [
                                    0.45773687548277814,
                                    0.45773687548277814,
                                    0.04226312451722186,
                                    0.04226312451722186,
                                ],
                                [
                                    0.2015877081724073,
                                    0.2015877081724073,
                                    0.2984122918275927,
                                    0.2984122918275927,
                                ],
                                [
                                    0.0556350832689629,
                                    0.044364916731037075,
                                    0.5007157494206662,
                                    0.39928425057933375,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.30245966692414833,
                                    0.2411895003862225,
                                    0.2538911657654808,
                                    0.20245966692414835,
                                ],
                                [
                                    0.055635083268962916,
                                    0.43801408404140796,
                                    0.05706658211029538,
                                    0.44928425057933374,
                                ],
                                [
                                    0.10563508326896291,
                                    0.8316632513517789,
                                    0.007066582110295394,
                                    0.055635083268962916,
                                ],
                                [
                                    0.03698591595859206,
                                    0.29118950038622243,
                                    0.07571574942066624,
                                    0.5961088342345192,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.41864916731037083,
                                    0.05317541634481457,
                                    0.4686491673103709,
                                    0.05952624903444373,
                                ],
                                [
                                    0.4686491673103709,
                                    0.05952624903444373,
                                    0.41864916731037083,
                                    0.05317541634481457,
                                ],
                                [
                                    0.44364916731037085,
                                    0.05635083268962915,
                                    0.44364916731037085,
                                    0.05635083268962915,
                                ],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [0.25, 0.25, 0.25, 0.25],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.031350832689629154,
                                    0.24682458365518542,
                                    0.08135083268962914,
                                    0.6404737509655563,
                                ],
                                [
                                    0.08135083268962914,
                                    0.6404737509655563,
                                    0.031350832689629154,
                                    0.24682458365518542,
                                ],
                                [
                                    0.05635083268962915,
                                    0.44364916731037085,
                                    0.05635083268962915,
                                    0.44364916731037085,
                                ],
                                [
                                    0.09436491673103706,
                                    0.0056350832689629135,
                                    0.8492842505793338,
                                    0.050715749420666235,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.14754033307585163,
                                    0.00881049961377749,
                                    0.7961088342345192,
                                    0.047540333075851655,
                                ],
                                [
                                    0.09436491673103711,
                                    0.011985915958592074,
                                    0.7929334178897046,
                                    0.10071574942066622,
                                ],
                                [
                                    0.1443649167310371,
                                    0.018336748648221227,
                                    0.7429334178897046,
                                    0.09436491673103707,
                                ],
                                [
                                    0.46301408404140787,
                                    0.05881049961377748,
                                    0.4242842505793338,
                                    0.053891165765480815,
                                ],
                                [
                                    0.04226312451722186,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.2359122918275927,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.22976312451722186,
                                    0.07658770817240729,
                                    0.5202368754827782,
                                    0.1734122918275927,
                                ],
                                [
                                    0.04226312451722186,
                                    0.04226312451722186,
                                    0.45773687548277814,
                                    0.45773687548277814,
                                ],
                                [
                                    0.16726312451722186,
                                    0.16726312451722186,
                                    0.33273687548277814,
                                    0.33273687548277814,
                                ],
                                [
                                    0.2984122918275927,
                                    0.2984122918275927,
                                    0.2015877081724073,
                                    0.2015877081724073,
                                ],
                                [
                                    0.0070665821102954005,
                                    0.00563508326896292,
                                    0.5492842505793337,
                                    0.43801408404140796,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.2538911657654808,
                                    0.20245966692414835,
                                    0.30245966692414833,
                                    0.2411895003862225,
                                ],
                                [
                                    0.007066582110295388,
                                    0.05563508326896287,
                                    0.10563508326896291,
                                    0.8316632513517789,
                                ],
                                [
                                    0.05706658211029538,
                                    0.44928425057933374,
                                    0.05563508326896291,
                                    0.43801408404140796,
                                ],
                                [
                                    0.07571574942066624,
                                    0.5961088342345192,
                                    0.03698591595859207,
                                    0.2911895003862225,
                                ],
                                [
                                    0.7085685011586675,
                                    0.07872983346207417,
                                    0.19143149884133245,
                                    0.021270166537925825,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7592842505793338,
                                    0.08436491673103708,
                                    0.14071574942066623,
                                    0.015635083268962912,
                                ],
                                [
                                    0.7429334178897046,
                                    0.09436491673103707,
                                    0.14436491673103707,
                                    0.018336748648221223,
                                ],
                                [
                                    0.7929334178897046,
                                    0.10071574942066622,
                                    0.09436491673103707,
                                    0.011985915958592068,
                                ],
                                [
                                    0.44364916731037085,
                                    0.05635083268962915,
                                    0.44364916731037085,
                                    0.05635083268962915,
                                ],
                                [
                                    0.24682458365518542,
                                    0.19682458365518543,
                                    0.3095262490344437,
                                    0.24682458365518542,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.38591229182759273,
                                    0.3077368754827781,
                                    0.17043854086203644,
                                    0.1359122918275927,
                                ],
                                [
                                    0.33273687548277814,
                                    0.33273687548277814,
                                    0.16726312451722186,
                                    0.16726312451722186,
                                ],
                                [
                                    0.45773687548277814,
                                    0.45773687548277814,
                                    0.04226312451722186,
                                    0.04226312451722186,
                                ],
                                [0.25, 0.25, 0.25, 0.25],
                                [
                                    0.021270166537925822,
                                    0.07872983346207416,
                                    0.19143149884133245,
                                    0.7085685011586675,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.1156350832689629,
                                    0.42801408404140795,
                                    0.09706658211029538,
                                    0.3592842505793338,
                                ],
                                [
                                    0.055635083268962916,
                                    0.43801408404140796,
                                    0.05706658211029538,
                                    0.44928425057933374,
                                ],
                                [
                                    0.10563508326896291,
                                    0.8316632513517789,
                                    0.007066582110295394,
                                    0.055635083268962916,
                                ],
                                [
                                    0.05635083268962915,
                                    0.44364916731037085,
                                    0.05635083268962915,
                                    0.44364916731037085,
                                ],
                                [
                                    0.39928425057933375,
                                    0.04436491673103708,
                                    0.5007157494206662,
                                    0.05563508326896291,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [0.45, 0.049999999999999996, 0.45, 0.049999999999999996],
                                [
                                    0.41864916731037083,
                                    0.05317541634481457,
                                    0.4686491673103709,
                                    0.05952624903444373,
                                ],
                                [
                                    0.4686491673103709,
                                    0.05952624903444373,
                                    0.41864916731037083,
                                    0.05317541634481457,
                                ],
                                [
                                    0.46301408404140787,
                                    0.05881049961377748,
                                    0.4242842505793338,
                                    0.053891165765480815,
                                ],
                                [
                                    0.1390877081724073,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.33273687548277814,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.2984122918275927,
                                    0.2984122918275927,
                                    0.2015877081724073,
                                    0.2015877081724073,
                                ],
                                [
                                    0.011985915958592068,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.7429334178897047,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.10635083268962914,
                                    0.39364916731037086,
                                    0.10635083268962914,
                                    0.39364916731037086,
                                ],
                                [
                                    0.031350832689629154,
                                    0.24682458365518542,
                                    0.08135083268962914,
                                    0.6404737509655563,
                                ],
                                [
                                    0.08135083268962914,
                                    0.6404737509655563,
                                    0.031350832689629154,
                                    0.24682458365518542,
                                ],
                                [
                                    0.07571574942066624,
                                    0.5961088342345192,
                                    0.03698591595859207,
                                    0.2911895003862225,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.14071574942066623,
                                    0.015635083268962912,
                                    0.7592842505793338,
                                    0.08436491673103708,
                                ],
                                [
                                    0.09436491673103711,
                                    0.011985915958592074,
                                    0.7929334178897046,
                                    0.10071574942066622,
                                ],
                                [
                                    0.1443649167310371,
                                    0.018336748648221227,
                                    0.7429334178897046,
                                    0.09436491673103707,
                                ],
                                [
                                    0.482379000772445,
                                    0.06127016653792582,
                                    0.4049193338482967,
                                    0.051431498841332475,
                                ],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.17043854086203644,
                                    0.1359122918275927,
                                    0.38591229182759273,
                                    0.3077368754827781,
                                ],
                                [
                                    0.04226312451722186,
                                    0.04226312451722186,
                                    0.45773687548277814,
                                    0.45773687548277814,
                                ],
                                [
                                    0.16726312451722186,
                                    0.16726312451722186,
                                    0.33273687548277814,
                                    0.33273687548277814,
                                ],
                                [
                                    0.3468245836551854,
                                    0.3468245836551854,
                                    0.15317541634481457,
                                    0.15317541634481457,
                                ],
                                [
                                    0.002701665379258313,
                                    0.010000000000000007,
                                    0.20999999999999996,
                                    0.7772983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.09706658211029538,
                                    0.3592842505793338,
                                    0.1156350832689629,
                                    0.42801408404140795,
                                ],
                                [
                                    0.007066582110295388,
                                    0.05563508326896287,
                                    0.10563508326896291,
                                    0.8316632513517789,
                                ],
                                [
                                    0.05706658211029538,
                                    0.44928425057933374,
                                    0.05563508326896291,
                                    0.43801408404140796,
                                ],
                                [
                                    0.09508066615170331,
                                    0.7485685011586676,
                                    0.01762099922755498,
                                    0.13872983346207415,
                                ],
                                [
                                    0.7772983346207417,
                                    0.009999999999999998,
                                    0.20999999999999996,
                                    0.0027016653792583103,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.7085685011586675,
                                    0.08999999999999998,
                                    0.17872983346207416,
                                    0.022701665379258308,
                                ],
                                [
                                    0.7972983346207416,
                                    0.10127016653792581,
                                    0.09,
                                    0.011431498841332478,
                                ],
                                [
                                    0.03127016653792586,
                                    0.003971831917184145,
                                    0.8560281680828159,
                                    0.10872983346207415,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.24682458365518545,
                                    0.24682458365518545,
                                    0.25317541634481455,
                                    0.25317541634481455,
                                ],
                                [
                                    0.4686491673103709,
                                    0.4686491673103709,
                                    0.031350832689629154,
                                    0.031350832689629154,
                                ],
                                [
                                    -0.11547375096555634,
                                    -0.11547375096555634,
                                    0.6154737509655563,
                                    0.6154737509655563,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.02127016653792583,
                                    0.16745966692414835,
                                    0.09143149884133248,
                                    0.7198386676965933,
                                ],
                                [
                                    0.10999999999999999,
                                    0.8660281680828159,
                                    0.0027016653792583103,
                                    0.021270166537925825,
                                ],
                                [
                                    -0.05602816808281586,
                                    -0.4411088342345193,
                                    0.16872983346207415,
                                    1.328407168855261,
                                ],
                                [
                                    0.43801408404140796,
                                    0.005635083268962914,
                                    0.5492842505793337,
                                    0.0070665821102953935,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.536743917503482,
                                    0.006905249806888745,
                                    0.4505544171172596,
                                    0.005796415572369563,
                                ],
                                [
                                    0.3992842505793337,
                                    0.05071574942066623,
                                    0.488014084041408,
                                    0.06198591595859207,
                                ],
                                [
                                    0.488014084041408,
                                    0.06198591595859207,
                                    0.39928425057933375,
                                    0.050715749420666235,
                                ],
                                [
                                    0.06563508326896292,
                                    0.008336748648221226,
                                    0.8216632513517788,
                                    0.10436491673103707,
                                ],
                                [
                                    0.2359122918275927,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.04226312451722186,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.6545614591379636,
                                    0.03908770817240728,
                                    0.2890877081724073,
                                    0.017263124517221864,
                                ],
                                [
                                    0.1390877081724073,
                                    0.1390877081724073,
                                    0.3609122918275927,
                                    0.3609122918275927,
                                ],
                                [
                                    0.3609122918275927,
                                    0.3609122918275927,
                                    0.1390877081724073,
                                    0.1390877081724073,
                                ],
                                [
                                    -0.029561459137963597,
                                    -0.029561459137963597,
                                    0.5295614591379636,
                                    0.5295614591379636,
                                ],
                                [
                                    0.050715749420666235,
                                    0.005635083268962914,
                                    0.8492842505793338,
                                    0.09436491673103707,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.7592842505793338,
                                    0.08436491673103708,
                                    0.14071574942066623,
                                    0.015635083268962912,
                                ],
                                [
                                    0.011985915958592074,
                                    0.09436491673103711,
                                    0.10071574942066622,
                                    0.7929334178897046,
                                ],
                                [
                                    0.10071574942066622,
                                    0.7929334178897046,
                                    0.011985915958592068,
                                    0.09436491673103707,
                                ],
                                [
                                    -0.021663251351778778,
                                    -0.17055441711725966,
                                    0.13436491673103707,
                                    1.0578527517380014,
                                ],
                                [
                                    0.09872983346207415,
                                    0.0012701665379258305,
                                    0.8885685011586675,
                                    0.011431498841332478,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.1974596669241483,
                                    0.002540333075851661,
                                    0.7898386676965934,
                                    0.010161332303406647,
                                ],
                                [
                                    0.09000000000000002,
                                    0.011431498841332483,
                                    0.7972983346207416,
                                    0.10127016653792581,
                                ],
                                [
                                    0.1787298334620742,
                                    0.022701665379258308,
                                    0.7085685011586675,
                                    0.08999999999999998,
                                ],
                                [
                                    0.09999999999999999,
                                    0.012701665379258308,
                                    0.7872983346207417,
                                    0.09999999999999999,
                                ],
                                [
                                    0.05317541634481457,
                                    0.003175416344814577,
                                    0.8904737509655563,
                                    0.05317541634481457,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.03135083268962913,
                                    0.03135083268962913,
                                    0.4686491673103709,
                                    0.4686491673103709,
                                ],
                                [
                                    0.25317541634481455,
                                    0.25317541634481455,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                ],
                                [
                                    0.05635083268962915,
                                    0.05635083268962915,
                                    0.44364916731037085,
                                    0.44364916731037085,
                                ],
                                [
                                    0.011431498841332488,
                                    0.001270166537925832,
                                    0.8885685011586675,
                                    0.09872983346207416,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.7200000000000001,
                                    0.08,
                                    0.17999999999999997,
                                    0.019999999999999993,
                                ],
                                [
                                    0.002701665379258307,
                                    0.021270166537925798,
                                    0.10999999999999999,
                                    0.8660281680828159,
                                ],
                                [
                                    0.09143149884133248,
                                    0.7198386676965933,
                                    0.021270166537925825,
                                    0.16745966692414832,
                                ],
                                [
                                    0.012701665379258308,
                                    0.09999999999999999,
                                    0.09999999999999999,
                                    0.7872983346207417,
                                ],
                                [
                                    0.7429334178897047,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.011985915958592068,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.7085685011586675,
                                    0.08999999999999998,
                                    0.17872983346207416,
                                    0.022701665379258308,
                                ],
                                [
                                    0.7972983346207416,
                                    0.10127016653792581,
                                    0.09,
                                    0.011431498841332478,
                                ],
                                [
                                    0.06563508326896292,
                                    0.008336748648221226,
                                    0.8216632513517788,
                                    0.10436491673103707,
                                ],
                                [
                                    0.33273687548277814,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.1390877081724073,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.6654737509655563,
                                    0.22182458365518543,
                                    0.08452624903444372,
                                    0.028175416344814574,
                                ],
                                [
                                    0.24682458365518545,
                                    0.24682458365518545,
                                    0.25317541634481455,
                                    0.25317541634481455,
                                ],
                                [
                                    0.4686491673103709,
                                    0.4686491673103709,
                                    0.031350832689629154,
                                    0.031350832689629154,
                                ],
                                [
                                    -0.029561459137963597,
                                    -0.029561459137963597,
                                    0.5295614591379636,
                                    0.5295614591379636,
                                ],
                                [
                                    0.0556350832689629,
                                    0.044364916731037075,
                                    0.5007157494206662,
                                    0.39928425057933375,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.49364916731037084,
                                    0.39364916731037086,
                                    0.06270166537925831,
                                    0.049999999999999996,
                                ],
                                [
                                    0.02127016653792583,
                                    0.16745966692414835,
                                    0.09143149884133248,
                                    0.7198386676965933,
                                ],
                                [
                                    0.10999999999999999,
                                    0.8660281680828159,
                                    0.0027016653792583103,
                                    0.021270166537925825,
                                ],
                                [
                                    -0.021663251351778778,
                                    -0.17055441711725966,
                                    0.13436491673103707,
                                    1.0578527517380014,
                                ],
                                [
                                    0.41864916731037083,
                                    0.024999999999999998,
                                    0.525,
                                    0.031350832689629154,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.5130140840414079,
                                    0.03063508326896291,
                                    0.43063508326896294,
                                    0.025715749420666238,
                                ],
                                [
                                    0.3992842505793337,
                                    0.05071574942066623,
                                    0.488014084041408,
                                    0.06198591595859207,
                                ],
                                [
                                    0.488014084041408,
                                    0.06198591595859207,
                                    0.39928425057933375,
                                    0.050715749420666235,
                                ],
                                [
                                    0.09999999999999999,
                                    0.012701665379258308,
                                    0.7872983346207417,
                                    0.09999999999999999,
                                ],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.5202368754827782,
                                    0.1734122918275927,
                                    0.22976312451722186,
                                    0.07658770817240729,
                                ],
                                [
                                    0.1390877081724073,
                                    0.1390877081724073,
                                    0.3609122918275927,
                                    0.3609122918275927,
                                ],
                                [
                                    0.3609122918275927,
                                    0.3609122918275927,
                                    0.1390877081724073,
                                    0.1390877081724073,
                                ],
                                [
                                    0.05635083268962915,
                                    0.05635083268962915,
                                    0.44364916731037085,
                                    0.44364916731037085,
                                ],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.4693649167310371,
                                    0.3742842505793338,
                                    0.08698591595859205,
                                    0.06936491673103708,
                                ],
                                [
                                    0.011985915958592074,
                                    0.09436491673103711,
                                    0.10071574942066622,
                                    0.7929334178897046,
                                ],
                                [
                                    0.10071574942066622,
                                    0.7929334178897046,
                                    0.011985915958592068,
                                    0.09436491673103707,
                                ],
                                [
                                    0.012701665379258308,
                                    0.09999999999999999,
                                    0.09999999999999999,
                                    0.7872983346207417,
                                ],
                                [
                                    0.09436491673103706,
                                    0.0056350832689629135,
                                    0.8492842505793338,
                                    0.050715749420666235,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.18872983346207411,
                                    0.011270166537925827,
                                    0.7549193338482967,
                                    0.04508066615170332,
                                ],
                                [
                                    0.09000000000000002,
                                    0.011431498841332483,
                                    0.7972983346207416,
                                    0.10127016653792581,
                                ],
                                [
                                    0.1787298334620742,
                                    0.022701665379258308,
                                    0.7085685011586675,
                                    0.08999999999999998,
                                ],
                                [
                                    0.13436491673103707,
                                    0.01706658211029539,
                                    0.7529334178897047,
                                    0.0956350832689629,
                                ],
                                [
                                    0.04226312451722186,
                                    0.014087708172407287,
                                    0.7077368754827782,
                                    0.2359122918275927,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.03135083268962913,
                                    0.03135083268962913,
                                    0.4686491673103709,
                                    0.4686491673103709,
                                ],
                                [
                                    0.25317541634481455,
                                    0.25317541634481455,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                ],
                                [
                                    0.1422631245172219,
                                    0.1422631245172219,
                                    0.3577368754827781,
                                    0.3577368754827781,
                                ],
                                [
                                    0.0070665821102954005,
                                    0.00563508326896292,
                                    0.5492842505793337,
                                    0.43801408404140796,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.44508066615170333,
                                    0.3549193338482967,
                                    0.1112701665379258,
                                    0.08872983346207415,
                                ],
                                [
                                    0.002701665379258307,
                                    0.021270166537925798,
                                    0.10999999999999999,
                                    0.8660281680828159,
                                ],
                                [
                                    0.09143149884133248,
                                    0.7198386676965933,
                                    0.021270166537925825,
                                    0.16745966692414832,
                                ],
                                [
                                    0.047066582110295394,
                                    0.3705544171172596,
                                    0.0656350832689629,
                                    0.516743917503482,
                                ],
                                [
                                    0.7085685011586675,
                                    0.07872983346207417,
                                    0.19143149884133245,
                                    0.021270166537925825,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7085685011586675,
                                    0.08999999999999998,
                                    0.17872983346207416,
                                    0.022701665379258308,
                                ],
                                [
                                    0.7972983346207416,
                                    0.10127016653792581,
                                    0.09,
                                    0.011431498841332478,
                                ],
                                [
                                    0.09999999999999999,
                                    0.012701665379258308,
                                    0.7872983346207417,
                                    0.09999999999999999,
                                ],
                                [
                                    0.24682458365518542,
                                    0.19682458365518543,
                                    0.3095262490344437,
                                    0.24682458365518542,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.49364916731037084,
                                    0.39364916731037086,
                                    0.06270166537925831,
                                    0.049999999999999996,
                                ],
                                [
                                    0.24682458365518545,
                                    0.24682458365518545,
                                    0.25317541634481455,
                                    0.25317541634481455,
                                ],
                                [
                                    0.4686491673103709,
                                    0.4686491673103709,
                                    0.031350832689629154,
                                    0.031350832689629154,
                                ],
                                [
                                    0.05635083268962915,
                                    0.05635083268962915,
                                    0.44364916731037085,
                                    0.44364916731037085,
                                ],
                                [
                                    0.021270166537925822,
                                    0.07872983346207416,
                                    0.19143149884133245,
                                    0.7085685011586675,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.18872983346207414,
                                    0.6985685011586675,
                                    0.023971831917184137,
                                    0.08872983346207416,
                                ],
                                [
                                    0.02127016653792583,
                                    0.16745966692414835,
                                    0.09143149884133248,
                                    0.7198386676965933,
                                ],
                                [
                                    0.10999999999999999,
                                    0.8660281680828159,
                                    0.0027016653792583103,
                                    0.021270166537925825,
                                ],
                                [
                                    0.012701665379258308,
                                    0.09999999999999999,
                                    0.09999999999999999,
                                    0.7872983346207417,
                                ],
                                [
                                    0.39928425057933375,
                                    0.04436491673103708,
                                    0.5007157494206662,
                                    0.05563508326896291,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.4892842505793338,
                                    0.05436491673103708,
                                    0.41071574942066624,
                                    0.045635083268962914,
                                ],
                                [
                                    0.3992842505793337,
                                    0.05071574942066623,
                                    0.488014084041408,
                                    0.06198591595859207,
                                ],
                                [
                                    0.488014084041408,
                                    0.06198591595859207,
                                    0.39928425057933375,
                                    0.050715749420666235,
                                ],
                                [
                                    0.13436491673103707,
                                    0.01706658211029539,
                                    0.7529334178897047,
                                    0.0956350832689629,
                                ],
                                [
                                    0.1390877081724073,
                                    0.11091229182759271,
                                    0.41726312451722186,
                                    0.33273687548277814,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.38591229182759273,
                                    0.3077368754827781,
                                    0.17043854086203644,
                                    0.1359122918275927,
                                ],
                                [
                                    0.1390877081724073,
                                    0.1390877081724073,
                                    0.3609122918275927,
                                    0.3609122918275927,
                                ],
                                [
                                    0.3609122918275927,
                                    0.3609122918275927,
                                    0.1390877081724073,
                                    0.1390877081724073,
                                ],
                                [
                                    0.1422631245172219,
                                    0.1422631245172219,
                                    0.3577368754827781,
                                    0.3577368754827781,
                                ],
                                [
                                    0.011985915958592068,
                                    0.04436491673103708,
                                    0.2007157494206662,
                                    0.7429334178897047,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.17944558288274037,
                                    0.6642035844276305,
                                    0.03325608249651789,
                                    0.12309475019311124,
                                ],
                                [
                                    0.011985915958592074,
                                    0.09436491673103711,
                                    0.10071574942066622,
                                    0.7929334178897046,
                                ],
                                [
                                    0.10071574942066622,
                                    0.7929334178897046,
                                    0.011985915958592068,
                                    0.09436491673103707,
                                ],
                                [
                                    0.047066582110295394,
                                    0.3705544171172596,
                                    0.0656350832689629,
                                    0.516743917503482,
                                ],
                                [0.08999999999999998, 0.009999999999999997, 0.81, 0.09],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.17999999999999997,
                                    0.019999999999999993,
                                    0.7200000000000001,
                                    0.08,
                                ],
                                [
                                    0.09000000000000002,
                                    0.011431498841332483,
                                    0.7972983346207416,
                                    0.10127016653792581,
                                ],
                                [
                                    0.1787298334620742,
                                    0.022701665379258308,
                                    0.7085685011586675,
                                    0.08999999999999998,
                                ],
                                [
                                    0.16872983346207412,
                                    0.021431498841332473,
                                    0.7185685011586675,
                                    0.09127016653792583,
                                ],
                                [
                                    0.031350832689629154,
                                    0.024999999999999998,
                                    0.525,
                                    0.41864916731037083,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.03135083268962913,
                                    0.03135083268962913,
                                    0.4686491673103709,
                                    0.4686491673103709,
                                ],
                                [
                                    0.25317541634481455,
                                    0.25317541634481455,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                ],
                                [
                                    0.22817541634481459,
                                    0.22817541634481459,
                                    0.2718245836551854,
                                    0.2718245836551854,
                                ],
                                [
                                    0.002701665379258313,
                                    0.010000000000000007,
                                    0.20999999999999996,
                                    0.7772983346207417,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.17016133230340663,
                                    0.6298386676965935,
                                    0.042540333075851644,
                                    0.1574596669241483,
                                ],
                                [
                                    0.002701665379258307,
                                    0.021270166537925798,
                                    0.10999999999999999,
                                    0.8660281680828159,
                                ],
                                [
                                    0.09143149884133248,
                                    0.7198386676965933,
                                    0.021270166537925825,
                                    0.16745966692414832,
                                ],
                                [
                                    0.08143149884133248,
                                    0.6411088342345193,
                                    0.03127016653792582,
                                    0.24618950038622242,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                8.414521069453256e-06,
                                8.414521069453256e-06,
                                8.414521069453256e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0002532741595451084,
                                0.0002532741595451084,
                                0.0002532741595451084,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0004754470671621776,
                                0.0004754470671621776,
                                0.0004754470671621776,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                1.3463233711125205e-05,
                                1.3463233711125205e-05,
                                1.3463233711125205e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0004052386552721734,
                                0.0004052386552721734,
                                0.0004052386552721734,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0007607153074594841,
                                0.0007607153074594841,
                                0.0007607153074594841,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                8.414521069453256e-06,
                                8.414521069453256e-06,
                                8.414521069453256e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0002532741595451084,
                                0.0002532741595451084,
                                0.0002532741595451084,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0004754470671621776,
                                0.0004754470671621776,
                                0.0004754470671621776,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                1.3463233711125205e-05,
                                1.3463233711125205e-05,
                                1.3463233711125205e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0004052386552721734,
                                0.0004052386552721734,
                                0.0004052386552721734,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0007607153074594841,
                                0.0007607153074594841,
                                0.0007607153074594841,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                2.1541173937800323e-05,
                                2.1541173937800323e-05,
                                2.1541173937800323e-05,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0006483818484354772,
                                0.0006483818484354772,
                                0.0006483818484354772,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0012171444919351743,
                                0.0012171444919351743,
                                0.0012171444919351743,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                1.3463233711125205e-05,
                                1.3463233711125205e-05,
                                1.3463233711125205e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0004052386552721734,
                                0.0004052386552721734,
                                0.0004052386552721734,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0007607153074594841,
                                0.0007607153074594841,
                                0.0007607153074594841,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                8.414521069453256e-06,
                                8.414521069453256e-06,
                                8.414521069453256e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0002532741595451084,
                                0.0002532741595451084,
                                0.0002532741595451084,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0004754470671621776,
                                0.0004754470671621776,
                                0.0004754470671621776,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                1.3463233711125205e-05,
                                1.3463233711125205e-05,
                                1.3463233711125205e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.0004052386552721734,
                                0.0004052386552721734,
                                0.0004052386552721734,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0007607153074594841,
                                0.0007607153074594841,
                                0.0007607153074594841,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                8.414521069453256e-06,
                                8.414521069453256e-06,
                                8.414521069453256e-06,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0002532741595451084,
                                0.0002532741595451084,
                                0.0002532741595451084,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0004754470671621776,
                                0.0004754470671621776,
                                0.0004754470671621776,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                5.708883915653138e-05,
                                5.708883915653138e-05,
                                5.708883915653138e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001428898033836306,
                                0.001428898033836306,
                                0.001428898033836306,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.002086258211597928,
                                0.002086258211597928,
                                0.002086258211597928,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                9.134214265045018e-05,
                                9.134214265045018e-05,
                                9.134214265045018e-05,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.002286236854138089,
                                0.002286236854138089,
                                0.002286236854138089,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0033380131385566843,
                                0.0033380131385566843,
                                0.0033380131385566843,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                5.708883915653138e-05,
                                5.708883915653138e-05,
                                5.708883915653138e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001428898033836306,
                                0.001428898033836306,
                                0.001428898033836306,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.002086258211597928,
                                0.002086258211597928,
                                0.002086258211597928,
                                0.00017177513394186608,
                                0.00017177513394186608,
                                0.00017177513394186608,
                                9.134214265045019e-05,
                                9.134214265045019e-05,
                                9.134214265045019e-05,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.002286236854138089,
                                0.002286236854138089,
                                0.002286236854138089,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0033380131385566843,
                                0.0033380131385566843,
                                0.0033380131385566843,
                                0.00027484021430698567,
                                0.00027484021430698567,
                                0.00027484021430698567,
                                0.00014614742824072026,
                                0.00014614742824072026,
                                0.00014614742824072026,
                                0.004877305288827922,
                                0.004877305288827922,
                                0.004877305288827922,
                                0.0036579789666209414,
                                0.0036579789666209414,
                                0.0036579789666209414,
                                0.002163812430106976,
                                0.002163812430106976,
                                0.002163812430106976,
                                0.0053408210216906934,
                                0.0053408210216906934,
                                0.0053408210216906934,
                                0.00017177513394186608,
                                0.00017177513394186608,
                                0.00017177513394186608,
                                9.134214265045019e-05,
                                9.134214265045019e-05,
                                9.134214265045019e-05,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.003048315805517452,
                                0.002286236854138089,
                                0.002286236854138089,
                                0.002286236854138089,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0033380131385566843,
                                0.0033380131385566843,
                                0.0033380131385566843,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                5.708883915653138e-05,
                                5.708883915653138e-05,
                                5.708883915653138e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001428898033836306,
                                0.001428898033836306,
                                0.001428898033836306,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.002086258211597928,
                                0.002086258211597928,
                                0.002086258211597928,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                9.134214265045018e-05,
                                9.134214265045018e-05,
                                9.134214265045018e-05,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.002286236854138089,
                                0.002286236854138089,
                                0.002286236854138089,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0033380131385566843,
                                0.0033380131385566843,
                                0.0033380131385566843,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                5.708883915653138e-05,
                                5.708883915653138e-05,
                                5.708883915653138e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001428898033836306,
                                0.001428898033836306,
                                0.001428898033836306,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.002086258211597928,
                                0.002086258211597928,
                                0.002086258211597928,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.038969552643732e-05,
                                6.038969552643732e-05,
                                6.038969552643732e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.001175623874291198,
                                0.001175623874291198,
                                0.001175623874291198,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0008846467500782385,
                                0.0008846467500782385,
                                0.0008846467500782385,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                9.662351284229969e-05,
                                9.662351284229969e-05,
                                9.662351284229969e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001880998198865916,
                                0.001880998198865916,
                                0.001880998198865916,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.001415434800125181,
                                0.001415434800125181,
                                0.001415434800125181,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.038969552643732e-05,
                                6.038969552643732e-05,
                                6.038969552643732e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.001175623874291198,
                                0.001175623874291198,
                                0.001175623874291198,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0008846467500782385,
                                0.0008846467500782385,
                                0.0008846467500782385,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                9.662351284229969e-05,
                                9.662351284229969e-05,
                                9.662351284229969e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001880998198865916,
                                0.001880998198865916,
                                0.001880998198865916,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.001415434800125181,
                                0.001415434800125181,
                                0.001415434800125181,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                0.00017177513394186605,
                                0.00015459762054767946,
                                0.00015459762054767946,
                                0.00015459762054767946,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.0030483158055174516,
                                0.003009597118185465,
                                0.003009597118185465,
                                0.003009597118185465,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.0013523827688168603,
                                0.002264695680200289,
                                0.002264695680200289,
                                0.002264695680200289,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                9.662351284229969e-05,
                                9.662351284229969e-05,
                                9.662351284229969e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001880998198865916,
                                0.001880998198865916,
                                0.001880998198865916,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.001415434800125181,
                                0.001415434800125181,
                                0.001415434800125181,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.038969552643732e-05,
                                6.038969552643732e-05,
                                6.038969552643732e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.001175623874291198,
                                0.001175623874291198,
                                0.001175623874291198,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0008846467500782385,
                                0.0008846467500782385,
                                0.0008846467500782385,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                0.00010735945871366632,
                                9.662351284229969e-05,
                                9.662351284229969e-05,
                                9.662351284229969e-05,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001905197378448408,
                                0.001880998198865916,
                                0.001880998198865916,
                                0.001880998198865916,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.0008452392305105379,
                                0.001415434800125181,
                                0.001415434800125181,
                                0.001415434800125181,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.709966169604147e-05,
                                6.038969552643732e-05,
                                6.038969552643732e-05,
                                6.038969552643732e-05,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.0011907483615302553,
                                0.001175623874291198,
                                0.001175623874291198,
                                0.001175623874291198,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0005282745190690862,
                                0.0008846467500782385,
                                0.0008846467500782385,
                                0.0008846467500782385,
                            ]
                        ),
                    )
                case 4:
                    return (
                        np.array(
                            [
                                [0.8707778735729046, 0.06461106321354772, 0.06461106321354769],
                                [0.8659570925834785, 0.1292221264270954, 0.004820780989426014],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9264168062367892, 0.06909712848837923, 0.00448606527483153],
                                [0.9260820905221947, 0.07358319376321075, 0.0003347157145944845],
                                [0.9260820905221947, 0.06909712848837923, 0.004820780989426014],
                                [0.64638501094228, 0.046518677526560914, 0.30709631153115907],
                                [0.6234718442658673, 0.35361498905772, 0.02291316667641278],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.9108367959583605, 0.06784094078410025, 0.021322263257539317],
                                [0.909245892539487, 0.08916320404163959, 0.0015909034188734612],
                                [0.9092458925394871, 0.06784094078410025, 0.02291316667641278],
                                [0.35361498905772004, 0.022913166676412855, 0.6234718442658671],
                                [0.3070963115311591, 0.64638501094228, 0.046518677526560935],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.8905092334115704, 0.06620196663242117, 0.04328879995600838],
                                [0.8872793558410179, 0.10949076658842953, 0.0032298775705525535],
                                [0.8872793558410179, 0.06620196663242114, 0.046518677526560935],
                                [0.12922212642709563, 0.0048207809894258435, 0.8659570925834785],
                                [0.0646110632135477, 0.8707778735729046, 0.06461106321354769],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.8749292231331417, 0.06494577892814217, 0.06012499793871616],
                                [0.8704431578583101, 0.12507077686685836, 0.004486065274831529],
                                [0.8704431578583101, 0.0649457789281422, 0.06461106321354769],
                                [0.6282926252552932, 0.30709631153115907, 0.06461106321354769],
                                [0.6234718442658671, 0.3717073747447068, 0.004820780989426014],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6670953599364701, 0.3284185747886984, 0.00448606527483153],
                                [0.6667606442218755, 0.33290464006352993, 0.0003347157145944845],
                                [0.6667606442218755, 0.3284185747886984, 0.004820780989426014],
                                [0.4718004659681028, 0.22110322250073805, 0.30709631153115907],
                                [0.44888729929169013, 0.5281995340318971, 0.02291316667641278],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.656229820713855, 0.32244791602860573, 0.021322263257539317],
                                [0.6546389172949814, 0.3437701792861451, 0.0015909034188734612],
                                [0.6546389172949816, 0.32244791602860573, 0.02291316667641278],
                                [0.267621900027299, 0.10890625570683388, 0.6234718442658671],
                                [0.221103222500738, 0.7323780999727011, 0.046518677526560935],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.6420533263338664, 0.3146578737101252, 0.04328879995600838],
                                [0.6388234487633138, 0.3579466736661336, 0.0032298775705525535],
                                [0.6388234487633139, 0.3146578737101252, 0.046518677526560935],
                                [0.11112974074010873, 0.022913166676412744, 0.8659570925834785],
                                [0.046518677526561025, 0.8888702592598913, 0.06461106321354769],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.6311877871112512, 0.30868721495003254, 0.06012499793871616],
                                [0.6267017218364197, 0.3688122128887487, 0.004486065274831529],
                                [0.6267017218364197, 0.30868721495003254, 0.06461106321354769],
                                [0.3119170925205851, 0.6234718442658672, 0.06461106321354769],
                                [0.3070963115311591, 0.6880829074794148, 0.004820780989426014],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.32875329050329294, 0.6667606442218755, 0.00448606527483153],
                                [0.3284185747886984, 0.6712467094967071, 0.0003347157145944845],
                                [0.3284185747886984, 0.6667606442218755, 0.004820780989426014],
                                [0.2440163891771508, 0.4488872992916901, 0.30709631153115907],
                                [0.221103222500738, 0.7559836108228493, 0.02291316667641278],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.32403881944747925, 0.6546389172949815, 0.021322263257539317],
                                [0.3224479160286058, 0.6759611805525207, 0.0015909034188734612],
                                [0.3224479160286058, 0.6546389172949815, 0.02291316667641278],
                                [0.1554249332333948, 0.2211032225007381, 0.6234718442658671],
                                [0.10890625570683388, 0.8445750667666052, 0.046518677526560935],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.3178877512806777, 0.6388234487633139, 0.04328879995600838],
                                [0.3146578737101252, 0.6821122487193222, 0.0032298775705525535],
                                [0.3146578737101252, 0.6388234487633139, 0.046518677526560935],
                                [0.08752422988996056, 0.046518677526560914, 0.8659570925834785],
                                [0.022913166676412855, 0.9124757701100394, 0.06461106321354769],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.3131732802248641, 0.6267017218364197, 0.06012499793871616],
                                [0.3086872149500326, 0.6868267197751359, 0.004486065274831529],
                                [0.3086872149500326, 0.6267017218364197, 0.06461106321354769],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.0646110632135477, 0.9305681557970262, 0.004820780989426014],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.06943184420297377, 0.9260820905221947, 0.00448606527483153],
                                [0.06909712848837923, 0.9305681557970262, 0.0003347157145944845],
                                [0.06909712848837923, 0.9260820905221947, 0.004820780989426014],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.046518677526561025, 0.9305681557970262, 0.02291316667641278],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.0678409407841003, 0.9305681557970262, 0.0015909034188734612],
                                [0.0678409407841003, 0.909245892539487, 0.02291316667641278],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.022913166676412855, 0.9305681557970262, 0.046518677526560935],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600838],
                                [0.06620196663242117, 0.9305681557970262, 0.0032298775705525535],
                                [0.06620196663242117, 0.8872793558410179, 0.046518677526560935],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.004820780989426066, 0.9305681557970262, 0.06461106321354769],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871616],
                                [0.06494577892814224, 0.9305681557970262, 0.004486065274831529],
                                [0.06494577892814224, 0.8704431578583101, 0.06461106321354769],
                                [0.8707778735729046, 0.06461106321354772, 0.06461106321354769],
                                [0.8659570925834785, 0.1292221264270954, 0.004820780989426014],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9276729939410682, 0.06909712848837923, 0.0032298775705525535],
                                [0.9260820905221947, 0.07232700605893178, 0.0015909034188734612],
                                [0.9260820905221947, 0.06909712848837923, 0.004820780989426014],
                                [0.64638501094228, 0.046518677526560914, 0.30709631153115907],
                                [0.6234718442658673, 0.35361498905772, 0.02291316667641278],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.916807454718453, 0.06784094078410026, 0.015351604497446674],
                                [0.909245892539487, 0.08319254528154695, 0.007561562178966105],
                                [0.9092458925394871, 0.06784094078410025, 0.02291316667641278],
                                [0.35361498905772004, 0.022913166676412855, 0.6234718442658671],
                                [0.3070963115311591, 0.64638501094228, 0.046518677526560935],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.9026309603384646, 0.06620196663242117, 0.03116707302911426],
                                [0.8872793558410179, 0.09736903966153541, 0.015351604497446674],
                                [0.8872793558410179, 0.06620196663242114, 0.046518677526560935],
                                [0.12922212642709563, 0.0048207809894258435, 0.8659570925834785],
                                [0.0646110632135477, 0.8707778735729046, 0.06461106321354769],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.8917654211158494, 0.06494577892814218, 0.04328879995600837],
                                [0.8704431578583102, 0.10823457888415057, 0.021322263257539314],
                                [0.8704431578583101, 0.0649457789281422, 0.06461106321354769],
                                [0.6282926252552932, 0.30709631153115907, 0.06461106321354769],
                                [0.6234718442658671, 0.3717073747447068, 0.004820780989426014],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.668351547640749, 0.3284185747886984, 0.0032298775705525535],
                                [0.6667606442218756, 0.33164845235925094, 0.0015909034188734612],
                                [0.6667606442218755, 0.3284185747886984, 0.004820780989426014],
                                [0.4718004659681028, 0.22110322250073805, 0.30709631153115907],
                                [0.44888729929169013, 0.5281995340318971, 0.02291316667641278],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.6622004794739476, 0.3224479160286058, 0.015351604497446674],
                                [0.6546389172949814, 0.3377995205260525, 0.007561562178966105],
                                [0.6546389172949816, 0.32244791602860573, 0.02291316667641278],
                                [0.267621900027299, 0.10890625570683388, 0.6234718442658671],
                                [0.221103222500738, 0.7323780999727011, 0.046518677526560935],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.6541750532607605, 0.3146578737101252, 0.03116707302911426],
                                [0.6388234487633139, 0.34582494673923947, 0.015351604497446674],
                                [0.6388234487633139, 0.3146578737101252, 0.046518677526560935],
                                [0.11112974074010873, 0.022913166676412744, 0.8659570925834785],
                                [0.046518677526561025, 0.8888702592598913, 0.06461106321354769],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.6480239850939591, 0.30868721495003254, 0.04328879995600837],
                                [0.6267017218364198, 0.3519760149060409, 0.021322263257539314],
                                [0.6267017218364197, 0.30868721495003254, 0.06461106321354769],
                                [0.3119170925205851, 0.6234718442658672, 0.06461106321354769],
                                [0.3070963115311591, 0.6880829074794148, 0.004820780989426014],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525535],
                                [0.3284185747886984, 0.6699905217924281, 0.0015909034188734612],
                                [0.3284185747886984, 0.6667606442218755, 0.004820780989426014],
                                [0.2440163891771508, 0.4488872992916901, 0.30709631153115907],
                                [0.221103222500738, 0.7559836108228493, 0.02291316667641278],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.3224479160286058, 0.6699905217924281, 0.007561562178966105],
                                [0.3224479160286058, 0.6546389172949815, 0.02291316667641278],
                                [0.1554249332333948, 0.2211032225007381, 0.6234718442658671],
                                [0.10890625570683388, 0.8445750667666052, 0.046518677526560935],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.3146578737101252, 0.6699905217924281, 0.015351604497446674],
                                [0.3146578737101252, 0.6388234487633139, 0.046518677526560935],
                                [0.08752422988996056, 0.046518677526560914, 0.8659570925834785],
                                [0.022913166676412855, 0.9124757701100394, 0.06461106321354769],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.330009478207572, 0.6267017218364197, 0.04328879995600837],
                                [0.3086872149500326, 0.6699905217924281, 0.021322263257539314],
                                [0.3086872149500326, 0.6267017218364197, 0.06461106321354769],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.0646110632135477, 0.9305681557970262, 0.004820780989426014],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.0706880319072527, 0.9260820905221947, 0.0032298775705525535],
                                [0.06909712848837923, 0.9293119680927473, 0.0015909034188734612],
                                [0.06909712848837923, 0.9260820905221947, 0.004820780989426014],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.046518677526561025, 0.9305681557970262, 0.02291316667641278],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.07540250296306639, 0.909245892539487, 0.015351604497446674],
                                [0.0678409407841003, 0.9245974970369336, 0.007561562178966105],
                                [0.0678409407841003, 0.909245892539487, 0.02291316667641278],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.022913166676412855, 0.9305681557970262, 0.046518677526560935],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.08155357112986794, 0.8872793558410178, 0.03116707302911426],
                                [0.06620196663242117, 0.9184464288701322, 0.015351604497446674],
                                [0.06620196663242117, 0.8872793558410179, 0.046518677526560935],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.004820780989426066, 0.9305681557970262, 0.06461106321354769],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.08626804218568163, 0.8704431578583101, 0.04328879995600837],
                                [0.06494577892814224, 0.9137319578143185, 0.021322263257539314],
                                [0.06494577892814224, 0.8704431578583101, 0.06461106321354769],
                                [0.8707778735729046, 0.06461106321354772, 0.06461106321354769],
                                [0.8659570925834785, 0.1292221264270954, 0.004820780989426014],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9293119680927473, 0.06909712848837923, 0.0015909034188734612],
                                [0.9260820905221947, 0.07068803190725267, 0.0032298775705525535],
                                [0.9260820905221947, 0.06909712848837923, 0.004820780989426014],
                                [0.64638501094228, 0.046518677526560914, 0.30709631153115907],
                                [0.6234718442658673, 0.35361498905772, 0.02291316667641278],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.9245974970369336, 0.06784094078410026, 0.007561562178966105],
                                [0.909245892539487, 0.07540250296306637, 0.015351604497446674],
                                [0.9092458925394871, 0.06784094078410025, 0.02291316667641278],
                                [0.35361498905772004, 0.022913166676412855, 0.6234718442658671],
                                [0.3070963115311591, 0.64638501094228, 0.046518677526560935],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.9184464288701322, 0.06620196663242116, 0.015351604497446674],
                                [0.8872793558410179, 0.08155357112986783, 0.03116707302911426],
                                [0.8872793558410179, 0.06620196663242114, 0.046518677526560935],
                                [0.12922212642709563, 0.0048207809894258435, 0.8659570925834785],
                                [0.0646110632135477, 0.8707778735729046, 0.06461106321354769],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.9137319578143186, 0.06494577892814218, 0.021322263257539314],
                                [0.8704431578583102, 0.08626804218568151, 0.04328879995600837],
                                [0.8704431578583101, 0.0649457789281422, 0.06461106321354769],
                                [0.6282926252552932, 0.30709631153115907, 0.06461106321354769],
                                [0.6234718442658671, 0.3717073747447068, 0.004820780989426014],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734612],
                                [0.6667606442218755, 0.33000947820757187, 0.0032298775705525535],
                                [0.6667606442218755, 0.3284185747886984, 0.004820780989426014],
                                [0.4718004659681028, 0.22110322250073805, 0.30709631153115907],
                                [0.44888729929169013, 0.5281995340318971, 0.02291316667641278],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6546389172949814, 0.3300094782075719, 0.015351604497446674],
                                [0.6546389172949816, 0.32244791602860573, 0.02291316667641278],
                                [0.267621900027299, 0.10890625570683388, 0.6234718442658671],
                                [0.221103222500738, 0.7323780999727011, 0.046518677526560935],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6388234487633139, 0.33000947820757187, 0.03116707302911426],
                                [0.6388234487633139, 0.3146578737101252, 0.046518677526560935],
                                [0.11112974074010873, 0.022913166676412744, 0.8659570925834785],
                                [0.046518677526561025, 0.8888702592598913, 0.06461106321354769],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.6699905217924282, 0.30868721495003254, 0.021322263257539314],
                                [0.6267017218364198, 0.33000947820757187, 0.04328879995600837],
                                [0.6267017218364197, 0.30868721495003254, 0.06461106321354769],
                                [0.3119170925205851, 0.6234718442658672, 0.06461106321354769],
                                [0.3070963115311591, 0.6880829074794148, 0.004820780989426014],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.331648452359251, 0.6667606442218755, 0.0015909034188734612],
                                [0.3284185747886984, 0.668351547640749, 0.0032298775705525535],
                                [0.3284185747886984, 0.6667606442218755, 0.004820780989426014],
                                [0.2440163891771508, 0.4488872992916901, 0.30709631153115907],
                                [0.221103222500738, 0.7559836108228493, 0.02291316667641278],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.33779952052605244, 0.6546389172949815, 0.007561562178966105],
                                [0.3224479160286058, 0.6622004794739476, 0.015351604497446674],
                                [0.3224479160286058, 0.6546389172949815, 0.02291316667641278],
                                [0.1554249332333948, 0.2211032225007381, 0.6234718442658671],
                                [0.10890625570683388, 0.8445750667666052, 0.046518677526560935],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.34582494673923947, 0.6388234487633139, 0.015351604497446674],
                                [0.3146578737101252, 0.6541750532607605, 0.03116707302911426],
                                [0.3146578737101252, 0.6388234487633139, 0.046518677526560935],
                                [0.08752422988996056, 0.046518677526560914, 0.8659570925834785],
                                [0.022913166676412855, 0.9124757701100394, 0.06461106321354769],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.3519760149060409, 0.6267017218364198, 0.021322263257539314],
                                [0.3086872149500326, 0.6480239850939591, 0.04328879995600837],
                                [0.3086872149500326, 0.6267017218364197, 0.06461106321354769],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.0646110632135477, 0.9305681557970262, 0.004820780989426014],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.07232700605893183, 0.9260820905221947, 0.0015909034188734612],
                                [0.06909712848837923, 0.9276729939410682, 0.0032298775705525535],
                                [0.06909712848837923, 0.9260820905221947, 0.004820780989426014],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.046518677526561025, 0.9305681557970262, 0.02291316667641278],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.08319254528154696, 0.909245892539487, 0.007561562178966105],
                                [0.0678409407841003, 0.916807454718453, 0.015351604497446674],
                                [0.0678409407841003, 0.909245892539487, 0.02291316667641278],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.022913166676412855, 0.9305681557970262, 0.046518677526560935],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.09736903966153543, 0.8872793558410179, 0.015351604497446674],
                                [0.06620196663242117, 0.9026309603384646, 0.03116707302911426],
                                [0.06620196663242117, 0.8872793558410179, 0.046518677526560935],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.004820780989426066, 0.9305681557970262, 0.06461106321354769],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.10823457888415056, 0.8704431578583102, 0.021322263257539314],
                                [0.06494577892814224, 0.8917654211158494, 0.04328879995600837],
                                [0.06494577892814224, 0.8704431578583101, 0.06461106321354769],
                                [0.8707778735729046, 0.06461106321354772, 0.06461106321354769],
                                [0.8659570925834785, 0.1292221264270954, 0.004820780989426014],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9305681557970262, 0.06909712848837923, 0.0003347157145944848],
                                [0.9260820905221948, 0.0694318442029737, 0.00448606527483153],
                                [0.9260820905221947, 0.06909712848837923, 0.004820780989426014],
                                [0.64638501094228, 0.046518677526560914, 0.30709631153115907],
                                [0.6234718442658673, 0.35361498905772, 0.02291316667641278],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.9305681557970262, 0.06784094078410025, 0.0015909034188734622],
                                [0.909245892539487, 0.06943184420297373, 0.021322263257539317],
                                [0.9092458925394871, 0.06784094078410025, 0.02291316667641278],
                                [0.35361498905772004, 0.022913166676412855, 0.6234718442658671],
                                [0.3070963115311591, 0.64638501094228, 0.046518677526560935],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.9305681557970262, 0.06620196663242116, 0.003229877570552556],
                                [0.8872793558410179, 0.06943184420297371, 0.04328879995600838],
                                [0.8872793558410179, 0.06620196663242114, 0.046518677526560935],
                                [0.12922212642709563, 0.0048207809894258435, 0.8659570925834785],
                                [0.0646110632135477, 0.8707778735729046, 0.06461106321354769],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.9305681557970262, 0.06494577892814218, 0.0044860652748315325],
                                [0.8704431578583101, 0.06943184420297373, 0.06012499793871616],
                                [0.8704431578583101, 0.0649457789281422, 0.06461106321354769],
                                [0.6282926252552932, 0.30709631153115907, 0.06461106321354769],
                                [0.6234718442658671, 0.3717073747447068, 0.004820780989426014],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6712467094967071, 0.3284185747886984, 0.0003347157145944848],
                                [0.6667606442218756, 0.3287532905032929, 0.00448606527483153],
                                [0.6667606442218755, 0.3284185747886984, 0.004820780989426014],
                                [0.4718004659681028, 0.22110322250073805, 0.30709631153115907],
                                [0.44888729929169013, 0.5281995340318971, 0.02291316667641278],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.6759611805525207, 0.3224479160286058, 0.0015909034188734622],
                                [0.6546389172949815, 0.32403881944747925, 0.021322263257539317],
                                [0.6546389172949816, 0.32244791602860573, 0.02291316667641278],
                                [0.267621900027299, 0.10890625570683388, 0.6234718442658671],
                                [0.221103222500738, 0.7323780999727011, 0.046518677526560935],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.6821122487193222, 0.3146578737101252, 0.003229877570552556],
                                [0.6388234487633138, 0.31788775128067775, 0.04328879995600838],
                                [0.6388234487633139, 0.3146578737101252, 0.046518677526560935],
                                [0.11112974074010873, 0.022913166676412744, 0.8659570925834785],
                                [0.046518677526561025, 0.8888702592598913, 0.06461106321354769],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.6868267197751359, 0.30868721495003254, 0.0044860652748315325],
                                [0.6267017218364197, 0.31317328022486407, 0.06012499793871616],
                                [0.6267017218364197, 0.30868721495003254, 0.06461106321354769],
                                [0.3119170925205851, 0.6234718442658672, 0.06461106321354769],
                                [0.3070963115311591, 0.6880829074794148, 0.004820780989426014],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.33290464006352993, 0.6667606442218755, 0.0003347157145944848],
                                [0.3284185747886984, 0.6670953599364701, 0.00448606527483153],
                                [0.3284185747886984, 0.6667606442218755, 0.004820780989426014],
                                [0.2440163891771508, 0.4488872992916901, 0.30709631153115907],
                                [0.221103222500738, 0.7559836108228493, 0.02291316667641278],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.34377017928614506, 0.6546389172949815, 0.0015909034188734622],
                                [0.3224479160286058, 0.6562298207138549, 0.021322263257539317],
                                [0.3224479160286058, 0.6546389172949815, 0.02291316667641278],
                                [0.1554249332333948, 0.2211032225007381, 0.6234718442658671],
                                [0.10890625570683388, 0.8445750667666052, 0.046518677526560935],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.35794667366613353, 0.6388234487633139, 0.003229877570552556],
                                [0.3146578737101252, 0.6420533263338664, 0.04328879995600838],
                                [0.3146578737101252, 0.6388234487633139, 0.046518677526560935],
                                [0.08752422988996056, 0.046518677526560914, 0.8659570925834785],
                                [0.022913166676412855, 0.9124757701100394, 0.06461106321354769],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.36881221288874877, 0.6267017218364197, 0.0044860652748315325],
                                [0.3086872149500326, 0.6311877871112512, 0.06012499793871616],
                                [0.3086872149500326, 0.6267017218364197, 0.06461106321354769],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.0646110632135477, 0.9305681557970262, 0.004820780989426014],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.07358319376321076, 0.9260820905221947, 0.0003347157145944848],
                                [0.06909712848837923, 0.9264168062367892, 0.00448606527483153],
                                [0.06909712848837923, 0.9260820905221947, 0.004820780989426014],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.046518677526561025, 0.9305681557970262, 0.02291316667641278],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.08916320404163958, 0.909245892539487, 0.0015909034188734622],
                                [0.0678409407841003, 0.9108367959583604, 0.021322263257539317],
                                [0.0678409407841003, 0.909245892539487, 0.02291316667641278],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.022913166676412855, 0.9305681557970262, 0.046518677526560935],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.1094907665884296, 0.8872793558410178, 0.003229877570552556],
                                [0.06620196663242117, 0.8905092334115704, 0.04328879995600838],
                                [0.06620196663242117, 0.8872793558410179, 0.046518677526560935],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.004820780989426066, 0.9305681557970262, 0.06461106321354769],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.1250707768668584, 0.8704431578583101, 0.0044860652748315325],
                                [0.06494577892814224, 0.8749292231331416, 0.06012499793871616],
                                [0.06494577892814224, 0.8704431578583101, 0.06461106321354769],
                                [0.8888702592598914, 0.0646110632135477, 0.046518677526560935],
                                [0.8659570925834786, 0.11112974074010865, 0.02291316667641278],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9108367959583605, 0.06784094078410025, 0.021322263257539317],
                                [0.909245892539487, 0.08916320404163959, 0.0015909034188734612],
                                [0.9092458925394871, 0.06784094078410025, 0.02291316667641278],
                                [0.7323780999727011, 0.04651867752656094, 0.22110322250073802],
                                [0.6234718442658672, 0.2676219000272989, 0.10890625570683385],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.8367850244481247, 0.0618702820240076, 0.10134469352786774],
                                [0.8292234622691586, 0.16321497555187534, 0.007561562178966105],
                                [0.8292234622691586, 0.0618702820240076, 0.10890625570683385],
                                [0.528199534031897, 0.0229131666764128, 0.44888729929169013],
                                [0.3070963115311591, 0.4718004659681029, 0.22110322250073802],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.7401681422911817, 0.054080239705527, 0.20575161800329134],
                                [0.724816537793735, 0.2598318577088184, 0.015351604497446674],
                                [0.724816537793735, 0.05408023970552703, 0.22110322250073802],
                                [0.37170737474470683, 0.004820780989426066, 0.6234718442658671],
                                [0.0646110632135477, 0.6282926252552932, 0.30709631153115907],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.6661163707809459, 0.04810958094543438, 0.28577404827361974],
                                [0.6447941075234066, 0.3338836292190541, 0.021322263257539317],
                                [0.6447941075234065, 0.04810958094543438, 0.30709631153115907],
                                [0.64638501094228, 0.3070963115311591, 0.046518677526560935],
                                [0.6234718442658673, 0.35361498905772, 0.02291316667641278],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.656229820713855, 0.32244791602860573, 0.021322263257539317],
                                [0.6546389172949814, 0.3437701792861451, 0.0015909034188734612],
                                [0.6546389172949816, 0.32244791602860573, 0.02291316667641278],
                                [0.557793554998524, 0.22110322250073802, 0.22110322250073802],
                                [0.44888729929169013, 0.442206445001476, 0.10890625570683385],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.6045859248839132, 0.2940693815882192, 0.10134469352786774],
                                [0.597024362704947, 0.39541407511608695, 0.007561562178966105],
                                [0.5970243627049469, 0.29406938158821927, 0.10890625570683385],
                                [0.442206445001476, 0.10890625570683388, 0.44888729929169013],
                                [0.221103222500738, 0.557793554998524, 0.22110322250073802],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.5372050628766181, 0.25704331912009065, 0.20575161800329134],
                                [0.5218534583791713, 0.46279493712338204, 0.015351604497446674],
                                [0.5218534583791713, 0.2570433191200907, 0.22110322250073802],
                                [0.35361498905772004, 0.022913166676412855, 0.6234718442658671],
                                [0.046518677526560914, 0.64638501094228, 0.30709631153115907],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.4855611670466762, 0.22866478467970408, 0.28577404827361974],
                                [0.4642389037891368, 0.5144388329533239, 0.021322263257539317],
                                [0.46423890378913674, 0.22866478467970414, 0.30709631153115907],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3070963115311591, 0.6699905217924281, 0.02291316667641278],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.32403881944747925, 0.6546389172949815, 0.021322263257539317],
                                [0.3224479160286058, 0.6759611805525207, 0.0015909034188734612],
                                [0.3224479160286058, 0.6546389172949815, 0.02291316667641278],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.221103222500738, 0.6699905217924281, 0.10890625570683385],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.30163094376718536, 0.597024362704947, 0.10134469352786774],
                                [0.29406938158821927, 0.6983690562328146, 0.007561562178966105],
                                [0.29406938158821927, 0.5970243627049469, 0.10890625570683385],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.10890625570683388, 0.6699905217924281, 0.22110322250073802],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.27239492361753737, 0.5218534583791713, 0.20575161800329134],
                                [0.2570433191200907, 0.7276050763824626, 0.015351604497446674],
                                [0.2570433191200907, 0.5218534583791713, 0.22110322250073802],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.022913166676412855, 0.669990521792428, 0.30709631153115907],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.24998704793724347, 0.4642389037891368, 0.28577404827361974],
                                [0.2286647846797042, 0.7500129520627565, 0.021322263257539317],
                                [0.22866478467970403, 0.46423890378913685, 0.30709631153115907],
                                [0.08752422988996056, 0.8659570925834785, 0.046518677526560935],
                                [0.0646110632135477, 0.9124757701100396, 0.02291316667641278],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.0678409407841003, 0.9305681557970262, 0.0015909034188734612],
                                [0.0678409407841003, 0.909245892539487, 0.02291316667641278],
                                [0.1554249332333948, 0.6234718442658672, 0.22110322250073802],
                                [0.046518677526561025, 0.8445750667666051, 0.10890625570683385],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.06187028202400768, 0.9305681557970262, 0.007561562178966105],
                                [0.06187028202400768, 0.8292234622691584, 0.10890625570683385],
                                [0.24401638917715085, 0.307096311531159, 0.44888729929169013],
                                [0.022913166676412855, 0.7559836108228492, 0.22110322250073802],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.05408023970552711, 0.9305681557970262, 0.015351604497446674],
                                [0.05408023970552711, 0.7248165377937349, 0.22110322250073802],
                                [0.3119170925205851, 0.06461106321354781, 0.6234718442658671],
                                [0.004820780989426066, 0.6880829074794148, 0.30709631153115907],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.04810958094543438, 0.9305681557970263, 0.021322263257539317],
                                [0.04810958094543438, 0.6447941075234065, 0.30709631153115907],
                                [0.8888702592598914, 0.0646110632135477, 0.046518677526560935],
                                [0.8659570925834786, 0.11112974074010865, 0.02291316667641278],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.916807454718453, 0.06784094078410026, 0.015351604497446674],
                                [0.909245892539487, 0.08319254528154695, 0.007561562178966105],
                                [0.9092458925394871, 0.06784094078410025, 0.02291316667641278],
                                [0.7323780999727011, 0.04651867752656094, 0.22110322250073802],
                                [0.6234718442658672, 0.2676219000272989, 0.10890625570683385],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.8651635588885112, 0.06187028202400763, 0.07296615908748122],
                                [0.8292234622691586, 0.13483644111148882, 0.035940096619352636],
                                [0.8292234622691586, 0.0618702820240076, 0.10890625570683385],
                                [0.528199534031897, 0.0229131666764128, 0.44888729929169013],
                                [0.3070963115311591, 0.4718004659681029, 0.22110322250073802],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.7977826968812161, 0.054080239705527056, 0.1481370634132568],
                                [0.7248165377937349, 0.20221730311878383, 0.07296615908748122],
                                [0.724816537793735, 0.05408023970552703, 0.22110322250073802],
                                [0.37170737474470683, 0.004820780989426066, 0.6234718442658671],
                                [0.0646110632135477, 0.6282926252552932, 0.30709631153115907],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.7461388010512743, 0.04810958094543438, 0.20575161800329134],
                                [0.6447941075234066, 0.2538611989487257, 0.10134469352786774],
                                [0.6447941075234065, 0.04810958094543438, 0.30709631153115907],
                                [0.64638501094228, 0.3070963115311591, 0.046518677526560935],
                                [0.6234718442658673, 0.35361498905772, 0.02291316667641278],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6622004794739476, 0.3224479160286058, 0.015351604497446674],
                                [0.6546389172949814, 0.3377995205260525, 0.007561562178966105],
                                [0.6546389172949816, 0.32244791602860573, 0.02291316667641278],
                                [0.557793554998524, 0.22110322250073802, 0.22110322250073802],
                                [0.44888729929169013, 0.442206445001476, 0.10890625570683385],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.6329644593242996, 0.2940693815882192, 0.07296615908748122],
                                [0.597024362704947, 0.3670355406757004, 0.035940096619352636],
                                [0.5970243627049469, 0.29406938158821927, 0.10890625570683385],
                                [0.442206445001476, 0.10890625570683388, 0.44888729929169013],
                                [0.221103222500738, 0.557793554998524, 0.22110322250073802],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.5948196174666526, 0.2570433191200906, 0.1481370634132568],
                                [0.5218534583791712, 0.4051803825333475, 0.07296615908748122],
                                [0.5218534583791713, 0.2570433191200907, 0.22110322250073802],
                                [0.35361498905772004, 0.022913166676412855, 0.6234718442658671],
                                [0.046518677526560914, 0.64638501094228, 0.30709631153115907],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.5655835973170045, 0.22866478467970414, 0.20575161800329134],
                                [0.46423890378913685, 0.4344164026829955, 0.10134469352786774],
                                [0.46423890378913674, 0.22866478467970414, 0.30709631153115907],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3070963115311591, 0.6699905217924281, 0.02291316667641278],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.3224479160286058, 0.6699905217924281, 0.007561562178966105],
                                [0.3224479160286058, 0.6546389172949815, 0.02291316667641278],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.221103222500738, 0.6699905217924281, 0.10890625570683385],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.29406938158821927, 0.6699905217924281, 0.035940096619352636],
                                [0.29406938158821927, 0.5970243627049469, 0.10890625570683385],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.10890625570683388, 0.6699905217924281, 0.22110322250073802],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.2570433191200907, 0.669990521792428, 0.07296615908748122],
                                [0.2570433191200907, 0.5218534583791713, 0.22110322250073802],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.022913166676412855, 0.669990521792428, 0.30709631153115907],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.2286647846797043, 0.669990521792428, 0.10134469352786774],
                                [0.22866478467970403, 0.46423890378913685, 0.30709631153115907],
                                [0.08752422988996056, 0.8659570925834785, 0.046518677526560935],
                                [0.0646110632135477, 0.9124757701100396, 0.02291316667641278],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.07540250296306639, 0.909245892539487, 0.015351604497446674],
                                [0.0678409407841003, 0.9245974970369336, 0.007561562178966105],
                                [0.0678409407841003, 0.909245892539487, 0.02291316667641278],
                                [0.1554249332333948, 0.6234718442658672, 0.22110322250073802],
                                [0.046518677526561025, 0.8445750667666051, 0.10890625570683385],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.09781037864336017, 0.8292234622691586, 0.07296615908748122],
                                [0.06187028202400768, 0.9021896213566397, 0.035940096619352636],
                                [0.06187028202400768, 0.8292234622691584, 0.10890625570683385],
                                [0.24401638917715085, 0.307096311531159, 0.44888729929169013],
                                [0.022913166676412855, 0.7559836108228492, 0.22110322250073802],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.12704639879300827, 0.7248165377937349, 0.1481370634132568],
                                [0.05408023970552711, 0.8729536012069916, 0.07296615908748122],
                                [0.05408023970552711, 0.7248165377937349, 0.22110322250073802],
                                [0.3119170925205851, 0.06461106321354781, 0.6234718442658671],
                                [0.004820780989426066, 0.6880829074794148, 0.30709631153115907],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.14945427447330217, 0.6447941075234065, 0.20575161800329134],
                                [0.04810958094543438, 0.8505457255266979, 0.10134469352786774],
                                [0.04810958094543438, 0.6447941075234065, 0.30709631153115907],
                                [0.8888702592598914, 0.0646110632135477, 0.046518677526560935],
                                [0.8659570925834786, 0.11112974074010865, 0.02291316667641278],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9245974970369336, 0.06784094078410026, 0.007561562178966105],
                                [0.909245892539487, 0.07540250296306637, 0.015351604497446674],
                                [0.9092458925394871, 0.06784094078410025, 0.02291316667641278],
                                [0.7323780999727011, 0.04651867752656094, 0.22110322250073802],
                                [0.6234718442658672, 0.2676219000272989, 0.10890625570683385],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.9021896213566398, 0.06187028202400761, 0.035940096619352636],
                                [0.8292234622691586, 0.09781037864336023, 0.07296615908748122],
                                [0.8292234622691586, 0.0618702820240076, 0.10890625570683385],
                                [0.528199534031897, 0.0229131666764128, 0.44888729929169013],
                                [0.3070963115311591, 0.4718004659681029, 0.22110322250073802],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.8729536012069916, 0.054080239705527056, 0.07296615908748122],
                                [0.7248165377937349, 0.12704639879300825, 0.1481370634132568],
                                [0.724816537793735, 0.05408023970552703, 0.22110322250073802],
                                [0.37170737474470683, 0.004820780989426066, 0.6234718442658671],
                                [0.0646110632135477, 0.6282926252552932, 0.30709631153115907],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.8505457255266979, 0.04810958094543441, 0.10134469352786774],
                                [0.6447941075234065, 0.14945427447330212, 0.20575161800329134],
                                [0.6447941075234065, 0.04810958094543438, 0.30709631153115907],
                                [0.64638501094228, 0.3070963115311591, 0.046518677526560935],
                                [0.6234718442658673, 0.35361498905772, 0.02291316667641278],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6546389172949814, 0.3300094782075719, 0.015351604497446674],
                                [0.6546389172949816, 0.32244791602860573, 0.02291316667641278],
                                [0.557793554998524, 0.22110322250073802, 0.22110322250073802],
                                [0.44888729929169013, 0.442206445001476, 0.10890625570683385],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.597024362704947, 0.3300094782075718, 0.07296615908748122],
                                [0.5970243627049469, 0.29406938158821927, 0.10890625570683385],
                                [0.442206445001476, 0.10890625570683388, 0.44888729929169013],
                                [0.221103222500738, 0.557793554998524, 0.22110322250073802],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.5218534583791713, 0.33000947820757187, 0.1481370634132568],
                                [0.5218534583791713, 0.2570433191200907, 0.22110322250073802],
                                [0.35361498905772004, 0.022913166676412855, 0.6234718442658671],
                                [0.046518677526560914, 0.64638501094228, 0.30709631153115907],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.4642389037891368, 0.33000947820757187, 0.20575161800329134],
                                [0.46423890378913674, 0.22866478467970414, 0.30709631153115907],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3070963115311591, 0.6699905217924281, 0.02291316667641278],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.33779952052605244, 0.6546389172949815, 0.007561562178966105],
                                [0.3224479160286058, 0.6622004794739476, 0.015351604497446674],
                                [0.3224479160286058, 0.6546389172949815, 0.02291316667641278],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.221103222500738, 0.6699905217924281, 0.10890625570683385],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.36703554067570043, 0.597024362704947, 0.035940096619352636],
                                [0.29406938158821916, 0.6329644593242996, 0.07296615908748122],
                                [0.29406938158821927, 0.5970243627049469, 0.10890625570683385],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.10890625570683388, 0.6699905217924281, 0.22110322250073802],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.4051803825333473, 0.5218534583791714, 0.07296615908748122],
                                [0.2570433191200907, 0.5948196174666525, 0.1481370634132568],
                                [0.2570433191200907, 0.5218534583791713, 0.22110322250073802],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.022913166676412855, 0.669990521792428, 0.30709631153115907],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.4344164026829955, 0.46423890378913685, 0.10134469352786774],
                                [0.2286647846797042, 0.5655835973170045, 0.20575161800329134],
                                [0.22866478467970403, 0.46423890378913685, 0.30709631153115907],
                                [0.08752422988996056, 0.8659570925834785, 0.046518677526560935],
                                [0.0646110632135477, 0.9124757701100396, 0.02291316667641278],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.08319254528154696, 0.909245892539487, 0.007561562178966105],
                                [0.0678409407841003, 0.916807454718453, 0.015351604497446674],
                                [0.0678409407841003, 0.909245892539487, 0.02291316667641278],
                                [0.1554249332333948, 0.6234718442658672, 0.22110322250073802],
                                [0.046518677526561025, 0.8445750667666051, 0.10890625570683385],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.13483644111148885, 0.8292234622691586, 0.035940096619352636],
                                [0.06187028202400757, 0.8651635588885112, 0.07296615908748122],
                                [0.06187028202400768, 0.8292234622691584, 0.10890625570683385],
                                [0.24401638917715085, 0.307096311531159, 0.44888729929169013],
                                [0.022913166676412855, 0.7559836108228492, 0.22110322250073802],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.20221730311878394, 0.7248165377937348, 0.07296615908748122],
                                [0.05408023970552711, 0.7977826968812161, 0.1481370634132568],
                                [0.05408023970552711, 0.7248165377937349, 0.22110322250073802],
                                [0.3119170925205851, 0.06461106321354781, 0.6234718442658671],
                                [0.004820780989426066, 0.6880829074794148, 0.30709631153115907],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.25386119894872583, 0.6447941075234065, 0.10134469352786774],
                                [0.04810958094543438, 0.7461388010512743, 0.20575161800329134],
                                [0.04810958094543438, 0.6447941075234065, 0.30709631153115907],
                                [0.8888702592598914, 0.0646110632135477, 0.046518677526560935],
                                [0.8659570925834786, 0.11112974074010865, 0.02291316667641278],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9305681557970262, 0.06784094078410025, 0.0015909034188734622],
                                [0.909245892539487, 0.06943184420297373, 0.021322263257539317],
                                [0.9092458925394871, 0.06784094078410025, 0.02291316667641278],
                                [0.7323780999727011, 0.04651867752656094, 0.22110322250073802],
                                [0.6234718442658672, 0.2676219000272989, 0.10890625570683385],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.9305681557970263, 0.0618702820240076, 0.007561562178966111],
                                [0.8292234622691586, 0.06943184420297371, 0.10134469352786774],
                                [0.8292234622691586, 0.0618702820240076, 0.10890625570683385],
                                [0.528199534031897, 0.0229131666764128, 0.44888729929169013],
                                [0.3070963115311591, 0.4718004659681029, 0.22110322250073802],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446686],
                                [0.724816537793735, 0.06943184420297371, 0.20575161800329134],
                                [0.724816537793735, 0.05408023970552703, 0.22110322250073802],
                                [0.37170737474470683, 0.004820780989426066, 0.6234718442658671],
                                [0.0646110632135477, 0.6282926252552932, 0.30709631153115907],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.9305681557970262, 0.048109580945434396, 0.021322263257539335],
                                [0.6447941075234065, 0.06943184420297371, 0.28577404827361974],
                                [0.6447941075234065, 0.04810958094543438, 0.30709631153115907],
                                [0.64638501094228, 0.3070963115311591, 0.046518677526560935],
                                [0.6234718442658673, 0.35361498905772, 0.02291316667641278],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6759611805525207, 0.3224479160286058, 0.0015909034188734622],
                                [0.6546389172949815, 0.32403881944747925, 0.021322263257539317],
                                [0.6546389172949816, 0.32244791602860573, 0.02291316667641278],
                                [0.557793554998524, 0.22110322250073802, 0.22110322250073802],
                                [0.44888729929169013, 0.442206445001476, 0.10890625570683385],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.6983690562328146, 0.29406938158821927, 0.007561562178966111],
                                [0.597024362704947, 0.3016309437671853, 0.10134469352786774],
                                [0.5970243627049469, 0.29406938158821927, 0.10890625570683385],
                                [0.442206445001476, 0.10890625570683388, 0.44888729929169013],
                                [0.221103222500738, 0.557793554998524, 0.22110322250073802],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.7276050763824626, 0.2570433191200907, 0.015351604497446686],
                                [0.5218534583791713, 0.27239492361753737, 0.20575161800329134],
                                [0.5218534583791713, 0.2570433191200907, 0.22110322250073802],
                                [0.35361498905772004, 0.022913166676412855, 0.6234718442658671],
                                [0.046518677526560914, 0.64638501094228, 0.30709631153115907],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.7500129520627565, 0.22866478467970414, 0.021322263257539335],
                                [0.4642389037891368, 0.24998704793724347, 0.28577404827361974],
                                [0.46423890378913674, 0.22866478467970414, 0.30709631153115907],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3070963115311591, 0.6699905217924281, 0.02291316667641278],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.34377017928614506, 0.6546389172949815, 0.0015909034188734622],
                                [0.3224479160286058, 0.6562298207138549, 0.021322263257539317],
                                [0.3224479160286058, 0.6546389172949815, 0.02291316667641278],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.221103222500738, 0.6699905217924281, 0.10890625570683385],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.39541407511608695, 0.597024362704947, 0.007561562178966111],
                                [0.2940693815882194, 0.6045859248839129, 0.10134469352786774],
                                [0.29406938158821927, 0.5970243627049469, 0.10890625570683385],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.10890625570683388, 0.6699905217924281, 0.22110322250073802],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.46279493712338193, 0.5218534583791714, 0.015351604497446686],
                                [0.2570433191200907, 0.537205062876618, 0.20575161800329134],
                                [0.2570433191200907, 0.5218534583791713, 0.22110322250073802],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.022913166676412855, 0.669990521792428, 0.30709631153115907],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.5144388329533238, 0.4642389037891368, 0.021322263257539335],
                                [0.2286647846797042, 0.48556116704667607, 0.28577404827361974],
                                [0.22866478467970403, 0.46423890378913685, 0.30709631153115907],
                                [0.08752422988996056, 0.8659570925834785, 0.046518677526560935],
                                [0.0646110632135477, 0.9124757701100396, 0.02291316667641278],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.08916320404163958, 0.909245892539487, 0.0015909034188734622],
                                [0.0678409407841003, 0.9108367959583604, 0.021322263257539317],
                                [0.0678409407841003, 0.909245892539487, 0.02291316667641278],
                                [0.1554249332333948, 0.6234718442658672, 0.22110322250073802],
                                [0.046518677526561025, 0.8445750667666051, 0.10890625570683385],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.16321497555187536, 0.8292234622691586, 0.007561562178966111],
                                [0.061870282024007794, 0.8367850244481245, 0.10134469352786774],
                                [0.06187028202400768, 0.8292234622691584, 0.10890625570683385],
                                [0.24401638917715085, 0.307096311531159, 0.44888729929169013],
                                [0.022913166676412855, 0.7559836108228492, 0.22110322250073802],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.25983185770881845, 0.7248165377937349, 0.015351604497446686],
                                [0.05408023970552711, 0.7401681422911816, 0.20575161800329134],
                                [0.05408023970552711, 0.7248165377937349, 0.22110322250073802],
                                [0.3119170925205851, 0.06461106321354781, 0.6234718442658671],
                                [0.004820780989426066, 0.6880829074794148, 0.30709631153115907],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.3338836292190541, 0.6447941075234065, 0.021322263257539335],
                                [0.04810958094543438, 0.6661163707809459, 0.28577404827361974],
                                [0.04810958094543438, 0.6447941075234065, 0.30709631153115907],
                                [0.9124757701100396, 0.0646110632135477, 0.02291316667641278],
                                [0.8659570925834786, 0.08752422988996048, 0.046518677526560935],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.8905092334115704, 0.06620196663242117, 0.04328879995600838],
                                [0.8872793558410179, 0.10949076658842953, 0.0032298775705525535],
                                [0.8872793558410179, 0.06620196663242114, 0.046518677526560935],
                                [0.8445750667666052, 0.04651867752656094, 0.10890625570683385],
                                [0.6234718442658672, 0.15542493323339476, 0.22110322250073802],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.7401681422911817, 0.054080239705527, 0.20575161800329134],
                                [0.724816537793735, 0.2598318577088184, 0.015351604497446674],
                                [0.724816537793735, 0.05408023970552703, 0.22110322250073802],
                                [0.7559836108228493, 0.02291316667641277, 0.22110322250073802],
                                [0.3070963115311591, 0.24401638917715074, 0.44888729929169013],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.5440150025635646, 0.03826477117385946, 0.4177202262625758],
                                [0.5128479295344504, 0.45598499743643534, 0.031167073029114263],
                                [0.5128479295344505, 0.0382647711738594, 0.44888729929169013],
                                [0.6880829074794148, 0.00482078098942601, 0.30709631153115907],
                                [0.0646110632135477, 0.3119170925205852, 0.6234718442658671],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.393673911443176, 0.02614304424696534, 0.5801830443098587],
                                [0.35038511148716767, 0.606326088556824, 0.04328879995600837],
                                [0.35038511148716767, 0.02614304424696523, 0.6234718442658671],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6234718442658672, 0.33000947820757187, 0.046518677526560935],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6420533263338664, 0.3146578737101252, 0.04328879995600838],
                                [0.6388234487633138, 0.3579466736661336, 0.0032298775705525535],
                                [0.6388234487633139, 0.3146578737101252, 0.046518677526560935],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.44888729929169013, 0.33000947820757187, 0.22110322250073802],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.5372050628766181, 0.25704331912009065, 0.20575161800329134],
                                [0.5218534583791713, 0.46279493712338204, 0.015351604497446674],
                                [0.5218534583791713, 0.2570433191200907, 0.22110322250073802],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.221103222500738, 0.33000947820757187, 0.44888729929169013],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.400407358943109, 0.1818724147943151, 0.4177202262625758],
                                [0.3692402859139948, 0.5995926410568909, 0.031167073029114263],
                                [0.3692402859139948, 0.18187241479431504, 0.44888729929169013],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.046518677526561025, 0.33000947820757187, 0.6234718442658671],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.2955590954858607, 0.12425786020428065, 0.5801830443098587],
                                [0.25227029552985236, 0.7044409045141393, 0.04328879995600837],
                                [0.25227029552985236, 0.12425786020428053, 0.6234718442658671],
                                [0.35361498905772004, 0.6234718442658672, 0.02291316667641278],
                                [0.3070963115311591, 0.64638501094228, 0.046518677526560935],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.3178877512806777, 0.6388234487633139, 0.04328879995600838],
                                [0.3146578737101252, 0.6821122487193222, 0.0032298775705525535],
                                [0.3146578737101252, 0.6388234487633139, 0.046518677526560935],
                                [0.442206445001476, 0.44888729929169013, 0.10890625570683385],
                                [0.221103222500738, 0.557793554998524, 0.22110322250073802],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.27239492361753737, 0.5218534583791713, 0.20575161800329134],
                                [0.2570433191200907, 0.7276050763824626, 0.015351604497446674],
                                [0.2570433191200907, 0.5218534583791713, 0.22110322250073802],
                                [0.557793554998524, 0.22110322250073802, 0.22110322250073802],
                                [0.10890625570683388, 0.442206445001476, 0.44888729929169013],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.21303948782342935, 0.36924028591399477, 0.4177202262625758],
                                [0.18187241479431504, 0.7869605121765707, 0.031167073029114263],
                                [0.18187241479431504, 0.3692402859139948, 0.44888729929169013],
                                [0.64638501094228, 0.04651867752656097, 0.30709631153115907],
                                [0.022913166676412855, 0.35361498905772004, 0.6234718442658671],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.16754666016028896, 0.25227029552985236, 0.5801830443098587],
                                [0.12425786020428053, 0.8324533398397111, 0.04328879995600837],
                                [0.12425786020428053, 0.25227029552985236, 0.6234718442658671],
                                [0.11112974074010873, 0.8659570925834785, 0.02291316667641278],
                                [0.0646110632135477, 0.8888702592598914, 0.046518677526560935],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.06943184420297377, 0.8872793558410178, 0.04328879995600838],
                                [0.06620196663242117, 0.9305681557970262, 0.0032298775705525535],
                                [0.06620196663242117, 0.8872793558410179, 0.046518677526560935],
                                [0.267621900027299, 0.6234718442658671, 0.10890625570683385],
                                [0.046518677526561025, 0.732378099972701, 0.22110322250073802],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.05408023970552711, 0.9305681557970262, 0.015351604497446674],
                                [0.05408023970552711, 0.7248165377937349, 0.22110322250073802],
                                [0.471800465968103, 0.307096311531159, 0.22110322250073802],
                                [0.022913166676412855, 0.528199534031897, 0.44888729929169013],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.06943184420297377, 0.5128479295344504, 0.4177202262625758],
                                [0.03826477117385951, 0.9305681557970262, 0.031167073029114263],
                                [0.03826477117385951, 0.5128479295344504, 0.44888729929169013],
                                [0.6282926252552932, 0.06461106321354776, 0.30709631153115907],
                                [0.004820780989426066, 0.37170737474470683, 0.6234718442658671],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.026143044246965452, 0.9305681557970262, 0.04328879995600837],
                                [0.02614304424696534, 0.35038511148716756, 0.6234718442658671],
                                [0.9124757701100396, 0.0646110632135477, 0.02291316667641278],
                                [0.8659570925834786, 0.08752422988996048, 0.046518677526560935],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9026309603384646, 0.06620196663242117, 0.03116707302911426],
                                [0.8872793558410179, 0.09736903966153541, 0.015351604497446674],
                                [0.8872793558410179, 0.06620196663242114, 0.046518677526560935],
                                [0.8445750667666052, 0.04651867752656094, 0.10890625570683385],
                                [0.6234718442658672, 0.15542493323339476, 0.22110322250073802],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.7977826968812161, 0.054080239705527056, 0.1481370634132568],
                                [0.7248165377937349, 0.20221730311878383, 0.07296615908748122],
                                [0.724816537793735, 0.05408023970552703, 0.22110322250073802],
                                [0.7559836108228493, 0.02291316667641277, 0.22110322250073802],
                                [0.3070963115311591, 0.24401638917715074, 0.44888729929169013],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.6609849929477072, 0.03826477117385951, 0.3007502358784333],
                                [0.5128479295344504, 0.3390150070522928, 0.1481370634132568],
                                [0.5128479295344505, 0.0382647711738594, 0.44888729929169013],
                                [0.6880829074794148, 0.00482078098942601, 0.30709631153115907],
                                [0.0646110632135477, 0.3119170925205852, 0.6234718442658671],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.5561367294904589, 0.026143044246965397, 0.41772022626257577],
                                [0.35038511148716756, 0.4438632705095411, 0.2057516180032913],
                                [0.35038511148716767, 0.02614304424696523, 0.6234718442658671],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6234718442658672, 0.33000947820757187, 0.046518677526560935],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6541750532607605, 0.3146578737101252, 0.03116707302911426],
                                [0.6388234487633139, 0.34582494673923947, 0.015351604497446674],
                                [0.6388234487633139, 0.3146578737101252, 0.046518677526560935],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.44888729929169013, 0.33000947820757187, 0.22110322250073802],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.5948196174666526, 0.2570433191200906, 0.1481370634132568],
                                [0.5218534583791712, 0.4051803825333475, 0.07296615908748122],
                                [0.5218534583791713, 0.2570433191200907, 0.22110322250073802],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.221103222500738, 0.33000947820757187, 0.44888729929169013],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.5173773493272515, 0.1818724147943151, 0.3007502358784333],
                                [0.3692402859139948, 0.48262265067274834, 0.1481370634132568],
                                [0.3692402859139948, 0.18187241479431504, 0.44888729929169013],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.046518677526561025, 0.33000947820757187, 0.6234718442658671],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.4580219135331436, 0.12425786020428065, 0.41772022626257577],
                                [0.25227029552985236, 0.5419780864668563, 0.2057516180032913],
                                [0.25227029552985236, 0.12425786020428053, 0.6234718442658671],
                                [0.35361498905772004, 0.6234718442658672, 0.02291316667641278],
                                [0.3070963115311591, 0.64638501094228, 0.046518677526560935],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.3146578737101252, 0.6699905217924281, 0.015351604497446674],
                                [0.3146578737101252, 0.6388234487633139, 0.046518677526560935],
                                [0.442206445001476, 0.44888729929169013, 0.10890625570683385],
                                [0.221103222500738, 0.557793554998524, 0.22110322250073802],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.2570433191200907, 0.669990521792428, 0.07296615908748122],
                                [0.2570433191200907, 0.5218534583791713, 0.22110322250073802],
                                [0.557793554998524, 0.22110322250073802, 0.22110322250073802],
                                [0.10890625570683388, 0.442206445001476, 0.44888729929169013],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.18187241479431504, 0.6699905217924281, 0.1481370634132568],
                                [0.18187241479431504, 0.3692402859139948, 0.44888729929169013],
                                [0.64638501094228, 0.04651867752656097, 0.30709631153115907],
                                [0.022913166676412855, 0.35361498905772004, 0.6234718442658671],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.12425786020428053, 0.6699905217924281, 0.2057516180032913],
                                [0.12425786020428053, 0.25227029552985236, 0.6234718442658671],
                                [0.11112974074010873, 0.8659570925834785, 0.02291316667641278],
                                [0.0646110632135477, 0.8888702592598914, 0.046518677526560935],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.08155357112986794, 0.8872793558410178, 0.03116707302911426],
                                [0.06620196663242117, 0.9184464288701322, 0.015351604497446674],
                                [0.06620196663242117, 0.8872793558410179, 0.046518677526560935],
                                [0.267621900027299, 0.6234718442658671, 0.10890625570683385],
                                [0.046518677526561025, 0.732378099972701, 0.22110322250073802],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.12704639879300827, 0.7248165377937349, 0.1481370634132568],
                                [0.05408023970552711, 0.8729536012069916, 0.07296615908748122],
                                [0.05408023970552711, 0.7248165377937349, 0.22110322250073802],
                                [0.471800465968103, 0.307096311531159, 0.22110322250073802],
                                [0.022913166676412855, 0.528199534031897, 0.44888729929169013],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.18640183458711634, 0.5128479295344504, 0.3007502358784333],
                                [0.03826477117385951, 0.8135981654128837, 0.1481370634132568],
                                [0.03826477117385951, 0.5128479295344504, 0.44888729929169013],
                                [0.6282926252552932, 0.06461106321354776, 0.30709631153115907],
                                [0.004820780989426066, 0.37170737474470683, 0.6234718442658671],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.23189466225025668, 0.35038511148716756, 0.41772022626257577],
                                [0.02614304424696534, 0.7681053377497433, 0.2057516180032913],
                                [0.02614304424696534, 0.35038511148716756, 0.6234718442658671],
                                [0.9124757701100396, 0.0646110632135477, 0.02291316667641278],
                                [0.8659570925834786, 0.08752422988996048, 0.046518677526560935],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9184464288701322, 0.06620196663242116, 0.015351604497446674],
                                [0.8872793558410179, 0.08155357112986783, 0.03116707302911426],
                                [0.8872793558410179, 0.06620196663242114, 0.046518677526560935],
                                [0.8445750667666052, 0.04651867752656094, 0.10890625570683385],
                                [0.6234718442658672, 0.15542493323339476, 0.22110322250073802],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.8729536012069916, 0.054080239705527056, 0.07296615908748122],
                                [0.7248165377937349, 0.12704639879300825, 0.1481370634132568],
                                [0.724816537793735, 0.05408023970552703, 0.22110322250073802],
                                [0.7559836108228493, 0.02291316667641277, 0.22110322250073802],
                                [0.3070963115311591, 0.24401638917715074, 0.44888729929169013],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.8135981654128837, 0.03826477117385946, 0.1481370634132568],
                                [0.5128479295344504, 0.1864018345871163, 0.3007502358784333],
                                [0.5128479295344505, 0.0382647711738594, 0.44888729929169013],
                                [0.6880829074794148, 0.00482078098942601, 0.30709631153115907],
                                [0.0646110632135477, 0.3119170925205852, 0.6234718442658671],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.7681053377497433, 0.02614304424696534, 0.2057516180032913],
                                [0.35038511148716756, 0.23189466225025668, 0.41772022626257577],
                                [0.35038511148716767, 0.02614304424696523, 0.6234718442658671],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6234718442658672, 0.33000947820757187, 0.046518677526560935],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6388234487633139, 0.33000947820757187, 0.03116707302911426],
                                [0.6388234487633139, 0.3146578737101252, 0.046518677526560935],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.44888729929169013, 0.33000947820757187, 0.22110322250073802],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.5218534583791713, 0.33000947820757187, 0.1481370634132568],
                                [0.5218534583791713, 0.2570433191200907, 0.22110322250073802],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.221103222500738, 0.33000947820757187, 0.44888729929169013],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.3692402859139948, 0.33000947820757187, 0.3007502358784333],
                                [0.3692402859139948, 0.18187241479431504, 0.44888729929169013],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.046518677526561025, 0.33000947820757187, 0.6234718442658671],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.6699905217924281, 0.12425786020428056, 0.2057516180032913],
                                [0.25227029552985236, 0.33000947820757187, 0.41772022626257577],
                                [0.25227029552985236, 0.12425786020428053, 0.6234718442658671],
                                [0.35361498905772004, 0.6234718442658672, 0.02291316667641278],
                                [0.3070963115311591, 0.64638501094228, 0.046518677526560935],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.34582494673923947, 0.6388234487633139, 0.015351604497446674],
                                [0.3146578737101252, 0.6541750532607605, 0.03116707302911426],
                                [0.3146578737101252, 0.6388234487633139, 0.046518677526560935],
                                [0.442206445001476, 0.44888729929169013, 0.10890625570683385],
                                [0.221103222500738, 0.557793554998524, 0.22110322250073802],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.4051803825333473, 0.5218534583791714, 0.07296615908748122],
                                [0.2570433191200907, 0.5948196174666525, 0.1481370634132568],
                                [0.2570433191200907, 0.5218534583791713, 0.22110322250073802],
                                [0.557793554998524, 0.22110322250073802, 0.22110322250073802],
                                [0.10890625570683388, 0.442206445001476, 0.44888729929169013],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.48262265067274845, 0.3692402859139947, 0.1481370634132568],
                                [0.18187241479431504, 0.5173773493272517, 0.3007502358784333],
                                [0.18187241479431504, 0.3692402859139948, 0.44888729929169013],
                                [0.64638501094228, 0.04651867752656097, 0.30709631153115907],
                                [0.022913166676412855, 0.35361498905772004, 0.6234718442658671],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.5419780864668563, 0.25227029552985236, 0.2057516180032913],
                                [0.12425786020428053, 0.4580219135331437, 0.41772022626257577],
                                [0.12425786020428053, 0.25227029552985236, 0.6234718442658671],
                                [0.11112974074010873, 0.8659570925834785, 0.02291316667641278],
                                [0.0646110632135477, 0.8888702592598914, 0.046518677526560935],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.09736903966153543, 0.8872793558410179, 0.015351604497446674],
                                [0.06620196663242117, 0.9026309603384646, 0.03116707302911426],
                                [0.06620196663242117, 0.8872793558410179, 0.046518677526560935],
                                [0.267621900027299, 0.6234718442658671, 0.10890625570683385],
                                [0.046518677526561025, 0.732378099972701, 0.22110322250073802],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.20221730311878394, 0.7248165377937348, 0.07296615908748122],
                                [0.05408023970552711, 0.7977826968812161, 0.1481370634132568],
                                [0.05408023970552711, 0.7248165377937349, 0.22110322250073802],
                                [0.471800465968103, 0.307096311531159, 0.22110322250073802],
                                [0.022913166676412855, 0.528199534031897, 0.44888729929169013],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.3390150070522928, 0.5128479295344504, 0.1481370634132568],
                                [0.03826477117385951, 0.6609849929477072, 0.3007502358784333],
                                [0.03826477117385951, 0.5128479295344504, 0.44888729929169013],
                                [0.6282926252552932, 0.06461106321354776, 0.30709631153115907],
                                [0.004820780989426066, 0.37170737474470683, 0.6234718442658671],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.4438632705095411, 0.35038511148716756, 0.2057516180032913],
                                [0.02614304424696534, 0.5561367294904589, 0.41772022626257577],
                                [0.02614304424696534, 0.35038511148716756, 0.6234718442658671],
                                [0.9124757701100396, 0.0646110632135477, 0.02291316667641278],
                                [0.8659570925834786, 0.08752422988996048, 0.046518677526560935],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9305681557970262, 0.06620196663242116, 0.003229877570552556],
                                [0.8872793558410179, 0.06943184420297371, 0.04328879995600838],
                                [0.8872793558410179, 0.06620196663242114, 0.046518677526560935],
                                [0.8445750667666052, 0.04651867752656094, 0.10890625570683385],
                                [0.6234718442658672, 0.15542493323339476, 0.22110322250073802],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446686],
                                [0.724816537793735, 0.06943184420297371, 0.20575161800329134],
                                [0.724816537793735, 0.05408023970552703, 0.22110322250073802],
                                [0.7559836108228493, 0.02291316667641277, 0.22110322250073802],
                                [0.3070963115311591, 0.24401638917715074, 0.44888729929169013],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.9305681557970262, 0.03826477117385946, 0.031167073029114287],
                                [0.5128479295344504, 0.06943184420297377, 0.4177202262625758],
                                [0.5128479295344505, 0.0382647711738594, 0.44888729929169013],
                                [0.6880829074794148, 0.00482078098942601, 0.30709631153115907],
                                [0.0646110632135477, 0.3119170925205852, 0.6234718442658671],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600841],
                                [0.35038511148716756, 0.06943184420297377, 0.5801830443098587],
                                [0.35038511148716767, 0.02614304424696523, 0.6234718442658671],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6234718442658672, 0.33000947820757187, 0.046518677526560935],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6821122487193222, 0.3146578737101252, 0.003229877570552556],
                                [0.6388234487633138, 0.31788775128067775, 0.04328879995600838],
                                [0.6388234487633139, 0.3146578737101252, 0.046518677526560935],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.44888729929169013, 0.33000947820757187, 0.22110322250073802],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.7276050763824626, 0.2570433191200907, 0.015351604497446686],
                                [0.5218534583791713, 0.27239492361753737, 0.20575161800329134],
                                [0.5218534583791713, 0.2570433191200907, 0.22110322250073802],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.221103222500738, 0.33000947820757187, 0.44888729929169013],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.7869605121765707, 0.18187241479431507, 0.031167073029114287],
                                [0.36924028591399477, 0.21303948782342935, 0.4177202262625758],
                                [0.3692402859139948, 0.18187241479431504, 0.44888729929169013],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.046518677526561025, 0.33000947820757187, 0.6234718442658671],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.832453339839711, 0.12425786020428056, 0.04328879995600841],
                                [0.25227029552985236, 0.16754666016028896, 0.5801830443098587],
                                [0.25227029552985236, 0.12425786020428053, 0.6234718442658671],
                                [0.35361498905772004, 0.6234718442658672, 0.02291316667641278],
                                [0.3070963115311591, 0.64638501094228, 0.046518677526560935],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.35794667366613353, 0.6388234487633139, 0.003229877570552556],
                                [0.3146578737101252, 0.6420533263338664, 0.04328879995600838],
                                [0.3146578737101252, 0.6388234487633139, 0.046518677526560935],
                                [0.442206445001476, 0.44888729929169013, 0.10890625570683385],
                                [0.221103222500738, 0.557793554998524, 0.22110322250073802],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.46279493712338193, 0.5218534583791714, 0.015351604497446686],
                                [0.2570433191200907, 0.537205062876618, 0.20575161800329134],
                                [0.2570433191200907, 0.5218534583791713, 0.22110322250073802],
                                [0.557793554998524, 0.22110322250073802, 0.22110322250073802],
                                [0.10890625570683388, 0.442206445001476, 0.44888729929169013],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.599592641056891, 0.36924028591399477, 0.031167073029114287],
                                [0.18187241479431498, 0.40040735894310914, 0.4177202262625758],
                                [0.18187241479431504, 0.3692402859139948, 0.44888729929169013],
                                [0.64638501094228, 0.04651867752656097, 0.30709631153115907],
                                [0.022913166676412855, 0.35361498905772004, 0.6234718442658671],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.7044409045141393, 0.2522702955298523, 0.04328879995600841],
                                [0.12425786020428053, 0.2955590954858608, 0.5801830443098587],
                                [0.12425786020428053, 0.25227029552985236, 0.6234718442658671],
                                [0.11112974074010873, 0.8659570925834785, 0.02291316667641278],
                                [0.0646110632135477, 0.8888702592598914, 0.046518677526560935],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.1094907665884296, 0.8872793558410178, 0.003229877570552556],
                                [0.06620196663242117, 0.8905092334115704, 0.04328879995600838],
                                [0.06620196663242117, 0.8872793558410179, 0.046518677526560935],
                                [0.267621900027299, 0.6234718442658671, 0.10890625570683385],
                                [0.046518677526561025, 0.732378099972701, 0.22110322250073802],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.25983185770881845, 0.7248165377937349, 0.015351604497446686],
                                [0.05408023970552711, 0.7401681422911816, 0.20575161800329134],
                                [0.05408023970552711, 0.7248165377937349, 0.22110322250073802],
                                [0.471800465968103, 0.307096311531159, 0.22110322250073802],
                                [0.022913166676412855, 0.528199534031897, 0.44888729929169013],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.4559849974364354, 0.5128479295344504, 0.031167073029114287],
                                [0.03826477117385951, 0.5440150025635646, 0.4177202262625758],
                                [0.03826477117385951, 0.5128479295344504, 0.44888729929169013],
                                [0.6282926252552932, 0.06461106321354776, 0.30709631153115907],
                                [0.004820780989426066, 0.37170737474470683, 0.6234718442658671],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.606326088556824, 0.35038511148716756, 0.04328879995600841],
                                [0.02614304424696534, 0.393673911443176, 0.5801830443098587],
                                [0.02614304424696534, 0.35038511148716756, 0.6234718442658671],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426019],
                                [0.8659570925834785, 0.06943184420297373, 0.06461106321354769],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.8749292231331417, 0.06494577892814217, 0.06012499793871616],
                                [0.8704431578583101, 0.12507077686685836, 0.004486065274831529],
                                [0.8704431578583101, 0.0649457789281422, 0.06461106321354769],
                                [0.9305681557970263, 0.04651867752656093, 0.022913166676412796],
                                [0.6234718442658671, 0.06943184420297371, 0.30709631153115907],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.6661163707809459, 0.04810958094543438, 0.28577404827361974],
                                [0.6447941075234066, 0.3338836292190541, 0.021322263257539317],
                                [0.6447941075234065, 0.04810958094543438, 0.30709631153115907],
                                [0.9305681557970263, 0.022913166676412786, 0.04651867752656097],
                                [0.3070963115311591, 0.06943184420297377, 0.6234718442658671],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.393673911443176, 0.02614304424696534, 0.5801830443098587],
                                [0.35038511148716767, 0.606326088556824, 0.04328879995600837],
                                [0.35038511148716767, 0.02614304424696523, 0.6234718442658671],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354775],
                                [0.0646110632135477, 0.06943184420297377, 0.8659570925834785],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.18486105909098027, 0.009306846264257373, 0.8058320946447624],
                                [0.12473606115226388, 0.81513894090902, 0.06012499793871617],
                                [0.12473606115226388, 0.009306846264257596, 0.8659570925834785],
                                [0.6880829074794148, 0.30709631153115907, 0.004820780989426019],
                                [0.6234718442658672, 0.3119170925205851, 0.06461106321354769],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6311877871112512, 0.30868721495003254, 0.06012499793871616],
                                [0.6267017218364197, 0.3688122128887487, 0.004486065274831529],
                                [0.6267017218364197, 0.30868721495003254, 0.06461106321354769],
                                [0.7559836108228493, 0.221103222500738, 0.022913166676412796],
                                [0.4488872992916901, 0.2440163891771508, 0.30709631153115907],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.4855611670466762, 0.22866478467970408, 0.28577404827361974],
                                [0.4642389037891368, 0.5144388329533239, 0.021322263257539317],
                                [0.46423890378913674, 0.22866478467970414, 0.30709631153115907],
                                [0.8445750667666052, 0.10890625570683385, 0.04651867752656097],
                                [0.221103222500738, 0.1554249332333949, 0.6234718442658671],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.2955590954858607, 0.12425786020428065, 0.5801830443098587],
                                [0.25227029552985236, 0.7044409045141393, 0.04328879995600837],
                                [0.25227029552985236, 0.12425786020428053, 0.6234718442658671],
                                [0.9124757701100396, 0.022913166676412786, 0.06461106321354775],
                                [0.046518677526561025, 0.08752422988996045, 0.8659570925834785],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.14993247542128552, 0.04423542993395213, 0.8058320946447624],
                                [0.08980747748256934, 0.8500675245787145, 0.06012499793871617],
                                [0.08980747748256934, 0.04423542993395213, 0.8659570925834785],
                                [0.37170737474470683, 0.6234718442658671, 0.004820780989426019],
                                [0.3070963115311591, 0.6282926252552932, 0.06461106321354769],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.3131732802248641, 0.6267017218364197, 0.06012499793871616],
                                [0.3086872149500326, 0.6868267197751359, 0.004486065274831529],
                                [0.3086872149500326, 0.6267017218364197, 0.06461106321354769],
                                [0.5281995340318972, 0.4488872992916901, 0.022913166676412796],
                                [0.22110322250073794, 0.47180046596810293, 0.30709631153115907],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.24998704793724347, 0.4642389037891368, 0.28577404827361974],
                                [0.2286647846797042, 0.7500129520627565, 0.021322263257539317],
                                [0.22866478467970403, 0.46423890378913685, 0.30709631153115907],
                                [0.7323780999727011, 0.221103222500738, 0.04651867752656097],
                                [0.10890625570683388, 0.267621900027299, 0.6234718442658671],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.16754666016028896, 0.25227029552985236, 0.5801830443098587],
                                [0.12425786020428053, 0.8324533398397111, 0.04328879995600837],
                                [0.12425786020428053, 0.25227029552985236, 0.6234718442658671],
                                [0.8888702592598913, 0.046518677526560984, 0.06461106321354775],
                                [0.022913166676412855, 0.11112974074010862, 0.8659570925834785],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.1043604278726683, 0.08980747748256934, 0.8058320946447624],
                                [0.04423542993395213, 0.8956395721273317, 0.06012499793871617],
                                [0.04423542993395213, 0.08980747748256934, 0.8659570925834785],
                                [0.1292221264270954, 0.8659570925834785, 0.004820780989426019],
                                [0.0646110632135477, 0.8707778735729046, 0.06461106321354769],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871616],
                                [0.06494577892814224, 0.9305681557970262, 0.004486065274831529],
                                [0.06494577892814224, 0.8704431578583101, 0.06461106321354769],
                                [0.35361498905772004, 0.6234718442658672, 0.022913166676412796],
                                [0.046518677526560914, 0.64638501094228, 0.30709631153115907],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.04810958094543438, 0.9305681557970263, 0.021322263257539317],
                                [0.04810958094543438, 0.6447941075234065, 0.30709631153115907],
                                [0.64638501094228, 0.30709631153115907, 0.04651867752656097],
                                [0.022913166676412855, 0.35361498905772004, 0.6234718442658671],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.026143044246965452, 0.9305681557970262, 0.04328879995600837],
                                [0.02614304424696534, 0.35038511148716756, 0.6234718442658671],
                                [0.8707778735729045, 0.06461106321354777, 0.06461106321354775],
                                [0.004820780989426066, 0.1292221264270954, 0.8659570925834785],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.009306846264257596, 0.9305681557970262, 0.06012499793871617],
                                [0.009306846264257596, 0.12473606115226388, 0.8659570925834785],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426019],
                                [0.8659570925834785, 0.06943184420297373, 0.06461106321354769],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.8917654211158494, 0.06494577892814218, 0.04328879995600837],
                                [0.8704431578583102, 0.10823457888415057, 0.021322263257539314],
                                [0.8704431578583101, 0.0649457789281422, 0.06461106321354769],
                                [0.9305681557970263, 0.04651867752656093, 0.022913166676412796],
                                [0.6234718442658671, 0.06943184420297371, 0.30709631153115907],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.7461388010512743, 0.04810958094543438, 0.20575161800329134],
                                [0.6447941075234066, 0.2538611989487257, 0.10134469352786774],
                                [0.6447941075234065, 0.04810958094543438, 0.30709631153115907],
                                [0.9305681557970263, 0.022913166676412786, 0.04651867752656097],
                                [0.3070963115311591, 0.06943184420297377, 0.6234718442658671],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.5561367294904589, 0.026143044246965397, 0.41772022626257577],
                                [0.35038511148716756, 0.4438632705095411, 0.2057516180032913],
                                [0.35038511148716767, 0.02614304424696523, 0.6234718442658671],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354775],
                                [0.0646110632135477, 0.06943184420297377, 0.8659570925834785],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.4105101094258836, 0.009306846264257596, 0.5801830443098588],
                                [0.12473606115226388, 0.5894898905741164, 0.28577404827361974],
                                [0.12473606115226388, 0.009306846264257596, 0.8659570925834785],
                                [0.6880829074794148, 0.30709631153115907, 0.004820780989426019],
                                [0.6234718442658672, 0.3119170925205851, 0.06461106321354769],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6480239850939591, 0.30868721495003254, 0.04328879995600837],
                                [0.6267017218364198, 0.3519760149060409, 0.021322263257539314],
                                [0.6267017218364197, 0.30868721495003254, 0.06461106321354769],
                                [0.7559836108228493, 0.221103222500738, 0.022913166676412796],
                                [0.4488872992916901, 0.2440163891771508, 0.30709631153115907],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.5655835973170045, 0.22866478467970414, 0.20575161800329134],
                                [0.46423890378913685, 0.4344164026829955, 0.10134469352786774],
                                [0.46423890378913674, 0.22866478467970414, 0.30709631153115907],
                                [0.8445750667666052, 0.10890625570683385, 0.04651867752656097],
                                [0.221103222500738, 0.1554249332333949, 0.6234718442658671],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.4580219135331436, 0.12425786020428065, 0.41772022626257577],
                                [0.25227029552985236, 0.5419780864668563, 0.2057516180032913],
                                [0.25227029552985236, 0.12425786020428053, 0.6234718442658671],
                                [0.9124757701100396, 0.022913166676412786, 0.06461106321354775],
                                [0.046518677526561025, 0.08752422988996045, 0.8659570925834785],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.3755815257561891, 0.04423542993395213, 0.5801830443098588],
                                [0.08980747748256934, 0.6244184742438109, 0.28577404827361974],
                                [0.08980747748256934, 0.04423542993395213, 0.8659570925834785],
                                [0.37170737474470683, 0.6234718442658671, 0.004820780989426019],
                                [0.3070963115311591, 0.6282926252552932, 0.06461106321354769],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.330009478207572, 0.6267017218364197, 0.04328879995600837],
                                [0.3086872149500326, 0.6699905217924281, 0.021322263257539314],
                                [0.3086872149500326, 0.6267017218364197, 0.06461106321354769],
                                [0.5281995340318972, 0.4488872992916901, 0.022913166676412796],
                                [0.22110322250073794, 0.47180046596810293, 0.30709631153115907],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.2286647846797043, 0.669990521792428, 0.10134469352786774],
                                [0.22866478467970403, 0.46423890378913685, 0.30709631153115907],
                                [0.7323780999727011, 0.221103222500738, 0.04651867752656097],
                                [0.10890625570683388, 0.267621900027299, 0.6234718442658671],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.12425786020428053, 0.6699905217924281, 0.2057516180032913],
                                [0.12425786020428053, 0.25227029552985236, 0.6234718442658671],
                                [0.8888702592598913, 0.046518677526560984, 0.06461106321354775],
                                [0.022913166676412855, 0.11112974074010862, 0.8659570925834785],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.33000947820757187, 0.08980747748256934, 0.5801830443098588],
                                [0.04423542993395213, 0.6699905217924281, 0.28577404827361974],
                                [0.04423542993395213, 0.08980747748256934, 0.8659570925834785],
                                [0.1292221264270954, 0.8659570925834785, 0.004820780989426019],
                                [0.0646110632135477, 0.8707778735729046, 0.06461106321354769],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.08626804218568163, 0.8704431578583101, 0.04328879995600837],
                                [0.06494577892814224, 0.9137319578143185, 0.021322263257539314],
                                [0.06494577892814224, 0.8704431578583101, 0.06461106321354769],
                                [0.35361498905772004, 0.6234718442658672, 0.022913166676412796],
                                [0.046518677526560914, 0.64638501094228, 0.30709631153115907],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.14945427447330217, 0.6447941075234065, 0.20575161800329134],
                                [0.04810958094543438, 0.8505457255266979, 0.10134469352786774],
                                [0.04810958094543438, 0.6447941075234065, 0.30709631153115907],
                                [0.64638501094228, 0.30709631153115907, 0.04651867752656097],
                                [0.022913166676412855, 0.35361498905772004, 0.6234718442658671],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.23189466225025668, 0.35038511148716756, 0.41772022626257577],
                                [0.02614304424696534, 0.7681053377497433, 0.2057516180032913],
                                [0.02614304424696534, 0.35038511148716756, 0.6234718442658671],
                                [0.8707778735729045, 0.06461106321354777, 0.06461106321354775],
                                [0.004820780989426066, 0.1292221264270954, 0.8659570925834785],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.29508089453787734, 0.12473606115226388, 0.5801830443098588],
                                [0.009306846264257596, 0.7049191054621227, 0.28577404827361974],
                                [0.009306846264257596, 0.12473606115226388, 0.8659570925834785],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426019],
                                [0.8659570925834785, 0.06943184420297373, 0.06461106321354769],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9137319578143186, 0.06494577892814218, 0.021322263257539314],
                                [0.8704431578583102, 0.08626804218568151, 0.04328879995600837],
                                [0.8704431578583101, 0.0649457789281422, 0.06461106321354769],
                                [0.9305681557970263, 0.04651867752656093, 0.022913166676412796],
                                [0.6234718442658671, 0.06943184420297371, 0.30709631153115907],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.8505457255266979, 0.04810958094543441, 0.10134469352786774],
                                [0.6447941075234065, 0.14945427447330212, 0.20575161800329134],
                                [0.6447941075234065, 0.04810958094543438, 0.30709631153115907],
                                [0.9305681557970263, 0.022913166676412786, 0.04651867752656097],
                                [0.3070963115311591, 0.06943184420297377, 0.6234718442658671],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.7681053377497433, 0.02614304424696534, 0.2057516180032913],
                                [0.35038511148716756, 0.23189466225025668, 0.41772022626257577],
                                [0.35038511148716767, 0.02614304424696523, 0.6234718442658671],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354775],
                                [0.0646110632135477, 0.06943184420297377, 0.8659570925834785],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.7049191054621227, 0.009306846264257596, 0.28577404827361974],
                                [0.12473606115226388, 0.29508089453787734, 0.5801830443098588],
                                [0.12473606115226388, 0.009306846264257596, 0.8659570925834785],
                                [0.6880829074794148, 0.30709631153115907, 0.004820780989426019],
                                [0.6234718442658672, 0.3119170925205851, 0.06461106321354769],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6699905217924282, 0.30868721495003254, 0.021322263257539314],
                                [0.6267017218364198, 0.33000947820757187, 0.04328879995600837],
                                [0.6267017218364197, 0.30868721495003254, 0.06461106321354769],
                                [0.7559836108228493, 0.221103222500738, 0.022913166676412796],
                                [0.4488872992916901, 0.2440163891771508, 0.30709631153115907],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.4642389037891368, 0.33000947820757187, 0.20575161800329134],
                                [0.46423890378913674, 0.22866478467970414, 0.30709631153115907],
                                [0.8445750667666052, 0.10890625570683385, 0.04651867752656097],
                                [0.221103222500738, 0.1554249332333949, 0.6234718442658671],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.6699905217924281, 0.12425786020428056, 0.2057516180032913],
                                [0.25227029552985236, 0.33000947820757187, 0.41772022626257577],
                                [0.25227029552985236, 0.12425786020428053, 0.6234718442658671],
                                [0.9124757701100396, 0.022913166676412786, 0.06461106321354775],
                                [0.046518677526561025, 0.08752422988996045, 0.8659570925834785],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.08980747748256934, 0.33000947820757187, 0.5801830443098588],
                                [0.08980747748256934, 0.04423542993395213, 0.8659570925834785],
                                [0.37170737474470683, 0.6234718442658671, 0.004820780989426019],
                                [0.3070963115311591, 0.6282926252552932, 0.06461106321354769],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.3519760149060409, 0.6267017218364198, 0.021322263257539314],
                                [0.3086872149500326, 0.6480239850939591, 0.04328879995600837],
                                [0.3086872149500326, 0.6267017218364197, 0.06461106321354769],
                                [0.5281995340318972, 0.4488872992916901, 0.022913166676412796],
                                [0.22110322250073794, 0.47180046596810293, 0.30709631153115907],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.4344164026829955, 0.46423890378913685, 0.10134469352786774],
                                [0.2286647846797042, 0.5655835973170045, 0.20575161800329134],
                                [0.22866478467970403, 0.46423890378913685, 0.30709631153115907],
                                [0.7323780999727011, 0.221103222500738, 0.04651867752656097],
                                [0.10890625570683388, 0.267621900027299, 0.6234718442658671],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.5419780864668563, 0.25227029552985236, 0.2057516180032913],
                                [0.12425786020428053, 0.4580219135331437, 0.41772022626257577],
                                [0.12425786020428053, 0.25227029552985236, 0.6234718442658671],
                                [0.8888702592598913, 0.046518677526560984, 0.06461106321354775],
                                [0.022913166676412855, 0.11112974074010862, 0.8659570925834785],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.6244184742438109, 0.08980747748256934, 0.28577404827361974],
                                [0.04423542993395213, 0.3755815257561891, 0.5801830443098588],
                                [0.04423542993395213, 0.08980747748256934, 0.8659570925834785],
                                [0.1292221264270954, 0.8659570925834785, 0.004820780989426019],
                                [0.0646110632135477, 0.8707778735729046, 0.06461106321354769],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.10823457888415056, 0.8704431578583102, 0.021322263257539314],
                                [0.06494577892814224, 0.8917654211158494, 0.04328879995600837],
                                [0.06494577892814224, 0.8704431578583101, 0.06461106321354769],
                                [0.35361498905772004, 0.6234718442658672, 0.022913166676412796],
                                [0.046518677526560914, 0.64638501094228, 0.30709631153115907],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.25386119894872583, 0.6447941075234065, 0.10134469352786774],
                                [0.04810958094543438, 0.7461388010512743, 0.20575161800329134],
                                [0.04810958094543438, 0.6447941075234065, 0.30709631153115907],
                                [0.64638501094228, 0.30709631153115907, 0.04651867752656097],
                                [0.022913166676412855, 0.35361498905772004, 0.6234718442658671],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.4438632705095411, 0.35038511148716756, 0.2057516180032913],
                                [0.02614304424696534, 0.5561367294904589, 0.41772022626257577],
                                [0.02614304424696534, 0.35038511148716756, 0.6234718442658671],
                                [0.8707778735729045, 0.06461106321354777, 0.06461106321354775],
                                [0.004820780989426066, 0.1292221264270954, 0.8659570925834785],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.5894898905741164, 0.12473606115226388, 0.28577404827361974],
                                [0.009306846264257596, 0.4105101094258836, 0.5801830443098588],
                                [0.009306846264257596, 0.12473606115226388, 0.8659570925834785],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426019],
                                [0.8659570925834785, 0.06943184420297373, 0.06461106321354769],
                                [0.8659570925834785, 0.0646110632135477, 0.06943184420297371],
                                [0.9305681557970262, 0.06494577892814218, 0.0044860652748315325],
                                [0.8704431578583101, 0.06943184420297373, 0.06012499793871616],
                                [0.8704431578583101, 0.0649457789281422, 0.06461106321354769],
                                [0.9305681557970263, 0.04651867752656093, 0.022913166676412796],
                                [0.6234718442658671, 0.06943184420297371, 0.30709631153115907],
                                [0.6234718442658672, 0.046518677526560914, 0.33000947820757187],
                                [0.9305681557970262, 0.048109580945434396, 0.021322263257539335],
                                [0.6447941075234065, 0.06943184420297371, 0.28577404827361974],
                                [0.6447941075234065, 0.04810958094543438, 0.30709631153115907],
                                [0.9305681557970263, 0.022913166676412786, 0.04651867752656097],
                                [0.3070963115311591, 0.06943184420297377, 0.6234718442658671],
                                [0.3070963115311591, 0.022913166676412744, 0.6699905217924281],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600841],
                                [0.35038511148716756, 0.06943184420297377, 0.5801830443098587],
                                [0.35038511148716767, 0.02614304424696523, 0.6234718442658671],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354775],
                                [0.0646110632135477, 0.06943184420297377, 0.8659570925834785],
                                [0.0646110632135477, 0.004820780989426066, 0.9305681557970262],
                                [0.9305681557970262, 0.00930684626425754, 0.060124997938716215],
                                [0.12473606115226388, 0.06943184420297377, 0.8058320946447624],
                                [0.12473606115226388, 0.009306846264257596, 0.8659570925834785],
                                [0.6880829074794148, 0.30709631153115907, 0.004820780989426019],
                                [0.6234718442658672, 0.3119170925205851, 0.06461106321354769],
                                [0.6234718442658671, 0.30709631153115907, 0.06943184420297371],
                                [0.6868267197751359, 0.30868721495003254, 0.0044860652748315325],
                                [0.6267017218364197, 0.31317328022486407, 0.06012499793871616],
                                [0.6267017218364197, 0.30868721495003254, 0.06461106321354769],
                                [0.7559836108228493, 0.221103222500738, 0.022913166676412796],
                                [0.4488872992916901, 0.2440163891771508, 0.30709631153115907],
                                [0.44888729929169013, 0.221103222500738, 0.33000947820757187],
                                [0.7500129520627565, 0.22866478467970414, 0.021322263257539335],
                                [0.4642389037891368, 0.24998704793724347, 0.28577404827361974],
                                [0.46423890378913674, 0.22866478467970414, 0.30709631153115907],
                                [0.8445750667666052, 0.10890625570683385, 0.04651867752656097],
                                [0.221103222500738, 0.1554249332333949, 0.6234718442658671],
                                [0.221103222500738, 0.10890625570683388, 0.6699905217924281],
                                [0.832453339839711, 0.12425786020428056, 0.04328879995600841],
                                [0.25227029552985236, 0.16754666016028896, 0.5801830443098587],
                                [0.25227029552985236, 0.12425786020428053, 0.6234718442658671],
                                [0.9124757701100396, 0.022913166676412786, 0.06461106321354775],
                                [0.046518677526561025, 0.08752422988996045, 0.8659570925834785],
                                [0.046518677526561025, 0.022913166676412744, 0.9305681557970262],
                                [0.8956395721273317, 0.04423542993395212, 0.060124997938716215],
                                [0.08980747748256934, 0.1043604278726683, 0.8058320946447624],
                                [0.08980747748256934, 0.04423542993395213, 0.8659570925834785],
                                [0.37170737474470683, 0.6234718442658671, 0.004820780989426019],
                                [0.3070963115311591, 0.6282926252552932, 0.06461106321354769],
                                [0.3070963115311591, 0.6234718442658671, 0.06943184420297371],
                                [0.36881221288874877, 0.6267017218364197, 0.0044860652748315325],
                                [0.3086872149500326, 0.6311877871112512, 0.06012499793871616],
                                [0.3086872149500326, 0.6267017218364197, 0.06461106321354769],
                                [0.5281995340318972, 0.4488872992916901, 0.022913166676412796],
                                [0.22110322250073794, 0.47180046596810293, 0.30709631153115907],
                                [0.221103222500738, 0.44888729929169013, 0.33000947820757187],
                                [0.5144388329533238, 0.4642389037891368, 0.021322263257539335],
                                [0.2286647846797042, 0.48556116704667607, 0.28577404827361974],
                                [0.22866478467970403, 0.46423890378913685, 0.30709631153115907],
                                [0.7323780999727011, 0.221103222500738, 0.04651867752656097],
                                [0.10890625570683388, 0.267621900027299, 0.6234718442658671],
                                [0.10890625570683388, 0.221103222500738, 0.6699905217924281],
                                [0.7044409045141393, 0.2522702955298523, 0.04328879995600841],
                                [0.12425786020428053, 0.2955590954858608, 0.5801830443098587],
                                [0.12425786020428053, 0.25227029552985236, 0.6234718442658671],
                                [0.8888702592598913, 0.046518677526560984, 0.06461106321354775],
                                [0.022913166676412855, 0.11112974074010862, 0.8659570925834785],
                                [0.022913166676412855, 0.046518677526560914, 0.9305681557970262],
                                [0.8500675245787145, 0.0898074774825693, 0.060124997938716215],
                                [0.04423542993395213, 0.14993247542128552, 0.8058320946447624],
                                [0.04423542993395213, 0.08980747748256934, 0.8659570925834785],
                                [0.1292221264270954, 0.8659570925834785, 0.004820780989426019],
                                [0.0646110632135477, 0.8707778735729046, 0.06461106321354769],
                                [0.0646110632135477, 0.8659570925834785, 0.06943184420297371],
                                [0.1250707768668584, 0.8704431578583101, 0.0044860652748315325],
                                [0.06494577892814224, 0.8749292231331416, 0.06012499793871616],
                                [0.06494577892814224, 0.8704431578583101, 0.06461106321354769],
                                [0.35361498905772004, 0.6234718442658672, 0.022913166676412796],
                                [0.046518677526560914, 0.64638501094228, 0.30709631153115907],
                                [0.046518677526561025, 0.6234718442658671, 0.33000947820757187],
                                [0.3338836292190541, 0.6447941075234065, 0.021322263257539335],
                                [0.04810958094543438, 0.6661163707809459, 0.28577404827361974],
                                [0.04810958094543438, 0.6447941075234065, 0.30709631153115907],
                                [0.64638501094228, 0.30709631153115907, 0.04651867752656097],
                                [0.022913166676412855, 0.35361498905772004, 0.6234718442658671],
                                [0.022913166676412855, 0.307096311531159, 0.6699905217924281],
                                [0.606326088556824, 0.35038511148716756, 0.04328879995600841],
                                [0.02614304424696534, 0.393673911443176, 0.5801830443098587],
                                [0.02614304424696534, 0.35038511148716756, 0.6234718442658671],
                                [0.8707778735729045, 0.06461106321354777, 0.06461106321354775],
                                [0.004820780989426066, 0.1292221264270954, 0.8659570925834785],
                                [0.004820780989426066, 0.0646110632135477, 0.9305681557970262],
                                [0.8151389409090198, 0.12473606115226395, 0.060124997938716215],
                                [0.009306846264257596, 0.18486105909098005, 0.8058320946447624],
                                [0.009306846264257596, 0.12473606115226388, 0.8659570925834785],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.8617825030938935,
                                    0.004174589489585057,
                                    0.13339671591668045,
                                    0.0006461914998409577,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8665800441539715,
                                    0.004197829418933068,
                                    0.12859917485660247,
                                    0.0006229515704929466,
                                ],
                                [
                                    0.8617825030938935,
                                    0.06429958742830122,
                                    0.06878565270313275,
                                    0.005132256774672488,
                                ],
                                [
                                    0.866268568368725,
                                    0.06463430314289571,
                                    0.06429958742830122,
                                    0.004797541060078002,
                                ],
                                [
                                    0.86209397887914,
                                    0.06432282735764924,
                                    0.06847417691788628,
                                    0.005109016845324477,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.6315742834494246,
                                    0.014810727492855358,
                                    0.3455125498741626,
                                    0.008102439183557419,
                                ],
                                [
                                    0.6091861299801529,
                                    0.30005976255933403,
                                    0.06080439181227522,
                                    0.029949715648237812,
                                ],
                                [
                                    0.6245377344775995,
                                    0.3076213247383002,
                                    0.045452787314828554,
                                    0.02238815346927171,
                                ],
                                [
                                    0.6102520201918853,
                                    0.30058477576647513,
                                    0.05973850160054283,
                                    0.029424702441096736,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.3371652874131856,
                                    0.01644970164453445,
                                    0.6163160350602535,
                                    0.030068975882026484,
                                ],
                                [
                                    0.2928105972454448,
                                    0.5944687585955731,
                                    0.03719888096212706,
                                    0.07552176319685502,
                                ],
                                [
                                    0.3081622017428915,
                                    0.6256358316246874,
                                    0.02184727646468039,
                                    0.04435469016774077,
                                ],
                                [
                                    0.2938764874571772,
                                    0.5966327459543933,
                                    0.03613299075039468,
                                    0.07335777583803486,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.1208729474479255,
                                    0.008349178979170127,
                                    0.8145159893385268,
                                    0.056261884234377564,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.06074794950920917,
                                    0.8141812736239326,
                                    0.008683894693764604,
                                    0.11638688217309373,
                                ],
                                [
                                    0.6204662230515879,
                                    0.0030056212142792692,
                                    0.374712995958986,
                                    0.0018151597751467452,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6252637641116658,
                                    0.00302886114362728,
                                    0.36991545489890804,
                                    0.001791919845798734,
                                ],
                                [
                                    0.6204662230515879,
                                    0.046294421170287654,
                                    0.31010193274543835,
                                    0.023137423032686063,
                                ],
                                [
                                    0.6249522883264195,
                                    0.046629136884882134,
                                    0.3056158674706068,
                                    0.02280270731809158,
                                ],
                                [
                                    0.8632629471544457,
                                    0.06441004678662242,
                                    0.06730520864258048,
                                    0.0050217974163512865,
                                ],
                                [
                                    0.4386018697840949,
                                    0.010285429507595284,
                                    0.5384849635394924,
                                    0.012627737168817495,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.4609900232533665,
                                    0.010810442714736357,
                                    0.5160968100702207,
                                    0.012102723961676422,
                                ],
                                [
                                    0.4386018697840948,
                                    0.21603704751088662,
                                    0.23138865200833328,
                                    0.11397243069668524,
                                ],
                                [
                                    0.4539534742815415,
                                    0.22359860968985273,
                                    0.21603704751088665,
                                    0.10641086851771915,
                                ],
                                [
                                    0.6142523049700043,
                                    0.30255514974844877,
                                    0.05573821682242383,
                                    0.027454328459123097,
                                ],
                                [
                                    0.2108177929931427,
                                    0.010285429507595282,
                                    0.7426635294802963,
                                    0.03623324801896565,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.2551724831608836,
                                    0.012449416866415453,
                                    0.6983088393125555,
                                    0.034069260660145484,
                                ],
                                [
                                    0.21081779299314274,
                                    0.42800565577017113,
                                    0.11919168521442913,
                                    0.241984866022257,
                                ],
                                [
                                    0.2261693974905894,
                                    0.4591727287992854,
                                    0.10384008071698247,
                                    0.21081779299314274,
                                ],
                                [
                                    0.2978767722352962,
                                    0.6047541881031684,
                                    0.032132705972275674,
                                    0.06523633368925974,
                                ],
                                [
                                    0.04351305631228175,
                                    0.003005621214279275,
                                    0.8918758804741705,
                                    0.061605441999268415,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.1039495300362444,
                                    0.007180210703864331,
                                    0.8314394067502079,
                                    0.057430852509683356,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.061916917784514955,
                                    0.8298485033313345,
                                    0.007514926418458816,
                                    0.10071965246569174,
                                ],
                                [
                                    0.3056158674706069,
                                    0.001480444060552261,
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3104134085306848,
                                    0.0015036839899002718,
                                    0.6847658104798892,
                                    0.0033170969995257424,
                                ],
                                [
                                    0.3056158674706068,
                                    0.02280270731809158,
                                    0.6249522883264195,
                                    0.046629136884882134,
                                ],
                                [
                                    0.3101019327454384,
                                    0.023137423032686066,
                                    0.6204662230515878,
                                    0.04629442117028765,
                                ],
                                [
                                    0.8647881243081728,
                                    0.06452384378457451,
                                    0.06578003148885347,
                                    0.004908000418399203,
                                ],
                                [
                                    0.21603704751088662,
                                    0.00506617498985139,
                                    0.7610497858127007,
                                    0.017846991686561387,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.2384252009801584,
                                    0.005591188196992464,
                                    0.7386616323434289,
                                    0.017321978479420314,
                                ],
                                [
                                    0.21603704751088665,
                                    0.10641086851771915,
                                    0.4539534742815415,
                                    0.22359860968985273,
                                ],
                                [
                                    0.23138865200833328,
                                    0.11397243069668524,
                                    0.4386018697840948,
                                    0.21603704751088662,
                                ],
                                [
                                    0.6194715594877481,
                                    0.30512593754918543,
                                    0.050518962304679935,
                                    0.02488354065838642,
                                ],
                                [
                                    0.10384008071698249,
                                    0.0050661749898513915,
                                    0.8496412417564566,
                                    0.04145250253670954,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.14819477088472324,
                                    0.007230162348671556,
                                    0.8052865515887159,
                                    0.03928851517788938,
                                ],
                                [
                                    0.10384008071698247,
                                    0.21081779299314274,
                                    0.2261693974905894,
                                    0.4591727287992854,
                                ],
                                [
                                    0.11919168521442913,
                                    0.241984866022257,
                                    0.21081779299314274,
                                    0.42800565577017113,
                                ],
                                [
                                    0.3030960267530401,
                                    0.6153504021170921,
                                    0.02691345145453178,
                                    0.05464011967533605,
                                ],
                                [
                                    0.02143272261586059,
                                    0.0014804440605522655,
                                    0.9139562141705917,
                                    0.06313061915299542,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.08186919633982323,
                                    0.005655033550137321,
                                    0.853519740446629,
                                    0.05895602966341037,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.06344209493824196,
                                    0.8502898628760766,
                                    0.005989749264731806,
                                    0.08027829292094968,
                                ],
                                [
                                    0.06429958742830123,
                                    0.0003114757852464733,
                                    0.9308796315822727,
                                    0.004509305204179541,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.06909712848837928,
                                    0.0003347157145944848,
                                    0.9260820905221947,
                                    0.00448606527483153,
                                ],
                                [
                                    0.06429958742830123,
                                    0.004797541060078003,
                                    0.866268568368725,
                                    0.06463430314289571,
                                ],
                                [
                                    0.0687856527031328,
                                    0.005132256774672492,
                                    0.8617825030938935,
                                    0.06429958742830122,
                                ],
                                [
                                    0.8659570925834785,
                                    0.06461106321354769,
                                    0.06461106321354769,
                                    0.004820780989426014,
                                ],
                                [
                                    0.04545278731482864,
                                    0.0010658902117323902,
                                    0.9316340460087587,
                                    0.02184727646468039,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.06784094078410031,
                                    0.0015909034188734622,
                                    0.909245892539487,
                                    0.021322263257539317,
                                ],
                                [
                                    0.04545278731482858,
                                    0.022388153469271723,
                                    0.6245377344775995,
                                    0.3076213247383002,
                                ],
                                [
                                    0.06080439181227523,
                                    0.029949715648237816,
                                    0.6091861299801529,
                                    0.30005976255933403,
                                ],
                                [
                                    0.6234718442658671,
                                    0.30709631153115907,
                                    0.046518677526560935,
                                    0.02291316667641278,
                                ],
                                [
                                    0.021847276464680463,
                                    0.0010658902117323915,
                                    0.9316340460087587,
                                    0.04545278731482855,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.06620196663242121,
                                    0.003229877570552556,
                                    0.8872793558410179,
                                    0.04328879995600838,
                                ],
                                [
                                    0.021847276464680394,
                                    0.044354690167740775,
                                    0.3081622017428915,
                                    0.6256358316246874,
                                ],
                                [
                                    0.03719888096212706,
                                    0.07552176319685502,
                                    0.2928105972454448,
                                    0.5944687585955731,
                                ],
                                [
                                    0.30709631153115907,
                                    0.6234718442658671,
                                    0.02291316667641278,
                                    0.046518677526560935,
                                ],
                                [
                                    0.004509305204179589,
                                    0.0003114757852464765,
                                    0.9308796315822727,
                                    0.06429958742830122,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.06461106321354775,
                                    0.8659570925834785,
                                    0.004820780989426019,
                                    0.06461106321354769,
                                ],
                                [
                                    0.8461152733864915,
                                    0.019841819196987055,
                                    0.1309715599370957,
                                    0.0030713474794257217,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8508255950175964,
                                    0.019952278555308258,
                                    0.1262612383059909,
                                    0.0029608881211045214,
                                ],
                                [
                                    0.8617825030938935,
                                    0.06429958742830122,
                                    0.06878565270313275,
                                    0.005132256774672488,
                                ],
                                [
                                    0.866268568368725,
                                    0.06463430314289571,
                                    0.06429958742830122,
                                    0.004797541060078002,
                                ],
                                [
                                    0.8632629471544457,
                                    0.06441004678662242,
                                    0.0673052086425805,
                                    0.005021797416351288,
                                ],
                                [
                                    0.5555718601682373,
                                    0.06789998409762983,
                                    0.3355218841249287,
                                    0.041006271609204024,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5759896396555354,
                                    0.07039537128674454,
                                    0.31510410463763067,
                                    0.038510884420089306,
                                ],
                                [
                                    0.6091861299801529,
                                    0.30005976255933403,
                                    0.06080439181227522,
                                    0.029949715648237812,
                                ],
                                [
                                    0.6245377344775995,
                                    0.3076213247383002,
                                    0.045452787314828554,
                                    0.02238815346927171,
                                ],
                                [
                                    0.6142523049700043,
                                    0.30255514974844877,
                                    0.05573821682242383,
                                    0.027454328459123097,
                                ],
                                [
                                    0.2391963274335293,
                                    0.06789998409762983,
                                    0.5397004500657328,
                                    0.15320323840310818,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.2754295754524949,
                                    0.07818541360522512,
                                    0.5034672020467671,
                                    0.1429178088955129,
                                ],
                                [
                                    0.2928105972454448,
                                    0.5944687585955731,
                                    0.03719888096212706,
                                    0.07552176319685502,
                                ],
                                [
                                    0.3081622017428915,
                                    0.6256358316246874,
                                    0.02184727646468039,
                                    0.04435469016774077,
                                ],
                                [
                                    0.2978767722352962,
                                    0.6047541881031684,
                                    0.032132705972275674,
                                    0.06523633368925975,
                                ],
                                [
                                    0.04476924401656064,
                                    0.01984181919698706,
                                    0.6481344444522802,
                                    0.287254492334172,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.08953848803312144,
                                    0.03968363839397418,
                                    0.6033652004357194,
                                    0.26741267313718486,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.061916917784514955,
                                    0.8298485033313345,
                                    0.007514926418458816,
                                    0.10071965246569174,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6138964516112577,
                                    0.014396173644035485,
                                    0.3631903817123295,
                                    0.008516993032377292,
                                ],
                                [
                                    0.6204662230515879,
                                    0.046294421170287654,
                                    0.31010193274543835,
                                    0.023137423032686063,
                                ],
                                [
                                    0.6249522883264195,
                                    0.046629136884882134,
                                    0.3056158674706068,
                                    0.02280270731809158,
                                ],
                                [
                                    0.8644319154297515,
                                    0.06449726621559562,
                                    0.0661362403672747,
                                    0.004934577987378098,
                                ],
                                [
                                    0.40000066429147924,
                                    0.048886635000210864,
                                    0.4910930800016869,
                                    0.060019620706622985,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.4204184437787773,
                                    0.051382022189325575,
                                    0.47067530051438883,
                                    0.05752423351750827,
                                ],
                                [
                                    0.4386018697840948,
                                    0.21603704751088662,
                                    0.23138865200833328,
                                    0.11397243069668524,
                                ],
                                [
                                    0.4539534742815415,
                                    0.22359860968985273,
                                    0.21603704751088665,
                                    0.10641086851771915,
                                ],
                                [
                                    0.6182525897481234,
                                    0.3045255237304224,
                                    0.05173793204430483,
                                    0.025483954477149455,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.20844983551949287,
                                    0.05917206450780616,
                                    0.5704469419797692,
                                    0.16193115799293187,
                                ],
                                [
                                    0.21081779299314274,
                                    0.42800565577017113,
                                    0.11919168521442913,
                                    0.241984866022257,
                                ],
                                [
                                    0.2261693974905894,
                                    0.4591727287992854,
                                    0.10384008071698247,
                                    0.21081779299314274,
                                ],
                                [
                                    0.3018770570134152,
                                    0.6128756302519436,
                                    0.02813242119415667,
                                    0.05711489154048462,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.07700220725740735,
                                    0.034127533482701373,
                                    0.6159014812114335,
                                    0.2729687780484577,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.06308588605982074,
                                    0.8455157330387365,
                                    0.006345958143153027,
                                    0.08505242275828974,
                                ],
                                [
                                    0.3000597625593341,
                                    0.007036548971825033,
                                    0.6770270707642532,
                                    0.015876617704587745,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3047700841904389,
                                    0.007147008330146231,
                                    0.6723167491331484,
                                    0.015766158346266546,
                                ],
                                [
                                    0.3056158674706068,
                                    0.02280270731809158,
                                    0.6249522883264195,
                                    0.046629136884882134,
                                ],
                                [
                                    0.3101019327454384,
                                    0.023137423032686066,
                                    0.6204662230515878,
                                    0.04629442117028765,
                                ],
                                [
                                    0.8659570925834785,
                                    0.06461106321354769,
                                    0.06461106321354769,
                                    0.004820780989426014,
                                ],
                                [
                                    0.19702369841346765,
                                    0.024079524087270352,
                                    0.6940700458796984,
                                    0.0848267316195635,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.21744147790076576,
                                    0.026574911276385074,
                                    0.6736522663924004,
                                    0.08233134443044877,
                                ],
                                [
                                    0.21603704751088665,
                                    0.10641086851771915,
                                    0.4539534742815415,
                                    0.22359860968985273,
                                ],
                                [
                                    0.23138865200833328,
                                    0.11397243069668524,
                                    0.4386018697840948,
                                    0.21603704751088662,
                                ],
                                [
                                    0.6234718442658671,
                                    0.30709631153115907,
                                    0.046518677526560935,
                                    0.02291316667641278,
                                ],
                                [
                                    0.08482673161956351,
                                    0.02407952408727036,
                                    0.6940700458796984,
                                    0.19702369841346767,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.12105997963852916,
                                    0.03436495359486564,
                                    0.6578367978607329,
                                    0.1867382689058724,
                                ],
                                [
                                    0.10384008071698247,
                                    0.21081779299314274,
                                    0.2261693974905894,
                                    0.4591727287992854,
                                ],
                                [
                                    0.11919168521442913,
                                    0.241984866022257,
                                    0.21081779299314274,
                                    0.42800565577017113,
                                ],
                                [
                                    0.30709631153115907,
                                    0.6234718442658671,
                                    0.02291316667641278,
                                    0.046518677526560935,
                                ],
                                [
                                    0.0158766177045878,
                                    0.0070365489718250546,
                                    0.6770270707642531,
                                    0.30005976255933403,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.06064586172114844,
                                    0.026878368168812113,
                                    0.6322578267476925,
                                    0.28021794336234696,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.06461106321354775,
                                    0.8659570925834785,
                                    0.004820780989426019,
                                    0.06461106321354769,
                                ],
                                [
                                    0.06313061915299545,
                                    0.0014804440605522607,
                                    0.9139562141705918,
                                    0.021432722615860517,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.06784094078410031,
                                    0.0015909034188734622,
                                    0.909245892539487,
                                    0.021322263257539317,
                                ],
                                [
                                    0.06429958742830123,
                                    0.004797541060078003,
                                    0.866268568368725,
                                    0.06463430314289571,
                                ],
                                [
                                    0.0687856527031328,
                                    0.005132256774672492,
                                    0.8617825030938935,
                                    0.06429958742830122,
                                ],
                                [
                                    0.8671260608587843,
                                    0.0646982826425209,
                                    0.0634420949382419,
                                    0.0047335615604528255,
                                ],
                                [
                                    0.04145250253670962,
                                    0.0050661749898514,
                                    0.8496412417564565,
                                    0.10384008071698245,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.061870282024007656,
                                    0.007561562178966111,
                                    0.8292234622691584,
                                    0.10134469352786774,
                                ],
                                [
                                    0.04545278731482858,
                                    0.022388153469271723,
                                    0.6245377344775995,
                                    0.3076213247383002,
                                ],
                                [
                                    0.06080439181227523,
                                    0.029949715648237816,
                                    0.6091861299801529,
                                    0.30005976255933403,
                                ],
                                [
                                    0.6274721290439862,
                                    0.30906668551313277,
                                    0.04251839274844193,
                                    0.020942792694439136,
                                ],
                                [
                                    0.01784699168656145,
                                    0.005066174989851407,
                                    0.7610497858127006,
                                    0.21603704751088662,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.05408023970552708,
                                    0.015351604497446686,
                                    0.7248165377937349,
                                    0.20575161800329134,
                                ],
                                [
                                    0.021847276464680394,
                                    0.044354690167740775,
                                    0.3081622017428915,
                                    0.6256358316246874,
                                ],
                                [
                                    0.03719888096212706,
                                    0.07552176319685502,
                                    0.2928105972454448,
                                    0.5944687585955731,
                                ],
                                [
                                    0.3110965963092781,
                                    0.6315932864146423,
                                    0.01891288189829378,
                                    0.03839723537778582,
                                ],
                                [
                                    0.003340336928873789,
                                    0.0014804440605522763,
                                    0.6895633515399671,
                                    0.3056158674706068,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.06578003148885354,
                                    0.8816243222908805,
                                    0.0036518127141202303,
                                    0.0489438335061457,
                                ],
                                [
                                    0.8256739138417495,
                                    0.04028317874172911,
                                    0.1278074086316896,
                                    0.006235498784831823,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8302704384749022,
                                    0.0405074350980024,
                                    0.12321088399853687,
                                    0.006011242428558539,
                                ],
                                [
                                    0.8617825030938935,
                                    0.06429958742830122,
                                    0.06878565270313275,
                                    0.005132256774672488,
                                ],
                                [
                                    0.866268568368725,
                                    0.06463430314289571,
                                    0.06429958742830122,
                                    0.004797541060078002,
                                ],
                                [
                                    0.8647881243081728,
                                    0.06452384378457451,
                                    0.06578003148885347,
                                    0.004908000418399203,
                                ],
                                [
                                    0.4856202103602057,
                                    0.13785163390566152,
                                    0.2932765671390563,
                                    0.0832515885950765,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5034672020467671,
                                    0.1429178088955129,
                                    0.2754295754524949,
                                    0.0781854136052251,
                                ],
                                [
                                    0.6091861299801529,
                                    0.30005976255933403,
                                    0.06080439181227522,
                                    0.029949715648237812,
                                ],
                                [
                                    0.6245377344775995,
                                    0.3076213247383002,
                                    0.045452787314828554,
                                    0.02238815346927171,
                                ],
                                [
                                    0.6194715594877481,
                                    0.30512593754918543,
                                    0.050518962304679935,
                                    0.02488354065838642,
                                ],
                                [
                                    0.16924467762549758,
                                    0.13785163390566155,
                                    0.38186802308281226,
                                    0.3110356653860286,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.19488171163053952,
                                    0.15873327742718052,
                                    0.35623098907777034,
                                    0.2901540218645096,
                                ],
                                [
                                    0.2928105972454448,
                                    0.5944687585955731,
                                    0.03719888096212706,
                                    0.07552176319685502,
                                ],
                                [
                                    0.3081622017428915,
                                    0.6256358316246874,
                                    0.02184727646468039,
                                    0.04435469016774077,
                                ],
                                [
                                    0.3030960267530401,
                                    0.6153504021170921,
                                    0.02691345145453178,
                                    0.05464011967533605,
                                ],
                                [
                                    0.024327884471818596,
                                    0.04028317874172911,
                                    0.3522002712623143,
                                    0.583188665524138,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.048655768943637275,
                                    0.08056635748345836,
                                    0.32787238679049563,
                                    0.5429054867824088,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.06344209493824196,
                                    0.8502898628760766,
                                    0.005989749264731807,
                                    0.08027829292094969,
                                ],
                                [
                                    0.5944687585955731,
                                    0.029003085670294096,
                                    0.35901256387786595,
                                    0.01751559185626684,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.5990652832287258,
                                    0.029227342026567377,
                                    0.3544160392447132,
                                    0.017291335499993555,
                                ],
                                [
                                    0.6204662230515879,
                                    0.046294421170287654,
                                    0.31010193274543835,
                                    0.023137423032686063,
                                ],
                                [
                                    0.6249522883264195,
                                    0.046629136884882134,
                                    0.3056158674706068,
                                    0.02280270731809158,
                                ],
                                [
                                    0.8659570925834785,
                                    0.06461106321354769,
                                    0.06461106321354769,
                                    0.004820780989426014,
                                ],
                                [
                                    0.3496368708786442,
                                    0.09925042841304595,
                                    0.4292599066206178,
                                    0.12185279408769208,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.36748386256520554,
                                    0.10431660340289733,
                                    0.41141291493405646,
                                    0.11678661909784069,
                                ],
                                [
                                    0.4386018697840948,
                                    0.21603704751088662,
                                    0.23138865200833328,
                                    0.11397243069668524,
                                ],
                                [
                                    0.4539534742815415,
                                    0.22359860968985273,
                                    0.21603704751088665,
                                    0.10641086851771915,
                                ],
                                [
                                    0.6234718442658671,
                                    0.30709631153115907,
                                    0.046518677526560935,
                                    0.02291316667641278,
                                ],
                                [
                                    0.12185279408769206,
                                    0.09925042841304593,
                                    0.4292599066206178,
                                    0.3496368708786442,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.14748982809273406,
                                    0.12013207193456495,
                                    0.4036228726155758,
                                    0.3287552273571252,
                                ],
                                [
                                    0.21081779299314274,
                                    0.42800565577017113,
                                    0.11919168521442913,
                                    0.241984866022257,
                                ],
                                [
                                    0.2261693974905894,
                                    0.4591727287992854,
                                    0.10384008071698247,
                                    0.21081779299314274,
                                ],
                                [
                                    0.30709631153115907,
                                    0.6234718442658671,
                                    0.02291316667641278,
                                    0.046518677526560935,
                                ],
                                [
                                    0.017515591856266877,
                                    0.029003085670294148,
                                    0.359012563877866,
                                    0.5944687585955729,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.04184347632808547,
                                    0.06928626441202326,
                                    0.3346846794060474,
                                    0.5541855798538439,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.06461106321354775,
                                    0.8659570925834785,
                                    0.004820780989426019,
                                    0.06461106321354769,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.2974071218785975,
                                    0.01450997064198757,
                                    0.6560742005948416,
                                    0.032008706884573364,
                                ],
                                [
                                    0.3056158674706068,
                                    0.02280270731809158,
                                    0.6249522883264195,
                                    0.046629136884882134,
                                ],
                                [
                                    0.3101019327454384,
                                    0.023137423032686066,
                                    0.6204662230515878,
                                    0.04629442117028765,
                                ],
                                [
                                    0.8674822697372055,
                                    0.06472486021149979,
                                    0.0630858860598207,
                                    0.004706983991473931,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.19006357918708858,
                                    0.053952809990062266,
                                    0.5888331983121734,
                                    0.16715041251067575,
                                ],
                                [
                                    0.21603704751088665,
                                    0.10641086851771915,
                                    0.4539534742815415,
                                    0.22359860968985273,
                                ],
                                [
                                    0.23138865200833328,
                                    0.11397243069668524,
                                    0.4386018697840948,
                                    0.21603704751088662,
                                ],
                                [
                                    0.6286910987836112,
                                    0.3096670993318958,
                                    0.04129942300881704,
                                    0.020342378875676102,
                                ],
                                [
                                    0.060019620706623,
                                    0.04888663500021088,
                                    0.4910930800016869,
                                    0.40000066429147924,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.08565665471166495,
                                    0.06976827852172984,
                                    0.4654560459966449,
                                    0.3791190207699603,
                                ],
                                [
                                    0.10384008071698247,
                                    0.21081779299314274,
                                    0.2261693974905894,
                                    0.4591727287992854,
                                ],
                                [
                                    0.11919168521442913,
                                    0.241984866022257,
                                    0.21081779299314274,
                                    0.42800565577017113,
                                ],
                                [
                                    0.312315566048903,
                                    0.6340680582797908,
                                    0.017693912158668886,
                                    0.03592246351263724,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.03295533686251712,
                                    0.05456889302744344,
                                    0.3435728188716158,
                                    0.5689029512384237,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.06613624036727477,
                                    0.8863984521282207,
                                    0.003295603835699009,
                                    0.04416970366880565,
                                ],
                                [
                                    0.061605441999268436,
                                    0.0030056212142792697,
                                    0.8918758804741707,
                                    0.04351305631228167,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.06620196663242121,
                                    0.003229877570552556,
                                    0.8872793558410179,
                                    0.04328879995600838,
                                ],
                                [
                                    0.06429958742830123,
                                    0.004797541060078003,
                                    0.866268568368725,
                                    0.06463430314289571,
                                ],
                                [
                                    0.0687856527031328,
                                    0.005132256774672492,
                                    0.8617825030938935,
                                    0.06429958742830122,
                                ],
                                [
                                    0.8686512380125113,
                                    0.06481207964047296,
                                    0.061916917784514906,
                                    0.004619764562500742,
                                ],
                                [
                                    0.03623324801896572,
                                    0.010285429507595303,
                                    0.7426635294802962,
                                    0.2108177929931427,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.05408023970552708,
                                    0.015351604497446686,
                                    0.7248165377937349,
                                    0.20575161800329134,
                                ],
                                [
                                    0.04545278731482858,
                                    0.022388153469271723,
                                    0.6245377344775995,
                                    0.3076213247383002,
                                ],
                                [
                                    0.06080439181227523,
                                    0.029949715648237816,
                                    0.6091861299801529,
                                    0.30005976255933403,
                                ],
                                [
                                    0.6326913835617302,
                                    0.31163747331386943,
                                    0.03729913823069804,
                                    0.018372004893702464,
                                ],
                                [
                                    0.012627737168817536,
                                    0.010285429507595319,
                                    0.5384849635394924,
                                    0.4386018697840948,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.038264771173859485,
                                    0.031167073029114287,
                                    0.5128479295344504,
                                    0.4177202262625758,
                                ],
                                [
                                    0.021847276464680394,
                                    0.044354690167740775,
                                    0.3081622017428915,
                                    0.6256358316246874,
                                ],
                                [
                                    0.03719888096212706,
                                    0.07552176319685502,
                                    0.2928105972454448,
                                    0.5944687585955731,
                                ],
                                [
                                    0.316315850827022,
                                    0.642189500428566,
                                    0.013693627380549887,
                                    0.027801021363862127,
                                ],
                                [
                                    0.001815159775146765,
                                    0.003005621214279301,
                                    0.3747129959589861,
                                    0.6204662230515878,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.06730520864258055,
                                    0.9020656818356226,
                                    0.002126635560393221,
                                    0.02850247396140365,
                                ],
                                [
                                    0.8100066841343474,
                                    0.0559504084491311,
                                    0.12538225265210484,
                                    0.008660654764416586,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.814515989338527,
                                    0.05626188423437758,
                                    0.12087294744792529,
                                    0.008349178979170114,
                                ],
                                [
                                    0.8617825030938935,
                                    0.06429958742830122,
                                    0.06878565270313275,
                                    0.005132256774672488,
                                ],
                                [
                                    0.866268568368725,
                                    0.06463430314289571,
                                    0.06429958742830122,
                                    0.004797541060078002,
                                ],
                                [
                                    0.8659570925834785,
                                    0.06461106321354769,
                                    0.06461106321354769,
                                    0.004820780989426014,
                                ],
                                [
                                    0.4320059405482901,
                                    0.19146590371757705,
                                    0.26089774792055076,
                                    0.11563040781358203,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.44788255825287787,
                                    0.19850245268940206,
                                    0.24502113021596297,
                                    0.10859385884175699,
                                ],
                                [
                                    0.6091861299801529,
                                    0.30005976255933403,
                                    0.06080439181227522,
                                    0.029949715648237812,
                                ],
                                [
                                    0.6245377344775995,
                                    0.3076213247383002,
                                    0.045452787314828554,
                                    0.02238815346927171,
                                ],
                                [
                                    0.6234718442658671,
                                    0.30709631153115907,
                                    0.046518677526560935,
                                    0.02291316667641278,
                                ],
                                [
                                    0.11563040781358208,
                                    0.19146590371757705,
                                    0.2608977479205508,
                                    0.43200594054829006,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.1331459996698489,
                                    0.22046898938787113,
                                    0.24338215606428398,
                                    0.403002854877996,
                                ],
                                [
                                    0.2928105972454448,
                                    0.5944687585955731,
                                    0.03719888096212706,
                                    0.07552176319685502,
                                ],
                                [
                                    0.3081622017428915,
                                    0.6256358316246874,
                                    0.02184727646468039,
                                    0.04435469016774077,
                                ],
                                [
                                    0.30709631153115907,
                                    0.6234718442658671,
                                    0.02291316667641278,
                                    0.046518677526560935,
                                ],
                                [
                                    0.008660654764416591,
                                    0.055950408449131114,
                                    0.12538225265210487,
                                    0.8100066841343474,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.017321309528833213,
                                    0.11190081689826242,
                                    0.11672159788768827,
                                    0.7540562756852162,
                                ],
                                [
                                    0.060436473723962686,
                                    0.8100066841343474,
                                    0.008995370479011078,
                                    0.1205614716626788,
                                ],
                                [
                                    0.06492253899879422,
                                    0.8701316820730636,
                                    0.004509305204179545,
                                    0.06043647372396264,
                                ],
                                [
                                    0.06461106321354775,
                                    0.8659570925834785,
                                    0.004820780989426019,
                                    0.06461106321354769,
                                ],
                                [
                                    0.5831886655241381,
                                    0.040283178741729105,
                                    0.3522002712623142,
                                    0.024327884471818582,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.5876979707283175,
                                    0.040594654526975575,
                                    0.34769096605813465,
                                    0.02401640868657211,
                                ],
                                [
                                    0.6204662230515879,
                                    0.046294421170287654,
                                    0.31010193274543835,
                                    0.023137423032686063,
                                ],
                                [
                                    0.6249522883264195,
                                    0.046629136884882134,
                                    0.3056158674706068,
                                    0.02280270731809158,
                                ],
                                [
                                    0.8671260608587843,
                                    0.0646982826425209,
                                    0.0634420949382419,
                                    0.0047335615604528255,
                                ],
                                [
                                    0.3110356653860286,
                                    0.13785163390566152,
                                    0.38186802308281226,
                                    0.16924467762549755,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.3269122830906163,
                                    0.14488818287748653,
                                    0.36599140537822455,
                                    0.16220812865367254,
                                ],
                                [
                                    0.4386018697840948,
                                    0.21603704751088662,
                                    0.23138865200833328,
                                    0.11397243069668524,
                                ],
                                [
                                    0.4539534742815415,
                                    0.22359860968985273,
                                    0.21603704751088665,
                                    0.10641086851771915,
                                ],
                                [
                                    0.6274721290439862,
                                    0.30906668551313277,
                                    0.04251839274844193,
                                    0.020942792694439136,
                                ],
                                [
                                    0.08325158859507652,
                                    0.1378516339056615,
                                    0.29327656713905637,
                                    0.48562021036020564,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.10076718045134339,
                                    0.16685471957595563,
                                    0.27576097528278953,
                                    0.45661712468991145,
                                ],
                                [
                                    0.21081779299314274,
                                    0.42800565577017113,
                                    0.11919168521442913,
                                    0.241984866022257,
                                ],
                                [
                                    0.2261693974905894,
                                    0.4591727287992854,
                                    0.10384008071698247,
                                    0.21081779299314274,
                                ],
                                [
                                    0.3110965963092781,
                                    0.6315932864146423,
                                    0.01891288189829378,
                                    0.03839723537778582,
                                ],
                                [
                                    0.0062354987848318374,
                                    0.04028317874172919,
                                    0.12780740863168963,
                                    0.8256739138417494,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.014896153549248429,
                                    0.0962335871908603,
                                    0.11914675386727304,
                                    0.7697235053926182,
                                ],
                                [
                                    0.043513056312281695,
                                    0.583188665524138,
                                    0.025918787890692067,
                                    0.34737949027288817,
                                ],
                                [
                                    0.04799912158711323,
                                    0.6433136634628541,
                                    0.021432722615860534,
                                    0.287254492334172,
                                ],
                                [
                                    0.06578003148885354,
                                    0.8816243222908805,
                                    0.0036518127141202303,
                                    0.0489438335061457,
                                ],
                                [
                                    0.28725449233417205,
                                    0.019841819196987055,
                                    0.6481344444522802,
                                    0.044769244016560635,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.2917637975383516,
                                    0.020153294982233526,
                                    0.6436251392481007,
                                    0.044457768231314164,
                                ],
                                [
                                    0.3056158674706068,
                                    0.02280270731809158,
                                    0.6249522883264195,
                                    0.046629136884882134,
                                ],
                                [
                                    0.3101019327454384,
                                    0.023137423032686066,
                                    0.6204662230515878,
                                    0.04629442117028765,
                                ],
                                [
                                    0.8686512380125113,
                                    0.06481207964047296,
                                    0.061916917784514906,
                                    0.004619764562500742,
                                ],
                                [
                                    0.15320323840310818,
                                    0.06789998409762982,
                                    0.5397004500657328,
                                    0.23919632743352925,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.16907985610769596,
                                    0.07493653306945487,
                                    0.5238238323611449,
                                    0.2321597784617042,
                                ],
                                [
                                    0.21603704751088665,
                                    0.10641086851771915,
                                    0.4539534742815415,
                                    0.22359860968985273,
                                ],
                                [
                                    0.23138865200833328,
                                    0.11397243069668524,
                                    0.4386018697840948,
                                    0.21603704751088662,
                                ],
                                [
                                    0.6326913835617302,
                                    0.31163747331386943,
                                    0.03729913823069804,
                                    0.018372004893702464,
                                ],
                                [
                                    0.041006271609204045,
                                    0.06789998409762983,
                                    0.33552188412492884,
                                    0.5555718601682372,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.058521863465470884,
                                    0.09690306976792391,
                                    0.318006292268662,
                                    0.5265687744979431,
                                ],
                                [
                                    0.10384008071698247,
                                    0.21081779299314274,
                                    0.2261693974905894,
                                    0.4591727287992854,
                                ],
                                [
                                    0.11919168521442913,
                                    0.241984866022257,
                                    0.21081779299314274,
                                    0.42800565577017113,
                                ],
                                [
                                    0.316315850827022,
                                    0.642189500428566,
                                    0.013693627380549887,
                                    0.027801021363862127,
                                ],
                                [
                                    0.0030713474794257334,
                                    0.01984181919698712,
                                    0.13097155993709575,
                                    0.8461152733864914,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.011732002243842325,
                                    0.07579222764611823,
                                    0.12231090517267915,
                                    0.7901648649373603,
                                ],
                                [
                                    0.021432722615860537,
                                    0.28725449233417205,
                                    0.04799912158711323,
                                    0.6433136634628541,
                                ],
                                [
                                    0.02591878789069207,
                                    0.3473794902728882,
                                    0.043513056312281695,
                                    0.583188665524138,
                                ],
                                [
                                    0.06730520864258055,
                                    0.9020656818356226,
                                    0.002126635560393221,
                                    0.02850247396140365,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06429958742830123,
                                    0.004797541060078003,
                                    0.866268568368725,
                                    0.06463430314289571,
                                ],
                                [
                                    0.0687856527031328,
                                    0.005132256774672492,
                                    0.8617825030938935,
                                    0.06429958742830122,
                                ],
                                [
                                    0.8698202062878171,
                                    0.06489929906944616,
                                    0.06074794950920911,
                                    0.0045325451335275525,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04545278731482858,
                                    0.022388153469271723,
                                    0.6245377344775995,
                                    0.3076213247383002,
                                ],
                                [
                                    0.06080439181227523,
                                    0.029949715648237816,
                                    0.6091861299801529,
                                    0.30005976255933403,
                                ],
                                [
                                    0.6366916683398491,
                                    0.31360784729584307,
                                    0.03329885345257904,
                                    0.01640163091172882,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.021847276464680394,
                                    0.044354690167740775,
                                    0.3081622017428915,
                                    0.6256358316246874,
                                ],
                                [
                                    0.03719888096212706,
                                    0.07552176319685502,
                                    0.2928105972454448,
                                    0.5944687585955731,
                                ],
                                [
                                    0.320316135605141,
                                    0.6503109425773411,
                                    0.009693342602430882,
                                    0.019679579215087006,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.004174589489585101,
                                    0.1333967159166805,
                                    0.8617825030938935,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.004509305204179549,
                                    0.06043647372396269,
                                    0.06492253899879422,
                                    0.8701316820730636,
                                ],
                                [
                                    0.008995370479011083,
                                    0.12056147166267886,
                                    0.060436473723962686,
                                    0.8100066841343474,
                                ],
                                [
                                    0.06847417691788633,
                                    0.9177329115430245,
                                    0.0009576672850874329,
                                    0.012835244254001657,
                                ],
                                [
                                    0.8617825030938935,
                                    0.004174589489585057,
                                    0.13339671591668045,
                                    0.0006461914998409577,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8845852104119851,
                                    0.004285048847906257,
                                    0.11059400859858888,
                                    0.0005357321415197574,
                                ],
                                [
                                    0.8461152733864915,
                                    0.06313061915299543,
                                    0.08445288241053475,
                                    0.006301225049978276,
                                ],
                                [
                                    0.8674375366440308,
                                    0.0647215225718689,
                                    0.06313061915299543,
                                    0.004710321631104814,
                                ],
                                [
                                    0.6051104691294324,
                                    0.04514869282432988,
                                    0.3254576866675939,
                                    0.02428315137864384,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.7155969984978721,
                                    0.016781101474829,
                                    0.2614898348257152,
                                    0.006132065201583779,
                                ],
                                [
                                    0.5555718601682373,
                                    0.27365160210092115,
                                    0.11441866162419075,
                                    0.056357876106650696,
                                ],
                                [
                                    0.6285380192557186,
                                    0.3095916987202738,
                                    0.04145250253670954,
                                    0.020417779487298063,
                                ],
                                [
                                    0.3860534901839117,
                                    0.19015390025961482,
                                    0.2839370316085164,
                                    0.13985557794795705,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5036283902385874,
                                    0.024571143793309564,
                                    0.44985293223485157,
                                    0.021947533733251368,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.15826941339295958,
                                    0.32132109489362387,
                                    0.1717400648146123,
                                    0.34866942689880426,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.3476909660581347,
                                    0.024016408686572115,
                                    0.5876979707283175,
                                    0.040594654526975575,
                                ],
                                [
                                    0.044769244016560676,
                                    0.6000248635068458,
                                    0.02466260018641309,
                                    0.33054329229018037,
                                ],
                                [
                                    0.06609150727410001,
                                    0.8857989117804657,
                                    0.0033403369288737563,
                                    0.04476924401656064,
                                ],
                                [
                                    0.02815730239012616,
                                    0.3773814343862215,
                                    0.04127454181284761,
                                    0.5531867214108047,
                                ],
                                [
                                    0.6204662230515879,
                                    0.0030056212142792692,
                                    0.374712995958986,
                                    0.0018151597751467452,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6432689303696795,
                                    0.0031160805726004694,
                                    0.35191028864089446,
                                    0.001704700416825545,
                                ],
                                [
                                    0.6091861299801529,
                                    0.04545278731482855,
                                    0.32138202581687336,
                                    0.023979056888145167,
                                ],
                                [
                                    0.6305083932376921,
                                    0.04704369073370201,
                                    0.3000597625593341,
                                    0.022388153469271706,
                                ],
                                [
                                    0.6106665740407051,
                                    0.045563246673149746,
                                    0.31990158175632105,
                                    0.023868597529823964,
                                ],
                                [
                                    0.4386018697840949,
                                    0.010285429507595284,
                                    0.5384849635394924,
                                    0.012627737168817495,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5450127383018141,
                                    0.012780816696709999,
                                    0.4320740950217733,
                                    0.010132349979702781,
                                ],
                                [
                                    0.4000006642914793,
                                    0.19702369841346767,
                                    0.2699898575009489,
                                    0.1329857797941042,
                                ],
                                [
                                    0.4729668233789605,
                                    0.23296379503282033,
                                    0.19702369841346765,
                                    0.09704568317475157,
                                ],
                                [
                                    0.40506683928133064,
                                    0.19951908560258239,
                                    0.2649236825110975,
                                    0.13049039260498949,
                                ],
                                [
                                    0.2108177929931427,
                                    0.010285429507595282,
                                    0.7426635294802963,
                                    0.03623324801896565,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.4216355859862854,
                                    0.020570859015190564,
                                    0.5318457364871536,
                                    0.02594781851137037,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.17728276249037855,
                                    0.3599223003862395,
                                    0.15272671571719332,
                                    0.31006822140618867,
                                ],
                                [
                                    0.04351305631228175,
                                    0.003005621214279275,
                                    0.8918758804741705,
                                    0.061605441999268415,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.3307675486464537,
                                    0.022847440411266323,
                                    0.6046213881399986,
                                    0.04176362280228137,
                                ],
                                [
                                    0.03223296324084667,
                                    0.4320059405482901,
                                    0.0371988809621271,
                                    0.4985622152487361,
                                ],
                                [
                                    0.05355522649838601,
                                    0.7177799888219099,
                                    0.01587661770458776,
                                    0.21278816697511635,
                                ],
                                [
                                    0.03371340730139894,
                                    0.45184775974527724,
                                    0.03571843690157483,
                                    0.478720396051749,
                                ],
                                [
                                    0.3056158674706069,
                                    0.001480444060552261,
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3284185747886984,
                                    0.0015909034188734612,
                                    0.6667606442218755,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.3000597625593341,
                                    0.022388153469271706,
                                    0.6305083932376921,
                                    0.04704369073370201,
                                ],
                                [
                                    0.32138202581687336,
                                    0.023979056888145167,
                                    0.6091861299801529,
                                    0.04545278731482855,
                                ],
                                [
                                    0.6179157393545944,
                                    0.04610412367774106,
                                    0.3126524164424318,
                                    0.02332772052523265,
                                ],
                                [
                                    0.21603704751088662,
                                    0.00506617498985139,
                                    0.7610497858127007,
                                    0.017846991686561387,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.3224479160286058,
                                    0.007561562178966105,
                                    0.6546389172949815,
                                    0.015351604497446674,
                                ],
                                [
                                    0.19702369841346767,
                                    0.09704568317475158,
                                    0.47296682337896045,
                                    0.23296379503282028,
                                ],
                                [
                                    0.2699898575009489,
                                    0.13298577979410423,
                                    0.40000066429147924,
                                    0.19702369841346765,
                                ],
                                [
                                    0.42987395019427116,
                                    0.21173803715777045,
                                    0.24011657159815697,
                                    0.11827144104980142,
                                ],
                                [
                                    0.10384008071698249,
                                    0.0050661749898513915,
                                    0.8496412417564566,
                                    0.04145250253670954,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.20208987340331908,
                                    0.41028609379907455,
                                    0.1279196048042528,
                                    0.2597044279933536,
                                ],
                                [
                                    0.02143272261586059,
                                    0.0014804440605522655,
                                    0.9139562141705917,
                                    0.06313061915299542,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.30868721495003254,
                                    0.021322263257539314,
                                    0.6267017218364197,
                                    0.04328879995600837,
                                ],
                                [
                                    0.015876617704587755,
                                    0.21278816697511632,
                                    0.05355522649838601,
                                    0.7177799888219099,
                                ],
                                [
                                    0.0371988809621271,
                                    0.4985622152487361,
                                    0.03223296324084667,
                                    0.43200594054829006,
                                ],
                                [
                                    0.0409625726152882,
                                    0.5490055189068115,
                                    0.02846927158768557,
                                    0.3815626368902147,
                                ],
                                [
                                    0.06429958742830123,
                                    0.0003114757852464733,
                                    0.9308796315822727,
                                    0.004509305204179541,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.08710229474639287,
                                    0.000421935143567674,
                                    0.9080769242641811,
                                    0.00439884584585834,
                                ],
                                [
                                    0.06313061915299548,
                                    0.004710321631104818,
                                    0.8674375366440308,
                                    0.0647215225718689,
                                ],
                                [
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                    0.8461152733864915,
                                    0.06313061915299543,
                                ],
                                [
                                    0.6234718442658671,
                                    0.046518677526560935,
                                    0.30709631153115907,
                                    0.02291316667641278,
                                ],
                                [
                                    0.04545278731482864,
                                    0.0010658902117323902,
                                    0.9316340460087587,
                                    0.02184727646468039,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.15186365583254768,
                                    0.0035612774008471028,
                                    0.8252231774910396,
                                    0.019351889275565675,
                                ],
                                [
                                    0.041452502536709596,
                                    0.020417779487298088,
                                    0.6285380192557185,
                                    0.30959169872027376,
                                ],
                                [
                                    0.11441866162419083,
                                    0.05635787610665073,
                                    0.5555718601682373,
                                    0.27365160210092115,
                                ],
                                [
                                    0.44888729929169013,
                                    0.22110322250073802,
                                    0.22110322250073802,
                                    0.10890625570683385,
                                ],
                                [
                                    0.021847276464680463,
                                    0.0010658902117323915,
                                    0.9316340460087587,
                                    0.04545278731482855,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.23266506945782317,
                                    0.011351319719327674,
                                    0.7208162530156159,
                                    0.03516735780723326,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.22110322250073802,
                                    0.44888729929169013,
                                    0.10890625570683385,
                                    0.22110322250073802,
                                ],
                                [
                                    0.004509305204179589,
                                    0.0003114757852464765,
                                    0.9308796315822727,
                                    0.06429958742830122,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.2917637975383516,
                                    0.020153294982233526,
                                    0.6436251392481007,
                                    0.044457768231314164,
                                ],
                                [
                                    0.0033403369288737554,
                                    0.04476924401656063,
                                    0.06609150727410001,
                                    0.8857989117804657,
                                ],
                                [
                                    0.024662600186413093,
                                    0.3305432922901804,
                                    0.044769244016560676,
                                    0.6000248635068458,
                                ],
                                [
                                    0.04651867752656097,
                                    0.6234718442658671,
                                    0.022913166676412796,
                                    0.30709631153115907,
                                ],
                                [
                                    0.8461152733864915,
                                    0.019841819196987055,
                                    0.1309715599370957,
                                    0.0030713474794257217,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8685034268557633,
                                    0.02036683240412813,
                                    0.108583406467824,
                                    0.002546334272284649,
                                ],
                                [
                                    0.8461152733864915,
                                    0.06313061915299543,
                                    0.08445288241053475,
                                    0.006301225049978276,
                                ],
                                [
                                    0.8674375366440308,
                                    0.0647215225718689,
                                    0.06313061915299543,
                                    0.004710321631104814,
                                ],
                                [
                                    0.6106665740407051,
                                    0.045563246673149746,
                                    0.31990158175632105,
                                    0.023868597529823964,
                                ],
                                [
                                    0.5555718601682373,
                                    0.06789998409762983,
                                    0.3355218841249287,
                                    0.041006271609204024,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.6526175433429888,
                                    0.0797605566297121,
                                    0.23847620095017721,
                                    0.029145699077121747,
                                ],
                                [
                                    0.5555718601682373,
                                    0.27365160210092115,
                                    0.11441866162419075,
                                    0.056357876106650696,
                                ],
                                [
                                    0.6285380192557186,
                                    0.3095916987202738,
                                    0.04145250253670954,
                                    0.020417779487298063,
                                ],
                                [
                                    0.4050668392813306,
                                    0.19951908560258236,
                                    0.2649236825110975,
                                    0.1304903926049895,
                                ],
                                [
                                    0.2391963274335293,
                                    0.06789998409762983,
                                    0.5397004500657328,
                                    0.15320323840310818,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.41141291493405635,
                                    0.11678661909784067,
                                    0.3674838625652056,
                                    0.10431660340289733,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.17728276249037853,
                                    0.3599223003862394,
                                    0.15272671571719335,
                                    0.3100682214061887,
                                ],
                                [
                                    0.04476924401656064,
                                    0.01984181919698706,
                                    0.6481344444522802,
                                    0.287254492334172,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.257557410991677,
                                    0.11414996375302978,
                                    0.43534627747716387,
                                    0.1929463477781293,
                                ],
                                [
                                    0.044769244016560676,
                                    0.6000248635068458,
                                    0.02466260018641309,
                                    0.33054329229018037,
                                ],
                                [
                                    0.06609150727410001,
                                    0.8857989117804657,
                                    0.0033403369288737563,
                                    0.04476924401656064,
                                ],
                                [
                                    0.033713407301398934,
                                    0.45184775974527713,
                                    0.035718436901574835,
                                    0.4787203960517491,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6315742834494246,
                                    0.014810727492855358,
                                    0.34551254987416263,
                                    0.00810243918355742,
                                ],
                                [
                                    0.6091861299801529,
                                    0.04545278731482855,
                                    0.32138202581687336,
                                    0.023979056888145167,
                                ],
                                [
                                    0.6305083932376921,
                                    0.04704369073370201,
                                    0.3000597625593341,
                                    0.022388153469271706,
                                ],
                                [
                                    0.6162226789519779,
                                    0.04597780052196962,
                                    0.3143454768450483,
                                    0.023454043681004094,
                                ],
                                [
                                    0.40000066429147924,
                                    0.048886635000210864,
                                    0.4910930800016869,
                                    0.060019620706622985,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.49704634746623083,
                                    0.060747207532293145,
                                    0.39404739682693535,
                                    0.04815904817454071,
                                ],
                                [
                                    0.4000006642914793,
                                    0.19702369841346767,
                                    0.2699898575009489,
                                    0.1329857797941042,
                                ],
                                [
                                    0.4729668233789605,
                                    0.23296379503282033,
                                    0.19702369841346765,
                                    0.09704568317475157,
                                ],
                                [
                                    0.4240801883787496,
                                    0.20888427094554995,
                                    0.24591033341367852,
                                    0.12112520726202192,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.3444331750010543,
                                    0.09777327000042171,
                                    0.4344636024982077,
                                    0.12332995250031631,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.19629611158779753,
                                    0.39852350587885504,
                                    0.13371336661977434,
                                    0.2714670159135731,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.24502113021596303,
                                    0.108593858841757,
                                    0.44788255825287787,
                                    0.19850245268940206,
                                ],
                                [
                                    0.03223296324084667,
                                    0.4320059405482901,
                                    0.0371988809621271,
                                    0.4985622152487361,
                                ],
                                [
                                    0.05355522649838601,
                                    0.7177799888219099,
                                    0.01587661770458776,
                                    0.21278816697511635,
                                ],
                                [
                                    0.039269512212671706,
                                    0.5263140851043328,
                                    0.030162331990302056,
                                    0.4042540706926934,
                                ],
                                [
                                    0.3000597625593341,
                                    0.007036548971825033,
                                    0.6770270707642532,
                                    0.015876617704587745,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3224479160286058,
                                    0.007561562178966105,
                                    0.6546389172949815,
                                    0.015351604497446674,
                                ],
                                [
                                    0.3000597625593341,
                                    0.022388153469271706,
                                    0.6305083932376921,
                                    0.04704369073370201,
                                ],
                                [
                                    0.32138202581687336,
                                    0.023979056888145167,
                                    0.6091861299801529,
                                    0.04545278731482855,
                                ],
                                [
                                    0.6234718442658671,
                                    0.046518677526560935,
                                    0.30709631153115907,
                                    0.02291316667641278,
                                ],
                                [
                                    0.19702369841346765,
                                    0.024079524087270352,
                                    0.6940700458796984,
                                    0.0848267316195635,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.2940693815882192,
                                    0.035940096619352636,
                                    0.5970243627049469,
                                    0.07296615908748122,
                                ],
                                [
                                    0.19702369841346767,
                                    0.09704568317475158,
                                    0.47296682337896045,
                                    0.23296379503282028,
                                ],
                                [
                                    0.2699898575009489,
                                    0.13298577979410423,
                                    0.40000066429147924,
                                    0.19702369841346765,
                                ],
                                [
                                    0.44888729929169013,
                                    0.22110322250073802,
                                    0.22110322250073802,
                                    0.10890625570683385,
                                ],
                                [
                                    0.08482673161956351,
                                    0.02407952408727036,
                                    0.6940700458796984,
                                    0.19702369841346767,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.22110322250073802,
                                    0.44888729929169013,
                                    0.10890625570683385,
                                    0.22110322250073802,
                                ],
                                [
                                    0.0158766177045878,
                                    0.0070365489718250546,
                                    0.6770270707642531,
                                    0.30005976255933403,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.2286647846797041,
                                    0.10134469352786774,
                                    0.46423890378913674,
                                    0.20575161800329134,
                                ],
                                [
                                    0.015876617704587755,
                                    0.21278816697511632,
                                    0.05355522649838601,
                                    0.7177799888219099,
                                ],
                                [
                                    0.0371988809621271,
                                    0.4985622152487361,
                                    0.03223296324084667,
                                    0.43200594054829006,
                                ],
                                [
                                    0.04651867752656097,
                                    0.6234718442658671,
                                    0.022913166676412796,
                                    0.30709631153115907,
                                ],
                                [
                                    0.06313061915299545,
                                    0.0014804440605522607,
                                    0.9139562141705918,
                                    0.021432722615860517,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.08551877262226723,
                                    0.0020054572676933354,
                                    0.89156806070132,
                                    0.020907709408719444,
                                ],
                                [
                                    0.06313061915299548,
                                    0.004710321631104818,
                                    0.8674375366440308,
                                    0.0647215225718689,
                                ],
                                [
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                    0.8461152733864915,
                                    0.06313061915299543,
                                ],
                                [
                                    0.6290279491771399,
                                    0.04693323137538081,
                                    0.30154020661988634,
                                    0.02249861282759291,
                                ],
                                [
                                    0.04145250253670962,
                                    0.0050661749898514,
                                    0.8496412417564565,
                                    0.10384008071698245,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.1384981857114611,
                                    0.016926747521933672,
                                    0.752595558581705,
                                    0.09197950818490018,
                                ],
                                [
                                    0.041452502536709596,
                                    0.020417779487298088,
                                    0.6285380192557185,
                                    0.30959169872027376,
                                ],
                                [
                                    0.11441866162419083,
                                    0.05635787610665073,
                                    0.5555718601682373,
                                    0.27365160210092115,
                                ],
                                [
                                    0.46790064838910905,
                                    0.2304684078437056,
                                    0.20208987340331908,
                                    0.0995410703638663,
                                ],
                                [
                                    0.01784699168656145,
                                    0.005066174989851407,
                                    0.7610497858127006,
                                    0.21603704751088662,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.19006357918708858,
                                    0.053952809990062266,
                                    0.5888331983121734,
                                    0.16715041251067575,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.24011657159815697,
                                    0.48748850478430567,
                                    0.0898929066094149,
                                    0.18250201700812246,
                                ],
                                [
                                    0.003340336928873789,
                                    0.0014804440605522763,
                                    0.6895633515399671,
                                    0.3056158674706068,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.2161285039039901,
                                    0.09578858861659496,
                                    0.4767751845648508,
                                    0.2113077229145641,
                                ],
                                [
                                    0.0033403369288737554,
                                    0.04476924401656063,
                                    0.06609150727410001,
                                    0.8857989117804657,
                                ],
                                [
                                    0.024662600186413093,
                                    0.3305432922901804,
                                    0.044769244016560676,
                                    0.6000248635068458,
                                ],
                                [
                                    0.05207478243783375,
                                    0.6979381696249228,
                                    0.017357061765140024,
                                    0.23262998617210345,
                                ],
                                [
                                    0.8256739138417495,
                                    0.04028317874172911,
                                    0.1278074086316896,
                                    0.006235498784831823,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8475211903064299,
                                    0.0413490689534615,
                                    0.10596013216700921,
                                    0.005169608573099435,
                                ],
                                [
                                    0.8461152733864915,
                                    0.06313061915299543,
                                    0.08445288241053475,
                                    0.006301225049978276,
                                ],
                                [
                                    0.8674375366440308,
                                    0.0647215225718689,
                                    0.06313061915299543,
                                    0.004710321631104814,
                                ],
                                [
                                    0.6179157393545944,
                                    0.04610412367774106,
                                    0.3126524164424318,
                                    0.02332772052523265,
                                ],
                                [
                                    0.4856202103602057,
                                    0.13785163390566152,
                                    0.2932765671390563,
                                    0.0832515885950765,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5704469419797692,
                                    0.16193115799293187,
                                    0.2084498355194928,
                                    0.05917206450780615,
                                ],
                                [
                                    0.5555718601682373,
                                    0.27365160210092115,
                                    0.11441866162419075,
                                    0.056357876106650696,
                                ],
                                [
                                    0.6285380192557186,
                                    0.3095916987202738,
                                    0.04145250253670954,
                                    0.020417779487298063,
                                ],
                                [
                                    0.42987395019427116,
                                    0.21173803715777045,
                                    0.24011657159815697,
                                    0.11827144104980142,
                                ],
                                [
                                    0.16924467762549758,
                                    0.13785163390566155,
                                    0.38186802308281226,
                                    0.3110356653860286,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.2910974717131896,
                                    0.23710206231870742,
                                    0.26001522899512025,
                                    0.21178523697298268,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.20208987340331908,
                                    0.41028609379907455,
                                    0.12791960480425282,
                                    0.2597044279933536,
                                ],
                                [
                                    0.024327884471818596,
                                    0.04028317874172911,
                                    0.3522002712623143,
                                    0.583188665524138,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.13995829228540066,
                                    0.23174908245930617,
                                    0.23656986344873224,
                                    0.39172276180656096,
                                ],
                                [
                                    0.044769244016560676,
                                    0.6000248635068458,
                                    0.02466260018641309,
                                    0.33054329229018037,
                                ],
                                [
                                    0.06609150727410001,
                                    0.8857989117804657,
                                    0.0033403369288737563,
                                    0.04476924401656064,
                                ],
                                [
                                    0.0409625726152882,
                                    0.5490055189068115,
                                    0.02846927158768557,
                                    0.3815626368902147,
                                ],
                                [
                                    0.5944687585955731,
                                    0.029003085670294096,
                                    0.35901256387786595,
                                    0.01751559185626684,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6163160350602535,
                                    0.030068975882026484,
                                    0.3371652874131856,
                                    0.01644970164453445,
                                ],
                                [
                                    0.6091861299801529,
                                    0.04545278731482855,
                                    0.32138202581687336,
                                    0.023979056888145167,
                                ],
                                [
                                    0.6305083932376921,
                                    0.04704369073370201,
                                    0.3000597625593341,
                                    0.022388153469271706,
                                ],
                                [
                                    0.6234718442658671,
                                    0.046518677526560935,
                                    0.30709631153115907,
                                    0.02291316667641278,
                                ],
                                [
                                    0.3496368708786442,
                                    0.09925042841304595,
                                    0.4292599066206178,
                                    0.12185279408769208,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.4344636024982077,
                                    0.12332995250031631,
                                    0.3444331750010543,
                                    0.09777327000042173,
                                ],
                                [
                                    0.4000006642914793,
                                    0.19702369841346767,
                                    0.2699898575009489,
                                    0.1329857797941042,
                                ],
                                [
                                    0.4729668233789605,
                                    0.23296379503282033,
                                    0.19702369841346765,
                                    0.09704568317475157,
                                ],
                                [
                                    0.44888729929169013,
                                    0.22110322250073802,
                                    0.22110322250073802,
                                    0.10890625570683385,
                                ],
                                [
                                    0.12185279408769206,
                                    0.09925042841304593,
                                    0.4292599066206178,
                                    0.3496368708786442,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.24370558817538412,
                                    0.19850085682609186,
                                    0.30740711253292574,
                                    0.25038644246559827,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.22110322250073802,
                                    0.44888729929169013,
                                    0.10890625570683385,
                                    0.22110322250073802,
                                ],
                                [
                                    0.017515591856266877,
                                    0.029003085670294148,
                                    0.359012563877866,
                                    0.5944687585955729,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.1331459996698489,
                                    0.22046898938787113,
                                    0.24338215606428398,
                                    0.403002854877996,
                                ],
                                [
                                    0.03223296324084667,
                                    0.4320059405482901,
                                    0.0371988809621271,
                                    0.4985622152487361,
                                ],
                                [
                                    0.05355522649838601,
                                    0.7177799888219099,
                                    0.01587661770458776,
                                    0.21278816697511635,
                                ],
                                [
                                    0.04651867752656097,
                                    0.6234718442658671,
                                    0.022913166676412796,
                                    0.30709631153115907,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3000597625593341,
                                    0.022388153469271706,
                                    0.6305083932376921,
                                    0.04704369073370201,
                                ],
                                [
                                    0.32138202581687336,
                                    0.023979056888145167,
                                    0.6091861299801529,
                                    0.04545278731482855,
                                ],
                                [
                                    0.6307210095797564,
                                    0.04705955453115225,
                                    0.2998471462172698,
                                    0.022372289671821463,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.19702369841346767,
                                    0.09704568317475158,
                                    0.47296682337896045,
                                    0.23296379503282028,
                                ],
                                [
                                    0.2699898575009489,
                                    0.13298577979410423,
                                    0.40000066429147924,
                                    0.19702369841346765,
                                ],
                                [
                                    0.4736944102046306,
                                    0.2333221740559261,
                                    0.19629611158779753,
                                    0.09668730415164578,
                                ],
                                [
                                    0.060019620706623,
                                    0.04888663500021088,
                                    0.4910930800016869,
                                    0.40000066429147924,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.24591033341367852,
                                    0.49925109270452517,
                                    0.08409914479389335,
                                    0.17073942908790296,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.015876617704587755,
                                    0.21278816697511632,
                                    0.05355522649838601,
                                    0.7177799888219099,
                                ],
                                [
                                    0.0371988809621271,
                                    0.4985622152487361,
                                    0.03223296324084667,
                                    0.43200594054829006,
                                ],
                                [
                                    0.05376784284045023,
                                    0.7206296034274016,
                                    0.015664001362523536,
                                    0.20993855236962472,
                                ],
                                [
                                    0.061605441999268436,
                                    0.0030056212142792697,
                                    0.8918758804741707,
                                    0.04351305631228167,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.0834527184639489,
                                    0.004071511426011661,
                                    0.8700286040094902,
                                    0.04244716610054927,
                                ],
                                [
                                    0.06313061915299548,
                                    0.004710321631104818,
                                    0.8674375366440308,
                                    0.0647215225718689,
                                ],
                                [
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                    0.8461152733864915,
                                    0.06313061915299543,
                                ],
                                [
                                    0.6362771144910292,
                                    0.04747410837997212,
                                    0.2942910413059971,
                                    0.021957735823001593,
                                ],
                                [
                                    0.03623324801896572,
                                    0.010285429507595303,
                                    0.7426635294802962,
                                    0.2108177929931427,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.12105997963852916,
                                    0.03436495359486564,
                                    0.6578367978607329,
                                    0.1867382689058724,
                                ],
                                [
                                    0.041452502536709596,
                                    0.020417779487298088,
                                    0.6285380192557185,
                                    0.30959169872027376,
                                ],
                                [
                                    0.11441866162419083,
                                    0.05635787610665073,
                                    0.5555718601682373,
                                    0.27365160210092115,
                                ],
                                [
                                    0.4927077593020496,
                                    0.24268735939889366,
                                    0.17728276249037858,
                                    0.08732211880867823,
                                ],
                                [
                                    0.012627737168817536,
                                    0.010285429507595319,
                                    0.5384849635394924,
                                    0.4386018697840948,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.1344805312565096,
                                    0.10953585792064124,
                                    0.41663216945180026,
                                    0.3393514413710489,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.2649236825110975,
                                    0.5378522981971408,
                                    0.06508579569647438,
                                    0.13213822359528737,
                                ],
                                [
                                    0.001815159775146765,
                                    0.003005621214279301,
                                    0.3747129959589861,
                                    0.6204662230515878,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.1174455675887288,
                                    0.1944715249318563,
                                    0.2590825881454041,
                                    0.42900031933401084,
                                ],
                                [
                                    0.0033403369288737554,
                                    0.04476924401656063,
                                    0.06609150727410001,
                                    0.8857989117804657,
                                ],
                                [
                                    0.024662600186413093,
                                    0.3305432922901804,
                                    0.044769244016560676,
                                    0.6000248635068458,
                                ],
                                [
                                    0.059323947751723005,
                                    0.7950959287864571,
                                    0.010107896451250764,
                                    0.1354722270105691,
                                ],
                                [
                                    0.8100066841343474,
                                    0.0559504084491311,
                                    0.12538225265210484,
                                    0.008660654764416586,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.831439406750208,
                                    0.05743085250968336,
                                    0.10394953003624433,
                                    0.007180210703864326,
                                ],
                                [
                                    0.8461152733864915,
                                    0.06313061915299543,
                                    0.08445288241053475,
                                    0.006301225049978276,
                                ],
                                [
                                    0.8674375366440308,
                                    0.0647215225718689,
                                    0.06313061915299543,
                                    0.004710321631104814,
                                ],
                                [
                                    0.6234718442658671,
                                    0.046518677526560935,
                                    0.30709631153115907,
                                    0.02291316667641278,
                                ],
                                [
                                    0.4320059405482901,
                                    0.19146590371757705,
                                    0.26089774792055076,
                                    0.11563040781358203,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.507467486824886,
                                    0.22491061314781494,
                                    0.18543620164395483,
                                    0.08218569838334411,
                                ],
                                [
                                    0.5555718601682373,
                                    0.27365160210092115,
                                    0.11441866162419075,
                                    0.056357876106650696,
                                ],
                                [
                                    0.6285380192557186,
                                    0.3095916987202738,
                                    0.04145250253670954,
                                    0.020417779487298063,
                                ],
                                [
                                    0.44888729929169013,
                                    0.22110322250073802,
                                    0.22110322250073802,
                                    0.10890625570683385,
                                ],
                                [
                                    0.11563040781358208,
                                    0.19146590371757705,
                                    0.2608977479205508,
                                    0.43200594054829006,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.19888199640865856,
                                    0.32931753762323845,
                                    0.17764615932547434,
                                    0.2941543066426286,
                                ],
                                [
                                    0.23919632743352928,
                                    0.4856202103602057,
                                    0.0908131507740426,
                                    0.18437031143222243,
                                ],
                                [
                                    0.3121624865210105,
                                    0.6337572737734625,
                                    0.01784699168656139,
                                    0.03623324801896565,
                                ],
                                [
                                    0.22110322250073802,
                                    0.44888729929169013,
                                    0.10890625570683385,
                                    0.22110322250073802,
                                ],
                                [
                                    0.008660654764416591,
                                    0.055950408449131114,
                                    0.12538225265210487,
                                    0.8100066841343474,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.04982473721894299,
                                    0.32188263752576385,
                                    0.08421817019757848,
                                    0.5440744550577147,
                                ],
                                [
                                    0.044769244016560676,
                                    0.6000248635068458,
                                    0.02466260018641309,
                                    0.33054329229018037,
                                ],
                                [
                                    0.06609150727410001,
                                    0.8857989117804657,
                                    0.0033403369288737563,
                                    0.04476924401656064,
                                ],
                                [
                                    0.04651867752656097,
                                    0.6234718442658671,
                                    0.022913166676412796,
                                    0.30709631153115907,
                                ],
                                [
                                    0.5831886655241381,
                                    0.040283178741729105,
                                    0.3522002712623142,
                                    0.024327884471818582,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6046213881399986,
                                    0.04176362280228137,
                                    0.3307675486464537,
                                    0.022847440411266323,
                                ],
                                [
                                    0.6091861299801529,
                                    0.04545278731482855,
                                    0.32138202581687336,
                                    0.023979056888145167,
                                ],
                                [
                                    0.6305083932376921,
                                    0.04704369073370201,
                                    0.3000597625593341,
                                    0.022388153469271706,
                                ],
                                [
                                    0.6290279491771399,
                                    0.04693323137538081,
                                    0.30154020661988634,
                                    0.02249861282759291,
                                ],
                                [
                                    0.3110356653860286,
                                    0.13785163390566152,
                                    0.38186802308281226,
                                    0.16924467762549755,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.3864972116626245,
                                    0.17129634333589944,
                                    0.30640647680621635,
                                    0.13579996819525963,
                                ],
                                [
                                    0.4000006642914793,
                                    0.19702369841346767,
                                    0.2699898575009489,
                                    0.1329857797941042,
                                ],
                                [
                                    0.4729668233789605,
                                    0.23296379503282033,
                                    0.19702369841346765,
                                    0.09704568317475157,
                                ],
                                [
                                    0.46790064838910905,
                                    0.2304684078437056,
                                    0.20208987340331908,
                                    0.0995410703638663,
                                ],
                                [
                                    0.08325158859507652,
                                    0.1378516339056615,
                                    0.29327656713905637,
                                    0.48562021036020564,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.16650317719015303,
                                    0.275703267811323,
                                    0.21002497854397986,
                                    0.3477685764545441,
                                ],
                                [
                                    0.17221658750052715,
                                    0.34963687087864415,
                                    0.15779289070704472,
                                    0.320353650913784,
                                ],
                                [
                                    0.24518274658800834,
                                    0.4977739342919009,
                                    0.0848267316195635,
                                    0.17221658750052715,
                                ],
                                [
                                    0.24011657159815697,
                                    0.48748850478430567,
                                    0.0898929066094149,
                                    0.18250201700812246,
                                ],
                                [
                                    0.0062354987848318374,
                                    0.04028317874172919,
                                    0.12780740863168963,
                                    0.8256739138417494,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.047399581239358224,
                                    0.3062154078183618,
                                    0.08664332617716325,
                                    0.5597416847651167,
                                ],
                                [
                                    0.03223296324084667,
                                    0.4320059405482901,
                                    0.0371988809621271,
                                    0.4985622152487361,
                                ],
                                [
                                    0.05355522649838601,
                                    0.7177799888219099,
                                    0.01587661770458776,
                                    0.21278816697511635,
                                ],
                                [
                                    0.05207478243783375,
                                    0.6979381696249228,
                                    0.017357061765140024,
                                    0.23262998617210345,
                                ],
                                [
                                    0.28725449233417205,
                                    0.019841819196987055,
                                    0.6481344444522802,
                                    0.044769244016560635,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.30868721495003254,
                                    0.021322263257539314,
                                    0.6267017218364197,
                                    0.04328879995600837,
                                ],
                                [
                                    0.3000597625593341,
                                    0.022388153469271706,
                                    0.6305083932376921,
                                    0.04704369073370201,
                                ],
                                [
                                    0.32138202581687336,
                                    0.023979056888145167,
                                    0.6091861299801529,
                                    0.04545278731482855,
                                ],
                                [
                                    0.6362771144910292,
                                    0.04747410837997212,
                                    0.2942910413059971,
                                    0.021957735823001593,
                                ],
                                [
                                    0.15320323840310818,
                                    0.06789998409762982,
                                    0.5397004500657328,
                                    0.23919632743352925,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.2286647846797041,
                                    0.10134469352786774,
                                    0.46423890378913674,
                                    0.20575161800329134,
                                ],
                                [
                                    0.19702369841346767,
                                    0.09704568317475158,
                                    0.47296682337896045,
                                    0.23296379503282028,
                                ],
                                [
                                    0.2699898575009489,
                                    0.13298577979410423,
                                    0.40000066429147924,
                                    0.19702369841346765,
                                ],
                                [
                                    0.4927077593020496,
                                    0.24268735939889366,
                                    0.17728276249037858,
                                    0.08732211880867823,
                                ],
                                [
                                    0.041006271609204045,
                                    0.06789998409762983,
                                    0.33552188412492884,
                                    0.5555718601682372,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.08482673161956351,
                                    0.17221658750052718,
                                    0.24518274658800834,
                                    0.4977739342919009,
                                ],
                                [
                                    0.15779289070704472,
                                    0.320353650913784,
                                    0.17221658750052715,
                                    0.34963687087864415,
                                ],
                                [
                                    0.2649236825110975,
                                    0.5378522981971408,
                                    0.06508579569647438,
                                    0.13213822359528737,
                                ],
                                [
                                    0.0030713474794257334,
                                    0.01984181919698712,
                                    0.13097155993709575,
                                    0.8461152733864914,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.04423542993395212,
                                    0.28577404827361974,
                                    0.08980747748256936,
                                    0.5801830443098588,
                                ],
                                [
                                    0.015876617704587755,
                                    0.21278816697511632,
                                    0.05355522649838601,
                                    0.7177799888219099,
                                ],
                                [
                                    0.0371988809621271,
                                    0.4985622152487361,
                                    0.03223296324084667,
                                    0.43200594054829006,
                                ],
                                [
                                    0.059323947751723005,
                                    0.7950959287864571,
                                    0.010107896451250764,
                                    0.1354722270105691,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.08186919633982323,
                                    0.005655033550137321,
                                    0.853519740446629,
                                    0.05895602966341037,
                                ],
                                [
                                    0.06313061915299548,
                                    0.004710321631104818,
                                    0.8674375366440308,
                                    0.0647215225718689,
                                ],
                                [
                                    0.08445288241053477,
                                    0.0063012250499782764,
                                    0.8461152733864915,
                                    0.06313061915299543,
                                ],
                                [
                                    0.6418332194023019,
                                    0.04788866222879199,
                                    0.28873493639472425,
                                    0.02154318197418172,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.10769450951744258,
                                    0.04773042371595221,
                                    0.5852091789513983,
                                    0.25936588781520686,
                                ],
                                [
                                    0.041452502536709596,
                                    0.020417779487298088,
                                    0.6285380192557185,
                                    0.30959169872027376,
                                ],
                                [
                                    0.11441866162419083,
                                    0.05635787610665073,
                                    0.5555718601682373,
                                    0.27365160210092115,
                                ],
                                [
                                    0.5117211083994685,
                                    0.25205254474186123,
                                    0.1582694133929596,
                                    0.07795693346571066,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.09187904098577504,
                                    0.1521373481913758,
                                    0.28464911474835786,
                                    0.4713344960744913,
                                ],
                                [
                                    0.01784699168656141,
                                    0.0362332480189657,
                                    0.3121624865210105,
                                    0.6337572737734625,
                                ],
                                [
                                    0.09081315077404262,
                                    0.1843703114322225,
                                    0.23919632743352925,
                                    0.48562021036020564,
                                ],
                                [
                                    0.28393703160851647,
                                    0.5764535036897563,
                                    0.046072446599055426,
                                    0.0935370181026718,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.004174589489585101,
                                    0.1333967159166805,
                                    0.8617825030938935,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.04181027395436735,
                                    0.2701068185662177,
                                    0.09223263346215413,
                                    0.5958502740172608,
                                ],
                                [
                                    0.0033403369288737554,
                                    0.04476924401656063,
                                    0.06609150727410001,
                                    0.8857989117804657,
                                ],
                                [
                                    0.024662600186413093,
                                    0.3305432922901804,
                                    0.044769244016560676,
                                    0.6000248635068458,
                                ],
                                [
                                    0.06488005266299578,
                                    0.8695622541455128,
                                    0.00455179153997799,
                                    0.06100590165151347,
                                ],
                                [
                                    0.8617825030938935,
                                    0.004174589489585057,
                                    0.13339671591668045,
                                    0.0006461914998409577,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9080769242641812,
                                    0.004398845845858341,
                                    0.08710229474639279,
                                    0.0004219351435676736,
                                ],
                                [
                                    0.8256739138417495,
                                    0.06160544199926843,
                                    0.1048942419552768,
                                    0.007826402203705283,
                                ],
                                [
                                    0.8689627137977578,
                                    0.06483531956982098,
                                    0.06160544199926842,
                                    0.00459652463315273,
                                ],
                                [
                                    0.26981875400370925,
                                    0.020131801818406795,
                                    0.660749401793317,
                                    0.04930004238456692,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.8252231774910396,
                                    0.019351889275565675,
                                    0.15186365583254768,
                                    0.0035612774008471028,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.09353701810267177,
                                    0.04607244659905541,
                                    0.5764535036897563,
                                    0.28393703160851647,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.720816253015616,
                                    0.03516735780723326,
                                    0.23266506945782311,
                                    0.011351319719327672,
                                ],
                                [
                                    0.16924467762549758,
                                    0.34360325190895286,
                                    0.1607648005820743,
                                    0.3263872698834753,
                                ],
                                [
                                    0.3173817410387544,
                                    0.6443534877873862,
                                    0.012627737168817495,
                                    0.025637034005041956,
                                ],
                                [
                                    -0.01865994869123235,
                                    -0.03788372633465729,
                                    0.3486694268988042,
                                    0.7078742481270854,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.6436251392481007,
                                    0.044457768231314164,
                                    0.2917637975383516,
                                    0.020153294982233526,
                                ],
                                [
                                    0.02432788447181862,
                                    0.32605722701534906,
                                    0.04510395973115515,
                                    0.6045109287816772,
                                ],
                                [
                                    0.06761668442782702,
                                    0.9062402713252077,
                                    0.0018151597751467471,
                                    0.024327884471818592,
                                ],
                                [
                                    -0.01436439085103707,
                                    -0.1925203752952414,
                                    0.08379623505401083,
                                    1.1230885310922676,
                                ],
                                [
                                    0.6204662230515879,
                                    0.0030056212142792692,
                                    0.374712995958986,
                                    0.0018151597751467452,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6667606442218755,
                                    0.0032298775705525535,
                                    0.3284185747886984,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.594468758595573,
                                    0.04435469016774077,
                                    0.33609939720145315,
                                    0.025077154035232946,
                                ],
                                [
                                    0.6377575585515814,
                                    0.047584567738293324,
                                    0.2928105972454448,
                                    0.021847276464680394,
                                ],
                                [
                                    0.2810988470751443,
                                    0.020973435673865903,
                                    0.6494693087218819,
                                    0.048458408529107815,
                                ],
                                [
                                    0.4386018697840949,
                                    0.010285429507595284,
                                    0.5384849635394924,
                                    0.012627737168817495,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.1321382235952874,
                                    0.06508579569647441,
                                    0.5378522981971408,
                                    0.2649236825110975,
                                ],
                                [
                                    0.2108177929931427,
                                    0.010285429507595282,
                                    0.7426635294802963,
                                    0.03623324801896565,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6388234487633139,
                                    0.03116707302911426,
                                    0.3146578737101252,
                                    0.015351604497446674,
                                ],
                                [
                                    0.12185279408769208,
                                    0.24738749182630274,
                                    0.20815668411987978,
                                    0.42260302996612537,
                                ],
                                [
                                    0.2699898575009489,
                                    0.5481377277047361,
                                    0.06001962070662299,
                                    0.12185279408769208,
                                ],
                                [
                                    0.0199412568013832,
                                    0.040485058556869624,
                                    0.31006822140618867,
                                    0.6295054632355586,
                                ],
                                [
                                    0.04351305631228175,
                                    0.003005621214279275,
                                    0.8918758804741705,
                                    0.061605441999268415,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.6267017218364197,
                                    0.04328879995600837,
                                    0.30868721495003254,
                                    0.021322263257539314,
                                ],
                                [
                                    0.01751559185626686,
                                    0.2347547036735855,
                                    0.05191625234670691,
                                    0.6958134521234407,
                                ],
                                [
                                    0.06080439181227527,
                                    0.8149377479834442,
                                    0.008627452390698502,
                                    0.11563040781358205,
                                ],
                                [
                                    -0.0030842977796020476,
                                    -0.04133765031939353,
                                    0.07251614198257582,
                                    0.9719058061164197,
                                ],
                                [
                                    0.3056158674706069,
                                    0.001480444060552261,
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35191028864089446,
                                    0.001704700416825545,
                                    0.6432689303696795,
                                    0.0031160805726004694,
                                ],
                                [
                                    0.2928105972454448,
                                    0.021847276464680394,
                                    0.6377575585515814,
                                    0.047584567738293324,
                                ],
                                [
                                    0.33609939720145315,
                                    0.025077154035232946,
                                    0.594468758595573,
                                    0.04435469016774077,
                                ],
                                [
                                    0.295816218459724,
                                    0.02207153282095367,
                                    0.6347519373373022,
                                    0.04736031138202004,
                                ],
                                [
                                    0.21603704751088662,
                                    0.00506617498985139,
                                    0.7610497858127007,
                                    0.017846991686561387,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.43207409502177324,
                                    0.01013234997970278,
                                    0.5450127383018141,
                                    0.012780816696709999,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.18250201700812246,
                                    0.0898929066094149,
                                    0.48748850478430567,
                                    0.24011657159815697,
                                ],
                                [
                                    0.10384008071698249,
                                    0.0050661749898513915,
                                    0.8496412417564566,
                                    0.04145250253670954,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.5318457364871536,
                                    0.02594781851137037,
                                    0.4216355859862855,
                                    0.020570859015190568,
                                ],
                                [
                                    0.06001962070662298,
                                    0.12185279408769206,
                                    0.2699898575009489,
                                    0.5481377277047361,
                                ],
                                [
                                    0.20815668411987978,
                                    0.42260302996612537,
                                    0.12185279408769208,
                                    0.24738749182630274,
                                ],
                                [
                                    0.0703050502142183,
                                    0.14273443760921112,
                                    0.2597044279933536,
                                    0.527256084183217,
                                ],
                                [
                                    0.02143272261586059,
                                    0.0014804440605522655,
                                    0.9139562141705917,
                                    0.06313061915299542,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.6046213881399986,
                                    0.04176362280228137,
                                    0.3307675486464537,
                                    0.022847440411266323,
                                ],
                                [
                                    0.0086274523906985,
                                    0.11563040781358204,
                                    0.06080439181227527,
                                    0.8149377479834442,
                                ],
                                [
                                    0.05191625234670691,
                                    0.6958134521234407,
                                    0.01751559185626686,
                                    0.2347547036735855,
                                ],
                                [
                                    0.011633073604977775,
                                    0.15591358655531118,
                                    0.05779877059799599,
                                    0.774654569241715,
                                ],
                                [
                                    0.06429958742830123,
                                    0.0003114757852464733,
                                    0.9308796315822727,
                                    0.004509305204179541,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.11059400859858896,
                                    0.0005357321415197579,
                                    0.884585210411985,
                                    0.004285048847906257,
                                ],
                                [
                                    0.061605441999268436,
                                    0.004596524633152731,
                                    0.8689627137977578,
                                    0.06483531956982098,
                                ],
                                [
                                    0.1048942419552768,
                                    0.007826402203705283,
                                    0.8256739138417495,
                                    0.06160544199926843,
                                ],
                                [
                                    0.30709631153115907,
                                    0.02291316667641278,
                                    0.6234718442658671,
                                    0.046518677526560935,
                                ],
                                [
                                    0.04545278731482864,
                                    0.0010658902117323902,
                                    0.9316340460087587,
                                    0.02184727646468039,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.26148983482571525,
                                    0.00613206520158378,
                                    0.7155969984978721,
                                    0.016781101474829,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.22110322250073802,
                                    0.10890625570683385,
                                    0.44888729929169013,
                                    0.22110322250073802,
                                ],
                                [
                                    0.021847276464680463,
                                    0.0010658902117323915,
                                    0.9316340460087587,
                                    0.04545278731482855,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.4498529322348516,
                                    0.02194753373325137,
                                    0.5036283902385874,
                                    0.024571143793309564,
                                ],
                                [
                                    0.012627737168817516,
                                    0.025637034005041998,
                                    0.3173817410387544,
                                    0.6443534877873861,
                                ],
                                [
                                    0.16076480058207432,
                                    0.32638726988347533,
                                    0.16924467762549755,
                                    0.3436032519089528,
                                ],
                                [
                                    0.10890625570683385,
                                    0.22110322250073802,
                                    0.22110322250073802,
                                    0.44888729929169013,
                                ],
                                [
                                    0.004509305204179589,
                                    0.0003114757852464765,
                                    0.9308796315822727,
                                    0.06429958742830122,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.5876979707283175,
                                    0.040594654526975575,
                                    0.3476909660581347,
                                    0.024016408686572115,
                                ],
                                [
                                    0.0018151597751467474,
                                    0.024327884471818596,
                                    0.06761668442782702,
                                    0.9062402713252077,
                                ],
                                [
                                    0.045103959731155156,
                                    0.6045109287816773,
                                    0.024327884471818613,
                                    0.32605722701534895,
                                ],
                                [
                                    0.022913166676412796,
                                    0.30709631153115907,
                                    0.04651867752656097,
                                    0.6234718442658671,
                                ],
                                [
                                    0.8461152733864915,
                                    0.019841819196987055,
                                    0.1309715599370957,
                                    0.0030713474794257217,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8915680607013201,
                                    0.020907709408719447,
                                    0.08551877262226715,
                                    0.0020054572676933336,
                                ],
                                [
                                    0.8256739138417495,
                                    0.06160544199926843,
                                    0.1048942419552768,
                                    0.007826402203705283,
                                ],
                                [
                                    0.8689627137977578,
                                    0.06483531956982098,
                                    0.06160544199926842,
                                    0.00459652463315273,
                                ],
                                [
                                    0.2810988470751443,
                                    0.020973435673865903,
                                    0.6494693087218819,
                                    0.048458408529107815,
                                ],
                                [
                                    0.5555718601682373,
                                    0.06789998409762983,
                                    0.3355218841249287,
                                    0.041006271609204024,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.752595558581705,
                                    0.09197950818490018,
                                    0.1384981857114611,
                                    0.016926747521933672,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.13213822359528732,
                                    0.06508579569647437,
                                    0.5378522981971408,
                                    0.2649236825110975,
                                ],
                                [
                                    0.2391963274335293,
                                    0.06789998409762983,
                                    0.5397004500657328,
                                    0.15320323840310818,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5888331983121735,
                                    0.16715041251067578,
                                    0.19006357918708855,
                                    0.05395280999006225,
                                ],
                                [
                                    0.16924467762549758,
                                    0.34360325190895286,
                                    0.1607648005820743,
                                    0.3263872698834753,
                                ],
                                [
                                    0.3173817410387544,
                                    0.6443534877873862,
                                    0.012627737168817495,
                                    0.025637034005041956,
                                ],
                                [
                                    0.019941256801383166,
                                    0.04048505855686955,
                                    0.3100682214061887,
                                    0.6295054632355586,
                                ],
                                [
                                    0.04476924401656064,
                                    0.01984181919698706,
                                    0.6481344444522802,
                                    0.287254492334172,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.4767751845648508,
                                    0.2113077229145641,
                                    0.2161285039039901,
                                    0.09578858861659496,
                                ],
                                [
                                    0.02432788447181862,
                                    0.32605722701534906,
                                    0.04510395973115515,
                                    0.6045109287816772,
                                ],
                                [
                                    0.06761668442782702,
                                    0.9062402713252077,
                                    0.0018151597751467471,
                                    0.024327884471818592,
                                ],
                                [
                                    -0.0030842977796020476,
                                    -0.04133765031939353,
                                    0.07251614198257582,
                                    0.9719058061164197,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.594468758595573,
                                    0.04435469016774077,
                                    0.33609939720145315,
                                    0.025077154035232946,
                                ],
                                [
                                    0.6377575585515814,
                                    0.047584567738293324,
                                    0.2928105972454448,
                                    0.021847276464680394,
                                ],
                                [
                                    0.2923789401465793,
                                    0.021815069529325,
                                    0.638189215650447,
                                    0.047616774673648714,
                                ],
                                [
                                    0.40000066429147924,
                                    0.048886635000210864,
                                    0.4910930800016869,
                                    0.060019620706622985,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.17073942908790296,
                                    0.08409914479389335,
                                    0.49925109270452517,
                                    0.24591033341367852,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.12185279408769208,
                                    0.24738749182630274,
                                    0.20815668411987978,
                                    0.42260302996612537,
                                ],
                                [
                                    0.2699898575009489,
                                    0.5481377277047361,
                                    0.06001962070662299,
                                    0.12185279408769208,
                                ],
                                [
                                    0.05854246229399875,
                                    0.11885384344839653,
                                    0.27146701591357314,
                                    0.5511366783440316,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.01751559185626686,
                                    0.2347547036735855,
                                    0.05191625234670691,
                                    0.6958134521234407,
                                ],
                                [
                                    0.06080439181227527,
                                    0.8149377479834442,
                                    0.008627452390698502,
                                    0.11563040781358205,
                                ],
                                [
                                    0.008195795291832975,
                                    0.10984507465645435,
                                    0.061236048911140796,
                                    0.8207230811405719,
                                ],
                                [
                                    0.3000597625593341,
                                    0.007036548971825033,
                                    0.6770270707642532,
                                    0.015876617704587745,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.34551254987416263,
                                    0.00810243918355742,
                                    0.6315742834494246,
                                    0.014810727492855358,
                                ],
                                [
                                    0.2928105972454448,
                                    0.021847276464680394,
                                    0.6377575585515814,
                                    0.047584567738293324,
                                ],
                                [
                                    0.33609939720145315,
                                    0.025077154035232946,
                                    0.594468758595573,
                                    0.04435469016774077,
                                ],
                                [
                                    0.30709631153115907,
                                    0.02291316667641278,
                                    0.6234718442658671,
                                    0.046518677526560935,
                                ],
                                [
                                    0.19702369841346765,
                                    0.024079524087270352,
                                    0.6940700458796984,
                                    0.0848267316195635,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.3940473968269353,
                                    0.048159048174540704,
                                    0.49704634746623083,
                                    0.060747207532293145,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.22110322250073802,
                                    0.10890625570683385,
                                    0.44888729929169013,
                                    0.22110322250073802,
                                ],
                                [
                                    0.08482673161956351,
                                    0.02407952408727036,
                                    0.6940700458796984,
                                    0.19702369841346767,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4344636024982077,
                                    0.12332995250031631,
                                    0.3444331750010543,
                                    0.09777327000042173,
                                ],
                                [
                                    0.06001962070662298,
                                    0.12185279408769206,
                                    0.2699898575009489,
                                    0.5481377277047361,
                                ],
                                [
                                    0.20815668411987978,
                                    0.42260302996612537,
                                    0.12185279408769208,
                                    0.24738749182630274,
                                ],
                                [
                                    0.10890625570683385,
                                    0.22110322250073802,
                                    0.22110322250073802,
                                    0.44888729929169013,
                                ],
                                [
                                    0.0158766177045878,
                                    0.0070365489718250546,
                                    0.6770270707642531,
                                    0.30005976255933403,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.44788255825287787,
                                    0.19850245268940206,
                                    0.24502113021596303,
                                    0.108593858841757,
                                ],
                                [
                                    0.0086274523906985,
                                    0.11563040781358204,
                                    0.06080439181227527,
                                    0.8149377479834442,
                                ],
                                [
                                    0.05191625234670691,
                                    0.6958134521234407,
                                    0.01751559185626686,
                                    0.2347547036735855,
                                ],
                                [
                                    0.022913166676412796,
                                    0.30709631153115907,
                                    0.04651867752656097,
                                    0.6234718442658671,
                                ],
                                [
                                    0.06313061915299545,
                                    0.0014804440605522607,
                                    0.9139562141705918,
                                    0.021432722615860517,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.10858340646782408,
                                    0.002546334272284651,
                                    0.8685034268557632,
                                    0.020366832404128128,
                                ],
                                [
                                    0.061605441999268436,
                                    0.004596524633152731,
                                    0.8689627137977578,
                                    0.06483531956982098,
                                ],
                                [
                                    0.1048942419552768,
                                    0.007826402203705283,
                                    0.8256739138417495,
                                    0.06160544199926843,
                                ],
                                [
                                    0.31837640460259414,
                                    0.023754800531871886,
                                    0.6121917511944321,
                                    0.04567704367110183,
                                ],
                                [
                                    0.04145250253670962,
                                    0.0050661749898514,
                                    0.8496412417564565,
                                    0.10384008071698245,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.23847620095017727,
                                    0.02914569907712175,
                                    0.6526175433429888,
                                    0.0797605566297121,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.2597044279933536,
                                    0.1279196048042528,
                                    0.41028609379907455,
                                    0.20208987340331908,
                                ],
                                [
                                    0.01784699168656145,
                                    0.005066174989851407,
                                    0.7610497858127006,
                                    0.21603704751088662,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.36748386256520565,
                                    0.10431660340289735,
                                    0.41141291493405635,
                                    0.11678661909784067,
                                ],
                                [
                                    0.012627737168817516,
                                    0.025637034005041998,
                                    0.3173817410387544,
                                    0.6443534877873861,
                                ],
                                [
                                    0.16076480058207432,
                                    0.32638726988347533,
                                    0.16924467762549755,
                                    0.3436032519089528,
                                ],
                                [
                                    0.1475074611994494,
                                    0.2994720073922649,
                                    0.18250201700812246,
                                    0.3705185144001632,
                                ],
                                [
                                    0.003340336928873789,
                                    0.0014804440605522763,
                                    0.6895633515399671,
                                    0.3056158674706068,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.43534627747716387,
                                    0.1929463477781293,
                                    0.257557410991677,
                                    0.11414996375302978,
                                ],
                                [
                                    0.0018151597751467474,
                                    0.024327884471818596,
                                    0.06761668442782702,
                                    0.9062402713252077,
                                ],
                                [
                                    0.045103959731155156,
                                    0.6045109287816773,
                                    0.024327884471818613,
                                    0.32605722701534895,
                                ],
                                [
                                    0.03419325974784782,
                                    0.45827903650700696,
                                    0.03523858445512595,
                                    0.47228911929001927,
                                ],
                                [
                                    0.8256739138417495,
                                    0.04028317874172911,
                                    0.1278074086316896,
                                    0.006235498784831823,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8700286040094903,
                                    0.04244716610054928,
                                    0.08345271846394882,
                                    0.004071511426011657,
                                ],
                                [
                                    0.8256739138417495,
                                    0.06160544199926843,
                                    0.1048942419552768,
                                    0.007826402203705283,
                                ],
                                [
                                    0.8689627137977578,
                                    0.06483531956982098,
                                    0.06160544199926842,
                                    0.00459652463315273,
                                ],
                                [
                                    0.295816218459724,
                                    0.02207153282095367,
                                    0.6347519373373022,
                                    0.04736031138202004,
                                ],
                                [
                                    0.4856202103602057,
                                    0.13785163390566152,
                                    0.2932765671390563,
                                    0.0832515885950765,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.6578367978607329,
                                    0.1867382689058724,
                                    0.12105997963852916,
                                    0.03436495359486564,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.18250201700812246,
                                    0.0898929066094149,
                                    0.48748850478430567,
                                    0.24011657159815697,
                                ],
                                [
                                    0.16924467762549758,
                                    0.13785163390566155,
                                    0.38186802308281226,
                                    0.3110356653860286,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.4166321694518003,
                                    0.33935144137104895,
                                    0.13448053125650958,
                                    0.10953585792064123,
                                ],
                                [
                                    0.16924467762549758,
                                    0.34360325190895286,
                                    0.1607648005820743,
                                    0.3263872698834753,
                                ],
                                [
                                    0.3173817410387544,
                                    0.6443534877873862,
                                    0.012627737168817495,
                                    0.025637034005041956,
                                ],
                                [
                                    0.07030505021421826,
                                    0.14273443760921103,
                                    0.2597044279933536,
                                    0.5272560841832171,
                                ],
                                [
                                    0.024327884471818596,
                                    0.04028317874172911,
                                    0.3522002712623143,
                                    0.583188665524138,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.2590825881454041,
                                    0.42900031933401084,
                                    0.1174455675887288,
                                    0.1944715249318563,
                                ],
                                [
                                    0.02432788447181862,
                                    0.32605722701534906,
                                    0.04510395973115515,
                                    0.6045109287816772,
                                ],
                                [
                                    0.06761668442782702,
                                    0.9062402713252077,
                                    0.0018151597751467471,
                                    0.024327884471818592,
                                ],
                                [
                                    0.011633073604977775,
                                    0.15591358655531118,
                                    0.05779877059799599,
                                    0.774654569241715,
                                ],
                                [
                                    0.5944687585955731,
                                    0.029003085670294096,
                                    0.35901256387786595,
                                    0.01751559185626684,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6388234487633139,
                                    0.03116707302911426,
                                    0.3146578737101252,
                                    0.015351604497446674,
                                ],
                                [
                                    0.594468758595573,
                                    0.04435469016774077,
                                    0.33609939720145315,
                                    0.025077154035232946,
                                ],
                                [
                                    0.6377575585515814,
                                    0.047584567738293324,
                                    0.2928105972454448,
                                    0.021847276464680394,
                                ],
                                [
                                    0.30709631153115907,
                                    0.02291316667641278,
                                    0.6234718442658671,
                                    0.046518677526560935,
                                ],
                                [
                                    0.3496368708786442,
                                    0.09925042841304595,
                                    0.4292599066206178,
                                    0.12185279408769208,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.22110322250073802,
                                    0.10890625570683385,
                                    0.44888729929169013,
                                    0.22110322250073802,
                                ],
                                [
                                    0.12185279408769206,
                                    0.09925042841304593,
                                    0.4292599066206178,
                                    0.3496368708786442,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.3692402859139948,
                                    0.3007502358784333,
                                    0.18187241479431507,
                                    0.1481370634132568,
                                ],
                                [
                                    0.12185279408769208,
                                    0.24738749182630274,
                                    0.20815668411987978,
                                    0.42260302996612537,
                                ],
                                [
                                    0.2699898575009489,
                                    0.5481377277047361,
                                    0.06001962070662299,
                                    0.12185279408769208,
                                ],
                                [
                                    0.10890625570683385,
                                    0.22110322250073802,
                                    0.22110322250073802,
                                    0.44888729929169013,
                                ],
                                [
                                    0.017515591856266877,
                                    0.029003085670294148,
                                    0.359012563877866,
                                    0.5944687585955729,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.25227029552985236,
                                    0.41772022626257577,
                                    0.12425786020428056,
                                    0.2057516180032913,
                                ],
                                [
                                    0.01751559185626686,
                                    0.2347547036735855,
                                    0.05191625234670691,
                                    0.6958134521234407,
                                ],
                                [
                                    0.06080439181227527,
                                    0.8149377479834442,
                                    0.008627452390698502,
                                    0.11563040781358205,
                                ],
                                [
                                    0.022913166676412796,
                                    0.30709631153115907,
                                    0.04651867752656097,
                                    0.6234718442658671,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3371652874131856,
                                    0.01644970164453445,
                                    0.6163160350602535,
                                    0.030068975882026484,
                                ],
                                [
                                    0.2928105972454448,
                                    0.021847276464680394,
                                    0.6377575585515814,
                                    0.047584567738293324,
                                ],
                                [
                                    0.33609939720145315,
                                    0.025077154035232946,
                                    0.594468758595573,
                                    0.04435469016774077,
                                ],
                                [
                                    0.3218136829157389,
                                    0.024011263823500557,
                                    0.6087544728812874,
                                    0.045420580379473156,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.3444331750010543,
                                    0.09777327000042171,
                                    0.4344636024982077,
                                    0.12332995250031631,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.2714670159135731,
                                    0.13371336661977434,
                                    0.39852350587885504,
                                    0.19629611158779753,
                                ],
                                [
                                    0.060019620706623,
                                    0.04888663500021088,
                                    0.4910930800016869,
                                    0.40000066429147924,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.30740711253292574,
                                    0.25038644246559827,
                                    0.24370558817538415,
                                    0.1985008568260919,
                                ],
                                [
                                    0.06001962070662298,
                                    0.12185279408769206,
                                    0.2699898575009489,
                                    0.5481377277047361,
                                ],
                                [
                                    0.20815668411987978,
                                    0.42260302996612537,
                                    0.12185279408769208,
                                    0.24738749182630274,
                                ],
                                [
                                    0.15927004911966897,
                                    0.3233526015530795,
                                    0.1707394290879029,
                                    0.34663792023934864,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.24338215606428398,
                                    0.403002854877996,
                                    0.1331459996698489,
                                    0.22046898938787113,
                                ],
                                [
                                    0.0086274523906985,
                                    0.11563040781358204,
                                    0.06080439181227527,
                                    0.8149377479834442,
                                ],
                                [
                                    0.05191625234670691,
                                    0.6958134521234407,
                                    0.01751559185626686,
                                    0.2347547036735855,
                                ],
                                [
                                    0.03763053806099262,
                                    0.5043475484058638,
                                    0.03180130614198115,
                                    0.42622060739116246,
                                ],
                                [
                                    0.061605441999268436,
                                    0.0030056212142792697,
                                    0.8918758804741707,
                                    0.04351305631228167,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.1059601321670093,
                                    0.0051696085730994394,
                                    0.8475211903064298,
                                    0.04134906895346149,
                                ],
                                [
                                    0.061605441999268436,
                                    0.004596524633152731,
                                    0.8689627137977578,
                                    0.06483531956982098,
                                ],
                                [
                                    0.1048942419552768,
                                    0.007826402203705283,
                                    0.8256739138417495,
                                    0.06160544199926843,
                                ],
                                [
                                    0.3330937759871739,
                                    0.024852897678959658,
                                    0.5974743798098524,
                                    0.044578946524014056,
                                ],
                                [
                                    0.03623324801896572,
                                    0.010285429507595303,
                                    0.7426635294802962,
                                    0.2108177929931427,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.20844983551949287,
                                    0.05917206450780616,
                                    0.5704469419797692,
                                    0.16193115799293187,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.3100682214061886,
                                    0.15272671571719332,
                                    0.3599223003862395,
                                    0.17728276249037855,
                                ],
                                [
                                    0.012627737168817536,
                                    0.010285429507595319,
                                    0.5384849635394924,
                                    0.4386018697840948,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.26001522899512025,
                                    0.2117852369729827,
                                    0.2910974717131896,
                                    0.23710206231870742,
                                ],
                                [
                                    0.012627737168817516,
                                    0.025637034005041998,
                                    0.3173817410387544,
                                    0.6443534877873861,
                                ],
                                [
                                    0.16076480058207432,
                                    0.32638726988347533,
                                    0.16924467762549755,
                                    0.3436032519089528,
                                ],
                                [
                                    0.1978712546122845,
                                    0.4017213864446064,
                                    0.13213822359528737,
                                    0.2682691353478217,
                                ],
                                [
                                    0.001815159775146765,
                                    0.003005621214279301,
                                    0.3747129959589861,
                                    0.6204662230515878,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.23656986344873224,
                                    0.39172276180656096,
                                    0.13995829228540066,
                                    0.23174908245930617,
                                ],
                                [
                                    0.0018151597751467474,
                                    0.024327884471818596,
                                    0.06761668442782702,
                                    0.9062402713252077,
                                ],
                                [
                                    0.045103959731155156,
                                    0.6045109287816773,
                                    0.024327884471818613,
                                    0.32605722701534895,
                                ],
                                [
                                    0.04891063113242764,
                                    0.6555302733817117,
                                    0.02052121307054613,
                                    0.2750378824153146,
                                ],
                                [
                                    0.8100066841343474,
                                    0.0559504084491311,
                                    0.12538225265210484,
                                    0.008660654764416586,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8535197404466291,
                                    0.058956029663410375,
                                    0.08186919633982316,
                                    0.005655033550137316,
                                ],
                                [
                                    0.8256739138417495,
                                    0.06160544199926843,
                                    0.1048942419552768,
                                    0.007826402203705283,
                                ],
                                [
                                    0.8689627137977578,
                                    0.06483531956982098,
                                    0.06160544199926842,
                                    0.00459652463315273,
                                ],
                                [
                                    0.30709631153115907,
                                    0.02291316667641278,
                                    0.6234718442658671,
                                    0.046518677526560935,
                                ],
                                [
                                    0.4320059405482901,
                                    0.19146590371757705,
                                    0.26089774792055076,
                                    0.11563040781358203,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5852091789513983,
                                    0.25936588781520686,
                                    0.10769450951744258,
                                    0.04773042371595221,
                                ],
                                [
                                    0.4856202103602057,
                                    0.23919632743352928,
                                    0.18437031143222243,
                                    0.0908131507740426,
                                ],
                                [
                                    0.6337572737734625,
                                    0.3121624865210105,
                                    0.03623324801896565,
                                    0.01784699168656139,
                                ],
                                [
                                    0.22110322250073802,
                                    0.10890625570683385,
                                    0.44888729929169013,
                                    0.22110322250073802,
                                ],
                                [
                                    0.11563040781358208,
                                    0.19146590371757705,
                                    0.2608977479205508,
                                    0.43200594054829006,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.2846491147483579,
                                    0.47133449607449135,
                                    0.09187904098577501,
                                    0.15213734819137578,
                                ],
                                [
                                    0.16924467762549758,
                                    0.34360325190895286,
                                    0.1607648005820743,
                                    0.3263872698834753,
                                ],
                                [
                                    0.3173817410387544,
                                    0.6443534877873862,
                                    0.012627737168817495,
                                    0.025637034005041956,
                                ],
                                [
                                    0.10890625570683385,
                                    0.22110322250073802,
                                    0.22110322250073802,
                                    0.44888729929169013,
                                ],
                                [
                                    0.008660654764416591,
                                    0.055950408449131114,
                                    0.12538225265210487,
                                    0.8100066841343474,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.09223263346215413,
                                    0.5958502740172608,
                                    0.04181027395436735,
                                    0.2701068185662177,
                                ],
                                [
                                    0.02432788447181862,
                                    0.32605722701534906,
                                    0.04510395973115515,
                                    0.6045109287816772,
                                ],
                                [
                                    0.06761668442782702,
                                    0.9062402713252077,
                                    0.0018151597751467471,
                                    0.024327884471818592,
                                ],
                                [
                                    0.022913166676412796,
                                    0.30709631153115907,
                                    0.04651867752656097,
                                    0.6234718442658671,
                                ],
                                [
                                    0.5831886655241381,
                                    0.040283178741729105,
                                    0.3522002712623142,
                                    0.024327884471818582,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6267017218364197,
                                    0.04328879995600837,
                                    0.30868721495003254,
                                    0.021322263257539314,
                                ],
                                [
                                    0.594468758595573,
                                    0.04435469016774077,
                                    0.33609939720145315,
                                    0.025077154035232946,
                                ],
                                [
                                    0.6377575585515814,
                                    0.047584567738293324,
                                    0.2928105972454448,
                                    0.021847276464680394,
                                ],
                                [
                                    0.31837640460259414,
                                    0.023754800531871886,
                                    0.6121917511944321,
                                    0.04567704367110183,
                                ],
                                [
                                    0.3110356653860286,
                                    0.13785163390566152,
                                    0.38186802308281226,
                                    0.16924467762549755,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.34963687087864415,
                                    0.17221658750052715,
                                    0.320353650913784,
                                    0.15779289070704472,
                                ],
                                [
                                    0.4977739342919009,
                                    0.24518274658800834,
                                    0.17221658750052715,
                                    0.0848267316195635,
                                ],
                                [
                                    0.2597044279933536,
                                    0.1279196048042528,
                                    0.41028609379907455,
                                    0.20208987340331908,
                                ],
                                [
                                    0.08325158859507652,
                                    0.1378516339056615,
                                    0.29327656713905637,
                                    0.48562021036020564,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.25227029552985236,
                                    0.41772022626257577,
                                    0.12425786020428056,
                                    0.2057516180032913,
                                ],
                                [
                                    0.12185279408769208,
                                    0.24738749182630274,
                                    0.20815668411987978,
                                    0.42260302996612537,
                                ],
                                [
                                    0.2699898575009489,
                                    0.5481377277047361,
                                    0.06001962070662299,
                                    0.12185279408769208,
                                ],
                                [
                                    0.1475074611994494,
                                    0.2994720073922649,
                                    0.18250201700812246,
                                    0.3705185144001632,
                                ],
                                [
                                    0.0062354987848318374,
                                    0.04028317874172919,
                                    0.12780740863168963,
                                    0.8256739138417494,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.08980747748256936,
                                    0.5801830443098588,
                                    0.04423542993395212,
                                    0.28577404827361974,
                                ],
                                [
                                    0.01751559185626686,
                                    0.2347547036735855,
                                    0.05191625234670691,
                                    0.6958134521234407,
                                ],
                                [
                                    0.06080439181227527,
                                    0.8149377479834442,
                                    0.008627452390698502,
                                    0.11563040781358205,
                                ],
                                [
                                    0.03419325974784782,
                                    0.45827903650700696,
                                    0.03523858445512595,
                                    0.47228911929001927,
                                ],
                                [
                                    0.28725449233417205,
                                    0.019841819196987055,
                                    0.6481344444522802,
                                    0.044769244016560635,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3307675486464537,
                                    0.022847440411266323,
                                    0.6046213881399986,
                                    0.04176362280228137,
                                ],
                                [
                                    0.2928105972454448,
                                    0.021847276464680394,
                                    0.6377575585515814,
                                    0.047584567738293324,
                                ],
                                [
                                    0.33609939720145315,
                                    0.025077154035232946,
                                    0.594468758595573,
                                    0.04435469016774077,
                                ],
                                [
                                    0.3330937759871739,
                                    0.024852897678959658,
                                    0.5974743798098524,
                                    0.044578946524014056,
                                ],
                                [
                                    0.15320323840310818,
                                    0.06789998409762982,
                                    0.5397004500657328,
                                    0.23919632743352925,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.30640647680621635,
                                    0.13579996819525963,
                                    0.3864972116626245,
                                    0.17129634333589944,
                                ],
                                [
                                    0.17221658750052718,
                                    0.08482673161956351,
                                    0.4977739342919009,
                                    0.24518274658800834,
                                ],
                                [
                                    0.320353650913784,
                                    0.15779289070704472,
                                    0.34963687087864415,
                                    0.17221658750052715,
                                ],
                                [
                                    0.3100682214061886,
                                    0.15272671571719332,
                                    0.3599223003862395,
                                    0.17728276249037855,
                                ],
                                [
                                    0.041006271609204045,
                                    0.06789998409762983,
                                    0.33552188412492884,
                                    0.5555718601682372,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.21002497854397986,
                                    0.3477685764545441,
                                    0.16650317719015303,
                                    0.275703267811323,
                                ],
                                [
                                    0.06001962070662298,
                                    0.12185279408769206,
                                    0.2699898575009489,
                                    0.5481377277047361,
                                ],
                                [
                                    0.20815668411987978,
                                    0.42260302996612537,
                                    0.12185279408769208,
                                    0.24738749182630274,
                                ],
                                [
                                    0.1978712546122845,
                                    0.4017213864446064,
                                    0.13213822359528737,
                                    0.2682691353478217,
                                ],
                                [
                                    0.0030713474794257334,
                                    0.01984181919698712,
                                    0.13097155993709575,
                                    0.8461152733864914,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.08664332617716325,
                                    0.5597416847651167,
                                    0.047399581239358224,
                                    0.3062154078183618,
                                ],
                                [
                                    0.0086274523906985,
                                    0.11563040781358204,
                                    0.06080439181227527,
                                    0.8149377479834442,
                                ],
                                [
                                    0.05191625234670691,
                                    0.6958134521234407,
                                    0.01751559185626686,
                                    0.2347547036735855,
                                ],
                                [
                                    0.04891063113242764,
                                    0.6555302733817117,
                                    0.02052121307054613,
                                    0.2750378824153146,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.1039495300362444,
                                    0.007180210703864331,
                                    0.8314394067502079,
                                    0.057430852509683356,
                                ],
                                [
                                    0.061605441999268436,
                                    0.004596524633152731,
                                    0.8689627137977578,
                                    0.06483531956982098,
                                ],
                                [
                                    0.1048942419552768,
                                    0.007826402203705283,
                                    0.8256739138417495,
                                    0.06160544199926843,
                                ],
                                [
                                    0.3443738690586089,
                                    0.025694531534418766,
                                    0.5861942867384173,
                                    0.04373731266855495,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.18543620164395488,
                                    0.08218569838334412,
                                    0.507467486824886,
                                    0.22491061314781494,
                                ],
                                [
                                    0.0362332480189657,
                                    0.01784699168656141,
                                    0.6337572737734625,
                                    0.3121624865210105,
                                ],
                                [
                                    0.1843703114322225,
                                    0.09081315077404262,
                                    0.48562021036020564,
                                    0.23919632743352925,
                                ],
                                [
                                    0.34866942689880426,
                                    0.1717400648146123,
                                    0.32132109489362387,
                                    0.15826941339295958,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.17764615932547434,
                                    0.29415430664262865,
                                    0.19888199640865856,
                                    0.32931753762323845,
                                ],
                                [
                                    0.012627737168817516,
                                    0.025637034005041998,
                                    0.3173817410387544,
                                    0.6443534877873861,
                                ],
                                [
                                    0.16076480058207432,
                                    0.32638726988347533,
                                    0.16924467762549755,
                                    0.3436032519089528,
                                ],
                                [
                                    0.23647246010490006,
                                    0.4800901713361333,
                                    0.09353701810267179,
                                    0.18990035045629478,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.004174589489585101,
                                    0.1333967159166805,
                                    0.8617825030938935,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.08421817019757848,
                                    0.5440744550577147,
                                    0.04982473721894299,
                                    0.32188263752576385,
                                ],
                                [
                                    0.0018151597751467474,
                                    0.024327884471818596,
                                    0.06761668442782702,
                                    0.9062402713252077,
                                ],
                                [
                                    0.045103959731155156,
                                    0.6045109287816773,
                                    0.024327884471818613,
                                    0.32605722701534895,
                                ],
                                [
                                    0.06019072420386266,
                                    0.8067129983575595,
                                    0.009241119999111112,
                                    0.12385515743946678,
                                ],
                                [
                                    0.8617825030938935,
                                    0.004174589489585057,
                                    0.13339671591668045,
                                    0.0006461914998409577,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.8100066841343474,
                                    0.06043647372396264,
                                    0.1205614716626788,
                                    0.008995370479011071,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879417,
                                    0.06043647372396264,
                                    0.004509305204179541,
                                ],
                                [
                                    0.01283524425400169,
                                    0.0009576672850874345,
                                    0.9177329115430245,
                                    0.06847417691788628,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410027,
                                    0.0015909034188734614,
                                ],
                                [
                                    0.4320059405482901,
                                    0.21278816697511638,
                                    0.23798458124413796,
                                    0.11722131123245548,
                                ],
                                [
                                    0.6377575585515814,
                                    0.3141328605029841,
                                    0.03223296324084665,
                                    0.01587661770458775,
                                ],
                                [
                                    -0.13066151190530173,
                                    -0.06435842890780485,
                                    0.8006520336977299,
                                    0.3943679071153767,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.0662019666324212,
                                    0.003229877570552555,
                                ],
                                [
                                    0.1156304078135821,
                                    0.23475470367358556,
                                    0.21437907039398976,
                                    0.43523581811884254,
                                ],
                                [
                                    0.32138202581687336,
                                    0.6524749299361613,
                                    0.008627452390698495,
                                    0.017515591856266843,
                                ],
                                [
                                    -0.1542670227554499,
                                    -0.3131953773954266,
                                    0.48427650096302177,
                                    0.9831858991878547,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                ],
                                [
                                    0.008660654764416595,
                                    0.11607540638784729,
                                    0.06077118943855717,
                                    0.8144927494091789,
                                ],
                                [
                                    0.0687856527031328,
                                    0.9219075010326095,
                                    0.0006461914998409586,
                                    0.00866065476441659,
                                ],
                                [
                                    -0.04695503797012005,
                                    -0.6293202145329522,
                                    0.11638688217309383,
                                    1.5598883703299784,
                                ],
                                [
                                    0.6204662230515879,
                                    0.0030056212142792692,
                                    0.374712995958986,
                                    0.0018151597751467452,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6847658104798892,
                                    0.0033170969995257424,
                                    0.3104134085306848,
                                    0.0015036839899002718,
                                ],
                                [
                                    0.583188665524138,
                                    0.04351305631228166,
                                    0.34737949027288817,
                                    0.025918787890692047,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711319,
                                    0.287254492334172,
                                    0.021432722615860517,
                                ],
                                [
                                    0.028502473961403752,
                                    0.0021266355603932266,
                                    0.9020656818356225,
                                    0.06730520864258048,
                                ],
                                [
                                    0.4386018697840949,
                                    0.010285429507595284,
                                    0.5384849635394924,
                                    0.012627737168817495,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.738661632343429,
                                    0.017321978479420318,
                                    0.23842520098015835,
                                    0.0055911881969924635,
                                ],
                                [
                                    0.3110356653860286,
                                    0.1532032384031082,
                                    0.3589548564063995,
                                    0.17680623980446367,
                                ],
                                [
                                    0.51678728338932,
                                    0.25454793193097597,
                                    0.15320323840310818,
                                    0.07546154627659593,
                                ],
                                [
                                    -0.07704724209338629,
                                    -0.03795026844939201,
                                    0.7470377638858144,
                                    0.3679597466569639,
                                ],
                                [
                                    0.2108177929931427,
                                    0.010285429507595282,
                                    0.7426635294802963,
                                    0.03623324801896565,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.8052865515887159,
                                    0.03928851517788938,
                                    0.14819477088472327,
                                    0.007230162348671557,
                                ],
                                [
                                    0.08325158859507653,
                                    0.16901870693477583,
                                    0.24675788961249534,
                                    0.5009718148576523,
                                ],
                                [
                                    0.28900320659836787,
                                    0.5867389331973516,
                                    0.04100627160920404,
                                    0.08325158859507652,
                                ],
                                [
                                    -0.10065275294353439,
                                    -0.20434682916005917,
                                    0.43066223115110625,
                                    0.8743373509524873,
                                ],
                                [
                                    0.04351305631228175,
                                    0.003005621214279275,
                                    0.8918758804741705,
                                    0.061605441999268415,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.853519740446629,
                                    0.05895602966341037,
                                    0.08186919633982322,
                                    0.00565503355013732,
                                ],
                                [
                                    0.00623549878483183,
                                    0.08357197869773751,
                                    0.06319634541814194,
                                    0.8469961770992888,
                                ],
                                [
                                    0.06636049672354805,
                                    0.8894040733424998,
                                    0.0030713474794257256,
                                    0.04116408245452639,
                                ],
                                [
                                    -0.03128780826271806,
                                    -0.4193383939054508,
                                    0.10071965246569183,
                                    1.349906549702477,
                                ],
                                [
                                    0.3056158674706069,
                                    0.001480444060552261,
                                    0.6895633515399671,
                                    0.0033403369288737537,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3699154548989081,
                                    0.0017919198457987341,
                                    0.6252637641116658,
                                    0.00302886114362728,
                                ],
                                [
                                    0.28725449233417205,
                                    0.02143272261586052,
                                    0.6433136634628541,
                                    0.04799912158711319,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069205,
                                    0.583188665524138,
                                    0.04351305631228166,
                                ],
                                [
                                    0.048943833506145784,
                                    0.003651812714120234,
                                    0.8816243222908804,
                                    0.06578003148885347,
                                ],
                                [
                                    0.21603704751088662,
                                    0.00506617498985139,
                                    0.7610497858127007,
                                    0.017846991686561387,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.5160968100702207,
                                    0.012102723961676422,
                                    0.4609900232533665,
                                    0.010810442714736357,
                                ],
                                [
                                    0.15320323840310815,
                                    0.07546154627659592,
                                    0.51678728338932,
                                    0.25454793193097597,
                                ],
                                [
                                    0.3589548564063995,
                                    0.17680623980446367,
                                    0.31103566538602856,
                                    0.15320323840310818,
                                ],
                                [
                                    -0.007095592285354626,
                                    -0.00349499378200012,
                                    0.6770861140777827,
                                    0.333504471989572,
                                ],
                                [
                                    0.10384008071698249,
                                    0.0050661749898513915,
                                    0.8496412417564566,
                                    0.04145250253670954,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.6983088393125555,
                                    0.034069260660145484,
                                    0.25517248316088353,
                                    0.01244941686641545,
                                ],
                                [
                                    0.04100627160920403,
                                    0.0832515885950765,
                                    0.28900320659836787,
                                    0.5867389331973516,
                                ],
                                [
                                    0.24675788961249534,
                                    0.5009718148576523,
                                    0.08325158859507653,
                                    0.16901870693477583,
                                ],
                                [
                                    -0.030701103135502724,
                                    -0.06232987070880641,
                                    0.3607105813430746,
                                    0.7323203925012346,
                                ],
                                [
                                    0.02143272261586059,
                                    0.0014804440605522655,
                                    0.9139562141705917,
                                    0.06313061915299542,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.8314394067502079,
                                    0.057430852509683356,
                                    0.1039495300362444,
                                    0.007180210703864331,
                                ],
                                [
                                    0.0030713474794257264,
                                    0.04116408245452641,
                                    0.06636049672354805,
                                    0.8894040733424998,
                                ],
                                [
                                    0.06319634541814194,
                                    0.8469961770992888,
                                    0.0062354987848318305,
                                    0.08357197869773753,
                                ],
                                [
                                    -0.010846448717975988,
                                    -0.1453707574139538,
                                    0.08027829292094976,
                                    1.07593891321098,
                                ],
                                [
                                    0.06429958742830123,
                                    0.0003114757852464733,
                                    0.9308796315822727,
                                    0.004509305204179541,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12859917485660247,
                                    0.0006229515704929466,
                                    0.8665800441539715,
                                    0.004197829418933068,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179545,
                                    0.8701316820730636,
                                    0.06492253899879417,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011075,
                                    0.8100066841343474,
                                    0.06043647372396264,
                                ],
                                [
                                    0.06461106321354775,
                                    0.004820780989426019,
                                    0.8659570925834785,
                                    0.06461106321354769,
                                ],
                                [
                                    0.04545278731482864,
                                    0.0010658902117323902,
                                    0.9316340460087587,
                                    0.02184727646468039,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.34551254987416263,
                                    0.00810243918355742,
                                    0.6315742834494246,
                                    0.014810727492855358,
                                ],
                                [
                                    0.03223296324084664,
                                    0.01587661770458774,
                                    0.6377575585515814,
                                    0.3141328605029841,
                                ],
                                [
                                    0.23798458124413802,
                                    0.11722131123245551,
                                    0.4320059405482901,
                                    0.21278816697511638,
                                ],
                                [
                                    0.04651867752656097,
                                    0.022913166676412796,
                                    0.6234718442658671,
                                    0.30709631153115907,
                                ],
                                [
                                    0.021847276464680463,
                                    0.0010658902117323915,
                                    0.9316340460087587,
                                    0.04545278731482855,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.6163160350602535,
                                    0.030068975882026484,
                                    0.3371652874131856,
                                    0.01644970164453445,
                                ],
                                [
                                    0.008627452390698495,
                                    0.017515591856266846,
                                    0.32138202581687336,
                                    0.6524749299361613,
                                ],
                                [
                                    0.21437907039398982,
                                    0.43523581811884265,
                                    0.11563040781358207,
                                    0.2347547036735855,
                                ],
                                [
                                    0.022913166676412796,
                                    0.04651867752656097,
                                    0.30709631153115907,
                                    0.6234718442658671,
                                ],
                                [
                                    0.004509305204179589,
                                    0.0003114757852464765,
                                    0.9308796315822727,
                                    0.06429958742830122,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.8145159893385269,
                                    0.05626188423437757,
                                    0.1208729474479254,
                                    0.00834917897917012,
                                ],
                                [
                                    0.0006461914998409619,
                                    0.008660654764416634,
                                    0.0687856527031328,
                                    0.9219075010326095,
                                ],
                                [
                                    0.06077118943855717,
                                    0.8144927494091789,
                                    0.008660654764416598,
                                    0.11607540638784732,
                                ],
                                [
                                    0.004820780989426022,
                                    0.06461106321354775,
                                    0.06461106321354775,
                                    0.8659570925834785,
                                ],
                                [
                                    0.8461152733864915,
                                    0.019841819196987055,
                                    0.1309715599370957,
                                    0.0030713474794257217,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.8100066841343474,
                                    0.06043647372396264,
                                    0.1205614716626788,
                                    0.008995370479011071,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879417,
                                    0.06043647372396264,
                                    0.004509305204179541,
                                ],
                                [
                                    0.02850247396140365,
                                    0.0021266355603932192,
                                    0.9020656818356226,
                                    0.0673052086425805,
                                ],
                                [
                                    0.5555718601682373,
                                    0.06789998409762983,
                                    0.3355218841249287,
                                    0.041006271609204024,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.8292234622691584,
                                    0.10134469352786774,
                                    0.06187028202400762,
                                    0.007561562178966106,
                                ],
                                [
                                    0.4320059405482901,
                                    0.21278816697511638,
                                    0.23798458124413796,
                                    0.11722131123245548,
                                ],
                                [
                                    0.6377575585515814,
                                    0.3141328605029841,
                                    0.03223296324084665,
                                    0.01587661770458775,
                                ],
                                [
                                    -0.07704724209338629,
                                    -0.03795026844939201,
                                    0.7470377638858144,
                                    0.3679597466569639,
                                ],
                                [
                                    0.2391963274335293,
                                    0.06789998409762983,
                                    0.5397004500657328,
                                    0.15320323840310818,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.7248165377937349,
                                    0.20575161800329134,
                                    0.054080239705527076,
                                    0.015351604497446684,
                                ],
                                [
                                    0.1156304078135821,
                                    0.23475470367358556,
                                    0.21437907039398976,
                                    0.43523581811884254,
                                ],
                                [
                                    0.32138202581687336,
                                    0.6524749299361613,
                                    0.008627452390698495,
                                    0.017515591856266843,
                                ],
                                [
                                    -0.10065275294353446,
                                    -0.20434682916005933,
                                    0.43066223115110636,
                                    0.8743373509524874,
                                ],
                                [
                                    0.04476924401656064,
                                    0.01984181919698706,
                                    0.6481344444522802,
                                    0.287254492334172,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.6447941075234065,
                                    0.28577404827361974,
                                    0.04810958094543443,
                                    0.021322263257539335,
                                ],
                                [
                                    0.008660654764416595,
                                    0.11607540638784729,
                                    0.06077118943855717,
                                    0.8144927494091789,
                                ],
                                [
                                    0.0687856527031328,
                                    0.9219075010326095,
                                    0.0006461914998409586,
                                    0.00866065476441659,
                                ],
                                [
                                    -0.03128780826271806,
                                    -0.4193383939054508,
                                    0.10071965246569183,
                                    1.349906549702477,
                                ],
                                [
                                    0.609186129980153,
                                    0.014285714285714287,
                                    0.36790070334343433,
                                    0.008627452390698492,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6723167491331484,
                                    0.015766158346266546,
                                    0.3047700841904389,
                                    0.007147008330146231,
                                ],
                                [
                                    0.583188665524138,
                                    0.04351305631228166,
                                    0.34737949027288817,
                                    0.025918787890692047,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711319,
                                    0.287254492334172,
                                    0.021432722615860517,
                                ],
                                [
                                    0.04416970366880572,
                                    0.003295603835699011,
                                    0.8863984521282205,
                                    0.0661362403672747,
                                ],
                                [
                                    0.40000066429147924,
                                    0.048886635000210864,
                                    0.4910930800016869,
                                    0.060019620706622985,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6736522663924005,
                                    0.08233134443044879,
                                    0.2174414779007657,
                                    0.026574911276385067,
                                ],
                                [
                                    0.3110356653860286,
                                    0.1532032384031082,
                                    0.3589548564063995,
                                    0.17680623980446367,
                                ],
                                [
                                    0.51678728338932,
                                    0.25454793193097597,
                                    0.15320323840310818,
                                    0.07546154627659593,
                                ],
                                [
                                    -0.023432972281470687,
                                    -0.011542107990979092,
                                    0.6934234940738988,
                                    0.34155158619855097,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.6578367978607329,
                                    0.1867382689058724,
                                    0.12105997963852917,
                                    0.034364953594865646,
                                ],
                                [
                                    0.08325158859507653,
                                    0.16901870693477583,
                                    0.24675788961249534,
                                    0.5009718148576523,
                                ],
                                [
                                    0.28900320659836787,
                                    0.5867389331973516,
                                    0.04100627160920404,
                                    0.08325158859507652,
                                ],
                                [
                                    -0.04703848313161887,
                                    -0.0954982809246918,
                                    0.3770479613391907,
                                    0.7654888027171199,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.6322578267476925,
                                    0.28021794336234696,
                                    0.06064586172114842,
                                    0.026878368168812103,
                                ],
                                [
                                    0.00623549878483183,
                                    0.08357197869773751,
                                    0.06319634541814194,
                                    0.8469961770992888,
                                ],
                                [
                                    0.06636049672354805,
                                    0.8894040733424998,
                                    0.0030713474794257256,
                                    0.04116408245452639,
                                ],
                                [
                                    -0.01562057855531605,
                                    -0.20935657327794924,
                                    0.08505242275828982,
                                    1.1399247290749754,
                                ],
                                [
                                    0.3000597625593341,
                                    0.007036548971825033,
                                    0.6770270707642532,
                                    0.015876617704587745,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.36319038171232954,
                                    0.008516993032377294,
                                    0.6138964516112577,
                                    0.014396173644035485,
                                ],
                                [
                                    0.28725449233417205,
                                    0.02143272261586052,
                                    0.6433136634628541,
                                    0.04799912158711319,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069205,
                                    0.583188665524138,
                                    0.04351305631228166,
                                ],
                                [
                                    0.06461106321354775,
                                    0.004820780989426019,
                                    0.8659570925834785,
                                    0.06461106321354769,
                                ],
                                [
                                    0.19702369841346765,
                                    0.024079524087270352,
                                    0.6940700458796984,
                                    0.0848267316195635,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.47067530051438883,
                                    0.05752423351750827,
                                    0.4204184437787773,
                                    0.051382022189325575,
                                ],
                                [
                                    0.15320323840310815,
                                    0.07546154627659592,
                                    0.51678728338932,
                                    0.25454793193097597,
                                ],
                                [
                                    0.3589548564063995,
                                    0.17680623980446367,
                                    0.31103566538602856,
                                    0.15320323840310818,
                                ],
                                [
                                    0.04651867752656097,
                                    0.022913166676412796,
                                    0.6234718442658671,
                                    0.30709631153115907,
                                ],
                                [
                                    0.08482673161956351,
                                    0.02407952408727036,
                                    0.6940700458796984,
                                    0.19702369841346767,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.5704469419797692,
                                    0.16193115799293187,
                                    0.2084498355194928,
                                    0.05917206450780615,
                                ],
                                [
                                    0.04100627160920403,
                                    0.0832515885950765,
                                    0.28900320659836787,
                                    0.5867389331973516,
                                ],
                                [
                                    0.24675788961249534,
                                    0.5009718148576523,
                                    0.08325158859507653,
                                    0.16901870693477583,
                                ],
                                [
                                    0.022913166676412796,
                                    0.04651867752656097,
                                    0.30709631153115907,
                                    0.6234718442658671,
                                ],
                                [
                                    0.0158766177045878,
                                    0.0070365489718250546,
                                    0.6770270707642531,
                                    0.30005976255933403,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.6159014812114335,
                                    0.2729687780484577,
                                    0.07700220725740735,
                                    0.034127533482701373,
                                ],
                                [
                                    0.0030713474794257264,
                                    0.04116408245452641,
                                    0.06636049672354805,
                                    0.8894040733424998,
                                ],
                                [
                                    0.06319634541814194,
                                    0.8469961770992888,
                                    0.0062354987848318305,
                                    0.08357197869773753,
                                ],
                                [
                                    0.004820780989426022,
                                    0.06461106321354775,
                                    0.06461106321354775,
                                    0.8659570925834785,
                                ],
                                [
                                    0.06313061915299545,
                                    0.0014804440605522607,
                                    0.9139562141705918,
                                    0.021432722615860517,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.1262612383059909,
                                    0.0029608881211045214,
                                    0.8508255950175964,
                                    0.019952278555308258,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179545,
                                    0.8701316820730636,
                                    0.06492253899879417,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011075,
                                    0.8100066841343474,
                                    0.06043647372396264,
                                ],
                                [
                                    0.0802782929209497,
                                    0.005989749264731803,
                                    0.8502898628760766,
                                    0.0634420949382419,
                                ],
                                [
                                    0.04145250253670962,
                                    0.0050661749898514,
                                    0.8496412417564565,
                                    0.10384008071698245,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.3151041046376307,
                                    0.03851088442008931,
                                    0.5759896396555354,
                                    0.07039537128674454,
                                ],
                                [
                                    0.03223296324084664,
                                    0.01587661770458774,
                                    0.6377575585515814,
                                    0.3141328605029841,
                                ],
                                [
                                    0.23798458124413802,
                                    0.11722131123245551,
                                    0.4320059405482901,
                                    0.21278816697511638,
                                ],
                                [
                                    0.1001329473384765,
                                    0.04932132713482568,
                                    0.5698575744539517,
                                    0.2806881510727462,
                                ],
                                [
                                    0.01784699168656145,
                                    0.005066174989851407,
                                    0.7610497858127006,
                                    0.21603704751088662,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.5034672020467671,
                                    0.1429178088955129,
                                    0.2754295754524949,
                                    0.07818541360522512,
                                ],
                                [
                                    0.008627452390698495,
                                    0.017515591856266846,
                                    0.32138202581687336,
                                    0.6524749299361613,
                                ],
                                [
                                    0.21437907039398982,
                                    0.43523581811884265,
                                    0.11563040781358207,
                                    0.2347547036735855,
                                ],
                                [
                                    0.07652743648832833,
                                    0.15536722576192835,
                                    0.25348204171924354,
                                    0.5146232960304997,
                                ],
                                [
                                    0.003340336928873789,
                                    0.0014804440605522763,
                                    0.6895633515399671,
                                    0.3056158674706068,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.6033652004357195,
                                    0.2674126731371849,
                                    0.08953848803312137,
                                    0.03968363839397415,
                                ],
                                [
                                    0.0006461914998409619,
                                    0.008660654764416634,
                                    0.0687856527031328,
                                    0.9219075010326095,
                                ],
                                [
                                    0.06077118943855717,
                                    0.8144927494091789,
                                    0.008660654764416598,
                                    0.11607540638784732,
                                ],
                                [
                                    0.020488010696828034,
                                    0.2745928838410493,
                                    0.048943833506145736,
                                    0.6559752719559769,
                                ],
                                [
                                    0.8256739138417495,
                                    0.04028317874172911,
                                    0.1278074086316896,
                                    0.006235498784831823,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8100066841343474,
                                    0.06043647372396264,
                                    0.1205614716626788,
                                    0.008995370479011071,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879417,
                                    0.06043647372396264,
                                    0.004509305204179541,
                                ],
                                [
                                    0.048943833506145784,
                                    0.003651812714120234,
                                    0.8816243222908804,
                                    0.06578003148885347,
                                ],
                                [
                                    0.4856202103602057,
                                    0.13785163390566152,
                                    0.2932765671390563,
                                    0.0832515885950765,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.7248165377937349,
                                    0.20575161800329134,
                                    0.05408023970552705,
                                    0.015351604497446677,
                                ],
                                [
                                    0.4320059405482901,
                                    0.21278816697511638,
                                    0.23798458124413796,
                                    0.11722131123245548,
                                ],
                                [
                                    0.6377575585515814,
                                    0.3141328605029841,
                                    0.03223296324084665,
                                    0.01587661770458775,
                                ],
                                [
                                    -0.007095592285354626,
                                    -0.00349499378200012,
                                    0.6770861140777827,
                                    0.333504471989572,
                                ],
                                [
                                    0.16924467762549758,
                                    0.13785163390566155,
                                    0.38186802308281226,
                                    0.3110356653860286,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5128479295344504,
                                    0.4177202262625758,
                                    0.03826477117385947,
                                    0.03116707302911428,
                                ],
                                [
                                    0.1156304078135821,
                                    0.23475470367358556,
                                    0.21437907039398976,
                                    0.43523581811884254,
                                ],
                                [
                                    0.32138202581687336,
                                    0.6524749299361613,
                                    0.008627452390698495,
                                    0.017515591856266843,
                                ],
                                [
                                    -0.030701103135502724,
                                    -0.06232987070880641,
                                    0.3607105813430746,
                                    0.7323203925012346,
                                ],
                                [
                                    0.024327884471818596,
                                    0.04028317874172911,
                                    0.3522002712623143,
                                    0.583188665524138,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.35038511148716756,
                                    0.5801830443098587,
                                    0.02614304424696536,
                                    0.04328879995600841,
                                ],
                                [
                                    0.008660654764416595,
                                    0.11607540638784729,
                                    0.06077118943855717,
                                    0.8144927494091789,
                                ],
                                [
                                    0.0687856527031328,
                                    0.9219075010326095,
                                    0.0006461914998409586,
                                    0.00866065476441659,
                                ],
                                [
                                    -0.010846448717975988,
                                    -0.1453707574139538,
                                    0.08027829292094976,
                                    1.07593891321098,
                                ],
                                [
                                    0.5944687585955731,
                                    0.029003085670294096,
                                    0.35901256387786595,
                                    0.01751559185626684,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6560742005948416,
                                    0.032008706884573364,
                                    0.2974071218785975,
                                    0.01450997064198757,
                                ],
                                [
                                    0.583188665524138,
                                    0.04351305631228166,
                                    0.34737949027288817,
                                    0.025918787890692047,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711319,
                                    0.287254492334172,
                                    0.021432722615860517,
                                ],
                                [
                                    0.06461106321354775,
                                    0.004820780989426019,
                                    0.8659570925834785,
                                    0.06461106321354769,
                                ],
                                [
                                    0.3496368708786442,
                                    0.09925042841304595,
                                    0.4292599066206178,
                                    0.12185279408769208,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5888331983121735,
                                    0.16715041251067578,
                                    0.19006357918708855,
                                    0.05395280999006225,
                                ],
                                [
                                    0.3110356653860286,
                                    0.1532032384031082,
                                    0.3589548564063995,
                                    0.17680623980446367,
                                ],
                                [
                                    0.51678728338932,
                                    0.25454793193097597,
                                    0.15320323840310818,
                                    0.07546154627659593,
                                ],
                                [
                                    0.04651867752656097,
                                    0.022913166676412796,
                                    0.6234718442658671,
                                    0.30709631153115907,
                                ],
                                [
                                    0.12185279408769206,
                                    0.09925042841304593,
                                    0.4292599066206178,
                                    0.3496368708786442,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.4654560459966449,
                                    0.3791190207699603,
                                    0.08565665471166496,
                                    0.06976827852172986,
                                ],
                                [
                                    0.08325158859507653,
                                    0.16901870693477583,
                                    0.24675788961249534,
                                    0.5009718148576523,
                                ],
                                [
                                    0.28900320659836787,
                                    0.5867389331973516,
                                    0.04100627160920404,
                                    0.08325158859507652,
                                ],
                                [
                                    0.022913166676412796,
                                    0.04651867752656097,
                                    0.30709631153115907,
                                    0.6234718442658671,
                                ],
                                [
                                    0.017515591856266877,
                                    0.029003085670294148,
                                    0.359012563877866,
                                    0.5944687585955729,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.3435728188716158,
                                    0.5689029512384237,
                                    0.03295533686251711,
                                    0.05456889302744342,
                                ],
                                [
                                    0.00623549878483183,
                                    0.08357197869773751,
                                    0.06319634541814194,
                                    0.8469961770992888,
                                ],
                                [
                                    0.06636049672354805,
                                    0.8894040733424998,
                                    0.0030713474794257256,
                                    0.04116408245452639,
                                ],
                                [
                                    0.004820780989426022,
                                    0.06461106321354775,
                                    0.06461106321354775,
                                    0.8659570925834785,
                                ],
                                [
                                    0.29281059724544484,
                                    0.014285714285714287,
                                    0.6606707252279942,
                                    0.032232963240846645,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.35441603924471327,
                                    0.01729133549999356,
                                    0.5990652832287258,
                                    0.029227342026567377,
                                ],
                                [
                                    0.28725449233417205,
                                    0.02143272261586052,
                                    0.6433136634628541,
                                    0.04799912158711319,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069205,
                                    0.583188665524138,
                                    0.04351305631228166,
                                ],
                                [
                                    0.08505242275828978,
                                    0.0063459581431530255,
                                    0.8455157330387365,
                                    0.06308588605982068,
                                ],
                                [
                                    0.17221658750052715,
                                    0.04888663500021086,
                                    0.6066801899987349,
                                    0.17221658750052715,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.41141291493405646,
                                    0.11678661909784069,
                                    0.36748386256520554,
                                    0.10431660340289733,
                                ],
                                [
                                    0.15320323840310815,
                                    0.07546154627659592,
                                    0.51678728338932,
                                    0.25454793193097597,
                                ],
                                [
                                    0.3589548564063995,
                                    0.17680623980446367,
                                    0.31103566538602856,
                                    0.15320323840310818,
                                ],
                                [
                                    0.11647032733459263,
                                    0.057368441343804685,
                                    0.5535201944578355,
                                    0.27264103686376717,
                                ],
                                [
                                    0.060019620706623,
                                    0.04888663500021088,
                                    0.4910930800016869,
                                    0.40000066429147924,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.4036228726155758,
                                    0.3287552273571252,
                                    0.14748982809273403,
                                    0.12013207193456493,
                                ],
                                [
                                    0.04100627160920403,
                                    0.0832515885950765,
                                    0.28900320659836787,
                                    0.5867389331973516,
                                ],
                                [
                                    0.24675788961249534,
                                    0.5009718148576523,
                                    0.08325158859507653,
                                    0.16901870693477583,
                                ],
                                [
                                    0.09286481648444446,
                                    0.18853563597781373,
                                    0.2371446617231274,
                                    0.4814548858146144,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.3346846794060474,
                                    0.5541855798538439,
                                    0.04184347632808547,
                                    0.06928626441202326,
                                ],
                                [
                                    0.0030713474794257264,
                                    0.04116408245452641,
                                    0.06636049672354805,
                                    0.8894040733424998,
                                ],
                                [
                                    0.06319634541814194,
                                    0.8469961770992888,
                                    0.0062354987848318305,
                                    0.08357197869773753,
                                ],
                                [
                                    0.025262140534168094,
                                    0.33857869970504473,
                                    0.044169703668805675,
                                    0.5919894560919815,
                                ],
                                [
                                    0.061605441999268436,
                                    0.0030056212142792697,
                                    0.8918758804741707,
                                    0.04351305631228167,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12321088399853687,
                                    0.006011242428558539,
                                    0.8302704384749022,
                                    0.0405074350980024,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179545,
                                    0.8701316820730636,
                                    0.06492253899879417,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011075,
                                    0.8100066841343474,
                                    0.06043647372396264,
                                ],
                                [
                                    0.10071965246569174,
                                    0.00751492641845881,
                                    0.8298485033313345,
                                    0.061916917784514906,
                                ],
                                [
                                    0.03623324801896572,
                                    0.010285429507595303,
                                    0.7426635294802962,
                                    0.2108177929931427,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.2754295754524949,
                                    0.07818541360522512,
                                    0.5034672020467671,
                                    0.1429178088955129,
                                ],
                                [
                                    0.03223296324084664,
                                    0.01587661770458774,
                                    0.6377575585515814,
                                    0.3141328605029841,
                                ],
                                [
                                    0.23798458124413802,
                                    0.11722131123245551,
                                    0.4320059405482901,
                                    0.21278816697511638,
                                ],
                                [
                                    0.17008459714650823,
                                    0.0837766018022176,
                                    0.49990592464591993,
                                    0.24623287640535427,
                                ],
                                [
                                    0.012627737168817536,
                                    0.010285429507595319,
                                    0.5384849635394924,
                                    0.4386018697840948,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.35623098907777034,
                                    0.2901540218645096,
                                    0.19488171163053952,
                                    0.15873327742718052,
                                ],
                                [
                                    0.008627452390698495,
                                    0.017515591856266846,
                                    0.32138202581687336,
                                    0.6524749299361613,
                                ],
                                [
                                    0.21437907039398982,
                                    0.43523581811884265,
                                    0.11563040781358207,
                                    0.2347547036735855,
                                ],
                                [
                                    0.14647908629635997,
                                    0.29738418421318114,
                                    0.1835303919112119,
                                    0.372606337579247,
                                ],
                                [
                                    0.001815159775146765,
                                    0.003005621214279301,
                                    0.3747129959589861,
                                    0.6204662230515878,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.3278723867904957,
                                    0.5429054867824088,
                                    0.04865576894363723,
                                    0.08056635748345829,
                                ],
                                [
                                    0.0006461914998409619,
                                    0.008660654764416634,
                                    0.0687856527031328,
                                    0.9219075010326095,
                                ],
                                [
                                    0.06077118943855717,
                                    0.8144927494091789,
                                    0.008660654764416598,
                                    0.11607540638784732,
                                ],
                                [
                                    0.040929370241570104,
                                    0.5485605203325463,
                                    0.028502473961403665,
                                    0.38200763546447997,
                                ],
                                [
                                    0.8100066841343474,
                                    0.0559504084491311,
                                    0.12538225265210484,
                                    0.008660654764416586,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8100066841343474,
                                    0.06043647372396264,
                                    0.1205614716626788,
                                    0.008995370479011071,
                                ],
                                [
                                    0.8701316820730636,
                                    0.06492253899879417,
                                    0.06043647372396264,
                                    0.004509305204179541,
                                ],
                                [
                                    0.06461106321354775,
                                    0.004820780989426019,
                                    0.8659570925834785,
                                    0.06461106321354769,
                                ],
                                [
                                    0.4320059405482901,
                                    0.19146590371757705,
                                    0.26089774792055076,
                                    0.11563040781358203,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.6447941075234065,
                                    0.28577404827361974,
                                    0.0481095809454344,
                                    0.02132226325753932,
                                ],
                                [
                                    0.4320059405482901,
                                    0.21278816697511638,
                                    0.23798458124413796,
                                    0.11722131123245548,
                                ],
                                [
                                    0.6377575585515814,
                                    0.3141328605029841,
                                    0.03223296324084665,
                                    0.01587661770458775,
                                ],
                                [
                                    0.04651867752656097,
                                    0.022913166676412796,
                                    0.6234718442658671,
                                    0.30709631153115907,
                                ],
                                [
                                    0.11563040781358208,
                                    0.19146590371757705,
                                    0.2608977479205508,
                                    0.43200594054829006,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.35038511148716756,
                                    0.5801830443098587,
                                    0.026143044246965355,
                                    0.0432887999560084,
                                ],
                                [
                                    0.1156304078135821,
                                    0.23475470367358556,
                                    0.21437907039398976,
                                    0.43523581811884254,
                                ],
                                [
                                    0.32138202581687336,
                                    0.6524749299361613,
                                    0.008627452390698495,
                                    0.017515591856266843,
                                ],
                                [
                                    0.022913166676412796,
                                    0.04651867752656097,
                                    0.30709631153115907,
                                    0.6234718442658671,
                                ],
                                [
                                    0.008660654764416591,
                                    0.055950408449131114,
                                    0.12538225265210487,
                                    0.8100066841343474,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179546,
                                    0.0003114757852464735,
                                ],
                                [
                                    0.12473606115226392,
                                    0.8058320946447624,
                                    0.009306846264257556,
                                    0.060124997938716215,
                                ],
                                [
                                    0.008660654764416595,
                                    0.11607540638784729,
                                    0.06077118943855717,
                                    0.8144927494091789,
                                ],
                                [
                                    0.0687856527031328,
                                    0.9219075010326095,
                                    0.0006461914998409586,
                                    0.00866065476441659,
                                ],
                                [
                                    0.004820780989426022,
                                    0.06461106321354775,
                                    0.06461106321354775,
                                    0.8659570925834785,
                                ],
                                [
                                    0.5831886655241381,
                                    0.040283178741729105,
                                    0.3522002712623142,
                                    0.024327884471818582,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.6436251392481007,
                                    0.044457768231314164,
                                    0.2917637975383516,
                                    0.020153294982233526,
                                ],
                                [
                                    0.583188665524138,
                                    0.04351305631228166,
                                    0.34737949027288817,
                                    0.025918787890692047,
                                ],
                                [
                                    0.6433136634628541,
                                    0.04799912158711319,
                                    0.287254492334172,
                                    0.021432722615860517,
                                ],
                                [
                                    0.0802782929209497,
                                    0.005989749264731803,
                                    0.8502898628760766,
                                    0.0634420949382419,
                                ],
                                [
                                    0.3110356653860286,
                                    0.13785163390566152,
                                    0.38186802308281226,
                                    0.16924467762549755,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.5238238323611449,
                                    0.23215977846170424,
                                    0.16907985610769594,
                                    0.07493653306945486,
                                ],
                                [
                                    0.3110356653860286,
                                    0.1532032384031082,
                                    0.3589548564063995,
                                    0.17680623980446367,
                                ],
                                [
                                    0.51678728338932,
                                    0.25454793193097597,
                                    0.15320323840310818,
                                    0.07546154627659593,
                                ],
                                [
                                    0.1001329473384765,
                                    0.04932132713482568,
                                    0.5698575744539517,
                                    0.2806881510727462,
                                ],
                                [
                                    0.08325158859507652,
                                    0.1378516339056615,
                                    0.29327656713905637,
                                    0.48562021036020564,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.318006292268662,
                                    0.5265687744979431,
                                    0.05852186346547089,
                                    0.09690306976792393,
                                ],
                                [
                                    0.08325158859507653,
                                    0.16901870693477583,
                                    0.24675788961249534,
                                    0.5009718148576523,
                                ],
                                [
                                    0.28900320659836787,
                                    0.5867389331973516,
                                    0.04100627160920404,
                                    0.08325158859507652,
                                ],
                                [
                                    0.07652743648832833,
                                    0.15536722576192835,
                                    0.25348204171924354,
                                    0.5146232960304997,
                                ],
                                [
                                    0.0062354987848318374,
                                    0.04028317874172919,
                                    0.12780740863168963,
                                    0.8256739138417494,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.01587661770458776,
                                    0.007036548971825036,
                                ],
                                [
                                    0.12231090517267915,
                                    0.7901648649373603,
                                    0.011732002243842321,
                                    0.0757922276461182,
                                ],
                                [
                                    0.00623549878483183,
                                    0.08357197869773751,
                                    0.06319634541814194,
                                    0.8469961770992888,
                                ],
                                [
                                    0.06636049672354805,
                                    0.8894040733424998,
                                    0.0030713474794257256,
                                    0.04116408245452639,
                                ],
                                [
                                    0.020488010696828034,
                                    0.2745928838410493,
                                    0.048943833506145736,
                                    0.6559752719559769,
                                ],
                                [
                                    0.28725449233417205,
                                    0.019841819196987055,
                                    0.6481344444522802,
                                    0.044769244016560635,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.3476909660581347,
                                    0.024016408686572115,
                                    0.5876979707283175,
                                    0.040594654526975575,
                                ],
                                [
                                    0.28725449233417205,
                                    0.02143272261586052,
                                    0.6433136634628541,
                                    0.04799912158711319,
                                ],
                                [
                                    0.3473794902728882,
                                    0.02591878789069205,
                                    0.583188665524138,
                                    0.04351305631228166,
                                ],
                                [
                                    0.10071965246569174,
                                    0.00751492641845881,
                                    0.8298485033313345,
                                    0.061916917784514906,
                                ],
                                [
                                    0.15320323840310818,
                                    0.06789998409762982,
                                    0.5397004500657328,
                                    0.23919632743352925,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.36599140537822455,
                                    0.16220812865367254,
                                    0.3269122830906163,
                                    0.14488818287748653,
                                ],
                                [
                                    0.15320323840310815,
                                    0.07546154627659592,
                                    0.51678728338932,
                                    0.25454793193097597,
                                ],
                                [
                                    0.3589548564063995,
                                    0.17680623980446367,
                                    0.31103566538602856,
                                    0.15320323840310818,
                                ],
                                [
                                    0.17008459714650823,
                                    0.0837766018022176,
                                    0.49990592464591993,
                                    0.24623287640535427,
                                ],
                                [
                                    0.041006271609204045,
                                    0.06789998409762983,
                                    0.33552188412492884,
                                    0.5555718601682372,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.27576097528278953,
                                    0.45661712468991145,
                                    0.10076718045134336,
                                    0.1668547195759556,
                                ],
                                [
                                    0.04100627160920403,
                                    0.0832515885950765,
                                    0.28900320659836787,
                                    0.5867389331973516,
                                ],
                                [
                                    0.24675788961249534,
                                    0.5009718148576523,
                                    0.08325158859507653,
                                    0.16901870693477583,
                                ],
                                [
                                    0.14647908629635997,
                                    0.29738418421318114,
                                    0.1835303919112119,
                                    0.372606337579247,
                                ],
                                [
                                    0.0030713474794257334,
                                    0.01984181919698712,
                                    0.13097155993709575,
                                    0.8461152733864914,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266857,
                                    0.029003085670294113,
                                ],
                                [
                                    0.11914675386727304,
                                    0.7697235053926182,
                                    0.014896153549248429,
                                    0.0962335871908603,
                                ],
                                [
                                    0.0030713474794257264,
                                    0.04116408245452641,
                                    0.06636049672354805,
                                    0.8894040733424998,
                                ],
                                [
                                    0.06319634541814194,
                                    0.8469961770992888,
                                    0.0062354987848318305,
                                    0.08357197869773753,
                                ],
                                [
                                    0.040929370241570104,
                                    0.5485605203325463,
                                    0.028502473961403665,
                                    0.38200763546447997,
                                ],
                                [
                                    0.060436473723962644,
                                    0.004174589489585057,
                                    0.8749524630624896,
                                    0.06043647372396263,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.12087294744792529,
                                    0.008349178979170114,
                                    0.814515989338527,
                                    0.05626188423437758,
                                ],
                                [
                                    0.06043647372396269,
                                    0.004509305204179545,
                                    0.8701316820730636,
                                    0.06492253899879417,
                                ],
                                [
                                    0.12056147166267886,
                                    0.008995370479011075,
                                    0.8100066841343474,
                                    0.06043647372396264,
                                ],
                                [
                                    0.1163868821730938,
                                    0.008683894693764602,
                                    0.8141812736239324,
                                    0.060747949509209115,
                                ],
                                [
                                    0.03223296324084671,
                                    0.014285714285714313,
                                    0.6606707252279942,
                                    0.2928105972454448,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.24502113021596303,
                                    0.108593858841757,
                                    0.44788255825287787,
                                    0.19850245268940206,
                                ],
                                [
                                    0.03223296324084664,
                                    0.01587661770458774,
                                    0.6377575585515814,
                                    0.3141328605029841,
                                ],
                                [
                                    0.23798458124413802,
                                    0.11722131123245551,
                                    0.4320059405482901,
                                    0.21278816697511638,
                                ],
                                [
                                    0.22369886695842367,
                                    0.11018476226063045,
                                    0.44629165483400446,
                                    0.21982471594694142,
                                ],
                                [
                                    0.008627452390698523,
                                    0.014285714285714332,
                                    0.3679007033434344,
                                    0.6091861299801528,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.24338215606428398,
                                    0.403002854877996,
                                    0.1331459996698489,
                                    0.22046898938787113,
                                ],
                                [
                                    0.008627452390698495,
                                    0.017515591856266846,
                                    0.32138202581687336,
                                    0.6524749299361613,
                                ],
                                [
                                    0.21437907039398982,
                                    0.43523581811884265,
                                    0.11563040781358207,
                                    0.2347547036735855,
                                ],
                                [
                                    0.2000933561082755,
                                    0.4062327324485485,
                                    0.12991612209929637,
                                    0.2637577893438796,
                                ],
                                [
                                    0.0006461914998409649,
                                    0.004174589489585101,
                                    0.1333967159166805,
                                    0.8617825030938935,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.008660654764416596,
                                    0.05595040844913115,
                                ],
                                [
                                    0.11672159788768828,
                                    0.7540562756852162,
                                    0.017321309528833196,
                                    0.11190081689826233,
                                ],
                                [
                                    0.0006461914998409619,
                                    0.008660654764416634,
                                    0.0687856527031328,
                                    0.9219075010326095,
                                ],
                                [
                                    0.06077118943855717,
                                    0.8144927494091789,
                                    0.008660654764416598,
                                    0.11607540638784732,
                                ],
                                [
                                    0.05659659994897211,
                                    0.7585423409600477,
                                    0.012835244254001663,
                                    0.1720258148369785,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                3.04824342698067e-07,
                                3.04824342698067e-07,
                                3.04824342698067e-07,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                1.2675443059700219e-05,
                                1.2675443059700219e-05,
                                1.2675443059700219e-05,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                5.09831504480304e-05,
                                5.09831504480304e-05,
                                5.09831504480304e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.146589721282735e-05,
                                5.146589721282735e-05,
                                5.146589721282735e-05,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                3.04824342698067e-07,
                                3.04824342698067e-07,
                                3.04824342698067e-07,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                1.2675443059700219e-05,
                                1.2675443059700219e-05,
                                1.2675443059700219e-05,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                5.09831504480304e-05,
                                5.09831504480304e-05,
                                5.09831504480304e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.146589721282735e-05,
                                5.146589721282735e-05,
                                5.146589721282735e-05,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.0713764017236968e-06,
                                1.0713764017236968e-06,
                                1.0713764017236968e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                4.455080737763316e-05,
                                4.455080737763316e-05,
                                4.455080737763316e-05,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.00017919219899590732,
                                0.00017919219899590732,
                                0.00017919219899590732,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001808889253374916,
                                0.0001808889253374916,
                                0.0001808889253374916,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.0713764017236968e-06,
                                1.0713764017236968e-06,
                                1.0713764017236968e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                4.455080737763316e-05,
                                4.455080737763316e-05,
                                4.455080737763316e-05,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.00017919219899590732,
                                0.00017919219899590732,
                                0.00017919219899590732,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001808889253374916,
                                0.0001808889253374916,
                                0.0001808889253374916,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.0713764017236968e-06,
                                1.0713764017236968e-06,
                                1.0713764017236968e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                4.455080737763316e-05,
                                4.455080737763316e-05,
                                4.455080737763316e-05,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.00017919219899590732,
                                0.00017919219899590732,
                                0.00017919219899590732,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001808889253374916,
                                0.0001808889253374916,
                                0.0001808889253374916,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.0713764017236968e-06,
                                1.0713764017236968e-06,
                                1.0713764017236968e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                4.455080737763316e-05,
                                4.455080737763316e-05,
                                4.455080737763316e-05,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.00017919219899590732,
                                0.00017919219899590732,
                                0.00017919219899590732,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001808889253374916,
                                0.0001808889253374916,
                                0.0001808889253374916,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                3.04824342698067e-07,
                                3.04824342698067e-07,
                                3.04824342698067e-07,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                1.2675443059700219e-05,
                                1.2675443059700219e-05,
                                1.2675443059700219e-05,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                5.09831504480304e-05,
                                5.09831504480304e-05,
                                5.09831504480304e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.146589721282735e-05,
                                5.146589721282735e-05,
                                5.146589721282735e-05,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                5.714731904802237e-07,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                2.37634429782147e-05,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                9.558128917587241e-05,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                9.648632461835273e-05,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                3.04824342698067e-07,
                                3.04824342698067e-07,
                                3.04824342698067e-07,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                1.2675443059700219e-05,
                                1.2675443059700219e-05,
                                1.2675443059700219e-05,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                5.09831504480304e-05,
                                5.09831504480304e-05,
                                5.09831504480304e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.146589721282735e-05,
                                5.146589721282735e-05,
                                5.146589721282735e-05,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                2.6668306392436735e-06,
                                2.6668306392436735e-06,
                                2.6668306392436735e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00010300713551791271,
                                0.00010300713551791271,
                                0.00010300713551791271,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.00037111483336979095,
                                0.00037111483336979095,
                                0.00037111483336979095,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0003397145281420491,
                                0.0003397145281420491,
                                0.0003397145281420491,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                2.6668306392436735e-06,
                                2.6668306392436735e-06,
                                2.6668306392436735e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00010300713551791271,
                                0.00010300713551791271,
                                0.00010300713551791271,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.00037111483336979095,
                                0.00037111483336979095,
                                0.00037111483336979095,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0003397145281420491,
                                0.0003397145281420491,
                                0.0003397145281420491,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                9.37319962372385e-06,
                                9.37319962372385e-06,
                                9.37319962372385e-06,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.00036204265455386914,
                                0.00036204265455386914,
                                0.00036204265455386914,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0013043698258568808,
                                0.0013043698258568808,
                                0.0013043698258568808,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0011940061136606857,
                                0.0011940061136606857,
                                0.0011940061136606857,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                9.37319962372385e-06,
                                9.37319962372385e-06,
                                9.37319962372385e-06,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.00036204265455386914,
                                0.00036204265455386914,
                                0.00036204265455386914,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0013043698258568808,
                                0.0013043698258568808,
                                0.0013043698258568808,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0011940061136606857,
                                0.0011940061136606857,
                                0.0011940061136606857,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                9.37319962372385e-06,
                                9.37319962372385e-06,
                                9.37319962372385e-06,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.00036204265455386914,
                                0.00036204265455386914,
                                0.00036204265455386914,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0013043698258568808,
                                0.0013043698258568808,
                                0.0013043698258568808,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0011940061136606857,
                                0.0011940061136606857,
                                0.0011940061136606857,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                9.37319962372385e-06,
                                9.37319962372385e-06,
                                9.37319962372385e-06,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.00036204265455386914,
                                0.00036204265455386914,
                                0.00036204265455386914,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0013043698258568808,
                                0.0013043698258568808,
                                0.0013043698258568808,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0011940061136606857,
                                0.0011940061136606857,
                                0.0011940061136606857,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                2.6668306392436735e-06,
                                2.6668306392436735e-06,
                                2.6668306392436735e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00010300713551791271,
                                0.00010300713551791271,
                                0.00010300713551791271,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.00037111483336979095,
                                0.00037111483336979095,
                                0.00037111483336979095,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0003397145281420491,
                                0.0003397145281420491,
                                0.0003397145281420491,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                4.999673583774649e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0001931138958772653,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0006957521042551431,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                0.0006368839953248644,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                2.6668306392436735e-06,
                                2.6668306392436735e-06,
                                2.6668306392436735e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00010300713551791271,
                                0.00010300713551791271,
                                0.00010300713551791271,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.00037111483336979095,
                                0.00037111483336979095,
                                0.00037111483336979095,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0003397145281420491,
                                0.0003397145281420491,
                                0.0003397145281420491,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.283439158832025e-06,
                                5.283439158832025e-06,
                                5.283439158832025e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00018279573894240542,
                                0.00018279573894240542,
                                0.00018279573894240542,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005331029324141486,
                                0.0005331029324141486,
                                0.0005331029324141486,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0003747839201835159,
                                0.0003747839201835159,
                                0.0003747839201835159,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.283439158832025e-06,
                                5.283439158832025e-06,
                                5.283439158832025e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00018279573894240542,
                                0.00018279573894240542,
                                0.00018279573894240542,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005331029324141486,
                                0.0005331029324141486,
                                0.0005331029324141486,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0003747839201835159,
                                0.0003747839201835159,
                                0.0003747839201835159,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                1.856988186905528e-05,
                                1.856988186905528e-05,
                                1.856988186905528e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0006424783509908982,
                                0.0006424783509908982,
                                0.0006424783509908982,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0018737148628709024,
                                0.0018737148628709024,
                                0.0018737148628709024,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0013172656890720908,
                                0.0013172656890720908,
                                0.0013172656890720908,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                1.856988186905528e-05,
                                1.856988186905528e-05,
                                1.856988186905528e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0006424783509908982,
                                0.0006424783509908982,
                                0.0006424783509908982,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0018737148628709024,
                                0.0018737148628709024,
                                0.0018737148628709024,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0013172656890720908,
                                0.0013172656890720908,
                                0.0013172656890720908,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                1.856988186905528e-05,
                                1.856988186905528e-05,
                                1.856988186905528e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0006424783509908982,
                                0.0006424783509908982,
                                0.0006424783509908982,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0018737148628709024,
                                0.0018737148628709024,
                                0.0018737148628709024,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0013172656890720908,
                                0.0013172656890720908,
                                0.0013172656890720908,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                2.705057360951367e-05,
                                1.856988186905528e-05,
                                1.856988186905528e-05,
                                1.856988186905528e-05,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0008248568610768284,
                                0.0006424783509908982,
                                0.0006424783509908982,
                                0.0006424783509908982,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.001674637594527879,
                                0.0018737148628709024,
                                0.0018737148628709024,
                                0.0018737148628709024,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0003625483765557066,
                                0.0013172656890720908,
                                0.0013172656890720908,
                                0.0013172656890720908,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.283439158832025e-06,
                                5.283439158832025e-06,
                                5.283439158832025e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00018279573894240542,
                                0.00018279573894240542,
                                0.00018279573894240542,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005331029324141486,
                                0.0005331029324141486,
                                0.0005331029324141486,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0003747839201835159,
                                0.0003747839201835159,
                                0.0003747839201835159,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                9.90519263022439e-06,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0003426985627689141,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0009994412878726055,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                0.0007026307699451246,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                5.283439158832025e-06,
                                5.283439158832025e-06,
                                5.283439158832025e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00018279573894240542,
                                0.00018279573894240542,
                                0.00018279573894240542,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005331029324141486,
                                0.0005331029324141486,
                                0.0005331029324141486,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0003747839201835159,
                                0.0003747839201835159,
                                0.0003747839201835159,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                3.8399897254024495e-06,
                                3.8399897254024495e-06,
                                3.8399897254024495e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012047372723136912,
                                0.00012047372723136912,
                                0.00012047372723136912,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.00026983695141394396,
                                0.00026983695141394396,
                                0.00026983695141394396,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                9.884635164816861e-05,
                                9.884635164816861e-05,
                                9.884635164816861e-05,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                3.8399897254024495e-06,
                                3.8399897254024495e-06,
                                3.8399897254024495e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012047372723136912,
                                0.00012047372723136912,
                                0.00012047372723136912,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.00026983695141394396,
                                0.00026983695141394396,
                                0.00026983695141394396,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                9.884635164816861e-05,
                                9.884635164816861e-05,
                                9.884635164816861e-05,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.3496541444961612e-05,
                                1.3496541444961612e-05,
                                1.3496541444961612e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004234330737530197,
                                0.0004234330737530197,
                                0.0004234330737530197,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009484050371407441,
                                0.0009484050371407441,
                                0.0009484050371407441,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0003474186071065433,
                                0.0003474186071065433,
                                0.0003474186071065433,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.3496541444961612e-05,
                                1.3496541444961612e-05,
                                1.3496541444961612e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004234330737530197,
                                0.0004234330737530197,
                                0.0004234330737530197,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009484050371407441,
                                0.0009484050371407441,
                                0.0009484050371407441,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0003474186071065433,
                                0.0003474186071065433,
                                0.0003474186071065433,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.3496541444961612e-05,
                                1.3496541444961612e-05,
                                1.3496541444961612e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004234330737530197,
                                0.0004234330737530197,
                                0.0004234330737530197,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009484050371407441,
                                0.0009484050371407441,
                                0.0009484050371407441,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0003474186071065433,
                                0.0003474186071065433,
                                0.0003474186071065433,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.4428801661188399e-05,
                                1.3496541444961612e-05,
                                1.3496541444961612e-05,
                                1.3496541444961612e-05,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004399794333071802,
                                0.0004234330737530197,
                                0.0004234330737530197,
                                0.0004234330737530197,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0008932532838162915,
                                0.0009484050371407441,
                                0.0009484050371407441,
                                0.0009484050371407441,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0001933836484734781,
                                0.0003474186071065433,
                                0.0003474186071065433,
                                0.0003474186071065433,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                3.8399897254024495e-06,
                                3.8399897254024495e-06,
                                3.8399897254024495e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012047372723136912,
                                0.00012047372723136912,
                                0.00012047372723136912,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.00026983695141394396,
                                0.00026983695141394396,
                                0.00026983695141394396,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                9.884635164816861e-05,
                                9.884635164816861e-05,
                                9.884635164816861e-05,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.69633651334819e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                7.1990680283715145e-06,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00023468544770372814,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.00022585960379860204,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0004764621501725786,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.0005058801477896584,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.00010315102180899588,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                0.0001853134150761091,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                4.105233207690923e-06,
                                3.8399897254024495e-06,
                                3.8399897254024495e-06,
                                3.8399897254024495e-06,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012518144075485924,
                                0.00012047372723136912,
                                0.00012047372723136912,
                                0.00012047372723136912,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.0002541453635380819,
                                0.00026983695141394396,
                                0.00026983695141394396,
                                0.00026983695141394396,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                5.502085302573657e-05,
                                9.884635164816861e-05,
                                9.884635164816861e-05,
                                9.884635164816861e-05,
                            ]
                        ),
                    )
                case 5:
                    return (
                        np.array(
                            [
                                [0.9105809565927103, 0.04470952170364481, 0.04470952170364481],
                                [0.9083804012656871, 0.08941904340728962, 0.002200555327023207],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9510958240821106, 0.04680684881076711, 0.0020973271071223014],
                                [0.9509925958622096, 0.04890417591788941, 0.00010322821990090549],
                                [0.9509925958622096, 0.04680684881076711, 0.002200555327023207],
                                [0.7439750182371332, 0.036084856923188136, 0.21994012483967856],
                                [0.7331497981296534, 0.2560249817628667, 0.01082522010747988],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9432803266800838, 0.0464022651215522, 0.010317408198364061],
                                [0.9427725147709679, 0.056719673319916265, 0.0005078119091158175],
                                [0.9427725147709679, 0.0464022651215522, 0.01082522010747988],
                                [0.5, 0.02345503851533398, 0.47654496148466596],
                                [0.47654496148466596, 0.5, 0.02345503851533401],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9318354397810211, 0.045809799367156415, 0.022354760851822406],
                                [0.9307351621175095, 0.06816456021897882, 0.0011002776635116035],
                                [0.9307351621175095, 0.045809799367156415, 0.02345503851533401],
                                [0.2560249817628668, 0.010825220107479883, 0.7331497981296533],
                                [0.21994012483967862, 0.7439750182371332, 0.036084856923188136],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.9203905528819587, 0.045217333612760625, 0.03439211350528074],
                                [0.9186978094640512, 0.07960944711804137, 0.0016927434179073895],
                                [0.9186978094640512, 0.04521733361276062, 0.036084856923188136],
                                [0.08941904340728968, 0.0022005553270232348, 0.9083804012656871],
                                [0.04470952170364484, 0.9105809565927103, 0.04470952170364481],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.9125750554799318, 0.04481274992354571, 0.042612194596522504],
                                [0.9104777283728095, 0.08742494452006823, 0.002097327107122302],
                                [0.9104777283728095, 0.04481274992354571, 0.04470952170364481],
                                [0.7353503534566767, 0.21994012483967854, 0.04470952170364481],
                                [0.7331497981296534, 0.26464964654332335, 0.002200555327023207],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7676451398548351, 0.23025753303804264, 0.0020973271071223014],
                                [0.7675419116349341, 0.2323548601451649, 0.00010322821990090549],
                                [0.7675419116349341, 0.23025753303804264, 0.002200555327023207],
                                [0.6025471746417439, 0.17751270051857743, 0.21994012483967856],
                                [0.5917219545342641, 0.397452825358256, 0.01082522010747988],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.761415332506709, 0.22826725929492692, 0.010317408198364061],
                                [0.7609075205975931, 0.23858466749329102, 0.0005078119091158175],
                                [0.7609075205975931, 0.22826725929492694, 0.01082522010747988],
                                [0.4080723660417549, 0.11538267247357914, 0.47654496148466596],
                                [0.38461732752642086, 0.5919276339582451, 0.02345503851533401],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.752292504254759, 0.2253527348934185, 0.022354760851822406],
                                [0.7511922265912474, 0.24770749574524092, 0.0011002776635116035],
                                [0.7511922265912474, 0.2253527348934185, 0.02345503851533401],
                                [0.21359755744176567, 0.05325264442858102, 0.7331497981296533],
                                [0.17751270051857748, 0.7864024425582343, 0.036084856923188136],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.7431696760028093, 0.22243821049191007, 0.03439211350528074],
                                [0.7414769325849018, 0.25683032399719086, 0.0016927434179073895],
                                [0.7414769325849018, 0.2224382104919101, 0.036084856923188136],
                                [0.08079437862683303, 0.010825220107479883, 0.9083804012656871],
                                [0.03608485692318819, 0.919205621373167, 0.04470952170364481],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.7369398686546831, 0.22044793674879443, 0.042612194596522504],
                                [0.7348425415475608, 0.2630601313453169, 0.002097327107122302],
                                [0.7348425415475608, 0.2204479367487944, 0.04470952170364481],
                                [0.4787455168116892, 0.47654496148466596, 0.04470952170364481],
                                [0.47654496148466596, 0.5212544831883108, 0.002200555327023207],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.4990029505563893, 0.4988997223364884, 0.0020973271071223014],
                                [0.4988997223364884, 0.5009970494436107, 0.00010322821990090549],
                                [0.4988997223364884, 0.4988997223364884, 0.002200555327023207],
                                [0.3954425476339006, 0.3846173275264208, 0.21994012483967856],
                                [0.38461732752642075, 0.6045574523660994, 0.01082522010747988],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.495095201855376, 0.49458738994626, 0.010317408198364061],
                                [0.49458738994626006, 0.5049047981446241, 0.0005078119091158175],
                                [0.49458738994626006, 0.49458738994626006, 0.01082522010747988],
                                [0.27345503851533404, 0.25, 0.47654496148466596],
                                [0.25, 0.726544961484666, 0.02345503851533401],
                                [0.25, 0.25, 0.5],
                                [0.4893727584058446, 0.488272480742333, 0.022354760851822406],
                                [0.488272480742333, 0.5106272415941554, 0.0011002776635116035],
                                [0.488272480742333, 0.488272480742333, 0.02345503851533401],
                                [0.15146752939676744, 0.11538267247357925, 0.7331497981296533],
                                [0.11538267247357914, 0.8485324706032327, 0.036084856923188136],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.48365031495631333, 0.48195757153840596, 0.03439211350528074],
                                [0.4819575715384059, 0.5163496850436867, 0.0016927434179073895],
                                [0.48195757153840585, 0.48195757153840596, 0.036084856923188136],
                                [0.06816456021897888, 0.023455038515334037, 0.9083804012656871],
                                [0.023455038515334037, 0.9318354397810211, 0.04470952170364481],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.4797425662552998, 0.47764523914817764, 0.042612194596522504],
                                [0.4776452391481776, 0.5202574337447001, 0.002097327107122302],
                                [0.4776452391481776, 0.4776452391481776, 0.04470952170364481],
                                [0.22214068016670185, 0.7331497981296533, 0.04470952170364481],
                                [0.21994012483967862, 0.7778593198332981, 0.002200555327023207],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.23036076125794358, 0.7675419116349341, 0.0020973271071223014],
                                [0.23025753303804264, 0.7696392387420564, 0.00010322821990090549],
                                [0.23025753303804264, 0.7675419116349341, 0.002200555327023207],
                                [0.18833792062605736, 0.591721954534264, 0.21994012483967856],
                                [0.17751270051857748, 0.8116620793739426, 0.01082522010747988],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.22877507120404283, 0.7609075205975931, 0.010317408198364061],
                                [0.22826725929492697, 0.7712249287959572, 0.0005078119091158175],
                                [0.22826725929492697, 0.7609075205975931, 0.01082522010747988],
                                [0.1388377109889133, 0.38461732752642075, 0.47654496148466596],
                                [0.11538267247357925, 0.8611622890110867, 0.02345503851533401],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.22645301255693018, 0.7511922265912474, 0.022354760851822406],
                                [0.22535273489341856, 0.7735469874430698, 0.0011002776635116035],
                                [0.22535273489341856, 0.7511922265912474, 0.02345503851533401],
                                [0.08933750135176921, 0.17751270051857748, 0.7331497981296533],
                                [0.05325264442858102, 0.9106624986482308, 0.036084856923188136],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.22413095390981752, 0.7414769325849018, 0.03439211350528074],
                                [0.22243821049191026, 0.7758690460901824, 0.0016927434179073895],
                                [0.22243821049191004, 0.7414769325849018, 0.036084856923188136],
                                [0.05553474181112472, 0.03608485692318819, 0.9083804012656871],
                                [0.010825220107479883, 0.9444652581888753, 0.04470952170364481],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.22254526385591678, 0.7348425415475607, 0.042612194596522504],
                                [0.22044793674879448, 0.7774547361440832, 0.002097327107122302],
                                [0.22044793674879448, 0.7348425415475607, 0.04470952170364481],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.04470952170364484, 0.9530899229693319, 0.002200555327023207],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.046910077030668074, 0.9509925958622096, 0.0020973271071223014],
                                [0.04680684881076713, 0.9530899229693319, 0.00010322821990090549],
                                [0.04680684881076713, 0.9509925958622096, 0.002200555327023207],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.03608485692318819, 0.9530899229693319, 0.01082522010747988],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.04640226512155221, 0.9530899229693319, 0.0005078119091158175],
                                [0.04640226512155221, 0.9427725147709679, 0.01082522010747988],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.023455038515334037, 0.9530899229693319, 0.02345503851533401],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.045809799367156456, 0.9530899229693319, 0.0011002776635116035],
                                [0.045809799367156456, 0.9307351621175095, 0.02345503851533401],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.010825220107479883, 0.9530899229693319, 0.036084856923188136],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.04521733361276081, 0.9530899229693318, 0.0016927434179073895],
                                [0.04521733361276059, 0.9186978094640512, 0.036084856923188136],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.0022005553270232348, 0.9530899229693319, 0.04470952170364481],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.04481274992354578, 0.9530899229693319, 0.002097327107122302],
                                [0.04481274992354578, 0.9104777283728094, 0.04470952170364481],
                                [0.9105809565927103, 0.04470952170364481, 0.04470952170364481],
                                [0.9083804012656871, 0.08941904340728962, 0.002200555327023207],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9515004077713255, 0.04680684881076711, 0.0016927434179073895],
                                [0.9509925958622096, 0.048499592228674504, 0.0005078119091158174],
                                [0.9509925958622096, 0.04680684881076711, 0.002200555327023207],
                                [0.7439750182371332, 0.036084856923188136, 0.21994012483967856],
                                [0.7331497981296534, 0.2560249817628667, 0.01082522010747988],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9452706004231994, 0.046402265121552204, 0.008327134455248368],
                                [0.9427725147709679, 0.05472939957680057, 0.00249808565223151],
                                [0.9427725147709679, 0.0464022651215522, 0.01082522010747988],
                                [0.5, 0.02345503851533398, 0.47654496148466596],
                                [0.47654496148466596, 0.5, 0.02345503851533401],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9361477721712494, 0.045809799367156415, 0.018042428461594068],
                                [0.9307351621175096, 0.06385222782875048, 0.00541261005373994],
                                [0.9307351621175095, 0.045809799367156415, 0.02345503851533401],
                                [0.2560249817628668, 0.010825220107479883, 0.7331497981296533],
                                [0.21994012483967862, 0.7439750182371332, 0.036084856923188136],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.9270249439192997, 0.04521733361276062, 0.027757722467939765],
                                [0.9186978094640512, 0.07297505608070039, 0.008327134455248368],
                                [0.9186978094640512, 0.04521733361276062, 0.036084856923188136],
                                [0.08941904340728968, 0.0022005553270232348, 0.9083804012656871],
                                [0.04470952170364484, 0.9105809565927103, 0.04470952170364481],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.9207951365711736, 0.04481274992354571, 0.03439211350528075],
                                [0.9104777283728095, 0.07920486342882647, 0.010317408198364061],
                                [0.9104777283728095, 0.04481274992354571, 0.04470952170364481],
                                [0.7353503534566767, 0.21994012483967854, 0.04470952170364481],
                                [0.7331497981296534, 0.26464964654332335, 0.002200555327023207],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.76804972354405, 0.2302575330380426, 0.0016927434179073895],
                                [0.7675419116349341, 0.23195027645595, 0.0005078119091158174],
                                [0.7675419116349341, 0.23025753303804264, 0.002200555327023207],
                                [0.6025471746417439, 0.17751270051857743, 0.21994012483967856],
                                [0.5917219545342641, 0.397452825358256, 0.01082522010747988],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7634056062498247, 0.22826725929492692, 0.008327134455248368],
                                [0.7609075205975931, 0.23659439375017532, 0.00249808565223151],
                                [0.7609075205975931, 0.22826725929492694, 0.01082522010747988],
                                [0.4080723660417549, 0.11538267247357914, 0.47654496148466596],
                                [0.38461732752642086, 0.5919276339582451, 0.02345503851533401],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7566048366449873, 0.2253527348934185, 0.018042428461594068],
                                [0.7511922265912475, 0.24339516335501257, 0.00541261005373994],
                                [0.7511922265912474, 0.2253527348934185, 0.02345503851533401],
                                [0.21359755744176567, 0.05325264442858102, 0.7331497981296533],
                                [0.17751270051857748, 0.7864024425582343, 0.036084856923188136],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.7498040670401502, 0.22243821049191007, 0.027757722467939765],
                                [0.7414769325849018, 0.2501959329598499, 0.008327134455248368],
                                [0.7414769325849018, 0.2224382104919101, 0.036084856923188136],
                                [0.08079437862683303, 0.010825220107479883, 0.9083804012656871],
                                [0.03608485692318819, 0.919205621373167, 0.04470952170364481],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.7451599497459249, 0.22044793674879437, 0.03439211350528075],
                                [0.7348425415475608, 0.25484005025407513, 0.010317408198364061],
                                [0.7348425415475608, 0.2204479367487944, 0.04470952170364481],
                                [0.4787455168116892, 0.47654496148466596, 0.04470952170364481],
                                [0.47654496148466596, 0.5212544831883108, 0.002200555327023207],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.49940753424560425, 0.4988997223364884, 0.0016927434179073895],
                                [0.4988997223364884, 0.5005924657543958, 0.0005078119091158174],
                                [0.4988997223364884, 0.4988997223364884, 0.002200555327023207],
                                [0.3954425476339006, 0.3846173275264208, 0.21994012483967856],
                                [0.38461732752642075, 0.6045574523660994, 0.01082522010747988],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.4970854755984916, 0.49458738994626006, 0.008327134455248368],
                                [0.49458738994626006, 0.5029145244015084, 0.00249808565223151],
                                [0.49458738994626006, 0.49458738994626006, 0.01082522010747988],
                                [0.27345503851533404, 0.25, 0.47654496148466596],
                                [0.25, 0.726544961484666, 0.02345503851533401],
                                [0.25, 0.25, 0.5],
                                [0.4936850907960729, 0.488272480742333, 0.018042428461594068],
                                [0.488272480742333, 0.5063149092039271, 0.00541261005373994],
                                [0.488272480742333, 0.488272480742333, 0.02345503851533401],
                                [0.15146752939676744, 0.11538267247357925, 0.7331497981296533],
                                [0.11538267247357914, 0.8485324706032327, 0.036084856923188136],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.4902847059936543, 0.48195757153840596, 0.027757722467939765],
                                [0.4819575715384059, 0.5097152940063457, 0.008327134455248368],
                                [0.48195757153840585, 0.48195757153840596, 0.036084856923188136],
                                [0.06816456021897888, 0.023455038515334037, 0.9083804012656871],
                                [0.023455038515334037, 0.9318354397810211, 0.04470952170364481],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.48796264734654177, 0.4776452391481775, 0.03439211350528075],
                                [0.4776452391481776, 0.5120373526534584, 0.010317408198364061],
                                [0.4776452391481776, 0.4776452391481776, 0.04470952170364481],
                                [0.22214068016670185, 0.7331497981296533, 0.04470952170364481],
                                [0.21994012483967862, 0.7778593198332981, 0.002200555327023207],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.23025753303804264, 0.7692346550528415, 0.0005078119091158174],
                                [0.23025753303804264, 0.7675419116349341, 0.002200555327023207],
                                [0.18833792062605736, 0.591721954534264, 0.21994012483967856],
                                [0.17751270051857748, 0.8116620793739426, 0.01082522010747988],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.22826725929492697, 0.7692346550528415, 0.00249808565223151],
                                [0.22826725929492697, 0.7609075205975931, 0.01082522010747988],
                                [0.1388377109889133, 0.38461732752642075, 0.47654496148466596],
                                [0.11538267247357925, 0.8611622890110867, 0.02345503851533401],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.22535273489341856, 0.7692346550528415, 0.00541261005373994],
                                [0.22535273489341856, 0.7511922265912474, 0.02345503851533401],
                                [0.08933750135176921, 0.17751270051857748, 0.7331497981296533],
                                [0.05325264442858102, 0.9106624986482308, 0.036084856923188136],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.22243821049191026, 0.7692346550528414, 0.008327134455248368],
                                [0.22243821049191004, 0.7414769325849018, 0.036084856923188136],
                                [0.05553474181112472, 0.03608485692318819, 0.9083804012656871],
                                [0.010825220107479883, 0.9444652581888753, 0.04470952170364481],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.22044793674879448, 0.7692346550528415, 0.010317408198364061],
                                [0.22044793674879448, 0.7348425415475607, 0.04470952170364481],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.04470952170364484, 0.9530899229693319, 0.002200555327023207],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.047314660719882995, 0.9509925958622096, 0.0016927434179073895],
                                [0.04680684881076713, 0.952685339280117, 0.0005078119091158174],
                                [0.04680684881076713, 0.9509925958622096, 0.002200555327023207],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.03608485692318819, 0.9530899229693319, 0.01082522010747988],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.04890035077378374, 0.9427725147709679, 0.008327134455248368],
                                [0.04640226512155221, 0.9510996492262163, 0.00249808565223151],
                                [0.04640226512155221, 0.9427725147709679, 0.01082522010747988],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.023455038515334037, 0.9530899229693319, 0.02345503851533401],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.0512224094208964, 0.9307351621175095, 0.018042428461594068],
                                [0.045809799367156456, 0.9487775905791036, 0.00541261005373994],
                                [0.045809799367156456, 0.9307351621175095, 0.02345503851533401],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.010825220107479883, 0.9530899229693319, 0.036084856923188136],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.053544468068009055, 0.9186978094640512, 0.027757722467939765],
                                [0.04521733361276081, 0.9464555319319908, 0.008327134455248368],
                                [0.04521733361276059, 0.9186978094640512, 0.036084856923188136],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.0022005553270232348, 0.9530899229693319, 0.04470952170364481],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.0551301581219098, 0.9104777283728095, 0.03439211350528075],
                                [0.04481274992354578, 0.9448698418780902, 0.010317408198364061],
                                [0.04481274992354578, 0.9104777283728094, 0.04470952170364481],
                                [0.9105809565927103, 0.04470952170364481, 0.04470952170364481],
                                [0.9083804012656871, 0.08941904340728962, 0.002200555327023207],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9520928735257213, 0.04680684881076711, 0.0011002776635116035],
                                [0.9509925958622096, 0.047907126474278715, 0.0011002776635116035],
                                [0.9509925958622096, 0.04680684881076711, 0.002200555327023207],
                                [0.7439750182371332, 0.036084856923188136, 0.21994012483967856],
                                [0.7331497981296534, 0.2560249817628667, 0.01082522010747988],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9481851248247078, 0.0464022651215522, 0.00541261005373994],
                                [0.9427725147709679, 0.05181487517529214, 0.00541261005373994],
                                [0.9427725147709679, 0.0464022651215522, 0.01082522010747988],
                                [0.5, 0.02345503851533398, 0.47654496148466596],
                                [0.47654496148466596, 0.5, 0.02345503851533401],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9424626813751765, 0.045809799367156415, 0.011727519257667005],
                                [0.9307351621175095, 0.05753731862482342, 0.011727519257667005],
                                [0.9307351621175095, 0.045809799367156415, 0.02345503851533401],
                                [0.2560249817628668, 0.010825220107479883, 0.7331497981296533],
                                [0.21994012483967862, 0.7439750182371332, 0.036084856923188136],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.9367402379256453, 0.04521733361276063, 0.018042428461594068],
                                [0.9186978094640512, 0.06325976207435469, 0.018042428461594068],
                                [0.9186978094640512, 0.04521733361276062, 0.036084856923188136],
                                [0.08941904340728968, 0.0022005553270232348, 0.9083804012656871],
                                [0.04470952170364484, 0.9105809565927103, 0.04470952170364481],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.9328324892246319, 0.04481274992354571, 0.022354760851822406],
                                [0.9104777283728095, 0.06716751077536813, 0.022354760851822406],
                                [0.9104777283728095, 0.04481274992354571, 0.04470952170364481],
                                [0.7353503534566767, 0.21994012483967854, 0.04470952170364481],
                                [0.7331497981296534, 0.26464964654332335, 0.002200555327023207],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7686421892984457, 0.23025753303804264, 0.0011002776635116035],
                                [0.7675419116349342, 0.2313578107015542, 0.0011002776635116035],
                                [0.7675419116349341, 0.23025753303804264, 0.002200555327023207],
                                [0.6025471746417439, 0.17751270051857743, 0.21994012483967856],
                                [0.5917219545342641, 0.397452825358256, 0.01082522010747988],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7663201306513331, 0.22826725929492694, 0.00541261005373994],
                                [0.7609075205975931, 0.23367986934866689, 0.00541261005373994],
                                [0.7609075205975931, 0.22826725929492694, 0.01082522010747988],
                                [0.4080723660417549, 0.11538267247357914, 0.47654496148466596],
                                [0.38461732752642086, 0.5919276339582451, 0.02345503851533401],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7629197458489145, 0.2253527348934185, 0.011727519257667005],
                                [0.7511922265912474, 0.23708025415108552, 0.011727519257667005],
                                [0.7511922265912474, 0.2253527348934185, 0.02345503851533401],
                                [0.21359755744176567, 0.05325264442858102, 0.7331497981296533],
                                [0.17751270051857748, 0.7864024425582343, 0.036084856923188136],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.7595193610464959, 0.22243821049191007, 0.018042428461594068],
                                [0.7414769325849018, 0.24048063895350416, 0.018042428461594068],
                                [0.7414769325849018, 0.2224382104919101, 0.036084856923188136],
                                [0.08079437862683303, 0.010825220107479883, 0.9083804012656871],
                                [0.03608485692318819, 0.919205621373167, 0.04470952170364481],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.7571973023993832, 0.22044793674879437, 0.022354760851822406],
                                [0.7348425415475608, 0.2428026976006168, 0.022354760851822406],
                                [0.7348425415475608, 0.2204479367487944, 0.04470952170364481],
                                [0.4787455168116892, 0.47654496148466596, 0.04470952170364481],
                                [0.47654496148466596, 0.5212544831883108, 0.002200555327023207],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.4988997223364884, 0.5, 0.0011002776635116035],
                                [0.4988997223364884, 0.4988997223364884, 0.002200555327023207],
                                [0.3954425476339006, 0.3846173275264208, 0.21994012483967856],
                                [0.38461732752642075, 0.6045574523660994, 0.01082522010747988],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.49458738994626006, 0.5, 0.00541261005373994],
                                [0.49458738994626006, 0.49458738994626006, 0.01082522010747988],
                                [0.27345503851533404, 0.25, 0.47654496148466596],
                                [0.25, 0.726544961484666, 0.02345503851533401],
                                [0.25, 0.25, 0.5],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.488272480742333, 0.5, 0.011727519257667005],
                                [0.488272480742333, 0.488272480742333, 0.02345503851533401],
                                [0.15146752939676744, 0.11538267247357925, 0.7331497981296533],
                                [0.11538267247357914, 0.8485324706032327, 0.036084856923188136],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.4819575715384059, 0.5, 0.018042428461594068],
                                [0.48195757153840585, 0.48195757153840596, 0.036084856923188136],
                                [0.06816456021897888, 0.023455038515334037, 0.9083804012656871],
                                [0.023455038515334037, 0.9318354397810211, 0.04470952170364481],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.4776452391481776, 0.5, 0.022354760851822406],
                                [0.4776452391481776, 0.4776452391481776, 0.04470952170364481],
                                [0.22214068016670185, 0.7331497981296533, 0.04470952170364481],
                                [0.21994012483967862, 0.7778593198332981, 0.002200555327023207],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.23135781070155426, 0.7675419116349341, 0.0011002776635116035],
                                [0.23025753303804264, 0.7686421892984457, 0.0011002776635116035],
                                [0.23025753303804264, 0.7675419116349341, 0.002200555327023207],
                                [0.18833792062605736, 0.591721954534264, 0.21994012483967856],
                                [0.17751270051857748, 0.8116620793739426, 0.01082522010747988],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.2336798693486669, 0.7609075205975931, 0.00541261005373994],
                                [0.22826725929492697, 0.7663201306513331, 0.00541261005373994],
                                [0.22826725929492697, 0.7609075205975931, 0.01082522010747988],
                                [0.1388377109889133, 0.38461732752642075, 0.47654496148466596],
                                [0.11538267247357925, 0.8611622890110867, 0.02345503851533401],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.23708025415108558, 0.7511922265912474, 0.011727519257667005],
                                [0.22535273489341856, 0.7629197458489144, 0.011727519257667005],
                                [0.22535273489341856, 0.7511922265912474, 0.02345503851533401],
                                [0.08933750135176921, 0.17751270051857748, 0.7331497981296533],
                                [0.05325264442858102, 0.9106624986482308, 0.036084856923188136],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.24048063895350424, 0.7414769325849017, 0.018042428461594068],
                                [0.22243821049191026, 0.7595193610464956, 0.018042428461594068],
                                [0.22243821049191004, 0.7414769325849018, 0.036084856923188136],
                                [0.05553474181112472, 0.03608485692318819, 0.9083804012656871],
                                [0.010825220107479883, 0.9444652581888753, 0.04470952170364481],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.2428026976006168, 0.7348425415475608, 0.022354760851822406],
                                [0.22044793674879448, 0.7571973023993831, 0.022354760851822406],
                                [0.22044793674879448, 0.7348425415475607, 0.04470952170364481],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.04470952170364484, 0.9530899229693319, 0.002200555327023207],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.04790712647427875, 0.9509925958622096, 0.0011002776635116035],
                                [0.04680684881076713, 0.9520928735257213, 0.0011002776635116035],
                                [0.04680684881076713, 0.9509925958622096, 0.002200555327023207],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.03608485692318819, 0.9530899229693319, 0.01082522010747988],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.05181487517529215, 0.9427725147709679, 0.00541261005373994],
                                [0.04640226512155221, 0.9481851248247078, 0.00541261005373994],
                                [0.04640226512155221, 0.9427725147709679, 0.01082522010747988],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.023455038515334037, 0.9530899229693319, 0.02345503851533401],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.057537318624823475, 0.9307351621175095, 0.011727519257667005],
                                [0.045809799367156456, 0.9424626813751765, 0.011727519257667005],
                                [0.045809799367156456, 0.9307351621175095, 0.02345503851533401],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.010825220107479883, 0.9530899229693319, 0.036084856923188136],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.0632597620743548, 0.9186978094640511, 0.018042428461594068],
                                [0.04521733361276081, 0.9367402379256451, 0.018042428461594068],
                                [0.04521733361276059, 0.9186978094640512, 0.036084856923188136],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.0022005553270232348, 0.9530899229693319, 0.04470952170364481],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.0671675107753682, 0.9104777283728094, 0.022354760851822406],
                                [0.04481274992354578, 0.9328324892246318, 0.022354760851822406],
                                [0.04481274992354578, 0.9104777283728094, 0.04470952170364481],
                                [0.9105809565927103, 0.04470952170364481, 0.04470952170364481],
                                [0.9083804012656871, 0.08941904340728962, 0.002200555327023207],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.952685339280117, 0.04680684881076712, 0.0005078119091158175],
                                [0.9509925958622097, 0.047314660719882926, 0.0016927434179073895],
                                [0.9509925958622096, 0.04680684881076711, 0.002200555327023207],
                                [0.7439750182371332, 0.036084856923188136, 0.21994012483967856],
                                [0.7331497981296534, 0.2560249817628667, 0.01082522010747988],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9510996492262163, 0.046402265121552204, 0.0024980856522315107],
                                [0.9427725147709679, 0.04890035077378371, 0.008327134455248368],
                                [0.9427725147709679, 0.0464022651215522, 0.01082522010747988],
                                [0.5, 0.02345503851533398, 0.47654496148466596],
                                [0.47654496148466596, 0.5, 0.02345503851533401],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9487775905791036, 0.045809799367156415, 0.005412610053739941],
                                [0.9307351621175095, 0.051222409420896356, 0.018042428461594068],
                                [0.9307351621175095, 0.045809799367156415, 0.02345503851533401],
                                [0.2560249817628668, 0.010825220107479883, 0.7331497981296533],
                                [0.21994012483967862, 0.7439750182371332, 0.036084856923188136],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.9464555319319911, 0.04521733361276063, 0.00832713445524837],
                                [0.9186978094640513, 0.053544468068008985, 0.027757722467939765],
                                [0.9186978094640512, 0.04521733361276062, 0.036084856923188136],
                                [0.08941904340728968, 0.0022005553270232348, 0.9083804012656871],
                                [0.04470952170364484, 0.9105809565927103, 0.04470952170364481],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.9448698418780903, 0.04481274992354571, 0.010317408198364065],
                                [0.9104777283728095, 0.055130158121909786, 0.03439211350528075],
                                [0.9104777283728095, 0.04481274992354571, 0.04470952170364481],
                                [0.7353503534566767, 0.21994012483967854, 0.04470952170364481],
                                [0.7331497981296534, 0.26464964654332335, 0.002200555327023207],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158175],
                                [0.7675419116349342, 0.23076534494715842, 0.0016927434179073895],
                                [0.7675419116349341, 0.23025753303804264, 0.002200555327023207],
                                [0.6025471746417439, 0.17751270051857743, 0.21994012483967856],
                                [0.5917219545342641, 0.397452825358256, 0.01082522010747988],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.7609075205975933, 0.23076534494715845, 0.008327134455248368],
                                [0.7609075205975931, 0.22826725929492694, 0.01082522010747988],
                                [0.4080723660417549, 0.11538267247357914, 0.47654496148466596],
                                [0.38461732752642086, 0.5919276339582451, 0.02345503851533401],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7692346550528415, 0.2253527348934185, 0.005412610053739941],
                                [0.7511922265912474, 0.23076534494715845, 0.018042428461594068],
                                [0.7511922265912474, 0.2253527348934185, 0.02345503851533401],
                                [0.21359755744176567, 0.05325264442858102, 0.7331497981296533],
                                [0.17751270051857748, 0.7864024425582343, 0.036084856923188136],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.7692346550528416, 0.22243821049191007, 0.00832713445524837],
                                [0.7414769325849018, 0.23076534494715847, 0.027757722467939765],
                                [0.7414769325849018, 0.2224382104919101, 0.036084856923188136],
                                [0.08079437862683303, 0.010825220107479883, 0.9083804012656871],
                                [0.03608485692318819, 0.919205621373167, 0.04470952170364481],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364065],
                                [0.7348425415475608, 0.23076534494715845, 0.03439211350528075],
                                [0.7348425415475608, 0.2204479367487944, 0.04470952170364481],
                                [0.4787455168116892, 0.47654496148466596, 0.04470952170364481],
                                [0.47654496148466596, 0.5212544831883108, 0.002200555327023207],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5005924657543958, 0.4988997223364884, 0.0005078119091158175],
                                [0.4988997223364884, 0.49940753424560425, 0.0016927434179073895],
                                [0.4988997223364884, 0.4988997223364884, 0.002200555327023207],
                                [0.3954425476339006, 0.3846173275264208, 0.21994012483967856],
                                [0.38461732752642075, 0.6045574523660994, 0.01082522010747988],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5029145244015084, 0.49458738994626006, 0.0024980856522315107],
                                [0.49458738994626006, 0.4970854755984916, 0.008327134455248368],
                                [0.49458738994626006, 0.49458738994626006, 0.01082522010747988],
                                [0.27345503851533404, 0.25, 0.47654496148466596],
                                [0.25, 0.726544961484666, 0.02345503851533401],
                                [0.25, 0.25, 0.5],
                                [0.5063149092039271, 0.488272480742333, 0.005412610053739941],
                                [0.488272480742333, 0.4936850907960729, 0.018042428461594068],
                                [0.488272480742333, 0.488272480742333, 0.02345503851533401],
                                [0.15146752939676744, 0.11538267247357925, 0.7331497981296533],
                                [0.11538267247357914, 0.8485324706032327, 0.036084856923188136],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.5097152940063456, 0.48195757153840596, 0.00832713445524837],
                                [0.48195757153840596, 0.4902847059936543, 0.027757722467939765],
                                [0.48195757153840585, 0.48195757153840596, 0.036084856923188136],
                                [0.06816456021897888, 0.023455038515334037, 0.9083804012656871],
                                [0.023455038515334037, 0.9318354397810211, 0.04470952170364481],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.5120373526534584, 0.4776452391481776, 0.010317408198364065],
                                [0.47764523914817764, 0.48796264734654166, 0.03439211350528075],
                                [0.4776452391481776, 0.4776452391481776, 0.04470952170364481],
                                [0.22214068016670185, 0.7331497981296533, 0.04470952170364481],
                                [0.21994012483967862, 0.7778593198332981, 0.002200555327023207],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.23195027645595012, 0.767541911634934, 0.0005078119091158175],
                                [0.23025753303804264, 0.76804972354405, 0.0016927434179073895],
                                [0.23025753303804264, 0.7675419116349341, 0.002200555327023207],
                                [0.18833792062605736, 0.591721954534264, 0.21994012483967856],
                                [0.17751270051857748, 0.8116620793739426, 0.01082522010747988],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.23659439375017532, 0.7609075205975931, 0.0024980856522315107],
                                [0.22826725929492697, 0.7634056062498247, 0.008327134455248368],
                                [0.22826725929492697, 0.7609075205975931, 0.01082522010747988],
                                [0.1388377109889133, 0.38461732752642075, 0.47654496148466596],
                                [0.11538267247357925, 0.8611622890110867, 0.02345503851533401],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.24339516335501266, 0.7511922265912474, 0.005412610053739941],
                                [0.22535273489341856, 0.7566048366449873, 0.018042428461594068],
                                [0.22535273489341856, 0.7511922265912474, 0.02345503851533401],
                                [0.08933750135176921, 0.17751270051857748, 0.7331497981296533],
                                [0.05325264442858102, 0.9106624986482308, 0.036084856923188136],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.2501959329598499, 0.7414769325849018, 0.00832713445524837],
                                [0.22243821049191026, 0.74980406704015, 0.027757722467939765],
                                [0.22243821049191004, 0.7414769325849018, 0.036084856923188136],
                                [0.05553474181112472, 0.03608485692318819, 0.9083804012656871],
                                [0.010825220107479883, 0.9444652581888753, 0.04470952170364481],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.2548400502540752, 0.7348425415475608, 0.010317408198364065],
                                [0.22044793674879448, 0.7451599497459248, 0.03439211350528075],
                                [0.22044793674879448, 0.7348425415475607, 0.04470952170364481],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.04470952170364484, 0.9530899229693319, 0.002200555327023207],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.048499592228674504, 0.9509925958622096, 0.0005078119091158175],
                                [0.04680684881076713, 0.9515004077713255, 0.0016927434179073895],
                                [0.04680684881076713, 0.9509925958622096, 0.002200555327023207],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.03608485692318819, 0.9530899229693319, 0.01082522010747988],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.054729399576800675, 0.9427725147709678, 0.0024980856522315107],
                                [0.04640226512155221, 0.9452706004231994, 0.008327134455248368],
                                [0.04640226512155221, 0.9427725147709679, 0.01082522010747988],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.023455038515334037, 0.9530899229693319, 0.02345503851533401],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.06385222782875055, 0.9307351621175095, 0.005412610053739941],
                                [0.045809799367156456, 0.9361477721712494, 0.018042428461594068],
                                [0.045809799367156456, 0.9307351621175095, 0.02345503851533401],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.010825220107479883, 0.9530899229693319, 0.036084856923188136],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.07297505608070043, 0.9186978094640512, 0.00832713445524837],
                                [0.04521733361276081, 0.9270249439192995, 0.027757722467939765],
                                [0.04521733361276059, 0.9186978094640512, 0.036084856923188136],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.0022005553270232348, 0.9530899229693319, 0.04470952170364481],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.07920486342882649, 0.9104777283728095, 0.010317408198364065],
                                [0.04481274992354578, 0.9207951365711735, 0.03439211350528075],
                                [0.04481274992354578, 0.9104777283728094, 0.04470952170364481],
                                [0.9105809565927103, 0.04470952170364481, 0.04470952170364481],
                                [0.9083804012656871, 0.08941904340728962, 0.002200555327023207],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090561],
                                [0.9509925958622096, 0.04691007703066802, 0.0020973271071223014],
                                [0.9509925958622096, 0.04680684881076711, 0.002200555327023207],
                                [0.7439750182371332, 0.036084856923188136, 0.21994012483967856],
                                [0.7331497981296534, 0.2560249817628667, 0.01082522010747988],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9530899229693319, 0.0464022651215522, 0.000507811909115818],
                                [0.942772514770968, 0.04691007703066802, 0.010317408198364061],
                                [0.9427725147709679, 0.0464022651215522, 0.01082522010747988],
                                [0.5, 0.02345503851533398, 0.47654496148466596],
                                [0.47654496148466596, 0.5, 0.02345503851533401],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.9307351621175095, 0.04691007703066802, 0.022354760851822406],
                                [0.9307351621175095, 0.045809799367156415, 0.02345503851533401],
                                [0.2560249817628668, 0.010825220107479883, 0.7331497981296533],
                                [0.21994012483967862, 0.7439750182371332, 0.036084856923188136],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073917],
                                [0.9186978094640513, 0.04691007703066801, 0.03439211350528074],
                                [0.9186978094640512, 0.04521733361276062, 0.036084856923188136],
                                [0.08941904340728968, 0.0022005553270232348, 0.9083804012656871],
                                [0.04470952170364484, 0.9105809565927103, 0.04470952170364481],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.953089922969332, 0.04481274992354571, 0.002097327107122304],
                                [0.9104777283728094, 0.04691007703066803, 0.042612194596522504],
                                [0.9104777283728095, 0.04481274992354571, 0.04470952170364481],
                                [0.7353503534566767, 0.21994012483967854, 0.04470952170364481],
                                [0.7331497981296534, 0.26464964654332335, 0.002200555327023207],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7696392387420564, 0.2302575330380426, 0.00010322821990090561],
                                [0.7675419116349342, 0.23036076125794352, 0.0020973271071223014],
                                [0.7675419116349341, 0.23025753303804264, 0.002200555327023207],
                                [0.6025471746417439, 0.17751270051857743, 0.21994012483967856],
                                [0.5917219545342641, 0.397452825358256, 0.01082522010747988],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7712249287959572, 0.22826725929492694, 0.000507811909115818],
                                [0.7609075205975933, 0.22877507120404278, 0.010317408198364061],
                                [0.7609075205975931, 0.22826725929492694, 0.01082522010747988],
                                [0.4080723660417549, 0.11538267247357914, 0.47654496148466596],
                                [0.38461732752642086, 0.5919276339582451, 0.02345503851533401],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7735469874430698, 0.2253527348934185, 0.0011002776635116048],
                                [0.7511922265912474, 0.22645301255693012, 0.022354760851822406],
                                [0.7511922265912474, 0.2253527348934185, 0.02345503851533401],
                                [0.21359755744176567, 0.05325264442858102, 0.7331497981296533],
                                [0.17751270051857748, 0.7864024425582343, 0.036084856923188136],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.7758690460901826, 0.22243821049191007, 0.0016927434179073917],
                                [0.7414769325849018, 0.2241309539098175, 0.03439211350528074],
                                [0.7414769325849018, 0.2224382104919101, 0.036084856923188136],
                                [0.08079437862683303, 0.010825220107479883, 0.9083804012656871],
                                [0.03608485692318819, 0.919205621373167, 0.04470952170364481],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.7774547361440833, 0.2204479367487944, 0.002097327107122304],
                                [0.7348425415475608, 0.22254526385591672, 0.042612194596522504],
                                [0.7348425415475608, 0.2204479367487944, 0.04470952170364481],
                                [0.4787455168116892, 0.47654496148466596, 0.04470952170364481],
                                [0.47654496148466596, 0.5212544831883108, 0.002200555327023207],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5009970494436107, 0.49889972233648844, 0.00010322821990090561],
                                [0.4988997223364884, 0.4990029505563893, 0.0020973271071223014],
                                [0.4988997223364884, 0.4988997223364884, 0.002200555327023207],
                                [0.3954425476339006, 0.3846173275264208, 0.21994012483967856],
                                [0.38461732752642075, 0.6045574523660994, 0.01082522010747988],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5049047981446241, 0.49458738994626006, 0.000507811909115818],
                                [0.4945873899462601, 0.49509520185537587, 0.010317408198364061],
                                [0.49458738994626006, 0.49458738994626006, 0.01082522010747988],
                                [0.27345503851533404, 0.25, 0.47654496148466596],
                                [0.25, 0.726544961484666, 0.02345503851533401],
                                [0.25, 0.25, 0.5],
                                [0.5106272415941554, 0.488272480742333, 0.0011002776635116048],
                                [0.488272480742333, 0.4893727584058446, 0.022354760851822406],
                                [0.488272480742333, 0.488272480742333, 0.02345503851533401],
                                [0.15146752939676744, 0.11538267247357925, 0.7331497981296533],
                                [0.11538267247357914, 0.8485324706032327, 0.036084856923188136],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.5163496850436866, 0.48195757153840596, 0.0016927434179073917],
                                [0.48195757153840596, 0.48365031495631333, 0.03439211350528074],
                                [0.48195757153840585, 0.48195757153840596, 0.036084856923188136],
                                [0.06816456021897888, 0.023455038515334037, 0.9083804012656871],
                                [0.023455038515334037, 0.9318354397810211, 0.04470952170364481],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.5202574337447001, 0.4776452391481776, 0.002097327107122304],
                                [0.4776452391481775, 0.47974256625529993, 0.042612194596522504],
                                [0.4776452391481776, 0.4776452391481776, 0.04470952170364481],
                                [0.22214068016670185, 0.7331497981296533, 0.04470952170364481],
                                [0.21994012483967862, 0.7778593198332981, 0.002200555327023207],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.23235486014516493, 0.7675419116349341, 0.00010322821990090561],
                                [0.23025753303804264, 0.7676451398548351, 0.0020973271071223014],
                                [0.23025753303804264, 0.7675419116349341, 0.002200555327023207],
                                [0.18833792062605736, 0.591721954534264, 0.21994012483967856],
                                [0.17751270051857748, 0.8116620793739426, 0.01082522010747988],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.2385846674932911, 0.760907520597593, 0.000507811909115818],
                                [0.22826725929492697, 0.761415332506709, 0.010317408198364061],
                                [0.22826725929492697, 0.7609075205975931, 0.01082522010747988],
                                [0.1388377109889133, 0.38461732752642075, 0.47654496148466596],
                                [0.11538267247357925, 0.8611622890110867, 0.02345503851533401],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.24770749574524098, 0.7511922265912474, 0.0011002776635116048],
                                [0.22535273489341856, 0.752292504254759, 0.022354760851822406],
                                [0.22535273489341856, 0.7511922265912474, 0.02345503851533401],
                                [0.08933750135176921, 0.17751270051857748, 0.7331497981296533],
                                [0.05325264442858102, 0.9106624986482308, 0.036084856923188136],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.25683032399719086, 0.7414769325849018, 0.0016927434179073917],
                                [0.22243821049191026, 0.743169676002809, 0.03439211350528074],
                                [0.22243821049191004, 0.7414769325849018, 0.036084856923188136],
                                [0.05553474181112472, 0.03608485692318819, 0.9083804012656871],
                                [0.010825220107479883, 0.9444652581888753, 0.04470952170364481],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.2630601313453169, 0.7348425415475608, 0.002097327107122304],
                                [0.22044793674879448, 0.736939868654683, 0.042612194596522504],
                                [0.22044793674879448, 0.7348425415475607, 0.04470952170364481],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.04470952170364484, 0.9530899229693319, 0.002200555327023207],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.048904175917889425, 0.9509925958622096, 0.00010322821990090561],
                                [0.04680684881076713, 0.9510958240821106, 0.0020973271071223014],
                                [0.04680684881076713, 0.9509925958622096, 0.002200555327023207],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.03608485692318819, 0.9530899229693319, 0.01082522010747988],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.05671967331991634, 0.9427725147709678, 0.000507811909115818],
                                [0.04640226512155221, 0.9432803266800838, 0.010317408198364061],
                                [0.04640226512155221, 0.9427725147709679, 0.01082522010747988],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.023455038515334037, 0.9530899229693319, 0.02345503851533401],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.06816456021897888, 0.9307351621175095, 0.0011002776635116048],
                                [0.045809799367156456, 0.9318354397810211, 0.022354760851822406],
                                [0.045809799367156456, 0.9307351621175095, 0.02345503851533401],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.010825220107479883, 0.9530899229693319, 0.036084856923188136],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.07960944711804141, 0.9186978094640512, 0.0016927434179073917],
                                [0.04521733361276081, 0.9203905528819585, 0.03439211350528074],
                                [0.04521733361276059, 0.9186978094640512, 0.036084856923188136],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.0022005553270232348, 0.9530899229693319, 0.04470952170364481],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.08742494452006833, 0.9104777283728094, 0.002097327107122304],
                                [0.04481274992354578, 0.9125750554799317, 0.042612194596522504],
                                [0.04481274992354578, 0.9104777283728094, 0.04470952170364481],
                                [0.919205621373167, 0.04470952170364481, 0.036084856923188136],
                                [0.9083804012656872, 0.08079437862683295, 0.01082522010747988],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9432803266800838, 0.0464022651215522, 0.010317408198364061],
                                [0.9427725147709679, 0.056719673319916265, 0.0005078119091158175],
                                [0.9427725147709679, 0.0464022651215522, 0.01082522010747988],
                                [0.7864024425582345, 0.036084856923188136, 0.1775127005185774],
                                [0.7331497981296534, 0.21359755744176556, 0.05325264442858103],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.904833449845214, 0.04441199137843651, 0.05075455877634951],
                                [0.9023353641929824, 0.09516655015478602, 0.00249808565223151],
                                [0.9023353641929824, 0.04441199137843651, 0.05325264442858103],
                                [0.5919276339582453, 0.02345503851533398, 0.38461732752642075],
                                [0.47654496148466596, 0.4080723660417548, 0.11538267247357922],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.8485324706032327, 0.04149746697692805, 0.10997006241983928],
                                [0.8431198605494927, 0.15146752939676736, 0.00541261005373994],
                                [0.8431198605494927, 0.04149746697692808, 0.11538267247357922],
                                [0.3974528253582561, 0.010825220107479883, 0.591721954534264],
                                [0.21994012483967862, 0.602547174641744, 0.1775127005185774],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.7922314913612514, 0.03858294257541964, 0.16918556606332902],
                                [0.783904356906003, 0.20776850863874866, 0.008327134455248368],
                                [0.783904356906003, 0.03858294257541964, 0.1775127005185774],
                                [0.26464964654332346, 0.0022005553270232348, 0.7331497981296533],
                                [0.04470952170364484, 0.7353503534566765, 0.21994012483967856],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.7537846145263816, 0.03659266883230394, 0.2096227166413145],
                                [0.7434672063280175, 0.24621538547361843, 0.010317408198364061],
                                [0.7434672063280174, 0.03659266883230394, 0.21994012483967856],
                                [0.7439750182371332, 0.21994012483967856, 0.036084856923188136],
                                [0.7331497981296534, 0.2560249817628667, 0.01082522010747988],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.761415332506709, 0.22826725929492692, 0.010317408198364061],
                                [0.7609075205975931, 0.23858466749329102, 0.0005078119091158175],
                                [0.7609075205975931, 0.22826725929492694, 0.01082522010747988],
                                [0.6449745989628453, 0.1775127005185774, 0.1775127005185774],
                                [0.5917219545342641, 0.35502540103715485, 0.05325264442858103],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.730768961137402, 0.21847648008624856, 0.05075455877634951],
                                [0.7282708754851703, 0.2692310388625981, 0.00249808565223151],
                                [0.7282708754851703, 0.2184764800862486, 0.05325264442858103],
                                [0.5, 0.1153826724735792, 0.38461732752642075],
                                [0.38461732752642086, 0.4999999999999999, 0.11538267247357922],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.6858909148472928, 0.2041390227328679, 0.10997006241983928],
                                [0.6804783047935529, 0.3141090851527072, 0.00541261005373994],
                                [0.6804783047935529, 0.2041390227328679, 0.11538267247357922],
                                [0.35502540103715496, 0.05325264442858102, 0.591721954534264],
                                [0.17751270051857748, 0.6449745989628451, 0.1775127005185774],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.6410128685571836, 0.18980156537948728, 0.16918556606332902],
                                [0.6326857341019353, 0.35898713144281635, 0.008327134455248368],
                                [0.6326857341019353, 0.1898015653794873, 0.1775127005185774],
                                [0.2560249817628668, 0.010825220107479883, 0.7331497981296533],
                                [0.03608485692318819, 0.7439750182371332, 0.21994012483967856],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.6103664971878766, 0.1800107861708089, 0.2096227166413145],
                                [0.6000490889895125, 0.38963350281212344, 0.010317408198364061],
                                [0.6000490889895125, 0.18001078617080896, 0.21994012483967856],
                                [0.4873701815921458, 0.476544961484666, 0.036084856923188136],
                                [0.47654496148466596, 0.5126298184078542, 0.01082522010747988],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.495095201855376, 0.49458738994626, 0.010317408198364061],
                                [0.49458738994626006, 0.5049047981446241, 0.0005078119091158175],
                                [0.49458738994626006, 0.49458738994626006, 0.01082522010747988],
                                [0.43786997195500177, 0.38461732752642086, 0.1775127005185774],
                                [0.38461732752642075, 0.5621300280449982, 0.05325264442858103],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.475871763437941, 0.4733736777857095, 0.05075455877634951],
                                [0.4733736777857095, 0.524128236562059, 0.00249808565223151],
                                [0.4733736777857095, 0.4733736777857095, 0.05325264442858103],
                                [0.36538267247357925, 0.25, 0.38461732752642075],
                                [0.25, 0.6346173275264207, 0.11538267247357922],
                                [0.25, 0.25, 0.5],
                                [0.44772127381695037, 0.4423086637632103, 0.10997006241983928],
                                [0.44230866376321043, 0.5522787261830496, 0.00541261005373994],
                                [0.44230866376321043, 0.4423086637632103, 0.11538267247357922],
                                [0.29289537299215673, 0.11538267247357925, 0.591721954534264],
                                [0.11538267247357925, 0.7071046270078434, 0.1775127005185774],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.4195707841959597, 0.41124364974071126, 0.16918556606332902],
                                [0.41124364974071126, 0.5804292158040404, 0.008327134455248368],
                                [0.41124364974071126, 0.41124364974071137, 0.1775127005185774],
                                [0.24339516335501266, 0.023455038515334037, 0.7331497981296533],
                                [0.023455038515334037, 0.7566048366449873, 0.21994012483967856],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.4003473457785248, 0.3900299375801607, 0.2096227166413145],
                                [0.3900299375801608, 0.5996526542214752, 0.010317408198364061],
                                [0.39002993758016063, 0.39002993758016075, 0.21994012483967856],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.21994012483967862, 0.7692346550528415, 0.01082522010747988],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.22877507120404283, 0.7609075205975931, 0.010317408198364061],
                                [0.22826725929492697, 0.7712249287959572, 0.0005078119091158175],
                                [0.22826725929492697, 0.7609075205975931, 0.01082522010747988],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.17751270051857748, 0.7692346550528415, 0.05325264442858103],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.22097456573848018, 0.7282708754851703, 0.05075455877634951],
                                [0.21847648008624865, 0.7790254342615198, 0.00249808565223151],
                                [0.21847648008624865, 0.7282708754851703, 0.05325264442858103],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.11538267247357925, 0.7692346550528415, 0.11538267247357922],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.20955163278660793, 0.6804783047935528, 0.10997006241983928],
                                [0.204139022732868, 0.7904483672133921, 0.00541261005373994],
                                [0.204139022732868, 0.6804783047935528, 0.11538267247357922],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.05325264442858102, 0.7692346550528416, 0.1775127005185774],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.1981286998347357, 0.6326857341019353, 0.16918556606332902],
                                [0.18980156537948734, 0.8018713001652643, 0.008327134455248368],
                                [0.18980156537948734, 0.6326857341019353, 0.1775127005185774],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.010825220107479883, 0.7692346550528415, 0.21994012483967856],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.19032819436917303, 0.6000490889895125, 0.2096227166413145],
                                [0.18001078617080912, 0.8096718056308269, 0.010317408198364061],
                                [0.1800107861708089, 0.6000490889895125, 0.21994012483967856],
                                [0.05553474181112472, 0.9083804012656871, 0.036084856923188136],
                                [0.04470952170364484, 0.9444652581888753, 0.01082522010747988],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.04640226512155221, 0.9530899229693319, 0.0005078119091158175],
                                [0.04640226512155221, 0.9427725147709679, 0.01082522010747988],
                                [0.08933750135176921, 0.7331497981296534, 0.1775127005185774],
                                [0.03608485692318819, 0.9106624986482308, 0.05325264442858103],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634951],
                                [0.044411991378436544, 0.9530899229693319, 0.00249808565223151],
                                [0.044411991378436544, 0.9023353641929824, 0.05325264442858103],
                                [0.1388377109889133, 0.47654496148466596, 0.38461732752642075],
                                [0.023455038515334037, 0.8611622890110867, 0.11538267247357922],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.04149746697692813, 0.9530899229693319, 0.00541261005373994],
                                [0.04149746697692813, 0.8431198605494926, 0.11538267247357922],
                                [0.18833792062605736, 0.21994012483967862, 0.591721954534264],
                                [0.010825220107479883, 0.8116620793739427, 0.1775127005185774],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332902],
                                [0.03858294257541972, 0.9530899229693319, 0.008327134455248368],
                                [0.03858294257541972, 0.7839043569060029, 0.1775127005185774],
                                [0.22214068016670185, 0.04470952170364484, 0.7331497981296533],
                                [0.0022005553270232348, 0.7778593198332981, 0.21994012483967856],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.03659266883230394, 0.953089922969332, 0.010317408198364061],
                                [0.03659266883230394, 0.7434672063280174, 0.21994012483967856],
                                [0.919205621373167, 0.04470952170364481, 0.036084856923188136],
                                [0.9083804012656872, 0.08079437862683295, 0.01082522010747988],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9452706004231994, 0.046402265121552204, 0.008327134455248368],
                                [0.9427725147709679, 0.05472939957680057, 0.00249808565223151],
                                [0.9427725147709679, 0.0464022651215522, 0.01082522010747988],
                                [0.7864024425582345, 0.036084856923188136, 0.1775127005185774],
                                [0.7331497981296534, 0.21359755744176556, 0.05325264442858103],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9146242290538923, 0.04441199137843651, 0.040963779567671145],
                                [0.9023353641929825, 0.08537577094610765, 0.012288864860909876],
                                [0.9023353641929824, 0.04441199137843651, 0.05325264442858103],
                                [0.5919276339582453, 0.02345503851533398, 0.38461732752642075],
                                [0.47654496148466596, 0.4080723660417548, 0.11538267247357922],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.8697461827637832, 0.04149746697692806, 0.0887563502592887],
                                [0.8431198605494927, 0.1302538172362168, 0.026626322214290513],
                                [0.8431198605494927, 0.04149746697692808, 0.11538267247357922],
                                [0.3974528253582561, 0.010825220107479883, 0.591721954534264],
                                [0.21994012483967862, 0.602547174641744, 0.1775127005185774],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.8248681364736742, 0.03858294257541964, 0.13654892095090623],
                                [0.7839043569060029, 0.1751318635263259, 0.040963779567671145],
                                [0.783904356906003, 0.03858294257541964, 0.1775127005185774],
                                [0.26464964654332346, 0.0022005553270232348, 0.7331497981296533],
                                [0.04470952170364484, 0.7353503534566765, 0.21994012483967856],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.794221765104367, 0.03659266883230394, 0.16918556606332905],
                                [0.7434672063280175, 0.205778234895633, 0.05075455877634952],
                                [0.7434672063280174, 0.03659266883230394, 0.21994012483967856],
                                [0.7439750182371332, 0.21994012483967856, 0.036084856923188136],
                                [0.7331497981296534, 0.2560249817628667, 0.01082522010747988],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7634056062498247, 0.22826725929492692, 0.008327134455248368],
                                [0.7609075205975931, 0.23659439375017532, 0.00249808565223151],
                                [0.7609075205975931, 0.22826725929492694, 0.01082522010747988],
                                [0.6449745989628453, 0.1775127005185774, 0.1775127005185774],
                                [0.5917219545342641, 0.35502540103715485, 0.05325264442858103],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7405597403460803, 0.21847648008624856, 0.040963779567671145],
                                [0.7282708754851703, 0.25944025965391976, 0.012288864860909876],
                                [0.7282708754851703, 0.2184764800862486, 0.05325264442858103],
                                [0.5, 0.1153826724735792, 0.38461732752642075],
                                [0.38461732752642086, 0.4999999999999999, 0.11538267247357922],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7071046270078434, 0.20413902273286794, 0.0887563502592887],
                                [0.6804783047935529, 0.2928953729921566, 0.026626322214290513],
                                [0.6804783047935529, 0.2041390227328679, 0.11538267247357922],
                                [0.35502540103715496, 0.05325264442858102, 0.591721954534264],
                                [0.17751270051857748, 0.6449745989628451, 0.1775127005185774],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.6736495136696065, 0.1898015653794873, 0.13654892095090623],
                                [0.6326857341019353, 0.32635048633039354, 0.040963779567671145],
                                [0.6326857341019353, 0.1898015653794873, 0.1775127005185774],
                                [0.2560249817628668, 0.010825220107479883, 0.7331497981296533],
                                [0.03608485692318819, 0.7439750182371332, 0.21994012483967856],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.6508036477658621, 0.18001078617080893, 0.16918556606332905],
                                [0.6000490889895125, 0.34919635223413803, 0.05075455877634952],
                                [0.6000490889895125, 0.18001078617080896, 0.21994012483967856],
                                [0.4873701815921458, 0.476544961484666, 0.036084856923188136],
                                [0.47654496148466596, 0.5126298184078542, 0.01082522010747988],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.4970854755984916, 0.49458738994626006, 0.008327134455248368],
                                [0.49458738994626006, 0.5029145244015084, 0.00249808565223151],
                                [0.49458738994626006, 0.49458738994626006, 0.01082522010747988],
                                [0.43786997195500177, 0.38461732752642086, 0.1775127005185774],
                                [0.38461732752642075, 0.5621300280449982, 0.05325264442858103],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.48566254264661934, 0.4733736777857095, 0.040963779567671145],
                                [0.4733736777857095, 0.5143374573533807, 0.012288864860909876],
                                [0.4733736777857095, 0.4733736777857095, 0.05325264442858103],
                                [0.36538267247357925, 0.25, 0.38461732752642075],
                                [0.25, 0.6346173275264207, 0.11538267247357922],
                                [0.25, 0.25, 0.5],
                                [0.4689349859775009, 0.4423086637632104, 0.0887563502592887],
                                [0.44230866376321043, 0.5310650140224991, 0.026626322214290513],
                                [0.44230866376321043, 0.4423086637632103, 0.11538267247357922],
                                [0.29289537299215673, 0.11538267247357925, 0.591721954534264],
                                [0.11538267247357925, 0.7071046270078434, 0.1775127005185774],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.4522074293083824, 0.41124364974071137, 0.13654892095090623],
                                [0.41124364974071126, 0.5477925706916176, 0.040963779567671145],
                                [0.41124364974071126, 0.41124364974071137, 0.1775127005185774],
                                [0.24339516335501266, 0.023455038515334037, 0.7331497981296533],
                                [0.023455038515334037, 0.7566048366449873, 0.21994012483967856],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.4407844963565103, 0.3900299375801607, 0.16918556606332905],
                                [0.3900299375801608, 0.5592155036434897, 0.05075455877634952],
                                [0.39002993758016063, 0.39002993758016075, 0.21994012483967856],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.21994012483967862, 0.7692346550528415, 0.01082522010747988],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.22826725929492697, 0.7692346550528415, 0.00249808565223151],
                                [0.22826725929492697, 0.7609075205975931, 0.01082522010747988],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.17751270051857748, 0.7692346550528415, 0.05325264442858103],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671145],
                                [0.21847648008624865, 0.7692346550528415, 0.012288864860909876],
                                [0.21847648008624865, 0.7282708754851703, 0.05325264442858103],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.11538267247357925, 0.7692346550528415, 0.11538267247357922],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.204139022732868, 0.7692346550528415, 0.026626322214290513],
                                [0.204139022732868, 0.6804783047935528, 0.11538267247357922],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.05325264442858102, 0.7692346550528416, 0.1775127005185774],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.18980156537948734, 0.7692346550528415, 0.040963779567671145],
                                [0.18980156537948734, 0.6326857341019353, 0.1775127005185774],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.010825220107479883, 0.7692346550528415, 0.21994012483967856],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.18001078617080912, 0.7692346550528414, 0.05075455877634952],
                                [0.1800107861708089, 0.6000490889895125, 0.21994012483967856],
                                [0.05553474181112472, 0.9083804012656871, 0.036084856923188136],
                                [0.04470952170364484, 0.9444652581888753, 0.01082522010747988],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.04890035077378374, 0.9427725147709679, 0.008327134455248368],
                                [0.04640226512155221, 0.9510996492262163, 0.00249808565223151],
                                [0.04640226512155221, 0.9427725147709679, 0.01082522010747988],
                                [0.08933750135176921, 0.7331497981296534, 0.1775127005185774],
                                [0.03608485692318819, 0.9106624986482308, 0.05325264442858103],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.0567008562393464, 0.9023353641929824, 0.040963779567671145],
                                [0.044411991378436544, 0.9432991437606536, 0.012288864860909876],
                                [0.044411991378436544, 0.9023353641929824, 0.05325264442858103],
                                [0.1388377109889133, 0.47654496148466596, 0.38461732752642075],
                                [0.023455038515334037, 0.8611622890110867, 0.11538267247357922],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.06812378919121864, 0.8431198605494926, 0.0887563502592887],
                                [0.04149746697692813, 0.9318762108087814, 0.026626322214290513],
                                [0.04149746697692813, 0.8431198605494926, 0.11538267247357922],
                                [0.18833792062605736, 0.21994012483967862, 0.591721954534264],
                                [0.010825220107479883, 0.8116620793739427, 0.1775127005185774],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.07954672214309089, 0.7839043569060029, 0.13654892095090623],
                                [0.03858294257541972, 0.9204532778569091, 0.040963779567671145],
                                [0.03858294257541972, 0.7839043569060029, 0.1775127005185774],
                                [0.22214068016670185, 0.04470952170364484, 0.7331497981296533],
                                [0.0022005553270232348, 0.7778593198332981, 0.21994012483967856],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.08734722760865354, 0.7434672063280174, 0.16918556606332905],
                                [0.03659266883230394, 0.9126527723913466, 0.05075455877634952],
                                [0.03659266883230394, 0.7434672063280174, 0.21994012483967856],
                                [0.919205621373167, 0.04470952170364481, 0.036084856923188136],
                                [0.9083804012656872, 0.08079437862683295, 0.01082522010747988],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9481851248247078, 0.0464022651215522, 0.00541261005373994],
                                [0.9427725147709679, 0.05181487517529214, 0.00541261005373994],
                                [0.9427725147709679, 0.0464022651215522, 0.01082522010747988],
                                [0.7864024425582345, 0.036084856923188136, 0.1775127005185774],
                                [0.7331497981296534, 0.21359755744176556, 0.05325264442858103],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.928961686407273, 0.044411991378436516, 0.026626322214290513],
                                [0.9023353641929824, 0.07103831359272703, 0.026626322214290513],
                                [0.9023353641929824, 0.04441199137843651, 0.05325264442858103],
                                [0.5919276339582453, 0.02345503851533398, 0.38461732752642075],
                                [0.47654496148466596, 0.4080723660417548, 0.11538267247357922],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9008111967862824, 0.04149746697692808, 0.05769133623678961],
                                [0.8431198605494927, 0.09918880321371769, 0.05769133623678961],
                                [0.8431198605494927, 0.04149746697692808, 0.11538267247357922],
                                [0.3974528253582561, 0.010825220107479883, 0.591721954534264],
                                [0.21994012483967862, 0.602547174641744, 0.1775127005185774],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.8726607071652916, 0.03858294257541965, 0.0887563502592887],
                                [0.7839043569060029, 0.12733929283470835, 0.0887563502592887],
                                [0.783904356906003, 0.03858294257541964, 0.1775127005185774],
                                [0.26464964654332346, 0.0022005553270232348, 0.7331497981296533],
                                [0.04470952170364484, 0.7353503534566765, 0.21994012483967856],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.8534372687478567, 0.03659266883230397, 0.10997006241983928],
                                [0.7434672063280174, 0.14656273125214322, 0.10997006241983928],
                                [0.7434672063280174, 0.03659266883230394, 0.21994012483967856],
                                [0.7439750182371332, 0.21994012483967856, 0.036084856923188136],
                                [0.7331497981296534, 0.2560249817628667, 0.01082522010747988],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7663201306513331, 0.22826725929492694, 0.00541261005373994],
                                [0.7609075205975931, 0.23367986934866689, 0.00541261005373994],
                                [0.7609075205975931, 0.22826725929492694, 0.01082522010747988],
                                [0.6449745989628453, 0.1775127005185774, 0.1775127005185774],
                                [0.5917219545342641, 0.35502540103715485, 0.05325264442858103],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.754897197699461, 0.21847648008624856, 0.026626322214290513],
                                [0.7282708754851703, 0.2451028023005391, 0.026626322214290513],
                                [0.7282708754851703, 0.2184764800862486, 0.05325264442858103],
                                [0.5, 0.1153826724735792, 0.38461732752642075],
                                [0.38461732752642086, 0.4999999999999999, 0.11538267247357922],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7381696410303424, 0.20413902273286794, 0.05769133623678961],
                                [0.680478304793553, 0.2618303589696575, 0.05769133623678961],
                                [0.6804783047935529, 0.2041390227328679, 0.11538267247357922],
                                [0.35502540103715496, 0.05325264442858102, 0.591721954534264],
                                [0.17751270051857748, 0.6449745989628451, 0.1775127005185774],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.7214420843612239, 0.18980156537948734, 0.0887563502592887],
                                [0.6326857341019352, 0.278557915638776, 0.0887563502592887],
                                [0.6326857341019353, 0.1898015653794873, 0.1775127005185774],
                                [0.2560249817628668, 0.010825220107479883, 0.7331497981296533],
                                [0.03608485692318819, 0.7439750182371332, 0.21994012483967856],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.7100191514093518, 0.18001078617080893, 0.10997006241983928],
                                [0.6000490889895125, 0.2899808485906482, 0.10997006241983928],
                                [0.6000490889895125, 0.18001078617080896, 0.21994012483967856],
                                [0.4873701815921458, 0.476544961484666, 0.036084856923188136],
                                [0.47654496148466596, 0.5126298184078542, 0.01082522010747988],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.49458738994626006, 0.5, 0.00541261005373994],
                                [0.49458738994626006, 0.49458738994626006, 0.01082522010747988],
                                [0.43786997195500177, 0.38461732752642086, 0.1775127005185774],
                                [0.38461732752642075, 0.5621300280449982, 0.05325264442858103],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5, 0.4733736777857095, 0.026626322214290513],
                                [0.4733736777857095, 0.5, 0.026626322214290513],
                                [0.4733736777857095, 0.4733736777857095, 0.05325264442858103],
                                [0.36538267247357925, 0.25, 0.38461732752642075],
                                [0.25, 0.6346173275264207, 0.11538267247357922],
                                [0.25, 0.25, 0.5],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.4423086637632105, 0.49999999999999994, 0.05769133623678961],
                                [0.44230866376321043, 0.4423086637632103, 0.11538267247357922],
                                [0.29289537299215673, 0.11538267247357925, 0.591721954534264],
                                [0.11538267247357925, 0.7071046270078434, 0.1775127005185774],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.41124364974071126, 0.5, 0.0887563502592887],
                                [0.41124364974071126, 0.41124364974071137, 0.1775127005185774],
                                [0.24339516335501266, 0.023455038515334037, 0.7331497981296533],
                                [0.023455038515334037, 0.7566048366449873, 0.21994012483967856],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.3900299375801608, 0.4999999999999999, 0.10997006241983928],
                                [0.39002993758016063, 0.39002993758016075, 0.21994012483967856],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.21994012483967862, 0.7692346550528415, 0.01082522010747988],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.2336798693486669, 0.7609075205975931, 0.00541261005373994],
                                [0.22826725929492697, 0.7663201306513331, 0.00541261005373994],
                                [0.22826725929492697, 0.7609075205975931, 0.01082522010747988],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.17751270051857748, 0.7692346550528415, 0.05325264442858103],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.24510280230053916, 0.7282708754851703, 0.026626322214290513],
                                [0.21847648008624865, 0.7548971976994608, 0.026626322214290513],
                                [0.21847648008624865, 0.7282708754851703, 0.05325264442858103],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.11538267247357925, 0.7692346550528415, 0.11538267247357922],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.26183035896965756, 0.6804783047935529, 0.05769133623678961],
                                [0.204139022732868, 0.7381696410303424, 0.05769133623678961],
                                [0.204139022732868, 0.6804783047935528, 0.11538267247357922],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.05325264442858102, 0.7692346550528416, 0.1775127005185774],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.2785579156387761, 0.6326857341019352, 0.0887563502592887],
                                [0.18980156537948734, 0.7214420843612239, 0.0887563502592887],
                                [0.18980156537948734, 0.6326857341019353, 0.1775127005185774],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.010825220107479883, 0.7692346550528415, 0.21994012483967856],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.2899808485906482, 0.6000490889895125, 0.10997006241983928],
                                [0.18001078617080912, 0.7100191514093516, 0.10997006241983928],
                                [0.1800107861708089, 0.6000490889895125, 0.21994012483967856],
                                [0.05553474181112472, 0.9083804012656871, 0.036084856923188136],
                                [0.04470952170364484, 0.9444652581888753, 0.01082522010747988],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.05181487517529215, 0.9427725147709679, 0.00541261005373994],
                                [0.04640226512155221, 0.9481851248247078, 0.00541261005373994],
                                [0.04640226512155221, 0.9427725147709679, 0.01082522010747988],
                                [0.08933750135176921, 0.7331497981296534, 0.1775127005185774],
                                [0.03608485692318819, 0.9106624986482308, 0.05325264442858103],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.07103831359272705, 0.9023353641929824, 0.026626322214290513],
                                [0.044411991378436544, 0.928961686407273, 0.026626322214290513],
                                [0.044411991378436544, 0.9023353641929824, 0.05325264442858103],
                                [0.1388377109889133, 0.47654496148466596, 0.38461732752642075],
                                [0.023455038515334037, 0.8611622890110867, 0.11538267247357922],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.0991888032137177, 0.8431198605494927, 0.05769133623678961],
                                [0.04149746697692813, 0.9008111967862823, 0.05769133623678961],
                                [0.04149746697692813, 0.8431198605494926, 0.11538267247357922],
                                [0.18833792062605736, 0.21994012483967862, 0.591721954534264],
                                [0.010825220107479883, 0.8116620793739427, 0.1775127005185774],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.12733929283470835, 0.7839043569060029, 0.0887563502592887],
                                [0.03858294257541972, 0.8726607071652915, 0.0887563502592887],
                                [0.03858294257541972, 0.7839043569060029, 0.1775127005185774],
                                [0.22214068016670185, 0.04470952170364484, 0.7331497981296533],
                                [0.0022005553270232348, 0.7778593198332981, 0.21994012483967856],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.14656273125214325, 0.7434672063280174, 0.10997006241983928],
                                [0.03659266883230394, 0.8534372687478567, 0.10997006241983928],
                                [0.03659266883230394, 0.7434672063280174, 0.21994012483967856],
                                [0.919205621373167, 0.04470952170364481, 0.036084856923188136],
                                [0.9083804012656872, 0.08079437862683295, 0.01082522010747988],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9510996492262163, 0.046402265121552204, 0.0024980856522315107],
                                [0.9427725147709679, 0.04890035077378371, 0.008327134455248368],
                                [0.9427725147709679, 0.0464022651215522, 0.01082522010747988],
                                [0.7864024425582345, 0.036084856923188136, 0.1775127005185774],
                                [0.7331497981296534, 0.21359755744176556, 0.05325264442858103],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9432991437606536, 0.0444119913784365, 0.012288864860909878],
                                [0.9023353641929824, 0.05670085623934639, 0.040963779567671145],
                                [0.9023353641929824, 0.04441199137843651, 0.05325264442858103],
                                [0.5919276339582453, 0.02345503851533398, 0.38461732752642075],
                                [0.47654496148466596, 0.4080723660417548, 0.11538267247357922],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9318762108087815, 0.04149746697692808, 0.02662632221429052],
                                [0.8431198605494926, 0.0681237891912186, 0.0887563502592887],
                                [0.8431198605494927, 0.04149746697692808, 0.11538267247357922],
                                [0.3974528253582561, 0.010825220107479883, 0.591721954534264],
                                [0.21994012483967862, 0.602547174641744, 0.1775127005185774],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.9204532778569092, 0.03858294257541965, 0.04096377956767115],
                                [0.783904356906003, 0.0795467221430908, 0.13654892095090623],
                                [0.783904356906003, 0.03858294257541964, 0.1775127005185774],
                                [0.26464964654332346, 0.0022005553270232348, 0.7331497981296533],
                                [0.04470952170364484, 0.7353503534566765, 0.21994012483967856],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.9126527723913466, 0.036592668832303964, 0.050754558776349525],
                                [0.7434672063280175, 0.08734722760865346, 0.16918556606332905],
                                [0.7434672063280174, 0.03659266883230394, 0.21994012483967856],
                                [0.7439750182371332, 0.21994012483967856, 0.036084856923188136],
                                [0.7331497981296534, 0.2560249817628667, 0.01082522010747988],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7692346550528415, 0.22826725929492694, 0.0024980856522315107],
                                [0.7609075205975933, 0.23076534494715845, 0.008327134455248368],
                                [0.7609075205975931, 0.22826725929492694, 0.01082522010747988],
                                [0.6449745989628453, 0.1775127005185774, 0.1775127005185774],
                                [0.5917219545342641, 0.35502540103715485, 0.05325264442858103],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909878],
                                [0.7282708754851703, 0.23076534494715847, 0.040963779567671145],
                                [0.7282708754851703, 0.2184764800862486, 0.05325264442858103],
                                [0.5, 0.1153826724735792, 0.38461732752642075],
                                [0.38461732752642086, 0.4999999999999999, 0.11538267247357922],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.6804783047935528, 0.23076534494715845, 0.0887563502592887],
                                [0.6804783047935529, 0.2041390227328679, 0.11538267247357922],
                                [0.35502540103715496, 0.05325264442858102, 0.591721954534264],
                                [0.17751270051857748, 0.6449745989628451, 0.1775127005185774],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.6326857341019353, 0.23076534494715847, 0.13654892095090623],
                                [0.6326857341019353, 0.1898015653794873, 0.1775127005185774],
                                [0.2560249817628668, 0.010825220107479883, 0.7331497981296533],
                                [0.03608485692318819, 0.7439750182371332, 0.21994012483967856],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.7692346550528416, 0.18001078617080893, 0.050754558776349525],
                                [0.6000490889895125, 0.23076534494715847, 0.16918556606332905],
                                [0.6000490889895125, 0.18001078617080896, 0.21994012483967856],
                                [0.4873701815921458, 0.476544961484666, 0.036084856923188136],
                                [0.47654496148466596, 0.5126298184078542, 0.01082522010747988],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5029145244015084, 0.49458738994626006, 0.0024980856522315107],
                                [0.49458738994626006, 0.4970854755984916, 0.008327134455248368],
                                [0.49458738994626006, 0.49458738994626006, 0.01082522010747988],
                                [0.43786997195500177, 0.38461732752642086, 0.1775127005185774],
                                [0.38461732752642075, 0.5621300280449982, 0.05325264442858103],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5143374573533807, 0.4733736777857095, 0.012288864860909878],
                                [0.4733736777857095, 0.48566254264661934, 0.040963779567671145],
                                [0.4733736777857095, 0.4733736777857095, 0.05325264442858103],
                                [0.36538267247357925, 0.25, 0.38461732752642075],
                                [0.25, 0.6346173275264207, 0.11538267247357922],
                                [0.25, 0.25, 0.5],
                                [0.5310650140224991, 0.4423086637632104, 0.02662632221429052],
                                [0.4423086637632104, 0.4689349859775009, 0.0887563502592887],
                                [0.44230866376321043, 0.4423086637632103, 0.11538267247357922],
                                [0.29289537299215673, 0.11538267247357925, 0.591721954534264],
                                [0.11538267247357925, 0.7071046270078434, 0.1775127005185774],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.5477925706916176, 0.41124364974071126, 0.04096377956767115],
                                [0.41124364974071126, 0.45220742930838254, 0.13654892095090623],
                                [0.41124364974071126, 0.41124364974071137, 0.1775127005185774],
                                [0.24339516335501266, 0.023455038515334037, 0.7331497981296533],
                                [0.023455038515334037, 0.7566048366449873, 0.21994012483967856],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.5592155036434898, 0.3900299375801607, 0.050754558776349525],
                                [0.3900299375801608, 0.4407844963565102, 0.16918556606332905],
                                [0.39002993758016063, 0.39002993758016075, 0.21994012483967856],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.21994012483967862, 0.7692346550528415, 0.01082522010747988],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.23659439375017532, 0.7609075205975931, 0.0024980856522315107],
                                [0.22826725929492697, 0.7634056062498247, 0.008327134455248368],
                                [0.22826725929492697, 0.7609075205975931, 0.01082522010747988],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.17751270051857748, 0.7692346550528415, 0.05325264442858103],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.2594402596539198, 0.7282708754851703, 0.012288864860909878],
                                [0.21847648008624865, 0.7405597403460802, 0.040963779567671145],
                                [0.21847648008624865, 0.7282708754851703, 0.05325264442858103],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.11538267247357925, 0.7692346550528415, 0.11538267247357922],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.29289537299215673, 0.6804783047935528, 0.02662632221429052],
                                [0.204139022732868, 0.7071046270078433, 0.0887563502592887],
                                [0.204139022732868, 0.6804783047935528, 0.11538267247357922],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.05325264442858102, 0.7692346550528416, 0.1775127005185774],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.32635048633039365, 0.6326857341019352, 0.04096377956767115],
                                [0.18980156537948734, 0.6736495136696065, 0.13654892095090623],
                                [0.18980156537948734, 0.6326857341019353, 0.1775127005185774],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.010825220107479883, 0.7692346550528415, 0.21994012483967856],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.34919635223413803, 0.6000490889895125, 0.050754558776349525],
                                [0.18001078617080912, 0.6508036477658619, 0.16918556606332905],
                                [0.1800107861708089, 0.6000490889895125, 0.21994012483967856],
                                [0.05553474181112472, 0.9083804012656871, 0.036084856923188136],
                                [0.04470952170364484, 0.9444652581888753, 0.01082522010747988],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.054729399576800675, 0.9427725147709678, 0.0024980856522315107],
                                [0.04640226512155221, 0.9452706004231994, 0.008327134455248368],
                                [0.04640226512155221, 0.9427725147709679, 0.01082522010747988],
                                [0.08933750135176921, 0.7331497981296534, 0.1775127005185774],
                                [0.03608485692318819, 0.9106624986482308, 0.05325264442858103],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.08537577094610771, 0.9023353641929824, 0.012288864860909878],
                                [0.044411991378436544, 0.9146242290538923, 0.040963779567671145],
                                [0.044411991378436544, 0.9023353641929824, 0.05325264442858103],
                                [0.1388377109889133, 0.47654496148466596, 0.38461732752642075],
                                [0.023455038515334037, 0.8611622890110867, 0.11538267247357922],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.13025381723621687, 0.8431198605494926, 0.02662632221429052],
                                [0.04149746697692813, 0.8697461827637831, 0.0887563502592887],
                                [0.04149746697692813, 0.8431198605494926, 0.11538267247357922],
                                [0.18833792062605736, 0.21994012483967862, 0.591721954534264],
                                [0.010825220107479883, 0.8116620793739427, 0.1775127005185774],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.17513186352632593, 0.7839043569060029, 0.04096377956767115],
                                [0.03858294257541972, 0.8248681364736741, 0.13654892095090623],
                                [0.03858294257541972, 0.7839043569060029, 0.1775127005185774],
                                [0.22214068016670185, 0.04470952170364484, 0.7331497981296533],
                                [0.0022005553270232348, 0.7778593198332981, 0.21994012483967856],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.20577823489563307, 0.7434672063280174, 0.050754558776349525],
                                [0.03659266883230394, 0.794221765104367, 0.16918556606332905],
                                [0.03659266883230394, 0.7434672063280174, 0.21994012483967856],
                                [0.919205621373167, 0.04470952170364481, 0.036084856923188136],
                                [0.9083804012656872, 0.08079437862683295, 0.01082522010747988],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9530899229693319, 0.0464022651215522, 0.000507811909115818],
                                [0.942772514770968, 0.04691007703066802, 0.010317408198364061],
                                [0.9427725147709679, 0.0464022651215522, 0.01082522010747988],
                                [0.7864024425582345, 0.036084856923188136, 0.1775127005185774],
                                [0.7331497981296534, 0.21359755744176556, 0.05325264442858103],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9530899229693319, 0.0444119913784365, 0.002498085652231513],
                                [0.9023353641929824, 0.046910077030668025, 0.05075455877634951],
                                [0.9023353641929824, 0.04441199137843651, 0.05325264442858103],
                                [0.5919276339582453, 0.02345503851533398, 0.38461732752642075],
                                [0.47654496148466596, 0.4080723660417548, 0.11538267247357922],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9530899229693319, 0.04149746697692808, 0.0054126100537399465],
                                [0.8431198605494927, 0.04691007703066802, 0.10997006241983928],
                                [0.8431198605494927, 0.04149746697692808, 0.11538267247357922],
                                [0.3974528253582561, 0.010825220107479883, 0.591721954534264],
                                [0.21994012483967862, 0.602547174641744, 0.1775127005185774],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248379],
                                [0.7839043569060029, 0.04691007703066802, 0.16918556606332902],
                                [0.783904356906003, 0.03858294257541964, 0.1775127005185774],
                                [0.26464964654332346, 0.0022005553270232348, 0.7331497981296533],
                                [0.04470952170364484, 0.7353503534566765, 0.21994012483967856],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364074],
                                [0.7434672063280174, 0.04691007703066802, 0.2096227166413145],
                                [0.7434672063280174, 0.03659266883230394, 0.21994012483967856],
                                [0.7439750182371332, 0.21994012483967856, 0.036084856923188136],
                                [0.7331497981296534, 0.2560249817628667, 0.01082522010747988],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7712249287959572, 0.22826725929492694, 0.000507811909115818],
                                [0.7609075205975933, 0.22877507120404278, 0.010317408198364061],
                                [0.7609075205975931, 0.22826725929492694, 0.01082522010747988],
                                [0.6449745989628453, 0.1775127005185774, 0.1775127005185774],
                                [0.5917219545342641, 0.35502540103715485, 0.05325264442858103],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7790254342615199, 0.2184764800862486, 0.002498085652231513],
                                [0.7282708754851704, 0.2209745657384801, 0.05075455877634951],
                                [0.7282708754851703, 0.2184764800862486, 0.05325264442858103],
                                [0.5, 0.1153826724735792, 0.38461732752642075],
                                [0.38461732752642086, 0.4999999999999999, 0.11538267247357922],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7904483672133922, 0.20413902273286794, 0.0054126100537399465],
                                [0.6804783047935529, 0.20955163278660785, 0.10997006241983928],
                                [0.6804783047935529, 0.2041390227328679, 0.11538267247357922],
                                [0.35502540103715496, 0.05325264442858102, 0.591721954534264],
                                [0.17751270051857748, 0.6449745989628451, 0.1775127005185774],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.8018713001652643, 0.1898015653794873, 0.008327134455248379],
                                [0.6326857341019353, 0.1981286998347357, 0.16918556606332902],
                                [0.6326857341019353, 0.1898015653794873, 0.1775127005185774],
                                [0.2560249817628668, 0.010825220107479883, 0.7331497981296533],
                                [0.03608485692318819, 0.7439750182371332, 0.21994012483967856],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.8096718056308271, 0.18001078617080893, 0.010317408198364074],
                                [0.6000490889895125, 0.19032819436917303, 0.2096227166413145],
                                [0.6000490889895125, 0.18001078617080896, 0.21994012483967856],
                                [0.4873701815921458, 0.476544961484666, 0.036084856923188136],
                                [0.47654496148466596, 0.5126298184078542, 0.01082522010747988],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5049047981446241, 0.49458738994626006, 0.000507811909115818],
                                [0.4945873899462601, 0.49509520185537587, 0.010317408198364061],
                                [0.49458738994626006, 0.49458738994626006, 0.01082522010747988],
                                [0.43786997195500177, 0.38461732752642086, 0.1775127005185774],
                                [0.38461732752642075, 0.5621300280449982, 0.05325264442858103],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.524128236562059, 0.4733736777857095, 0.002498085652231513],
                                [0.4733736777857095, 0.475871763437941, 0.05075455877634951],
                                [0.4733736777857095, 0.4733736777857095, 0.05325264442858103],
                                [0.36538267247357925, 0.25, 0.38461732752642075],
                                [0.25, 0.6346173275264207, 0.11538267247357922],
                                [0.25, 0.25, 0.5],
                                [0.5522787261830497, 0.4423086637632104, 0.0054126100537399465],
                                [0.44230866376321043, 0.44772127381695026, 0.10997006241983928],
                                [0.44230866376321043, 0.4423086637632103, 0.11538267247357922],
                                [0.29289537299215673, 0.11538267247357925, 0.591721954534264],
                                [0.11538267247357925, 0.7071046270078434, 0.1775127005185774],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.5804292158040403, 0.4112436497407113, 0.008327134455248379],
                                [0.41124364974071126, 0.4195707841959597, 0.16918556606332902],
                                [0.41124364974071126, 0.41124364974071137, 0.1775127005185774],
                                [0.24339516335501266, 0.023455038515334037, 0.7331497981296533],
                                [0.023455038515334037, 0.7566048366449873, 0.21994012483967856],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.5996526542214753, 0.39002993758016075, 0.010317408198364074],
                                [0.3900299375801608, 0.4003473457785247, 0.2096227166413145],
                                [0.39002993758016063, 0.39002993758016075, 0.21994012483967856],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.21994012483967862, 0.7692346550528415, 0.01082522010747988],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.2385846674932911, 0.760907520597593, 0.000507811909115818],
                                [0.22826725929492697, 0.761415332506709, 0.010317408198364061],
                                [0.22826725929492697, 0.7609075205975931, 0.01082522010747988],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.17751270051857748, 0.7692346550528415, 0.05325264442858103],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.26923103886259814, 0.7282708754851703, 0.002498085652231513],
                                [0.21847648008624865, 0.7307689611374019, 0.05075455877634951],
                                [0.21847648008624865, 0.7282708754851703, 0.05325264442858103],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.11538267247357925, 0.7692346550528415, 0.11538267247357922],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.3141090851527073, 0.6804783047935528, 0.0054126100537399465],
                                [0.204139022732868, 0.6858909148472927, 0.10997006241983928],
                                [0.204139022732868, 0.6804783047935528, 0.11538267247357922],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.05325264442858102, 0.7692346550528416, 0.1775127005185774],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.35898713144281635, 0.6326857341019353, 0.008327134455248379],
                                [0.18980156537948734, 0.6410128685571836, 0.16918556606332902],
                                [0.18980156537948734, 0.6326857341019353, 0.1775127005185774],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.010825220107479883, 0.7692346550528415, 0.21994012483967856],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.3896335028121235, 0.6000490889895125, 0.010317408198364074],
                                [0.18001078617080912, 0.6103664971878764, 0.2096227166413145],
                                [0.1800107861708089, 0.6000490889895125, 0.21994012483967856],
                                [0.05553474181112472, 0.9083804012656871, 0.036084856923188136],
                                [0.04470952170364484, 0.9444652581888753, 0.01082522010747988],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.05671967331991634, 0.9427725147709678, 0.000507811909115818],
                                [0.04640226512155221, 0.9432803266800838, 0.010317408198364061],
                                [0.04640226512155221, 0.9427725147709679, 0.01082522010747988],
                                [0.08933750135176921, 0.7331497981296534, 0.1775127005185774],
                                [0.03608485692318819, 0.9106624986482308, 0.05325264442858103],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.09516655015478603, 0.9023353641929824, 0.002498085652231513],
                                [0.044411991378436544, 0.904833449845214, 0.05075455877634951],
                                [0.044411991378436544, 0.9023353641929824, 0.05325264442858103],
                                [0.1388377109889133, 0.47654496148466596, 0.38461732752642075],
                                [0.023455038515334037, 0.8611622890110867, 0.11538267247357922],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.15146752939676744, 0.8431198605494926, 0.0054126100537399465],
                                [0.04149746697692813, 0.8485324706032326, 0.10997006241983928],
                                [0.04149746697692813, 0.8431198605494926, 0.11538267247357922],
                                [0.18833792062605736, 0.21994012483967862, 0.591721954534264],
                                [0.010825220107479883, 0.8116620793739427, 0.1775127005185774],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.20776850863874874, 0.7839043569060029, 0.008327134455248379],
                                [0.03858294257541972, 0.7922314913612513, 0.16918556606332902],
                                [0.03858294257541972, 0.7839043569060029, 0.1775127005185774],
                                [0.22214068016670185, 0.04470952170364484, 0.7331497981296533],
                                [0.0022005553270232348, 0.7778593198332981, 0.21994012483967856],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.24621538547361843, 0.7434672063280175, 0.010317408198364074],
                                [0.03659266883230394, 0.7537846145263816, 0.2096227166413145],
                                [0.03659266883230394, 0.7434672063280174, 0.21994012483967856],
                                [0.9318354397810211, 0.04470952170364481, 0.02345503851533401],
                                [0.9083804012656871, 0.06816456021897882, 0.02345503851533401],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9318354397810211, 0.045809799367156415, 0.022354760851822406],
                                [0.9307351621175095, 0.06816456021897882, 0.0011002776635116035],
                                [0.9307351621175095, 0.045809799367156415, 0.02345503851533401],
                                [0.8485324706032327, 0.036084856923188136, 0.11538267247357922],
                                [0.7331497981296534, 0.15146752939676736, 0.11538267247357922],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.8485324706032327, 0.04149746697692805, 0.10997006241983928],
                                [0.8431198605494927, 0.15146752939676736, 0.00541261005373994],
                                [0.8431198605494927, 0.04149746697692808, 0.11538267247357922],
                                [0.726544961484666, 0.023455038515334037, 0.25],
                                [0.47654496148466596, 0.27345503851533404, 0.25],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.726544961484666, 0.035182557773001, 0.23827248074233298],
                                [0.7148174422269991, 0.273455038515334, 0.011727519257667005],
                                [0.7148174422269991, 0.035182557773001, 0.25],
                                [0.6045574523660994, 0.010825220107479883, 0.38461732752642075],
                                [0.21994012483967862, 0.39544254763390063, 0.38461732752642075],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.6045574523660995, 0.028867648569073923, 0.36657489906482665],
                                [0.5865150239045053, 0.39544254763390063, 0.018042428461594068],
                                [0.5865150239045054, 0.028867648569073923, 0.38461732752642075],
                                [0.5212544831883108, 0.0022005553270232348, 0.47654496148466596],
                                [0.04470952170364484, 0.4787455168116892, 0.47654496148466596],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.5212544831883108, 0.0245553161788456, 0.45419020063284354],
                                [0.4988997223364884, 0.4787455168116892, 0.022354760851822406],
                                [0.4988997223364884, 0.024555316178845654, 0.47654496148466596],
                                [0.7566048366449873, 0.21994012483967856, 0.02345503851533401],
                                [0.7331497981296534, 0.24339516335501257, 0.02345503851533401],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.752292504254759, 0.2253527348934185, 0.022354760851822406],
                                [0.7511922265912474, 0.24770749574524092, 0.0011002776635116035],
                                [0.7511922265912474, 0.2253527348934185, 0.02345503851533401],
                                [0.7071046270078434, 0.1775127005185774, 0.11538267247357922],
                                [0.5917219545342641, 0.2928953729921566, 0.11538267247357922],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.6858909148472928, 0.2041390227328679, 0.10997006241983928],
                                [0.6804783047935529, 0.3141090851527072, 0.00541261005373994],
                                [0.6804783047935529, 0.2041390227328679, 0.11538267247357922],
                                [0.6346173275264207, 0.11538267247357925, 0.25],
                                [0.38461732752642086, 0.36538267247357914, 0.25],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.5886535105472982, 0.17307400871036882, 0.23827248074233298],
                                [0.5769259912896312, 0.4113464894527018, 0.011727519257667005],
                                [0.5769259912896312, 0.17307400871036882, 0.25],
                                [0.5621300280449982, 0.05325264442858102, 0.38461732752642075],
                                [0.17751270051857748, 0.43786997195500177, 0.38461732752642075],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.4914161062473037, 0.14200899468786965, 0.36657489906482665],
                                [0.4733736777857095, 0.5085838937526964, 0.018042428461594068],
                                [0.4733736777857096, 0.14200899468786965, 0.38461732752642075],
                                [0.5126298184078542, 0.010825220107479883, 0.47654496148466596],
                                [0.03608485692318819, 0.48737018159214585, 0.47654496148466596],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.4250145168398374, 0.12079528252731908, 0.45419020063284354],
                                [0.40265975598801484, 0.5749854831601627, 0.022354760851822406],
                                [0.40265975598801496, 0.12079528252731908, 0.47654496148466596],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.47654496148466596, 0.5, 0.02345503851533401],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.4893727584058446, 0.488272480742333, 0.022354760851822406],
                                [0.488272480742333, 0.5106272415941554, 0.0011002776635116035],
                                [0.488272480742333, 0.488272480742333, 0.02345503851533401],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.38461732752642075, 0.5, 0.11538267247357922],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.44772127381695037, 0.4423086637632103, 0.10997006241983928],
                                [0.44230866376321043, 0.5522787261830496, 0.00541261005373994],
                                [0.44230866376321043, 0.4423086637632103, 0.11538267247357922],
                                [0.5, 0.25, 0.25],
                                [0.25, 0.5, 0.25],
                                [0.25, 0.25, 0.5],
                                [0.386727519257667, 0.375, 0.23827248074233298],
                                [0.375, 0.613272480742333, 0.011727519257667005],
                                [0.375, 0.375, 0.25],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.11538267247357925, 0.5, 0.38461732752642075],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.3257337646983838, 0.30769133623678957, 0.36657489906482665],
                                [0.3076913362367897, 0.6742662353016162, 0.018042428461594068],
                                [0.3076913362367897, 0.30769133623678957, 0.38461732752642075],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.023455038515334037, 0.5, 0.47654496148466596],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.28408228010948944, 0.261727519257667, 0.45419020063284354],
                                [0.261727519257667, 0.7159177198905106, 0.022354760851822406],
                                [0.261727519257667, 0.261727519257667, 0.47654496148466596],
                                [0.24339516335501266, 0.7331497981296533, 0.02345503851533401],
                                [0.21994012483967862, 0.7566048366449873, 0.02345503851533401],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.22645301255693018, 0.7511922265912474, 0.022354760851822406],
                                [0.22535273489341856, 0.7735469874430698, 0.0011002776635116035],
                                [0.22535273489341856, 0.7511922265912474, 0.02345503851533401],
                                [0.29289537299215673, 0.591721954534264, 0.11538267247357922],
                                [0.17751270051857748, 0.7071046270078433, 0.11538267247357922],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.20955163278660793, 0.6804783047935528, 0.10997006241983928],
                                [0.204139022732868, 0.7904483672133921, 0.00541261005373994],
                                [0.204139022732868, 0.6804783047935528, 0.11538267247357922],
                                [0.36538267247357925, 0.38461732752642075, 0.25],
                                [0.11538267247357925, 0.6346173275264207, 0.25],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.18480152796803595, 0.5769259912896311, 0.23827248074233298],
                                [0.17307400871036882, 0.8151984720319642, 0.011727519257667005],
                                [0.17307400871036882, 0.5769259912896312, 0.25],
                                [0.43786997195500177, 0.17751270051857748, 0.38461732752642075],
                                [0.05325264442858102, 0.5621300280449982, 0.38461732752642075],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.16005142314946386, 0.4733736777857095, 0.36657489906482665],
                                [0.14200899468786976, 0.8399485768505361, 0.018042428461594068],
                                [0.14200899468786976, 0.4733736777857095, 0.38461732752642075],
                                [0.48737018159214585, 0.03608485692318819, 0.47654496148466596],
                                [0.010825220107479883, 0.5126298184078542, 0.47654496148466596],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.1431500433791416, 0.40265975598801484, 0.45419020063284354],
                                [0.12079528252731919, 0.8568499566208584, 0.022354760851822406],
                                [0.12079528252731919, 0.40265975598801484, 0.47654496148466596],
                                [0.06816456021897888, 0.9083804012656871, 0.02345503851533401],
                                [0.04470952170364484, 0.9318354397810211, 0.02345503851533401],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.045809799367156456, 0.9530899229693319, 0.0011002776635116035],
                                [0.045809799367156456, 0.9307351621175095, 0.02345503851533401],
                                [0.15146752939676744, 0.7331497981296533, 0.11538267247357922],
                                [0.03608485692318819, 0.8485324706032326, 0.11538267247357922],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.04149746697692813, 0.9530899229693319, 0.00541261005373994],
                                [0.04149746697692813, 0.8431198605494926, 0.11538267247357922],
                                [0.27345503851533404, 0.47654496148466596, 0.25],
                                [0.023455038515334037, 0.726544961484666, 0.25],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.035182557773001055, 0.9530899229693319, 0.011727519257667005],
                                [0.035182557773001055, 0.714817442226999, 0.25],
                                [0.39544254763390063, 0.21994012483967862, 0.38461732752642075],
                                [0.010825220107479883, 0.6045574523660994, 0.38461732752642075],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.028867648569073978, 0.9530899229693319, 0.018042428461594068],
                                [0.028867648569073978, 0.5865150239045053, 0.38461732752642075],
                                [0.4787455168116892, 0.04470952170364484, 0.47654496148466596],
                                [0.0022005553270232348, 0.5212544831883108, 0.47654496148466596],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.024555316178845654, 0.9530899229693319, 0.022354760851822406],
                                [0.024555316178845654, 0.4988997223364884, 0.47654496148466596],
                                [0.9318354397810211, 0.04470952170364481, 0.02345503851533401],
                                [0.9083804012656871, 0.06816456021897882, 0.02345503851533401],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9361477721712494, 0.045809799367156415, 0.018042428461594068],
                                [0.9307351621175096, 0.06385222782875048, 0.00541261005373994],
                                [0.9307351621175095, 0.045809799367156415, 0.02345503851533401],
                                [0.8485324706032327, 0.036084856923188136, 0.11538267247357922],
                                [0.7331497981296534, 0.15146752939676736, 0.11538267247357922],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.8697461827637832, 0.04149746697692806, 0.0887563502592887],
                                [0.8431198605494927, 0.1302538172362168, 0.026626322214290513],
                                [0.8431198605494927, 0.04149746697692808, 0.11538267247357922],
                                [0.726544961484666, 0.023455038515334037, 0.25],
                                [0.47654496148466596, 0.27345503851533404, 0.25],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.7725087784637887, 0.035182557773001, 0.19230866376321037],
                                [0.7148174422269991, 0.22749122153621137, 0.05769133623678961],
                                [0.7148174422269991, 0.035182557773001, 0.25],
                                [0.6045574523660994, 0.010825220107479883, 0.38461732752642075],
                                [0.21994012483967862, 0.39544254763390063, 0.38461732752642075],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.6752713741637941, 0.028867648569073923, 0.295860977267132],
                                [0.5865150239045052, 0.32472862583620604, 0.0887563502592887],
                                [0.5865150239045054, 0.028867648569073923, 0.38461732752642075],
                                [0.5212544831883108, 0.0022005553270232348, 0.47654496148466596],
                                [0.04470952170364484, 0.4787455168116892, 0.47654496148466596],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.6088697847563278, 0.0245553161788456, 0.36657489906482665],
                                [0.4988997223364884, 0.3911302152436723, 0.10997006241983928],
                                [0.4988997223364884, 0.024555316178845654, 0.47654496148466596],
                                [0.7566048366449873, 0.21994012483967856, 0.02345503851533401],
                                [0.7331497981296534, 0.24339516335501257, 0.02345503851533401],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7566048366449873, 0.2253527348934185, 0.018042428461594068],
                                [0.7511922265912475, 0.24339516335501257, 0.00541261005373994],
                                [0.7511922265912474, 0.2253527348934185, 0.02345503851533401],
                                [0.7071046270078434, 0.1775127005185774, 0.11538267247357922],
                                [0.5917219545342641, 0.2928953729921566, 0.11538267247357922],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7071046270078434, 0.20413902273286794, 0.0887563502592887],
                                [0.6804783047935529, 0.2928953729921566, 0.026626322214290513],
                                [0.6804783047935529, 0.2041390227328679, 0.11538267247357922],
                                [0.6346173275264207, 0.11538267247357925, 0.25],
                                [0.38461732752642086, 0.36538267247357914, 0.25],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.6346173275264209, 0.17307400871036882, 0.19230866376321037],
                                [0.5769259912896312, 0.3653826724735792, 0.05769133623678961],
                                [0.5769259912896312, 0.17307400871036882, 0.25],
                                [0.5621300280449982, 0.05325264442858102, 0.38461732752642075],
                                [0.17751270051857748, 0.43786997195500177, 0.38461732752642075],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.5621300280449982, 0.14200899468786976, 0.295860977267132],
                                [0.47337367778570943, 0.4378699719550018, 0.0887563502592887],
                                [0.4733736777857096, 0.14200899468786965, 0.38461732752642075],
                                [0.5126298184078542, 0.010825220107479883, 0.47654496148466596],
                                [0.03608485692318819, 0.48737018159214585, 0.47654496148466596],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.5126298184078542, 0.12079528252731914, 0.36657489906482665],
                                [0.40265975598801484, 0.48737018159214585, 0.10997006241983928],
                                [0.40265975598801496, 0.12079528252731908, 0.47654496148466596],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.47654496148466596, 0.5, 0.02345503851533401],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.4936850907960729, 0.488272480742333, 0.018042428461594068],
                                [0.488272480742333, 0.5063149092039271, 0.00541261005373994],
                                [0.488272480742333, 0.488272480742333, 0.02345503851533401],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.38461732752642075, 0.5, 0.11538267247357922],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.4689349859775009, 0.4423086637632104, 0.0887563502592887],
                                [0.44230866376321043, 0.5310650140224991, 0.026626322214290513],
                                [0.44230866376321043, 0.4423086637632103, 0.11538267247357922],
                                [0.5, 0.25, 0.25],
                                [0.25, 0.5, 0.25],
                                [0.25, 0.25, 0.5],
                                [0.43269133623678974, 0.37499999999999994, 0.19230866376321037],
                                [0.375, 0.5673086637632104, 0.05769133623678961],
                                [0.375, 0.375, 0.25],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.11538267247357925, 0.5, 0.38461732752642075],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.3964476864960783, 0.3076913362367897, 0.295860977267132],
                                [0.3076913362367897, 0.6035523135039216, 0.0887563502592887],
                                [0.3076913362367897, 0.30769133623678957, 0.38461732752642075],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.023455038515334037, 0.5, 0.47654496148466596],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.37169758167750633, 0.261727519257667, 0.36657489906482665],
                                [0.261727519257667, 0.6283024183224937, 0.10997006241983928],
                                [0.261727519257667, 0.261727519257667, 0.47654496148466596],
                                [0.24339516335501266, 0.7331497981296533, 0.02345503851533401],
                                [0.21994012483967862, 0.7566048366449873, 0.02345503851533401],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.22535273489341856, 0.7692346550528415, 0.00541261005373994],
                                [0.22535273489341856, 0.7511922265912474, 0.02345503851533401],
                                [0.29289537299215673, 0.591721954534264, 0.11538267247357922],
                                [0.17751270051857748, 0.7071046270078433, 0.11538267247357922],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.204139022732868, 0.7692346550528415, 0.026626322214290513],
                                [0.204139022732868, 0.6804783047935528, 0.11538267247357922],
                                [0.36538267247357925, 0.38461732752642075, 0.25],
                                [0.11538267247357925, 0.6346173275264207, 0.25],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.17307400871036882, 0.7692346550528416, 0.05769133623678961],
                                [0.17307400871036882, 0.5769259912896312, 0.25],
                                [0.43786997195500177, 0.17751270051857748, 0.38461732752642075],
                                [0.05325264442858102, 0.5621300280449982, 0.38461732752642075],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.14200899468786976, 0.7692346550528415, 0.0887563502592887],
                                [0.14200899468786976, 0.4733736777857095, 0.38461732752642075],
                                [0.48737018159214585, 0.03608485692318819, 0.47654496148466596],
                                [0.010825220107479883, 0.5126298184078542, 0.47654496148466596],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.12079528252731919, 0.7692346550528415, 0.10997006241983928],
                                [0.12079528252731919, 0.40265975598801484, 0.47654496148466596],
                                [0.06816456021897888, 0.9083804012656871, 0.02345503851533401],
                                [0.04470952170364484, 0.9318354397810211, 0.02345503851533401],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.0512224094208964, 0.9307351621175095, 0.018042428461594068],
                                [0.045809799367156456, 0.9487775905791036, 0.00541261005373994],
                                [0.045809799367156456, 0.9307351621175095, 0.02345503851533401],
                                [0.15146752939676744, 0.7331497981296533, 0.11538267247357922],
                                [0.03608485692318819, 0.8485324706032326, 0.11538267247357922],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.06812378919121864, 0.8431198605494926, 0.0887563502592887],
                                [0.04149746697692813, 0.9318762108087814, 0.026626322214290513],
                                [0.04149746697692813, 0.8431198605494926, 0.11538267247357922],
                                [0.27345503851533404, 0.47654496148466596, 0.25],
                                [0.023455038515334037, 0.726544961484666, 0.25],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.09287389400979063, 0.7148174422269991, 0.19230866376321037],
                                [0.035182557773001055, 0.9071261059902094, 0.05769133623678961],
                                [0.035182557773001055, 0.714817442226999, 0.25],
                                [0.39544254763390063, 0.21994012483967862, 0.38461732752642075],
                                [0.010825220107479883, 0.6045574523660994, 0.38461732752642075],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.11762399882836272, 0.5865150239045053, 0.295860977267132],
                                [0.028867648569073978, 0.8823760011716373, 0.0887563502592887],
                                [0.028867648569073978, 0.5865150239045053, 0.38461732752642075],
                                [0.4787455168116892, 0.04470952170364484, 0.47654496148466596],
                                [0.0022005553270232348, 0.5212544831883108, 0.47654496148466596],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.13452537859868496, 0.4988997223364884, 0.36657489906482665],
                                [0.024555316178845654, 0.865474621401315, 0.10997006241983928],
                                [0.024555316178845654, 0.4988997223364884, 0.47654496148466596],
                                [0.9318354397810211, 0.04470952170364481, 0.02345503851533401],
                                [0.9083804012656871, 0.06816456021897882, 0.02345503851533401],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9424626813751765, 0.045809799367156415, 0.011727519257667005],
                                [0.9307351621175095, 0.05753731862482342, 0.011727519257667005],
                                [0.9307351621175095, 0.045809799367156415, 0.02345503851533401],
                                [0.8485324706032327, 0.036084856923188136, 0.11538267247357922],
                                [0.7331497981296534, 0.15146752939676736, 0.11538267247357922],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9008111967862824, 0.04149746697692808, 0.05769133623678961],
                                [0.8431198605494927, 0.09918880321371769, 0.05769133623678961],
                                [0.8431198605494927, 0.04149746697692808, 0.11538267247357922],
                                [0.726544961484666, 0.023455038515334037, 0.25],
                                [0.47654496148466596, 0.27345503851533404, 0.25],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.8398174422269991, 0.035182557773001, 0.125],
                                [0.7148174422269991, 0.160182557773001, 0.125],
                                [0.7148174422269991, 0.035182557773001, 0.25],
                                [0.6045574523660994, 0.010825220107479883, 0.38461732752642075],
                                [0.21994012483967862, 0.39544254763390063, 0.38461732752642075],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.7788236876677157, 0.02886764856907395, 0.19230866376321037],
                                [0.5865150239045054, 0.22117631233228435, 0.19230866376321037],
                                [0.5865150239045054, 0.028867648569073923, 0.38461732752642075],
                                [0.5212544831883108, 0.0022005553270232348, 0.47654496148466596],
                                [0.04470952170364484, 0.4787455168116892, 0.47654496148466596],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.7371722030788214, 0.024555316178845654, 0.23827248074233298],
                                [0.4988997223364884, 0.26282779692117864, 0.23827248074233298],
                                [0.4988997223364884, 0.024555316178845654, 0.47654496148466596],
                                [0.7566048366449873, 0.21994012483967856, 0.02345503851533401],
                                [0.7331497981296534, 0.24339516335501257, 0.02345503851533401],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7629197458489145, 0.2253527348934185, 0.011727519257667005],
                                [0.7511922265912474, 0.23708025415108552, 0.011727519257667005],
                                [0.7511922265912474, 0.2253527348934185, 0.02345503851533401],
                                [0.7071046270078434, 0.1775127005185774, 0.11538267247357922],
                                [0.5917219545342641, 0.2928953729921566, 0.11538267247357922],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7381696410303424, 0.20413902273286794, 0.05769133623678961],
                                [0.680478304793553, 0.2618303589696575, 0.05769133623678961],
                                [0.6804783047935529, 0.2041390227328679, 0.11538267247357922],
                                [0.6346173275264207, 0.11538267247357925, 0.25],
                                [0.38461732752642086, 0.36538267247357914, 0.25],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7019259912896312, 0.17307400871036882, 0.125],
                                [0.5769259912896312, 0.2980740087103688, 0.125],
                                [0.5769259912896312, 0.17307400871036882, 0.25],
                                [0.5621300280449982, 0.05325264442858102, 0.38461732752642075],
                                [0.17751270051857748, 0.43786997195500177, 0.38461732752642075],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.6656823415489199, 0.14200899468786976, 0.19230866376321037],
                                [0.47337367778570955, 0.33431765845108014, 0.19230866376321037],
                                [0.4733736777857096, 0.14200899468786965, 0.38461732752642075],
                                [0.5126298184078542, 0.010825220107479883, 0.47654496148466596],
                                [0.03608485692318819, 0.48737018159214585, 0.47654496148466596],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.6409322367303478, 0.12079528252731919, 0.23827248074233298],
                                [0.40265975598801484, 0.3590677632696522, 0.23827248074233298],
                                [0.40265975598801496, 0.12079528252731908, 0.47654496148466596],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.47654496148466596, 0.5, 0.02345503851533401],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.488272480742333, 0.5, 0.011727519257667005],
                                [0.488272480742333, 0.488272480742333, 0.02345503851533401],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.38461732752642075, 0.5, 0.11538267247357922],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.4423086637632105, 0.49999999999999994, 0.05769133623678961],
                                [0.44230866376321043, 0.4423086637632103, 0.11538267247357922],
                                [0.5, 0.25, 0.25],
                                [0.25, 0.5, 0.25],
                                [0.25, 0.25, 0.5],
                                [0.5, 0.375, 0.125],
                                [0.375, 0.5, 0.125],
                                [0.375, 0.375, 0.25],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.11538267247357925, 0.5, 0.38461732752642075],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.30769133623678974, 0.49999999999999994, 0.19230866376321037],
                                [0.3076913362367897, 0.30769133623678957, 0.38461732752642075],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.023455038515334037, 0.5, 0.47654496148466596],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.261727519257667, 0.5, 0.23827248074233298],
                                [0.261727519257667, 0.261727519257667, 0.47654496148466596],
                                [0.24339516335501266, 0.7331497981296533, 0.02345503851533401],
                                [0.21994012483967862, 0.7566048366449873, 0.02345503851533401],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.23708025415108558, 0.7511922265912474, 0.011727519257667005],
                                [0.22535273489341856, 0.7629197458489144, 0.011727519257667005],
                                [0.22535273489341856, 0.7511922265912474, 0.02345503851533401],
                                [0.29289537299215673, 0.591721954534264, 0.11538267247357922],
                                [0.17751270051857748, 0.7071046270078433, 0.11538267247357922],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.26183035896965756, 0.6804783047935529, 0.05769133623678961],
                                [0.204139022732868, 0.7381696410303424, 0.05769133623678961],
                                [0.204139022732868, 0.6804783047935528, 0.11538267247357922],
                                [0.36538267247357925, 0.38461732752642075, 0.25],
                                [0.11538267247357925, 0.6346173275264207, 0.25],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.2980740087103688, 0.5769259912896312, 0.125],
                                [0.17307400871036882, 0.7019259912896312, 0.125],
                                [0.17307400871036882, 0.5769259912896312, 0.25],
                                [0.43786997195500177, 0.17751270051857748, 0.38461732752642075],
                                [0.05325264442858102, 0.5621300280449982, 0.38461732752642075],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.33431765845108025, 0.47337367778570943, 0.19230866376321037],
                                [0.14200899468786976, 0.6656823415489199, 0.19230866376321037],
                                [0.14200899468786976, 0.4733736777857095, 0.38461732752642075],
                                [0.48737018159214585, 0.03608485692318819, 0.47654496148466596],
                                [0.010825220107479883, 0.5126298184078542, 0.47654496148466596],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.3590677632696522, 0.40265975598801484, 0.23827248074233298],
                                [0.12079528252731919, 0.6409322367303478, 0.23827248074233298],
                                [0.12079528252731919, 0.40265975598801484, 0.47654496148466596],
                                [0.06816456021897888, 0.9083804012656871, 0.02345503851533401],
                                [0.04470952170364484, 0.9318354397810211, 0.02345503851533401],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.057537318624823475, 0.9307351621175095, 0.011727519257667005],
                                [0.045809799367156456, 0.9424626813751765, 0.011727519257667005],
                                [0.045809799367156456, 0.9307351621175095, 0.02345503851533401],
                                [0.15146752939676744, 0.7331497981296533, 0.11538267247357922],
                                [0.03608485692318819, 0.8485324706032326, 0.11538267247357922],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.0991888032137177, 0.8431198605494927, 0.05769133623678961],
                                [0.04149746697692813, 0.9008111967862823, 0.05769133623678961],
                                [0.04149746697692813, 0.8431198605494926, 0.11538267247357922],
                                [0.27345503851533404, 0.47654496148466596, 0.25],
                                [0.023455038515334037, 0.726544961484666, 0.25],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.16018255777300106, 0.714817442226999, 0.125],
                                [0.035182557773001055, 0.839817442226999, 0.125],
                                [0.035182557773001055, 0.714817442226999, 0.25],
                                [0.39544254763390063, 0.21994012483967862, 0.38461732752642075],
                                [0.010825220107479883, 0.6045574523660994, 0.38461732752642075],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.2211763123322843, 0.5865150239045054, 0.19230866376321037],
                                [0.028867648569073978, 0.7788236876677157, 0.19230866376321037],
                                [0.028867648569073978, 0.5865150239045053, 0.38461732752642075],
                                [0.4787455168116892, 0.04470952170364484, 0.47654496148466596],
                                [0.0022005553270232348, 0.5212544831883108, 0.47654496148466596],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.26282779692117864, 0.4988997223364884, 0.23827248074233298],
                                [0.024555316178845654, 0.7371722030788214, 0.23827248074233298],
                                [0.024555316178845654, 0.4988997223364884, 0.47654496148466596],
                                [0.9318354397810211, 0.04470952170364481, 0.02345503851533401],
                                [0.9083804012656871, 0.06816456021897882, 0.02345503851533401],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9487775905791036, 0.045809799367156415, 0.005412610053739941],
                                [0.9307351621175095, 0.051222409420896356, 0.018042428461594068],
                                [0.9307351621175095, 0.045809799367156415, 0.02345503851533401],
                                [0.8485324706032327, 0.036084856923188136, 0.11538267247357922],
                                [0.7331497981296534, 0.15146752939676736, 0.11538267247357922],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9318762108087815, 0.04149746697692808, 0.02662632221429052],
                                [0.8431198605494926, 0.0681237891912186, 0.0887563502592887],
                                [0.8431198605494927, 0.04149746697692808, 0.11538267247357922],
                                [0.726544961484666, 0.023455038515334037, 0.25],
                                [0.47654496148466596, 0.27345503851533404, 0.25],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9071261059902093, 0.035182557773001014, 0.057691336236789625],
                                [0.7148174422269991, 0.09287389400979063, 0.19230866376321037],
                                [0.7148174422269991, 0.035182557773001, 0.25],
                                [0.6045574523660994, 0.010825220107479883, 0.38461732752642075],
                                [0.21994012483967862, 0.39544254763390063, 0.38461732752642075],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.8823760011716373, 0.02886764856907395, 0.08875635025928873],
                                [0.5865150239045053, 0.11762399882836272, 0.295860977267132],
                                [0.5865150239045054, 0.028867648569073923, 0.38461732752642075],
                                [0.5212544831883108, 0.0022005553270232348, 0.47654496148466596],
                                [0.04470952170364484, 0.4787455168116892, 0.47654496148466596],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.8654746214013151, 0.0245553161788456, 0.10997006241983931],
                                [0.4988997223364884, 0.13452537859868496, 0.36657489906482665],
                                [0.4988997223364884, 0.024555316178845654, 0.47654496148466596],
                                [0.7566048366449873, 0.21994012483967856, 0.02345503851533401],
                                [0.7331497981296534, 0.24339516335501257, 0.02345503851533401],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7692346550528415, 0.2253527348934185, 0.005412610053739941],
                                [0.7511922265912474, 0.23076534494715845, 0.018042428461594068],
                                [0.7511922265912474, 0.2253527348934185, 0.02345503851533401],
                                [0.7071046270078434, 0.1775127005185774, 0.11538267247357922],
                                [0.5917219545342641, 0.2928953729921566, 0.11538267247357922],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7692346550528415, 0.20413902273286794, 0.02662632221429052],
                                [0.6804783047935528, 0.23076534494715845, 0.0887563502592887],
                                [0.6804783047935529, 0.2041390227328679, 0.11538267247357922],
                                [0.6346173275264207, 0.11538267247357925, 0.25],
                                [0.38461732752642086, 0.36538267247357914, 0.25],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7692346550528415, 0.17307400871036882, 0.057691336236789625],
                                [0.5769259912896312, 0.23076534494715845, 0.19230866376321037],
                                [0.5769259912896312, 0.17307400871036882, 0.25],
                                [0.5621300280449982, 0.05325264442858102, 0.38461732752642075],
                                [0.17751270051857748, 0.43786997195500177, 0.38461732752642075],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.7692346550528415, 0.14200899468786976, 0.08875635025928873],
                                [0.4733736777857095, 0.2307653449471585, 0.295860977267132],
                                [0.4733736777857096, 0.14200899468786965, 0.38461732752642075],
                                [0.5126298184078542, 0.010825220107479883, 0.47654496148466596],
                                [0.03608485692318819, 0.48737018159214585, 0.47654496148466596],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983931],
                                [0.40265975598801484, 0.2307653449471585, 0.36657489906482665],
                                [0.40265975598801496, 0.12079528252731908, 0.47654496148466596],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.47654496148466596, 0.5, 0.02345503851533401],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5063149092039271, 0.488272480742333, 0.005412610053739941],
                                [0.488272480742333, 0.4936850907960729, 0.018042428461594068],
                                [0.488272480742333, 0.488272480742333, 0.02345503851533401],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.38461732752642075, 0.5, 0.11538267247357922],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5310650140224991, 0.4423086637632104, 0.02662632221429052],
                                [0.4423086637632104, 0.4689349859775009, 0.0887563502592887],
                                [0.44230866376321043, 0.4423086637632103, 0.11538267247357922],
                                [0.5, 0.25, 0.25],
                                [0.25, 0.5, 0.25],
                                [0.25, 0.25, 0.5],
                                [0.5673086637632103, 0.375, 0.057691336236789625],
                                [0.37500000000000006, 0.4326913362367896, 0.19230866376321037],
                                [0.375, 0.375, 0.25],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.11538267247357925, 0.5, 0.38461732752642075],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.6035523135039216, 0.3076913362367896, 0.08875635025928873],
                                [0.3076913362367897, 0.3964476864960783, 0.295860977267132],
                                [0.3076913362367897, 0.30769133623678957, 0.38461732752642075],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.023455038515334037, 0.5, 0.47654496148466596],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.6283024183224937, 0.261727519257667, 0.10997006241983931],
                                [0.261727519257667, 0.37169758167750633, 0.36657489906482665],
                                [0.261727519257667, 0.261727519257667, 0.47654496148466596],
                                [0.24339516335501266, 0.7331497981296533, 0.02345503851533401],
                                [0.21994012483967862, 0.7566048366449873, 0.02345503851533401],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.24339516335501266, 0.7511922265912474, 0.005412610053739941],
                                [0.22535273489341856, 0.7566048366449873, 0.018042428461594068],
                                [0.22535273489341856, 0.7511922265912474, 0.02345503851533401],
                                [0.29289537299215673, 0.591721954534264, 0.11538267247357922],
                                [0.17751270051857748, 0.7071046270078433, 0.11538267247357922],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.29289537299215673, 0.6804783047935528, 0.02662632221429052],
                                [0.204139022732868, 0.7071046270078433, 0.0887563502592887],
                                [0.204139022732868, 0.6804783047935528, 0.11538267247357922],
                                [0.36538267247357925, 0.38461732752642075, 0.25],
                                [0.11538267247357925, 0.6346173275264207, 0.25],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.36538267247357914, 0.5769259912896312, 0.057691336236789625],
                                [0.17307400871036882, 0.6346173275264209, 0.19230866376321037],
                                [0.17307400871036882, 0.5769259912896312, 0.25],
                                [0.43786997195500177, 0.17751270051857748, 0.38461732752642075],
                                [0.05325264442858102, 0.5621300280449982, 0.38461732752642075],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.43786997195500177, 0.4733736777857095, 0.08875635025928873],
                                [0.14200899468786976, 0.5621300280449982, 0.295860977267132],
                                [0.14200899468786976, 0.4733736777857095, 0.38461732752642075],
                                [0.48737018159214585, 0.03608485692318819, 0.47654496148466596],
                                [0.010825220107479883, 0.5126298184078542, 0.47654496148466596],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.48737018159214585, 0.40265975598801484, 0.10997006241983931],
                                [0.12079528252731919, 0.5126298184078542, 0.36657489906482665],
                                [0.12079528252731919, 0.40265975598801484, 0.47654496148466596],
                                [0.06816456021897888, 0.9083804012656871, 0.02345503851533401],
                                [0.04470952170364484, 0.9318354397810211, 0.02345503851533401],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.06385222782875055, 0.9307351621175095, 0.005412610053739941],
                                [0.045809799367156456, 0.9361477721712494, 0.018042428461594068],
                                [0.045809799367156456, 0.9307351621175095, 0.02345503851533401],
                                [0.15146752939676744, 0.7331497981296533, 0.11538267247357922],
                                [0.03608485692318819, 0.8485324706032326, 0.11538267247357922],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.13025381723621687, 0.8431198605494926, 0.02662632221429052],
                                [0.04149746697692813, 0.8697461827637831, 0.0887563502592887],
                                [0.04149746697692813, 0.8431198605494926, 0.11538267247357922],
                                [0.27345503851533404, 0.47654496148466596, 0.25],
                                [0.023455038515334037, 0.726544961484666, 0.25],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.22749122153621149, 0.7148174422269988, 0.057691336236789625],
                                [0.035182557773001166, 0.7725087784637885, 0.19230866376321037],
                                [0.035182557773001055, 0.714817442226999, 0.25],
                                [0.39544254763390063, 0.21994012483967862, 0.38461732752642075],
                                [0.010825220107479883, 0.6045574523660994, 0.38461732752642075],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.324728625836206, 0.5865150239045053, 0.08875635025928873],
                                [0.028867648569073978, 0.675271374163794, 0.295860977267132],
                                [0.028867648569073978, 0.5865150239045053, 0.38461732752642075],
                                [0.4787455168116892, 0.04470952170364484, 0.47654496148466596],
                                [0.0022005553270232348, 0.5212544831883108, 0.47654496148466596],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.3911302152436723, 0.4988997223364884, 0.10997006241983931],
                                [0.024555316178845654, 0.6088697847563277, 0.36657489906482665],
                                [0.024555316178845654, 0.4988997223364884, 0.47654496148466596],
                                [0.9318354397810211, 0.04470952170364481, 0.02345503851533401],
                                [0.9083804012656871, 0.06816456021897882, 0.02345503851533401],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116048],
                                [0.9307351621175095, 0.04691007703066802, 0.022354760851822406],
                                [0.9307351621175095, 0.045809799367156415, 0.02345503851533401],
                                [0.8485324706032327, 0.036084856923188136, 0.11538267247357922],
                                [0.7331497981296534, 0.15146752939676736, 0.11538267247357922],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9530899229693319, 0.04149746697692808, 0.0054126100537399465],
                                [0.8431198605494927, 0.04691007703066802, 0.10997006241983928],
                                [0.8431198605494927, 0.04149746697692808, 0.11538267247357922],
                                [0.726544961484666, 0.023455038515334037, 0.25],
                                [0.47654496148466596, 0.27345503851533404, 0.25],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667018],
                                [0.7148174422269991, 0.04691007703066802, 0.23827248074233298],
                                [0.7148174422269991, 0.035182557773001, 0.25],
                                [0.6045574523660994, 0.010825220107479883, 0.38461732752642075],
                                [0.21994012483967862, 0.39544254763390063, 0.38461732752642075],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.9530899229693319, 0.02886764856907395, 0.01804242846159409],
                                [0.5865150239045053, 0.046910077030668074, 0.36657489906482665],
                                [0.5865150239045054, 0.028867648569073923, 0.38461732752642075],
                                [0.5212544831883108, 0.0022005553270232348, 0.47654496148466596],
                                [0.04470952170364484, 0.4787455168116892, 0.47654496148466596],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.9530899229693319, 0.024555316178845616, 0.02235476085182243],
                                [0.4988997223364884, 0.046910077030668074, 0.45419020063284354],
                                [0.4988997223364884, 0.024555316178845654, 0.47654496148466596],
                                [0.7566048366449873, 0.21994012483967856, 0.02345503851533401],
                                [0.7331497981296534, 0.24339516335501257, 0.02345503851533401],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7735469874430698, 0.2253527348934185, 0.0011002776635116048],
                                [0.7511922265912474, 0.22645301255693012, 0.022354760851822406],
                                [0.7511922265912474, 0.2253527348934185, 0.02345503851533401],
                                [0.7071046270078434, 0.1775127005185774, 0.11538267247357922],
                                [0.5917219545342641, 0.2928953729921566, 0.11538267247357922],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7904483672133922, 0.20413902273286794, 0.0054126100537399465],
                                [0.6804783047935529, 0.20955163278660785, 0.10997006241983928],
                                [0.6804783047935529, 0.2041390227328679, 0.11538267247357922],
                                [0.6346173275264207, 0.11538267247357925, 0.25],
                                [0.38461732752642086, 0.36538267247357914, 0.25],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.8151984720319642, 0.17307400871036882, 0.011727519257667018],
                                [0.5769259912896312, 0.18480152796803584, 0.23827248074233298],
                                [0.5769259912896312, 0.17307400871036882, 0.25],
                                [0.5621300280449982, 0.05325264442858102, 0.38461732752642075],
                                [0.17751270051857748, 0.43786997195500177, 0.38461732752642075],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.8399485768505361, 0.14200899468786973, 0.01804242846159409],
                                [0.4733736777857095, 0.16005142314946386, 0.36657489906482665],
                                [0.4733736777857096, 0.14200899468786965, 0.38461732752642075],
                                [0.5126298184078542, 0.010825220107479883, 0.47654496148466596],
                                [0.03608485692318819, 0.48737018159214585, 0.47654496148466596],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.8568499566208584, 0.12079528252731918, 0.02235476085182243],
                                [0.40265975598801484, 0.1431500433791416, 0.45419020063284354],
                                [0.40265975598801496, 0.12079528252731908, 0.47654496148466596],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.47654496148466596, 0.5, 0.02345503851533401],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5106272415941554, 0.488272480742333, 0.0011002776635116048],
                                [0.488272480742333, 0.4893727584058446, 0.022354760851822406],
                                [0.488272480742333, 0.488272480742333, 0.02345503851533401],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.38461732752642075, 0.5, 0.11538267247357922],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5522787261830497, 0.4423086637632104, 0.0054126100537399465],
                                [0.44230866376321043, 0.44772127381695026, 0.10997006241983928],
                                [0.44230866376321043, 0.4423086637632103, 0.11538267247357922],
                                [0.5, 0.25, 0.25],
                                [0.25, 0.5, 0.25],
                                [0.25, 0.25, 0.5],
                                [0.613272480742333, 0.375, 0.011727519257667018],
                                [0.375, 0.386727519257667, 0.23827248074233298],
                                [0.375, 0.375, 0.25],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.11538267247357925, 0.5, 0.38461732752642075],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.6742662353016162, 0.3076913362367896, 0.01804242846159409],
                                [0.3076913362367897, 0.32573376469838367, 0.36657489906482665],
                                [0.3076913362367897, 0.30769133623678957, 0.38461732752642075],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.023455038515334037, 0.5, 0.47654496148466596],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.7159177198905106, 0.261727519257667, 0.02235476085182243],
                                [0.261727519257667, 0.28408228010948944, 0.45419020063284354],
                                [0.261727519257667, 0.261727519257667, 0.47654496148466596],
                                [0.24339516335501266, 0.7331497981296533, 0.02345503851533401],
                                [0.21994012483967862, 0.7566048366449873, 0.02345503851533401],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.24770749574524098, 0.7511922265912474, 0.0011002776635116048],
                                [0.22535273489341856, 0.752292504254759, 0.022354760851822406],
                                [0.22535273489341856, 0.7511922265912474, 0.02345503851533401],
                                [0.29289537299215673, 0.591721954534264, 0.11538267247357922],
                                [0.17751270051857748, 0.7071046270078433, 0.11538267247357922],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.3141090851527073, 0.6804783047935528, 0.0054126100537399465],
                                [0.204139022732868, 0.6858909148472927, 0.10997006241983928],
                                [0.204139022732868, 0.6804783047935528, 0.11538267247357922],
                                [0.36538267247357925, 0.38461732752642075, 0.25],
                                [0.11538267247357925, 0.6346173275264207, 0.25],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.4113464894527019, 0.5769259912896311, 0.011727519257667018],
                                [0.17307400871036882, 0.5886535105472982, 0.23827248074233298],
                                [0.17307400871036882, 0.5769259912896312, 0.25],
                                [0.43786997195500177, 0.17751270051857748, 0.38461732752642075],
                                [0.05325264442858102, 0.5621300280449982, 0.38461732752642075],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.5085838937526964, 0.4733736777857095, 0.01804242846159409],
                                [0.14200899468786976, 0.4914161062473036, 0.36657489906482665],
                                [0.14200899468786976, 0.4733736777857095, 0.38461732752642075],
                                [0.48737018159214585, 0.03608485692318819, 0.47654496148466596],
                                [0.010825220107479883, 0.5126298184078542, 0.47654496148466596],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.5749854831601627, 0.40265975598801484, 0.02235476085182243],
                                [0.12079528252731919, 0.42501451683983726, 0.45419020063284354],
                                [0.12079528252731919, 0.40265975598801484, 0.47654496148466596],
                                [0.06816456021897888, 0.9083804012656871, 0.02345503851533401],
                                [0.04470952170364484, 0.9318354397810211, 0.02345503851533401],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.06816456021897888, 0.9307351621175095, 0.0011002776635116048],
                                [0.045809799367156456, 0.9318354397810211, 0.022354760851822406],
                                [0.045809799367156456, 0.9307351621175095, 0.02345503851533401],
                                [0.15146752939676744, 0.7331497981296533, 0.11538267247357922],
                                [0.03608485692318819, 0.8485324706032326, 0.11538267247357922],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.15146752939676744, 0.8431198605494926, 0.0054126100537399465],
                                [0.04149746697692813, 0.8485324706032326, 0.10997006241983928],
                                [0.04149746697692813, 0.8431198605494926, 0.11538267247357922],
                                [0.27345503851533404, 0.47654496148466596, 0.25],
                                [0.023455038515334037, 0.726544961484666, 0.25],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.27345503851533404, 0.714817442226999, 0.011727519257667018],
                                [0.035182557773001055, 0.726544961484666, 0.23827248074233298],
                                [0.035182557773001055, 0.714817442226999, 0.25],
                                [0.39544254763390063, 0.21994012483967862, 0.38461732752642075],
                                [0.010825220107479883, 0.6045574523660994, 0.38461732752642075],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.39544254763390063, 0.5865150239045053, 0.01804242846159409],
                                [0.028867648569073978, 0.6045574523660994, 0.36657489906482665],
                                [0.028867648569073978, 0.5865150239045053, 0.38461732752642075],
                                [0.4787455168116892, 0.04470952170364484, 0.47654496148466596],
                                [0.0022005553270232348, 0.5212544831883108, 0.47654496148466596],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.4787455168116892, 0.4988997223364884, 0.02235476085182243],
                                [0.024555316178845654, 0.5212544831883108, 0.45419020063284354],
                                [0.024555316178845654, 0.4988997223364884, 0.47654496148466596],
                                [0.9444652581888753, 0.04470952170364481, 0.010825220107479883],
                                [0.9083804012656871, 0.055534741811124694, 0.036084856923188136],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9203905528819587, 0.045217333612760625, 0.03439211350528074],
                                [0.9186978094640512, 0.07960944711804137, 0.0016927434179073895],
                                [0.9186978094640512, 0.04521733361276062, 0.036084856923188136],
                                [0.9106624986482308, 0.03608485692318814, 0.05325264442858104],
                                [0.7331497981296534, 0.08933750135176918, 0.1775127005185774],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.7922314913612514, 0.03858294257541964, 0.16918556606332902],
                                [0.783904356906003, 0.20776850863874866, 0.008327134455248368],
                                [0.783904356906003, 0.03858294257541964, 0.1775127005185774],
                                [0.8611622890110867, 0.02345503851533401, 0.11538267247357925],
                                [0.47654496148466596, 0.1388377109889133, 0.38461732752642075],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.6045574523660995, 0.028867648569073923, 0.36657489906482665],
                                [0.5865150239045053, 0.39544254763390063, 0.018042428461594068],
                                [0.5865150239045054, 0.028867648569073923, 0.38461732752642075],
                                [0.8116620793739426, 0.010825220107479883, 0.17751270051857745],
                                [0.21994012483967862, 0.18833792062605736, 0.591721954534264],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.4168834133709476, 0.019152354562728235, 0.5639642320663242],
                                [0.38912569090300775, 0.5831165866290525, 0.027757722467939765],
                                [0.38912569090300786, 0.019152354562728124, 0.591721954534264],
                                [0.7778593198332981, 0.002200555327023207, 0.21994012483967862],
                                [0.04470952170364484, 0.22214068016670185, 0.7331497981296533],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.28872435185024026, 0.012517963525387255, 0.6987576846243725],
                                [0.25433223834495944, 0.7112756481497599, 0.03439211350528074],
                                [0.25433223834495955, 0.012517963525387144, 0.7331497981296533],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7331497981296533, 0.23076534494715845, 0.036084856923188136],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7431696760028093, 0.22243821049191007, 0.03439211350528074],
                                [0.7414769325849018, 0.25683032399719086, 0.0016927434179073895],
                                [0.7414769325849018, 0.2224382104919101, 0.036084856923188136],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858104],
                                [0.5917219545342641, 0.23076534494715847, 0.1775127005185774],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.6410128685571836, 0.18980156537948728, 0.16918556606332902],
                                [0.6326857341019353, 0.35898713144281635, 0.008327134455248368],
                                [0.6326857341019353, 0.1898015653794873, 0.1775127005185774],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357925],
                                [0.38461732752642086, 0.2307653449471584, 0.38461732752642075],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.4914161062473037, 0.14200899468786965, 0.36657489906482665],
                                [0.4733736777857095, 0.5085838937526964, 0.018042428461594068],
                                [0.4733736777857096, 0.14200899468786965, 0.38461732752642075],
                                [0.7692346550528415, 0.05325264442858105, 0.17751270051857745],
                                [0.17751270051857748, 0.2307653449471585, 0.591721954534264],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.34181934393742364, 0.09421642399625219, 0.5639642320663242],
                                [0.3140616214694838, 0.6581806560625765, 0.027757722467939765],
                                [0.3140616214694838, 0.09421642399625219, 0.591721954534264],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967862],
                                [0.03608485692318819, 0.2307653449471585, 0.7331497981296533],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.23966253649179814, 0.06157977888382937, 0.6987576846243725],
                                [0.20527042298651732, 0.760337463508202, 0.03439211350528074],
                                [0.2052704229865172, 0.061579778883829484, 0.7331497981296533],
                                [0.5126298184078542, 0.47654496148466596, 0.010825220107479883],
                                [0.4765449614846659, 0.4873701815921459, 0.036084856923188136],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.48365031495631333, 0.48195757153840596, 0.03439211350528074],
                                [0.4819575715384059, 0.5163496850436867, 0.0016927434179073895],
                                [0.48195757153840585, 0.48195757153840596, 0.036084856923188136],
                                [0.5621300280449981, 0.3846173275264208, 0.05325264442858104],
                                [0.38461732752642075, 0.4378699719550019, 0.1775127005185774],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.4195707841959597, 0.41124364974071126, 0.16918556606332902],
                                [0.41124364974071126, 0.5804292158040404, 0.008327134455248368],
                                [0.41124364974071126, 0.41124364974071137, 0.1775127005185774],
                                [0.6346173275264207, 0.25, 0.11538267247357925],
                                [0.25, 0.36538267247357925, 0.38461732752642075],
                                [0.25, 0.25, 0.5],
                                [0.3257337646983838, 0.30769133623678957, 0.36657489906482665],
                                [0.3076913362367897, 0.6742662353016162, 0.018042428461594068],
                                [0.3076913362367897, 0.30769133623678957, 0.38461732752642075],
                                [0.7071046270078433, 0.11538267247357928, 0.17751270051857745],
                                [0.11538267247357925, 0.29289537299215673, 0.591721954534264],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.23189674520080783, 0.204139022732868, 0.5639642320663242],
                                [0.204139022732868, 0.7681032547991923, 0.027757722467939765],
                                [0.204139022732868, 0.204139022732868, 0.591721954534264],
                                [0.7566048366449873, 0.023455038515334037, 0.21994012483967862],
                                [0.023455038515334037, 0.24339516335501266, 0.7331497981296533],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.16781721444045417, 0.13342510093517335, 0.6987576846243725],
                                [0.13342510093517335, 0.832182785559546, 0.03439211350528074],
                                [0.13342510093517335, 0.13342510093517335, 0.7331497981296533],
                                [0.2560249817628668, 0.7331497981296533, 0.010825220107479883],
                                [0.21994012483967862, 0.7439750182371332, 0.036084856923188136],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.22413095390981752, 0.7414769325849018, 0.03439211350528074],
                                [0.22243821049191026, 0.7758690460901824, 0.0016927434179073895],
                                [0.22243821049191004, 0.7414769325849018, 0.036084856923188136],
                                [0.35502540103715485, 0.5917219545342641, 0.05325264442858104],
                                [0.17751270051857748, 0.6449745989628451, 0.1775127005185774],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.1981286998347357, 0.6326857341019353, 0.16918556606332902],
                                [0.18980156537948734, 0.8018713001652643, 0.008327134455248368],
                                [0.18980156537948734, 0.6326857341019353, 0.1775127005185774],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.11538267247357925, 0.5, 0.38461732752642075],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.16005142314946386, 0.4733736777857095, 0.36657489906482665],
                                [0.14200899468786976, 0.8399485768505361, 0.018042428461594068],
                                [0.14200899468786976, 0.4733736777857095, 0.38461732752642075],
                                [0.644974598962845, 0.17751270051857745, 0.17751270051857745],
                                [0.05325264442858102, 0.35502540103715496, 0.591721954534264],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.12197414646419202, 0.3140616214694838, 0.5639642320663242],
                                [0.09421642399625219, 0.8780258535358081, 0.027757722467939765],
                                [0.09421642399625219, 0.3140616214694838, 0.591721954534264],
                                [0.7439750182371332, 0.03608485692318819, 0.21994012483967862],
                                [0.010825220107479883, 0.2560249817628668, 0.7331497981296533],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.09597189238911019, 0.20527042298651732, 0.6987576846243725],
                                [0.061579778883829484, 0.9040281076108898, 0.03439211350528074],
                                [0.061579778883829484, 0.2052704229865172, 0.7331497981296533],
                                [0.08079437862683303, 0.9083804012656871, 0.010825220107479883],
                                [0.04470952170364484, 0.919205621373167, 0.036084856923188136],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.04521733361276081, 0.9530899229693318, 0.0016927434179073895],
                                [0.04521733361276059, 0.9186978094640512, 0.036084856923188136],
                                [0.21359755744176556, 0.7331497981296534, 0.05325264442858104],
                                [0.03608485692318819, 0.7864024425582344, 0.1775127005185774],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332902],
                                [0.03858294257541972, 0.9530899229693319, 0.008327134455248368],
                                [0.03858294257541972, 0.7839043569060029, 0.1775127005185774],
                                [0.4080723660417548, 0.47654496148466596, 0.11538267247357925],
                                [0.023455038515334037, 0.5919276339582452, 0.38461732752642075],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.028867648569073978, 0.9530899229693319, 0.018042428461594068],
                                [0.028867648569073978, 0.5865150239045053, 0.38461732752642075],
                                [0.6025471746417439, 0.21994012483967865, 0.17751270051857745],
                                [0.010825220107479883, 0.3974528253582561, 0.591721954534264],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.046910077030668074, 0.38912569090300775, 0.5639642320663242],
                                [0.019152354562728346, 0.9530899229693319, 0.027757722467939765],
                                [0.019152354562728235, 0.38912569090300775, 0.591721954534264],
                                [0.7353503534566765, 0.04470952170364484, 0.21994012483967862],
                                [0.0022005553270232348, 0.26464964654332346, 0.7331497981296533],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.012517963525387366, 0.9530899229693319, 0.03439211350528074],
                                [0.012517963525387255, 0.25433223834495944, 0.7331497981296533],
                                [0.9444652581888753, 0.04470952170364481, 0.010825220107479883],
                                [0.9083804012656871, 0.055534741811124694, 0.036084856923188136],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9270249439192997, 0.04521733361276062, 0.027757722467939765],
                                [0.9186978094640512, 0.07297505608070039, 0.008327134455248368],
                                [0.9186978094640512, 0.04521733361276062, 0.036084856923188136],
                                [0.9106624986482308, 0.03608485692318814, 0.05325264442858104],
                                [0.7331497981296534, 0.08933750135176918, 0.1775127005185774],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.8248681364736742, 0.03858294257541964, 0.13654892095090623],
                                [0.7839043569060029, 0.1751318635263259, 0.040963779567671145],
                                [0.783904356906003, 0.03858294257541964, 0.1775127005185774],
                                [0.8611622890110867, 0.02345503851533401, 0.11538267247357925],
                                [0.47654496148466596, 0.1388377109889133, 0.38461732752642075],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.6752713741637941, 0.028867648569073923, 0.295860977267132],
                                [0.5865150239045052, 0.32472862583620604, 0.0887563502592887],
                                [0.5865150239045054, 0.028867648569073923, 0.38461732752642075],
                                [0.8116620793739426, 0.010825220107479883, 0.17751270051857745],
                                [0.21994012483967862, 0.18833792062605736, 0.591721954534264],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.5256746118539142, 0.01915235456272818, 0.45517303358335776],
                                [0.38912569090300775, 0.47432538814608605, 0.13654892095090623],
                                [0.38912569090300786, 0.019152354562728124, 0.591721954534264],
                                [0.7778593198332981, 0.002200555327023207, 0.21994012483967862],
                                [0.04470952170364484, 0.22214068016670185, 0.7331497981296533],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.42351780440828857, 0.012517963525387144, 0.5639642320663243],
                                [0.25433223834495944, 0.5764821955917115, 0.16918556606332902],
                                [0.25433223834495955, 0.012517963525387144, 0.7331497981296533],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7331497981296533, 0.23076534494715845, 0.036084856923188136],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7498040670401502, 0.22243821049191007, 0.027757722467939765],
                                [0.7414769325849018, 0.2501959329598499, 0.008327134455248368],
                                [0.7414769325849018, 0.2224382104919101, 0.036084856923188136],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858104],
                                [0.5917219545342641, 0.23076534494715847, 0.1775127005185774],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.6736495136696065, 0.1898015653794873, 0.13654892095090623],
                                [0.6326857341019353, 0.32635048633039354, 0.040963779567671145],
                                [0.6326857341019353, 0.1898015653794873, 0.1775127005185774],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357925],
                                [0.38461732752642086, 0.2307653449471584, 0.38461732752642075],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.5621300280449982, 0.14200899468786976, 0.295860977267132],
                                [0.47337367778570943, 0.4378699719550018, 0.0887563502592887],
                                [0.4733736777857096, 0.14200899468786965, 0.38461732752642075],
                                [0.7692346550528415, 0.05325264442858105, 0.17751270051857745],
                                [0.17751270051857748, 0.2307653449471585, 0.591721954534264],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.45061054242039017, 0.09421642399625213, 0.45517303358335776],
                                [0.3140616214694838, 0.54938945757961, 0.13654892095090623],
                                [0.3140616214694838, 0.09421642399625219, 0.591721954534264],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967862],
                                [0.03608485692318819, 0.2307653449471585, 0.7331497981296533],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.37445598904984645, 0.06157977888382926, 0.5639642320663243],
                                [0.20527042298651732, 0.6255440109501537, 0.16918556606332902],
                                [0.2052704229865172, 0.061579778883829484, 0.7331497981296533],
                                [0.5126298184078542, 0.47654496148466596, 0.010825220107479883],
                                [0.4765449614846659, 0.4873701815921459, 0.036084856923188136],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.4902847059936543, 0.48195757153840596, 0.027757722467939765],
                                [0.4819575715384059, 0.5097152940063457, 0.008327134455248368],
                                [0.48195757153840585, 0.48195757153840596, 0.036084856923188136],
                                [0.5621300280449981, 0.3846173275264208, 0.05325264442858104],
                                [0.38461732752642075, 0.4378699719550019, 0.1775127005185774],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.4522074293083824, 0.41124364974071137, 0.13654892095090623],
                                [0.41124364974071126, 0.5477925706916176, 0.040963779567671145],
                                [0.41124364974071126, 0.41124364974071137, 0.1775127005185774],
                                [0.6346173275264207, 0.25, 0.11538267247357925],
                                [0.25, 0.36538267247357925, 0.38461732752642075],
                                [0.25, 0.25, 0.5],
                                [0.3964476864960783, 0.3076913362367897, 0.295860977267132],
                                [0.3076913362367897, 0.6035523135039216, 0.0887563502592887],
                                [0.3076913362367897, 0.30769133623678957, 0.38461732752642075],
                                [0.7071046270078433, 0.11538267247357928, 0.17751270051857745],
                                [0.11538267247357925, 0.29289537299215673, 0.591721954534264],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.34068794368377436, 0.20413902273286794, 0.45517303358335776],
                                [0.204139022732868, 0.6593120563162258, 0.13654892095090623],
                                [0.204139022732868, 0.204139022732868, 0.591721954534264],
                                [0.7566048366449873, 0.023455038515334037, 0.21994012483967862],
                                [0.023455038515334037, 0.24339516335501266, 0.7331497981296533],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.3026106669985025, 0.13342510093517324, 0.5639642320663243],
                                [0.13342510093517335, 0.6973893330014976, 0.16918556606332902],
                                [0.13342510093517335, 0.13342510093517335, 0.7331497981296533],
                                [0.2560249817628668, 0.7331497981296533, 0.010825220107479883],
                                [0.21994012483967862, 0.7439750182371332, 0.036084856923188136],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.22243821049191026, 0.7692346550528414, 0.008327134455248368],
                                [0.22243821049191004, 0.7414769325849018, 0.036084856923188136],
                                [0.35502540103715485, 0.5917219545342641, 0.05325264442858104],
                                [0.17751270051857748, 0.6449745989628451, 0.1775127005185774],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.18980156537948734, 0.7692346550528415, 0.040963779567671145],
                                [0.18980156537948734, 0.6326857341019353, 0.1775127005185774],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.11538267247357925, 0.5, 0.38461732752642075],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.14200899468786976, 0.7692346550528415, 0.0887563502592887],
                                [0.14200899468786976, 0.4733736777857095, 0.38461732752642075],
                                [0.644974598962845, 0.17751270051857745, 0.17751270051857745],
                                [0.05325264442858102, 0.35502540103715496, 0.591721954534264],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.23076534494715856, 0.31406162146948374, 0.45517303358335776],
                                [0.09421642399625219, 0.7692346550528416, 0.13654892095090623],
                                [0.09421642399625219, 0.3140616214694838, 0.591721954534264],
                                [0.7439750182371332, 0.03608485692318819, 0.21994012483967862],
                                [0.010825220107479883, 0.2560249817628668, 0.7331497981296533],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.061579778883829484, 0.7692346550528415, 0.16918556606332902],
                                [0.061579778883829484, 0.2052704229865172, 0.7331497981296533],
                                [0.08079437862683303, 0.9083804012656871, 0.010825220107479883],
                                [0.04470952170364484, 0.919205621373167, 0.036084856923188136],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.053544468068009055, 0.9186978094640512, 0.027757722467939765],
                                [0.04521733361276081, 0.9464555319319908, 0.008327134455248368],
                                [0.04521733361276059, 0.9186978094640512, 0.036084856923188136],
                                [0.21359755744176556, 0.7331497981296534, 0.05325264442858104],
                                [0.03608485692318819, 0.7864024425582344, 0.1775127005185774],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.07954672214309089, 0.7839043569060029, 0.13654892095090623],
                                [0.03858294257541972, 0.9204532778569091, 0.040963779567671145],
                                [0.03858294257541972, 0.7839043569060029, 0.1775127005185774],
                                [0.4080723660417548, 0.47654496148466596, 0.11538267247357925],
                                [0.023455038515334037, 0.5919276339582452, 0.38461732752642075],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.11762399882836272, 0.5865150239045053, 0.295860977267132],
                                [0.028867648569073978, 0.8823760011716373, 0.0887563502592887],
                                [0.028867648569073978, 0.5865150239045053, 0.38461732752642075],
                                [0.6025471746417439, 0.21994012483967865, 0.17751270051857745],
                                [0.010825220107479883, 0.3974528253582561, 0.591721954534264],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.1557012755136346, 0.3891256909030077, 0.45517303358335776],
                                [0.019152354562728346, 0.8442987244863654, 0.13654892095090623],
                                [0.019152354562728235, 0.38912569090300775, 0.591721954534264],
                                [0.7353503534566765, 0.04470952170364484, 0.21994012483967862],
                                [0.0022005553270232348, 0.26464964654332346, 0.7331497981296533],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.18170352958871638, 0.2543322383449593, 0.5639642320663243],
                                [0.012517963525387366, 0.8182964704112836, 0.16918556606332902],
                                [0.012517963525387255, 0.25433223834495944, 0.7331497981296533],
                                [0.9444652581888753, 0.04470952170364481, 0.010825220107479883],
                                [0.9083804012656871, 0.055534741811124694, 0.036084856923188136],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9367402379256453, 0.04521733361276063, 0.018042428461594068],
                                [0.9186978094640512, 0.06325976207435469, 0.018042428461594068],
                                [0.9186978094640512, 0.04521733361276062, 0.036084856923188136],
                                [0.9106624986482308, 0.03608485692318814, 0.05325264442858104],
                                [0.7331497981296534, 0.08933750135176918, 0.1775127005185774],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.8726607071652916, 0.03858294257541965, 0.0887563502592887],
                                [0.7839043569060029, 0.12733929283470835, 0.0887563502592887],
                                [0.783904356906003, 0.03858294257541964, 0.1775127005185774],
                                [0.8611622890110867, 0.02345503851533401, 0.11538267247357925],
                                [0.47654496148466596, 0.1388377109889133, 0.38461732752642075],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.7788236876677157, 0.02886764856907395, 0.19230866376321037],
                                [0.5865150239045054, 0.22117631233228435, 0.19230866376321037],
                                [0.5865150239045054, 0.028867648569073923, 0.38461732752642075],
                                [0.8116620793739426, 0.010825220107479883, 0.17751270051857745],
                                [0.21994012483967862, 0.18833792062605736, 0.591721954534264],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.6849866681701398, 0.019152354562728235, 0.295860977267132],
                                [0.38912569090300775, 0.31501333182986024, 0.295860977267132],
                                [0.38912569090300786, 0.019152354562728124, 0.591721954534264],
                                [0.7778593198332981, 0.002200555327023207, 0.21994012483967862],
                                [0.04470952170364484, 0.22214068016670185, 0.7331497981296533],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.6209071374097861, 0.012517963525387255, 0.36657489906482665],
                                [0.25433223834495944, 0.3790928625902139, 0.36657489906482665],
                                [0.25433223834495955, 0.012517963525387144, 0.7331497981296533],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7331497981296533, 0.23076534494715845, 0.036084856923188136],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7595193610464959, 0.22243821049191007, 0.018042428461594068],
                                [0.7414769325849018, 0.24048063895350416, 0.018042428461594068],
                                [0.7414769325849018, 0.2224382104919101, 0.036084856923188136],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858104],
                                [0.5917219545342641, 0.23076534494715847, 0.1775127005185774],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7214420843612239, 0.18980156537948734, 0.0887563502592887],
                                [0.6326857341019352, 0.278557915638776, 0.0887563502592887],
                                [0.6326857341019353, 0.1898015653794873, 0.1775127005185774],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357925],
                                [0.38461732752642086, 0.2307653449471584, 0.38461732752642075],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.6656823415489199, 0.14200899468786976, 0.19230866376321037],
                                [0.47337367778570955, 0.33431765845108014, 0.19230866376321037],
                                [0.4733736777857096, 0.14200899468786965, 0.38461732752642075],
                                [0.7692346550528415, 0.05325264442858105, 0.17751270051857745],
                                [0.17751270051857748, 0.2307653449471585, 0.591721954534264],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.6099225987366158, 0.09421642399625219, 0.295860977267132],
                                [0.3140616214694838, 0.3900774012633842, 0.295860977267132],
                                [0.3140616214694838, 0.09421642399625219, 0.591721954534264],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967862],
                                [0.03608485692318819, 0.2307653449471585, 0.7331497981296533],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.571845322051344, 0.06157977888382943, 0.36657489906482665],
                                [0.20527042298651732, 0.428154677948656, 0.36657489906482665],
                                [0.2052704229865172, 0.061579778883829484, 0.7331497981296533],
                                [0.5126298184078542, 0.47654496148466596, 0.010825220107479883],
                                [0.4765449614846659, 0.4873701815921459, 0.036084856923188136],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.4819575715384059, 0.5, 0.018042428461594068],
                                [0.48195757153840585, 0.48195757153840596, 0.036084856923188136],
                                [0.5621300280449981, 0.3846173275264208, 0.05325264442858104],
                                [0.38461732752642075, 0.4378699719550019, 0.1775127005185774],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.41124364974071126, 0.5, 0.0887563502592887],
                                [0.41124364974071126, 0.41124364974071137, 0.1775127005185774],
                                [0.6346173275264207, 0.25, 0.11538267247357925],
                                [0.25, 0.36538267247357925, 0.38461732752642075],
                                [0.25, 0.25, 0.5],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.30769133623678974, 0.49999999999999994, 0.19230866376321037],
                                [0.3076913362367897, 0.30769133623678957, 0.38461732752642075],
                                [0.7071046270078433, 0.11538267247357928, 0.17751270051857745],
                                [0.11538267247357925, 0.29289537299215673, 0.591721954534264],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.5, 0.204139022732868, 0.295860977267132],
                                [0.204139022732868, 0.5, 0.295860977267132],
                                [0.204139022732868, 0.204139022732868, 0.591721954534264],
                                [0.7566048366449873, 0.023455038515334037, 0.21994012483967862],
                                [0.023455038515334037, 0.24339516335501266, 0.7331497981296533],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.13342510093517335, 0.5, 0.36657489906482665],
                                [0.13342510093517335, 0.13342510093517335, 0.7331497981296533],
                                [0.2560249817628668, 0.7331497981296533, 0.010825220107479883],
                                [0.21994012483967862, 0.7439750182371332, 0.036084856923188136],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.24048063895350424, 0.7414769325849017, 0.018042428461594068],
                                [0.22243821049191026, 0.7595193610464956, 0.018042428461594068],
                                [0.22243821049191004, 0.7414769325849018, 0.036084856923188136],
                                [0.35502540103715485, 0.5917219545342641, 0.05325264442858104],
                                [0.17751270051857748, 0.6449745989628451, 0.1775127005185774],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.2785579156387761, 0.6326857341019352, 0.0887563502592887],
                                [0.18980156537948734, 0.7214420843612239, 0.0887563502592887],
                                [0.18980156537948734, 0.6326857341019353, 0.1775127005185774],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.11538267247357925, 0.5, 0.38461732752642075],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.33431765845108025, 0.47337367778570943, 0.19230866376321037],
                                [0.14200899468786976, 0.6656823415489199, 0.19230866376321037],
                                [0.14200899468786976, 0.4733736777857095, 0.38461732752642075],
                                [0.644974598962845, 0.17751270051857745, 0.17751270051857745],
                                [0.05325264442858102, 0.35502540103715496, 0.591721954534264],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.3900774012633842, 0.3140616214694838, 0.295860977267132],
                                [0.09421642399625219, 0.6099225987366158, 0.295860977267132],
                                [0.09421642399625219, 0.3140616214694838, 0.591721954534264],
                                [0.7439750182371332, 0.03608485692318819, 0.21994012483967862],
                                [0.010825220107479883, 0.2560249817628668, 0.7331497981296533],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.428154677948656, 0.20527042298651732, 0.36657489906482665],
                                [0.061579778883829484, 0.5718453220513439, 0.36657489906482665],
                                [0.061579778883829484, 0.2052704229865172, 0.7331497981296533],
                                [0.08079437862683303, 0.9083804012656871, 0.010825220107479883],
                                [0.04470952170364484, 0.919205621373167, 0.036084856923188136],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.0632597620743548, 0.9186978094640511, 0.018042428461594068],
                                [0.04521733361276081, 0.9367402379256451, 0.018042428461594068],
                                [0.04521733361276059, 0.9186978094640512, 0.036084856923188136],
                                [0.21359755744176556, 0.7331497981296534, 0.05325264442858104],
                                [0.03608485692318819, 0.7864024425582344, 0.1775127005185774],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.12733929283470835, 0.7839043569060029, 0.0887563502592887],
                                [0.03858294257541972, 0.8726607071652915, 0.0887563502592887],
                                [0.03858294257541972, 0.7839043569060029, 0.1775127005185774],
                                [0.4080723660417548, 0.47654496148466596, 0.11538267247357925],
                                [0.023455038515334037, 0.5919276339582452, 0.38461732752642075],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.2211763123322843, 0.5865150239045054, 0.19230866376321037],
                                [0.028867648569073978, 0.7788236876677157, 0.19230866376321037],
                                [0.028867648569073978, 0.5865150239045053, 0.38461732752642075],
                                [0.6025471746417439, 0.21994012483967865, 0.17751270051857745],
                                [0.010825220107479883, 0.3974528253582561, 0.591721954534264],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.31501333182986024, 0.38912569090300775, 0.295860977267132],
                                [0.019152354562728346, 0.6849866681701396, 0.295860977267132],
                                [0.019152354562728235, 0.38912569090300775, 0.591721954534264],
                                [0.7353503534566765, 0.04470952170364484, 0.21994012483967862],
                                [0.0022005553270232348, 0.26464964654332346, 0.7331497981296533],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.3790928625902139, 0.25433223834495944, 0.36657489906482665],
                                [0.012517963525387366, 0.620907137409786, 0.36657489906482665],
                                [0.012517963525387255, 0.25433223834495944, 0.7331497981296533],
                                [0.9444652581888753, 0.04470952170364481, 0.010825220107479883],
                                [0.9083804012656871, 0.055534741811124694, 0.036084856923188136],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9464555319319911, 0.04521733361276063, 0.00832713445524837],
                                [0.9186978094640513, 0.053544468068008985, 0.027757722467939765],
                                [0.9186978094640512, 0.04521733361276062, 0.036084856923188136],
                                [0.9106624986482308, 0.03608485692318814, 0.05325264442858104],
                                [0.7331497981296534, 0.08933750135176918, 0.1775127005185774],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9204532778569092, 0.03858294257541965, 0.04096377956767115],
                                [0.783904356906003, 0.0795467221430908, 0.13654892095090623],
                                [0.783904356906003, 0.03858294257541964, 0.1775127005185774],
                                [0.8611622890110867, 0.02345503851533401, 0.11538267247357925],
                                [0.47654496148466596, 0.1388377109889133, 0.38461732752642075],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.8823760011716373, 0.02886764856907395, 0.08875635025928873],
                                [0.5865150239045053, 0.11762399882836272, 0.295860977267132],
                                [0.5865150239045054, 0.028867648569073923, 0.38461732752642075],
                                [0.8116620793739426, 0.010825220107479883, 0.17751270051857745],
                                [0.21994012483967862, 0.18833792062605736, 0.591721954534264],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.8442987244863654, 0.019152354562728235, 0.1365489209509063],
                                [0.3891256909030078, 0.1557012755136345, 0.45517303358335776],
                                [0.38912569090300786, 0.019152354562728124, 0.591721954534264],
                                [0.7778593198332981, 0.002200555327023207, 0.21994012483967862],
                                [0.04470952170364484, 0.22214068016670185, 0.7331497981296533],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.8182964704112837, 0.012517963525387255, 0.16918556606332907],
                                [0.25433223834495944, 0.18170352958871627, 0.5639642320663243],
                                [0.25433223834495955, 0.012517963525387144, 0.7331497981296533],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7331497981296533, 0.23076534494715845, 0.036084856923188136],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7692346550528416, 0.22243821049191007, 0.00832713445524837],
                                [0.7414769325849018, 0.23076534494715847, 0.027757722467939765],
                                [0.7414769325849018, 0.2224382104919101, 0.036084856923188136],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858104],
                                [0.5917219545342641, 0.23076534494715847, 0.1775127005185774],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7692346550528415, 0.18980156537948728, 0.04096377956767115],
                                [0.6326857341019353, 0.23076534494715847, 0.13654892095090623],
                                [0.6326857341019353, 0.1898015653794873, 0.1775127005185774],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357925],
                                [0.38461732752642086, 0.2307653449471584, 0.38461732752642075],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7692346550528415, 0.14200899468786976, 0.08875635025928873],
                                [0.4733736777857095, 0.2307653449471585, 0.295860977267132],
                                [0.4733736777857096, 0.14200899468786965, 0.38461732752642075],
                                [0.7692346550528415, 0.05325264442858105, 0.17751270051857745],
                                [0.17751270051857748, 0.2307653449471585, 0.591721954534264],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.7692346550528415, 0.09421642399625219, 0.1365489209509063],
                                [0.31406162146948385, 0.23076534494715845, 0.45517303358335776],
                                [0.3140616214694838, 0.09421642399625219, 0.591721954534264],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967862],
                                [0.03608485692318819, 0.2307653449471585, 0.7331497981296533],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.7692346550528416, 0.0615797788838294, 0.16918556606332907],
                                [0.20527042298651732, 0.2307653449471584, 0.5639642320663243],
                                [0.2052704229865172, 0.061579778883829484, 0.7331497981296533],
                                [0.5126298184078542, 0.47654496148466596, 0.010825220107479883],
                                [0.4765449614846659, 0.4873701815921459, 0.036084856923188136],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5097152940063456, 0.48195757153840596, 0.00832713445524837],
                                [0.48195757153840596, 0.4902847059936543, 0.027757722467939765],
                                [0.48195757153840585, 0.48195757153840596, 0.036084856923188136],
                                [0.5621300280449981, 0.3846173275264208, 0.05325264442858104],
                                [0.38461732752642075, 0.4378699719550019, 0.1775127005185774],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5477925706916176, 0.41124364974071126, 0.04096377956767115],
                                [0.41124364974071126, 0.45220742930838254, 0.13654892095090623],
                                [0.41124364974071126, 0.41124364974071137, 0.1775127005185774],
                                [0.6346173275264207, 0.25, 0.11538267247357925],
                                [0.25, 0.36538267247357925, 0.38461732752642075],
                                [0.25, 0.25, 0.5],
                                [0.6035523135039216, 0.3076913362367896, 0.08875635025928873],
                                [0.3076913362367897, 0.3964476864960783, 0.295860977267132],
                                [0.3076913362367897, 0.30769133623678957, 0.38461732752642075],
                                [0.7071046270078433, 0.11538267247357928, 0.17751270051857745],
                                [0.11538267247357925, 0.29289537299215673, 0.591721954534264],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.6593120563162257, 0.20413902273286802, 0.1365489209509063],
                                [0.20413902273286805, 0.34068794368377425, 0.45517303358335776],
                                [0.204139022732868, 0.204139022732868, 0.591721954534264],
                                [0.7566048366449873, 0.023455038515334037, 0.21994012483967862],
                                [0.023455038515334037, 0.24339516335501266, 0.7331497981296533],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.6973893330014976, 0.13342510093517335, 0.16918556606332907],
                                [0.13342510093517335, 0.30261066699850236, 0.5639642320663243],
                                [0.13342510093517335, 0.13342510093517335, 0.7331497981296533],
                                [0.2560249817628668, 0.7331497981296533, 0.010825220107479883],
                                [0.21994012483967862, 0.7439750182371332, 0.036084856923188136],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.2501959329598499, 0.7414769325849018, 0.00832713445524837],
                                [0.22243821049191026, 0.74980406704015, 0.027757722467939765],
                                [0.22243821049191004, 0.7414769325849018, 0.036084856923188136],
                                [0.35502540103715485, 0.5917219545342641, 0.05325264442858104],
                                [0.17751270051857748, 0.6449745989628451, 0.1775127005185774],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.32635048633039365, 0.6326857341019352, 0.04096377956767115],
                                [0.18980156537948734, 0.6736495136696065, 0.13654892095090623],
                                [0.18980156537948734, 0.6326857341019353, 0.1775127005185774],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.11538267247357925, 0.5, 0.38461732752642075],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.43786997195500177, 0.4733736777857095, 0.08875635025928873],
                                [0.14200899468786976, 0.5621300280449982, 0.295860977267132],
                                [0.14200899468786976, 0.4733736777857095, 0.38461732752642075],
                                [0.644974598962845, 0.17751270051857745, 0.17751270051857745],
                                [0.05325264442858102, 0.35502540103715496, 0.591721954534264],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.5493894575796099, 0.3140616214694838, 0.1365489209509063],
                                [0.09421642399625224, 0.45061054242039006, 0.45517303358335776],
                                [0.09421642399625219, 0.3140616214694838, 0.591721954534264],
                                [0.7439750182371332, 0.03608485692318819, 0.21994012483967862],
                                [0.010825220107479883, 0.2560249817628668, 0.7331497981296533],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.6255440109501538, 0.20527042298651726, 0.16918556606332907],
                                [0.061579778883829484, 0.3744559890498462, 0.5639642320663243],
                                [0.061579778883829484, 0.2052704229865172, 0.7331497981296533],
                                [0.08079437862683303, 0.9083804012656871, 0.010825220107479883],
                                [0.04470952170364484, 0.919205621373167, 0.036084856923188136],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.07297505608070043, 0.9186978094640512, 0.00832713445524837],
                                [0.04521733361276081, 0.9270249439192995, 0.027757722467939765],
                                [0.04521733361276059, 0.9186978094640512, 0.036084856923188136],
                                [0.21359755744176556, 0.7331497981296534, 0.05325264442858104],
                                [0.03608485692318819, 0.7864024425582344, 0.1775127005185774],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.17513186352632593, 0.7839043569060029, 0.04096377956767115],
                                [0.03858294257541972, 0.8248681364736741, 0.13654892095090623],
                                [0.03858294257541972, 0.7839043569060029, 0.1775127005185774],
                                [0.4080723660417548, 0.47654496148466596, 0.11538267247357925],
                                [0.023455038515334037, 0.5919276339582452, 0.38461732752642075],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.324728625836206, 0.5865150239045053, 0.08875635025928873],
                                [0.028867648569073978, 0.675271374163794, 0.295860977267132],
                                [0.028867648569073978, 0.5865150239045053, 0.38461732752642075],
                                [0.6025471746417439, 0.21994012483967865, 0.17751270051857745],
                                [0.010825220107479883, 0.3974528253582561, 0.591721954534264],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.47432538814608605, 0.38912569090300764, 0.1365489209509063],
                                [0.019152354562728346, 0.525674611853914, 0.45517303358335776],
                                [0.019152354562728235, 0.38912569090300775, 0.591721954534264],
                                [0.7353503534566765, 0.04470952170364484, 0.21994012483967862],
                                [0.0022005553270232348, 0.26464964654332346, 0.7331497981296533],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.5764821955917117, 0.2543322383449594, 0.16918556606332907],
                                [0.012517963525387366, 0.42351780440828835, 0.5639642320663243],
                                [0.012517963525387255, 0.25433223834495944, 0.7331497981296533],
                                [0.9444652581888753, 0.04470952170364481, 0.010825220107479883],
                                [0.9083804012656871, 0.055534741811124694, 0.036084856923188136],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073917],
                                [0.9186978094640513, 0.04691007703066801, 0.03439211350528074],
                                [0.9186978094640512, 0.04521733361276062, 0.036084856923188136],
                                [0.9106624986482308, 0.03608485692318814, 0.05325264442858104],
                                [0.7331497981296534, 0.08933750135176918, 0.1775127005185774],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.953089922969332, 0.038582942575419645, 0.008327134455248379],
                                [0.7839043569060029, 0.04691007703066802, 0.16918556606332902],
                                [0.783904356906003, 0.03858294257541964, 0.1775127005185774],
                                [0.8611622890110867, 0.02345503851533401, 0.11538267247357925],
                                [0.47654496148466596, 0.1388377109889133, 0.38461732752642075],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9530899229693319, 0.02886764856907395, 0.01804242846159409],
                                [0.5865150239045053, 0.046910077030668074, 0.36657489906482665],
                                [0.5865150239045054, 0.028867648569073923, 0.38461732752642075],
                                [0.8116620793739426, 0.010825220107479883, 0.17751270051857745],
                                [0.21994012483967862, 0.18833792062605736, 0.591721954534264],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.9530899229693319, 0.019152354562728256, 0.027757722467939797],
                                [0.38912569090300775, 0.046910077030668074, 0.5639642320663242],
                                [0.38912569090300786, 0.019152354562728124, 0.591721954534264],
                                [0.7778593198332981, 0.002200555327023207, 0.21994012483967862],
                                [0.04470952170364484, 0.22214068016670185, 0.7331497981296533],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.9530899229693319, 0.012517963525387275, 0.034392113505280784],
                                [0.25433223834495944, 0.046910077030668074, 0.6987576846243725],
                                [0.25433223834495955, 0.012517963525387144, 0.7331497981296533],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7331497981296533, 0.23076534494715845, 0.036084856923188136],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7758690460901826, 0.22243821049191007, 0.0016927434179073917],
                                [0.7414769325849018, 0.2241309539098175, 0.03439211350528074],
                                [0.7414769325849018, 0.2224382104919101, 0.036084856923188136],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858104],
                                [0.5917219545342641, 0.23076534494715847, 0.1775127005185774],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.8018713001652643, 0.1898015653794873, 0.008327134455248379],
                                [0.6326857341019353, 0.1981286998347357, 0.16918556606332902],
                                [0.6326857341019353, 0.1898015653794873, 0.1775127005185774],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357925],
                                [0.38461732752642086, 0.2307653449471584, 0.38461732752642075],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.8399485768505361, 0.14200899468786973, 0.01804242846159409],
                                [0.4733736777857095, 0.16005142314946386, 0.36657489906482665],
                                [0.4733736777857096, 0.14200899468786965, 0.38461732752642075],
                                [0.7692346550528415, 0.05325264442858105, 0.17751270051857745],
                                [0.17751270051857748, 0.2307653449471585, 0.591721954534264],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.878025853535808, 0.0942164239962522, 0.027757722467939797],
                                [0.3140616214694838, 0.12197414646419202, 0.5639642320663242],
                                [0.3140616214694838, 0.09421642399625219, 0.591721954534264],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967862],
                                [0.03608485692318819, 0.2307653449471585, 0.7331497981296533],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.9040281076108898, 0.06157977888382941, 0.034392113505280784],
                                [0.20527042298651732, 0.09597189238911019, 0.6987576846243725],
                                [0.2052704229865172, 0.061579778883829484, 0.7331497981296533],
                                [0.5126298184078542, 0.47654496148466596, 0.010825220107479883],
                                [0.4765449614846659, 0.4873701815921459, 0.036084856923188136],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5163496850436866, 0.48195757153840596, 0.0016927434179073917],
                                [0.48195757153840596, 0.48365031495631333, 0.03439211350528074],
                                [0.48195757153840585, 0.48195757153840596, 0.036084856923188136],
                                [0.5621300280449981, 0.3846173275264208, 0.05325264442858104],
                                [0.38461732752642075, 0.4378699719550019, 0.1775127005185774],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5804292158040403, 0.4112436497407113, 0.008327134455248379],
                                [0.41124364974071126, 0.4195707841959597, 0.16918556606332902],
                                [0.41124364974071126, 0.41124364974071137, 0.1775127005185774],
                                [0.6346173275264207, 0.25, 0.11538267247357925],
                                [0.25, 0.36538267247357925, 0.38461732752642075],
                                [0.25, 0.25, 0.5],
                                [0.6742662353016162, 0.3076913362367896, 0.01804242846159409],
                                [0.3076913362367897, 0.32573376469838367, 0.36657489906482665],
                                [0.3076913362367897, 0.30769133623678957, 0.38461732752642075],
                                [0.7071046270078433, 0.11538267247357928, 0.17751270051857745],
                                [0.11538267247357925, 0.29289537299215673, 0.591721954534264],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.7681032547991922, 0.204139022732868, 0.027757722467939797],
                                [0.204139022732868, 0.23189674520080783, 0.5639642320663242],
                                [0.204139022732868, 0.204139022732868, 0.591721954534264],
                                [0.7566048366449873, 0.023455038515334037, 0.21994012483967862],
                                [0.023455038515334037, 0.24339516335501266, 0.7331497981296533],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.8321827855595458, 0.13342510093517332, 0.034392113505280784],
                                [0.13342510093517335, 0.16781721444045417, 0.6987576846243725],
                                [0.13342510093517335, 0.13342510093517335, 0.7331497981296533],
                                [0.2560249817628668, 0.7331497981296533, 0.010825220107479883],
                                [0.21994012483967862, 0.7439750182371332, 0.036084856923188136],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.25683032399719086, 0.7414769325849018, 0.0016927434179073917],
                                [0.22243821049191026, 0.743169676002809, 0.03439211350528074],
                                [0.22243821049191004, 0.7414769325849018, 0.036084856923188136],
                                [0.35502540103715485, 0.5917219545342641, 0.05325264442858104],
                                [0.17751270051857748, 0.6449745989628451, 0.1775127005185774],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.35898713144281635, 0.6326857341019353, 0.008327134455248379],
                                [0.18980156537948734, 0.6410128685571836, 0.16918556606332902],
                                [0.18980156537948734, 0.6326857341019353, 0.1775127005185774],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.11538267247357925, 0.5, 0.38461732752642075],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.5085838937526964, 0.4733736777857095, 0.01804242846159409],
                                [0.14200899468786976, 0.4914161062473036, 0.36657489906482665],
                                [0.14200899468786976, 0.4733736777857095, 0.38461732752642075],
                                [0.644974598962845, 0.17751270051857745, 0.17751270051857745],
                                [0.05325264442858102, 0.35502540103715496, 0.591721954534264],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.6581806560625764, 0.3140616214694838, 0.027757722467939797],
                                [0.09421642399625219, 0.34181934393742364, 0.5639642320663242],
                                [0.09421642399625219, 0.3140616214694838, 0.591721954534264],
                                [0.7439750182371332, 0.03608485692318819, 0.21994012483967862],
                                [0.010825220107479883, 0.2560249817628668, 0.7331497981296533],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.760337463508202, 0.20527042298651724, 0.034392113505280784],
                                [0.061579778883829484, 0.23966253649179803, 0.6987576846243725],
                                [0.061579778883829484, 0.2052704229865172, 0.7331497981296533],
                                [0.08079437862683303, 0.9083804012656871, 0.010825220107479883],
                                [0.04470952170364484, 0.919205621373167, 0.036084856923188136],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.07960944711804141, 0.9186978094640512, 0.0016927434179073917],
                                [0.04521733361276081, 0.9203905528819585, 0.03439211350528074],
                                [0.04521733361276059, 0.9186978094640512, 0.036084856923188136],
                                [0.21359755744176556, 0.7331497981296534, 0.05325264442858104],
                                [0.03608485692318819, 0.7864024425582344, 0.1775127005185774],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.20776850863874874, 0.7839043569060029, 0.008327134455248379],
                                [0.03858294257541972, 0.7922314913612513, 0.16918556606332902],
                                [0.03858294257541972, 0.7839043569060029, 0.1775127005185774],
                                [0.4080723660417548, 0.47654496148466596, 0.11538267247357925],
                                [0.023455038515334037, 0.5919276339582452, 0.38461732752642075],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.39544254763390063, 0.5865150239045053, 0.01804242846159409],
                                [0.028867648569073978, 0.6045574523660994, 0.36657489906482665],
                                [0.028867648569073978, 0.5865150239045053, 0.38461732752642075],
                                [0.6025471746417439, 0.21994012483967865, 0.17751270051857745],
                                [0.010825220107479883, 0.3974528253582561, 0.591721954534264],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.5831165866290524, 0.3891256909030077, 0.027757722467939797],
                                [0.019152354562728346, 0.4168834133709475, 0.5639642320663242],
                                [0.019152354562728235, 0.38912569090300775, 0.591721954534264],
                                [0.7353503534566765, 0.04470952170364484, 0.21994012483967862],
                                [0.0022005553270232348, 0.26464964654332346, 0.7331497981296533],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.7112756481497597, 0.2543322383449594, 0.034392113505280784],
                                [0.012517963525387366, 0.28872435185024015, 0.6987576846243725],
                                [0.012517963525387255, 0.25433223834495944, 0.7331497981296533],
                                [0.9530899229693319, 0.04470952170364481, 0.0022005553270232096],
                                [0.9083804012656871, 0.04691007703066802, 0.04470952170364481],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9125750554799318, 0.04481274992354571, 0.042612194596522504],
                                [0.9104777283728095, 0.08742494452006823, 0.002097327107122302],
                                [0.9104777283728095, 0.04481274992354571, 0.04470952170364481],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479893],
                                [0.7331497981296533, 0.04691007703066802, 0.21994012483967856],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.7537846145263816, 0.03659266883230394, 0.2096227166413145],
                                [0.7434672063280175, 0.24621538547361843, 0.010317408198364061],
                                [0.7434672063280174, 0.03659266883230394, 0.21994012483967856],
                                [0.9530899229693319, 0.02345503851533401, 0.023455038515334037],
                                [0.47654496148466596, 0.046910077030668074, 0.47654496148466596],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.5212544831883108, 0.0245553161788456, 0.45419020063284354],
                                [0.4988997223364884, 0.4787455168116892, 0.022354760851822406],
                                [0.4988997223364884, 0.024555316178845654, 0.47654496148466596],
                                [0.9530899229693319, 0.010825220107479883, 0.03608485692318818],
                                [0.21994012483967862, 0.046910077030668074, 0.7331497981296533],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.28872435185024026, 0.012517963525387255, 0.6987576846243725],
                                [0.25433223834495944, 0.7112756481497599, 0.03439211350528074],
                                [0.25433223834495955, 0.012517963525387144, 0.7331497981296533],
                                [0.9530899229693319, 0.002200555327023214, 0.04470952170364486],
                                [0.04470952170364484, 0.046910077030668074, 0.9083804012656871],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.12993391089668993, 0.004297882434145528, 0.8657682066691645],
                                [0.08732171630016738, 0.8700660891033101, 0.042612194596522504],
                                [0.08732171630016738, 0.004297882434145528, 0.9083804012656871],
                                [0.7778593198332981, 0.21994012483967856, 0.0022005553270232096],
                                [0.7331497981296534, 0.22214068016670177, 0.04470952170364481],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7369398686546831, 0.22044793674879443, 0.042612194596522504],
                                [0.7348425415475608, 0.2630601313453169, 0.002097327107122302],
                                [0.7348425415475608, 0.2204479367487944, 0.04470952170364481],
                                [0.8116620793739426, 0.17751270051857743, 0.010825220107479893],
                                [0.591721954534264, 0.1883379206260573, 0.21994012483967856],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.6103664971878766, 0.1800107861708089, 0.2096227166413145],
                                [0.6000490889895125, 0.38963350281212344, 0.010317408198364061],
                                [0.6000490889895125, 0.18001078617080896, 0.21994012483967856],
                                [0.8611622890110867, 0.11538267247357922, 0.023455038515334037],
                                [0.38461732752642086, 0.13883771098891318, 0.47654496148466596],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.4250145168398374, 0.12079528252731908, 0.45419020063284354],
                                [0.40265975598801484, 0.5749854831601627, 0.022354760851822406],
                                [0.40265975598801496, 0.12079528252731908, 0.47654496148466596],
                                [0.9106624986482308, 0.053252644428581034, 0.03608485692318818],
                                [0.17751270051857748, 0.08933750135176921, 0.7331497981296533],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.23966253649179814, 0.06157977888382937, 0.6987576846243725],
                                [0.20527042298651732, 0.760337463508202, 0.03439211350528074],
                                [0.2052704229865172, 0.061579778883829484, 0.7331497981296533],
                                [0.9444652581888753, 0.01082522010747989, 0.04470952170364486],
                                [0.03608485692318819, 0.05553474181112472, 0.9083804012656871],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.11308916502499167, 0.02114262830584379, 0.8657682066691645],
                                [0.0704769704284689, 0.8869108349750086, 0.042612194596522504],
                                [0.0704769704284689, 0.021142628305844013, 0.9083804012656871],
                                [0.5212544831883108, 0.47654496148466596, 0.0022005553270232096],
                                [0.47654496148466596, 0.4787455168116892, 0.04470952170364481],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.4797425662552998, 0.47764523914817764, 0.042612194596522504],
                                [0.4776452391481776, 0.5202574337447001, 0.002097327107122302],
                                [0.4776452391481776, 0.4776452391481776, 0.04470952170364481],
                                [0.6045574523660993, 0.3846173275264208, 0.010825220107479893],
                                [0.3846173275264207, 0.3954425476339007, 0.21994012483967856],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.4003473457785248, 0.3900299375801607, 0.2096227166413145],
                                [0.3900299375801608, 0.5996526542214752, 0.010317408198364061],
                                [0.39002993758016063, 0.39002993758016075, 0.21994012483967856],
                                [0.726544961484666, 0.25, 0.023455038515334037],
                                [0.25, 0.27345503851533404, 0.47654496148466596],
                                [0.25, 0.25, 0.5],
                                [0.28408228010948944, 0.261727519257667, 0.45419020063284354],
                                [0.261727519257667, 0.7159177198905106, 0.022354760851822406],
                                [0.261727519257667, 0.261727519257667, 0.47654496148466596],
                                [0.8485324706032326, 0.11538267247357926, 0.03608485692318818],
                                [0.11538267247357925, 0.15146752939676744, 0.7331497981296533],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.16781721444045417, 0.13342510093517335, 0.6987576846243725],
                                [0.13342510093517335, 0.832182785559546, 0.03439211350528074],
                                [0.13342510093517335, 0.13342510093517335, 0.7331497981296533],
                                [0.9318354397810211, 0.023455038515334016, 0.04470952170364486],
                                [0.023455038515334037, 0.06816456021897888, 0.9083804012656871],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.088421993963679, 0.045809799367156456, 0.8657682066691645],
                                [0.045809799367156456, 0.911578006036321, 0.042612194596522504],
                                [0.045809799367156456, 0.045809799367156456, 0.9083804012656871],
                                [0.26464964654332346, 0.7331497981296533, 0.0022005553270232096],
                                [0.21994012483967862, 0.7353503534566765, 0.04470952170364481],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.22254526385591678, 0.7348425415475607, 0.042612194596522504],
                                [0.22044793674879448, 0.7774547361440832, 0.002097327107122302],
                                [0.22044793674879448, 0.7348425415475607, 0.04470952170364481],
                                [0.397452825358256, 0.5917219545342641, 0.010825220107479893],
                                [0.17751270051857748, 0.6025471746417439, 0.21994012483967856],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.19032819436917303, 0.6000490889895125, 0.2096227166413145],
                                [0.18001078617080912, 0.8096718056308269, 0.010317408198364061],
                                [0.1800107861708089, 0.6000490889895125, 0.21994012483967856],
                                [0.5919276339582452, 0.38461732752642075, 0.023455038515334037],
                                [0.11538267247357925, 0.4080723660417548, 0.47654496148466596],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.1431500433791416, 0.40265975598801484, 0.45419020063284354],
                                [0.12079528252731919, 0.8568499566208584, 0.022354760851822406],
                                [0.12079528252731919, 0.40265975598801484, 0.47654496148466596],
                                [0.7864024425582343, 0.17751270051857748, 0.03608485692318818],
                                [0.05325264442858102, 0.21359755744176567, 0.7331497981296533],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.09597189238911019, 0.20527042298651732, 0.6987576846243725],
                                [0.061579778883829484, 0.9040281076108898, 0.03439211350528074],
                                [0.061579778883829484, 0.2052704229865172, 0.7331497981296533],
                                [0.919205621373167, 0.03608485692318817, 0.04470952170364486],
                                [0.010825220107479883, 0.08079437862683303, 0.9083804012656871],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.06375482290236656, 0.0704769704284689, 0.8657682066691645],
                                [0.021142628305844013, 0.9362451770976334, 0.042612194596522504],
                                [0.021142628305844013, 0.0704769704284689, 0.9083804012656871],
                                [0.08941904340728968, 0.9083804012656871, 0.0022005553270232096],
                                [0.04470952170364484, 0.9105809565927103, 0.04470952170364481],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.04481274992354578, 0.9530899229693319, 0.002097327107122302],
                                [0.04481274992354578, 0.9104777283728094, 0.04470952170364481],
                                [0.2560249817628667, 0.7331497981296534, 0.010825220107479893],
                                [0.03608485692318819, 0.7439750182371332, 0.21994012483967856],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.03659266883230394, 0.953089922969332, 0.010317408198364061],
                                [0.03659266883230394, 0.7434672063280174, 0.21994012483967856],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.023455038515334037, 0.5, 0.47654496148466596],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.024555316178845654, 0.9530899229693319, 0.022354760851822406],
                                [0.024555316178845654, 0.4988997223364884, 0.47654496148466596],
                                [0.7439750182371332, 0.21994012483967862, 0.03608485692318818],
                                [0.010825220107479883, 0.2560249817628668, 0.7331497981296533],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.012517963525387366, 0.9530899229693319, 0.03439211350528074],
                                [0.012517963525387255, 0.25433223834495944, 0.7331497981296533],
                                [0.9105809565927103, 0.04470952170364482, 0.04470952170364486],
                                [0.0022005553270232348, 0.08941904340728968, 0.9083804012656871],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.004297882434145528, 0.9530899229693319, 0.042612194596522504],
                                [0.004297882434145528, 0.08732171630016738, 0.9083804012656871],
                                [0.9530899229693319, 0.04470952170364481, 0.0022005553270232096],
                                [0.9083804012656871, 0.04691007703066802, 0.04470952170364481],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9207951365711736, 0.04481274992354571, 0.03439211350528075],
                                [0.9104777283728095, 0.07920486342882647, 0.010317408198364061],
                                [0.9104777283728095, 0.04481274992354571, 0.04470952170364481],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479893],
                                [0.7331497981296533, 0.04691007703066802, 0.21994012483967856],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.794221765104367, 0.03659266883230394, 0.16918556606332905],
                                [0.7434672063280175, 0.205778234895633, 0.05075455877634952],
                                [0.7434672063280174, 0.03659266883230394, 0.21994012483967856],
                                [0.9530899229693319, 0.02345503851533401, 0.023455038515334037],
                                [0.47654496148466596, 0.046910077030668074, 0.47654496148466596],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.6088697847563278, 0.0245553161788456, 0.36657489906482665],
                                [0.4988997223364884, 0.3911302152436723, 0.10997006241983928],
                                [0.4988997223364884, 0.024555316178845654, 0.47654496148466596],
                                [0.9530899229693319, 0.010825220107479883, 0.03608485692318818],
                                [0.21994012483967862, 0.046910077030668074, 0.7331497981296533],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.42351780440828857, 0.012517963525387144, 0.5639642320663243],
                                [0.25433223834495944, 0.5764821955917115, 0.16918556606332902],
                                [0.25433223834495955, 0.012517963525387144, 0.7331497981296533],
                                [0.9530899229693319, 0.002200555327023214, 0.04470952170364486],
                                [0.04470952170364484, 0.046910077030668074, 0.9083804012656871],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.2969444329414821, 0.004297882434145306, 0.6987576846243726],
                                [0.08732171630016738, 0.7030555670585181, 0.2096227166413145],
                                [0.08732171630016738, 0.004297882434145528, 0.9083804012656871],
                                [0.7778593198332981, 0.21994012483967856, 0.0022005553270232096],
                                [0.7331497981296534, 0.22214068016670177, 0.04470952170364481],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7451599497459249, 0.22044793674879437, 0.03439211350528075],
                                [0.7348425415475608, 0.25484005025407513, 0.010317408198364061],
                                [0.7348425415475608, 0.2204479367487944, 0.04470952170364481],
                                [0.8116620793739426, 0.17751270051857743, 0.010825220107479893],
                                [0.591721954534264, 0.1883379206260573, 0.21994012483967856],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.6508036477658621, 0.18001078617080893, 0.16918556606332905],
                                [0.6000490889895125, 0.34919635223413803, 0.05075455877634952],
                                [0.6000490889895125, 0.18001078617080896, 0.21994012483967856],
                                [0.8611622890110867, 0.11538267247357922, 0.023455038515334037],
                                [0.38461732752642086, 0.13883771098891318, 0.47654496148466596],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.5126298184078542, 0.12079528252731914, 0.36657489906482665],
                                [0.40265975598801484, 0.48737018159214585, 0.10997006241983928],
                                [0.40265975598801496, 0.12079528252731908, 0.47654496148466596],
                                [0.9106624986482308, 0.053252644428581034, 0.03608485692318818],
                                [0.17751270051857748, 0.08933750135176921, 0.7331497981296533],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.37445598904984645, 0.06157977888382926, 0.5639642320663243],
                                [0.20527042298651732, 0.6255440109501537, 0.16918556606332902],
                                [0.2052704229865172, 0.061579778883829484, 0.7331497981296533],
                                [0.9444652581888753, 0.01082522010747989, 0.04470952170364486],
                                [0.03608485692318819, 0.05553474181112472, 0.9083804012656871],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.2800996870697836, 0.02114262830584379, 0.6987576846243726],
                                [0.0704769704284689, 0.7199003129302166, 0.2096227166413145],
                                [0.0704769704284689, 0.021142628305844013, 0.9083804012656871],
                                [0.5212544831883108, 0.47654496148466596, 0.0022005553270232096],
                                [0.47654496148466596, 0.4787455168116892, 0.04470952170364481],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.48796264734654177, 0.4776452391481775, 0.03439211350528075],
                                [0.4776452391481776, 0.5120373526534584, 0.010317408198364061],
                                [0.4776452391481776, 0.4776452391481776, 0.04470952170364481],
                                [0.6045574523660993, 0.3846173275264208, 0.010825220107479893],
                                [0.3846173275264207, 0.3954425476339007, 0.21994012483967856],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.4407844963565103, 0.3900299375801607, 0.16918556606332905],
                                [0.3900299375801608, 0.5592155036434897, 0.05075455877634952],
                                [0.39002993758016063, 0.39002993758016075, 0.21994012483967856],
                                [0.726544961484666, 0.25, 0.023455038515334037],
                                [0.25, 0.27345503851533404, 0.47654496148466596],
                                [0.25, 0.25, 0.5],
                                [0.37169758167750633, 0.261727519257667, 0.36657489906482665],
                                [0.261727519257667, 0.6283024183224937, 0.10997006241983928],
                                [0.261727519257667, 0.261727519257667, 0.47654496148466596],
                                [0.8485324706032326, 0.11538267247357926, 0.03608485692318818],
                                [0.11538267247357925, 0.15146752939676744, 0.7331497981296533],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.3026106669985025, 0.13342510093517324, 0.5639642320663243],
                                [0.13342510093517335, 0.6973893330014976, 0.16918556606332902],
                                [0.13342510093517335, 0.13342510093517335, 0.7331497981296533],
                                [0.9318354397810211, 0.023455038515334016, 0.04470952170364486],
                                [0.023455038515334037, 0.06816456021897888, 0.9083804012656871],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.25543251600847094, 0.045809799367156456, 0.6987576846243726],
                                [0.045809799367156456, 0.744567483991529, 0.2096227166413145],
                                [0.045809799367156456, 0.045809799367156456, 0.9083804012656871],
                                [0.26464964654332346, 0.7331497981296533, 0.0022005553270232096],
                                [0.21994012483967862, 0.7353503534566765, 0.04470952170364481],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528075],
                                [0.22044793674879448, 0.7692346550528415, 0.010317408198364061],
                                [0.22044793674879448, 0.7348425415475607, 0.04470952170364481],
                                [0.397452825358256, 0.5917219545342641, 0.010825220107479893],
                                [0.17751270051857748, 0.6025471746417439, 0.21994012483967856],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332905],
                                [0.18001078617080912, 0.7692346550528414, 0.05075455877634952],
                                [0.1800107861708089, 0.6000490889895125, 0.21994012483967856],
                                [0.5919276339582452, 0.38461732752642075, 0.023455038515334037],
                                [0.11538267247357925, 0.4080723660417548, 0.47654496148466596],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.12079528252731919, 0.7692346550528415, 0.10997006241983928],
                                [0.12079528252731919, 0.40265975598801484, 0.47654496148466596],
                                [0.7864024425582343, 0.17751270051857748, 0.03608485692318818],
                                [0.05325264442858102, 0.21359755744176567, 0.7331497981296533],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.061579778883829484, 0.7692346550528415, 0.16918556606332902],
                                [0.061579778883829484, 0.2052704229865172, 0.7331497981296533],
                                [0.919205621373167, 0.03608485692318817, 0.04470952170364486],
                                [0.010825220107479883, 0.08079437862683303, 0.9083804012656871],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.2307653449471585, 0.0704769704284689, 0.6987576846243726],
                                [0.021142628305844013, 0.7692346550528415, 0.2096227166413145],
                                [0.021142628305844013, 0.0704769704284689, 0.9083804012656871],
                                [0.08941904340728968, 0.9083804012656871, 0.0022005553270232096],
                                [0.04470952170364484, 0.9105809565927103, 0.04470952170364481],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.0551301581219098, 0.9104777283728095, 0.03439211350528075],
                                [0.04481274992354578, 0.9448698418780902, 0.010317408198364061],
                                [0.04481274992354578, 0.9104777283728094, 0.04470952170364481],
                                [0.2560249817628667, 0.7331497981296534, 0.010825220107479893],
                                [0.03608485692318819, 0.7439750182371332, 0.21994012483967856],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.08734722760865354, 0.7434672063280174, 0.16918556606332905],
                                [0.03659266883230394, 0.9126527723913466, 0.05075455877634952],
                                [0.03659266883230394, 0.7434672063280174, 0.21994012483967856],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.023455038515334037, 0.5, 0.47654496148466596],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.13452537859868496, 0.4988997223364884, 0.36657489906482665],
                                [0.024555316178845654, 0.865474621401315, 0.10997006241983928],
                                [0.024555316178845654, 0.4988997223364884, 0.47654496148466596],
                                [0.7439750182371332, 0.21994012483967862, 0.03608485692318818],
                                [0.010825220107479883, 0.2560249817628668, 0.7331497981296533],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.18170352958871638, 0.2543322383449593, 0.5639642320663243],
                                [0.012517963525387366, 0.8182964704112836, 0.16918556606332902],
                                [0.012517963525387255, 0.25433223834495944, 0.7331497981296533],
                                [0.9105809565927103, 0.04470952170364482, 0.04470952170364486],
                                [0.0022005553270232348, 0.08941904340728968, 0.9083804012656871],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.21392059907546002, 0.08732171630016738, 0.6987576846243726],
                                [0.004297882434145528, 0.78607940092454, 0.2096227166413145],
                                [0.004297882434145528, 0.08732171630016738, 0.9083804012656871],
                                [0.9530899229693319, 0.04470952170364481, 0.0022005553270232096],
                                [0.9083804012656871, 0.04691007703066802, 0.04470952170364481],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9328324892246319, 0.04481274992354571, 0.022354760851822406],
                                [0.9104777283728095, 0.06716751077536813, 0.022354760851822406],
                                [0.9104777283728095, 0.04481274992354571, 0.04470952170364481],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479893],
                                [0.7331497981296533, 0.04691007703066802, 0.21994012483967856],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.8534372687478567, 0.03659266883230397, 0.10997006241983928],
                                [0.7434672063280174, 0.14656273125214322, 0.10997006241983928],
                                [0.7434672063280174, 0.03659266883230394, 0.21994012483967856],
                                [0.9530899229693319, 0.02345503851533401, 0.023455038515334037],
                                [0.47654496148466596, 0.046910077030668074, 0.47654496148466596],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.7371722030788214, 0.024555316178845654, 0.23827248074233298],
                                [0.4988997223364884, 0.26282779692117864, 0.23827248074233298],
                                [0.4988997223364884, 0.024555316178845654, 0.47654496148466596],
                                [0.9530899229693319, 0.010825220107479883, 0.03608485692318818],
                                [0.21994012483967862, 0.046910077030668074, 0.7331497981296533],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.6209071374097861, 0.012517963525387255, 0.36657489906482665],
                                [0.25433223834495944, 0.3790928625902139, 0.36657489906482665],
                                [0.25433223834495955, 0.012517963525387144, 0.7331497981296533],
                                [0.9530899229693319, 0.002200555327023214, 0.04470952170364486],
                                [0.04470952170364484, 0.046910077030668074, 0.9083804012656871],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.5415119169330109, 0.004297882434145528, 0.45419020063284354],
                                [0.08732171630016738, 0.45848808306698907, 0.45419020063284354],
                                [0.08732171630016738, 0.004297882434145528, 0.9083804012656871],
                                [0.7778593198332981, 0.21994012483967856, 0.0022005553270232096],
                                [0.7331497981296534, 0.22214068016670177, 0.04470952170364481],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7571973023993832, 0.22044793674879437, 0.022354760851822406],
                                [0.7348425415475608, 0.2428026976006168, 0.022354760851822406],
                                [0.7348425415475608, 0.2204479367487944, 0.04470952170364481],
                                [0.8116620793739426, 0.17751270051857743, 0.010825220107479893],
                                [0.591721954534264, 0.1883379206260573, 0.21994012483967856],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7100191514093518, 0.18001078617080893, 0.10997006241983928],
                                [0.6000490889895125, 0.2899808485906482, 0.10997006241983928],
                                [0.6000490889895125, 0.18001078617080896, 0.21994012483967856],
                                [0.8611622890110867, 0.11538267247357922, 0.023455038515334037],
                                [0.38461732752642086, 0.13883771098891318, 0.47654496148466596],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.6409322367303478, 0.12079528252731919, 0.23827248074233298],
                                [0.40265975598801484, 0.3590677632696522, 0.23827248074233298],
                                [0.40265975598801496, 0.12079528252731908, 0.47654496148466596],
                                [0.9106624986482308, 0.053252644428581034, 0.03608485692318818],
                                [0.17751270051857748, 0.08933750135176921, 0.7331497981296533],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.571845322051344, 0.06157977888382943, 0.36657489906482665],
                                [0.20527042298651732, 0.428154677948656, 0.36657489906482665],
                                [0.2052704229865172, 0.061579778883829484, 0.7331497981296533],
                                [0.9444652581888753, 0.01082522010747989, 0.04470952170364486],
                                [0.03608485692318819, 0.05553474181112472, 0.9083804012656871],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.5246671710613124, 0.021142628305843958, 0.45419020063284354],
                                [0.0704769704284689, 0.47533282893868756, 0.45419020063284354],
                                [0.0704769704284689, 0.021142628305844013, 0.9083804012656871],
                                [0.5212544831883108, 0.47654496148466596, 0.0022005553270232096],
                                [0.47654496148466596, 0.4787455168116892, 0.04470952170364481],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.4776452391481776, 0.5, 0.022354760851822406],
                                [0.4776452391481776, 0.4776452391481776, 0.04470952170364481],
                                [0.6045574523660993, 0.3846173275264208, 0.010825220107479893],
                                [0.3846173275264207, 0.3954425476339007, 0.21994012483967856],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.3900299375801608, 0.4999999999999999, 0.10997006241983928],
                                [0.39002993758016063, 0.39002993758016075, 0.21994012483967856],
                                [0.726544961484666, 0.25, 0.023455038515334037],
                                [0.25, 0.27345503851533404, 0.47654496148466596],
                                [0.25, 0.25, 0.5],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.261727519257667, 0.5, 0.23827248074233298],
                                [0.261727519257667, 0.261727519257667, 0.47654496148466596],
                                [0.8485324706032326, 0.11538267247357926, 0.03608485692318818],
                                [0.11538267247357925, 0.15146752939676744, 0.7331497981296533],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.13342510093517335, 0.5, 0.36657489906482665],
                                [0.13342510093517335, 0.13342510093517335, 0.7331497981296533],
                                [0.9318354397810211, 0.023455038515334016, 0.04470952170364486],
                                [0.023455038515334037, 0.06816456021897888, 0.9083804012656871],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.045809799367156456, 0.5, 0.45419020063284354],
                                [0.045809799367156456, 0.045809799367156456, 0.9083804012656871],
                                [0.26464964654332346, 0.7331497981296533, 0.0022005553270232096],
                                [0.21994012483967862, 0.7353503534566765, 0.04470952170364481],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.2428026976006168, 0.7348425415475608, 0.022354760851822406],
                                [0.22044793674879448, 0.7571973023993831, 0.022354760851822406],
                                [0.22044793674879448, 0.7348425415475607, 0.04470952170364481],
                                [0.397452825358256, 0.5917219545342641, 0.010825220107479893],
                                [0.17751270051857748, 0.6025471746417439, 0.21994012483967856],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.2899808485906482, 0.6000490889895125, 0.10997006241983928],
                                [0.18001078617080912, 0.7100191514093516, 0.10997006241983928],
                                [0.1800107861708089, 0.6000490889895125, 0.21994012483967856],
                                [0.5919276339582452, 0.38461732752642075, 0.023455038515334037],
                                [0.11538267247357925, 0.4080723660417548, 0.47654496148466596],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.3590677632696522, 0.40265975598801484, 0.23827248074233298],
                                [0.12079528252731919, 0.6409322367303478, 0.23827248074233298],
                                [0.12079528252731919, 0.40265975598801484, 0.47654496148466596],
                                [0.7864024425582343, 0.17751270051857748, 0.03608485692318818],
                                [0.05325264442858102, 0.21359755744176567, 0.7331497981296533],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.428154677948656, 0.20527042298651732, 0.36657489906482665],
                                [0.061579778883829484, 0.5718453220513439, 0.36657489906482665],
                                [0.061579778883829484, 0.2052704229865172, 0.7331497981296533],
                                [0.919205621373167, 0.03608485692318817, 0.04470952170364486],
                                [0.010825220107479883, 0.08079437862683303, 0.9083804012656871],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.47533282893868756, 0.0704769704284689, 0.45419020063284354],
                                [0.021142628305844013, 0.5246671710613124, 0.45419020063284354],
                                [0.021142628305844013, 0.0704769704284689, 0.9083804012656871],
                                [0.08941904340728968, 0.9083804012656871, 0.0022005553270232096],
                                [0.04470952170364484, 0.9105809565927103, 0.04470952170364481],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.0671675107753682, 0.9104777283728094, 0.022354760851822406],
                                [0.04481274992354578, 0.9328324892246318, 0.022354760851822406],
                                [0.04481274992354578, 0.9104777283728094, 0.04470952170364481],
                                [0.2560249817628667, 0.7331497981296534, 0.010825220107479893],
                                [0.03608485692318819, 0.7439750182371332, 0.21994012483967856],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.14656273125214325, 0.7434672063280174, 0.10997006241983928],
                                [0.03659266883230394, 0.8534372687478567, 0.10997006241983928],
                                [0.03659266883230394, 0.7434672063280174, 0.21994012483967856],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.023455038515334037, 0.5, 0.47654496148466596],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.26282779692117864, 0.4988997223364884, 0.23827248074233298],
                                [0.024555316178845654, 0.7371722030788214, 0.23827248074233298],
                                [0.024555316178845654, 0.4988997223364884, 0.47654496148466596],
                                [0.7439750182371332, 0.21994012483967862, 0.03608485692318818],
                                [0.010825220107479883, 0.2560249817628668, 0.7331497981296533],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.3790928625902139, 0.25433223834495944, 0.36657489906482665],
                                [0.012517963525387366, 0.620907137409786, 0.36657489906482665],
                                [0.012517963525387255, 0.25433223834495944, 0.7331497981296533],
                                [0.9105809565927103, 0.04470952170364482, 0.04470952170364486],
                                [0.0022005553270232348, 0.08941904340728968, 0.9083804012656871],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.45848808306698907, 0.08732171630016738, 0.45419020063284354],
                                [0.004297882434145528, 0.5415119169330109, 0.45419020063284354],
                                [0.004297882434145528, 0.08732171630016738, 0.9083804012656871],
                                [0.9530899229693319, 0.04470952170364481, 0.0022005553270232096],
                                [0.9083804012656871, 0.04691007703066802, 0.04470952170364481],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.9448698418780903, 0.04481274992354571, 0.010317408198364065],
                                [0.9104777283728095, 0.055130158121909786, 0.03439211350528075],
                                [0.9104777283728095, 0.04481274992354571, 0.04470952170364481],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479893],
                                [0.7331497981296533, 0.04691007703066802, 0.21994012483967856],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.9126527723913466, 0.036592668832303964, 0.050754558776349525],
                                [0.7434672063280175, 0.08734722760865346, 0.16918556606332905],
                                [0.7434672063280174, 0.03659266883230394, 0.21994012483967856],
                                [0.9530899229693319, 0.02345503851533401, 0.023455038515334037],
                                [0.47654496148466596, 0.046910077030668074, 0.47654496148466596],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.8654746214013151, 0.0245553161788456, 0.10997006241983931],
                                [0.4988997223364884, 0.13452537859868496, 0.36657489906482665],
                                [0.4988997223364884, 0.024555316178845654, 0.47654496148466596],
                                [0.9530899229693319, 0.010825220107479883, 0.03608485692318818],
                                [0.21994012483967862, 0.046910077030668074, 0.7331497981296533],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.8182964704112837, 0.012517963525387255, 0.16918556606332907],
                                [0.25433223834495944, 0.18170352958871627, 0.5639642320663243],
                                [0.25433223834495955, 0.012517963525387144, 0.7331497981296533],
                                [0.9530899229693319, 0.002200555327023214, 0.04470952170364486],
                                [0.04470952170364484, 0.046910077030668074, 0.9083804012656871],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.78607940092454, 0.0042978824341455, 0.20962271664131454],
                                [0.08732171630016738, 0.21392059907546002, 0.6987576846243726],
                                [0.08732171630016738, 0.004297882434145528, 0.9083804012656871],
                                [0.7778593198332981, 0.21994012483967856, 0.0022005553270232096],
                                [0.7331497981296534, 0.22214068016670177, 0.04470952170364481],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364065],
                                [0.7348425415475608, 0.23076534494715845, 0.03439211350528075],
                                [0.7348425415475608, 0.2204479367487944, 0.04470952170364481],
                                [0.8116620793739426, 0.17751270051857743, 0.010825220107479893],
                                [0.591721954534264, 0.1883379206260573, 0.21994012483967856],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.7692346550528416, 0.18001078617080893, 0.050754558776349525],
                                [0.6000490889895125, 0.23076534494715847, 0.16918556606332905],
                                [0.6000490889895125, 0.18001078617080896, 0.21994012483967856],
                                [0.8611622890110867, 0.11538267247357922, 0.023455038515334037],
                                [0.38461732752642086, 0.13883771098891318, 0.47654496148466596],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983931],
                                [0.40265975598801484, 0.2307653449471585, 0.36657489906482665],
                                [0.40265975598801496, 0.12079528252731908, 0.47654496148466596],
                                [0.9106624986482308, 0.053252644428581034, 0.03608485692318818],
                                [0.17751270051857748, 0.08933750135176921, 0.7331497981296533],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.7692346550528416, 0.0615797788838294, 0.16918556606332907],
                                [0.20527042298651732, 0.2307653449471584, 0.5639642320663243],
                                [0.2052704229865172, 0.061579778883829484, 0.7331497981296533],
                                [0.9444652581888753, 0.01082522010747989, 0.04470952170364486],
                                [0.03608485692318819, 0.05553474181112472, 0.9083804012656871],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.7692346550528415, 0.021142628305843958, 0.20962271664131454],
                                [0.0704769704284689, 0.2307653449471585, 0.6987576846243726],
                                [0.0704769704284689, 0.021142628305844013, 0.9083804012656871],
                                [0.5212544831883108, 0.47654496148466596, 0.0022005553270232096],
                                [0.47654496148466596, 0.4787455168116892, 0.04470952170364481],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5120373526534584, 0.4776452391481776, 0.010317408198364065],
                                [0.47764523914817764, 0.48796264734654166, 0.03439211350528075],
                                [0.4776452391481776, 0.4776452391481776, 0.04470952170364481],
                                [0.6045574523660993, 0.3846173275264208, 0.010825220107479893],
                                [0.3846173275264207, 0.3954425476339007, 0.21994012483967856],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5592155036434898, 0.3900299375801607, 0.050754558776349525],
                                [0.3900299375801608, 0.4407844963565102, 0.16918556606332905],
                                [0.39002993758016063, 0.39002993758016075, 0.21994012483967856],
                                [0.726544961484666, 0.25, 0.023455038515334037],
                                [0.25, 0.27345503851533404, 0.47654496148466596],
                                [0.25, 0.25, 0.5],
                                [0.6283024183224937, 0.261727519257667, 0.10997006241983931],
                                [0.261727519257667, 0.37169758167750633, 0.36657489906482665],
                                [0.261727519257667, 0.261727519257667, 0.47654496148466596],
                                [0.8485324706032326, 0.11538267247357926, 0.03608485692318818],
                                [0.11538267247357925, 0.15146752939676744, 0.7331497981296533],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.6973893330014976, 0.13342510093517335, 0.16918556606332907],
                                [0.13342510093517335, 0.30261066699850236, 0.5639642320663243],
                                [0.13342510093517335, 0.13342510093517335, 0.7331497981296533],
                                [0.9318354397810211, 0.023455038515334016, 0.04470952170364486],
                                [0.023455038515334037, 0.06816456021897888, 0.9083804012656871],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.744567483991529, 0.045809799367156456, 0.20962271664131454],
                                [0.045809799367156456, 0.25543251600847094, 0.6987576846243726],
                                [0.045809799367156456, 0.045809799367156456, 0.9083804012656871],
                                [0.26464964654332346, 0.7331497981296533, 0.0022005553270232096],
                                [0.21994012483967862, 0.7353503534566765, 0.04470952170364481],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.2548400502540752, 0.7348425415475608, 0.010317408198364065],
                                [0.22044793674879448, 0.7451599497459248, 0.03439211350528075],
                                [0.22044793674879448, 0.7348425415475607, 0.04470952170364481],
                                [0.397452825358256, 0.5917219545342641, 0.010825220107479893],
                                [0.17751270051857748, 0.6025471746417439, 0.21994012483967856],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.34919635223413803, 0.6000490889895125, 0.050754558776349525],
                                [0.18001078617080912, 0.6508036477658619, 0.16918556606332905],
                                [0.1800107861708089, 0.6000490889895125, 0.21994012483967856],
                                [0.5919276339582452, 0.38461732752642075, 0.023455038515334037],
                                [0.11538267247357925, 0.4080723660417548, 0.47654496148466596],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.48737018159214585, 0.40265975598801484, 0.10997006241983931],
                                [0.12079528252731919, 0.5126298184078542, 0.36657489906482665],
                                [0.12079528252731919, 0.40265975598801484, 0.47654496148466596],
                                [0.7864024425582343, 0.17751270051857748, 0.03608485692318818],
                                [0.05325264442858102, 0.21359755744176567, 0.7331497981296533],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.6255440109501538, 0.20527042298651726, 0.16918556606332907],
                                [0.061579778883829484, 0.3744559890498462, 0.5639642320663243],
                                [0.061579778883829484, 0.2052704229865172, 0.7331497981296533],
                                [0.919205621373167, 0.03608485692318817, 0.04470952170364486],
                                [0.010825220107479883, 0.08079437862683303, 0.9083804012656871],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.7199003129302166, 0.07047697042846895, 0.20962271664131454],
                                [0.021142628305844013, 0.2800996870697834, 0.6987576846243726],
                                [0.021142628305844013, 0.0704769704284689, 0.9083804012656871],
                                [0.08941904340728968, 0.9083804012656871, 0.0022005553270232096],
                                [0.04470952170364484, 0.9105809565927103, 0.04470952170364481],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.07920486342882649, 0.9104777283728095, 0.010317408198364065],
                                [0.04481274992354578, 0.9207951365711735, 0.03439211350528075],
                                [0.04481274992354578, 0.9104777283728094, 0.04470952170364481],
                                [0.2560249817628667, 0.7331497981296534, 0.010825220107479893],
                                [0.03608485692318819, 0.7439750182371332, 0.21994012483967856],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.20577823489563307, 0.7434672063280174, 0.050754558776349525],
                                [0.03659266883230394, 0.794221765104367, 0.16918556606332905],
                                [0.03659266883230394, 0.7434672063280174, 0.21994012483967856],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.023455038515334037, 0.5, 0.47654496148466596],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.3911302152436723, 0.4988997223364884, 0.10997006241983931],
                                [0.024555316178845654, 0.6088697847563277, 0.36657489906482665],
                                [0.024555316178845654, 0.4988997223364884, 0.47654496148466596],
                                [0.7439750182371332, 0.21994012483967862, 0.03608485692318818],
                                [0.010825220107479883, 0.2560249817628668, 0.7331497981296533],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.5764821955917117, 0.2543322383449594, 0.16918556606332907],
                                [0.012517963525387366, 0.42351780440828835, 0.5639642320663243],
                                [0.012517963525387255, 0.25433223834495944, 0.7331497981296533],
                                [0.9105809565927103, 0.04470952170364482, 0.04470952170364486],
                                [0.0022005553270232348, 0.08941904340728968, 0.9083804012656871],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.7030555670585181, 0.08732171630016744, 0.20962271664131454],
                                [0.004297882434145528, 0.2969444329414819, 0.6987576846243726],
                                [0.004297882434145528, 0.08732171630016738, 0.9083804012656871],
                                [0.9530899229693319, 0.04470952170364481, 0.0022005553270232096],
                                [0.9083804012656871, 0.04691007703066802, 0.04470952170364481],
                                [0.9083804012656871, 0.04470952170364481, 0.04691007703066802],
                                [0.953089922969332, 0.04481274992354571, 0.002097327107122304],
                                [0.9104777283728094, 0.04691007703066803, 0.042612194596522504],
                                [0.9104777283728095, 0.04481274992354571, 0.04470952170364481],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479893],
                                [0.7331497981296533, 0.04691007703066802, 0.21994012483967856],
                                [0.7331497981296533, 0.036084856923188136, 0.23076534494715845],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364074],
                                [0.7434672063280174, 0.04691007703066802, 0.2096227166413145],
                                [0.7434672063280174, 0.03659266883230394, 0.21994012483967856],
                                [0.9530899229693319, 0.02345503851533401, 0.023455038515334037],
                                [0.47654496148466596, 0.046910077030668074, 0.47654496148466596],
                                [0.47654496148466596, 0.023455038515334037, 0.5],
                                [0.9530899229693319, 0.024555316178845616, 0.02235476085182243],
                                [0.4988997223364884, 0.046910077030668074, 0.45419020063284354],
                                [0.4988997223364884, 0.024555316178845654, 0.47654496148466596],
                                [0.9530899229693319, 0.010825220107479883, 0.03608485692318818],
                                [0.21994012483967862, 0.046910077030668074, 0.7331497981296533],
                                [0.21994012483967862, 0.010825220107479883, 0.7692346550528415],
                                [0.9530899229693319, 0.012517963525387275, 0.034392113505280784],
                                [0.25433223834495944, 0.046910077030668074, 0.6987576846243725],
                                [0.25433223834495955, 0.012517963525387144, 0.7331497981296533],
                                [0.9530899229693319, 0.002200555327023214, 0.04470952170364486],
                                [0.04470952170364484, 0.046910077030668074, 0.9083804012656871],
                                [0.04470952170364484, 0.0022005553270232348, 0.9530899229693319],
                                [0.9530899229693319, 0.004297882434145514, 0.04261219459652255],
                                [0.08732171630016738, 0.046910077030668074, 0.8657682066691645],
                                [0.08732171630016738, 0.004297882434145528, 0.9083804012656871],
                                [0.7778593198332981, 0.21994012483967856, 0.0022005553270232096],
                                [0.7331497981296534, 0.22214068016670177, 0.04470952170364481],
                                [0.7331497981296533, 0.21994012483967856, 0.04691007703066802],
                                [0.7774547361440833, 0.2204479367487944, 0.002097327107122304],
                                [0.7348425415475608, 0.22254526385591672, 0.042612194596522504],
                                [0.7348425415475608, 0.2204479367487944, 0.04470952170364481],
                                [0.8116620793739426, 0.17751270051857743, 0.010825220107479893],
                                [0.591721954534264, 0.1883379206260573, 0.21994012483967856],
                                [0.591721954534264, 0.17751270051857743, 0.23076534494715845],
                                [0.8096718056308271, 0.18001078617080893, 0.010317408198364074],
                                [0.6000490889895125, 0.19032819436917303, 0.2096227166413145],
                                [0.6000490889895125, 0.18001078617080896, 0.21994012483967856],
                                [0.8611622890110867, 0.11538267247357922, 0.023455038515334037],
                                [0.38461732752642086, 0.13883771098891318, 0.47654496148466596],
                                [0.38461732752642086, 0.11538267247357914, 0.5],
                                [0.8568499566208584, 0.12079528252731918, 0.02235476085182243],
                                [0.40265975598801484, 0.1431500433791416, 0.45419020063284354],
                                [0.40265975598801496, 0.12079528252731908, 0.47654496148466596],
                                [0.9106624986482308, 0.053252644428581034, 0.03608485692318818],
                                [0.17751270051857748, 0.08933750135176921, 0.7331497981296533],
                                [0.17751270051857748, 0.05325264442858102, 0.7692346550528415],
                                [0.9040281076108898, 0.06157977888382941, 0.034392113505280784],
                                [0.20527042298651732, 0.09597189238911019, 0.6987576846243725],
                                [0.2052704229865172, 0.061579778883829484, 0.7331497981296533],
                                [0.9444652581888753, 0.01082522010747989, 0.04470952170364486],
                                [0.03608485692318819, 0.05553474181112472, 0.9083804012656871],
                                [0.03608485692318819, 0.010825220107479883, 0.9530899229693319],
                                [0.9362451770976336, 0.02114262830584395, 0.04261219459652255],
                                [0.0704769704284689, 0.06375482290236656, 0.8657682066691645],
                                [0.0704769704284689, 0.021142628305844013, 0.9083804012656871],
                                [0.5212544831883108, 0.47654496148466596, 0.0022005553270232096],
                                [0.47654496148466596, 0.4787455168116892, 0.04470952170364481],
                                [0.4765449614846659, 0.476544961484666, 0.04691007703066802],
                                [0.5202574337447001, 0.4776452391481776, 0.002097327107122304],
                                [0.4776452391481775, 0.47974256625529993, 0.042612194596522504],
                                [0.4776452391481776, 0.4776452391481776, 0.04470952170364481],
                                [0.6045574523660993, 0.3846173275264208, 0.010825220107479893],
                                [0.3846173275264207, 0.3954425476339007, 0.21994012483967856],
                                [0.3846173275264207, 0.3846173275264208, 0.23076534494715845],
                                [0.5996526542214753, 0.39002993758016075, 0.010317408198364074],
                                [0.3900299375801608, 0.4003473457785247, 0.2096227166413145],
                                [0.39002993758016063, 0.39002993758016075, 0.21994012483967856],
                                [0.726544961484666, 0.25, 0.023455038515334037],
                                [0.25, 0.27345503851533404, 0.47654496148466596],
                                [0.25, 0.25, 0.5],
                                [0.7159177198905106, 0.261727519257667, 0.02235476085182243],
                                [0.261727519257667, 0.28408228010948944, 0.45419020063284354],
                                [0.261727519257667, 0.261727519257667, 0.47654496148466596],
                                [0.8485324706032326, 0.11538267247357926, 0.03608485692318818],
                                [0.11538267247357925, 0.15146752939676744, 0.7331497981296533],
                                [0.11538267247357925, 0.11538267247357925, 0.7692346550528415],
                                [0.8321827855595458, 0.13342510093517332, 0.034392113505280784],
                                [0.13342510093517335, 0.16781721444045417, 0.6987576846243725],
                                [0.13342510093517335, 0.13342510093517335, 0.7331497981296533],
                                [0.9318354397810211, 0.023455038515334016, 0.04470952170364486],
                                [0.023455038515334037, 0.06816456021897888, 0.9083804012656871],
                                [0.023455038515334037, 0.023455038515334037, 0.9530899229693319],
                                [0.911578006036321, 0.04580979936715645, 0.04261219459652255],
                                [0.045809799367156456, 0.088421993963679, 0.8657682066691645],
                                [0.045809799367156456, 0.045809799367156456, 0.9083804012656871],
                                [0.26464964654332346, 0.7331497981296533, 0.0022005553270232096],
                                [0.21994012483967862, 0.7353503534566765, 0.04470952170364481],
                                [0.21994012483967862, 0.7331497981296533, 0.04691007703066802],
                                [0.2630601313453169, 0.7348425415475608, 0.002097327107122304],
                                [0.22044793674879448, 0.736939868654683, 0.042612194596522504],
                                [0.22044793674879448, 0.7348425415475607, 0.04470952170364481],
                                [0.397452825358256, 0.5917219545342641, 0.010825220107479893],
                                [0.17751270051857748, 0.6025471746417439, 0.21994012483967856],
                                [0.17751270051857748, 0.591721954534264, 0.23076534494715845],
                                [0.3896335028121235, 0.6000490889895125, 0.010317408198364074],
                                [0.18001078617080912, 0.6103664971878764, 0.2096227166413145],
                                [0.1800107861708089, 0.6000490889895125, 0.21994012483967856],
                                [0.5919276339582452, 0.38461732752642075, 0.023455038515334037],
                                [0.11538267247357925, 0.4080723660417548, 0.47654496148466596],
                                [0.11538267247357925, 0.38461732752642075, 0.5],
                                [0.5749854831601627, 0.40265975598801484, 0.02235476085182243],
                                [0.12079528252731919, 0.42501451683983726, 0.45419020063284354],
                                [0.12079528252731919, 0.40265975598801484, 0.47654496148466596],
                                [0.7864024425582343, 0.17751270051857748, 0.03608485692318818],
                                [0.05325264442858102, 0.21359755744176567, 0.7331497981296533],
                                [0.05325264442858102, 0.17751270051857748, 0.7692346550528415],
                                [0.760337463508202, 0.20527042298651724, 0.034392113505280784],
                                [0.061579778883829484, 0.23966253649179803, 0.6987576846243725],
                                [0.061579778883829484, 0.2052704229865172, 0.7331497981296533],
                                [0.919205621373167, 0.03608485692318817, 0.04470952170364486],
                                [0.010825220107479883, 0.08079437862683303, 0.9083804012656871],
                                [0.010825220107479883, 0.03608485692318819, 0.9530899229693319],
                                [0.8869108349750084, 0.07047697042846901, 0.04261219459652255],
                                [0.021142628305844013, 0.11308916502499144, 0.8657682066691645],
                                [0.021142628305844013, 0.0704769704284689, 0.9083804012656871],
                                [0.08941904340728968, 0.9083804012656871, 0.0022005553270232096],
                                [0.04470952170364484, 0.9105809565927103, 0.04470952170364481],
                                [0.04470952170364484, 0.9083804012656871, 0.04691007703066802],
                                [0.08742494452006833, 0.9104777283728094, 0.002097327107122304],
                                [0.04481274992354578, 0.9125750554799317, 0.042612194596522504],
                                [0.04481274992354578, 0.9104777283728094, 0.04470952170364481],
                                [0.2560249817628667, 0.7331497981296534, 0.010825220107479893],
                                [0.03608485692318819, 0.7439750182371332, 0.21994012483967856],
                                [0.03608485692318819, 0.7331497981296533, 0.23076534494715845],
                                [0.24621538547361843, 0.7434672063280175, 0.010317408198364074],
                                [0.03659266883230394, 0.7537846145263816, 0.2096227166413145],
                                [0.03659266883230394, 0.7434672063280174, 0.21994012483967856],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.023455038515334037, 0.5, 0.47654496148466596],
                                [0.023455038515334037, 0.47654496148466596, 0.5],
                                [0.4787455168116892, 0.4988997223364884, 0.02235476085182243],
                                [0.024555316178845654, 0.5212544831883108, 0.45419020063284354],
                                [0.024555316178845654, 0.4988997223364884, 0.47654496148466596],
                                [0.7439750182371332, 0.21994012483967862, 0.03608485692318818],
                                [0.010825220107479883, 0.2560249817628668, 0.7331497981296533],
                                [0.010825220107479883, 0.21994012483967862, 0.7692346550528415],
                                [0.7112756481497597, 0.2543322383449594, 0.034392113505280784],
                                [0.012517963525387366, 0.28872435185024015, 0.6987576846243725],
                                [0.012517963525387255, 0.25433223834495944, 0.7331497981296533],
                                [0.9105809565927103, 0.04470952170364482, 0.04470952170364486],
                                [0.0022005553270232348, 0.08941904340728968, 0.9083804012656871],
                                [0.0022005553270232348, 0.04470952170364484, 0.9530899229693319],
                                [0.8700660891033101, 0.08732171630016738, 0.04261219459652255],
                                [0.004297882434145528, 0.12993391089668993, 0.8657682066691645],
                                [0.004297882434145528, 0.08732171630016738, 0.9083804012656871],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.9063814599347185,
                                    0.0019989413309686862,
                                    0.09141798473825831,
                                    0.00020161399605452077,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9085771728179943,
                                    0.002003783774715976,
                                    0.08922227185498238,
                                    0.00019677155230723057,
                                ],
                                [
                                    0.9063814599347184,
                                    0.04461113592749119,
                                    0.04670846303461349,
                                    0.002298941103176822,
                                ],
                                [
                                    0.9084787870418407,
                                    0.0447143641473921,
                                    0.04461113592749119,
                                    0.002195712883275917,
                                ],
                                [
                                    0.906479845710872,
                                    0.044615978371238485,
                                    0.04661007725845988,
                                    0.0022940986594295323,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.73592132491025,
                                    0.008053693326883325,
                                    0.25325345498227014,
                                    0.002771526780596554,
                                ],
                                [
                                    0.7252132901931454,
                                    0.21755922457782245,
                                    0.04402136485969607,
                                    0.013206120369336003,
                                ],
                                [
                                    0.7335404246483938,
                                    0.22005731023005395,
                                    0.035694230404447705,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7256039167118858,
                                    0.21767640996819784,
                                    0.04363073834095564,
                                    0.013088934978960616,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.4882724807423329,
                                    0.011727519257667003,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.46591771989051056,
                                    0.46591771989051056,
                                    0.03408228010948941,
                                    0.03408228010948941,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.2467863569271919,
                                    0.0092386248356749,
                                    0.71712878614962,
                                    0.026846232087513234,
                                ],
                                [
                                    0.21200361690317068,
                                    0.7066941925608805,
                                    0.01876172804398782,
                                    0.06254046249196094,
                                ],
                                [
                                    0.22033075135841906,
                                    0.7344519150288203,
                                    0.01043459358873945,
                                    0.03478274002402117,
                                ],
                                [
                                    0.2123942434219111,
                                    0.7079963094600474,
                                    0.018371101525247388,
                                    0.06123834559279398,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.0854211607453523,
                                    0.003997882661937375,
                                    0.8698693175510028,
                                    0.04071163904170744,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991898,
                                    0.08532277496919863,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.04280896614882979,
                                    0.869766089331102,
                                    0.004101110881838283,
                                    0.08332383363822993,
                                ],
                                [
                                    0.7315364614358733,
                                    0.0016133366937801977,
                                    0.26626298323710357,
                                    0.0005872186332430093,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7337321743191492,
                                    0.0016181791375274879,
                                    0.2640672703538276,
                                    0.000582376189495719,
                                ],
                                [
                                    0.7315364614358731,
                                    0.03600545019906094,
                                    0.22155346153345876,
                                    0.010904626831607072,
                                ],
                                [
                                    0.7336337885429954,
                                    0.03610867841896185,
                                    0.21945613442633644,
                                    0.010801398611706165,
                                ],
                                [
                                    0.9068654503480605,
                                    0.04463495742326491,
                                    0.04622447262127139,
                                    0.002275119607403109,
                                ],
                                [
                                    0.5853164341340025,
                                    0.006405520400261611,
                                    0.4038583457585176,
                                    0.004419699707218268,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.596024468851107,
                                    0.006522705790636998,
                                    0.3931503110414131,
                                    0.004302514316842881,
                                ],
                                [
                                    0.5853164341340025,
                                    0.17559108646359065,
                                    0.18391822091883903,
                                    0.05517425848356779,
                                ],
                                [
                                    0.5936435685892508,
                                    0.17808917211582218,
                                    0.17559108646359065,
                                    0.05267617283133628,
                                ],
                                [
                                    0.7271349042481322,
                                    0.2181356961750672,
                                    0.04209975080470932,
                                    0.01262964877209125,
                                ],
                                [
                                    0.3755961132956238,
                                    0.009021214230797037,
                                    0.6009488481890422,
                                    0.014433824284536972,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.39850101297920204,
                                    0.009571353062552839,
                                    0.5780439485054639,
                                    0.01388368545278117,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.4680738860856248,
                                    0.4680738860856248,
                                    0.03192611391437524,
                                    0.03192611391437524,
                                ],
                                [
                                    0.17110718011831585,
                                    0.0064055204002616125,
                                    0.792807962958496,
                                    0.029679336522926522,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.2058899201423371,
                                    0.007707637299428574,
                                    0.7580252229344747,
                                    0.028377219623759563,
                                ],
                                [
                                    0.17110718011831585,
                                    0.5703697524665859,
                                    0.059658164828842654,
                                    0.19886490258625558,
                                ],
                                [
                                    0.17943431457356424,
                                    0.5981274749345258,
                                    0.05133103037359428,
                                    0.1711071801183158,
                                ],
                                [
                                    0.21392523095815744,
                                    0.7130997129611422,
                                    0.016840113989001062,
                                    0.05613494209169933,
                                ],
                                [
                                    0.03447152022940799,
                                    0.0016133366937802001,
                                    0.9208189580669471,
                                    0.04309618500986461,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.07718210060208414,
                                    0.003612278024748888,
                                    0.878108377694271,
                                    0.041097243678895924,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.04319457078601828,
                                    0.8776005657851552,
                                    0.003715506244649794,
                                    0.07548935718417667,
                                ],
                                [
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                    0.522303146741872,
                                    0.0011518917734620563,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.47769201081438073,
                                    0.001053505997308441,
                                    0.520107433858596,
                                    0.001147049329714766,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383556,
                                    0.4775936250382271,
                                    0.023506652625284463,
                                ],
                                [
                                    0.4775936250382271,
                                    0.023506652625284463,
                                    0.4754962979311048,
                                    0.023403424405383556,
                                ],
                                [
                                    0.9074301234882796,
                                    0.04466275003744165,
                                    0.045659799481052345,
                                    0.0022473269932263697,
                                ],
                                [
                                    0.3804537602987966,
                                    0.004163567227624184,
                                    0.6087210195937236,
                                    0.006661652879855695,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.39116179501590104,
                                    0.004280752617999571,
                                    0.598012984876619,
                                    0.006544467489480308,
                                ],
                                [
                                    0.3804537602987966,
                                    0.11413362964746347,
                                    0.3887808947540449,
                                    0.11663171529969497,
                                ],
                                [
                                    0.3887808947540449,
                                    0.11663171529969497,
                                    0.3804537602987966,
                                    0.11413362964746347,
                                ],
                                [
                                    0.7293768574207696,
                                    0.2188082674039382,
                                    0.03985779763207189,
                                    0.011957077543220247,
                                ],
                                [
                                    0.2441362403711665,
                                    0.005863759628833502,
                                    0.7324087211134995,
                                    0.017591278886500507,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.2670411400547447,
                                    0.006413898460589305,
                                    0.7095038214299212,
                                    0.017041140054744705,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.4712313406875883,
                                    0.4712313406875883,
                                    0.02876865931241171,
                                    0.02876865931241171,
                                ],
                                [
                                    0.11121910524595506,
                                    0.004163567227624185,
                                    0.8526960378308568,
                                    0.03192128969556395,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.14600184526997628,
                                    0.005465684126791146,
                                    0.8179132978068355,
                                    0.03061917279639699,
                                ],
                                [
                                    0.11121910524595506,
                                    0.37073846629245083,
                                    0.11954623970120344,
                                    0.39849618876039067,
                                ],
                                [
                                    0.11954623970120344,
                                    0.39849618876039067,
                                    0.11121910524595506,
                                    0.37073846629245083,
                                ],
                                [
                                    0.21616718413079486,
                                    0.7205730537948505,
                                    0.014598160816363634,
                                    0.04866160125799105,
                                ],
                                [
                                    0.022406374961772883,
                                    0.001048663553561152,
                                    0.9328841033345823,
                                    0.04366085815008366,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.06511695533444903,
                                    0.0030476048845298398,
                                    0.8901735229619061,
                                    0.04166191681911497,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.043759243926237326,
                                    0.8890732452983946,
                                    0.003150833104430746,
                                    0.06401667767093737,
                                ],
                                [
                                    0.21945613442633652,
                                    0.00048399041334210393,
                                    0.7783433102466403,
                                    0.001716564913681103,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.22165184730961246,
                                    0.0004888328570893943,
                                    0.7761475973633644,
                                    0.0017117224699338127,
                                ],
                                [
                                    0.21945613442633646,
                                    0.010801398611706167,
                                    0.7336337885429954,
                                    0.03610867841896185,
                                ],
                                [
                                    0.22155346153345878,
                                    0.010904626831607074,
                                    0.7315364614358731,
                                    0.03600545019906094,
                                ],
                                [
                                    0.9079947966284987,
                                    0.04469054265161839,
                                    0.0450951263408333,
                                    0.0022195343790496307,
                                ],
                                [
                                    0.17559108646359073,
                                    0.001921614054986759,
                                    0.8135836934289294,
                                    0.00890360605249312,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.18629912118069522,
                                    0.0020387994453621456,
                                    0.8028756587118249,
                                    0.008786420662117734,
                                ],
                                [
                                    0.17559108646359067,
                                    0.052676172831336285,
                                    0.5936435685892508,
                                    0.17808917211582218,
                                ],
                                [
                                    0.18391822091883905,
                                    0.055174258483567794,
                                    0.5853164341340025,
                                    0.17559108646359065,
                                ],
                                [
                                    0.731618810593407,
                                    0.2194808386328092,
                                    0.037615844459434465,
                                    0.011284506314349244,
                                ],
                                [
                                    0.11267636744670928,
                                    0.0027063050268699707,
                                    0.8638685940379567,
                                    0.02074873348846404,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.1355812671302875,
                                    0.003256443858625773,
                                    0.8409636943543785,
                                    0.020198594656708237,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.4743887952895518,
                                    0.4743887952895518,
                                    0.025611204710448178,
                                    0.025611204710448178,
                                ],
                                [
                                    0.05133103037359426,
                                    0.0019216140549867579,
                                    0.9125841127032176,
                                    0.034163242868201375,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.08611377039761549,
                                    0.0032237309541537184,
                                    0.8778013726791963,
                                    0.03286112596903442,
                                ],
                                [
                                    0.051331030373594294,
                                    0.17110718011831585,
                                    0.1794343145735642,
                                    0.5981274749345257,
                                ],
                                [
                                    0.05965816482884268,
                                    0.19886490258625567,
                                    0.17110718011831583,
                                    0.5703697524665858,
                                ],
                                [
                                    0.21840913730343228,
                                    0.7280463946285587,
                                    0.01235620764372621,
                                    0.04118826042428279,
                                ],
                                [
                                    0.010341229694137779,
                                    0.00048399041334210404,
                                    0.9449492486022174,
                                    0.044225531290302704,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.05305181006681393,
                                    0.0024829317443107917,
                                    0.9022386682295412,
                                    0.04222658995933402,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.04432391706645637,
                                    0.9005459248116339,
                                    0.002586159964211699,
                                    0.05254399815769808,
                                ],
                                [
                                    0.04461113592749122,
                                    9.838577615361534e-05,
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04680684881076717,
                                    0.00010322821990090561,
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                ],
                                [
                                    0.04461113592749121,
                                    0.002195712883275918,
                                    0.9084787870418407,
                                    0.0447143641473921,
                                ],
                                [
                                    0.04670846303461354,
                                    0.002298941103176825,
                                    0.9063814599347184,
                                    0.04461113592749119,
                                ],
                                [
                                    0.9083804012656871,
                                    0.04470952170364481,
                                    0.04470952170364481,
                                    0.002200555327023207,
                                ],
                                [
                                    0.03569423040444776,
                                    0.00039062651874043134,
                                    0.9534805494880724,
                                    0.010434593588739449,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.04640226512155225,
                                    0.000507811909115818,
                                    0.9427725147709679,
                                    0.010317408198364061,
                                ],
                                [
                                    0.03569423040444771,
                                    0.010708034717104496,
                                    0.7335404246483938,
                                    0.22005731023005395,
                                ],
                                [
                                    0.044021364859696085,
                                    0.013206120369336006,
                                    0.7252132901931454,
                                    0.21755922457782245,
                                ],
                                [
                                    0.7331497981296533,
                                    0.21994012483967856,
                                    0.036084856923188136,
                                    0.01082522010747988,
                                ],
                                [
                                    0.022904899683578235,
                                    0.0005501388317558024,
                                    0.9536400618010877,
                                    0.022904899683578207,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.04580979936715647,
                                    0.0011002776635116048,
                                    0.9307351621175095,
                                    0.022354760851822406,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.47654496148466596,
                                    0.47654496148466596,
                                    0.02345503851533401,
                                    0.02345503851533401,
                                ],
                                [
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                    0.9534805494880724,
                                    0.035694230404447705,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.04521733361276068,
                                    0.0016927434179073917,
                                    0.9186978094640511,
                                    0.03439211350528074,
                                ],
                                [
                                    0.010434593588739468,
                                    0.034782740024021236,
                                    0.22033075135841904,
                                    0.7344519150288202,
                                ],
                                [
                                    0.01876172804398785,
                                    0.06254046249196105,
                                    0.21200361690317066,
                                    0.7066941925608805,
                                ],
                                [
                                    0.21994012483967862,
                                    0.7331497981296533,
                                    0.010825220107479883,
                                    0.036084856923188136,
                                ],
                                [
                                    0.0021021695508696182,
                                    9.838577615361652e-05,
                                    0.9531883087454855,
                                    0.04461113592749119,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.04470952170364486,
                                    0.9083804012656871,
                                    0.0022005553270232096,
                                    0.04470952170364481,
                                ],
                                [
                                    0.8985469834806652,
                                    0.009833417785021958,
                                    0.09062779641185491,
                                    0.0009918023224579212,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9007237173119147,
                                    0.00985723928079567,
                                    0.08845106258060541,
                                    0.0009679808266842078,
                                ],
                                [
                                    0.9063814599347184,
                                    0.04461113592749119,
                                    0.04670846303461349,
                                    0.002298941103176822,
                                ],
                                [
                                    0.9084787870418407,
                                    0.0447143641473921,
                                    0.04461113592749119,
                                    0.002195712883275917,
                                ],
                                [
                                    0.9068654503480605,
                                    0.04463495742326491,
                                    0.04622447262127139,
                                    0.002275119607403109,
                                ],
                                [
                                    0.6941076326169691,
                                    0.03904216551268439,
                                    0.25263972295445,
                                    0.014210478915896635,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7043563811272041,
                                    0.03961863710992915,
                                    0.2423909744442148,
                                    0.013634007318651883,
                                ],
                                [
                                    0.7252132901931454,
                                    0.21755922457782245,
                                    0.04402136485969607,
                                    0.013206120369336003,
                                ],
                                [
                                    0.7335404246483938,
                                    0.22005731023005395,
                                    0.035694230404447705,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7271349042481322,
                                    0.2181356961750672,
                                    0.04209975080470932,
                                    0.01262964877209125,
                                ],
                                [
                                    0.4215599302747463,
                                    0.05498503120991964,
                                    0.46305739725167444,
                                    0.06039764126365958,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632103,
                                    0.057691336236789605,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.4680738860856248,
                                    0.4680738860856248,
                                    0.03192611391437524,
                                    0.03192611391437524,
                                ],
                                [
                                    0.18089795932699423,
                                    0.0390421655126844,
                                    0.6415893401544284,
                                    0.13847053500589301,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.2105772958499208,
                                    0.04544768591294602,
                                    0.6119100036315018,
                                    0.1320650146056314,
                                ],
                                [
                                    0.21200361690317068,
                                    0.7066941925608805,
                                    0.01876172804398782,
                                    0.06254046249196094,
                                ],
                                [
                                    0.22033075135841906,
                                    0.7344519150288203,
                                    0.01043459358873945,
                                    0.03478274002402117,
                                ],
                                [
                                    0.21392523095815744,
                                    0.7130997129611422,
                                    0.016840113989001062,
                                    0.05613494209169933,
                                ],
                                [
                                    0.03487610391862287,
                                    0.009833417785021965,
                                    0.7451837712416985,
                                    0.2101067070546566,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.06975220783724574,
                                    0.01966683557004393,
                                    0.7103076673230756,
                                    0.20027328926963464,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991898,
                                    0.08532277496919863,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.04319457078601828,
                                    0.8776005657851552,
                                    0.003715506244649794,
                                    0.07548935718417667,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.727390024024395,
                                    0.007960329432281652,
                                    0.2617847558681251,
                                    0.002864890675198227,
                                ],
                                [
                                    0.7315364614358731,
                                    0.03600545019906094,
                                    0.22155346153345876,
                                    0.010904626831607072,
                                ],
                                [
                                    0.7336337885429954,
                                    0.03610867841896185,
                                    0.21945613442633644,
                                    0.010801398611706165,
                                ],
                                [
                                    0.907251054985249,
                                    0.04465393647529133,
                                    0.045838867984082904,
                                    0.0022561405553766854,
                                ],
                                [
                                    0.560211195688866,
                                    0.031510758845398154,
                                    0.386536159882553,
                                    0.02174188558318287,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.5704599441991011,
                                    0.03208723044264291,
                                    0.37628741137231786,
                                    0.02116541398593812,
                                ],
                                [
                                    0.5853164341340025,
                                    0.17559108646359065,
                                    0.18391822091883903,
                                    0.05517425848356779,
                                ],
                                [
                                    0.5936435685892508,
                                    0.17808917211582218,
                                    0.17559108646359065,
                                    0.05267617283133628,
                                ],
                                [
                                    0.7286658917843785,
                                    0.21859498238193656,
                                    0.04056876326846299,
                                    0.012170362565221885,
                                ],
                                [
                                    0.3402391523967765,
                                    0.044378175129644364,
                                    0.5443781751296443,
                                    0.07100449734393485,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.36098788588524056,
                                    0.047084480156514334,
                                    0.5236294416411802,
                                    0.06829819231706488,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.47023005228073894,
                                    0.47023005228073894,
                                    0.029769947719261072,
                                    0.029769947719261072,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.1756812781961059,
                                    0.03791627924565978,
                                    0.6468060212853167,
                                    0.1395964212729176,
                                ],
                                [
                                    0.17110718011831585,
                                    0.5703697524665859,
                                    0.059658164828842654,
                                    0.19886490258625558,
                                ],
                                [
                                    0.17943431457356424,
                                    0.5981274749345258,
                                    0.05133103037359428,
                                    0.1711071801183158,
                                ],
                                [
                                    0.21545621849440375,
                                    0.7182031164622368,
                                    0.015309126452754736,
                                    0.051031538590604685,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.0630244529053031,
                                    0.017769925721529915,
                                    0.7170354222550183,
                                    0.20217019911814865,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.043580175423206774,
                                    0.8854350422392085,
                                    0.003329901607461305,
                                    0.0676548807301234,
                                ],
                                [
                                    0.47138625738548395,
                                    0.005158704099182031,
                                    0.5177885225070362,
                                    0.005666516008297848,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.47356299121673345,
                                    0.005182525594955745,
                                    0.5156117886757867,
                                    0.005642694512524134,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383556,
                                    0.4775936250382271,
                                    0.023506652625284463,
                                ],
                                [
                                    0.4775936250382271,
                                    0.023506652625284463,
                                    0.4754962979311048,
                                    0.023403424405383556,
                                ],
                                [
                                    0.9078157281254681,
                                    0.04468172908946807,
                                    0.04527419484386386,
                                    0.0022283479411999464,
                                ],
                                [
                                    0.36413543774258517,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.03277075464474545,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.37438418625282033,
                                    0.021058361381080325,
                                    0.5723631693185987,
                                    0.0321942830475007,
                                ],
                                [
                                    0.3804537602987966,
                                    0.11413362964746347,
                                    0.3887808947540449,
                                    0.11663171529969497,
                                ],
                                [
                                    0.3887808947540449,
                                    0.11663171529969497,
                                    0.3804537602987966,
                                    0.11413362964746347,
                                ],
                                [
                                    0.7309078449570159,
                                    0.21926755361080755,
                                    0.03832681009582556,
                                    0.011497791336350881,
                                ],
                                [
                                    0.2211543318816052,
                                    0.028845668118394806,
                                    0.6634629956448156,
                                    0.08653700435518441,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.24190306537006925,
                                    0.031551973145264776,
                                    0.6427142621563515,
                                    0.08383069932831444,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.4733875068827025,
                                    0.4733875068827025,
                                    0.02661249311729754,
                                    0.02661249311729754,
                                ],
                                [
                                    0.09490078268974368,
                                    0.020481889783835576,
                                    0.727586516791679,
                                    0.15703081073474182,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.12458011921267025,
                                    0.026887410184097196,
                                    0.6979071802687524,
                                    0.1506252903344802,
                                ],
                                [
                                    0.11121910524595506,
                                    0.37073846629245083,
                                    0.11954623970120344,
                                    0.39849618876039067,
                                ],
                                [
                                    0.11954623970120344,
                                    0.39849618876039067,
                                    0.11121910524595506,
                                    0.37073846629245083,
                                ],
                                [
                                    0.2176981716670412,
                                    0.7256764572959451,
                                    0.01306717328011731,
                                    0.04355819775689641,
                                ],
                                [
                                    0.018296334416152,
                                    0.005158704099182037,
                                    0.7617635407441694,
                                    0.21478142074049653,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.05317243833477487,
                                    0.014992121884204,
                                    0.7268874368255465,
                                    0.20494800295547455,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.04414484856342581,
                                    0.8969077217524478,
                                    0.0027652284672422573,
                                    0.0561822012168841,
                                ],
                                [
                                    0.2175592245778225,
                                    0.0023809002618561236,
                                    0.7716155553146976,
                                    0.008444319845623756,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.219735958409072,
                                    0.0024047217576298376,
                                    0.7694388214834481,
                                    0.008420498349850042,
                                ],
                                [
                                    0.21945613442633646,
                                    0.010801398611706167,
                                    0.7336337885429954,
                                    0.03610867841896185,
                                ],
                                [
                                    0.22155346153345878,
                                    0.010904626831607074,
                                    0.7315364614358731,
                                    0.03600545019906094,
                                ],
                                [
                                    0.9083804012656871,
                                    0.04470952170364481,
                                    0.04470952170364481,
                                    0.002200555327023207,
                                ],
                                [
                                    0.16805967979630448,
                                    0.009453020722272998,
                                    0.7786876757751144,
                                    0.04379962370630803,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.17830842830653962,
                                    0.01002949231951775,
                                    0.7684389272648794,
                                    0.04322315210906328,
                                ],
                                [
                                    0.17559108646359067,
                                    0.052676172831336285,
                                    0.5936435685892508,
                                    0.17808917211582218,
                                ],
                                [
                                    0.18391822091883905,
                                    0.055174258483567794,
                                    0.5853164341340025,
                                    0.17559108646359065,
                                ],
                                [
                                    0.7331497981296533,
                                    0.21994012483967856,
                                    0.036084856923188136,
                                    0.01082522010747988,
                                ],
                                [
                                    0.10206951136643398,
                                    0.01331316110714526,
                                    0.7825478161599868,
                                    0.10206951136643397,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.12281824485489805,
                                    0.016019466134015233,
                                    0.7617990826715227,
                                    0.09936320633956398,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.47654496148466596,
                                    0.47654496148466596,
                                    0.02345503851533401,
                                    0.02345503851533401,
                                ],
                                [
                                    0.04379962370630803,
                                    0.009453020722272993,
                                    0.7786876757751146,
                                    0.1680596797963044,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.0734789602292346,
                                    0.01585854112253461,
                                    0.749008339252188,
                                    0.16165415939604277,
                                ],
                                [
                                    0.051331030373594294,
                                    0.17110718011831585,
                                    0.1794343145735642,
                                    0.5981274749345257,
                                ],
                                [
                                    0.05965816482884268,
                                    0.19886490258625567,
                                    0.17110718011831583,
                                    0.5703697524665858,
                                ],
                                [
                                    0.21994012483967862,
                                    0.7331497981296533,
                                    0.010825220107479883,
                                    0.036084856923188136,
                                ],
                                [
                                    0.008444319845623757,
                                    0.002380900261856124,
                                    0.7716155553146976,
                                    0.21755922457782245,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.04332042376424663,
                                    0.012214318046878088,
                                    0.7367394513960748,
                                    0.20772580679280048,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.04470952170364486,
                                    0.9083804012656871,
                                    0.0022005553270232096,
                                    0.04470952170364481,
                                ],
                                [
                                    0.04422553129030273,
                                    0.00048399041334210415,
                                    0.9449492486022174,
                                    0.010341229694137775,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04640226512155225,
                                    0.000507811909115818,
                                    0.9427725147709679,
                                    0.010317408198364061,
                                ],
                                [
                                    0.04461113592749121,
                                    0.002195712883275918,
                                    0.9084787870418407,
                                    0.0447143641473921,
                                ],
                                [
                                    0.04670846303461354,
                                    0.002298941103176825,
                                    0.9063814599347184,
                                    0.04461113592749119,
                                ],
                                [
                                    0.9087660059028756,
                                    0.04472850075567123,
                                    0.04432391706645632,
                                    0.0021815762749967838,
                                ],
                                [
                                    0.03416324286820143,
                                    0.0019216140549867611,
                                    0.9125841127032176,
                                    0.051331030373594266,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.04441199137843656,
                                    0.002498085652231513,
                                    0.9023353641929824,
                                    0.05075455877634951,
                                ],
                                [
                                    0.03569423040444771,
                                    0.010708034717104496,
                                    0.7335404246483938,
                                    0.22005731023005395,
                                ],
                                [
                                    0.044021364859696085,
                                    0.013206120369336006,
                                    0.7252132901931454,
                                    0.21755922457782245,
                                ],
                                [
                                    0.7346807856658997,
                                    0.22039941104654795,
                                    0.034553869386941806,
                                    0.010365933900610514,
                                ],
                                [
                                    0.020748733488464063,
                                    0.0027063050268699733,
                                    0.8638685940379567,
                                    0.11267636744670925,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.041497466976928125,
                                    0.0054126100537399465,
                                    0.8431198605494926,
                                    0.10997006241983928,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.4787011276797802,
                                    0.4787011276797802,
                                    0.02129887232021984,
                                    0.02129887232021984,
                                ],
                                [
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                    0.8135836934289296,
                                    0.17559108646359065,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.0385829425754197,
                                    0.008327134455248379,
                                    0.7839043569060029,
                                    0.16918556606332902,
                                ],
                                [
                                    0.010434593588739468,
                                    0.034782740024021236,
                                    0.22033075135841904,
                                    0.7344519150288202,
                                ],
                                [
                                    0.01876172804398785,
                                    0.06254046249196105,
                                    0.21200361690317066,
                                    0.7066941925608805,
                                ],
                                [
                                    0.22147111237592493,
                                    0.7382532016307479,
                                    0.009294232571233553,
                                    0.030981453422093484,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.00048399041334210995,
                                    0.7783433102466403,
                                    0.21945613442633646,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.045095126340833354,
                                    0.9162148777197404,
                                    0.0018149506898347207,
                                    0.03687504524959154,
                                ],
                                [
                                    0.8870743039674259,
                                    0.021306097298261256,
                                    0.08947065751724008,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.8892232451844986,
                                    0.021357711408211705,
                                    0.08732171630016732,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9063814599347184,
                                    0.04461113592749119,
                                    0.04670846303461349,
                                    0.002298941103176822,
                                ],
                                [
                                    0.9084787870418407,
                                    0.0447143641473921,
                                    0.04461113592749119,
                                    0.002195712883275917,
                                ],
                                [
                                    0.9074301234882796,
                                    0.04466275003744165,
                                    0.045659799481052345,
                                    0.0022473269932263697,
                                ],
                                [
                                    0.6485570150979889,
                                    0.08459278303166452,
                                    0.23606031242843187,
                                    0.030789889441914697,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.658133192379353,
                                    0.08584182585778029,
                                    0.22648413514706775,
                                    0.029540846615798942,
                                ],
                                [
                                    0.7252132901931454,
                                    0.21755922457782245,
                                    0.04402136485969607,
                                    0.013206120369336003,
                                ],
                                [
                                    0.7335404246483938,
                                    0.22005731023005395,
                                    0.035694230404447705,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7293768574207696,
                                    0.2188082674039382,
                                    0.03985779763207189,
                                    0.011957077543220247,
                                ],
                                [
                                    0.3574087211134995,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.1308637596288335,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [0.375, 0.125, 0.37499999999999994, 0.12499999999999999],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.4712313406875883,
                                    0.4712313406875883,
                                    0.02876865931241171,
                                    0.02876865931241171,
                                ],
                                [
                                    0.13534734180801408,
                                    0.08459278303166454,
                                    0.4800353306655652,
                                    0.3000245444947562,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.15755333749723235,
                                    0.09847164426563444,
                                    0.45782933497634687,
                                    0.2861456832607863,
                                ],
                                [
                                    0.21200361690317068,
                                    0.7066941925608805,
                                    0.01876172804398782,
                                    0.06254046249196094,
                                ],
                                [
                                    0.22033075135841906,
                                    0.7344519150288203,
                                    0.01043459358873945,
                                    0.03478274002402117,
                                ],
                                [
                                    0.21616718413079486,
                                    0.7205730537948505,
                                    0.014598160816363637,
                                    0.048661601257991065,
                                ],
                                [
                                    0.023403424405383573,
                                    0.021306097298261266,
                                    0.5000516141099505,
                                    0.4552388641864047,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.046806848810767146,
                                    0.04261219459652253,
                                    0.4766481897045669,
                                    0.4339327668881434,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991898,
                                    0.08532277496919863,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.043759243926237326,
                                    0.8890732452983946,
                                    0.003150833104430746,
                                    0.06401667767093737,
                                ],
                                [
                                    0.7159537413770131,
                                    0.017196056752640375,
                                    0.26059122010765295,
                                    0.006258981762693634,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7181026825940858,
                                    0.01724767086259083,
                                    0.25844227889058013,
                                    0.006207367652743181,
                                ],
                                [
                                    0.7315364614358731,
                                    0.03600545019906094,
                                    0.22155346153345876,
                                    0.010904626831607072,
                                ],
                                [
                                    0.7336337885429954,
                                    0.03610867841896185,
                                    0.21945613442633644,
                                    0.010801398611706165,
                                ],
                                [
                                    0.9078157281254681,
                                    0.04468172908946807,
                                    0.04527419484386386,
                                    0.0022283479411999464,
                                ],
                                [
                                    0.523447494058811,
                                    0.06827446047545313,
                                    0.3611698334676098,
                                    0.047108211998126086,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.5330236713401751,
                                    0.0695235033015689,
                                    0.35159365618624566,
                                    0.045859169172010335,
                                ],
                                [
                                    0.5853164341340025,
                                    0.17559108646359065,
                                    0.18391822091883903,
                                    0.05517425848356779,
                                ],
                                [
                                    0.5936435685892508,
                                    0.17808917211582218,
                                    0.17559108646359065,
                                    0.05267617283133628,
                                ],
                                [
                                    0.7309078449570159,
                                    0.21926755361080755,
                                    0.038326810095825566,
                                    0.011497791336350883,
                                ],
                                [
                                    0.28846299564481565,
                                    0.09615433188160522,
                                    0.46153700435518435,
                                    0.15384566811839478,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.3060542745313162,
                                    0.10201809151043872,
                                    0.4439457254686838,
                                    0.14798190848956128,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.4733875068827025,
                                    0.4733875068827025,
                                    0.02661249311729754,
                                    0.02661249311729754,
                                ],
                                [
                                    0.10923824004312432,
                                    0.06827446047545316,
                                    0.5061444324304549,
                                    0.3163428670509676,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.13144423573234262,
                                    0.08215332170942306,
                                    0.48393843674123665,
                                    0.30246400581699767,
                                ],
                                [
                                    0.17110718011831585,
                                    0.5703697524665859,
                                    0.059658164828842654,
                                    0.19886490258625558,
                                ],
                                [
                                    0.17943431457356424,
                                    0.5981274749345258,
                                    0.05133103037359428,
                                    0.1711071801183158,
                                ],
                                [
                                    0.2176981716670412,
                                    0.7256764572959451,
                                    0.01306717328011731,
                                    0.04355819775689641,
                                ],
                                [
                                    0.018888800170547792,
                                    0.0171960567526404,
                                    0.5045662383447862,
                                    0.45934890473202555,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.04229222457593136,
                                    0.03850215405090167,
                                    0.4811628139394027,
                                    0.4380428074337643,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.04414484856342581,
                                    0.8969077217524478,
                                    0.0027652284672422573,
                                    0.0561822012168841,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.4675165222758275,
                                    0.011228994535861656,
                                    0.5090284392088384,
                                    0.012226043979472353,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383556,
                                    0.4775936250382271,
                                    0.023506652625284463,
                                ],
                                [
                                    0.4775936250382271,
                                    0.023506652625284463,
                                    0.4754962979311048,
                                    0.023403424405383556,
                                ],
                                [
                                    0.9083804012656871,
                                    0.04470952170364481,
                                    0.04470952170364481,
                                    0.002200555327023207,
                                ],
                                [
                                    0.3402391523967764,
                                    0.04437817512964435,
                                    0.5443781751296444,
                                    0.07100449734393487,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3498153296781405,
                                    0.04562721795576011,
                                    0.5348019978482802,
                                    0.06975545451781912,
                                ],
                                [
                                    0.3804537602987966,
                                    0.11413362964746347,
                                    0.3887808947540449,
                                    0.11663171529969497,
                                ],
                                [
                                    0.3887808947540449,
                                    0.11663171529969497,
                                    0.3804537602987966,
                                    0.11413362964746347,
                                ],
                                [
                                    0.7331497981296533,
                                    0.21994012483967856,
                                    0.036084856923188136,
                                    0.01082522010747988,
                                ],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.20509127888650053,
                                    0.06836375962883351,
                                    0.5449087211134995,
                                    0.1816362403711665,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.47654496148466596,
                                    0.47654496148466596,
                                    0.02345503851533401,
                                    0.02345503851533401,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.09321049303315318,
                                    0.05825703636361427,
                                    0.522172179440426,
                                    0.32636029116280646,
                                ],
                                [
                                    0.11121910524595506,
                                    0.37073846629245083,
                                    0.11954623970120344,
                                    0.39849618876039067,
                                ],
                                [
                                    0.11954623970120344,
                                    0.39849618876039067,
                                    0.11121910524595506,
                                    0.37073846629245083,
                                ],
                                [
                                    0.21994012483967862,
                                    0.7331497981296533,
                                    0.010825220107479883,
                                    0.036084856923188136,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.03568108249480639,
                                    0.03248347772417248,
                                    0.48777395602052764,
                                    0.4440614837604935,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.04470952170364486,
                                    0.9083804012656871,
                                    0.0022005553270232096,
                                    0.04470952170364481,
                                ],
                                [
                                    0.21478142074049658,
                                    0.0051587040991820324,
                                    0.7617635407441694,
                                    0.01829633441615198,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.21693036195756937,
                                    0.005210318209132486,
                                    0.7596145995270966,
                                    0.018244720306201525,
                                ],
                                [
                                    0.21945613442633646,
                                    0.010801398611706167,
                                    0.7336337885429954,
                                    0.03610867841896185,
                                ],
                                [
                                    0.22155346153345878,
                                    0.010904626831607074,
                                    0.7315364614358731,
                                    0.03600545019906094,
                                ],
                                [
                                    0.9089450744059062,
                                    0.044737314317821554,
                                    0.04414484856342576,
                                    0.002172762712846468,
                                ],
                                [
                                    0.1570308107347419,
                                    0.020481889783835583,
                                    0.7275865167916789,
                                    0.09490078268974364,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.16660698801610602,
                                    0.021730932609951337,
                                    0.7180103395103147,
                                    0.09365173986362789,
                                ],
                                [
                                    0.17559108646359067,
                                    0.052676172831336285,
                                    0.5936435685892508,
                                    0.17808917211582218,
                                ],
                                [
                                    0.18391822091883905,
                                    0.055174258483567794,
                                    0.5853164341340025,
                                    0.17559108646359065,
                                ],
                                [
                                    0.7353917513022908,
                                    0.22061269606854958,
                                    0.03384290375055071,
                                    0.010152648878608877,
                                ],
                                [
                                    0.08653700435518444,
                                    0.028845668118394813,
                                    0.6634629956448156,
                                    0.2211543318816052,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.10412828324168497,
                                    0.03470942774722832,
                                    0.645871716758315,
                                    0.21529057225277168,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.4797024160866295,
                                    0.4797024160866295,
                                    0.020297583913370477,
                                    0.020297583913370477,
                                ],
                                [
                                    0.03277075464474545,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.36413543774258517,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.054976750333963736,
                                    0.034360751017805474,
                                    0.5604059221396155,
                                    0.35025657650861525,
                                ],
                                [
                                    0.051331030373594294,
                                    0.17110718011831585,
                                    0.1794343145735642,
                                    0.5981274749345257,
                                ],
                                [
                                    0.05965816482884268,
                                    0.19886490258625567,
                                    0.17110718011831583,
                                    0.5703697524665858,
                                ],
                                [
                                    0.22218207801231604,
                                    0.7406231389633616,
                                    0.008583266934842454,
                                    0.02861151608947986,
                                ],
                                [
                                    0.00566651600829785,
                                    0.0051587040991820324,
                                    0.5177885225070362,
                                    0.47138625738548395,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.02906994041368142,
                                    0.0264648013974433,
                                    0.4943850981016526,
                                    0.4500801600872227,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.04527419484386391,
                                    0.9198530807789265,
                                    0.0016358821868041622,
                                    0.03323684219040551,
                                ],
                                [
                                    0.043660858150083685,
                                    0.0010486635535611516,
                                    0.9328841033345823,
                                    0.02240637496177286,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04580979936715647,
                                    0.0011002776635116048,
                                    0.9307351621175095,
                                    0.022354760851822406,
                                ],
                                [
                                    0.04461113592749121,
                                    0.002195712883275918,
                                    0.9084787870418407,
                                    0.0447143641473921,
                                ],
                                [
                                    0.04670846303461354,
                                    0.002298941103176825,
                                    0.9063814599347184,
                                    0.04461113592749119,
                                ],
                                [
                                    0.9093306790430947,
                                    0.044756293369847974,
                                    0.04375924392623728,
                                    0.0021537836608200448,
                                ],
                                [
                                    0.031921289695564,
                                    0.004163567227624191,
                                    0.8526960378308568,
                                    0.11121910524595503,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.041497466976928125,
                                    0.0054126100537399465,
                                    0.8431198605494926,
                                    0.10997006241983928,
                                ],
                                [
                                    0.03569423040444771,
                                    0.010708034717104496,
                                    0.7335404246483938,
                                    0.22005731023005395,
                                ],
                                [
                                    0.044021364859696085,
                                    0.013206120369336006,
                                    0.7252132901931454,
                                    0.21755922457782245,
                                ],
                                [
                                    0.7369227388385371,
                                    0.22107198227541894,
                                    0.03231191621430438,
                                    0.009693362671739512,
                                ],
                                [
                                    0.017591278886500528,
                                    0.005863759628833509,
                                    0.7324087211134995,
                                    0.2441362403711665,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.035182557773001055,
                                    0.011727519257667018,
                                    0.714817442226999,
                                    0.23827248074233298,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.4818585822817437,
                                    0.4818585822817437,
                                    0.01814141771825631,
                                    0.01814141771825631,
                                ],
                                [
                                    0.006661652879855697,
                                    0.004163567227624186,
                                    0.6087210195937236,
                                    0.3804537602987966,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.028867648569073985,
                                    0.01804242846159409,
                                    0.5865150239045053,
                                    0.36657489906482665,
                                ],
                                [
                                    0.010434593588739468,
                                    0.034782740024021236,
                                    0.22033075135841904,
                                    0.7344519150288202,
                                ],
                                [
                                    0.01876172804398785,
                                    0.06254046249196105,
                                    0.21200361690317066,
                                    0.7066941925608805,
                                ],
                                [
                                    0.22371306554856238,
                                    0.7457265424644562,
                                    0.007052279398596128,
                                    0.023508112588385213,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.001048663553561164,
                                    0.522303146741872,
                                    0.4754962979311048,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.0456597994810524,
                                    0.9276875572329797,
                                    0.0012502775496156732,
                                    0.025402365736352243,
                                ],
                                [
                                    0.8756016244541865,
                                    0.03277877681150055,
                                    0.08831351862262524,
                                    0.0033060801116875874,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.8777227730570826,
                                    0.032858183535627736,
                                    0.08619237001972922,
                                    0.0032266733875603954,
                                ],
                                [
                                    0.9063814599347184,
                                    0.04461113592749119,
                                    0.04670846303461349,
                                    0.002298941103176822,
                                ],
                                [
                                    0.9084787870418407,
                                    0.0447143641473921,
                                    0.04461113592749119,
                                    0.002195712883275917,
                                ],
                                [
                                    0.9079947966284987,
                                    0.04469054265161839,
                                    0.0450951263408333,
                                    0.0022195343790496307,
                                ],
                                [
                                    0.6030063975790088,
                                    0.13014340055064463,
                                    0.21948090190241384,
                                    0.04736929996793276,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6119100036315019,
                                    0.13206501460563141,
                                    0.21057729584992071,
                                    0.045447685912946,
                                ],
                                [
                                    0.7252132901931454,
                                    0.21755922457782245,
                                    0.04402136485969607,
                                    0.013206120369336003,
                                ],
                                [
                                    0.7335404246483938,
                                    0.22005731023005395,
                                    0.035694230404447705,
                                    0.010708034717104494,
                                ],
                                [
                                    0.731618810593407,
                                    0.2194808386328092,
                                    0.037615844459434465,
                                    0.011284506314349244,
                                ],
                                [
                                    0.29325751195225264,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.20132987799400742,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.30769133623678957,
                                    0.19230866376321035,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.4743887952895518,
                                    0.4743887952895518,
                                    0.025611204710448178,
                                    0.025611204710448178,
                                ],
                                [
                                    0.08979672428903396,
                                    0.13014340055064466,
                                    0.318481321176702,
                                    0.46157855398361936,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.10452937914454397,
                                    0.15149560261832284,
                                    0.303748666321192,
                                    0.44022635191594117,
                                ],
                                [
                                    0.21200361690317068,
                                    0.7066941925608805,
                                    0.01876172804398782,
                                    0.06254046249196094,
                                ],
                                [
                                    0.22033075135841906,
                                    0.7344519150288203,
                                    0.01043459358873945,
                                    0.03478274002402117,
                                ],
                                [
                                    0.21840913730343228,
                                    0.7280463946285587,
                                    0.01235620764372621,
                                    0.04118826042428279,
                                ],
                                [
                                    0.011930744892144272,
                                    0.032778776811500564,
                                    0.2549194569782024,
                                    0.7003710213181528,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.023861489784288543,
                                    0.06555755362300113,
                                    0.24298871208605816,
                                    0.6675922445066522,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991898,
                                    0.08532277496919863,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.04432391706645637,
                                    0.9005459248116339,
                                    0.002586159964211699,
                                    0.05254399815769808,
                                ],
                                [
                                    0.7066941925608806,
                                    0.026455605568772807,
                                    0.25722095051593125,
                                    0.009629251354415327,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7088153411637766,
                                    0.0265350122929,
                                    0.2550998019130352,
                                    0.009549844630288134,
                                ],
                                [
                                    0.7315364614358731,
                                    0.03600545019906094,
                                    0.22155346153345876,
                                    0.010904626831607072,
                                ],
                                [
                                    0.7336337885429954,
                                    0.03610867841896185,
                                    0.21945613442633644,
                                    0.010801398611706165,
                                ],
                                [
                                    0.9083804012656871,
                                    0.04470952170364481,
                                    0.04470952170364481,
                                    0.002200555327023207,
                                ],
                                [
                                    0.48668379242875603,
                                    0.1050381621055081,
                                    0.3358035070526666,
                                    0.07247453841306929,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.49558739848124916,
                                    0.10695977616049486,
                                    0.32689990100017347,
                                    0.07055292435808254,
                                ],
                                [
                                    0.5853164341340025,
                                    0.17559108646359065,
                                    0.18391822091883903,
                                    0.05517425848356779,
                                ],
                                [
                                    0.5936435685892508,
                                    0.17808917211582218,
                                    0.17559108646359065,
                                    0.05267617283133628,
                                ],
                                [
                                    0.7331497981296533,
                                    0.21994012483967856,
                                    0.036084856923188136,
                                    0.01082522010747988,
                                ],
                                [
                                    0.2366868388928548,
                                    0.14793048863356606,
                                    0.37869583358072445,
                                    0.2366868388928547,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.2511206631773918,
                                    0.1569517028643631,
                                    0.36426200929618746,
                                    0.22766562466205764,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.47654496148466596,
                                    0.47654496148466596,
                                    0.02345503851533401,
                                    0.02345503851533401,
                                ],
                                [
                                    0.07247453841306935,
                                    0.10503816210550813,
                                    0.33580350705266665,
                                    0.48668379242875587,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.08720719326857936,
                                    0.1263903641731863,
                                    0.32107085219715664,
                                    0.4653315903610777,
                                ],
                                [
                                    0.17110718011831585,
                                    0.5703697524665859,
                                    0.059658164828842654,
                                    0.19886490258625558,
                                ],
                                [
                                    0.17943431457356424,
                                    0.5981274749345258,
                                    0.05133103037359428,
                                    0.1711071801183158,
                                ],
                                [
                                    0.21994012483967862,
                                    0.7331497981296533,
                                    0.010825220107479883,
                                    0.036084856923188136,
                                ],
                                [
                                    0.009629251354415346,
                                    0.026455605568772845,
                                    0.25722095051593136,
                                    0.7066941925608805,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.021559996246559618,
                                    0.05923438238027341,
                                    0.24529020562378706,
                                    0.6739154157493799,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.04470952170364486,
                                    0.9083804012656871,
                                    0.0022005553270232096,
                                    0.04470952170364481,
                                ],
                                [
                                    0.45934890473202555,
                                    0.01719605675264037,
                                    0.5045662383447862,
                                    0.018888800170547764,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.4614700533349216,
                                    0.017275463476767564,
                                    0.5024450897418902,
                                    0.01880939344642057,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383556,
                                    0.4775936250382271,
                                    0.023506652625284463,
                                ],
                                [
                                    0.4775936250382271,
                                    0.023506652625284463,
                                    0.4754962979311048,
                                    0.023403424405383556,
                                ],
                                [
                                    0.9089450744059062,
                                    0.044737314317821554,
                                    0.04414484856342576,
                                    0.002172762712846468,
                                ],
                                [
                                    0.31634286705096765,
                                    0.06827446047545312,
                                    0.506144432430455,
                                    0.10923824004312428,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3252464731034608,
                                    0.07019607453043988,
                                    0.49724082637796185,
                                    0.10731662598813752,
                                ],
                                [
                                    0.3804537602987966,
                                    0.11413362964746347,
                                    0.3887808947540449,
                                    0.11663171529969497,
                                ],
                                [
                                    0.3887808947540449,
                                    0.11663171529969497,
                                    0.3804537602987966,
                                    0.11413362964746347,
                                ],
                                [
                                    0.7353917513022908,
                                    0.22061269606854958,
                                    0.03384290375055071,
                                    0.010152648878608877,
                                ],
                                [
                                    0.1538456681183948,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.2884629956448156,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1682794924029318,
                                    0.10517554611240224,
                                    0.4471031800706474,
                                    0.27944178141401854,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.4797024160866295,
                                    0.4797024160866295,
                                    0.020297583913370477,
                                    0.020297583913370477,
                                ],
                                [
                                    0.047108211998126114,
                                    0.06827446047545314,
                                    0.3611698334676099,
                                    0.5234474940588109,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.06184086685363612,
                                    0.08962666254313133,
                                    0.3464371786120999,
                                    0.5020952919911327,
                                ],
                                [
                                    0.11121910524595506,
                                    0.37073846629245083,
                                    0.11954623970120344,
                                    0.39849618876039067,
                                ],
                                [
                                    0.11954623970120344,
                                    0.39849618876039067,
                                    0.11121910524595506,
                                    0.37073846629245083,
                                ],
                                [
                                    0.22218207801231604,
                                    0.7406231389633616,
                                    0.008583266934842454,
                                    0.02861151608947986,
                                ],
                                [
                                    0.006258981762693645,
                                    0.017196056752640392,
                                    0.26059122010765307,
                                    0.715953741377013,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.018189726654837916,
                                    0.04997483356414096,
                                    0.24866047521550877,
                                    0.6831749645655123,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.04527419484386391,
                                    0.9198530807789265,
                                    0.0016358821868041622,
                                    0.03323684219040551,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.2141247655060667,
                                    0.008015914660635132,
                                    0.7497903775707451,
                                    0.028068942262553003,
                                ],
                                [
                                    0.21945613442633646,
                                    0.010801398611706167,
                                    0.7336337885429954,
                                    0.03610867841896185,
                                ],
                                [
                                    0.22155346153345878,
                                    0.010904626831607074,
                                    0.7315364614358731,
                                    0.03600545019906094,
                                ],
                                [
                                    0.9095097475461252,
                                    0.04476510693199829,
                                    0.04358017542320672,
                                    0.002144970098669729,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.15490554772567244,
                                    0.03343237290038492,
                                    0.6675817517557502,
                                    0.14408032761819248,
                                ],
                                [
                                    0.17559108646359067,
                                    0.052676172831336285,
                                    0.5936435685892508,
                                    0.17808917211582218,
                                ],
                                [
                                    0.18391822091883905,
                                    0.055174258483567794,
                                    0.5853164341340025,
                                    0.17559108646359065,
                                ],
                                [
                                    0.7376337044749283,
                                    0.22128526729742057,
                                    0.03160095057791328,
                                    0.009480077649737873,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.08543832162847188,
                                    0.053399389360441404,
                                    0.5299443508451074,
                                    0.33121793816597933,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.48285987068859304,
                                    0.48285987068859304,
                                    0.017140129311406946,
                                    0.017140129311406946,
                                ],
                                [
                                    0.021741885583182873,
                                    0.03151075884539815,
                                    0.38653615988255313,
                                    0.5602111956888659,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.03647454043869288,
                                    0.05286296091307633,
                                    0.3718035050270431,
                                    0.5388589936211877,
                                ],
                                [
                                    0.051331030373594294,
                                    0.17110718011831585,
                                    0.1794343145735642,
                                    0.5981274749345257,
                                ],
                                [
                                    0.05965816482884268,
                                    0.19886490258625567,
                                    0.17110718011831583,
                                    0.5703697524665858,
                                ],
                                [
                                    0.2244240311849535,
                                    0.74809647979707,
                                    0.0063413137622050295,
                                    0.021138175255771594,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.014819457063116215,
                                    0.04071528474800851,
                                    0.2520307448072305,
                                    0.6924345133816449,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.04583886798408296,
                                    0.9313257602921656,
                                    0.0010712090465851147,
                                    0.021764162677166222,
                                ],
                                [
                                    0.04309618500986464,
                                    0.0016133366937801986,
                                    0.9208189580669471,
                                    0.034471520229407936,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04521733361276068,
                                    0.0016927434179073917,
                                    0.9186978094640511,
                                    0.03439211350528074,
                                ],
                                [
                                    0.04461113592749121,
                                    0.002195712883275918,
                                    0.9084787870418407,
                                    0.0447143641473921,
                                ],
                                [
                                    0.04670846303461354,
                                    0.002298941103176825,
                                    0.9063814599347184,
                                    0.04461113592749119,
                                ],
                                [
                                    0.9098953521833137,
                                    0.04478408598402471,
                                    0.043194570786018224,
                                    0.0021259910466433054,
                                ],
                                [
                                    0.02967933652292657,
                                    0.0064055204002616195,
                                    0.7928079629584961,
                                    0.17110718011831577,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.0385829425754197,
                                    0.008327134455248379,
                                    0.7839043569060029,
                                    0.16918556606332902,
                                ],
                                [
                                    0.03569423040444771,
                                    0.010708034717104496,
                                    0.7335404246483938,
                                    0.22005731023005395,
                                ],
                                [
                                    0.044021364859696085,
                                    0.013206120369336006,
                                    0.7252132901931454,
                                    0.21755922457782245,
                                ],
                                [
                                    0.7391646920111745,
                                    0.22174455350428993,
                                    0.030069963041666956,
                                    0.009020791442868508,
                                ],
                                [
                                    0.014433824284536993,
                                    0.009021214230797044,
                                    0.6009488481890423,
                                    0.3755961132956237,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.028867648569073985,
                                    0.01804242846159409,
                                    0.5865150239045053,
                                    0.36657489906482665,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.4850160368837072,
                                    0.4850160368837072,
                                    0.014983963116292777,
                                    0.014983963116292777,
                                ],
                                [
                                    0.004419699707218271,
                                    0.006405520400261612,
                                    0.4038583457585177,
                                    0.5853164341340024,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.019152354562728277,
                                    0.027757722467939797,
                                    0.3891256909030077,
                                    0.5639642320663242,
                                ],
                                [
                                    0.010434593588739468,
                                    0.034782740024021236,
                                    0.22033075135841904,
                                    0.7344519150288202,
                                ],
                                [
                                    0.01876172804398785,
                                    0.06254046249196105,
                                    0.21200361690317066,
                                    0.7066941925608805,
                                ],
                                [
                                    0.2259550187211998,
                                    0.7531998832981646,
                                    0.004810326225958702,
                                    0.016034771754676942,
                                ],
                                [
                                    0.000587218633243017,
                                    0.0016133366937802177,
                                    0.2662629832371037,
                                    0.7315364614358731,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.04622447262127145,
                                    0.939160236746219,
                                    0.0006856044093966257,
                                    0.01392968622311295,
                                ],
                                [
                                    0.8677671480001333,
                                    0.040613253265553824,
                                    0.08752333029622184,
                                    0.004096268438090988,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.8698693175510028,
                                    0.04071163904170744,
                                    0.08542116074535225,
                                    0.0039978826619373724,
                                ],
                                [
                                    0.9063814599347184,
                                    0.04461113592749119,
                                    0.04670846303461349,
                                    0.002298941103176822,
                                ],
                                [
                                    0.9084787870418407,
                                    0.0447143641473921,
                                    0.04461113592749119,
                                    0.002195712883275917,
                                ],
                                [
                                    0.9083804012656871,
                                    0.04470952170364481,
                                    0.04470952170364481,
                                    0.002200555327023207,
                                ],
                                [
                                    0.5719007400028323,
                                    0.1612490581268211,
                                    0.2081591351574891,
                                    0.058691066712857454,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.5803450598484561,
                                    0.16362995838867722,
                                    0.19971481531186536,
                                    0.05631016645100133,
                                ],
                                [
                                    0.7252132901931454,
                                    0.21755922457782245,
                                    0.04402136485969607,
                                    0.013206120369336003,
                                ],
                                [
                                    0.7335404246483938,
                                    0.22005731023005395,
                                    0.035694230404447705,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7331497981296533,
                                    0.21994012483967856,
                                    0.036084856923188136,
                                    0.01082522010747988,
                                ],
                                [
                                    0.2494498611682442,
                                    0.22709510031642177,
                                    0.27400517734708985,
                                    0.2494498611682442,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.26172751925766696,
                                    0.23827248074233295,
                                ],
                                [
                                    0.4653675810587548,
                                    0.4653675810587548,
                                    0.03463241894124521,
                                    0.03463241894124521,
                                ],
                                [
                                    0.47709510031642177,
                                    0.47709510031642177,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                ],
                                [
                                    0.47654496148466596,
                                    0.47654496148466596,
                                    0.02345503851533401,
                                    0.02345503851533401,
                                ],
                                [
                                    0.058691066712857495,
                                    0.16124905812682114,
                                    0.2081591351574892,
                                    0.5719007400028322,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.06832031806727284,
                                    0.18770466369559397,
                                    0.19852988380307385,
                                    0.5454451344340593,
                                ],
                                [
                                    0.21200361690317068,
                                    0.7066941925608805,
                                    0.01876172804398782,
                                    0.06254046249196094,
                                ],
                                [
                                    0.22033075135841906,
                                    0.7344519150288203,
                                    0.01043459358873945,
                                    0.03478274002402117,
                                ],
                                [
                                    0.21994012483967862,
                                    0.7331497981296533,
                                    0.010825220107479883,
                                    0.036084856923188136,
                                ],
                                [
                                    0.004096268438090994,
                                    0.040613253265553845,
                                    0.08752333029622192,
                                    0.8677671480001332,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.008192536876181988,
                                    0.08122650653110769,
                                    0.08342706185813092,
                                    0.8271538947345795,
                                ],
                                [
                                    0.04271058037267617,
                                    0.8677671480001333,
                                    0.004199496657991898,
                                    0.08532277496919863,
                                ],
                                [
                                    0.04480790747979848,
                                    0.9103793425966559,
                                    0.0021021695508695944,
                                    0.042710580372676124,
                                ],
                                [
                                    0.04470952170364486,
                                    0.9083804012656871,
                                    0.0022005553270232096,
                                    0.04470952170364481,
                                ],
                                [
                                    0.7003710213181529,
                                    0.03277877681150055,
                                    0.25491945697820234,
                                    0.01193074489214426,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7024731908690225,
                                    0.03287716258765417,
                                    0.25281728742733267,
                                    0.011832359115990643,
                                ],
                                [
                                    0.7315364614358731,
                                    0.03600545019906094,
                                    0.22155346153345876,
                                    0.010904626831607072,
                                ],
                                [
                                    0.7336337885429954,
                                    0.03610867841896185,
                                    0.21945613442633644,
                                    0.010801398611706165,
                                ],
                                [
                                    0.9087660059028756,
                                    0.04472850075567123,
                                    0.04432391706645632,
                                    0.0021815762749967838,
                                ],
                                [
                                    0.46157855398361947,
                                    0.13014340055064466,
                                    0.3184813211767019,
                                    0.0897967242890339,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.4700228738292432,
                                    0.13252430081250077,
                                    0.3100370013310782,
                                    0.08741582402717779,
                                ],
                                [
                                    0.5853164341340025,
                                    0.17559108646359065,
                                    0.18391822091883903,
                                    0.05517425848356779,
                                ],
                                [
                                    0.5936435685892508,
                                    0.17808917211582218,
                                    0.17559108646359065,
                                    0.05267617283133628,
                                ],
                                [
                                    0.7346807856658997,
                                    0.22039941104654795,
                                    0.034553869386941806,
                                    0.010365933900610514,
                                ],
                                [
                                    0.20132987799400748,
                                    0.18328744953241338,
                                    0.32212516052132656,
                                    0.2932575119522526,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.2136075360834303,
                                    0.1944648299583246,
                                    0.30984750243190373,
                                    0.28208013152634137,
                                ],
                                [
                                    0.37559611329562376,
                                    0.37559611329562376,
                                    0.12440388670437626,
                                    0.12440388670437626,
                                ],
                                [
                                    0.3873236325532907,
                                    0.3873236325532907,
                                    0.11267636744670925,
                                    0.11267636744670925,
                                ],
                                [
                                    0.4787011276797802,
                                    0.4787011276797802,
                                    0.02129887232021984,
                                    0.02129887232021984,
                                ],
                                [
                                    0.0473692999679328,
                                    0.1301434005506447,
                                    0.2194809019024139,
                                    0.6030063975790086,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.05699855132234814,
                                    0.15659900611941752,
                                    0.20985165054799854,
                                    0.5765507920102357,
                                ],
                                [
                                    0.17110718011831585,
                                    0.5703697524665859,
                                    0.059658164828842654,
                                    0.19886490258625558,
                                ],
                                [
                                    0.17943431457356424,
                                    0.5981274749345258,
                                    0.05133103037359428,
                                    0.1711071801183158,
                                ],
                                [
                                    0.22147111237592493,
                                    0.7382532016307479,
                                    0.009294232571233553,
                                    0.030981453422093484,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.0327787768115006,
                                    0.08831351862262532,
                                    0.8756016244541865,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.007402348549778589,
                                    0.07339203007705444,
                                    0.08421725018453433,
                                    0.8349883711886327,
                                ],
                                [
                                    0.034471520229407984,
                                    0.7003710213181528,
                                    0.012438556801260093,
                                    0.2527189016511791,
                                ],
                                [
                                    0.036568847336530284,
                                    0.7429832159146753,
                                    0.010341229694137788,
                                    0.2101067070546566,
                                ],
                                [
                                    0.045095126340833354,
                                    0.9162148777197404,
                                    0.001814950689834721,
                                    0.036875045249591544,
                                ],
                                [
                                    0.4552388641864047,
                                    0.021306097298261252,
                                    0.5000516141099505,
                                    0.02340342440538356,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.4573410337372743,
                                    0.02140448307441487,
                                    0.49794944455908086,
                                    0.023305038629229943,
                                ],
                                [
                                    0.4754962979311048,
                                    0.023403424405383556,
                                    0.4775936250382271,
                                    0.023506652625284463,
                                ],
                                [
                                    0.4775936250382271,
                                    0.023506652625284463,
                                    0.4754962979311048,
                                    0.023403424405383556,
                                ],
                                [
                                    0.9093306790430947,
                                    0.044756293369847974,
                                    0.04375924392623728,
                                    0.0021537836608200448,
                                ],
                                [
                                    0.3000245444947562,
                                    0.08459278303166452,
                                    0.4800353306655652,
                                    0.13534734180801405,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.30846886434037996,
                                    0.08697368329352065,
                                    0.4715910108199414,
                                    0.13296644154615792,
                                ],
                                [
                                    0.3804537602987966,
                                    0.11413362964746347,
                                    0.3887808947540449,
                                    0.11663171529969497,
                                ],
                                [
                                    0.3887808947540449,
                                    0.11663171529969497,
                                    0.3804537602987966,
                                    0.11413362964746347,
                                ],
                                [
                                    0.7369227388385371,
                                    0.22107198227541894,
                                    0.03231191621430438,
                                    0.009693362671739512,
                                ],
                                [
                                    0.1308637596288335,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.3574087211134995,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.14314141771825634,
                                    0.1303136207970777,
                                    0.3803136207970777,
                                    0.34623134068758826,
                                ],
                                [
                                    0.2441362403711665,
                                    0.2441362403711665,
                                    0.2558637596288335,
                                    0.2558637596288335,
                                ],
                                [
                                    0.2558637596288335,
                                    0.2558637596288335,
                                    0.2441362403711665,
                                    0.2441362403711665,
                                ],
                                [
                                    0.4818585822817437,
                                    0.4818585822817437,
                                    0.01814141771825631,
                                    0.01814141771825631,
                                ],
                                [
                                    0.030789889441914717,
                                    0.08459278303166454,
                                    0.23606031242843198,
                                    0.6485570150979888,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.040419140796330064,
                                    0.11104838860043738,
                                    0.22643106107401662,
                                    0.6221014095292159,
                                ],
                                [
                                    0.11121910524595506,
                                    0.37073846629245083,
                                    0.11954623970120344,
                                    0.39849618876039067,
                                ],
                                [
                                    0.11954623970120344,
                                    0.39849618876039067,
                                    0.11121910524595506,
                                    0.37073846629245083,
                                ],
                                [
                                    0.22371306554856238,
                                    0.7457265424644562,
                                    0.007052279398596128,
                                    0.023508112588385213,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                    0.08947065751724015,
                                    0.8870743039674258,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.006245209655163753,
                                    0.061919350563815125,
                                    0.08537438907914915,
                                    0.8464610507018719,
                                ],
                                [
                                    0.022406374961772883,
                                    0.4552388641864047,
                                    0.02450370206889519,
                                    0.49785105878292724,
                                ],
                                [
                                    0.02450370206889519,
                                    0.49785105878292724,
                                    0.022406374961772883,
                                    0.4552388641864047,
                                ],
                                [
                                    0.0456597994810524,
                                    0.9276875572329797,
                                    0.0012502775496156732,
                                    0.025402365736352243,
                                ],
                                [
                                    0.21010670705465664,
                                    0.009833417785021961,
                                    0.7451837712416985,
                                    0.03487610391862285,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.21220887660552626,
                                    0.009931803561175578,
                                    0.7430816016908289,
                                    0.03477771814246924,
                                ],
                                [
                                    0.21945613442633646,
                                    0.010801398611706167,
                                    0.7336337885429954,
                                    0.03610867841896185,
                                ],
                                [
                                    0.22155346153345878,
                                    0.010904626831607074,
                                    0.7315364614358731,
                                    0.03600545019906094,
                                ],
                                [
                                    0.9098953521833137,
                                    0.04478408598402471,
                                    0.043194570786018224,
                                    0.0021259910466433054,
                                ],
                                [
                                    0.13847053500589307,
                                    0.039042165512684406,
                                    0.6415893401544284,
                                    0.18089795932699415,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.1469148548515168,
                                    0.04142306577454053,
                                    0.6331450203088046,
                                    0.17851705906513804,
                                ],
                                [
                                    0.17559108646359067,
                                    0.052676172831336285,
                                    0.5936435685892508,
                                    0.17808917211582218,
                                ],
                                [
                                    0.18391822091883905,
                                    0.055174258483567794,
                                    0.5853164341340025,
                                    0.17559108646359065,
                                ],
                                [
                                    0.7391646920111745,
                                    0.22174455350428993,
                                    0.030069963041666956,
                                    0.009020791442868508,
                                ],
                                [
                                    0.060397641263659596,
                                    0.054985031209919655,
                                    0.46305739725167444,
                                    0.4215599302747463,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.07267529935308242,
                                    0.06616241163583086,
                                    0.4507797391622516,
                                    0.4103825498488351,
                                ],
                                [
                                    0.11267636744670928,
                                    0.11267636744670928,
                                    0.3873236325532907,
                                    0.3873236325532907,
                                ],
                                [
                                    0.1244038867043763,
                                    0.1244038867043763,
                                    0.3755961132956237,
                                    0.3755961132956237,
                                ],
                                [
                                    0.4850160368837072,
                                    0.4850160368837072,
                                    0.014983963116292777,
                                    0.014983963116292777,
                                ],
                                [
                                    0.014210478915896638,
                                    0.039042165512684385,
                                    0.25263972295445003,
                                    0.694107632616969,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.023839730270311985,
                                    0.06549777108145723,
                                    0.24301047160003472,
                                    0.667652027048196,
                                ],
                                [
                                    0.051331030373594294,
                                    0.17110718011831585,
                                    0.1794343145735642,
                                    0.5981274749345257,
                                ],
                                [
                                    0.05965816482884268,
                                    0.19886490258625567,
                                    0.17110718011831583,
                                    0.5703697524665858,
                                ],
                                [
                                    0.2259550187211998,
                                    0.7531998832981646,
                                    0.004810326225958702,
                                    0.016034771754676942,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.00983341778502196,
                                    0.09062779641185499,
                                    0.8985469834806651,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.005088070760548917,
                                    0.050446671050575806,
                                    0.086531527973764,
                                    0.8579337302151113,
                                ],
                                [
                                    0.010341229694137793,
                                    0.2101067070546567,
                                    0.036568847336530284,
                                    0.7429832159146752,
                                ],
                                [
                                    0.012438556801260098,
                                    0.2527189016511792,
                                    0.03447152022940798,
                                    0.7003710213181527,
                                ],
                                [
                                    0.04622447262127145,
                                    0.939160236746219,
                                    0.0006856044093966257,
                                    0.01392968622311295,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04461113592749121,
                                    0.002195712883275918,
                                    0.9084787870418407,
                                    0.0447143641473921,
                                ],
                                [
                                    0.04670846303461354,
                                    0.002298941103176825,
                                    0.9063814599347184,
                                    0.04461113592749119,
                                ],
                                [
                                    0.9102809568205023,
                                    0.04480306503605114,
                                    0.04280896614882974,
                                    0.002107011994616882,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.03569423040444771,
                                    0.010708034717104496,
                                    0.7335404246483938,
                                    0.22005731023005395,
                                ],
                                [
                                    0.044021364859696085,
                                    0.013206120369336006,
                                    0.7252132901931454,
                                    0.21755922457782245,
                                ],
                                [
                                    0.7406956795474209,
                                    0.22220383971115928,
                                    0.028538975505420634,
                                    0.008561505235999144,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.022904899683578228,
                                    0.022904899683578228,
                                    0.47709510031642177,
                                    0.47709510031642177,
                                ],
                                [
                                    0.03463241894124525,
                                    0.03463241894124525,
                                    0.46536758105875475,
                                    0.46536758105875475,
                                ],
                                [
                                    0.48717220307882136,
                                    0.48717220307882136,
                                    0.01282779692117861,
                                    0.01282779692117861,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.010434593588739468,
                                    0.034782740024021236,
                                    0.22033075135841904,
                                    0.7344519150288202,
                                ],
                                [
                                    0.01876172804398785,
                                    0.06254046249196105,
                                    0.21200361690317066,
                                    0.7066941925608805,
                                ],
                                [
                                    0.22748600625744614,
                                    0.7583032867992593,
                                    0.0032793386897123746,
                                    0.010931368253582294,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.0019989413309687114,
                                    0.09141798473825839,
                                    0.9063814599347184,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0021021695508695974,
                                    0.042710580372676187,
                                    0.04480790747979848,
                                    0.9103793425966558,
                                ],
                                [
                                    0.004199496657991903,
                                    0.08532277496919871,
                                    0.04271058037267617,
                                    0.8677671480001332,
                                ],
                                [
                                    0.046610077258459934,
                                    0.9469947132002723,
                                    0.0002999997722081366,
                                    0.006095209769059678,
                                ],
                                [
                                    0.9063814599347185,
                                    0.0019989413309686862,
                                    0.09141798473825831,
                                    0.00020161399605452077,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9171828585464247,
                                    0.0020227628267424,
                                    0.08061658612655213,
                                    0.00017779250028080717,
                                ],
                                [
                                    0.8985469834806652,
                                    0.044225531290302704,
                                    0.054542939488666765,
                                    0.002684545740365311,
                                ],
                                [
                                    0.9088643916790292,
                                    0.044733343199418525,
                                    0.04422553129030271,
                                    0.002176733831249494,
                                ],
                                [
                                    0.7238003707579735,
                                    0.03562468800561975,
                                    0.2292895522113584,
                                    0.011285389025048269,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7778894630244817,
                                    0.00851297953375269,
                                    0.21128531686803834,
                                    0.0023122405737271887,
                                ],
                                [
                                    0.694107632616969,
                                    0.20822773157601343,
                                    0.07512702243587252,
                                    0.022537613371145005,
                                ],
                                [
                                    0.7350714121846401,
                                    0.2205165964369233,
                                    0.034163242868201375,
                                    0.010248748510235129,
                                ],
                                [
                                    0.5546014030765665,
                                    0.16637677885215704,
                                    0.21463325197627506,
                                    0.0643885660950014,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.5780439485054641,
                                    0.013883685452781175,
                                    0.3985010129792019,
                                    0.009571353062552836,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.3323386013433711,
                                    0.3323386013433711,
                                    0.16766139865662888,
                                    0.16766139865662888,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.38311079702148654,
                                    0.014342028336769553,
                                    0.5808043460553253,
                                    0.021742828586418583,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.14039214906087982,
                                    0.4679840743838811,
                                    0.09037319588627866,
                                    0.3012505806689604,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.2528172874273328,
                                    0.011832359115990648,
                                    0.7024731908690224,
                                    0.03287716258765416,
                                ],
                                [
                                    0.03487610391862289,
                                    0.7085911024093945,
                                    0.012033973112045179,
                                    0.24449882055993732,
                                ],
                                [
                                    0.04519351211698697,
                                    0.9182138190507091,
                                    0.0017165649136811055,
                                    0.03487610391862285,
                                ],
                                [
                                    0.026735429551508316,
                                    0.5431939170583828,
                                    0.020174647479159757,
                                    0.4098960059109491,
                                ],
                                [
                                    0.7315364614358733,
                                    0.0016133366937801977,
                                    0.26626298323710357,
                                    0.0005872186332430093,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7423378600475794,
                                    0.0016371581895539113,
                                    0.2554615846253974,
                                    0.0005633971374692957,
                                ],
                                [
                                    0.7252132901931454,
                                    0.035694230404447705,
                                    0.2278766327761865,
                                    0.011215846626220312,
                                ],
                                [
                                    0.7355306983915094,
                                    0.036202042313563526,
                                    0.21755922457782245,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7256972806064875,
                                    0.03571805190022142,
                                    0.22739264236284437,
                                    0.011192025130446596,
                                ],
                                [
                                    0.5853164341340025,
                                    0.006405520400261611,
                                    0.4038583457585176,
                                    0.004419699707218268,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6379926069653389,
                                    0.006981991997506364,
                                    0.3511821729271813,
                                    0.003843228109973516,
                                ],
                                [
                                    0.5602111956888659,
                                    0.1680596797963044,
                                    0.20902345936397557,
                                    0.06270566515085402,
                                ],
                                [
                                    0.6011749752565371,
                                    0.1803485446572143,
                                    0.1680596797963044,
                                    0.05041680028994414,
                                ],
                                [
                                    0.5621328097438527,
                                    0.1686361513935492,
                                    0.2071018453089888,
                                    0.06212919355360927,
                                ],
                                [
                                    0.3755961132956238,
                                    0.009021214230797037,
                                    0.6009488481890422,
                                    0.014433824284536972,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.4882724807423329,
                                    0.011727519257667003,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.3429454574236464,
                                    0.3429454574236464,
                                    0.1570545425763536,
                                    0.1570545425763536,
                                ],
                                [
                                    0.17110718011831585,
                                    0.0064055204002616125,
                                    0.792807962958496,
                                    0.029679336522926522,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.3422143602366317,
                                    0.012811040800523225,
                                    0.62170078284018,
                                    0.02327381612266491,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.14792355572816607,
                                    0.4930893128290176,
                                    0.08284178921899243,
                                    0.27614534222382386,
                                ],
                                [
                                    0.03447152022940799,
                                    0.0016133366937802001,
                                    0.9208189580669471,
                                    0.04309618500986461,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.24457822728406464,
                                    0.011446754478802161,
                                    0.7107122510122905,
                                    0.03326276722484265,
                                ],
                                [
                                    0.02814834898668023,
                                    0.5719007400028322,
                                    0.018761728043987843,
                                    0.3811891829664997,
                                ],
                                [
                                    0.03846575718504431,
                                    0.7815234566441468,
                                    0.008444319845623766,
                                    0.17156646632518516,
                                ],
                                [
                                    0.02863233940002234,
                                    0.5817341577878543,
                                    0.018277737630645732,
                                    0.37135576518147767,
                                ],
                                [
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                    0.522303146741872,
                                    0.0011518917734620563,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.48629769654281096,
                                    0.0010724850493348643,
                                    0.5115017481301658,
                                    0.0011280702776883427,
                                ],
                                [
                                    0.47138625738548395,
                                    0.023201132560776102,
                                    0.481703665583848,
                                    0.023708944469891916,
                                ],
                                [
                                    0.481703665583848,
                                    0.023708944469891916,
                                    0.47138625738548395,
                                    0.023201132560776102,
                                ],
                                [
                                    0.7284750844438135,
                                    0.035854772464403946,
                                    0.2246148385255185,
                                    0.011055304566264076,
                                ],
                                [
                                    0.3804537602987966,
                                    0.004163567227624184,
                                    0.6087210195937236,
                                    0.006661652879855695,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4331299331301328,
                                    0.0047400388248689355,
                                    0.5560448467623873,
                                    0.006085181282610944,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312428,
                                    0.40509921731025633,
                                    0.12152710490403416,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403416,
                                    0.36413543774258517,
                                    0.10923824004312428,
                                ],
                                [
                                    0.5731616788054152,
                                    0.17194473968536722,
                                    0.1960729762474262,
                                    0.058820605261791205,
                                ],
                                [
                                    0.2441362403711665,
                                    0.005863759628833502,
                                    0.7324087211134995,
                                    0.017591278886500507,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.35681260781787577,
                                    0.008570064655703473,
                                    0.6197323536667902,
                                    0.014884973859630536,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.35847796443489593,
                                    0.35847796443489593,
                                    0.14152203556510407,
                                    0.14152203556510407,
                                ],
                                [
                                    0.11121910524595506,
                                    0.004163567227624185,
                                    0.8526960378308568,
                                    0.03192128969556395,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.2823262853642709,
                                    0.010569087627885798,
                                    0.6815888577125409,
                                    0.02551576929530234,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.15895242478972865,
                                    0.5298530144590726,
                                    0.07181292015742986,
                                    0.23938164059376893,
                                ],
                                [
                                    0.022406374961772883,
                                    0.001048663553561152,
                                    0.9328841033345823,
                                    0.04366085815008366,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.23251308201642953,
                                    0.010882081338583113,
                                    0.7227773962799257,
                                    0.033827440365061696,
                                ],
                                [
                                    0.018296334416152,
                                    0.3717336031640087,
                                    0.028613742614516074,
                                    0.5813563198053232,
                                ],
                                [
                                    0.028613742614516074,
                                    0.5813563198053232,
                                    0.018296334416152,
                                    0.3717336031640087,
                                ],
                                [
                                    0.03141014323734825,
                                    0.6381718575940181,
                                    0.015499933793319825,
                                    0.31491806537531386,
                                ],
                                [
                                    0.21945613442633652,
                                    0.00048399041334210393,
                                    0.7783433102466403,
                                    0.001716564913681103,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.23025753303804267,
                                    0.0005078119091158175,
                                    0.7675419116349341,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.21755922457782245,
                                    0.010708034717104494,
                                    0.7355306983915094,
                                    0.036202042313563526,
                                ],
                                [
                                    0.22787663277618653,
                                    0.011215846626220312,
                                    0.7252132901931454,
                                    0.035694230404447705,
                                ],
                                [
                                    0.7312528882811393,
                                    0.035991493028586466,
                                    0.22183703468819257,
                                    0.010918584002081552,
                                ],
                                [
                                    0.17559108646359073,
                                    0.001921614054986759,
                                    0.8135836934289294,
                                    0.00890360605249312,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.228267259294927,
                                    0.0024980856522315107,
                                    0.7609075205975931,
                                    0.008327134455248368,
                                ],
                                [
                                    0.16805967979630448,
                                    0.050416800289944164,
                                    0.6011749752565371,
                                    0.18034854465721428,
                                ],
                                [
                                    0.20902345936397562,
                                    0.06270566515085403,
                                    0.5602111956888659,
                                    0.1680596797963044,
                                ],
                                [
                                    0.5841905478669779,
                                    0.1752533279771853,
                                    0.18504410718586364,
                                    0.05551201696997316,
                                ],
                                [
                                    0.11267636744670928,
                                    0.0027063050268699707,
                                    0.8638685940379567,
                                    0.02074873348846404,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.22535273489341856,
                                    0.005412610053739941,
                                    0.7511922265912474,
                                    0.018042428461594068,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.3740104714461455,
                                    0.3740104714461455,
                                    0.1259895285538545,
                                    0.1259895285538545,
                                ],
                                [
                                    0.05133103037359426,
                                    0.0019216140549867579,
                                    0.9125841127032176,
                                    0.034163242868201375,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.16998129385129124,
                                    0.5666167160891276,
                                    0.06078405109586727,
                                    0.20261793896371394,
                                ],
                                [
                                    0.010341229694137779,
                                    0.00048399041334210404,
                                    0.9449492486022174,
                                    0.044225531290302704,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.22044793674879443,
                                    0.010317408198364065,
                                    0.7348425415475607,
                                    0.03439211350528075,
                                ],
                                [
                                    0.00844431984562377,
                                    0.17156646632518524,
                                    0.0384657571850443,
                                    0.7815234566441467,
                                ],
                                [
                                    0.018761728043987846,
                                    0.3811891829664998,
                                    0.028148348986680227,
                                    0.5719007400028322,
                                ],
                                [
                                    0.03418794707467416,
                                    0.6946095574001818,
                                    0.012722129955993915,
                                    0.25848036556915,
                                ],
                                [
                                    0.04461113592749122,
                                    9.838577615361534e-05,
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.055412534539197394,
                                    0.00012220727192732892,
                                    0.9423869101337794,
                                    0.002078348055095878,
                                ],
                                [
                                    0.04422553129030271,
                                    0.0021767338312494943,
                                    0.9088643916790292,
                                    0.044733343199418525,
                                ],
                                [
                                    0.05454293948866678,
                                    0.0026845457403653116,
                                    0.8985469834806652,
                                    0.044225531290302704,
                                ],
                                [
                                    0.7331497981296533,
                                    0.036084856923188136,
                                    0.21994012483967856,
                                    0.01082522010747988,
                                ],
                                [
                                    0.03569423040444776,
                                    0.00039062651874043134,
                                    0.9534805494880724,
                                    0.010434593588739449,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.08837040323578403,
                                    0.0009670981159851829,
                                    0.9008043766567361,
                                    0.009858121991494696,
                                ],
                                [
                                    0.0341632428682014,
                                    0.010248748510235136,
                                    0.7350714121846401,
                                    0.2205165964369233,
                                ],
                                [
                                    0.07512702243587255,
                                    0.022537613371145012,
                                    0.694107632616969,
                                    0.20822773157601343,
                                ],
                                [
                                    0.591721954534264,
                                    0.1775127005185774,
                                    0.1775127005185774,
                                    0.05325264442858103,
                                ],
                                [
                                    0.022904899683578235,
                                    0.0005501388317558024,
                                    0.9536400618010877,
                                    0.022904899683578207,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.1355812671302875,
                                    0.003256443858625773,
                                    0.8409636943543785,
                                    0.020198594656708237,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.38461732752642075,
                                    0.38461732752642075,
                                    0.11538267247357922,
                                    0.11538267247357922,
                                ],
                                [
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                    0.9534805494880724,
                                    0.035694230404447705,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.18154177370705532,
                                    0.006796146919002044,
                                    0.7823733693697565,
                                    0.02928871000418609,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.17751270051857745,
                                    0.591721954534264,
                                    0.05325264442858104,
                                    0.1775127005185774,
                                ],
                                [
                                    0.0021021695508696182,
                                    9.838577615361652e-05,
                                    0.9531883087454855,
                                    0.04461113592749119,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.21220887660552626,
                                    0.009931803561175578,
                                    0.7430816016908289,
                                    0.03477771814246924,
                                ],
                                [
                                    0.00171656491368111,
                                    0.03487610391862295,
                                    0.04519351211698697,
                                    0.918213819050709,
                                ],
                                [
                                    0.012033973112045182,
                                    0.24449882055993738,
                                    0.03487610391862289,
                                    0.7085911024093945,
                                ],
                                [
                                    0.03608485692318818,
                                    0.7331497981296533,
                                    0.010825220107479893,
                                    0.21994012483967856,
                                ],
                                [
                                    0.8985469834806652,
                                    0.009833417785021958,
                                    0.09062779641185491,
                                    0.0009918023224579212,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9092550181977698,
                                    0.009950603175397345,
                                    0.07991976169475042,
                                    0.0008746169320825346,
                                ],
                                [
                                    0.8985469834806652,
                                    0.044225531290302704,
                                    0.054542939488666765,
                                    0.002684545740365311,
                                ],
                                [
                                    0.9088643916790292,
                                    0.044733343199418525,
                                    0.04422553129030271,
                                    0.002176733831249494,
                                ],
                                [
                                    0.7256972806064875,
                                    0.03571805190022142,
                                    0.22739264236284437,
                                    0.011192025130446596,
                                ],
                                [
                                    0.6941076326169691,
                                    0.03904216551268439,
                                    0.25263972295445,
                                    0.014210478915896635,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7445244329069132,
                                    0.041878009651321275,
                                    0.20222292266450578,
                                    0.011374634777259751,
                                ],
                                [
                                    0.694107632616969,
                                    0.20822773157601343,
                                    0.07512702243587252,
                                    0.022537613371145005,
                                ],
                                [
                                    0.7350714121846401,
                                    0.2205165964369233,
                                    0.034163242868201375,
                                    0.010248748510235129,
                                ],
                                [
                                    0.5621328097438527,
                                    0.1686361513935492,
                                    0.2071018453089888,
                                    0.06212919355360927,
                                ],
                                [
                                    0.4215599302747463,
                                    0.05498503120991964,
                                    0.46305739725167444,
                                    0.06039764126365958,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.5236294416411804,
                                    0.06829819231706491,
                                    0.3609878858852404,
                                    0.04708448015651432,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.3429454574236464,
                                    0.3429454574236464,
                                    0.1570545425763536,
                                    0.1570545425763536,
                                ],
                                [
                                    0.18089795932699423,
                                    0.0390421655126844,
                                    0.6415893401544284,
                                    0.13847053500589301,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.3268999010001736,
                                    0.07055292435808257,
                                    0.49558739848124905,
                                    0.10695977616049483,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.14792355572816607,
                                    0.4930893128290176,
                                    0.08284178921899243,
                                    0.27614534222382386,
                                ],
                                [
                                    0.03487610391862287,
                                    0.009833417785021965,
                                    0.7451837712416985,
                                    0.2101067070546566,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.20644257024380808,
                                    0.05820707629951537,
                                    0.5736173049165133,
                                    0.16173304854016318,
                                ],
                                [
                                    0.03487610391862289,
                                    0.7085911024093945,
                                    0.012033973112045179,
                                    0.24449882055993732,
                                ],
                                [
                                    0.04519351211698697,
                                    0.9182138190507091,
                                    0.0017165649136811055,
                                    0.03487610391862285,
                                ],
                                [
                                    0.02863233940002234,
                                    0.5817341577878543,
                                    0.018277737630645732,
                                    0.37135576518147767,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.73592132491025,
                                    0.008053693326883325,
                                    0.25325345498227014,
                                    0.002771526780596554,
                                ],
                                [
                                    0.7252132901931454,
                                    0.035694230404447705,
                                    0.2278766327761865,
                                    0.011215846626220312,
                                ],
                                [
                                    0.7355306983915094,
                                    0.036202042313563526,
                                    0.21755922457782245,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7275941904550015,
                                    0.035811415794823095,
                                    0.22549573251433036,
                                    0.011098661235844923,
                                ],
                                [
                                    0.560211195688866,
                                    0.031510758845398154,
                                    0.386536159882553,
                                    0.02174188558318287,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6106279959788102,
                                    0.034346602984035045,
                                    0.3361193595926088,
                                    0.018906041444545985,
                                ],
                                [
                                    0.5602111956888659,
                                    0.1680596797963044,
                                    0.20902345936397557,
                                    0.06270566515085402,
                                ],
                                [
                                    0.6011749752565371,
                                    0.1803485446572143,
                                    0.1680596797963044,
                                    0.05041680028994414,
                                ],
                                [
                                    0.569664216411139,
                                    0.1708955239349413,
                                    0.19957043864170254,
                                    0.059869821012217134,
                                ],
                                [
                                    0.3402391523967765,
                                    0.044378175129644364,
                                    0.5443781751296443,
                                    0.07100449734393485,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632103,
                                    0.057691336236789605,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.3535523135039217,
                                    0.3535523135039217,
                                    0.1464476864960783,
                                    0.1464476864960783,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.29200388334635863,
                                    0.06302151769079632,
                                    0.530483416135064,
                                    0.11449118282778108,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.1554549623954523,
                                    0.5181945512741541,
                                    0.0753103825517062,
                                    0.25104010377868735,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.19971481531186544,
                                    0.056310166451001356,
                                    0.580345059848456,
                                    0.16362995838867722,
                                ],
                                [
                                    0.02814834898668023,
                                    0.5719007400028322,
                                    0.018761728043987843,
                                    0.3811891829664997,
                                ],
                                [
                                    0.03846575718504431,
                                    0.7815234566441468,
                                    0.008444319845623766,
                                    0.17156646632518516,
                                ],
                                [
                                    0.030529249248536363,
                                    0.6202743985173257,
                                    0.016380827782131714,
                                    0.33281552445200624,
                                ],
                                [
                                    0.47138625738548395,
                                    0.005158704099182031,
                                    0.5177885225070362,
                                    0.005666516008297848,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.4820942921025884,
                                    0.005275889489557417,
                                    0.5070804877899316,
                                    0.005549330617922462,
                                ],
                                [
                                    0.47138625738548395,
                                    0.023201132560776102,
                                    0.481703665583848,
                                    0.023708944469891916,
                                ],
                                [
                                    0.481703665583848,
                                    0.023708944469891916,
                                    0.47138625738548395,
                                    0.023201132560776102,
                                ],
                                [
                                    0.7303719942923275,
                                    0.035948136359005615,
                                    0.22271792867700446,
                                    0.010961940671662403,
                                ],
                                [
                                    0.36413543774258517,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.03277075464474545,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.41455223803252933,
                                    0.023317733922472456,
                                    0.5321951175388897,
                                    0.02993491050610857,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312428,
                                    0.40509921731025633,
                                    0.12152710490403416,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403416,
                                    0.36413543774258517,
                                    0.10923824004312428,
                                ],
                                [
                                    0.5806930854727015,
                                    0.17420411222675938,
                                    0.18854156958013998,
                                    0.056561232720399084,
                                ],
                                [
                                    0.2211543318816052,
                                    0.028845668118394806,
                                    0.6634629956448156,
                                    0.08653700435518441,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.32322384324803916,
                                    0.04215882922554007,
                                    0.5613934842783815,
                                    0.07322384324803916,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.3690848205151712,
                                    0.3690848205151712,
                                    0.13091517948482878,
                                    0.13091517948482878,
                                ],
                                [
                                    0.09490078268974368,
                                    0.020481889783835576,
                                    0.727586516791679,
                                    0.15703081073474182,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.240902724362923,
                                    0.051992648629233744,
                                    0.5815845751184996,
                                    0.12552005188934365,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.1664838314570149,
                                    0.5549582529042092,
                                    0.06428151349014362,
                                    0.21427640214863236,
                                ],
                                [
                                    0.018296334416152,
                                    0.005158704099182037,
                                    0.7617635407441694,
                                    0.21478142074049653,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.1898628007413372,
                                    0.053532362613675444,
                                    0.5901970744189842,
                                    0.16640776222600312,
                                ],
                                [
                                    0.018296334416152,
                                    0.3717336031640087,
                                    0.028613742614516074,
                                    0.5813563198053232,
                                ],
                                [
                                    0.028613742614516074,
                                    0.5813563198053232,
                                    0.018296334416152,
                                    0.3717336031640087,
                                ],
                                [
                                    0.03330705308586227,
                                    0.6767120983234896,
                                    0.013603023944805804,
                                    0.27637782464584243,
                                ],
                                [
                                    0.2175592245778225,
                                    0.0023809002618561236,
                                    0.7716155553146976,
                                    0.008444319845623756,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.228267259294927,
                                    0.0024980856522315107,
                                    0.7609075205975931,
                                    0.008327134455248368,
                                ],
                                [
                                    0.21755922457782245,
                                    0.010708034717104494,
                                    0.7355306983915094,
                                    0.036202042313563526,
                                ],
                                [
                                    0.22787663277618653,
                                    0.011215846626220312,
                                    0.7252132901931454,
                                    0.035694230404447705,
                                ],
                                [
                                    0.7331497981296533,
                                    0.036084856923188136,
                                    0.21994012483967856,
                                    0.01082522010747988,
                                ],
                                [
                                    0.16805967979630448,
                                    0.009453020722272998,
                                    0.7786876757751144,
                                    0.04379962370630803,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.21847648008624862,
                                    0.012288864860909878,
                                    0.7282708754851703,
                                    0.040963779567671145,
                                ],
                                [
                                    0.16805967979630448,
                                    0.050416800289944164,
                                    0.6011749752565371,
                                    0.18034854465721428,
                                ],
                                [
                                    0.20902345936397562,
                                    0.06270566515085403,
                                    0.5602111956888659,
                                    0.1680596797963044,
                                ],
                                [
                                    0.591721954534264,
                                    0.1775127005185774,
                                    0.1775127005185774,
                                    0.05325264442858103,
                                ],
                                [
                                    0.10206951136643398,
                                    0.01331316110714526,
                                    0.7825478161599868,
                                    0.10206951136643397,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.20413902273286796,
                                    0.02662632221429052,
                                    0.6804783047935528,
                                    0.0887563502592887,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.38461732752642075,
                                    0.38461732752642075,
                                    0.11538267247357922,
                                    0.11538267247357922,
                                ],
                                [
                                    0.04379962370630803,
                                    0.009453020722272993,
                                    0.7786876757751146,
                                    0.1680596797963044,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.17751270051857745,
                                    0.591721954534264,
                                    0.05325264442858104,
                                    0.1775127005185774,
                                ],
                                [
                                    0.008444319845623757,
                                    0.002380900261856124,
                                    0.7716155553146976,
                                    0.21755922457782245,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.18001078617080896,
                                    0.050754558776349525,
                                    0.6000490889895124,
                                    0.16918556606332905,
                                ],
                                [
                                    0.00844431984562377,
                                    0.17156646632518524,
                                    0.0384657571850443,
                                    0.7815234566441467,
                                ],
                                [
                                    0.018761728043987846,
                                    0.3811891829664998,
                                    0.028148348986680227,
                                    0.5719007400028322,
                                ],
                                [
                                    0.03608485692318818,
                                    0.7331497981296533,
                                    0.010825220107479893,
                                    0.21994012483967856,
                                ],
                                [
                                    0.04422553129030273,
                                    0.00048399041334210415,
                                    0.9449492486022174,
                                    0.010341229694137775,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.05493356600740723,
                                    0.0006011758037174909,
                                    0.9342412138851129,
                                    0.010224044303762388,
                                ],
                                [
                                    0.04422553129030271,
                                    0.0021767338312494943,
                                    0.9088643916790292,
                                    0.044733343199418525,
                                ],
                                [
                                    0.05454293948866678,
                                    0.0026845457403653116,
                                    0.8985469834806652,
                                    0.044225531290302704,
                                ],
                                [
                                    0.7350467079781674,
                                    0.03617822081778981,
                                    0.21804321499116452,
                                    0.010731856212878206,
                                ],
                                [
                                    0.03416324286820143,
                                    0.0019216140549867611,
                                    0.9125841127032176,
                                    0.051331030373594266,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.08458004315814557,
                                    0.004757458193623642,
                                    0.8621673124132734,
                                    0.04849518623495738,
                                ],
                                [
                                    0.0341632428682014,
                                    0.010248748510235136,
                                    0.7350714121846401,
                                    0.2205165964369233,
                                ],
                                [
                                    0.07512702243587255,
                                    0.022537613371145012,
                                    0.694107632616969,
                                    0.20822773157601343,
                                ],
                                [
                                    0.5992533612015504,
                                    0.17977207305996956,
                                    0.16998129385129115,
                                    0.05099327188718889,
                                ],
                                [
                                    0.020748733488464063,
                                    0.0027063050268699733,
                                    0.8638685940379567,
                                    0.11267636744670925,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.12281824485489805,
                                    0.016019466134015233,
                                    0.7617990826715227,
                                    0.09936320633956398,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.3952241836066961,
                                    0.3952241836066961,
                                    0.10477581639330394,
                                    0.10477581639330394,
                                ],
                                [
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                    0.8135836934289296,
                                    0.17559108646359065,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.15490554772567244,
                                    0.03343237290038492,
                                    0.6675817517557502,
                                    0.14408032761819248,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.1850441071858637,
                                    0.6168271929794006,
                                    0.0457212377612948,
                                    0.15240746207344086,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.00048399041334210995,
                                    0.7783433102466403,
                                    0.21945613442633646,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.17328303123886632,
                                    0.04885764892783551,
                                    0.606776843921455,
                                    0.17108247591184306,
                                ],
                                [
                                    0.00171656491368111,
                                    0.03487610391862295,
                                    0.04519351211698697,
                                    0.918213819050709,
                                ],
                                [
                                    0.012033973112045182,
                                    0.24449882055993738,
                                    0.03487610391862289,
                                    0.7085911024093945,
                                ],
                                [
                                    0.0379817667717022,
                                    0.7716900388591248,
                                    0.00892831025896587,
                                    0.1813998841102071,
                                ],
                                [
                                    0.8870743039674259,
                                    0.021306097298261256,
                                    0.08947065751724008,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.8976456181203479,
                                    0.021560003252819163,
                                    0.0788993433643181,
                                    0.0018950352625148456,
                                ],
                                [
                                    0.8985469834806652,
                                    0.044225531290302704,
                                    0.054542939488666765,
                                    0.002684545740365311,
                                ],
                                [
                                    0.9088643916790292,
                                    0.044733343199418525,
                                    0.04422553129030271,
                                    0.002176733831249494,
                                ],
                                [
                                    0.7284750844438135,
                                    0.035854772464403946,
                                    0.2246148385255185,
                                    0.011055304566264076,
                                ],
                                [
                                    0.6485570150979889,
                                    0.08459278303166452,
                                    0.23606031242843187,
                                    0.030789889441914697,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.695665227096115,
                                    0.09073721546211946,
                                    0.18895210043030577,
                                    0.024645457011459756,
                                ],
                                [
                                    0.694107632616969,
                                    0.20822773157601343,
                                    0.07512702243587252,
                                    0.022537613371145005,
                                ],
                                [
                                    0.7350714121846401,
                                    0.2205165964369233,
                                    0.034163242868201375,
                                    0.010248748510235129,
                                ],
                                [
                                    0.5731616788054152,
                                    0.17194473968536722,
                                    0.1960729762474262,
                                    0.058820605261791205,
                                ],
                                [
                                    0.3574087211134995,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.1308637596288335,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.443945725468684,
                                    0.14798190848956133,
                                    0.30605427453131606,
                                    0.10201809151043868,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.35847796443489593,
                                    0.35847796443489593,
                                    0.14152203556510407,
                                    0.14152203556510407,
                                ],
                                [
                                    0.13534734180801408,
                                    0.08459278303166454,
                                    0.4800353306655652,
                                    0.3000245444947562,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.2445855818511384,
                                    0.1528672435071177,
                                    0.3707970906224408,
                                    0.23175008401930305,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.15895242478972865,
                                    0.5298530144590726,
                                    0.07181292015742986,
                                    0.23938164059376893,
                                ],
                                [
                                    0.023403424405383573,
                                    0.021306097298261266,
                                    0.5000516141099505,
                                    0.4552388641864047,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.1385321909244049,
                                    0.12611745561891854,
                                    0.3849228475909291,
                                    0.35042750586574745,
                                ],
                                [
                                    0.03487610391862289,
                                    0.7085911024093945,
                                    0.012033973112045179,
                                    0.24449882055993732,
                                ],
                                [
                                    0.04519351211698697,
                                    0.9182138190507091,
                                    0.0017165649136811055,
                                    0.03487610391862285,
                                ],
                                [
                                    0.03141014323734825,
                                    0.6381718575940181,
                                    0.015499933793319825,
                                    0.31491806537531386,
                                ],
                                [
                                    0.7159537413770131,
                                    0.017196056752640375,
                                    0.26059122010765295,
                                    0.006258981762693634,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.726525055529935,
                                    0.017449962707198282,
                                    0.25001990595473095,
                                    0.006005075808135725,
                                ],
                                [
                                    0.7252132901931454,
                                    0.035694230404447705,
                                    0.2278766327761865,
                                    0.011215846626220312,
                                ],
                                [
                                    0.7355306983915094,
                                    0.036202042313563526,
                                    0.21755922457782245,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7303719942923275,
                                    0.035948136359005615,
                                    0.22271792867700446,
                                    0.010961940671662403,
                                ],
                                [
                                    0.523447494058811,
                                    0.06827446047545313,
                                    0.3611698334676098,
                                    0.047108211998126086,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.5705557060569372,
                                    0.07441889290590809,
                                    0.31406162146948363,
                                    0.040963779567671145,
                                ],
                                [
                                    0.5602111956888659,
                                    0.1680596797963044,
                                    0.20902345936397557,
                                    0.06270566515085402,
                                ],
                                [
                                    0.6011749752565371,
                                    0.1803485446572143,
                                    0.1680596797963044,
                                    0.05041680028994414,
                                ],
                                [
                                    0.5806930854727015,
                                    0.17420411222675938,
                                    0.18854156958013998,
                                    0.056561232720399084,
                                ],
                                [
                                    0.28846299564481565,
                                    0.09615433188160522,
                                    0.46153700435518435,
                                    0.15384566811839478,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [0.375, 0.125, 0.37499999999999994, 0.12499999999999999],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.3690848205151712,
                                    0.3690848205151712,
                                    0.13091517948482878,
                                    0.13091517948482878,
                                ],
                                [
                                    0.10923824004312432,
                                    0.06827446047545316,
                                    0.5061444324304549,
                                    0.3163428670509676,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.21847648008624865,
                                    0.13654892095090632,
                                    0.3969061923873306,
                                    0.24806840657551443,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.16648383145701487,
                                    0.5549582529042091,
                                    0.06428151349014363,
                                    0.2142764021486324,
                                ],
                                [
                                    0.018888800170547792,
                                    0.0171960567526404,
                                    0.5045662383447862,
                                    0.45934890473202555,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.13401756668956913,
                                    0.12200741507329767,
                                    0.3894374718257649,
                                    0.3545375464113683,
                                ],
                                [
                                    0.02814834898668023,
                                    0.5719007400028322,
                                    0.018761728043987843,
                                    0.3811891829664997,
                                ],
                                [
                                    0.03846575718504431,
                                    0.7815234566441468,
                                    0.008444319845623766,
                                    0.17156646632518516,
                                ],
                                [
                                    0.03330705308586227,
                                    0.6767120983234896,
                                    0.013603023944805804,
                                    0.27637782464584243,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.4759388952116767,
                                    0.011431286380469112,
                                    0.5006060662729892,
                                    0.012023752134864897,
                                ],
                                [
                                    0.47138625738548395,
                                    0.023201132560776102,
                                    0.481703665583848,
                                    0.023708944469891916,
                                ],
                                [
                                    0.481703665583848,
                                    0.023708944469891916,
                                    0.47138625738548395,
                                    0.023201132560776102,
                                ],
                                [
                                    0.7331497981296533,
                                    0.036084856923188136,
                                    0.21994012483967856,
                                    0.01082522010747988,
                                ],
                                [
                                    0.3402391523967764,
                                    0.04437817512964435,
                                    0.5443781751296444,
                                    0.07100449734393487,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.38734736439490247,
                                    0.05052260756009929,
                                    0.4972699631315183,
                                    0.06486006491347994,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312428,
                                    0.40509921731025633,
                                    0.12152710490403416,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403416,
                                    0.36413543774258517,
                                    0.10923824004312428,
                                ],
                                [
                                    0.591721954534264,
                                    0.1775127005185774,
                                    0.1775127005185774,
                                    0.05325264442858103,
                                ],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.2740370043551844,
                                    0.09134566811839481,
                                    0.4759629956448156,
                                    0.1586543318816052,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.38461732752642075,
                                    0.38461732752642075,
                                    0.11538267247357922,
                                    0.11538267247357922,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.1802427373870592,
                                    0.11265263560509751,
                                    0.43513993508652005,
                                    0.2719646919213232,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.17751270051857745,
                                    0.591721954534264,
                                    0.05325264442858104,
                                    0.1775127005185774,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.12740642460844417,
                                    0.11598873874656848,
                                    0.3960486139068899,
                                    0.36055622273809745,
                                ],
                                [
                                    0.018296334416152,
                                    0.3717336031640087,
                                    0.028613742614516074,
                                    0.5813563198053232,
                                ],
                                [
                                    0.028613742614516074,
                                    0.5813563198053232,
                                    0.018296334416152,
                                    0.3717336031640087,
                                ],
                                [
                                    0.03608485692318818,
                                    0.7331497981296533,
                                    0.010825220107479893,
                                    0.21994012483967856,
                                ],
                                [
                                    0.21478142074049658,
                                    0.0051587040991820324,
                                    0.7617635407441694,
                                    0.01829633441615198,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.22535273489341856,
                                    0.005412610053739941,
                                    0.7511922265912474,
                                    0.018042428461594068,
                                ],
                                [
                                    0.21755922457782245,
                                    0.010708034717104494,
                                    0.7355306983915094,
                                    0.036202042313563526,
                                ],
                                [
                                    0.22787663277618653,
                                    0.011215846626220312,
                                    0.7252132901931454,
                                    0.035694230404447705,
                                ],
                                [
                                    0.7359276019669793,
                                    0.03622157748737066,
                                    0.21716232100235264,
                                    0.010688499543297357,
                                ],
                                [
                                    0.1570308107347419,
                                    0.020481889783835583,
                                    0.7275865167916789,
                                    0.09490078268974364,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.20413902273286796,
                                    0.02662632221429052,
                                    0.6804783047935528,
                                    0.0887563502592887,
                                ],
                                [
                                    0.16805967979630448,
                                    0.050416800289944164,
                                    0.6011749752565371,
                                    0.18034854465721428,
                                ],
                                [
                                    0.20902345936397562,
                                    0.06270566515085403,
                                    0.5602111956888659,
                                    0.1680596797963044,
                                ],
                                [
                                    0.6027508235958267,
                                    0.18082128881039547,
                                    0.16648383145701484,
                                    0.04994405613676297,
                                ],
                                [
                                    0.08653700435518444,
                                    0.028845668118394813,
                                    0.6634629956448156,
                                    0.2211543318816052,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.17307400871036888,
                                    0.057691336236789625,
                                    0.5769259912896312,
                                    0.19230866376321037,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.40014983453767033,
                                    0.40014983453767033,
                                    0.09985016546232968,
                                    0.09985016546232968,
                                ],
                                [
                                    0.03277075464474545,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.36413543774258517,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.18854156958014004,
                                    0.6284856561643191,
                                    0.042223775367018455,
                                    0.14074899888852244,
                                ],
                                [
                                    0.00566651600829785,
                                    0.0051587040991820324,
                                    0.5177885225070362,
                                    0.47138625738548395,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.12079528252731919,
                                    0.10997006241983931,
                                    0.40265975598801484,
                                    0.36657489906482665,
                                ],
                                [
                                    0.00844431984562377,
                                    0.17156646632518524,
                                    0.0384657571850443,
                                    0.7815234566441467,
                                ],
                                [
                                    0.018761728043987846,
                                    0.3811891829664998,
                                    0.028148348986680227,
                                    0.5719007400028322,
                                ],
                                [
                                    0.03886266076051409,
                                    0.7895874979358172,
                                    0.00804741627015398,
                                    0.1635024250335147,
                                ],
                                [
                                    0.043660858150083685,
                                    0.0010486635535611516,
                                    0.9328841033345823,
                                    0.02240637496177286,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.05423217230300566,
                                    0.0013025695081190602,
                                    0.9223127891816603,
                                    0.02215246900721495,
                                ],
                                [
                                    0.04422553129030271,
                                    0.0021767338312494943,
                                    0.9088643916790292,
                                    0.044733343199418525,
                                ],
                                [
                                    0.05454293948866678,
                                    0.0026845457403653116,
                                    0.8985469834806652,
                                    0.044225531290302704,
                                ],
                                [
                                    0.7378245118154934,
                                    0.03631494138197233,
                                    0.21526541115383863,
                                    0.010595135648695684,
                                ],
                                [
                                    0.031921289695564,
                                    0.004163567227624191,
                                    0.8526960378308568,
                                    0.11121910524595503,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.07902950169369008,
                                    0.010307999658079128,
                                    0.8055878258327307,
                                    0.10507467281550009,
                                ],
                                [
                                    0.0341632428682014,
                                    0.010248748510235136,
                                    0.7350714121846401,
                                    0.2205165964369233,
                                ],
                                [
                                    0.07512702243587255,
                                    0.022537613371145012,
                                    0.694107632616969,
                                    0.20822773157601343,
                                ],
                                [
                                    0.6102822302631129,
                                    0.1830806613517876,
                                    0.1589524247897286,
                                    0.04768468359537084,
                                ],
                                [
                                    0.017591278886500528,
                                    0.005863759628833509,
                                    0.7324087211134995,
                                    0.2441362403711665,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.10412828324168497,
                                    0.03470942774722832,
                                    0.645871716758315,
                                    0.21529057225277168,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.4107566906179456,
                                    0.4107566906179456,
                                    0.0892433093820544,
                                    0.0892433093820544,
                                ],
                                [
                                    0.006661652879855697,
                                    0.004163567227624186,
                                    0.6087210195937236,
                                    0.3804537602987966,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.11589989292298003,
                                    0.07243802770307733,
                                    0.4994827795505992,
                                    0.3121792998233434,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.19607297624742628,
                                    0.6535908946094556,
                                    0.03469236869973222,
                                    0.1156437604433859,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.001048663553561164,
                                    0.522303146741872,
                                    0.4754962979311048,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.11628065829248342,
                                    0.10586002187421843,
                                    0.40717438022285063,
                                    0.3706849396104475,
                                ],
                                [
                                    0.00171656491368111,
                                    0.03487610391862295,
                                    0.04519351211698697,
                                    0.918213819050709,
                                ],
                                [
                                    0.012033973112045182,
                                    0.24449882055993738,
                                    0.03487610391862289,
                                    0.7085911024093945,
                                ],
                                [
                                    0.040759570609028115,
                                    0.8281277386652887,
                                    0.00615050642163996,
                                    0.12496218430404328,
                                ],
                                [
                                    0.8756016244541865,
                                    0.03277877681150055,
                                    0.08831351862262524,
                                    0.0033060801116875874,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.8860362180429261,
                                    0.03316940333024098,
                                    0.07787892503388578,
                                    0.0029154535929471564,
                                ],
                                [
                                    0.8985469834806652,
                                    0.044225531290302704,
                                    0.054542939488666765,
                                    0.002684545740365311,
                                ],
                                [
                                    0.9088643916790292,
                                    0.044733343199418525,
                                    0.04422553129030271,
                                    0.002176733831249494,
                                ],
                                [
                                    0.7312528882811393,
                                    0.035991493028586466,
                                    0.22183703468819257,
                                    0.010918584002081552,
                                ],
                                [
                                    0.6030063975790088,
                                    0.13014340055064463,
                                    0.21948090190241384,
                                    0.04736929996793276,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6468060212853168,
                                    0.13959642127291763,
                                    0.1756812781961058,
                                    0.03791627924565976,
                                ],
                                [
                                    0.694107632616969,
                                    0.20822773157601343,
                                    0.07512702243587252,
                                    0.022537613371145005,
                                ],
                                [
                                    0.7350714121846401,
                                    0.2205165964369233,
                                    0.034163242868201375,
                                    0.010248748510235129,
                                ],
                                [
                                    0.5841905478669779,
                                    0.1752533279771853,
                                    0.18504410718586364,
                                    0.05551201696997316,
                                ],
                                [
                                    0.29325751195225264,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.20132987799400742,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.36426200929618757,
                                    0.22766562466205773,
                                    0.2511206631773917,
                                    0.15695170286436302,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.3740104714461455,
                                    0.3740104714461455,
                                    0.1259895285538545,
                                    0.1259895285538545,
                                ],
                                [
                                    0.08979672428903396,
                                    0.13014340055064466,
                                    0.318481321176702,
                                    0.46157855398361936,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.16227126270210332,
                                    0.23518156265615278,
                                    0.24600678276363266,
                                    0.3565403918781112,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.16998129385129124,
                                    0.5666167160891276,
                                    0.06078405109586727,
                                    0.20261793896371394,
                                ],
                                [
                                    0.011930744892144272,
                                    0.032778776811500564,
                                    0.2549194569782024,
                                    0.7003710213181528,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.07062181160500176,
                                    0.19402783493832168,
                                    0.19622839026534492,
                                    0.5391219631913317,
                                ],
                                [
                                    0.03487610391862289,
                                    0.7085911024093945,
                                    0.012033973112045179,
                                    0.24449882055993732,
                                ],
                                [
                                    0.04519351211698697,
                                    0.9182138190507091,
                                    0.0017165649136811055,
                                    0.03487610391862285,
                                ],
                                [
                                    0.03418794707467416,
                                    0.6946095574001818,
                                    0.012722129955993915,
                                    0.25848036556915,
                                ],
                                [
                                    0.7066941925608806,
                                    0.026455605568772807,
                                    0.25722095051593125,
                                    0.009629251354415327,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7171287861496201,
                                    0.026846232087513237,
                                    0.24678635692719178,
                                    0.009238624835674896,
                                ],
                                [
                                    0.7252132901931454,
                                    0.035694230404447705,
                                    0.2278766327761865,
                                    0.011215846626220312,
                                ],
                                [
                                    0.7355306983915094,
                                    0.036202042313563526,
                                    0.21755922457782245,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7331497981296533,
                                    0.036084856923188136,
                                    0.21994012483967856,
                                    0.01082522010747988,
                                ],
                                [
                                    0.48668379242875603,
                                    0.1050381621055081,
                                    0.3358035070526666,
                                    0.07247453841306929,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.5304834161350641,
                                    0.1144911828277811,
                                    0.2920038833463585,
                                    0.0630215176907963,
                                ],
                                [
                                    0.5602111956888659,
                                    0.1680596797963044,
                                    0.20902345936397557,
                                    0.06270566515085402,
                                ],
                                [
                                    0.6011749752565371,
                                    0.1803485446572143,
                                    0.1680596797963044,
                                    0.05041680028994414,
                                ],
                                [
                                    0.591721954534264,
                                    0.1775127005185774,
                                    0.1775127005185774,
                                    0.05325264442858103,
                                ],
                                [
                                    0.2366868388928548,
                                    0.14793048863356606,
                                    0.37869583358072445,
                                    0.2366868388928547,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.30769133623678957,
                                    0.19230866376321035,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.38461732752642075,
                                    0.38461732752642075,
                                    0.11538267247357922,
                                    0.11538267247357922,
                                ],
                                [
                                    0.07247453841306935,
                                    0.10503816210550813,
                                    0.33580350705266665,
                                    0.48668379242875587,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.1449490768261387,
                                    0.21007632421101627,
                                    0.26332896863959726,
                                    0.3816456303232478,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.17751270051857745,
                                    0.591721954534264,
                                    0.05325264442858104,
                                    0.1775127005185774,
                                ],
                                [
                                    0.009629251354415346,
                                    0.026455605568772845,
                                    0.25722095051593136,
                                    0.7066941925608805,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.06832031806727284,
                                    0.18770466369559397,
                                    0.19852988380307385,
                                    0.5454451344340593,
                                ],
                                [
                                    0.02814834898668023,
                                    0.5719007400028322,
                                    0.018761728043987843,
                                    0.3811891829664997,
                                ],
                                [
                                    0.03846575718504431,
                                    0.7815234566441468,
                                    0.008444319845623766,
                                    0.17156646632518516,
                                ],
                                [
                                    0.03608485692318818,
                                    0.7331497981296533,
                                    0.010825220107479893,
                                    0.21994012483967856,
                                ],
                                [
                                    0.45934890473202555,
                                    0.01719605675264037,
                                    0.5045662383447862,
                                    0.018888800170547764,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.469783498320765,
                                    0.017586683271380802,
                                    0.4941316447560468,
                                    0.018498173651807334,
                                ],
                                [
                                    0.47138625738548395,
                                    0.023201132560776102,
                                    0.481703665583848,
                                    0.023708944469891916,
                                ],
                                [
                                    0.481703665583848,
                                    0.023708944469891916,
                                    0.47138625738548395,
                                    0.023201132560776102,
                                ],
                                [
                                    0.7359276019669793,
                                    0.03622157748737066,
                                    0.21716232100235264,
                                    0.010688499543297357,
                                ],
                                [
                                    0.31634286705096765,
                                    0.06827446047545312,
                                    0.506144432430455,
                                    0.10923824004312428,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.36014249075727567,
                                    0.07772748119772611,
                                    0.46234480872414696,
                                    0.09978521932085128,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312428,
                                    0.40509921731025633,
                                    0.12152710490403416,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403416,
                                    0.36413543774258517,
                                    0.10923824004312428,
                                ],
                                [
                                    0.6027508235958267,
                                    0.18082128881039547,
                                    0.16648383145701484,
                                    0.04994405613676297,
                                ],
                                [
                                    0.1538456681183948,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.2884629956448156,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.2248501654623297,
                                    0.14053250701124956,
                                    0.39053250701124953,
                                    0.2440848205151712,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.40014983453767033,
                                    0.40014983453767033,
                                    0.09985016546232968,
                                    0.09985016546232968,
                                ],
                                [
                                    0.047108211998126114,
                                    0.06827446047545314,
                                    0.3611698334676099,
                                    0.5234474940588109,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.11958275041119547,
                                    0.17331262258096128,
                                    0.2886952950545405,
                                    0.41840933195330277,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.18854156958014004,
                                    0.6284856561643191,
                                    0.042223775367018455,
                                    0.14074899888852244,
                                ],
                                [
                                    0.006258981762693645,
                                    0.017196056752640392,
                                    0.26059122010765307,
                                    0.715953741377013,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.06495004847555114,
                                    0.17844511487946152,
                                    0.20190015339479556,
                                    0.5547046832501918,
                                ],
                                [
                                    0.018296334416152,
                                    0.3717336031640087,
                                    0.028613742614516074,
                                    0.5813563198053232,
                                ],
                                [
                                    0.028613742614516074,
                                    0.5813563198053232,
                                    0.018296334416152,
                                    0.3717336031640087,
                                ],
                                [
                                    0.03886266076051409,
                                    0.7895874979358172,
                                    0.00804741627015398,
                                    0.1635024250335147,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.21755922457782245,
                                    0.010708034717104494,
                                    0.7355306983915094,
                                    0.036202042313563526,
                                ],
                                [
                                    0.22787663277618653,
                                    0.011215846626220312,
                                    0.7252132901931454,
                                    0.035694230404447705,
                                ],
                                [
                                    0.7387054058043052,
                                    0.03635829805155318,
                                    0.21438451716502674,
                                    0.010551778979114836,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.16805967979630448,
                                    0.050416800289944164,
                                    0.6011749752565371,
                                    0.18034854465721428,
                                ],
                                [
                                    0.20902345936397562,
                                    0.06270566515085403,
                                    0.5602111956888659,
                                    0.1680596797963044,
                                ],
                                [
                                    0.6137796926573892,
                                    0.18412987710221354,
                                    0.15545496239545226,
                                    0.04663546784494492,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.41568234154891986,
                                    0.41568234154891986,
                                    0.08431765845108014,
                                    0.08431765845108014,
                                ],
                                [
                                    0.021741885583182873,
                                    0.03151075884539815,
                                    0.38653615988255313,
                                    0.5602111956888659,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.19957043864170262,
                                    0.665249357794374,
                                    0.031194906305455877,
                                    0.10398529725846747,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.00844431984562377,
                                    0.17156646632518524,
                                    0.0384657571850443,
                                    0.7815234566441467,
                                ],
                                [
                                    0.018761728043987846,
                                    0.3811891829664998,
                                    0.028148348986680227,
                                    0.5719007400028322,
                                ],
                                [
                                    0.04164046459784,
                                    0.846025197741981,
                                    0.005269612432828071,
                                    0.10706472522735086,
                                ],
                                [
                                    0.04309618500986464,
                                    0.0016133366937801986,
                                    0.9208189580669471,
                                    0.034471520229407936,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.05353077859860409,
                                    0.0020039632125206297,
                                    0.9103843644782077,
                                    0.034080893710667505,
                                ],
                                [
                                    0.04422553129030271,
                                    0.0021767338312494943,
                                    0.9088643916790292,
                                    0.044733343199418525,
                                ],
                                [
                                    0.05454293948866678,
                                    0.0026845457403653116,
                                    0.8985469834806652,
                                    0.044225531290302704,
                                ],
                                [
                                    0.7406023156528192,
                                    0.03645166194615485,
                                    0.21248760731651273,
                                    0.010458415084513163,
                                ],
                                [
                                    0.02967933652292657,
                                    0.0064055204002616195,
                                    0.7928079629584961,
                                    0.17110718011831577,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.0734789602292346,
                                    0.01585854112253461,
                                    0.749008339252188,
                                    0.16165415939604277,
                                ],
                                [
                                    0.0341632428682014,
                                    0.010248748510235136,
                                    0.7350714121846401,
                                    0.2205165964369233,
                                ],
                                [
                                    0.07512702243587255,
                                    0.022537613371145012,
                                    0.694107632616969,
                                    0.20822773157601343,
                                ],
                                [
                                    0.6213110993246755,
                                    0.18638924964360568,
                                    0.147923555728166,
                                    0.044376095303552784,
                                ],
                                [
                                    0.014433824284536993,
                                    0.009021214230797044,
                                    0.6009488481890423,
                                    0.3755961132956237,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.08543832162847188,
                                    0.053399389360441404,
                                    0.5299443508451074,
                                    0.33121793816597933,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.42628919762919515,
                                    0.42628919762919515,
                                    0.07371080237080485,
                                    0.07371080237080485,
                                ],
                                [
                                    0.004419699707218271,
                                    0.006405520400261612,
                                    0.4038583457585177,
                                    0.5853164341340024,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.07689423812028762,
                                    0.11144368250576975,
                                    0.33138380734544837,
                                    0.48027827202849427,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.20710184530898884,
                                    0.6903545962395105,
                                    0.023663499638169647,
                                    0.07888005881333095,
                                ],
                                [
                                    0.000587218633243017,
                                    0.0016133366937802177,
                                    0.2662629832371037,
                                    0.7315364614358731,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.05927828534610051,
                                    0.16286239482060133,
                                    0.20757191652424617,
                                    0.5702874033090519,
                                ],
                                [
                                    0.00171656491368111,
                                    0.03487610391862295,
                                    0.04519351211698697,
                                    0.918213819050709,
                                ],
                                [
                                    0.012033973112045182,
                                    0.24449882055993738,
                                    0.03487610391862289,
                                    0.7085911024093945,
                                ],
                                [
                                    0.04353737444635402,
                                    0.8845654384714525,
                                    0.0033727025843140494,
                                    0.06852448449787943,
                                ],
                                [
                                    0.8677671480001333,
                                    0.040613253265553824,
                                    0.08752333029622184,
                                    0.004096268438090988,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.8781083776942711,
                                    0.04109724367889593,
                                    0.07718210060208407,
                                    0.003612278024748884,
                                ],
                                [
                                    0.8985469834806652,
                                    0.044225531290302704,
                                    0.054542939488666765,
                                    0.002684545740365311,
                                ],
                                [
                                    0.9088643916790292,
                                    0.044733343199418525,
                                    0.04422553129030271,
                                    0.002176733831249494,
                                ],
                                [
                                    0.7331497981296533,
                                    0.036084856923188136,
                                    0.21994012483967856,
                                    0.01082522010747988,
                                ],
                                [
                                    0.5719007400028323,
                                    0.1612490581268211,
                                    0.2081591351574891,
                                    0.058691066712857454,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6134409911677482,
                                    0.17296145139048624,
                                    0.16661888399257319,
                                    0.04697867344919233,
                                ],
                                [
                                    0.694107632616969,
                                    0.20822773157601343,
                                    0.07512702243587252,
                                    0.022537613371145005,
                                ],
                                [
                                    0.7350714121846401,
                                    0.2205165964369233,
                                    0.034163242868201375,
                                    0.010248748510235129,
                                ],
                                [
                                    0.591721954534264,
                                    0.1775127005185774,
                                    0.1775127005185774,
                                    0.05325264442858103,
                                ],
                                [
                                    0.2494498611682442,
                                    0.22709510031642177,
                                    0.27400517734708985,
                                    0.2494498611682442,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.30984750243190384,
                                    0.2820801315263415,
                                    0.21360753608343022,
                                    0.1944648299583245,
                                ],
                                [
                                    0.42155993027474636,
                                    0.42155993027474636,
                                    0.07844006972525365,
                                    0.07844006972525365,
                                ],
                                [
                                    0.47925126651153593,
                                    0.47925126651153593,
                                    0.02074873348846404,
                                    0.02074873348846404,
                                ],
                                [
                                    0.38461732752642075,
                                    0.38461732752642075,
                                    0.11538267247357922,
                                    0.11538267247357922,
                                ],
                                [
                                    0.058691066712857495,
                                    0.16124905812682114,
                                    0.2081591351574892,
                                    0.5719007400028322,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.10606036668079029,
                                    0.2913924586774658,
                                    0.1607898351895564,
                                    0.4417573394521875,
                                ],
                                [
                                    0.1808979593269942,
                                    0.6030063975790086,
                                    0.049867385620164274,
                                    0.16622825747383277,
                                ],
                                [
                                    0.2218617388946654,
                                    0.739555318529915,
                                    0.008903606052493124,
                                    0.02967933652292653,
                                ],
                                [
                                    0.17751270051857745,
                                    0.591721954534264,
                                    0.05325264442858104,
                                    0.1775127005185774,
                                ],
                                [
                                    0.004096268438090994,
                                    0.040613253265553845,
                                    0.08752333029622192,
                                    0.8677671480001332,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.024247094421477038,
                                    0.2404025521218464,
                                    0.06737250431283588,
                                    0.6679778491438406,
                                ],
                                [
                                    0.03487610391862289,
                                    0.7085911024093945,
                                    0.012033973112045179,
                                    0.24449882055993732,
                                ],
                                [
                                    0.04519351211698697,
                                    0.9182138190507091,
                                    0.0017165649136811055,
                                    0.03487610391862285,
                                ],
                                [
                                    0.03608485692318818,
                                    0.7331497981296533,
                                    0.010825220107479893,
                                    0.21994012483967856,
                                ],
                                [
                                    0.7003710213181529,
                                    0.03277877681150055,
                                    0.25491945697820234,
                                    0.01193074489214426,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7107122510122906,
                                    0.03326276722484266,
                                    0.24457822728406453,
                                    0.011446754478802156,
                                ],
                                [
                                    0.7252132901931454,
                                    0.035694230404447705,
                                    0.2278766327761865,
                                    0.011215846626220312,
                                ],
                                [
                                    0.7355306983915094,
                                    0.036202042313563526,
                                    0.21755922457782245,
                                    0.010708034717104494,
                                ],
                                [
                                    0.7350467079781674,
                                    0.03617822081778981,
                                    0.21804321499116452,
                                    0.010731856212878206,
                                ],
                                [
                                    0.46157855398361947,
                                    0.13014340055064466,
                                    0.3184813211767019,
                                    0.0897967242890339,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.5031188051485355,
                                    0.1418557938143098,
                                    0.27694107001178603,
                                    0.07808433102536877,
                                ],
                                [
                                    0.5602111956888659,
                                    0.1680596797963044,
                                    0.20902345936397557,
                                    0.06270566515085402,
                                ],
                                [
                                    0.6011749752565371,
                                    0.1803485446572143,
                                    0.1680596797963044,
                                    0.05041680028994414,
                                ],
                                [
                                    0.5992533612015504,
                                    0.17977207305996956,
                                    0.16998129385129118,
                                    0.0509932718871889,
                                ],
                                [
                                    0.20132987799400748,
                                    0.18328744953241338,
                                    0.32212516052132656,
                                    0.2932575119522526,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.26172751925766696,
                                    0.23827248074233295,
                                ],
                                [
                                    0.34023915239677643,
                                    0.34023915239677643,
                                    0.15976084760322357,
                                    0.15976084760322357,
                                ],
                                [
                                    0.39793048863356606,
                                    0.39793048863356606,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                ],
                                [
                                    0.3952241836066961,
                                    0.3952241836066961,
                                    0.10477581639330394,
                                    0.10477581639330394,
                                ],
                                [
                                    0.0473692999679328,
                                    0.1301434005506447,
                                    0.2194809019024139,
                                    0.6030063975790086,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.0947385999358656,
                                    0.2602868011012894,
                                    0.1721116019344811,
                                    0.47286299702836393,
                                ],
                                [
                                    0.14600194167317931,
                                    0.486683792428756,
                                    0.0847634032739792,
                                    0.2825508626240855,
                                ],
                                [
                                    0.18696572124085045,
                                    0.6232327133796622,
                                    0.04379962370630804,
                                    0.14600194167317926,
                                ],
                                [
                                    0.1850441071858637,
                                    0.6168271929794006,
                                    0.04572123776129481,
                                    0.15240746207344089,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.0327787768115006,
                                    0.08831351862262532,
                                    0.8756016244541865,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.02345690609507364,
                                    0.23256807566779317,
                                    0.06816269263923927,
                                    0.675812325597894,
                                ],
                                [
                                    0.02814834898668023,
                                    0.5719007400028322,
                                    0.018761728043987843,
                                    0.3811891829664997,
                                ],
                                [
                                    0.03846575718504431,
                                    0.7815234566441468,
                                    0.008444319845623766,
                                    0.17156646632518516,
                                ],
                                [
                                    0.0379817667717022,
                                    0.7716900388591248,
                                    0.008928310258965871,
                                    0.18139988411020713,
                                ],
                                [
                                    0.4552388641864047,
                                    0.021306097298261252,
                                    0.5000516141099505,
                                    0.02340342440538356,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.4655800938805425,
                                    0.02179008771160336,
                                    0.48971038441581266,
                                    0.022919433992041452,
                                ],
                                [
                                    0.47138625738548395,
                                    0.023201132560776102,
                                    0.481703665583848,
                                    0.023708944469891916,
                                ],
                                [
                                    0.481703665583848,
                                    0.023708944469891916,
                                    0.47138625738548395,
                                    0.023201132560776102,
                                ],
                                [
                                    0.7378245118154934,
                                    0.03631494138197233,
                                    0.21526541115383863,
                                    0.010595135648695684,
                                ],
                                [
                                    0.3000245444947562,
                                    0.08459278303166452,
                                    0.4800353306655652,
                                    0.13534734180801405,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3415647956596721,
                                    0.09630517629532964,
                                    0.43849507950064925,
                                    0.12363494854434892,
                                ],
                                [
                                    0.36413543774258517,
                                    0.10923824004312428,
                                    0.40509921731025633,
                                    0.12152710490403416,
                                ],
                                [
                                    0.40509921731025633,
                                    0.12152710490403416,
                                    0.36413543774258517,
                                    0.10923824004312428,
                                ],
                                [
                                    0.6102822302631129,
                                    0.1830806613517876,
                                    0.1589524247897286,
                                    0.04768468359537084,
                                ],
                                [
                                    0.1308637596288335,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.3574087211134995,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1912614008924931,
                                    0.17412127158108615,
                                    0.33219363762284093,
                                    0.3024236899035798,
                                ],
                                [
                                    0.22115433188160522,
                                    0.22115433188160522,
                                    0.2788456681183948,
                                    0.2788456681183948,
                                ],
                                [
                                    0.27884566811839484,
                                    0.27884566811839484,
                                    0.2211543318816052,
                                    0.2211543318816052,
                                ],
                                [
                                    0.4107566906179456,
                                    0.4107566906179456,
                                    0.0892433093820544,
                                    0.0892433093820544,
                                ],
                                [
                                    0.030789889441914717,
                                    0.08459278303166454,
                                    0.23606031242843198,
                                    0.6485570150979888,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.07815918940984752,
                                    0.21473618358230923,
                                    0.18869101246049919,
                                    0.5184136145473441,
                                ],
                                [
                                    0.09490078268974367,
                                    0.3163428670509676,
                                    0.13586456225741483,
                                    0.4528917880018739,
                                ],
                                [
                                    0.13586456225741483,
                                    0.4528917880018739,
                                    0.09490078268974368,
                                    0.31634286705096765,
                                ],
                                [
                                    0.19607297624742628,
                                    0.6535908946094556,
                                    0.03469236869973222,
                                    0.1156437604433859,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                    0.08947065751724015,
                                    0.8870743039674258,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.0222997672004588,
                                    0.22109539615455384,
                                    0.06931983153385411,
                                    0.6872850051111332,
                                ],
                                [
                                    0.018296334416152,
                                    0.3717336031640087,
                                    0.028613742614516074,
                                    0.5813563198053232,
                                ],
                                [
                                    0.028613742614516074,
                                    0.5813563198053232,
                                    0.018296334416152,
                                    0.3717336031640087,
                                ],
                                [
                                    0.040759570609028115,
                                    0.8281277386652887,
                                    0.00615050642163996,
                                    0.12496218430404328,
                                ],
                                [
                                    0.21010670705465664,
                                    0.009833417785021961,
                                    0.7451837712416985,
                                    0.03487610391862285,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.22044793674879443,
                                    0.010317408198364065,
                                    0.7348425415475607,
                                    0.03439211350528075,
                                ],
                                [
                                    0.21755922457782245,
                                    0.010708034717104494,
                                    0.7355306983915094,
                                    0.036202042313563526,
                                ],
                                [
                                    0.22787663277618653,
                                    0.011215846626220312,
                                    0.7252132901931454,
                                    0.035694230404447705,
                                ],
                                [
                                    0.7406023156528192,
                                    0.03645166194615485,
                                    0.21248760731651273,
                                    0.010458415084513163,
                                ],
                                [
                                    0.13847053500589307,
                                    0.039042165512684406,
                                    0.6415893401544284,
                                    0.18089795932699415,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.18001078617080896,
                                    0.050754558776349525,
                                    0.6000490889895124,
                                    0.16918556606332905,
                                ],
                                [
                                    0.16805967979630448,
                                    0.050416800289944164,
                                    0.6011749752565371,
                                    0.18034854465721428,
                                ],
                                [
                                    0.20902345936397562,
                                    0.06270566515085403,
                                    0.5602111956888659,
                                    0.1680596797963044,
                                ],
                                [
                                    0.6213110993246755,
                                    0.18638924964360568,
                                    0.147923555728166,
                                    0.044376095303552784,
                                ],
                                [
                                    0.060397641263659596,
                                    0.054985031209919655,
                                    0.46305739725167444,
                                    0.4215599302747463,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.12079528252731919,
                                    0.10997006241983931,
                                    0.40265975598801484,
                                    0.36657489906482665,
                                ],
                                [
                                    0.102069511366434,
                                    0.102069511366434,
                                    0.397930488633566,
                                    0.397930488633566,
                                ],
                                [
                                    0.15976084760322362,
                                    0.15976084760322362,
                                    0.3402391523967764,
                                    0.3402391523967764,
                                ],
                                [
                                    0.42628919762919515,
                                    0.42628919762919515,
                                    0.07371080237080485,
                                    0.07371080237080485,
                                ],
                                [
                                    0.014210478915896638,
                                    0.039042165512684385,
                                    0.25263972295445003,
                                    0.694107632616969,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.04379962370630805,
                                    0.1460019416731793,
                                    0.18696572124085045,
                                    0.6232327133796622,
                                ],
                                [
                                    0.0847634032739792,
                                    0.2825508626240855,
                                    0.14600194167317931,
                                    0.486683792428756,
                                ],
                                [
                                    0.20710184530898884,
                                    0.6903545962395105,
                                    0.023663499638169647,
                                    0.07888005881333095,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.00983341778502196,
                                    0.09062779641185499,
                                    0.8985469834806651,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.021142628305843965,
                                    0.20962271664131454,
                                    0.07047697042846894,
                                    0.6987576846243726,
                                ],
                                [
                                    0.00844431984562377,
                                    0.17156646632518524,
                                    0.0384657571850443,
                                    0.7815234566441467,
                                ],
                                [
                                    0.018761728043987846,
                                    0.3811891829664998,
                                    0.028148348986680227,
                                    0.5719007400028322,
                                ],
                                [
                                    0.04353737444635402,
                                    0.8845654384714525,
                                    0.0033727025843140494,
                                    0.06852448449787943,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.05305181006681393,
                                    0.0024829317443107917,
                                    0.9022386682295412,
                                    0.04222658995933402,
                                ],
                                [
                                    0.04422553129030271,
                                    0.0021767338312494943,
                                    0.9088643916790292,
                                    0.044733343199418525,
                                ],
                                [
                                    0.05454293948866678,
                                    0.0026845457403653116,
                                    0.8985469834806652,
                                    0.044225531290302704,
                                ],
                                [
                                    0.7424992255013332,
                                    0.03654502584075653,
                                    0.21059069746799872,
                                    0.01036505118991149,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.06968860015159613,
                                    0.019648901200173072,
                                    0.7103712750087252,
                                    0.2002912236395055,
                                ],
                                [
                                    0.0341632428682014,
                                    0.010248748510235136,
                                    0.7350714121846401,
                                    0.2205165964369233,
                                ],
                                [
                                    0.07512702243587255,
                                    0.022537613371145012,
                                    0.694107632616969,
                                    0.20822773157601343,
                                ],
                                [
                                    0.6288425059919617,
                                    0.18864862218499778,
                                    0.14039214906087977,
                                    0.04211672276216065,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.07267529935308242,
                                    0.06616241163583086,
                                    0.4507797391622516,
                                    0.4103825498488351,
                                ],
                                [
                                    0.020748733488464066,
                                    0.020748733488464066,
                                    0.47925126651153593,
                                    0.47925126651153593,
                                ],
                                [
                                    0.07844006972525369,
                                    0.07844006972525369,
                                    0.4215599302747463,
                                    0.4215599302747463,
                                ],
                                [
                                    0.43689605370947043,
                                    0.43689605370947043,
                                    0.06310394629052957,
                                    0.06310394629052957,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.05025801213890474,
                                    0.13807990848715262,
                                    0.21659218973144195,
                                    0.5950698896425007,
                                ],
                                [
                                    0.00890360605249314,
                                    0.02967933652292658,
                                    0.22186173889466537,
                                    0.739555318529915,
                                ],
                                [
                                    0.04986738562016429,
                                    0.1662282574738328,
                                    0.1808979593269942,
                                    0.6030063975790086,
                                ],
                                [
                                    0.21463325197627509,
                                    0.715459834684647,
                                    0.016132092970883406,
                                    0.0537748203681944,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.0019989413309687114,
                                    0.09141798473825839,
                                    0.9063814599347184,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.020352439979440567,
                                    0.2017882401872613,
                                    0.07126715875487234,
                                    0.7065921610784258,
                                ],
                                [
                                    0.00171656491368111,
                                    0.03487610391862295,
                                    0.04519351211698697,
                                    0.918213819050709,
                                ],
                                [
                                    0.012033973112045182,
                                    0.24449882055993738,
                                    0.03487610391862289,
                                    0.7085911024093945,
                                ],
                                [
                                    0.045434284294868045,
                                    0.9231056792009239,
                                    0.0014757927358000284,
                                    0.029984243768408005,
                                ],
                                [
                                    0.9063814599347185,
                                    0.0019989413309686862,
                                    0.09141798473825831,
                                    0.00020161399605452077,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.929784884340102,
                                    0.002050555440919139,
                                    0.06801456033287476,
                                    0.00014999988610406802,
                                ],
                                [
                                    0.8870743039674259,
                                    0.043660858150083665,
                                    0.06601561900190606,
                                    0.003249218880584358,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359526,
                                    0.04366085815008366,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.45628752773996584,
                                    0.022457989071723312,
                                    0.4968023952293661,
                                    0.024452087958944706,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.8393469198406089,
                                    0.009185550762623694,
                                    0.14982786005191118,
                                    0.0016396693448561858,
                                ],
                                [
                                    0.6485570150979889,
                                    0.19456284545150382,
                                    0.12067763995485266,
                                    0.036202499495654634,
                                ],
                                [
                                    0.7373133653572775,
                                    0.2211891676657943,
                                    0.03192128969556395,
                                    0.009576177281364125,
                                ],
                                [
                                    0.3041881117223804,
                                    0.09125443591152022,
                                    0.4650465433304611,
                                    0.13951090903563823,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.7095038214299212,
                                    0.017041140054744705,
                                    0.2670411400547447,
                                    0.006413898460589305,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.13672751925766702,
                                    0.13672751925766702,
                                    0.363272480742333,
                                    0.363272480742333,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.5827420831956215,
                                    0.021815369170477824,
                                    0.3811730598811903,
                                    0.014269487752710313,
                                ],
                                [
                                    0.1353473418080141,
                                    0.4511676820964913,
                                    0.09541800313914442,
                                    0.3180669729563503,
                                ],
                                [
                                    0.2241036920673028,
                                    0.7470286593636232,
                                    0.006661652879855697,
                                    0.022205995689218255,
                                ],
                                [
                                    0.03495345666953891,
                                    0.11651407272722854,
                                    0.19581188827761958,
                                    0.6527205823256129,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.49794944455908086,
                                    0.023305038629229943,
                                    0.4573410337372743,
                                    0.02140448307441487,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.04575818525720601,
                                    0.9296864985639484,
                                    0.0011518917734620578,
                                    0.023403424405383556,
                                ],
                                [
                                    0.003197604770633912,
                                    0.06496695544834497,
                                    0.04371247226003416,
                                    0.888122967520987,
                                ],
                                [
                                    0.7315364614358733,
                                    0.0016133366937801977,
                                    0.26626298323710357,
                                    0.0005872186332430093,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7549398858412568,
                                    0.0016649508037306505,
                                    0.24285955883172,
                                    0.0005356045232925566,
                                ],
                                [
                                    0.7159537413770131,
                                    0.03523848521423444,
                                    0.23713618159231892,
                                    0.011671591816433574,
                                ],
                                [
                                    0.7383085022288354,
                                    0.036338762877746046,
                                    0.21478142074049653,
                                    0.01057131415292197,
                                ],
                                [
                                    0.46039756828558676,
                                    0.022660280916330766,
                                    0.49269235468374517,
                                    0.024249796114337252,
                                ],
                                [
                                    0.5853164341340025,
                                    0.006405520400261611,
                                    0.4038583457585176,
                                    0.004419699707218268,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.699450063781466,
                                    0.007654563226377366,
                                    0.2897247161110541,
                                    0.003170656881102513,
                                ],
                                [
                                    0.523447494058811,
                                    0.15703081073474184,
                                    0.24578716099403053,
                                    0.0737345342124166,
                                ],
                                [
                                    0.6122038443180997,
                                    0.18365713294903238,
                                    0.15703081073474184,
                                    0.047108211998126086,
                                ],
                                [
                                    0.32050643427859177,
                                    0.09614982551585939,
                                    0.44872822077424973,
                                    0.13461551943129904,
                                ],
                                [
                                    0.3755961132956238,
                                    0.009021214230797037,
                                    0.6009488481890422,
                                    0.014433824284536972,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.6197323536667902,
                                    0.014884973859630536,
                                    0.35681260781787577,
                                    0.008570064655703473,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.1597094277472283,
                                    0.1597094277472283,
                                    0.3402905722527717,
                                    0.3402905722527717,
                                ],
                                [
                                    0.17110718011831585,
                                    0.0064055204002616125,
                                    0.792807962958496,
                                    0.029679336522926522,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.5418456464107667,
                                    0.020284381634231494,
                                    0.4220694966660451,
                                    0.01580047528895664,
                                ],
                                [
                                    0.10923824004312434,
                                    0.3641354377425853,
                                    0.12152710490403416,
                                    0.4050992173102562,
                                ],
                                [
                                    0.19799459030241304,
                                    0.6599964150097172,
                                    0.03277075464474546,
                                    0.10923824004312427,
                                ],
                                [
                                    0.051271779225750304,
                                    0.1709096719687118,
                                    0.1794935657214082,
                                    0.5983249830841297,
                                ],
                                [
                                    0.03447152022940799,
                                    0.0016133366937802001,
                                    0.9208189580669471,
                                    0.04309618500986461,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.48971038441581266,
                                    0.022919433992041452,
                                    0.4655800938805425,
                                    0.02179008771160336,
                                ],
                                [
                                    0.018888800170547792,
                                    0.3837709558174672,
                                    0.028021276860120282,
                                    0.5693189671518648,
                                ],
                                [
                                    0.041243561022370215,
                                    0.8379611564503106,
                                    0.005666516008297855,
                                    0.1151287665190213,
                                ],
                                [
                                    0.007307645316254797,
                                    0.14847221647074096,
                                    0.03960243171441328,
                                    0.804617706498591,
                                ],
                                [
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                    0.522303146741872,
                                    0.0011518917734620563,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.4988997223364884,
                                    0.0011002776635116035,
                                    0.4988997223364884,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.46536758105875475,
                                    0.022904899683578207,
                                    0.4877223419105772,
                                    0.02400517734708981,
                                ],
                                [
                                    0.4877223419105772,
                                    0.02400517734708981,
                                    0.46536758105875475,
                                    0.022904899683578207,
                                ],
                                [
                                    0.4664162446123159,
                                    0.02295651379352866,
                                    0.486673678357016,
                                    0.023953563237139357,
                                ],
                                [
                                    0.3804537602987966,
                                    0.004163567227624184,
                                    0.6087210195937236,
                                    0.006661652879855695,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.49458738994626006,
                                    0.00541261005373994,
                                    0.49458738994626006,
                                    0.00541261005373994,
                                ],
                                [
                                    0.34023915239677643,
                                    0.10206951136643398,
                                    0.42899550265606506,
                                    0.12869583358072448,
                                ],
                                [
                                    0.4289955026560652,
                                    0.1286958335807245,
                                    0.3402391523967764,
                                    0.10206951136643397,
                                ],
                                [
                                    0.3444027196244006,
                                    0.10331855419254973,
                                    0.4248319354284409,
                                    0.1274467907546087,
                                ],
                                [
                                    0.2441362403711665,
                                    0.005863759628833502,
                                    0.7324087211134995,
                                    0.017591278886500507,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.1933637596288335,
                                    0.1933637596288335,
                                    0.3066362403711665,
                                    0.3066362403711665,
                                ],
                                [
                                    0.11121910524595506,
                                    0.004163567227624185,
                                    0.8526960378308568,
                                    0.03192128969556395,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.4819575715384059,
                                    0.018042428461594068,
                                    0.4819575715384059,
                                    0.018042428461594068,
                                ],
                                [
                                    0.07100449734393491,
                                    0.23668683889285477,
                                    0.1597608476032236,
                                    0.5325478161599867,
                                ],
                                [
                                    0.1597608476032236,
                                    0.5325478161599867,
                                    0.0710044973439349,
                                    0.23668683889285475,
                                ],
                                [
                                    0.0751680645715591,
                                    0.25056570012682466,
                                    0.15559728037559942,
                                    0.5186689549260168,
                                ],
                                [
                                    0.022406374961772883,
                                    0.001048663553561152,
                                    0.9328841033345823,
                                    0.04366085815008366,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.4776452391481776,
                                    0.022354760851822406,
                                    0.4776452391481776,
                                    0.022354760851822406,
                                ],
                                [
                                    0.012277658089422822,
                                    0.2494498611682442,
                                    0.034632418941245253,
                                    0.7036400618010877,
                                ],
                                [
                                    0.034632418941245253,
                                    0.7036400618010877,
                                    0.012277658089422822,
                                    0.2494498611682442,
                                ],
                                [
                                    0.013326321642983974,
                                    0.27075595846650546,
                                    0.0335837553876841,
                                    0.6823339645028265,
                                ],
                                [
                                    0.21945613442633652,
                                    0.00048399041334210393,
                                    0.7783433102466403,
                                    0.001716564913681103,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.24285955883172008,
                                    0.0005356045232925567,
                                    0.7549398858412567,
                                    0.0016649508037306503,
                                ],
                                [
                                    0.21478142074049658,
                                    0.010571314152921974,
                                    0.7383085022288354,
                                    0.036338762877746046,
                                ],
                                [
                                    0.237136181592319,
                                    0.011671591816433577,
                                    0.715953741377013,
                                    0.03523848521423444,
                                ],
                                [
                                    0.4724349209390451,
                                    0.023252746670726555,
                                    0.4806550020302868,
                                    0.023657330359941463,
                                ],
                                [
                                    0.17559108646359073,
                                    0.001921614054986759,
                                    0.8135836934289294,
                                    0.00890360605249312,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.2897247161110542,
                                    0.0031706568811025143,
                                    0.6994500637814659,
                                    0.007654563226377365,
                                ],
                                [
                                    0.15703081073474187,
                                    0.0471082119981261,
                                    0.6122038443180996,
                                    0.18365713294903235,
                                ],
                                [
                                    0.2457871609940306,
                                    0.07373453421241662,
                                    0.5234474940588109,
                                    0.15703081073474182,
                                ],
                                [
                                    0.36829900497020934,
                                    0.11048728286924005,
                                    0.40093565008263216,
                                    0.1202780620779184,
                                ],
                                [
                                    0.11267636744670928,
                                    0.0027063050268699707,
                                    0.8638685940379567,
                                    0.02074873348846404,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.35681260781787577,
                                    0.008570064655703473,
                                    0.6197323536667902,
                                    0.014884973859630536,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.22701809151043872,
                                    0.22701809151043872,
                                    0.2729819084895613,
                                    0.2729819084895613,
                                ],
                                [
                                    0.05133103037359426,
                                    0.0019216140549867579,
                                    0.9125841127032176,
                                    0.034163242868201375,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.4220694966660451,
                                    0.01580047528895664,
                                    0.5418456464107667,
                                    0.020284381634231494,
                                ],
                                [
                                    0.032770754644745465,
                                    0.1092382400431243,
                                    0.19799459030241304,
                                    0.6599964150097172,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.09906434991736786,
                                    0.3302217282849375,
                                    0.13170099502979066,
                                    0.439012926767904,
                                ],
                                [
                                    0.010341229694137779,
                                    0.00048399041334210404,
                                    0.9449492486022174,
                                    0.044225531290302704,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.4655800938805425,
                                    0.02179008771160336,
                                    0.48971038441581266,
                                    0.022919433992041452,
                                ],
                                [
                                    0.005666516008297856,
                                    0.11512876651902133,
                                    0.041243561022370215,
                                    0.8379611564503106,
                                ],
                                [
                                    0.02802127686012029,
                                    0.5693189671518649,
                                    0.018888800170547785,
                                    0.38377095581746706,
                                ],
                                [
                                    0.019344997969713153,
                                    0.39303970046226994,
                                    0.02756507906095492,
                                    0.5600502225070619,
                                ],
                                [
                                    0.04461113592749122,
                                    9.838577615361534e-05,
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.0680145603328748,
                                    0.00014999988610406816,
                                    0.929784884340102,
                                    0.002050555440919139,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727566,
                                    0.9094290648192482,
                                    0.04476113581359526,
                                ],
                                [
                                    0.06601561900190613,
                                    0.0032492188805843614,
                                    0.8870743039674258,
                                    0.04366085815008366,
                                ],
                                [
                                    0.47654496148466596,
                                    0.02345503851533401,
                                    0.47654496148466596,
                                    0.02345503851533401,
                                ],
                                [
                                    0.03569423040444776,
                                    0.00039062651874043134,
                                    0.9534805494880724,
                                    0.010434593588739449,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.14982786005191126,
                                    0.0016396693448561866,
                                    0.8393469198406088,
                                    0.009185550762623692,
                                ],
                                [
                                    0.031921289695563994,
                                    0.009576177281364137,
                                    0.7373133653572775,
                                    0.2211891676657943,
                                ],
                                [
                                    0.12067763995485271,
                                    0.036202499495654655,
                                    0.6485570150979888,
                                    0.1945628454515038,
                                ],
                                [
                                    0.38461732752642075,
                                    0.11538267247357922,
                                    0.38461732752642075,
                                    0.11538267247357922,
                                ],
                                [
                                    0.022904899683578235,
                                    0.0005501388317558024,
                                    0.9536400618010877,
                                    0.022904899683578207,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.2670411400547447,
                                    0.006413898460589305,
                                    0.7095038214299212,
                                    0.017041140054744705,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [0.25, 0.25, 0.25, 0.25],
                                [
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                    0.9534805494880724,
                                    0.035694230404447705,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.3811730598811903,
                                    0.014269487752710313,
                                    0.5827420831956215,
                                    0.021815369170477824,
                                ],
                                [
                                    0.006661652879855703,
                                    0.022205995689218275,
                                    0.2241036920673028,
                                    0.7470286593636232,
                                ],
                                [
                                    0.09541800313914443,
                                    0.3180669729563503,
                                    0.13534734180801408,
                                    0.4511676820964912,
                                ],
                                [
                                    0.11538267247357925,
                                    0.38461732752642075,
                                    0.11538267247357925,
                                    0.38461732752642075,
                                ],
                                [
                                    0.0021021695508696182,
                                    9.838577615361652e-05,
                                    0.9531883087454855,
                                    0.04461113592749119,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.4573410337372743,
                                    0.02140448307441487,
                                    0.49794944455908086,
                                    0.023305038629229943,
                                ],
                                [
                                    0.0011518917734620597,
                                    0.023403424405383594,
                                    0.04575818525720601,
                                    0.9296864985639484,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.023455038515334037,
                                    0.47654496148466596,
                                    0.023455038515334037,
                                    0.47654496148466596,
                                ],
                                [
                                    0.8985469834806652,
                                    0.009833417785021958,
                                    0.09062779641185491,
                                    0.0009918023224579212,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9217481160414412,
                                    0.010087323739579867,
                                    0.0674266638510788,
                                    0.0007378963679000126,
                                ],
                                [
                                    0.8870743039674259,
                                    0.043660858150083665,
                                    0.06601561900190606,
                                    0.003249218880584358,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359526,
                                    0.04366085815008366,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.46039756828558676,
                                    0.022660280916330766,
                                    0.49269235468374517,
                                    0.024249796114337252,
                                ],
                                [
                                    0.6941076326169691,
                                    0.03904216551268439,
                                    0.25263972295445,
                                    0.014210478915896635,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.8033458726600934,
                                    0.04518659794313933,
                                    0.14340148291132565,
                                    0.008066046485441696,
                                ],
                                [
                                    0.6485570150979889,
                                    0.19456284545150382,
                                    0.12067763995485266,
                                    0.036202499495654634,
                                ],
                                [
                                    0.7373133653572775,
                                    0.2211891676657943,
                                    0.03192128969556395,
                                    0.009576177281364125,
                                ],
                                [
                                    0.32050643427859177,
                                    0.09614982551585939,
                                    0.44872822077424973,
                                    0.13461551943129904,
                                ],
                                [
                                    0.4215599302747463,
                                    0.05498503120991964,
                                    0.46305739725167444,
                                    0.06039764126365958,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.6427142621563515,
                                    0.08383069932831444,
                                    0.24190306537006925,
                                    0.031551973145264776,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.1597094277472283,
                                    0.1597094277472283,
                                    0.3402905722527717,
                                    0.3402905722527717,
                                ],
                                [
                                    0.18089795932699423,
                                    0.0390421655126844,
                                    0.6415893401544284,
                                    0.13847053500589301,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.49724082637796185,
                                    0.10731662598813752,
                                    0.3252464731034608,
                                    0.07019607453043988,
                                ],
                                [
                                    0.1353473418080141,
                                    0.4511676820964913,
                                    0.09541800313914442,
                                    0.3180669729563503,
                                ],
                                [
                                    0.2241036920673028,
                                    0.7470286593636232,
                                    0.006661652879855697,
                                    0.022205995689218255,
                                ],
                                [
                                    0.051271779225750304,
                                    0.1709096719687118,
                                    0.1794935657214082,
                                    0.5983249830841297,
                                ],
                                [
                                    0.03487610391862287,
                                    0.009833417785021965,
                                    0.7451837712416985,
                                    0.2101067070546566,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.40660970708263156,
                                    0.1146447761056792,
                                    0.3734501680776898,
                                    0.10529534873399936,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.04575818525720601,
                                    0.9296864985639484,
                                    0.0011518917734620578,
                                    0.023403424405383556,
                                ],
                                [
                                    0.007307645316254797,
                                    0.14847221647074096,
                                    0.03960243171441328,
                                    0.804617706498591,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7484144227539216,
                                    0.008190413891065847,
                                    0.24076035713859853,
                                    0.002634806216414032,
                                ],
                                [
                                    0.7159537413770131,
                                    0.03523848521423444,
                                    0.23713618159231892,
                                    0.011671591816433574,
                                ],
                                [
                                    0.7383085022288354,
                                    0.036338762877746046,
                                    0.21478142074049653,
                                    0.01057131415292197,
                                ],
                                [
                                    0.4645076088312076,
                                    0.022862572760938223,
                                    0.4885823141381243,
                                    0.024047504269729795,
                                ],
                                [
                                    0.560211195688866,
                                    0.031510758845398154,
                                    0.386536159882553,
                                    0.02174188558318287,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6694494357319903,
                                    0.037655191275853095,
                                    0.2772979198394287,
                                    0.015597453152727932,
                                ],
                                [
                                    0.523447494058811,
                                    0.15703081073474184,
                                    0.24578716099403053,
                                    0.0737345342124166,
                                ],
                                [
                                    0.6122038443180997,
                                    0.18365713294903238,
                                    0.15703081073474184,
                                    0.047108211998126086,
                                ],
                                [
                                    0.3368247568348032,
                                    0.10104521512019858,
                                    0.4324098982180383,
                                    0.12972012982695988,
                                ],
                                [
                                    0.3402391523967765,
                                    0.044378175129644364,
                                    0.5443781751296443,
                                    0.07100449734393485,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.5613934842783815,
                                    0.07322384324803916,
                                    0.32322384324803916,
                                    0.04215882922554007,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.18269133623678963,
                                    0.18269133623678963,
                                    0.3173086637632104,
                                    0.3173086637632104,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.46234480872414696,
                                    0.09978521932085128,
                                    0.36014249075727567,
                                    0.07772748119772611,
                                ],
                                [
                                    0.10923824004312434,
                                    0.3641354377425853,
                                    0.12152710490403416,
                                    0.4050992173102562,
                                ],
                                [
                                    0.19799459030241304,
                                    0.6599964150097172,
                                    0.03277075464474546,
                                    0.10923824004312427,
                                ],
                                [
                                    0.0675901017819617,
                                    0.22530527121019503,
                                    0.1631752431651968,
                                    0.5439293838426464,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.39988195215068895,
                                    0.1127478662571652,
                                    0.38017792300963243,
                                    0.10719225858251337,
                                ],
                                [
                                    0.018888800170547792,
                                    0.3837709558174672,
                                    0.028021276860120282,
                                    0.5693189671518648,
                                ],
                                [
                                    0.041243561022370215,
                                    0.8379611564503106,
                                    0.005666516008297855,
                                    0.1151287665190213,
                                ],
                                [
                                    0.011417685861875682,
                                    0.23197747749313696,
                                    0.03549239116879239,
                                    0.7211124454761949,
                                ],
                                [
                                    0.47138625738548395,
                                    0.005158704099182031,
                                    0.5177885225070362,
                                    0.005666516008297848,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.49458738994626006,
                                    0.00541261005373994,
                                    0.49458738994626006,
                                    0.00541261005373994,
                                ],
                                [
                                    0.46536758105875475,
                                    0.022904899683578207,
                                    0.4877223419105772,
                                    0.02400517734708981,
                                ],
                                [
                                    0.4877223419105772,
                                    0.02400517734708981,
                                    0.46536758105875475,
                                    0.022904899683578207,
                                ],
                                [
                                    0.47052628515793676,
                                    0.023158805638136114,
                                    0.48256363781139516,
                                    0.023751271392531904,
                                ],
                                [
                                    0.36413543774258517,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.03277075464474545,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4733736777857095,
                                    0.026626322214290513,
                                    0.4733736777857095,
                                    0.026626322214290513,
                                ],
                                [
                                    0.34023915239677643,
                                    0.10206951136643398,
                                    0.42899550265606506,
                                    0.12869583358072448,
                                ],
                                [
                                    0.4289955026560652,
                                    0.1286958335807245,
                                    0.3402391523967764,
                                    0.10206951136643397,
                                ],
                                [
                                    0.360721042180612,
                                    0.10821394379688891,
                                    0.4085136128722295,
                                    0.12255140115026954,
                                ],
                                [
                                    0.2211543318816052,
                                    0.028845668118394806,
                                    0.6634629956448156,
                                    0.08653700435518441,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.21634566811839484,
                                    0.21634566811839484,
                                    0.28365433188160516,
                                    0.28365433188160516,
                                ],
                                [
                                    0.09490078268974368,
                                    0.020481889783835576,
                                    0.727586516791679,
                                    0.15703081073474182,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.4112436497407113,
                                    0.0887563502592887,
                                    0.4112436497407113,
                                    0.0887563502592887,
                                ],
                                [
                                    0.07100449734393491,
                                    0.23668683889285477,
                                    0.1597608476032236,
                                    0.5325478161599867,
                                ],
                                [
                                    0.1597608476032236,
                                    0.5325478161599867,
                                    0.0710044973439349,
                                    0.23668683889285475,
                                ],
                                [
                                    0.09148638712777046,
                                    0.30496129936830785,
                                    0.13927895781938804,
                                    0.46427335568453365,
                                ],
                                [
                                    0.018296334416152,
                                    0.005158704099182037,
                                    0.7617635407441694,
                                    0.21478142074049653,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.3900299375801607,
                                    0.10997006241983928,
                                    0.3900299375801607,
                                    0.10997006241983928,
                                ],
                                [
                                    0.012277658089422822,
                                    0.2494498611682442,
                                    0.034632418941245253,
                                    0.7036400618010877,
                                ],
                                [
                                    0.034632418941245253,
                                    0.7036400618010877,
                                    0.012277658089422822,
                                    0.2494498611682442,
                                ],
                                [
                                    0.01743636218860486,
                                    0.3542612194889015,
                                    0.029473714842063212,
                                    0.5988287034804305,
                                ],
                                [
                                    0.2175592245778225,
                                    0.0023809002618561236,
                                    0.7716155553146976,
                                    0.008444319845623756,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.2407603571385986,
                                    0.002634806216414033,
                                    0.7484144227539214,
                                    0.008190413891065847,
                                ],
                                [
                                    0.21478142074049658,
                                    0.010571314152921974,
                                    0.7383085022288354,
                                    0.036338762877746046,
                                ],
                                [
                                    0.237136181592319,
                                    0.011671591816433577,
                                    0.715953741377013,
                                    0.03523848521423444,
                                ],
                                [
                                    0.47654496148466596,
                                    0.02345503851533401,
                                    0.47654496148466596,
                                    0.02345503851533401,
                                ],
                                [
                                    0.16805967979630448,
                                    0.009453020722272998,
                                    0.7786876757751144,
                                    0.04379962370630803,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.2772979198394288,
                                    0.015597453152727937,
                                    0.6694494357319902,
                                    0.03765519127585309,
                                ],
                                [
                                    0.15703081073474187,
                                    0.0471082119981261,
                                    0.6122038443180996,
                                    0.18365713294903235,
                                ],
                                [
                                    0.2457871609940306,
                                    0.07373453421241662,
                                    0.5234474940588109,
                                    0.15703081073474182,
                                ],
                                [
                                    0.38461732752642075,
                                    0.11538267247357922,
                                    0.38461732752642075,
                                    0.11538267247357922,
                                ],
                                [
                                    0.10206951136643398,
                                    0.01331316110714526,
                                    0.7825478161599868,
                                    0.10206951136643397,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.32322384324803916,
                                    0.04215882922554007,
                                    0.5613934842783815,
                                    0.07322384324803916,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [0.25, 0.25, 0.25, 0.25],
                                [
                                    0.04379962370630803,
                                    0.009453020722272993,
                                    0.7786876757751146,
                                    0.1680596797963044,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.36014249075727567,
                                    0.07772748119772611,
                                    0.46234480872414696,
                                    0.09978521932085128,
                                ],
                                [
                                    0.032770754644745465,
                                    0.1092382400431243,
                                    0.19799459030241304,
                                    0.6599964150097172,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.11538267247357925,
                                    0.38461732752642075,
                                    0.11538267247357925,
                                    0.38461732752642075,
                                ],
                                [
                                    0.008444319845623757,
                                    0.002380900261856124,
                                    0.7716155553146976,
                                    0.21755922457782245,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.38017792300963243,
                                    0.10719225858251337,
                                    0.39988195215068895,
                                    0.1127478662571652,
                                ],
                                [
                                    0.005666516008297856,
                                    0.11512876651902133,
                                    0.041243561022370215,
                                    0.8379611564503106,
                                ],
                                [
                                    0.02802127686012029,
                                    0.5693189671518649,
                                    0.018888800170547785,
                                    0.38377095581746706,
                                ],
                                [
                                    0.023455038515334037,
                                    0.47654496148466596,
                                    0.023455038515334037,
                                    0.47654496148466596,
                                ],
                                [
                                    0.04422553129030273,
                                    0.00048399041334210415,
                                    0.9449492486022174,
                                    0.010341229694137775,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.06742666385107886,
                                    0.0007378963679000132,
                                    0.9217481160414412,
                                    0.010087323739579867,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727566,
                                    0.9094290648192482,
                                    0.04476113581359526,
                                ],
                                [
                                    0.06601561900190613,
                                    0.0032492188805843614,
                                    0.8870743039674258,
                                    0.04366085815008366,
                                ],
                                [
                                    0.4806550020302868,
                                    0.023657330359941463,
                                    0.4724349209390451,
                                    0.023252746670726555,
                                ],
                                [
                                    0.03416324286820143,
                                    0.0019216140549867611,
                                    0.9125841127032176,
                                    0.051331030373594266,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.14340148291132573,
                                    0.008066046485441701,
                                    0.8033458726600933,
                                    0.045186597943139326,
                                ],
                                [
                                    0.031921289695563994,
                                    0.009576177281364137,
                                    0.7373133653572775,
                                    0.2211891676657943,
                                ],
                                [
                                    0.12067763995485271,
                                    0.036202499495654655,
                                    0.6485570150979888,
                                    0.1945628454515038,
                                ],
                                [
                                    0.40093565008263216,
                                    0.1202780620779184,
                                    0.36829900497020934,
                                    0.11048728286924005,
                                ],
                                [
                                    0.020748733488464063,
                                    0.0027063050268699733,
                                    0.8638685940379567,
                                    0.11267636744670925,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.24190306537006925,
                                    0.031551973145264776,
                                    0.6427142621563515,
                                    0.08383069932831444,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.2729819084895613,
                                    0.2729819084895613,
                                    0.2270180915104387,
                                    0.2270180915104387,
                                ],
                                [
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                    0.8135836934289296,
                                    0.17559108646359065,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.3252464731034608,
                                    0.07019607453043988,
                                    0.49724082637796185,
                                    0.10731662598813752,
                                ],
                                [
                                    0.006661652879855703,
                                    0.022205995689218275,
                                    0.2241036920673028,
                                    0.7470286593636232,
                                ],
                                [
                                    0.09541800313914443,
                                    0.3180669729563503,
                                    0.13534734180801408,
                                    0.4511676820964912,
                                ],
                                [
                                    0.13170099502979066,
                                    0.439012926767904,
                                    0.09906434991736786,
                                    0.3302217282849375,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.00048399041334210995,
                                    0.7783433102466403,
                                    0.21945613442633646,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.3734501680776898,
                                    0.10529534873399936,
                                    0.40660970708263156,
                                    0.1146447761056792,
                                ],
                                [
                                    0.0011518917734620597,
                                    0.023403424405383594,
                                    0.04575818525720601,
                                    0.9296864985639484,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.02756507906095492,
                                    0.5600502225070619,
                                    0.019344997969713153,
                                    0.39303970046226994,
                                ],
                                [
                                    0.8870743039674259,
                                    0.021306097298261256,
                                    0.08947065751724008,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.909979203651004,
                                    0.021856236130017054,
                                    0.06656575783366186,
                                    0.0015988023853169527,
                                ],
                                [
                                    0.8870743039674259,
                                    0.043660858150083665,
                                    0.06601561900190606,
                                    0.003249218880584358,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359526,
                                    0.04366085815008366,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.4664162446123159,
                                    0.02295651379352866,
                                    0.486673678357016,
                                    0.023953563237139357,
                                ],
                                [
                                    0.6485570150979889,
                                    0.08459278303166452,
                                    0.23606031242843187,
                                    0.030789889441914697,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7506265264644228,
                                    0.09790594413880979,
                                    0.13399080106199793,
                                    0.017476728334769442,
                                ],
                                [
                                    0.6485570150979889,
                                    0.19456284545150382,
                                    0.12067763995485266,
                                    0.036202499495654634,
                                ],
                                [
                                    0.7373133653572775,
                                    0.2211891676657943,
                                    0.03192128969556395,
                                    0.009576177281364125,
                                ],
                                [
                                    0.3444027196244006,
                                    0.10331855419254973,
                                    0.4248319354284409,
                                    0.1274467907546087,
                                ],
                                [
                                    0.3574087211134995,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.1308637596288335,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.5449087211134995,
                                    0.1816362403711665,
                                    0.20509127888650053,
                                    0.06836375962883351,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.1933637596288335,
                                    0.1933637596288335,
                                    0.3066362403711665,
                                    0.3066362403711665,
                                ],
                                [
                                    0.13534734180801408,
                                    0.08459278303166454,
                                    0.4800353306655652,
                                    0.3000245444947562,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.3720341807008688,
                                    0.23252327166523054,
                                    0.24334849177271042,
                                    0.1520940558611902,
                                ],
                                [
                                    0.1353473418080141,
                                    0.4511676820964913,
                                    0.09541800313914442,
                                    0.3180669729563503,
                                ],
                                [
                                    0.2241036920673028,
                                    0.7470286593636232,
                                    0.006661652879855697,
                                    0.022205995689218255,
                                ],
                                [
                                    0.07516806457155907,
                                    0.2505657001268246,
                                    0.15559728037559944,
                                    0.518668954926017,
                                ],
                                [
                                    0.023403424405383573,
                                    0.021306097298261266,
                                    0.5000516141099505,
                                    0.4552388641864047,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.27285328557362776,
                                    0.24840119761468304,
                                    0.2506017529417063,
                                    0.22814376386998292,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.04575818525720601,
                                    0.9296864985639484,
                                    0.0011518917734620578,
                                    0.023403424405383556,
                                ],
                                [
                                    0.013326321642983974,
                                    0.27075595846650546,
                                    0.0335837553876841,
                                    0.6823339645028265,
                                ],
                                [
                                    0.7159537413770131,
                                    0.017196056752640375,
                                    0.26059122010765295,
                                    0.006258981762693634,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7388586410605913,
                                    0.017746195584396177,
                                    0.23768632042407473,
                                    0.0057088429309378325,
                                ],
                                [
                                    0.7159537413770131,
                                    0.03523848521423444,
                                    0.23713618159231892,
                                    0.011671591816433574,
                                ],
                                [
                                    0.7383085022288354,
                                    0.036338762877746046,
                                    0.21478142074049653,
                                    0.01057131415292197,
                                ],
                                [
                                    0.47052628515793676,
                                    0.023158805638136114,
                                    0.48256363781139516,
                                    0.023751271392531904,
                                ],
                                [
                                    0.523447494058811,
                                    0.06827446047545313,
                                    0.3611698334676098,
                                    0.047108211998126086,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6255170054252449,
                                    0.0815876215825984,
                                    0.2591003221011758,
                                    0.03379505089098083,
                                ],
                                [
                                    0.523447494058811,
                                    0.15703081073474184,
                                    0.24578716099403053,
                                    0.0737345342124166,
                                ],
                                [
                                    0.6122038443180997,
                                    0.18365713294903238,
                                    0.15703081073474184,
                                    0.047108211998126086,
                                ],
                                [
                                    0.360721042180612,
                                    0.10821394379688891,
                                    0.4085136128722295,
                                    0.12255140115026954,
                                ],
                                [
                                    0.28846299564481565,
                                    0.09615433188160522,
                                    0.46153700435518435,
                                    0.15384566811839478,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.4759629956448156,
                                    0.1586543318816052,
                                    0.2740370043551844,
                                    0.09134566811839481,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.21634566811839478,
                                    0.21634566811839478,
                                    0.2836543318816052,
                                    0.2836543318816052,
                                ],
                                [
                                    0.10923824004312432,
                                    0.06827446047545316,
                                    0.5061444324304549,
                                    0.3163428670509676,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.34592507893597907,
                                    0.21620494910901916,
                                    0.2694575935376002,
                                    0.1684123784174016,
                                ],
                                [
                                    0.10923824004312434,
                                    0.3641354377425853,
                                    0.12152710490403416,
                                    0.4050992173102562,
                                ],
                                [
                                    0.19799459030241304,
                                    0.6599964150097172,
                                    0.03277075464474546,
                                    0.10923824004312427,
                                ],
                                [
                                    0.09148638712777046,
                                    0.30496129936830785,
                                    0.13927895781938804,
                                    0.46427335568453365,
                                ],
                                [
                                    0.018888800170547792,
                                    0.0171960567526404,
                                    0.5045662383447862,
                                    0.45934890473202555,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.268338661338792,
                                    0.24429115706906215,
                                    0.25511637717654206,
                                    0.2322538044156038,
                                ],
                                [
                                    0.018888800170547792,
                                    0.3837709558174672,
                                    0.028021276860120282,
                                    0.5693189671518648,
                                ],
                                [
                                    0.041243561022370215,
                                    0.8379611564503106,
                                    0.005666516008297855,
                                    0.1151287665190213,
                                ],
                                [
                                    0.01743636218860486,
                                    0.3542612194889015,
                                    0.029473714842063212,
                                    0.5988287034804305,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.46536758105875475,
                                    0.022904899683578207,
                                    0.4877223419105772,
                                    0.02400517734708981,
                                ],
                                [
                                    0.4877223419105772,
                                    0.02400517734708981,
                                    0.46536758105875475,
                                    0.022904899683578207,
                                ],
                                [
                                    0.47654496148466596,
                                    0.02345503851533401,
                                    0.47654496148466596,
                                    0.02345503851533401,
                                ],
                                [
                                    0.3402391523967764,
                                    0.04437817512964435,
                                    0.5443781751296444,
                                    0.07100449734393487,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.34023915239677643,
                                    0.10206951136643398,
                                    0.42899550265606506,
                                    0.12869583358072448,
                                ],
                                [
                                    0.4289955026560652,
                                    0.1286958335807245,
                                    0.3402391523967764,
                                    0.10206951136643397,
                                ],
                                [
                                    0.38461732752642075,
                                    0.11538267247357922,
                                    0.38461732752642075,
                                    0.11538267247357922,
                                ],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [0.25, 0.25, 0.25, 0.25],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.07100449734393491,
                                    0.23668683889285477,
                                    0.1597608476032236,
                                    0.5325478161599867,
                                ],
                                [
                                    0.1597608476032236,
                                    0.5325478161599867,
                                    0.0710044973439349,
                                    0.23668683889285475,
                                ],
                                [
                                    0.11538267247357925,
                                    0.38461732752642075,
                                    0.11538267247357925,
                                    0.38461732752642075,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.012277658089422822,
                                    0.2494498611682442,
                                    0.034632418941245253,
                                    0.7036400618010877,
                                ],
                                [
                                    0.034632418941245253,
                                    0.7036400618010877,
                                    0.012277658089422822,
                                    0.2494498611682442,
                                ],
                                [
                                    0.023455038515334037,
                                    0.47654496148466596,
                                    0.023455038515334037,
                                    0.47654496148466596,
                                ],
                                [
                                    0.21478142074049658,
                                    0.0051587040991820324,
                                    0.7617635407441694,
                                    0.01829633441615198,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.2376863204240748,
                                    0.005708842930937835,
                                    0.7388586410605912,
                                    0.017746195584396173,
                                ],
                                [
                                    0.21478142074049658,
                                    0.010571314152921974,
                                    0.7383085022288354,
                                    0.036338762877746046,
                                ],
                                [
                                    0.237136181592319,
                                    0.011671591816433577,
                                    0.715953741377013,
                                    0.03523848521423444,
                                ],
                                [
                                    0.48256363781139516,
                                    0.023751271392531904,
                                    0.47052628515793676,
                                    0.023158805638136114,
                                ],
                                [
                                    0.1570308107347419,
                                    0.020481889783835583,
                                    0.7275865167916789,
                                    0.09490078268974364,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.2591003221011759,
                                    0.033795050890980845,
                                    0.6255170054252449,
                                    0.08158762158259839,
                                ],
                                [
                                    0.15703081073474187,
                                    0.0471082119981261,
                                    0.6122038443180996,
                                    0.18365713294903235,
                                ],
                                [
                                    0.2457871609940306,
                                    0.07373453421241662,
                                    0.5234474940588109,
                                    0.15703081073474182,
                                ],
                                [
                                    0.4085136128722295,
                                    0.12255140115026954,
                                    0.36072104218061196,
                                    0.1082139437968889,
                                ],
                                [
                                    0.08653700435518444,
                                    0.028845668118394813,
                                    0.6634629956448156,
                                    0.2211543318816052,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.2740370043551844,
                                    0.09134566811839481,
                                    0.4759629956448156,
                                    0.1586543318816052,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.28365433188160516,
                                    0.28365433188160516,
                                    0.2163456681183948,
                                    0.2163456681183948,
                                ],
                                [
                                    0.03277075464474545,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.36413543774258517,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.2694575935376002,
                                    0.1684123784174016,
                                    0.34592507893597907,
                                    0.21620494910901916,
                                ],
                                [
                                    0.032770754644745465,
                                    0.1092382400431243,
                                    0.19799459030241304,
                                    0.6599964150097172,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.139278957819388,
                                    0.46427335568453354,
                                    0.09148638712777048,
                                    0.3049612993683079,
                                ],
                                [
                                    0.00566651600829785,
                                    0.0051587040991820324,
                                    0.5177885225070362,
                                    0.47138625738548395,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.25511637717654206,
                                    0.2322538044156038,
                                    0.268338661338792,
                                    0.24429115706906215,
                                ],
                                [
                                    0.005666516008297856,
                                    0.11512876651902133,
                                    0.041243561022370215,
                                    0.8379611564503106,
                                ],
                                [
                                    0.02802127686012029,
                                    0.5693189671518649,
                                    0.018888800170547785,
                                    0.38377095581746706,
                                ],
                                [
                                    0.029473714842063212,
                                    0.5988287034804305,
                                    0.01743636218860486,
                                    0.3542612194889015,
                                ],
                                [
                                    0.043660858150083685,
                                    0.0010486635535611516,
                                    0.9328841033345823,
                                    0.02240637496177286,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.06656575783366192,
                                    0.001598802385316954,
                                    0.909979203651004,
                                    0.021856236130017054,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727566,
                                    0.9094290648192482,
                                    0.04476113581359526,
                                ],
                                [
                                    0.06601561900190613,
                                    0.0032492188805843614,
                                    0.8870743039674258,
                                    0.04366085815008366,
                                ],
                                [
                                    0.486673678357016,
                                    0.023953563237139357,
                                    0.4664162446123159,
                                    0.02295651379352866,
                                ],
                                [
                                    0.031921289695564,
                                    0.004163567227624191,
                                    0.8526960378308568,
                                    0.11121910524595503,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.13399080106199798,
                                    0.017476728334769452,
                                    0.7506265264644227,
                                    0.09790594413880978,
                                ],
                                [
                                    0.031921289695563994,
                                    0.009576177281364137,
                                    0.7373133653572775,
                                    0.2211891676657943,
                                ],
                                [
                                    0.12067763995485271,
                                    0.036202499495654655,
                                    0.6485570150979888,
                                    0.1945628454515038,
                                ],
                                [
                                    0.42483193542844094,
                                    0.12744679075460874,
                                    0.34440271962440056,
                                    0.10331855419254972,
                                ],
                                [
                                    0.017591278886500528,
                                    0.005863759628833509,
                                    0.7324087211134995,
                                    0.2441362403711665,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.20509127888650053,
                                    0.06836375962883351,
                                    0.5449087211134995,
                                    0.1816362403711665,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.3066362403711665,
                                    0.3066362403711665,
                                    0.1933637596288335,
                                    0.1933637596288335,
                                ],
                                [
                                    0.006661652879855697,
                                    0.004163567227624186,
                                    0.6087210195937236,
                                    0.3804537602987966,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.24334849177271042,
                                    0.1520940558611902,
                                    0.3720341807008688,
                                    0.23252327166523054,
                                ],
                                [
                                    0.006661652879855703,
                                    0.022205995689218275,
                                    0.2241036920673028,
                                    0.7470286593636232,
                                ],
                                [
                                    0.09541800313914443,
                                    0.3180669729563503,
                                    0.13534734180801408,
                                    0.4511676820964912,
                                ],
                                [
                                    0.15559728037559942,
                                    0.5186689549260168,
                                    0.07516806457155908,
                                    0.25056570012682466,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.001048663553561164,
                                    0.522303146741872,
                                    0.4754962979311048,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.2506017529417063,
                                    0.22814376386998292,
                                    0.27285328557362776,
                                    0.24840119761468304,
                                ],
                                [
                                    0.0011518917734620597,
                                    0.023403424405383594,
                                    0.04575818525720601,
                                    0.9296864985639484,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.0335837553876841,
                                    0.6823339645028265,
                                    0.013326321642983974,
                                    0.27075595846650546,
                                ],
                                [
                                    0.8756016244541865,
                                    0.03277877681150055,
                                    0.08831351862262524,
                                    0.0033060801116875874,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.8982102912605668,
                                    0.03362514852045424,
                                    0.06570485181624493,
                                    0.0024597084027338924,
                                ],
                                [
                                    0.8870743039674259,
                                    0.043660858150083665,
                                    0.06601561900190606,
                                    0.003249218880584358,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359526,
                                    0.04366085815008366,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.4724349209390451,
                                    0.023252746670726555,
                                    0.4806550020302868,
                                    0.023657330359941463,
                                ],
                                [
                                    0.6030063975790088,
                                    0.13014340055064463,
                                    0.21948090190241384,
                                    0.04736929996793276,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6979071802687524,
                                    0.15062529033448022,
                                    0.12458011921267018,
                                    0.026887410184097182,
                                ],
                                [
                                    0.6485570150979889,
                                    0.19456284545150382,
                                    0.12067763995485266,
                                    0.036202499495654634,
                                ],
                                [
                                    0.7373133653572775,
                                    0.2211891676657943,
                                    0.03192128969556395,
                                    0.009576177281364125,
                                ],
                                [
                                    0.36829900497020934,
                                    0.11048728286924005,
                                    0.40093565008263216,
                                    0.1202780620779184,
                                ],
                                [
                                    0.29325751195225264,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.20132987799400742,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.4471031800706474,
                                    0.27944178141401854,
                                    0.1682794924029318,
                                    0.10517554611240224,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [
                                    0.22701809151043867,
                                    0.22701809151043867,
                                    0.27298190848956133,
                                    0.27298190848956133,
                                ],
                                [
                                    0.08979672428903396,
                                    0.13014340055064466,
                                    0.318481321176702,
                                    0.46157855398361936,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.24682753502377583,
                                    0.3577299173423235,
                                    0.16145051044196015,
                                    0.23399203719194048,
                                ],
                                [
                                    0.1353473418080141,
                                    0.4511676820964913,
                                    0.09541800313914442,
                                    0.3180669729563503,
                                ],
                                [
                                    0.2241036920673028,
                                    0.7470286593636232,
                                    0.006661652879855697,
                                    0.022205995689218255,
                                ],
                                [
                                    0.09906434991736786,
                                    0.3302217282849375,
                                    0.13170099502979066,
                                    0.439012926767904,
                                ],
                                [
                                    0.011930744892144272,
                                    0.032778776811500564,
                                    0.2549194569782024,
                                    0.7003710213181528,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.139096864064624,
                                    0.38215761912368684,
                                    0.1277533378057227,
                                    0.35099217900596646,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.04575818525720601,
                                    0.9296864985639484,
                                    0.0011518917734620578,
                                    0.023403424405383556,
                                ],
                                [
                                    0.019344997969713153,
                                    0.39303970046226994,
                                    0.02756507906095492,
                                    0.5600502225070619,
                                ],
                                [
                                    0.7066941925608806,
                                    0.026455605568772807,
                                    0.25722095051593125,
                                    0.009629251354415327,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7293028593672609,
                                    0.027301977277726503,
                                    0.23461228370955092,
                                    0.008782879645461632,
                                ],
                                [
                                    0.7159537413770131,
                                    0.03523848521423444,
                                    0.23713618159231892,
                                    0.011671591816433574,
                                ],
                                [
                                    0.7383085022288354,
                                    0.036338762877746046,
                                    0.21478142074049653,
                                    0.01057131415292197,
                                ],
                                [
                                    0.47654496148466596,
                                    0.02345503851533401,
                                    0.47654496148466596,
                                    0.02345503851533401,
                                ],
                                [
                                    0.48668379242875603,
                                    0.1050381621055081,
                                    0.3358035070526666,
                                    0.07247453841306929,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.5815845751184997,
                                    0.12552005188934368,
                                    0.2409027243629229,
                                    0.05199264862923372,
                                ],
                                [
                                    0.523447494058811,
                                    0.15703081073474184,
                                    0.24578716099403053,
                                    0.0737345342124166,
                                ],
                                [
                                    0.6122038443180997,
                                    0.18365713294903238,
                                    0.15703081073474184,
                                    0.047108211998126086,
                                ],
                                [
                                    0.38461732752642075,
                                    0.11538267247357922,
                                    0.38461732752642075,
                                    0.11538267247357922,
                                ],
                                [
                                    0.2366868388928548,
                                    0.14793048863356606,
                                    0.37869583358072445,
                                    0.2366868388928547,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.39053250701124953,
                                    0.2440848205151712,
                                    0.2248501654623297,
                                    0.14053250701124956,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [0.25, 0.25, 0.25, 0.25],
                                [
                                    0.07247453841306935,
                                    0.10503816210550813,
                                    0.33580350705266665,
                                    0.48668379242875587,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.22950534914781123,
                                    0.332624678897187,
                                    0.17877269631792475,
                                    0.259097275637077,
                                ],
                                [
                                    0.10923824004312434,
                                    0.3641354377425853,
                                    0.12152710490403416,
                                    0.4050992173102562,
                                ],
                                [
                                    0.19799459030241304,
                                    0.6599964150097172,
                                    0.03277075464474546,
                                    0.10923824004312427,
                                ],
                                [
                                    0.11538267247357925,
                                    0.38461732752642075,
                                    0.11538267247357925,
                                    0.38461732752642075,
                                ],
                                [
                                    0.009629251354415346,
                                    0.026455605568772845,
                                    0.25722095051593136,
                                    0.7066941925608805,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.13679537052689505,
                                    0.3758344478809591,
                                    0.13005483134345164,
                                    0.3573153502486942,
                                ],
                                [
                                    0.018888800170547792,
                                    0.3837709558174672,
                                    0.028021276860120282,
                                    0.5693189671518648,
                                ],
                                [
                                    0.041243561022370215,
                                    0.8379611564503106,
                                    0.005666516008297855,
                                    0.1151287665190213,
                                ],
                                [
                                    0.023455038515334037,
                                    0.47654496148466596,
                                    0.023455038515334037,
                                    0.47654496148466596,
                                ],
                                [
                                    0.45934890473202555,
                                    0.01719605675264037,
                                    0.5045662383447862,
                                    0.018888800170547764,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.4819575715384059,
                                    0.018042428461594068,
                                    0.4819575715384059,
                                    0.018042428461594068,
                                ],
                                [
                                    0.46536758105875475,
                                    0.022904899683578207,
                                    0.4877223419105772,
                                    0.02400517734708981,
                                ],
                                [
                                    0.4877223419105772,
                                    0.02400517734708981,
                                    0.46536758105875475,
                                    0.022904899683578207,
                                ],
                                [
                                    0.48256363781139516,
                                    0.023751271392531904,
                                    0.47052628515793676,
                                    0.023158805638136114,
                                ],
                                [
                                    0.31634286705096765,
                                    0.06827446047545312,
                                    0.506144432430455,
                                    0.10923824004312428,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4112436497407113,
                                    0.0887563502592887,
                                    0.4112436497407113,
                                    0.0887563502592887,
                                ],
                                [
                                    0.34023915239677643,
                                    0.10206951136643398,
                                    0.42899550265606506,
                                    0.12869583358072448,
                                ],
                                [
                                    0.4289955026560652,
                                    0.1286958335807245,
                                    0.3402391523967764,
                                    0.10206951136643397,
                                ],
                                [
                                    0.4085136128722295,
                                    0.12255140115026954,
                                    0.36072104218061196,
                                    0.1082139437968889,
                                ],
                                [
                                    0.1538456681183948,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.2884629956448156,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.28365433188160516,
                                    0.28365433188160516,
                                    0.2163456681183948,
                                    0.2163456681183948,
                                ],
                                [
                                    0.047108211998126114,
                                    0.06827446047545314,
                                    0.3611698334676099,
                                    0.5234474940588109,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.204139022732868,
                                    0.295860977267132,
                                    0.204139022732868,
                                    0.295860977267132,
                                ],
                                [
                                    0.07100449734393491,
                                    0.23668683889285477,
                                    0.1597608476032236,
                                    0.5325478161599867,
                                ],
                                [
                                    0.1597608476032236,
                                    0.5325478161599867,
                                    0.0710044973439349,
                                    0.23668683889285475,
                                ],
                                [
                                    0.139278957819388,
                                    0.46427335568453354,
                                    0.09148638712777048,
                                    0.3049612993683079,
                                ],
                                [
                                    0.006258981762693645,
                                    0.017196056752640392,
                                    0.26059122010765307,
                                    0.715953741377013,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.13342510093517335,
                                    0.36657489906482665,
                                    0.13342510093517335,
                                    0.36657489906482665,
                                ],
                                [
                                    0.012277658089422822,
                                    0.2494498611682442,
                                    0.034632418941245253,
                                    0.7036400618010877,
                                ],
                                [
                                    0.034632418941245253,
                                    0.7036400618010877,
                                    0.012277658089422822,
                                    0.2494498611682442,
                                ],
                                [
                                    0.029473714842063212,
                                    0.5988287034804305,
                                    0.01743636218860486,
                                    0.3542612194889015,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.234612283709551,
                                    0.008782879645461636,
                                    0.7293028593672608,
                                    0.0273019772777265,
                                ],
                                [
                                    0.21478142074049658,
                                    0.010571314152921974,
                                    0.7383085022288354,
                                    0.036338762877746046,
                                ],
                                [
                                    0.237136181592319,
                                    0.011671591816433577,
                                    0.715953741377013,
                                    0.03523848521423444,
                                ],
                                [
                                    0.4885823141381243,
                                    0.024047504269729795,
                                    0.4645076088312076,
                                    0.022862572760938223,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.240902724362923,
                                    0.051992648629233744,
                                    0.5815845751184996,
                                    0.12552005188934365,
                                ],
                                [
                                    0.15703081073474187,
                                    0.0471082119981261,
                                    0.6122038443180996,
                                    0.18365713294903235,
                                ],
                                [
                                    0.2457871609940306,
                                    0.07373453421241662,
                                    0.5234474940588109,
                                    0.15703081073474182,
                                ],
                                [
                                    0.43240989821803827,
                                    0.12972012982695985,
                                    0.33682475683480323,
                                    0.1010452151201986,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.2248501654623297,
                                    0.14053250701124956,
                                    0.39053250701124953,
                                    0.2440848205151712,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.3173086637632104,
                                    0.3173086637632104,
                                    0.18269133623678963,
                                    0.18269133623678963,
                                ],
                                [
                                    0.021741885583182873,
                                    0.03151075884539815,
                                    0.38653615988255313,
                                    0.5602111956888659,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.17877269631792475,
                                    0.259097275637077,
                                    0.22950534914781123,
                                    0.332624678897187,
                                ],
                                [
                                    0.032770754644745465,
                                    0.1092382400431243,
                                    0.19799459030241304,
                                    0.6599964150097172,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.1631752431651968,
                                    0.5439293838426464,
                                    0.0675901017819617,
                                    0.22530527121019503,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.13005483134345164,
                                    0.3573153502486942,
                                    0.13679537052689505,
                                    0.3758344478809591,
                                ],
                                [
                                    0.005666516008297856,
                                    0.11512876651902133,
                                    0.041243561022370215,
                                    0.8379611564503106,
                                ],
                                [
                                    0.02802127686012029,
                                    0.5693189671518649,
                                    0.018888800170547785,
                                    0.38377095581746706,
                                ],
                                [
                                    0.03549239116879239,
                                    0.7211124454761949,
                                    0.011417685861875682,
                                    0.23197747749313696,
                                ],
                                [
                                    0.04309618500986464,
                                    0.0016133366937801986,
                                    0.9208189580669471,
                                    0.034471520229407936,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.06570485181624498,
                                    0.0024597084027338945,
                                    0.8982102912605668,
                                    0.03362514852045424,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727566,
                                    0.9094290648192482,
                                    0.04476113581359526,
                                ],
                                [
                                    0.06601561900190613,
                                    0.0032492188805843614,
                                    0.8870743039674258,
                                    0.04366085815008366,
                                ],
                                [
                                    0.49269235468374517,
                                    0.024249796114337252,
                                    0.46039756828558676,
                                    0.022660280916330766,
                                ],
                                [
                                    0.02967933652292657,
                                    0.0064055204002616195,
                                    0.7928079629584961,
                                    0.17110718011831577,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.12458011921267025,
                                    0.026887410184097196,
                                    0.6979071802687524,
                                    0.1506252903344802,
                                ],
                                [
                                    0.031921289695563994,
                                    0.009576177281364137,
                                    0.7373133653572775,
                                    0.2211891676657943,
                                ],
                                [
                                    0.12067763995485271,
                                    0.036202499495654655,
                                    0.6485570150979888,
                                    0.1945628454515038,
                                ],
                                [
                                    0.44872822077424973,
                                    0.13461551943129904,
                                    0.3205064342785918,
                                    0.0961498255158594,
                                ],
                                [
                                    0.014433824284536993,
                                    0.009021214230797044,
                                    0.6009488481890423,
                                    0.3755961132956237,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.1682794924029318,
                                    0.10517554611240224,
                                    0.4471031800706474,
                                    0.27944178141401854,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.3402905722527717,
                                    0.3402905722527717,
                                    0.15970942774722832,
                                    0.15970942774722832,
                                ],
                                [
                                    0.004419699707218271,
                                    0.006405520400261612,
                                    0.4038583457585177,
                                    0.5853164341340024,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.16145051044196015,
                                    0.23399203719194048,
                                    0.24682753502377583,
                                    0.3577299173423235,
                                ],
                                [
                                    0.006661652879855703,
                                    0.022205995689218275,
                                    0.2241036920673028,
                                    0.7470286593636232,
                                ],
                                [
                                    0.09541800313914443,
                                    0.3180669729563503,
                                    0.13534734180801408,
                                    0.4511676820964912,
                                ],
                                [
                                    0.1794935657214082,
                                    0.5983249830841297,
                                    0.051271779225750304,
                                    0.1709096719687118,
                                ],
                                [
                                    0.000587218633243017,
                                    0.0016133366937802177,
                                    0.2662629832371037,
                                    0.7315364614358731,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.1277533378057227,
                                    0.35099217900596646,
                                    0.139096864064624,
                                    0.38215761912368684,
                                ],
                                [
                                    0.0011518917734620597,
                                    0.023403424405383594,
                                    0.04575818525720601,
                                    0.9296864985639484,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.03960243171441328,
                                    0.804617706498591,
                                    0.007307645316254797,
                                    0.14847221647074096,
                                ],
                                [
                                    0.8677671480001333,
                                    0.040613253265553824,
                                    0.08752333029622184,
                                    0.004096268438090988,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.8901735229619061,
                                    0.04166191681911497,
                                    0.06511695533444899,
                                    0.003047604884529837,
                                ],
                                [
                                    0.8870743039674259,
                                    0.043660858150083665,
                                    0.06601561900190606,
                                    0.003249218880584358,
                                ],
                                [
                                    0.9094290648192482,
                                    0.04476113581359526,
                                    0.04366085815008366,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.47654496148466596,
                                    0.02345503851533401,
                                    0.47654496148466596,
                                    0.02345503851533401,
                                ],
                                [
                                    0.5719007400028323,
                                    0.1612490581268211,
                                    0.2081591351574891,
                                    0.058691066712857454,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6619061330882368,
                                    0.18662633751499588,
                                    0.11815374207208465,
                                    0.033313787324682695,
                                ],
                                [
                                    0.6485570150979889,
                                    0.19456284545150382,
                                    0.12067763995485266,
                                    0.036202499495654634,
                                ],
                                [
                                    0.7373133653572775,
                                    0.2211891676657943,
                                    0.03192128969556395,
                                    0.009576177281364125,
                                ],
                                [
                                    0.38461732752642075,
                                    0.11538267247357922,
                                    0.38461732752642075,
                                    0.11538267247357922,
                                ],
                                [
                                    0.2494498611682442,
                                    0.22709510031642177,
                                    0.27400517734708985,
                                    0.2494498611682442,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.3803136207970777,
                                    0.34623134068758826,
                                    0.14314141771825634,
                                    0.1303136207970777,
                                ],
                                [
                                    0.35740872111349953,
                                    0.35740872111349953,
                                    0.1425912788865005,
                                    0.1425912788865005,
                                ],
                                [
                                    0.4824087211134995,
                                    0.4824087211134995,
                                    0.017591278886500507,
                                    0.017591278886500507,
                                ],
                                [0.25, 0.25, 0.25, 0.25],
                                [
                                    0.058691066712857495,
                                    0.16124905812682114,
                                    0.2081591351574892,
                                    0.5719007400028322,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.1613262782061161,
                                    0.44323117415998325,
                                    0.10552392366423057,
                                    0.28991862396967005,
                                ],
                                [
                                    0.1353473418080141,
                                    0.4511676820964913,
                                    0.09541800313914442,
                                    0.3180669729563503,
                                ],
                                [
                                    0.2241036920673028,
                                    0.7470286593636232,
                                    0.006661652879855697,
                                    0.022205995689218255,
                                ],
                                [
                                    0.11538267247357925,
                                    0.38461732752642075,
                                    0.11538267247357925,
                                    0.38461732752642075,
                                ],
                                [
                                    0.004096268438090994,
                                    0.040613253265553845,
                                    0.08752333029622192,
                                    0.8677671480001332,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.04775712658817469,
                                    0.4734973566001361,
                                    0.04386247214613822,
                                    0.434883044665551,
                                ],
                                [
                                    0.023403424405383583,
                                    0.4754962979311048,
                                    0.02350665262528449,
                                    0.4775936250382271,
                                ],
                                [
                                    0.04575818525720601,
                                    0.9296864985639484,
                                    0.0011518917734620578,
                                    0.023403424405383556,
                                ],
                                [
                                    0.023455038515334037,
                                    0.47654496148466596,
                                    0.023455038515334037,
                                    0.47654496148466596,
                                ],
                                [
                                    0.7003710213181529,
                                    0.03277877681150055,
                                    0.25491945697820234,
                                    0.01193074489214426,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7227773962799258,
                                    0.0338274403650617,
                                    0.23251308201642945,
                                    0.01088208133858311,
                                ],
                                [
                                    0.7159537413770131,
                                    0.03523848521423444,
                                    0.23713618159231892,
                                    0.011671591816433574,
                                ],
                                [
                                    0.7383085022288354,
                                    0.036338762877746046,
                                    0.21478142074049653,
                                    0.01057131415292197,
                                ],
                                [
                                    0.4806550020302868,
                                    0.023657330359941463,
                                    0.4724349209390451,
                                    0.023252746670726555,
                                ],
                                [
                                    0.46157855398361947,
                                    0.13014340055064466,
                                    0.3184813211767019,
                                    0.0897967242890339,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.5515839470690239,
                                    0.1555206799388194,
                                    0.22847592809129746,
                                    0.06441944490085914,
                                ],
                                [
                                    0.523447494058811,
                                    0.15703081073474184,
                                    0.24578716099403053,
                                    0.0737345342124166,
                                ],
                                [
                                    0.6122038443180997,
                                    0.18365713294903238,
                                    0.15703081073474184,
                                    0.047108211998126086,
                                ],
                                [
                                    0.40093565008263216,
                                    0.1202780620779184,
                                    0.36829900497020934,
                                    0.11048728286924005,
                                ],
                                [
                                    0.20132987799400748,
                                    0.18328744953241338,
                                    0.32212516052132656,
                                    0.2932575119522526,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.33219363762284093,
                                    0.3024236899035798,
                                    0.1912614008924931,
                                    0.17412127158108615,
                                ],
                                [
                                    0.2884629956448156,
                                    0.2884629956448156,
                                    0.2115370043551844,
                                    0.2115370043551844,
                                ],
                                [
                                    0.4134629956448156,
                                    0.4134629956448156,
                                    0.08653700435518441,
                                    0.08653700435518441,
                                ],
                                [
                                    0.2729819084895613,
                                    0.2729819084895613,
                                    0.2270180915104387,
                                    0.2270180915104387,
                                ],
                                [
                                    0.0473692999679328,
                                    0.1301434005506447,
                                    0.2194809019024139,
                                    0.6030063975790086,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.15000451146119143,
                                    0.4121255165838068,
                                    0.11684569040915527,
                                    0.3210242815458465,
                                ],
                                [
                                    0.10923824004312434,
                                    0.3641354377425853,
                                    0.12152710490403416,
                                    0.4050992173102562,
                                ],
                                [
                                    0.19799459030241304,
                                    0.6599964150097172,
                                    0.03277075464474546,
                                    0.10923824004312427,
                                ],
                                [
                                    0.13170099502979066,
                                    0.439012926767904,
                                    0.09906434991736786,
                                    0.3302217282849375,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.0327787768115006,
                                    0.08831351862262532,
                                    0.8756016244541865,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.04696693826177129,
                                    0.46566288014608287,
                                    0.04465266047254162,
                                    0.4427175211196042,
                                ],
                                [
                                    0.018888800170547792,
                                    0.3837709558174672,
                                    0.028021276860120282,
                                    0.5693189671518648,
                                ],
                                [
                                    0.041243561022370215,
                                    0.8379611564503106,
                                    0.005666516008297855,
                                    0.1151287665190213,
                                ],
                                [
                                    0.027565079060954917,
                                    0.5600502225070618,
                                    0.019344997969713153,
                                    0.39303970046227,
                                ],
                                [
                                    0.4552388641864047,
                                    0.021306097298261252,
                                    0.5000516141099505,
                                    0.02340342440538356,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.4776452391481776,
                                    0.022354760851822406,
                                    0.4776452391481776,
                                    0.022354760851822406,
                                ],
                                [
                                    0.46536758105875475,
                                    0.022904899683578207,
                                    0.4877223419105772,
                                    0.02400517734708981,
                                ],
                                [
                                    0.4877223419105772,
                                    0.02400517734708981,
                                    0.46536758105875475,
                                    0.022904899683578207,
                                ],
                                [
                                    0.486673678357016,
                                    0.023953563237139357,
                                    0.4664162446123159,
                                    0.02295651379352866,
                                ],
                                [
                                    0.3000245444947562,
                                    0.08459278303166452,
                                    0.4800353306655652,
                                    0.13534734180801405,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.3900299375801607,
                                    0.10997006241983928,
                                    0.3900299375801607,
                                    0.10997006241983928,
                                ],
                                [
                                    0.34023915239677643,
                                    0.10206951136643398,
                                    0.42899550265606506,
                                    0.12869583358072448,
                                ],
                                [
                                    0.4289955026560652,
                                    0.1286958335807245,
                                    0.3402391523967764,
                                    0.10206951136643397,
                                ],
                                [
                                    0.42483193542844094,
                                    0.12744679075460874,
                                    0.34440271962440056,
                                    0.10331855419254972,
                                ],
                                [
                                    0.1308637596288335,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.3574087211134995,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [0.1875, 0.1875, 0.3125, 0.3125],
                                [0.3125, 0.3125, 0.1875, 0.1875],
                                [
                                    0.3066362403711665,
                                    0.3066362403711665,
                                    0.1933637596288335,
                                    0.1933637596288335,
                                ],
                                [
                                    0.030789889441914717,
                                    0.08459278303166454,
                                    0.23606031242843198,
                                    0.6485570150979888,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.13342510093517335,
                                    0.36657489906482665,
                                    0.13342510093517335,
                                    0.36657489906482665,
                                ],
                                [
                                    0.07100449734393491,
                                    0.23668683889285477,
                                    0.1597608476032236,
                                    0.5325478161599867,
                                ],
                                [
                                    0.1597608476032236,
                                    0.5325478161599867,
                                    0.0710044973439349,
                                    0.23668683889285475,
                                ],
                                [
                                    0.15559728037559942,
                                    0.5186689549260168,
                                    0.07516806457155908,
                                    0.25056570012682466,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                    0.08947065751724015,
                                    0.8870743039674258,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.045809799367156456,
                                    0.45419020063284354,
                                    0.045809799367156456,
                                    0.45419020063284354,
                                ],
                                [
                                    0.012277658089422822,
                                    0.2494498611682442,
                                    0.034632418941245253,
                                    0.7036400618010877,
                                ],
                                [
                                    0.034632418941245253,
                                    0.7036400618010877,
                                    0.012277658089422822,
                                    0.2494498611682442,
                                ],
                                [
                                    0.0335837553876841,
                                    0.6823339645028265,
                                    0.013326321642983974,
                                    0.27075595846650546,
                                ],
                                [
                                    0.21010670705465664,
                                    0.009833417785021961,
                                    0.7451837712416985,
                                    0.03487610391862285,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.23251308201642953,
                                    0.010882081338583113,
                                    0.7227773962799257,
                                    0.033827440365061696,
                                ],
                                [
                                    0.21478142074049658,
                                    0.010571314152921974,
                                    0.7383085022288354,
                                    0.036338762877746046,
                                ],
                                [
                                    0.237136181592319,
                                    0.011671591816433577,
                                    0.715953741377013,
                                    0.03523848521423444,
                                ],
                                [
                                    0.49269235468374517,
                                    0.024249796114337252,
                                    0.46039756828558676,
                                    0.022660280916330766,
                                ],
                                [
                                    0.13847053500589307,
                                    0.039042165512684406,
                                    0.6415893401544284,
                                    0.18089795932699415,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.22847592809129755,
                                    0.06441944490085917,
                                    0.5515839470690238,
                                    0.1555206799388194,
                                ],
                                [
                                    0.15703081073474187,
                                    0.0471082119981261,
                                    0.6122038443180996,
                                    0.18365713294903235,
                                ],
                                [
                                    0.2457871609940306,
                                    0.07373453421241662,
                                    0.5234474940588109,
                                    0.15703081073474182,
                                ],
                                [
                                    0.44872822077424973,
                                    0.13461551943129904,
                                    0.3205064342785918,
                                    0.0961498255158594,
                                ],
                                [
                                    0.060397641263659596,
                                    0.054985031209919655,
                                    0.46305739725167444,
                                    0.4215599302747463,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.1912614008924931,
                                    0.17412127158108615,
                                    0.33219363762284093,
                                    0.3024236899035798,
                                ],
                                [
                                    0.08653700435518441,
                                    0.08653700435518441,
                                    0.4134629956448156,
                                    0.4134629956448156,
                                ],
                                [
                                    0.2115370043551844,
                                    0.2115370043551844,
                                    0.2884629956448156,
                                    0.2884629956448156,
                                ],
                                [
                                    0.3402905722527717,
                                    0.3402905722527717,
                                    0.15970942774722832,
                                    0.15970942774722832,
                                ],
                                [
                                    0.014210478915896638,
                                    0.039042165512684385,
                                    0.25263972295445003,
                                    0.694107632616969,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.11684569040915527,
                                    0.3210242815458465,
                                    0.15000451146119143,
                                    0.4121255165838068,
                                ],
                                [
                                    0.032770754644745465,
                                    0.1092382400431243,
                                    0.19799459030241304,
                                    0.6599964150097172,
                                ],
                                [
                                    0.12152710490403419,
                                    0.40509921731025633,
                                    0.10923824004312431,
                                    0.36413543774258517,
                                ],
                                [
                                    0.1794935657214082,
                                    0.5983249830841297,
                                    0.051271779225750304,
                                    0.1709096719687118,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.00983341778502196,
                                    0.09062779641185499,
                                    0.8985469834806651,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.04465266047254162,
                                    0.4427175211196042,
                                    0.04696693826177129,
                                    0.46566288014608287,
                                ],
                                [
                                    0.005666516008297856,
                                    0.11512876651902133,
                                    0.041243561022370215,
                                    0.8379611564503106,
                                ],
                                [
                                    0.02802127686012029,
                                    0.5693189671518649,
                                    0.018888800170547785,
                                    0.38377095581746706,
                                ],
                                [
                                    0.03960243171441328,
                                    0.804617706498591,
                                    0.007307645316254797,
                                    0.14847221647074096,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.06511695533444903,
                                    0.0030476048845298398,
                                    0.8901735229619061,
                                    0.04166191681911497,
                                ],
                                [
                                    0.0436608581500837,
                                    0.0021489412170727566,
                                    0.9094290648192482,
                                    0.04476113581359526,
                                ],
                                [
                                    0.06601561900190613,
                                    0.0032492188805843614,
                                    0.8870743039674258,
                                    0.04366085815008366,
                                ],
                                [
                                    0.4968023952293661,
                                    0.024452087958944706,
                                    0.45628752773996584,
                                    0.022457989071723312,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.11815374207208472,
                                    0.033313787324682716,
                                    0.6619061330882366,
                                    0.18662633751499585,
                                ],
                                [
                                    0.031921289695563994,
                                    0.009576177281364137,
                                    0.7373133653572775,
                                    0.2211891676657943,
                                ],
                                [
                                    0.12067763995485271,
                                    0.036202499495654655,
                                    0.6485570150979888,
                                    0.1945628454515038,
                                ],
                                [
                                    0.465046543330461,
                                    0.1395109090356382,
                                    0.3041881117223804,
                                    0.09125443591152023,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.14314141771825634,
                                    0.1303136207970777,
                                    0.3803136207970777,
                                    0.34623134068758826,
                                ],
                                [
                                    0.017591278886500528,
                                    0.017591278886500528,
                                    0.4824087211134995,
                                    0.4824087211134995,
                                ],
                                [
                                    0.14259127888650053,
                                    0.14259127888650053,
                                    0.3574087211134995,
                                    0.3574087211134995,
                                ],
                                [
                                    0.363272480742333,
                                    0.363272480742333,
                                    0.13672751925766702,
                                    0.13672751925766702,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.10552392366423057,
                                    0.28991862396967005,
                                    0.1613262782061161,
                                    0.44323117415998325,
                                ],
                                [
                                    0.006661652879855703,
                                    0.022205995689218275,
                                    0.2241036920673028,
                                    0.7470286593636232,
                                ],
                                [
                                    0.09541800313914443,
                                    0.3180669729563503,
                                    0.13534734180801408,
                                    0.4511676820964912,
                                ],
                                [
                                    0.19581188827761958,
                                    0.6527205823256129,
                                    0.03495345666953891,
                                    0.11651407272722854,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.0019989413309687114,
                                    0.09141798473825839,
                                    0.9063814599347184,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.04386247214613822,
                                    0.434883044665551,
                                    0.04775712658817469,
                                    0.4734973566001361,
                                ],
                                [
                                    0.0011518917734620597,
                                    0.023403424405383594,
                                    0.04575818525720601,
                                    0.9296864985639484,
                                ],
                                [
                                    0.02350665262528449,
                                    0.4775936250382271,
                                    0.023403424405383583,
                                    0.4754962979311048,
                                ],
                                [
                                    0.04371247226003416,
                                    0.888122967520987,
                                    0.003197604770633912,
                                    0.06496695544834497,
                                ],
                                [
                                    0.9063814599347185,
                                    0.0019989413309686862,
                                    0.09141798473825831,
                                    0.00020161399605452077,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9423869101337794,
                                    0.002078348055095878,
                                    0.05541253453919737,
                                    0.00012220727192732887,
                                ],
                                [
                                    0.8756016244541865,
                                    0.04309618500986461,
                                    0.07748829851514534,
                                    0.0038138920208034043,
                                ],
                                [
                                    0.9099937379594674,
                                    0.044788928427772004,
                                    0.043096185009864604,
                                    0.002121148602896015,
                                ],
                                [
                                    0.18877468472195827,
                                    0.009291290137826877,
                                    0.7643152382473737,
                                    0.03761878689284114,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9008043766567361,
                                    0.009858121991494696,
                                    0.088370403235784,
                                    0.0009670981159851826,
                                ],
                                [
                                    0.6030063975790086,
                                    0.18089795932699418,
                                    0.16622825747383277,
                                    0.04986738562016427,
                                ],
                                [
                                    0.739555318529915,
                                    0.22186173889466534,
                                    0.02967933652292653,
                                    0.008903606052493122,
                                ],
                                [
                                    0.05377482036819442,
                                    0.01613209297088341,
                                    0.715459834684647,
                                    0.21463325197627503,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.8409636943543785,
                                    0.020198594656708237,
                                    0.13558126713028748,
                                    0.0032564438586257724,
                                ],
                                [
                                    0.2932575119522527,
                                    0.2932575119522527,
                                    0.20674248804774734,
                                    0.20674248804774734,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    -0.058883562828037084,
                                    -0.058883562828037084,
                                    0.5588835628280371,
                                    0.5588835628280371,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.7823733693697565,
                                    0.02928871000418609,
                                    0.1815417737070553,
                                    0.006796146919002042,
                                ],
                                [
                                    0.08979672428903399,
                                    0.2993289666139739,
                                    0.14096862065812452,
                                    0.4699056884388676,
                                ],
                                [
                                    0.22634564523994025,
                                    0.7545020001973315,
                                    0.00441969970721827,
                                    0.014732654855509982,
                                ],
                                [
                                    -0.07048523572180201,
                                    -0.23495592892942405,
                                    0.30125058066896054,
                                    1.0041905839822656,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.7430816016908289,
                                    0.03477771814246924,
                                    0.21220887660552623,
                                    0.009931803561175576,
                                ],
                                [
                                    0.011930744892144286,
                                    0.24240149345281525,
                                    0.03497933213852379,
                                    0.7106884295165167,
                                ],
                                [
                                    0.04632285839742507,
                                    0.9411591780771876,
                                    0.0005872186332430102,
                                    0.011930744892144263,
                                ],
                                [
                                    -0.020340220010240495,
                                    -0.4132600061616929,
                                    0.06725029704090857,
                                    1.3663499291310248,
                                ],
                                [
                                    0.7315364614358733,
                                    0.0016133366937801977,
                                    0.26626298323710357,
                                    0.0005872186332430093,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7675419116349341,
                                    0.0016927434179073895,
                                    0.2302575330380426,
                                    0.0005078119091158174,
                                ],
                                [
                                    0.7066941925608805,
                                    0.03478274002402118,
                                    0.24639573040845136,
                                    0.01212733700664684,
                                ],
                                [
                                    0.7410863060661613,
                                    0.03647548344192857,
                                    0.2120036169031706,
                                    0.010434593588739449,
                                ],
                                [
                                    0.195097855964686,
                                    0.009602509932440117,
                                    0.7579920670046459,
                                    0.037307567098227905,
                                ],
                                [
                                    0.5853164341340025,
                                    0.006405520400261611,
                                    0.4038583457585176,
                                    0.004419699707218268,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317926,
                                    0.2825508626240855,
                                    0.08476340327397917,
                                ],
                                [
                                    0.6232327133796622,
                                    0.1869657212408504,
                                    0.14600194167317926,
                                    0.043799623706308036,
                                ],
                                [
                                    0.07888005881333099,
                                    0.023663499638169654,
                                    0.6903545962395105,
                                    0.20710184530898879,
                                ],
                                [
                                    0.3755961132956238,
                                    0.009021214230797037,
                                    0.6009488481890422,
                                    0.014433824284536972,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7511922265912474,
                                    0.018042428461594068,
                                    0.22535273489341853,
                                    0.0054126100537399404,
                                ],
                                [
                                    0.2366868388928548,
                                    0.2366868388928548,
                                    0.2633131611071452,
                                    0.2633131611071452,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    -0.02352660192918976,
                                    -0.02352660192918976,
                                    0.5235266019291898,
                                    0.5235266019291898,
                                ],
                                [
                                    0.17110718011831585,
                                    0.0064055204002616125,
                                    0.792807962958496,
                                    0.029679336522926522,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.7414769325849017,
                                    0.027757722467939765,
                                    0.22243821049191012,
                                    0.00832713445524837,
                                ],
                                [
                                    0.07247453841306935,
                                    0.24158708305641444,
                                    0.15829080653408914,
                                    0.5276475719964271,
                                ],
                                [
                                    0.20902345936397562,
                                    0.6967601166397722,
                                    0.02174188558318288,
                                    0.07247453841306932,
                                ],
                                [
                                    -0.045379997276665446,
                                    -0.15126996889159403,
                                    0.276145342223824,
                                    0.9205046239444356,
                                ],
                                [
                                    0.03447152022940799,
                                    0.0016133366937802001,
                                    0.9208189580669471,
                                    0.04309618500986461,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.7348425415475607,
                                    0.03439211350528075,
                                    0.22044793674879443,
                                    0.010317408198364065,
                                ],
                                [
                                    0.009629251354415341,
                                    0.19564117163210187,
                                    0.03728082567625273,
                                    0.7574487513372301,
                                ],
                                [
                                    0.04402136485969613,
                                    0.8943988562564745,
                                    0.0028887121709719452,
                                    0.058691066712857475,
                                ],
                                [
                                    -0.014017048767512735,
                                    -0.2847897248463721,
                                    0.06092712579818081,
                                    1.2378796478157041,
                                ],
                                [
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                    0.522303146741872,
                                    0.0011518917734620563,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5115017481301658,
                                    0.0011280702776883427,
                                    0.48629769654281096,
                                    0.0010724850493348643,
                                ],
                                [
                                    0.45934890473202555,
                                    0.022608666806380313,
                                    0.4937410182373064,
                                    0.024301410224287705,
                                ],
                                [
                                    0.4937410182373064,
                                    0.024301410224287705,
                                    0.45934890473202555,
                                    0.022608666806380313,
                                ],
                                [
                                    0.2043574047808184,
                                    0.010058255122653377,
                                    0.7487325181885135,
                                    0.03685182190801464,
                                ],
                                [
                                    0.3804537602987966,
                                    0.004163567227624184,
                                    0.6087210195937236,
                                    0.006661652879855695,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5560448467623872,
                                    0.006085181282610942,
                                    0.43312993313013287,
                                    0.004740038824868936,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974364,
                                    0.4528917880018739,
                                    0.1358645622574148,
                                ],
                                [
                                    0.4528917880018739,
                                    0.1358645622574148,
                                    0.31634286705096765,
                                    0.09490078268974365,
                                ],
                                [
                                    0.11564376044338598,
                                    0.03469236869973224,
                                    0.6535908946094555,
                                    0.1960729762474262,
                                ],
                                [
                                    0.2441362403711665,
                                    0.005863759628833502,
                                    0.7324087211134995,
                                    0.017591278886500507,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.6197323536667902,
                                    0.014884973859630536,
                                    0.35681260781787577,
                                    0.008570064655703473,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.02824955482277114,
                                    0.02824955482277114,
                                    0.47175044517722886,
                                    0.47175044517722886,
                                ],
                                [
                                    0.11121910524595506,
                                    0.004163567227624185,
                                    0.8526960378308568,
                                    0.03192128969556395,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.6815888577125409,
                                    0.02551576929530234,
                                    0.2823262853642709,
                                    0.010569087627885798,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.18365713294903238,
                                    0.6122038443180996,
                                    0.047108211998126114,
                                    0.15703081073474187,
                                ],
                                [
                                    -0.008616295646610457,
                                    -0.028721614205423213,
                                    0.23938164059376896,
                                    0.7979562692582647,
                                ],
                                [
                                    0.022406374961772883,
                                    0.001048663553561152,
                                    0.9328841033345823,
                                    0.04366085815008366,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.7227773962799257,
                                    0.033827440365061696,
                                    0.23251308201642953,
                                    0.010882081338583113,
                                ],
                                [
                                    0.006258981762693645,
                                    0.1271661191724797,
                                    0.04065109526797443,
                                    0.8259238037968523,
                                ],
                                [
                                    0.04065109526797443,
                                    0.8259238037968523,
                                    0.006258981762693645,
                                    0.1271661191724797,
                                ],
                                [
                                    -0.004757499951380294,
                                    -0.09665994066100704,
                                    0.051667576982048366,
                                    1.049749863630339,
                                ],
                                [
                                    0.21945613442633652,
                                    0.00048399041334210393,
                                    0.7783433102466403,
                                    0.001716564913681103,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25546158462539753,
                                    0.000563397137469296,
                                    0.7423378600475793,
                                    0.001637158189553911,
                                ],
                                [
                                    0.21200361690317068,
                                    0.010434593588739452,
                                    0.7410863060661612,
                                    0.036475483441928566,
                                ],
                                [
                                    0.24639573040845147,
                                    0.012127337006646845,
                                    0.7066941925608804,
                                    0.03478274002402117,
                                ],
                                [
                                    0.21361695359695088,
                                    0.010514000312866643,
                                    0.739472969372381,
                                    0.03639607671780137,
                                ],
                                [
                                    0.17559108646359073,
                                    0.001921614054986759,
                                    0.8135836934289294,
                                    0.00890360605249312,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.35118217292718135,
                                    0.0038432281099735166,
                                    0.6379926069653388,
                                    0.006981991997506362,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630804,
                                    0.6232327133796622,
                                    0.1869657212408504,
                                ],
                                [
                                    0.2825508626240855,
                                    0.08476340327397917,
                                    0.486683792428756,
                                    0.14600194167317926,
                                ],
                                [
                                    0.15240746207344089,
                                    0.045721237761294796,
                                    0.6168271929794006,
                                    0.18504410718586364,
                                ],
                                [
                                    0.11267636744670928,
                                    0.0027063050268699707,
                                    0.8638685940379567,
                                    0.02074873348846404,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.08002571157473193,
                                    0.08002571157473193,
                                    0.41997428842526807,
                                    0.41997428842526807,
                                ],
                                [
                                    0.05133103037359426,
                                    0.0019216140549867579,
                                    0.9125841127032176,
                                    0.034163242868201375,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.62170078284018,
                                    0.02327381612266491,
                                    0.34221436023663165,
                                    0.012811040800523223,
                                ],
                                [
                                    0.021741885583182876,
                                    0.0724745384130693,
                                    0.20902345936397562,
                                    0.6967601166397722,
                                ],
                                [
                                    0.15829080653408914,
                                    0.5276475719964271,
                                    0.07247453841306933,
                                    0.2415870830564144,
                                ],
                                [
                                    0.028147405983444507,
                                    0.09382674048074752,
                                    0.202617938963714,
                                    0.6754079145720939,
                                ],
                                [
                                    0.010341229694137779,
                                    0.00048399041334210404,
                                    0.9449492486022174,
                                    0.044225531290302704,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.7107122510122905,
                                    0.03326276722484265,
                                    0.24457822728406464,
                                    0.011446754478802161,
                                ],
                                [
                                    0.0028887121709719483,
                                    0.05869106671285754,
                                    0.04402136485969613,
                                    0.8943988562564744,
                                ],
                                [
                                    0.03728082567625273,
                                    0.7574487513372301,
                                    0.009629251354415343,
                                    0.19564117163210193,
                                ],
                                [
                                    0.0045020488647521464,
                                    0.09146984352435805,
                                    0.04240802816591593,
                                    0.8616200794449739,
                                ],
                                [
                                    0.04461113592749122,
                                    9.838577615361534e-05,
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08061658612655222,
                                    0.00017779250028080736,
                                    0.9171828585464246,
                                    0.0020227628267424,
                                ],
                                [
                                    0.04309618500986468,
                                    0.002121148602896019,
                                    0.9099937379594673,
                                    0.044788928427772,
                                ],
                                [
                                    0.07748829851514548,
                                    0.003813892020803411,
                                    0.8756016244541864,
                                    0.043096185009864604,
                                ],
                                [
                                    0.21994012483967862,
                                    0.010825220107479883,
                                    0.7331497981296533,
                                    0.036084856923188136,
                                ],
                                [
                                    0.03569423040444776,
                                    0.00039062651874043134,
                                    0.9534805494880724,
                                    0.010434593588739449,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.21128531686803836,
                                    0.002312240573727189,
                                    0.7778894630244817,
                                    0.00851297953375269,
                                ],
                                [
                                    0.02967933652292658,
                                    0.008903606052493138,
                                    0.739555318529915,
                                    0.22186173889466532,
                                ],
                                [
                                    0.1662282574738328,
                                    0.049867385620164274,
                                    0.6030063975790086,
                                    0.18089795932699418,
                                ],
                                [
                                    0.17751270051857745,
                                    0.05325264442858104,
                                    0.591721954534264,
                                    0.1775127005185774,
                                ],
                                [
                                    0.022904899683578235,
                                    0.0005501388317558024,
                                    0.9536400618010877,
                                    0.022904899683578207,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.39850101297920193,
                                    0.009571353062552836,
                                    0.578043948505464,
                                    0.013883685452781173,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.11538267247357925,
                                    0.11538267247357925,
                                    0.38461732752642075,
                                    0.38461732752642075,
                                ],
                                [
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                    0.9534805494880724,
                                    0.035694230404447705,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.5808043460553253,
                                    0.021742828586418583,
                                    0.38311079702148654,
                                    0.014342028336769553,
                                ],
                                [
                                    0.004419699707218267,
                                    0.01473265485550997,
                                    0.22634564523994025,
                                    0.7545020001973315,
                                ],
                                [
                                    0.14096862065812457,
                                    0.4699056884388678,
                                    0.08979672428903394,
                                    0.29932896661397373,
                                ],
                                [
                                    0.053252644428581054,
                                    0.17751270051857745,
                                    0.17751270051857745,
                                    0.591721954534264,
                                ],
                                [
                                    0.0021021695508696182,
                                    9.838577615361652e-05,
                                    0.9531883087454855,
                                    0.04461113592749119,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.7024731908690224,
                                    0.03287716258765416,
                                    0.2528172874273328,
                                    0.011832359115990648,
                                ],
                                [
                                    0.0005872186332430094,
                                    0.011930744892144246,
                                    0.04632285839742507,
                                    0.9411591780771876,
                                ],
                                [
                                    0.0349793321385238,
                                    0.7106884295165169,
                                    0.011930744892144277,
                                    0.24240149345281511,
                                ],
                                [
                                    0.010825220107479895,
                                    0.21994012483967862,
                                    0.03608485692318818,
                                    0.7331497981296533,
                                ],
                                [
                                    0.8985469834806652,
                                    0.009833417785021958,
                                    0.09062779641185491,
                                    0.0009918023224579212,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9342412138851129,
                                    0.010224044303762388,
                                    0.0549335660074072,
                                    0.0006011758037174906,
                                ],
                                [
                                    0.8756016244541865,
                                    0.04309618500986461,
                                    0.07748829851514534,
                                    0.0038138920208034043,
                                ],
                                [
                                    0.9099937379594674,
                                    0.044788928427772004,
                                    0.043096185009864604,
                                    0.002121148602896015,
                                ],
                                [
                                    0.195097855964686,
                                    0.009602509932440117,
                                    0.7579920670046459,
                                    0.037307567098227905,
                                ],
                                [
                                    0.6941076326169691,
                                    0.03904216551268439,
                                    0.25263972295445,
                                    0.014210478915896635,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.8621673124132734,
                                    0.04849518623495738,
                                    0.08458004315814555,
                                    0.004757458193623641,
                                ],
                                [
                                    0.6030063975790086,
                                    0.18089795932699418,
                                    0.16622825747383277,
                                    0.04986738562016427,
                                ],
                                [
                                    0.739555318529915,
                                    0.22186173889466534,
                                    0.02967933652292653,
                                    0.008903606052493122,
                                ],
                                [
                                    0.07888005881333099,
                                    0.023663499638169654,
                                    0.6903545962395105,
                                    0.20710184530898879,
                                ],
                                [
                                    0.4215599302747463,
                                    0.05498503120991964,
                                    0.46305739725167444,
                                    0.06039764126365958,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.7617990826715227,
                                    0.09936320633956398,
                                    0.12281824485489802,
                                    0.01601946613401523,
                                ],
                                [
                                    0.2932575119522527,
                                    0.2932575119522527,
                                    0.20674248804774734,
                                    0.20674248804774734,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    -0.02352660192918976,
                                    -0.02352660192918976,
                                    0.5235266019291898,
                                    0.5235266019291898,
                                ],
                                [
                                    0.18089795932699423,
                                    0.0390421655126844,
                                    0.6415893401544284,
                                    0.13847053500589301,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.6675817517557502,
                                    0.14408032761819248,
                                    0.15490554772567242,
                                    0.033432372900384914,
                                ],
                                [
                                    0.08979672428903399,
                                    0.2993289666139739,
                                    0.14096862065812452,
                                    0.4699056884388676,
                                ],
                                [
                                    0.22634564523994025,
                                    0.7545020001973315,
                                    0.00441969970721827,
                                    0.014732654855509982,
                                ],
                                [
                                    -0.045379997276665446,
                                    -0.15126996889159403,
                                    0.276145342223824,
                                    0.9205046239444356,
                                ],
                                [
                                    0.03487610391862287,
                                    0.009833417785021965,
                                    0.7451837712416985,
                                    0.2101067070546566,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.606776843921455,
                                    0.17108247591184306,
                                    0.17328303123886632,
                                    0.048857648927835506,
                                ],
                                [
                                    0.011930744892144286,
                                    0.24240149345281525,
                                    0.03497933213852379,
                                    0.7106884295165167,
                                ],
                                [
                                    0.04632285839742507,
                                    0.9411591780771876,
                                    0.0005872186332430102,
                                    0.011930744892144263,
                                ],
                                [
                                    -0.014017048767512735,
                                    -0.2847897248463721,
                                    0.06092712579818081,
                                    1.2378796478157041,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7066941925608805,
                                    0.03478274002402118,
                                    0.24639573040845136,
                                    0.01212733700664684,
                                ],
                                [
                                    0.7410863060661613,
                                    0.03647548344192857,
                                    0.2120036169031706,
                                    0.010434593588739449,
                                ],
                                [
                                    0.20142102720741376,
                                    0.009913729727053355,
                                    0.7516688957619182,
                                    0.03699634730361466,
                                ],
                                [
                                    0.560211195688866,
                                    0.031510758845398154,
                                    0.386536159882553,
                                    0.02174188558318287,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317926,
                                    0.2825508626240855,
                                    0.08476340327397917,
                                ],
                                [
                                    0.6232327133796622,
                                    0.1869657212408504,
                                    0.14600194167317926,
                                    0.043799623706308036,
                                ],
                                [
                                    0.10398529725846747,
                                    0.03119490630545587,
                                    0.665249357794374,
                                    0.19957043864170257,
                                ],
                                [
                                    0.3402391523967765,
                                    0.044378175129644364,
                                    0.5443781751296443,
                                    0.07100449734393485,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286796,
                                    0.026626322214290517,
                                ],
                                [
                                    0.2366868388928548,
                                    0.2366868388928548,
                                    0.2633131611071452,
                                    0.2633131611071452,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.011830358969657617,
                                    0.011830358969657617,
                                    0.4881696410303424,
                                    0.4881696410303424,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.18980156537948736,
                                    0.04096377956767115,
                                ],
                                [
                                    0.07247453841306935,
                                    0.24158708305641444,
                                    0.15829080653408914,
                                    0.5276475719964271,
                                ],
                                [
                                    0.20902345936397562,
                                    0.6967601166397722,
                                    0.02174188558318288,
                                    0.07247453841306932,
                                ],
                                [
                                    -0.020274758831528874,
                                    -0.067584008853764,
                                    0.25104010377868735,
                                    0.8368186639066055,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080896,
                                    0.050754558776349525,
                                ],
                                [
                                    0.009629251354415341,
                                    0.19564117163210187,
                                    0.03728082567625273,
                                    0.7574487513372301,
                                ],
                                [
                                    0.04402136485969613,
                                    0.8943988562564745,
                                    0.0028887121709719452,
                                    0.058691066712857475,
                                ],
                                [
                                    -0.007693877524784997,
                                    -0.15631944353105176,
                                    0.05460395455545307,
                                    1.1094093665003837,
                                ],
                                [
                                    0.47138625738548395,
                                    0.005158704099182031,
                                    0.5177885225070362,
                                    0.005666516008297848,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5070804877899316,
                                    0.005549330617922462,
                                    0.4820942921025884,
                                    0.005275889489557417,
                                ],
                                [
                                    0.45934890473202555,
                                    0.022608666806380313,
                                    0.4937410182373064,
                                    0.024301410224287705,
                                ],
                                [
                                    0.4937410182373064,
                                    0.024301410224287705,
                                    0.45934890473202555,
                                    0.022608666806380313,
                                ],
                                [
                                    0.21068057602354612,
                                    0.010369474917266615,
                                    0.7424093469457858,
                                    0.036540602113401405,
                                ],
                                [
                                    0.36413543774258517,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.03277075464474545,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5321951175388896,
                                    0.029934910506108567,
                                    0.4145522380325294,
                                    0.02331773392247246,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974364,
                                    0.4528917880018739,
                                    0.1358645622574148,
                                ],
                                [
                                    0.4528917880018739,
                                    0.1358645622574148,
                                    0.31634286705096765,
                                    0.09490078268974365,
                                ],
                                [
                                    0.14074899888852246,
                                    0.042223775367018455,
                                    0.6284856561643191,
                                    0.18854156958013998,
                                ],
                                [
                                    0.2211543318816052,
                                    0.028845668118394806,
                                    0.6634629956448156,
                                    0.08653700435518441,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.5613934842783815,
                                    0.07322384324803916,
                                    0.32322384324803916,
                                    0.04215882922554007,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.0636065157216184,
                                    0.0636065157216184,
                                    0.4363934842783816,
                                    0.4363934842783816,
                                ],
                                [
                                    0.09490078268974368,
                                    0.020481889783835576,
                                    0.727586516791679,
                                    0.15703081073474182,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.5815845751184996,
                                    0.12552005188934365,
                                    0.240902724362923,
                                    0.051992648629233744,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.18365713294903238,
                                    0.6122038443180996,
                                    0.047108211998126114,
                                    0.15703081073474187,
                                ],
                                [
                                    0.01648894279852609,
                                    0.05496434583240672,
                                    0.21427640214863242,
                                    0.7142703092204348,
                                ],
                                [
                                    0.018296334416152,
                                    0.005158704099182037,
                                    0.7617635407441694,
                                    0.21478142074049653,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.5901970744189842,
                                    0.16640776222600312,
                                    0.1898628007413372,
                                    0.053532362613675444,
                                ],
                                [
                                    0.006258981762693645,
                                    0.1271661191724797,
                                    0.04065109526797443,
                                    0.8259238037968523,
                                ],
                                [
                                    0.04065109526797443,
                                    0.8259238037968523,
                                    0.006258981762693645,
                                    0.1271661191724797,
                                ],
                                [
                                    0.0015656712913474542,
                                    0.03181034065431352,
                                    0.045344405739320616,
                                    0.9212795823150184,
                                ],
                                [
                                    0.2175592245778225,
                                    0.0023809002618561236,
                                    0.7716155553146976,
                                    0.008444319845623756,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25325345498227025,
                                    0.002771526780596555,
                                    0.7359213249102499,
                                    0.008053693326883323,
                                ],
                                [
                                    0.21200361690317068,
                                    0.010434593588739452,
                                    0.7410863060661612,
                                    0.036475483441928566,
                                ],
                                [
                                    0.24639573040845147,
                                    0.012127337006646845,
                                    0.7066941925608804,
                                    0.03478274002402117,
                                ],
                                [
                                    0.21994012483967862,
                                    0.010825220107479883,
                                    0.7331497981296533,
                                    0.036084856923188136,
                                ],
                                [
                                    0.16805967979630448,
                                    0.009453020722272998,
                                    0.7786876757751144,
                                    0.04379962370630803,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.33611935959260886,
                                    0.01890604144454599,
                                    0.6106279959788101,
                                    0.03434660298403504,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630804,
                                    0.6232327133796622,
                                    0.1869657212408504,
                                ],
                                [
                                    0.2825508626240855,
                                    0.08476340327397917,
                                    0.486683792428756,
                                    0.14600194167317926,
                                ],
                                [
                                    0.17751270051857745,
                                    0.05325264442858104,
                                    0.591721954534264,
                                    0.1775127005185774,
                                ],
                                [
                                    0.10206951136643398,
                                    0.01331316110714526,
                                    0.7825478161599868,
                                    0.10206951136643397,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.11538267247357925,
                                    0.11538267247357925,
                                    0.38461732752642075,
                                    0.38461732752642075,
                                ],
                                [
                                    0.04379962370630803,
                                    0.009453020722272993,
                                    0.7786876757751146,
                                    0.1680596797963044,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.530483416135064,
                                    0.11449118282778108,
                                    0.29200388334635863,
                                    0.06302151769079632,
                                ],
                                [
                                    0.021741885583182876,
                                    0.0724745384130693,
                                    0.20902345936397562,
                                    0.6967601166397722,
                                ],
                                [
                                    0.15829080653408914,
                                    0.5276475719964271,
                                    0.07247453841306933,
                                    0.2415870830564144,
                                ],
                                [
                                    0.053252644428581054,
                                    0.17751270051857745,
                                    0.17751270051857745,
                                    0.591721954534264,
                                ],
                                [
                                    0.008444319845623757,
                                    0.002380900261856124,
                                    0.7716155553146976,
                                    0.21755922457782245,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.580345059848456,
                                    0.16362995838867722,
                                    0.19971481531186544,
                                    0.056310166451001356,
                                ],
                                [
                                    0.0028887121709719483,
                                    0.05869106671285754,
                                    0.04402136485969613,
                                    0.8943988562564744,
                                ],
                                [
                                    0.03728082567625273,
                                    0.7574487513372301,
                                    0.009629251354415343,
                                    0.19564117163210193,
                                ],
                                [
                                    0.010825220107479895,
                                    0.21994012483967862,
                                    0.03608485692318818,
                                    0.7331497981296533,
                                ],
                                [
                                    0.04422553129030273,
                                    0.00048399041334210415,
                                    0.9449492486022174,
                                    0.010341229694137775,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.0799197616947505,
                                    0.0008746169320825355,
                                    0.9092550181977697,
                                    0.009950603175397343,
                                ],
                                [
                                    0.04309618500986468,
                                    0.002121148602896019,
                                    0.9099937379594673,
                                    0.044788928427772,
                                ],
                                [
                                    0.07748829851514548,
                                    0.003813892020803411,
                                    0.8756016244541864,
                                    0.043096185009864604,
                                ],
                                [
                                    0.22626329608240636,
                                    0.01113643990209312,
                                    0.7268266268869256,
                                    0.0357736371285749,
                                ],
                                [
                                    0.03416324286820143,
                                    0.0019216140549867611,
                                    0.9125841127032176,
                                    0.051331030373594266,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2022229226645058,
                                    0.011374634777259753,
                                    0.7445244329069132,
                                    0.041878009651321275,
                                ],
                                [
                                    0.02967933652292658,
                                    0.008903606052493138,
                                    0.739555318529915,
                                    0.22186173889466532,
                                ],
                                [
                                    0.1662282574738328,
                                    0.049867385620164274,
                                    0.6030063975790086,
                                    0.18089795932699418,
                                ],
                                [
                                    0.20261793896371402,
                                    0.060784051095867285,
                                    0.5666167160891274,
                                    0.16998129385129115,
                                ],
                                [
                                    0.020748733488464063,
                                    0.0027063050268699733,
                                    0.8638685940379567,
                                    0.11267636744670925,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.36098788588524044,
                                    0.04708448015651433,
                                    0.5236294416411803,
                                    0.0682981923170649,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.15073963337242657,
                                    0.15073963337242657,
                                    0.3492603666275734,
                                    0.3492603666275734,
                                ],
                                [
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                    0.8135836934289296,
                                    0.17559108646359065,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.49558739848124905,
                                    0.10695977616049483,
                                    0.3268999010001736,
                                    0.07055292435808257,
                                ],
                                [
                                    0.004419699707218267,
                                    0.01473265485550997,
                                    0.22634564523994025,
                                    0.7545020001973315,
                                ],
                                [
                                    0.14096862065812457,
                                    0.4699056884388678,
                                    0.08979672428903394,
                                    0.29932896661397373,
                                ],
                                [
                                    0.0783578828737176,
                                    0.2611986605564074,
                                    0.1524074620734409,
                                    0.5080359944964341,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.00048399041334210995,
                                    0.7783433102466403,
                                    0.21945613442633646,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.5736173049165133,
                                    0.16173304854016318,
                                    0.20644257024380808,
                                    0.05820707629951537,
                                ],
                                [
                                    0.0005872186332430094,
                                    0.011930744892144246,
                                    0.04632285839742507,
                                    0.9411591780771876,
                                ],
                                [
                                    0.0349793321385238,
                                    0.7106884295165169,
                                    0.011930744892144277,
                                    0.24240149345281511,
                                ],
                                [
                                    0.017148391350207643,
                                    0.3484104061549992,
                                    0.02976168568046043,
                                    0.6046795168143327,
                                ],
                                [
                                    0.8870743039674259,
                                    0.021306097298261256,
                                    0.08947065751724008,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9223127891816603,
                                    0.02215246900721495,
                                    0.05423217230300563,
                                    0.0013025695081190596,
                                ],
                                [
                                    0.8756016244541865,
                                    0.04309618500986461,
                                    0.07748829851514534,
                                    0.0038138920208034043,
                                ],
                                [
                                    0.9099937379594674,
                                    0.044788928427772004,
                                    0.043096185009864604,
                                    0.002121148602896015,
                                ],
                                [
                                    0.2043574047808184,
                                    0.010058255122653377,
                                    0.7487325181885135,
                                    0.03685182190801464,
                                ],
                                [
                                    0.6485570150979889,
                                    0.08459278303166452,
                                    0.23606031242843187,
                                    0.030789889441914697,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.8055878258327307,
                                    0.10507467281550009,
                                    0.07902950169369005,
                                    0.010307999658079124,
                                ],
                                [
                                    0.6030063975790086,
                                    0.18089795932699418,
                                    0.16622825747383277,
                                    0.04986738562016427,
                                ],
                                [
                                    0.739555318529915,
                                    0.22186173889466534,
                                    0.02967933652292653,
                                    0.008903606052493122,
                                ],
                                [
                                    0.11564376044338598,
                                    0.03469236869973224,
                                    0.6535908946094555,
                                    0.1960729762474262,
                                ],
                                [
                                    0.3574087211134995,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.1308637596288335,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.645871716758315,
                                    0.21529057225277168,
                                    0.10412828324168494,
                                    0.034709427747228315,
                                ],
                                [
                                    0.2932575119522527,
                                    0.2932575119522527,
                                    0.20674248804774734,
                                    0.20674248804774734,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.028249554822771084,
                                    0.028249554822771084,
                                    0.4717504451772289,
                                    0.4717504451772289,
                                ],
                                [
                                    0.13534734180801408,
                                    0.08459278303166454,
                                    0.4800353306655652,
                                    0.3000245444947562,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.4994827795505992,
                                    0.3121792998233434,
                                    0.11589989292298,
                                    0.07243802770307733,
                                ],
                                [
                                    0.08979672428903399,
                                    0.2993289666139739,
                                    0.14096862065812452,
                                    0.4699056884388676,
                                ],
                                [
                                    0.22634564523994025,
                                    0.7545020001973315,
                                    0.00441969970721827,
                                    0.014732654855509982,
                                ],
                                [
                                    -0.008616295646610457,
                                    -0.028721614205423213,
                                    0.23938164059376896,
                                    0.7979562692582647,
                                ],
                                [
                                    0.023403424405383573,
                                    0.021306097298261266,
                                    0.5000516141099505,
                                    0.4552388641864047,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.40717438022285063,
                                    0.3706849396104475,
                                    0.11628065829248341,
                                    0.10586002187421842,
                                ],
                                [
                                    0.011930744892144286,
                                    0.24240149345281525,
                                    0.03497933213852379,
                                    0.7106884295165167,
                                ],
                                [
                                    0.04632285839742507,
                                    0.9411591780771876,
                                    0.0005872186332430102,
                                    0.011930744892144263,
                                ],
                                [
                                    -0.004757499951380294,
                                    -0.09665994066100704,
                                    0.051667576982048366,
                                    1.049749863630339,
                                ],
                                [
                                    0.7159537413770131,
                                    0.017196056752640375,
                                    0.26059122010765295,
                                    0.006258981762693634,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7511922265912474,
                                    0.018042428461594068,
                                    0.2253527348934185,
                                    0.00541261005373994,
                                ],
                                [
                                    0.7066941925608805,
                                    0.03478274002402118,
                                    0.24639573040845136,
                                    0.01212733700664684,
                                ],
                                [
                                    0.7410863060661613,
                                    0.03647548344192857,
                                    0.2120036169031706,
                                    0.010434593588739449,
                                ],
                                [
                                    0.21068057602354612,
                                    0.010369474917266615,
                                    0.7424093469457858,
                                    0.036540602113401405,
                                ],
                                [
                                    0.523447494058811,
                                    0.06827446047545313,
                                    0.3611698334676098,
                                    0.047108211998126086,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317926,
                                    0.2825508626240855,
                                    0.08476340327397917,
                                ],
                                [
                                    0.6232327133796622,
                                    0.1869657212408504,
                                    0.14600194167317926,
                                    0.043799623706308036,
                                ],
                                [
                                    0.14074899888852246,
                                    0.042223775367018455,
                                    0.6284856561643191,
                                    0.18854156958013998,
                                ],
                                [
                                    0.28846299564481565,
                                    0.09615433188160522,
                                    0.46153700435518435,
                                    0.15384566811839478,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.5769259912896312,
                                    0.19230866376321037,
                                    0.17307400871036885,
                                    0.05769133623678962,
                                ],
                                [
                                    0.2366868388928548,
                                    0.2366868388928548,
                                    0.2633131611071452,
                                    0.2633131611071452,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.0636065157216184,
                                    0.0636065157216184,
                                    0.4363934842783816,
                                    0.4363934842783816,
                                ],
                                [
                                    0.10923824004312432,
                                    0.06827446047545316,
                                    0.5061444324304549,
                                    0.3163428670509676,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.4733736777857095,
                                    0.295860977267132,
                                    0.1420089946878698,
                                    0.08875635025928873,
                                ],
                                [
                                    0.07247453841306935,
                                    0.24158708305641444,
                                    0.15829080653408914,
                                    0.5276475719964271,
                                ],
                                [
                                    0.20902345936397562,
                                    0.6967601166397722,
                                    0.02174188558318288,
                                    0.07247453841306932,
                                ],
                                [
                                    0.016488942798526064,
                                    0.054964345832406634,
                                    0.21427640214863244,
                                    0.7142703092204349,
                                ],
                                [
                                    0.018888800170547792,
                                    0.0171960567526404,
                                    0.5045662383447862,
                                    0.45934890473202555,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.40265975598801484,
                                    0.36657489906482665,
                                    0.12079528252731919,
                                    0.10997006241983931,
                                ],
                                [
                                    0.009629251354415341,
                                    0.19564117163210187,
                                    0.03728082567625273,
                                    0.7574487513372301,
                                ],
                                [
                                    0.04402136485969613,
                                    0.8943988562564745,
                                    0.0028887121709719452,
                                    0.058691066712857475,
                                ],
                                [
                                    0.001565671291347449,
                                    0.031810340654313415,
                                    0.04534440573932062,
                                    0.9212795823150185,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5006060662729892,
                                    0.012023752134864897,
                                    0.4759388952116767,
                                    0.011431286380469112,
                                ],
                                [
                                    0.45934890473202555,
                                    0.022608666806380313,
                                    0.4937410182373064,
                                    0.024301410224287705,
                                ],
                                [
                                    0.4937410182373064,
                                    0.024301410224287705,
                                    0.45934890473202555,
                                    0.022608666806380313,
                                ],
                                [
                                    0.21994012483967862,
                                    0.010825220107479883,
                                    0.7331497981296533,
                                    0.036084856923188136,
                                ],
                                [
                                    0.3402391523967764,
                                    0.04437817512964435,
                                    0.5443781751296444,
                                    0.07100449734393487,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.49726996313151817,
                                    0.06486006491347993,
                                    0.3873473643949025,
                                    0.0505226075600993,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974364,
                                    0.4528917880018739,
                                    0.1358645622574148,
                                ],
                                [
                                    0.4528917880018739,
                                    0.1358645622574148,
                                    0.31634286705096765,
                                    0.09490078268974365,
                                ],
                                [
                                    0.17751270051857745,
                                    0.05325264442858104,
                                    0.591721954534264,
                                    0.1775127005185774,
                                ],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.4759629956448156,
                                    0.1586543318816052,
                                    0.2740370043551844,
                                    0.09134566811839481,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.11538267247357925,
                                    0.11538267247357925,
                                    0.38461732752642075,
                                    0.38461732752642075,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.43513993508652005,
                                    0.2719646919213232,
                                    0.1802427373870592,
                                    0.11265263560509751,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.18365713294903238,
                                    0.6122038443180996,
                                    0.047108211998126114,
                                    0.15703081073474187,
                                ],
                                [
                                    0.053252644428581054,
                                    0.17751270051857745,
                                    0.17751270051857745,
                                    0.591721954534264,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.3960486139068899,
                                    0.36055622273809745,
                                    0.12740642460844417,
                                    0.11598873874656848,
                                ],
                                [
                                    0.006258981762693645,
                                    0.1271661191724797,
                                    0.04065109526797443,
                                    0.8259238037968523,
                                ],
                                [
                                    0.04065109526797443,
                                    0.8259238037968523,
                                    0.006258981762693645,
                                    0.1271661191724797,
                                ],
                                [
                                    0.010825220107479895,
                                    0.21994012483967862,
                                    0.03608485692318818,
                                    0.7331497981296533,
                                ],
                                [
                                    0.21478142074049658,
                                    0.0051587040991820324,
                                    0.7617635407441694,
                                    0.01829633441615198,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25001990595473106,
                                    0.006005075808135728,
                                    0.7265250555299348,
                                    0.017449962707198282,
                                ],
                                [
                                    0.21200361690317068,
                                    0.010434593588739452,
                                    0.7410863060661612,
                                    0.036475483441928566,
                                ],
                                [
                                    0.24639573040845147,
                                    0.012127337006646845,
                                    0.7066941925608804,
                                    0.03478274002402117,
                                ],
                                [
                                    0.2291996736558111,
                                    0.011280965297693148,
                                    0.7238902493135209,
                                    0.03562911173297487,
                                ],
                                [
                                    0.1570308107347419,
                                    0.020481889783835583,
                                    0.7275865167916789,
                                    0.09490078268974364,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.3140616214694837,
                                    0.04096377956767115,
                                    0.5705557060569371,
                                    0.07441889290590807,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630804,
                                    0.6232327133796622,
                                    0.1869657212408504,
                                ],
                                [
                                    0.2825508626240855,
                                    0.08476340327397917,
                                    0.486683792428756,
                                    0.14600194167317926,
                                ],
                                [
                                    0.21427640214863244,
                                    0.06428151349014362,
                                    0.5549582529042091,
                                    0.1664838314570148,
                                ],
                                [
                                    0.08653700435518444,
                                    0.028845668118394813,
                                    0.6634629956448156,
                                    0.2211543318816052,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.1671588292255401,
                                    0.1671588292255401,
                                    0.3328411707744599,
                                    0.3328411707744599,
                                ],
                                [
                                    0.03277075464474545,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.36413543774258517,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.3969061923873306,
                                    0.24806840657551443,
                                    0.21847648008624862,
                                    0.1365489209509063,
                                ],
                                [
                                    0.021741885583182876,
                                    0.0724745384130693,
                                    0.20902345936397562,
                                    0.6967601166397722,
                                ],
                                [
                                    0.15829080653408914,
                                    0.5276475719964271,
                                    0.07247453841306933,
                                    0.2415870830564144,
                                ],
                                [
                                    0.09001634605863601,
                                    0.3000610552047482,
                                    0.1407489988885225,
                                    0.4691735998480933,
                                ],
                                [
                                    0.00566651600829785,
                                    0.0051587040991820324,
                                    0.5177885225070362,
                                    0.47138625738548395,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.3894374718257649,
                                    0.3545375464113683,
                                    0.13401756668956913,
                                    0.12200741507329767,
                                ],
                                [
                                    0.0028887121709719483,
                                    0.05869106671285754,
                                    0.04402136485969613,
                                    0.8943988562564744,
                                ],
                                [
                                    0.03728082567625273,
                                    0.7574487513372301,
                                    0.009629251354415343,
                                    0.19564117163210193,
                                ],
                                [
                                    0.020084768923612335,
                                    0.4080699090250437,
                                    0.02682530810705574,
                                    0.5450200139442882,
                                ],
                                [
                                    0.043660858150083685,
                                    0.0010486635535611516,
                                    0.9328841033345823,
                                    0.02240637496177286,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.07889934336431818,
                                    0.0018950352625148475,
                                    0.8976456181203478,
                                    0.021560003252819163,
                                ],
                                [
                                    0.04309618500986468,
                                    0.002121148602896019,
                                    0.9099937379594673,
                                    0.044788928427772,
                                ],
                                [
                                    0.07748829851514548,
                                    0.003813892020803411,
                                    0.8756016244541864,
                                    0.043096185009864604,
                                ],
                                [
                                    0.23552284489853884,
                                    0.011592185092306388,
                                    0.7175670780707931,
                                    0.03531789193836163,
                                ],
                                [
                                    0.031921289695564,
                                    0.004163567227624191,
                                    0.8526960378308568,
                                    0.11121910524595503,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.1889521004303058,
                                    0.02464545701145976,
                                    0.695665227096115,
                                    0.09073721546211946,
                                ],
                                [
                                    0.02967933652292658,
                                    0.008903606052493138,
                                    0.739555318529915,
                                    0.22186173889466532,
                                ],
                                [
                                    0.1662282574738328,
                                    0.049867385620164274,
                                    0.6030063975790086,
                                    0.18089795932699418,
                                ],
                                [
                                    0.23938164059376893,
                                    0.07181292015742984,
                                    0.5298530144590726,
                                    0.1589524247897286,
                                ],
                                [
                                    0.017591278886500528,
                                    0.005863759628833509,
                                    0.7324087211134995,
                                    0.2441362403711665,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.30605427453131606,
                                    0.1020180915104387,
                                    0.44394572546868394,
                                    0.1479819084895613,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.20251579012438736,
                                    0.20251579012438736,
                                    0.29748420987561264,
                                    0.29748420987561264,
                                ],
                                [
                                    0.006661652879855697,
                                    0.004163567227624186,
                                    0.6087210195937236,
                                    0.3804537602987966,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.3707970906224408,
                                    0.23175008401930305,
                                    0.2445855818511384,
                                    0.1528672435071177,
                                ],
                                [
                                    0.004419699707218267,
                                    0.01473265485550997,
                                    0.22634564523994025,
                                    0.7545020001973315,
                                ],
                                [
                                    0.14096862065812457,
                                    0.4699056884388678,
                                    0.08979672428903394,
                                    0.29932896661397373,
                                ],
                                [
                                    0.11512158450377256,
                                    0.3837470152425781,
                                    0.11564376044338594,
                                    0.3854876398102634,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.001048663553561164,
                                    0.522303146741872,
                                    0.4754962979311048,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.3849228475909291,
                                    0.35042750586574745,
                                    0.1385321909244049,
                                    0.12611745561891854,
                                ],
                                [
                                    0.0005872186332430094,
                                    0.011930744892144246,
                                    0.04632285839742507,
                                    0.9411591780771876,
                                ],
                                [
                                    0.0349793321385238,
                                    0.7106884295165169,
                                    0.011930744892144277,
                                    0.24240149345281511,
                                ],
                                [
                                    0.026407940166340085,
                                    0.5365401903403643,
                                    0.02050213686432799,
                                    0.4165497326289676,
                                ],
                                [
                                    0.8756016244541865,
                                    0.03277877681150055,
                                    0.08831351862262524,
                                    0.0033060801116875874,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9103843644782077,
                                    0.034080893710667505,
                                    0.05353077859860406,
                                    0.0020039632125206284,
                                ],
                                [
                                    0.8756016244541865,
                                    0.04309618500986461,
                                    0.07748829851514534,
                                    0.0038138920208034043,
                                ],
                                [
                                    0.9099937379594674,
                                    0.044788928427772004,
                                    0.043096185009864604,
                                    0.002121148602896015,
                                ],
                                [
                                    0.21361695359695088,
                                    0.010514000312866643,
                                    0.739472969372381,
                                    0.03639607671780137,
                                ],
                                [
                                    0.6030063975790088,
                                    0.13014340055064463,
                                    0.21948090190241384,
                                    0.04736929996793276,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.749008339252188,
                                    0.16165415939604277,
                                    0.07347896022923459,
                                    0.015858541122534608,
                                ],
                                [
                                    0.6030063975790086,
                                    0.18089795932699418,
                                    0.16622825747383277,
                                    0.04986738562016427,
                                ],
                                [
                                    0.739555318529915,
                                    0.22186173889466534,
                                    0.02967933652292653,
                                    0.008903606052493122,
                                ],
                                [
                                    0.15240746207344089,
                                    0.045721237761294796,
                                    0.6168271929794006,
                                    0.18504410718586364,
                                ],
                                [
                                    0.29325751195225264,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.20132987799400742,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.5299443508451074,
                                    0.33121793816597933,
                                    0.08543832162847187,
                                    0.0533993893604414,
                                ],
                                [
                                    0.2932575119522527,
                                    0.2932575119522527,
                                    0.20674248804774734,
                                    0.20674248804774734,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.08002571157473193,
                                    0.08002571157473193,
                                    0.41997428842526807,
                                    0.41997428842526807,
                                ],
                                [
                                    0.08979672428903396,
                                    0.13014340055064466,
                                    0.318481321176702,
                                    0.46157855398361936,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.33138380734544837,
                                    0.48027827202849427,
                                    0.07689423812028762,
                                    0.11144368250576972,
                                ],
                                [
                                    0.08979672428903399,
                                    0.2993289666139739,
                                    0.14096862065812452,
                                    0.4699056884388676,
                                ],
                                [
                                    0.22634564523994025,
                                    0.7545020001973315,
                                    0.00441969970721827,
                                    0.014732654855509982,
                                ],
                                [
                                    0.028147405983444507,
                                    0.09382674048074752,
                                    0.202617938963714,
                                    0.6754079145720939,
                                ],
                                [
                                    0.011930744892144272,
                                    0.032778776811500564,
                                    0.2549194569782024,
                                    0.7003710213181528,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.20757191652424617,
                                    0.5702874033090519,
                                    0.0592782853461005,
                                    0.16286239482060133,
                                ],
                                [
                                    0.011930744892144286,
                                    0.24240149345281525,
                                    0.03497933213852379,
                                    0.7106884295165167,
                                ],
                                [
                                    0.04632285839742507,
                                    0.9411591780771876,
                                    0.0005872186332430102,
                                    0.011930744892144263,
                                ],
                                [
                                    0.0045020488647521464,
                                    0.09146984352435805,
                                    0.04240802816591593,
                                    0.8616200794449739,
                                ],
                                [
                                    0.7066941925608806,
                                    0.026455605568772807,
                                    0.25722095051593125,
                                    0.009629251354415327,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7414769325849017,
                                    0.027757722467939765,
                                    0.22243821049191007,
                                    0.008327134455248368,
                                ],
                                [
                                    0.7066941925608805,
                                    0.03478274002402118,
                                    0.24639573040845136,
                                    0.01212733700664684,
                                ],
                                [
                                    0.7410863060661613,
                                    0.03647548344192857,
                                    0.2120036169031706,
                                    0.010434593588739449,
                                ],
                                [
                                    0.21994012483967862,
                                    0.010825220107479883,
                                    0.7331497981296533,
                                    0.036084856923188136,
                                ],
                                [
                                    0.48668379242875603,
                                    0.1050381621055081,
                                    0.3358035070526666,
                                    0.07247453841306929,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317926,
                                    0.2825508626240855,
                                    0.08476340327397917,
                                ],
                                [
                                    0.6232327133796622,
                                    0.1869657212408504,
                                    0.14600194167317926,
                                    0.043799623706308036,
                                ],
                                [
                                    0.17751270051857745,
                                    0.05325264442858104,
                                    0.591721954534264,
                                    0.1775127005185774,
                                ],
                                [
                                    0.2366868388928548,
                                    0.14793048863356606,
                                    0.37869583358072445,
                                    0.2366868388928547,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.4733736777857095,
                                    0.295860977267132,
                                    0.14200899468786976,
                                    0.08875635025928871,
                                ],
                                [
                                    0.2366868388928548,
                                    0.2366868388928548,
                                    0.2633131611071452,
                                    0.2633131611071452,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.11538267247357925,
                                    0.11538267247357925,
                                    0.38461732752642075,
                                    0.38461732752642075,
                                ],
                                [
                                    0.07247453841306935,
                                    0.10503816210550813,
                                    0.33580350705266665,
                                    0.48668379242875587,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.31406162146948374,
                                    0.45517303358335776,
                                    0.09421642399625223,
                                    0.1365489209509063,
                                ],
                                [
                                    0.07247453841306935,
                                    0.24158708305641444,
                                    0.15829080653408914,
                                    0.5276475719964271,
                                ],
                                [
                                    0.20902345936397562,
                                    0.6967601166397722,
                                    0.02174188558318288,
                                    0.07247453841306932,
                                ],
                                [
                                    0.053252644428581054,
                                    0.17751270051857745,
                                    0.17751270051857745,
                                    0.591721954534264,
                                ],
                                [
                                    0.009629251354415346,
                                    0.026455605568772845,
                                    0.25722095051593136,
                                    0.7066941925608805,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.20527042298651726,
                                    0.5639642320663243,
                                    0.061579778883829435,
                                    0.16918556606332907,
                                ],
                                [
                                    0.009629251354415341,
                                    0.19564117163210187,
                                    0.03728082567625273,
                                    0.7574487513372301,
                                ],
                                [
                                    0.04402136485969613,
                                    0.8943988562564745,
                                    0.0028887121709719452,
                                    0.058691066712857475,
                                ],
                                [
                                    0.010825220107479895,
                                    0.21994012483967862,
                                    0.03608485692318818,
                                    0.7331497981296533,
                                ],
                                [
                                    0.45934890473202555,
                                    0.01719605675264037,
                                    0.5045662383447862,
                                    0.018888800170547764,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.4941316447560468,
                                    0.018498173651807334,
                                    0.469783498320765,
                                    0.017586683271380802,
                                ],
                                [
                                    0.45934890473202555,
                                    0.022608666806380313,
                                    0.4937410182373064,
                                    0.024301410224287705,
                                ],
                                [
                                    0.4937410182373064,
                                    0.024301410224287705,
                                    0.45934890473202555,
                                    0.022608666806380313,
                                ],
                                [
                                    0.2291996736558111,
                                    0.011280965297693148,
                                    0.7238902493135209,
                                    0.03562911173297487,
                                ],
                                [
                                    0.31634286705096765,
                                    0.06827446047545312,
                                    0.506144432430455,
                                    0.10923824004312428,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.46234480872414685,
                                    0.09978521932085127,
                                    0.3601424907572757,
                                    0.07772748119772613,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974364,
                                    0.4528917880018739,
                                    0.1358645622574148,
                                ],
                                [
                                    0.4528917880018739,
                                    0.1358645622574148,
                                    0.31634286705096765,
                                    0.09490078268974365,
                                ],
                                [
                                    0.21427640214863244,
                                    0.06428151349014362,
                                    0.5549582529042091,
                                    0.1664838314570148,
                                ],
                                [
                                    0.1538456681183948,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.2884629956448156,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.39053250701124953,
                                    0.2440848205151712,
                                    0.2248501654623297,
                                    0.14053250701124956,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.1671588292255401,
                                    0.1671588292255401,
                                    0.3328411707744599,
                                    0.3328411707744599,
                                ],
                                [
                                    0.047108211998126114,
                                    0.06827446047545314,
                                    0.3611698334676099,
                                    0.5234474940588109,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.2886952950545405,
                                    0.41840933195330277,
                                    0.11958275041119547,
                                    0.17331262258096128,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.18365713294903238,
                                    0.6122038443180996,
                                    0.047108211998126114,
                                    0.15703081073474187,
                                ],
                                [
                                    0.09001634605863601,
                                    0.3000610552047482,
                                    0.1407489988885225,
                                    0.4691735998480933,
                                ],
                                [
                                    0.006258981762693645,
                                    0.017196056752640392,
                                    0.26059122010765307,
                                    0.715953741377013,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.20190015339479556,
                                    0.5547046832501918,
                                    0.06495004847555114,
                                    0.17844511487946152,
                                ],
                                [
                                    0.006258981762693645,
                                    0.1271661191724797,
                                    0.04065109526797443,
                                    0.8259238037968523,
                                ],
                                [
                                    0.04065109526797443,
                                    0.8259238037968523,
                                    0.006258981762693645,
                                    0.1271661191724797,
                                ],
                                [
                                    0.020084768923612335,
                                    0.4080699090250437,
                                    0.02682530810705574,
                                    0.5450200139442882,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.2467863569271919,
                                    0.0092386248356749,
                                    0.71712878614962,
                                    0.026846232087513234,
                                ],
                                [
                                    0.21200361690317068,
                                    0.010434593588739452,
                                    0.7410863060661612,
                                    0.036475483441928566,
                                ],
                                [
                                    0.24639573040845147,
                                    0.012127337006646845,
                                    0.7066941925608804,
                                    0.03478274002402117,
                                ],
                                [
                                    0.23845922247194346,
                                    0.011736710487906409,
                                    0.7146307004973885,
                                    0.03517336654276161,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.2920038833463586,
                                    0.06302151769079631,
                                    0.5304834161350641,
                                    0.11449118282778109,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630804,
                                    0.6232327133796622,
                                    0.1869657212408504,
                                ],
                                [
                                    0.2825508626240855,
                                    0.08476340327397917,
                                    0.486683792428756,
                                    0.14600194167317926,
                                ],
                                [
                                    0.2510401037786874,
                                    0.0753103825517062,
                                    0.518194551274154,
                                    0.15545496239545223,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.21893498597750088,
                                    0.21893498597750088,
                                    0.2810650140224991,
                                    0.2810650140224991,
                                ],
                                [
                                    0.021741885583182873,
                                    0.03151075884539815,
                                    0.38653615988255313,
                                    0.5602111956888659,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.26332896863959726,
                                    0.3816456303232478,
                                    0.1449490768261387,
                                    0.2100763242110162,
                                ],
                                [
                                    0.021741885583182876,
                                    0.0724745384130693,
                                    0.20902345936397562,
                                    0.6967601166397722,
                                ],
                                [
                                    0.15829080653408914,
                                    0.5276475719964271,
                                    0.07247453841306933,
                                    0.2415870830564144,
                                ],
                                [
                                    0.12678004768869097,
                                    0.4226094098909189,
                                    0.10398529725846752,
                                    0.34662524516192256,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.19852988380307385,
                                    0.5454451344340593,
                                    0.06832031806727284,
                                    0.18770466369559397,
                                ],
                                [
                                    0.0028887121709719483,
                                    0.05869106671285754,
                                    0.04402136485969613,
                                    0.8943988562564744,
                                ],
                                [
                                    0.03728082567625273,
                                    0.7574487513372301,
                                    0.009629251354415343,
                                    0.19564117163210193,
                                ],
                                [
                                    0.02934431773974478,
                                    0.5961996932104089,
                                    0.017565759290923293,
                                    0.35689022975892304,
                                ],
                                [
                                    0.04309618500986464,
                                    0.0016133366937801986,
                                    0.9208189580669471,
                                    0.034471520229407936,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.07787892503388587,
                                    0.0029154535929471594,
                                    0.886036218042926,
                                    0.033169403330240974,
                                ],
                                [
                                    0.04309618500986468,
                                    0.002121148602896019,
                                    0.9099937379594673,
                                    0.044788928427772,
                                ],
                                [
                                    0.07748829851514548,
                                    0.003813892020803411,
                                    0.8756016244541864,
                                    0.043096185009864604,
                                ],
                                [
                                    0.2447823937146712,
                                    0.012047930282519648,
                                    0.7083075292546608,
                                    0.03486214674814837,
                                ],
                                [
                                    0.02967933652292657,
                                    0.0064055204002616195,
                                    0.7928079629584961,
                                    0.17110718011831577,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.1756812781961058,
                                    0.03791627924565976,
                                    0.6468060212853168,
                                    0.13959642127291763,
                                ],
                                [
                                    0.02967933652292658,
                                    0.008903606052493138,
                                    0.739555318529915,
                                    0.22186173889466532,
                                ],
                                [
                                    0.1662282574738328,
                                    0.049867385620164274,
                                    0.6030063975790086,
                                    0.18089795932699418,
                                ],
                                [
                                    0.2761453422238239,
                                    0.08284178921899242,
                                    0.4930893128290176,
                                    0.147923555728166,
                                ],
                                [
                                    0.014433824284536993,
                                    0.009021214230797044,
                                    0.6009488481890423,
                                    0.3755961132956237,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.25112066317739173,
                                    0.15695170286436305,
                                    0.3642620092961875,
                                    0.2276656246620577,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.2542919468763482,
                                    0.2542919468763482,
                                    0.2457080531236518,
                                    0.2457080531236518,
                                ],
                                [
                                    0.004419699707218271,
                                    0.006405520400261612,
                                    0.4038583457585177,
                                    0.5853164341340024,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.24600678276363266,
                                    0.3565403918781112,
                                    0.16227126270210332,
                                    0.23518156265615278,
                                ],
                                [
                                    0.004419699707218267,
                                    0.01473265485550997,
                                    0.22634564523994025,
                                    0.7545020001973315,
                                ],
                                [
                                    0.14096862065812457,
                                    0.4699056884388678,
                                    0.08979672428903394,
                                    0.29932896661397373,
                                ],
                                [
                                    0.15188528613382754,
                                    0.5062953699287489,
                                    0.07888005881333096,
                                    0.2629392851240926,
                                ],
                                [
                                    0.000587218633243017,
                                    0.0016133366937802177,
                                    0.2662629832371037,
                                    0.7315364614358731,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.19622839026534492,
                                    0.5391219631913317,
                                    0.07062181160500176,
                                    0.19402783493832168,
                                ],
                                [
                                    0.0005872186332430094,
                                    0.011930744892144246,
                                    0.04632285839742507,
                                    0.9411591780771876,
                                ],
                                [
                                    0.0349793321385238,
                                    0.7106884295165169,
                                    0.011930744892144277,
                                    0.24240149345281511,
                                ],
                                [
                                    0.03566748898247253,
                                    0.7246699745257295,
                                    0.011242588048195544,
                                    0.22841994844360247,
                                ],
                                [
                                    0.8677671480001333,
                                    0.040613253265553824,
                                    0.08752333029622184,
                                    0.004096268438090988,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9022386682295412,
                                    0.04222658995933402,
                                    0.0530518100668139,
                                    0.0024829317443107904,
                                ],
                                [
                                    0.8756016244541865,
                                    0.04309618500986461,
                                    0.07748829851514534,
                                    0.0038138920208034043,
                                ],
                                [
                                    0.9099937379594674,
                                    0.044788928427772004,
                                    0.043096185009864604,
                                    0.002121148602896015,
                                ],
                                [
                                    0.21994012483967862,
                                    0.010825220107479883,
                                    0.7331497981296533,
                                    0.036084856923188136,
                                ],
                                [
                                    0.5719007400028323,
                                    0.1612490581268211,
                                    0.2081591351574891,
                                    0.058691066712857454,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7103712750087252,
                                    0.2002912236395055,
                                    0.06968860015159611,
                                    0.019648901200173065,
                                ],
                                [
                                    0.6030063975790086,
                                    0.18089795932699418,
                                    0.16622825747383277,
                                    0.04986738562016427,
                                ],
                                [
                                    0.739555318529915,
                                    0.22186173889466534,
                                    0.02967933652292653,
                                    0.008903606052493122,
                                ],
                                [
                                    0.17751270051857745,
                                    0.05325264442858104,
                                    0.591721954534264,
                                    0.1775127005185774,
                                ],
                                [
                                    0.2494498611682442,
                                    0.22709510031642177,
                                    0.27400517734708985,
                                    0.2494498611682442,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.4507797391622516,
                                    0.4103825498488351,
                                    0.07267529935308241,
                                    0.06616241163583085,
                                ],
                                [
                                    0.2932575119522527,
                                    0.2932575119522527,
                                    0.20674248804774734,
                                    0.20674248804774734,
                                ],
                                [
                                    0.485566175715463,
                                    0.485566175715463,
                                    0.014433824284536975,
                                    0.014433824284536975,
                                ],
                                [
                                    0.11538267247357925,
                                    0.11538267247357925,
                                    0.38461732752642075,
                                    0.38461732752642075,
                                ],
                                [
                                    0.058691066712857495,
                                    0.16124905812682114,
                                    0.2081591351574892,
                                    0.5719007400028322,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.21659218973144195,
                                    0.5950698896425007,
                                    0.05025801213890473,
                                    0.1380799084871526,
                                ],
                                [
                                    0.08979672428903399,
                                    0.2993289666139739,
                                    0.14096862065812452,
                                    0.4699056884388676,
                                ],
                                [
                                    0.22634564523994025,
                                    0.7545020001973315,
                                    0.00441969970721827,
                                    0.014732654855509982,
                                ],
                                [
                                    0.053252644428581054,
                                    0.17751270051857745,
                                    0.17751270051857745,
                                    0.591721954534264,
                                ],
                                [
                                    0.004096268438090994,
                                    0.040613253265553845,
                                    0.08752333029622192,
                                    0.8677671480001332,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.07126715875487234,
                                    0.7065921610784258,
                                    0.020352439979440563,
                                    0.20178824018726127,
                                ],
                                [
                                    0.011930744892144286,
                                    0.24240149345281525,
                                    0.03497933213852379,
                                    0.7106884295165167,
                                ],
                                [
                                    0.04632285839742507,
                                    0.9411591780771876,
                                    0.0005872186332430102,
                                    0.011930744892144263,
                                ],
                                [
                                    0.010825220107479895,
                                    0.21994012483967862,
                                    0.03608485692318818,
                                    0.7331497981296533,
                                ],
                                [
                                    0.7003710213181529,
                                    0.03277877681150055,
                                    0.25491945697820234,
                                    0.01193074489214426,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7348425415475607,
                                    0.03439211350528075,
                                    0.22044793674879437,
                                    0.010317408198364061,
                                ],
                                [
                                    0.7066941925608805,
                                    0.03478274002402118,
                                    0.24639573040845136,
                                    0.01212733700664684,
                                ],
                                [
                                    0.7410863060661613,
                                    0.03647548344192857,
                                    0.2120036169031706,
                                    0.010434593588739449,
                                ],
                                [
                                    0.22626329608240636,
                                    0.01113643990209312,
                                    0.7268266268869256,
                                    0.0357736371285749,
                                ],
                                [
                                    0.46157855398361947,
                                    0.13014340055064466,
                                    0.3184813211767019,
                                    0.0897967242890339,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.486683792428756,
                                    0.14600194167317926,
                                    0.2825508626240855,
                                    0.08476340327397917,
                                ],
                                [
                                    0.6232327133796622,
                                    0.1869657212408504,
                                    0.14600194167317926,
                                    0.043799623706308036,
                                ],
                                [
                                    0.20261793896371402,
                                    0.060784051095867285,
                                    0.5666167160891274,
                                    0.16998129385129115,
                                ],
                                [
                                    0.20132987799400748,
                                    0.18328744953241338,
                                    0.32212516052132656,
                                    0.2932575119522526,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.40265975598801484,
                                    0.36657489906482665,
                                    0.12079528252731918,
                                    0.1099700624198393,
                                ],
                                [
                                    0.2366868388928548,
                                    0.2366868388928548,
                                    0.2633131611071452,
                                    0.2633131611071452,
                                ],
                                [
                                    0.4289955026560651,
                                    0.4289955026560651,
                                    0.07100449734393487,
                                    0.07100449734393487,
                                ],
                                [
                                    0.15073963337242657,
                                    0.15073963337242657,
                                    0.3492603666275734,
                                    0.3492603666275734,
                                ],
                                [
                                    0.0473692999679328,
                                    0.1301434005506447,
                                    0.2194809019024139,
                                    0.6030063975790086,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.20527042298651726,
                                    0.5639642320663243,
                                    0.061579778883829435,
                                    0.16918556606332907,
                                ],
                                [
                                    0.07247453841306935,
                                    0.24158708305641444,
                                    0.15829080653408914,
                                    0.5276475719964271,
                                ],
                                [
                                    0.20902345936397562,
                                    0.6967601166397722,
                                    0.02174188558318288,
                                    0.07247453841306932,
                                ],
                                [
                                    0.0783578828737176,
                                    0.2611986605564074,
                                    0.1524074620734409,
                                    0.5080359944964341,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.0327787768115006,
                                    0.08831351862262532,
                                    0.8756016244541865,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.07047697042846894,
                                    0.6987576846243726,
                                    0.021142628305843965,
                                    0.20962271664131454,
                                ],
                                [
                                    0.009629251354415341,
                                    0.19564117163210187,
                                    0.03728082567625273,
                                    0.7574487513372301,
                                ],
                                [
                                    0.04402136485969613,
                                    0.8943988562564745,
                                    0.0028887121709719452,
                                    0.058691066712857475,
                                ],
                                [
                                    0.017148391350207643,
                                    0.3484104061549992,
                                    0.02976168568046043,
                                    0.6046795168143327,
                                ],
                                [
                                    0.4552388641864047,
                                    0.021306097298261252,
                                    0.5000516141099505,
                                    0.02340342440538356,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.48971038441581266,
                                    0.022919433992041452,
                                    0.4655800938805425,
                                    0.02179008771160336,
                                ],
                                [
                                    0.45934890473202555,
                                    0.022608666806380313,
                                    0.4937410182373064,
                                    0.024301410224287705,
                                ],
                                [
                                    0.4937410182373064,
                                    0.024301410224287705,
                                    0.45934890473202555,
                                    0.022608666806380313,
                                ],
                                [
                                    0.23552284489853884,
                                    0.011592185092306388,
                                    0.7175670780707931,
                                    0.03531789193836163,
                                ],
                                [
                                    0.3000245444947562,
                                    0.08459278303166452,
                                    0.4800353306655652,
                                    0.13534734180801405,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4384950795006492,
                                    0.1236349485443489,
                                    0.3415647956596721,
                                    0.09630517629532966,
                                ],
                                [
                                    0.3163428670509676,
                                    0.09490078268974364,
                                    0.4528917880018739,
                                    0.1358645622574148,
                                ],
                                [
                                    0.4528917880018739,
                                    0.1358645622574148,
                                    0.31634286705096765,
                                    0.09490078268974365,
                                ],
                                [
                                    0.23938164059376893,
                                    0.07181292015742984,
                                    0.5298530144590726,
                                    0.1589524247897286,
                                ],
                                [
                                    0.1308637596288335,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.3574087211134995,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.33219363762284093,
                                    0.3024236899035798,
                                    0.1912614008924931,
                                    0.17412127158108615,
                                ],
                                [
                                    0.15384566811839484,
                                    0.15384566811839484,
                                    0.34615433188160516,
                                    0.34615433188160516,
                                ],
                                [
                                    0.34615433188160516,
                                    0.34615433188160516,
                                    0.1538456681183948,
                                    0.1538456681183948,
                                ],
                                [
                                    0.20251579012438736,
                                    0.20251579012438736,
                                    0.29748420987561264,
                                    0.29748420987561264,
                                ],
                                [
                                    0.030789889441914717,
                                    0.08459278303166454,
                                    0.23606031242843198,
                                    0.6485570150979888,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.18869101246049919,
                                    0.5184136145473441,
                                    0.07815918940984752,
                                    0.21473618358230923,
                                ],
                                [
                                    0.047108211998126114,
                                    0.15703081073474187,
                                    0.18365713294903238,
                                    0.6122038443180996,
                                ],
                                [
                                    0.18365713294903238,
                                    0.6122038443180996,
                                    0.047108211998126114,
                                    0.15703081073474187,
                                ],
                                [
                                    0.11512158450377256,
                                    0.3837470152425781,
                                    0.11564376044338594,
                                    0.3854876398102634,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                    0.08947065751724015,
                                    0.8870743039674258,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.06931983153385411,
                                    0.6872850051111332,
                                    0.0222997672004588,
                                    0.22109539615455384,
                                ],
                                [
                                    0.006258981762693645,
                                    0.1271661191724797,
                                    0.04065109526797443,
                                    0.8259238037968523,
                                ],
                                [
                                    0.04065109526797443,
                                    0.8259238037968523,
                                    0.006258981762693645,
                                    0.1271661191724797,
                                ],
                                [
                                    0.026407940166340085,
                                    0.5365401903403643,
                                    0.02050213686432799,
                                    0.4165497326289676,
                                ],
                                [
                                    0.21010670705465664,
                                    0.009833417785021961,
                                    0.7451837712416985,
                                    0.03487610391862285,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.24457822728406464,
                                    0.011446754478802161,
                                    0.7107122510122905,
                                    0.03326276722484265,
                                ],
                                [
                                    0.21200361690317068,
                                    0.010434593588739452,
                                    0.7410863060661612,
                                    0.036475483441928566,
                                ],
                                [
                                    0.24639573040845147,
                                    0.012127337006646845,
                                    0.7066941925608804,
                                    0.03478274002402117,
                                ],
                                [
                                    0.2447823937146712,
                                    0.012047930282519648,
                                    0.7083075292546608,
                                    0.03486214674814837,
                                ],
                                [
                                    0.13847053500589307,
                                    0.039042165512684406,
                                    0.6415893401544284,
                                    0.18089795932699415,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.27694107001178603,
                                    0.07808433102536878,
                                    0.5031188051485354,
                                    0.14185579381430977,
                                ],
                                [
                                    0.1460019416731793,
                                    0.04379962370630804,
                                    0.6232327133796622,
                                    0.1869657212408504,
                                ],
                                [
                                    0.2825508626240855,
                                    0.08476340327397917,
                                    0.486683792428756,
                                    0.14600194167317926,
                                ],
                                [
                                    0.2761453422238239,
                                    0.08284178921899242,
                                    0.4930893128290176,
                                    0.147923555728166,
                                ],
                                [
                                    0.060397641263659596,
                                    0.054985031209919655,
                                    0.46305739725167444,
                                    0.4215599302747463,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.07100449734393488,
                                    0.07100449734393488,
                                    0.4289955026560651,
                                    0.4289955026560651,
                                ],
                                [
                                    0.26331316110714525,
                                    0.26331316110714525,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                ],
                                [
                                    0.2542919468763482,
                                    0.2542919468763482,
                                    0.2457080531236518,
                                    0.2457080531236518,
                                ],
                                [
                                    0.014210478915896638,
                                    0.039042165512684385,
                                    0.25263972295445003,
                                    0.694107632616969,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.1721116019344811,
                                    0.47286299702836393,
                                    0.09473859993586559,
                                    0.2602868011012893,
                                ],
                                [
                                    0.021741885583182876,
                                    0.0724745384130693,
                                    0.20902345936397562,
                                    0.6967601166397722,
                                ],
                                [
                                    0.15829080653408914,
                                    0.5276475719964271,
                                    0.07247453841306933,
                                    0.2415870830564144,
                                ],
                                [
                                    0.15188528613382754,
                                    0.5062953699287489,
                                    0.07888005881333096,
                                    0.2629392851240926,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.00983341778502196,
                                    0.09062779641185499,
                                    0.8985469834806651,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.06816269263923927,
                                    0.675812325597894,
                                    0.02345690609507364,
                                    0.23256807566779317,
                                ],
                                [
                                    0.0028887121709719483,
                                    0.05869106671285754,
                                    0.04402136485969613,
                                    0.8943988562564744,
                                ],
                                [
                                    0.03728082567625273,
                                    0.7574487513372301,
                                    0.009629251354415343,
                                    0.19564117163210193,
                                ],
                                [
                                    0.03566748898247253,
                                    0.7246699745257295,
                                    0.011242588048195544,
                                    0.22841994844360247,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.07718210060208414,
                                    0.003612278024748888,
                                    0.878108377694271,
                                    0.041097243678895924,
                                ],
                                [
                                    0.04309618500986468,
                                    0.002121148602896019,
                                    0.9099937379594673,
                                    0.044788928427772,
                                ],
                                [
                                    0.07748829851514548,
                                    0.003813892020803411,
                                    0.8756016244541864,
                                    0.043096185009864604,
                                ],
                                [
                                    0.25110556495739894,
                                    0.012359150077132886,
                                    0.701984358011933,
                                    0.03455092695353513,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.1666188839925732,
                                    0.04697867344919233,
                                    0.6134409911677482,
                                    0.17296145139048624,
                                ],
                                [
                                    0.02967933652292658,
                                    0.008903606052493138,
                                    0.739555318529915,
                                    0.22186173889466532,
                                ],
                                [
                                    0.1662282574738328,
                                    0.049867385620164274,
                                    0.6030063975790086,
                                    0.18089795932699418,
                                ],
                                [
                                    0.3012505806689605,
                                    0.09037319588627866,
                                    0.467984074383881,
                                    0.14039214906087977,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.21360753608343025,
                                    0.19446482995832454,
                                    0.3098475024319038,
                                    0.2820801315263414,
                                ],
                                [
                                    0.014433824284536989,
                                    0.014433824284536989,
                                    0.485566175715463,
                                    0.485566175715463,
                                ],
                                [
                                    0.20674248804774736,
                                    0.20674248804774736,
                                    0.29325751195225264,
                                    0.29325751195225264,
                                ],
                                [
                                    0.28964890777519553,
                                    0.28964890777519553,
                                    0.21035109222480447,
                                    0.21035109222480447,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.1607898351895564,
                                    0.4417573394521875,
                                    0.10606036668079029,
                                    0.2913924586774658,
                                ],
                                [
                                    0.004419699707218267,
                                    0.01473265485550997,
                                    0.22634564523994025,
                                    0.7545020001973315,
                                ],
                                [
                                    0.14096862065812457,
                                    0.4699056884388678,
                                    0.08979672428903394,
                                    0.29932896661397373,
                                ],
                                [
                                    0.1769905245789641,
                                    0.5899813299665788,
                                    0.053774820368194406,
                                    0.17925332508626265,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.0019989413309687114,
                                    0.09141798473825839,
                                    0.9063814599347184,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.06737250431283588,
                                    0.6679778491438406,
                                    0.024247094421477038,
                                    0.2404025521218464,
                                ],
                                [
                                    0.0005872186332430094,
                                    0.011930744892144246,
                                    0.04632285839742507,
                                    0.9411591780771876,
                                ],
                                [
                                    0.0349793321385238,
                                    0.7106884295165169,
                                    0.011930744892144277,
                                    0.24240149345281511,
                                ],
                                [
                                    0.04199066022520028,
                                    0.85314025584105,
                                    0.004919416805467795,
                                    0.09994966712828192,
                                ],
                                [
                                    0.9063814599347185,
                                    0.0019989413309686862,
                                    0.09141798473825831,
                                    0.00020161399605452077,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.8677671480001333,
                                    0.042710580372676124,
                                    0.08532277496919863,
                                    0.004199496657991893,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979843,
                                    0.042710580372676124,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.006095209769059684,
                                    0.0002999997722081366,
                                    0.9469947132002723,
                                    0.04661007725845988,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.04640226512155221,
                                    0.0005078119091158176,
                                ],
                                [
                                    0.5719007400028322,
                                    0.17156646632518516,
                                    0.19733391505000922,
                                    0.05919887862197327,
                                ],
                                [
                                    0.7410863060661613,
                                    0.2223210251015347,
                                    0.0281483489866802,
                                    0.008444319845623756,
                                ],
                                [
                                    -0.11722769326712491,
                                    -0.03516753814515736,
                                    0.8864623483199664,
                                    0.26593288309231583,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.04580979936715644,
                                    0.0011002776635116041,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    -0.19246268137517653,
                                    -0.19246268137517653,
                                    0.6924626813751765,
                                    0.6924626813751765,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.04521733361276067,
                                    0.001692743417907391,
                                ],
                                [
                                    0.05869106671285752,
                                    0.19564117163210204,
                                    0.172074278234301,
                                    0.5735934834207395,
                                ],
                                [
                                    0.22787663277618656,
                                    0.7596054036984262,
                                    0.0028887121709719426,
                                    0.00962925135441533,
                                ],
                                [
                                    -0.14248733008283326,
                                    -0.47496816400559033,
                                    0.37325267502999177,
                                    1.2442028190584318,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354577,
                                    0.002097327107122304,
                                ],
                                [
                                    0.004096268438090996,
                                    0.08322544786207639,
                                    0.04281380859257708,
                                    0.8698644751072555,
                                ],
                                [
                                    0.046708463034613554,
                                    0.948993654531241,
                                    0.00020161399605452123,
                                    0.0040962684380909916,
                                ],
                                [
                                    -0.036413756607561965,
                                    -0.739832178434412,
                                    0.08332383363823004,
                                    1.6929221014037439,
                                ],
                                [
                                    0.7315364614358733,
                                    0.0016133366937801977,
                                    0.26626298323710357,
                                    0.0005872186332430093,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7761475973633645,
                                    0.001711722469933813,
                                    0.22165184730961238,
                                    0.0004888328570893941,
                                ],
                                [
                                    0.7003710213181528,
                                    0.03447152022940794,
                                    0.2527189016511791,
                                    0.012438556801260077,
                                ],
                                [
                                    0.7429832159146753,
                                    0.03656884733653024,
                                    0.2101067070546566,
                                    0.010341229694137775,
                                ],
                                [
                                    0.01392968622311303,
                                    0.0006856044093966288,
                                    0.9391602367462188,
                                    0.04622447262127139,
                                ],
                                [
                                    0.5853164341340025,
                                    0.006405520400261611,
                                    0.4038583457585176,
                                    0.004419699707218268,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.8028756587118249,
                                    0.008786420662117734,
                                    0.18629912118069517,
                                    0.002038799445362145,
                                ],
                                [
                                    0.4615785539836194,
                                    0.13847053500589301,
                                    0.3076561010692221,
                                    0.09229480994126542,
                                ],
                                [
                                    0.6307641200469485,
                                    0.18922509378224256,
                                    0.13847053500589301,
                                    0.0415402511649159,
                                ],
                                [
                                    -0.08612203569094845,
                                    -0.025836045143348352,
                                    0.85535669074379,
                                    0.2566013900905068,
                                ],
                                [
                                    0.3755961132956238,
                                    0.009021214230797037,
                                    0.6009488481890422,
                                    0.014433824284536972,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.8409636943543785,
                                    0.020198594656708237,
                                    0.13558126713028748,
                                    0.0032564438586257724,
                                ],
                                [
                                    0.20132987799400748,
                                    0.20132987799400748,
                                    0.2986701220059925,
                                    0.2986701220059925,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    -0.14865503059116802,
                                    -0.14865503059116802,
                                    0.648655030591168,
                                    0.648655030591168,
                                ],
                                [
                                    0.17110718011831585,
                                    0.0064055204002616125,
                                    0.792807962958496,
                                    0.029679336522926522,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.8778013726791963,
                                    0.03286112596903442,
                                    0.08611377039761549,
                                    0.0032237309541537184,
                                ],
                                [
                                    0.04736929996793278,
                                    0.15790112301858444,
                                    0.18339604497922574,
                                    0.6113335320342571,
                                ],
                                [
                                    0.21655486603126187,
                                    0.7218653550849088,
                                    0.014210478915896644,
                                    0.04736929996793278,
                                ],
                                [
                                    -0.11138167250665684,
                                    -0.37128036902371864,
                                    0.34214701745381537,
                                    1.1405150240765602,
                                ],
                                [
                                    0.03447152022940799,
                                    0.0016133366937802001,
                                    0.9208189580669471,
                                    0.04309618500986461,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.9022386682295412,
                                    0.04222658995933402,
                                    0.053051810066813955,
                                    0.002482931744310793,
                                ],
                                [
                                    0.0033060801116875918,
                                    0.0671708903167813,
                                    0.04360399691898048,
                                    0.8859190326525506,
                                ],
                                [
                                    0.045918274708210145,
                                    0.9329390969859458,
                                    0.0009918023224579234,
                                    0.020150825983386036,
                                ],
                                [
                                    -0.028579280153508673,
                                    -0.5806561328436731,
                                    0.07548935718417675,
                                    1.533746055813005,
                                ],
                                [
                                    0.4754962979311048,
                                    0.0010486635535611507,
                                    0.522303146741872,
                                    0.0011518917734620563,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.520107433858596,
                                    0.001147049329714766,
                                    0.47769201081438073,
                                    0.001053505997308441,
                                ],
                                [
                                    0.4552388641864047,
                                    0.02240637496177286,
                                    0.49785105878292724,
                                    0.02450370206889516,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889516,
                                    0.4552388641864047,
                                    0.02240637496177286,
                                ],
                                [
                                    0.025402365736352274,
                                    0.0012502775496156732,
                                    0.9276875572329797,
                                    0.045659799481052345,
                                ],
                                [
                                    0.3804537602987966,
                                    0.004163567227624184,
                                    0.6087210195937236,
                                    0.006661652879855695,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5980129848766189,
                                    0.006544467489480307,
                                    0.3911617950159011,
                                    0.004280752617999571,
                                ],
                                [
                                    0.3000245444947562,
                                    0.09000539308540446,
                                    0.4692101105580853,
                                    0.140759951861754,
                                ],
                                [
                                    0.4692101105580853,
                                    0.140759951861754,
                                    0.3000245444947562,
                                    0.09000539308540446,
                                ],
                                [
                                    -0.04057141817196846,
                                    -0.012171159018838758,
                                    0.8098060732248099,
                                    0.2429365039659972,
                                ],
                                [
                                    0.2441362403711665,
                                    0.005863759628833502,
                                    0.7324087211134995,
                                    0.017591278886500507,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.7095038214299212,
                                    0.017041140054744705,
                                    0.2670411400547447,
                                    0.006413898460589305,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    -0.08450382142992119,
                                    -0.08450382142992119,
                                    0.5845038214299212,
                                    0.5845038214299212,
                                ],
                                [
                                    0.11121910524595506,
                                    0.004163567227624185,
                                    0.8526960378308568,
                                    0.03192128969556395,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.8179132978068355,
                                    0.03061917279639699,
                                    0.14600184526997628,
                                    0.005465684126791146,
                                ],
                                [
                                    0.030789889441914717,
                                    0.10263521149325863,
                                    0.1999754555052438,
                                    0.6665994435595829,
                                ],
                                [
                                    0.1999754555052438,
                                    0.6665994435595829,
                                    0.030789889441914717,
                                    0.10263521149325863,
                                ],
                                [
                                    -0.06583105498767668,
                                    -0.21944165354120107,
                                    0.29659639993483516,
                                    0.9886763085940425,
                                ],
                                [
                                    0.022406374961772883,
                                    0.001048663553561152,
                                    0.9328841033345823,
                                    0.04366085815008366,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.8901735229619061,
                                    0.04166191681911497,
                                    0.06511695533444903,
                                    0.0030476048845298398,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                ],
                                [
                                    -0.017106600640269375,
                                    -0.34756132836538356,
                                    0.06401667767093745,
                                    1.3006512513347155,
                                ],
                                [
                                    0.21945613442633652,
                                    0.00048399041334210393,
                                    0.7783433102466403,
                                    0.001716564913681103,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.2640672703538277,
                                    0.0005823761894957193,
                                    0.733732174319149,
                                    0.0016181791375274876,
                                ],
                                [
                                    0.2101067070546567,
                                    0.01034122969413778,
                                    0.7429832159146752,
                                    0.036568847336530236,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260083,
                                    0.7003710213181527,
                                    0.034471520229407936,
                                ],
                                [
                                    0.03687504524959162,
                                    0.0018149506898347228,
                                    0.9162148777197403,
                                    0.0450951263408333,
                                ],
                                [
                                    0.17559108646359073,
                                    0.001921614054986759,
                                    0.8135836934289294,
                                    0.00890360605249312,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.3931503110414131,
                                    0.004302514316842881,
                                    0.596024468851107,
                                    0.006522705790636998,
                                ],
                                [
                                    0.13847053500589307,
                                    0.04154025116491592,
                                    0.6307641200469484,
                                    0.18922509378224253,
                                ],
                                [
                                    0.30765610106922214,
                                    0.09229480994126545,
                                    0.46157855398361936,
                                    0.138470535005893,
                                ],
                                [
                                    0.0049791993470117155,
                                    0.0014937271056708877,
                                    0.7642554557058298,
                                    0.22927161784148756,
                                ],
                                [
                                    0.11267636744670928,
                                    0.0027063050268699707,
                                    0.8638685940379567,
                                    0.02074873348846404,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.578043948505464,
                                    0.013883685452781173,
                                    0.39850101297920193,
                                    0.009571353062552836,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    -0.020352612268674353,
                                    -0.020352612268674353,
                                    0.5203526122686744,
                                    0.5203526122686744,
                                ],
                                [
                                    0.05133103037359426,
                                    0.0019216140549867579,
                                    0.9125841127032176,
                                    0.034163242868201375,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.7580252229344747,
                                    0.028377219623759563,
                                    0.2058899201423371,
                                    0.007707637299428574,
                                ],
                                [
                                    0.014210478915896657,
                                    0.04736929996793283,
                                    0.21655486603126184,
                                    0.7218653550849087,
                                ],
                                [
                                    0.18339604497922574,
                                    0.6113335320342571,
                                    0.04736929996793279,
                                    0.15790112301858447,
                                ],
                                [
                                    -0.02028043746869657,
                                    -0.06760293805868367,
                                    0.25104578241585507,
                                    0.8368375931115252,
                                ],
                                [
                                    0.010341229694137779,
                                    0.00048399041334210404,
                                    0.9449492486022174,
                                    0.044225531290302704,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.878108377694271,
                                    0.041097243678895924,
                                    0.07718210060208414,
                                    0.003612278024748888,
                                ],
                                [
                                    0.000991802322457926,
                                    0.02015082598338609,
                                    0.045918274708210145,
                                    0.9329390969859458,
                                ],
                                [
                                    0.04360399691898048,
                                    0.8859190326525506,
                                    0.003306080111687594,
                                    0.06717089031678135,
                                ],
                                [
                                    -0.005633921127030066,
                                    -0.1144665238870938,
                                    0.05254399815769814,
                                    1.0675564468564258,
                                ],
                                [
                                    0.04461113592749122,
                                    9.838577615361534e-05,
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08922227185498244,
                                    0.00019677155230723067,
                                    0.9085771728179943,
                                    0.002003783774715976,
                                ],
                                [
                                    0.042710580372676187,
                                    0.002102169550869595,
                                    0.9103793425966558,
                                    0.044807907479798424,
                                ],
                                [
                                    0.08532277496919871,
                                    0.0041994966579918976,
                                    0.8677671480001332,
                                    0.04271058037267612,
                                ],
                                [
                                    0.04470952170364486,
                                    0.0022005553270232096,
                                    0.9083804012656871,
                                    0.04470952170364481,
                                ],
                                [
                                    0.03569423040444776,
                                    0.00039062651874043134,
                                    0.9534805494880724,
                                    0.010434593588739449,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.25325345498227014,
                                    0.002771526780596554,
                                    0.73592132491025,
                                    0.008053693326883325,
                                ],
                                [
                                    0.028148348986680272,
                                    0.008444319845623778,
                                    0.7410863060661612,
                                    0.22232102510153468,
                                ],
                                [
                                    0.19733391505000927,
                                    0.05919887862197328,
                                    0.5719007400028322,
                                    0.17156646632518516,
                                ],
                                [
                                    0.03608485692318818,
                                    0.010825220107479893,
                                    0.7331497981296533,
                                    0.21994012483967856,
                                ],
                                [
                                    0.022904899683578235,
                                    0.0005501388317558024,
                                    0.9536400618010877,
                                    0.022904899683578207,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.023455038515334037,
                                    0.023455038515334037,
                                    0.47654496148466596,
                                    0.47654496148466596,
                                ],
                                [
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                    0.9534805494880724,
                                    0.035694230404447705,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.71712878614962,
                                    0.026846232087513234,
                                    0.2467863569271919,
                                    0.0092386248356749,
                                ],
                                [
                                    0.0028887121709719383,
                                    0.009629251354415317,
                                    0.22787663277618656,
                                    0.7596054036984262,
                                ],
                                [
                                    0.17207427823430102,
                                    0.5735934834207397,
                                    0.05869106671285748,
                                    0.1956411716321019,
                                ],
                                [
                                    0.010825220107479895,
                                    0.03608485692318818,
                                    0.21994012483967862,
                                    0.7331497981296533,
                                ],
                                [
                                    0.0021021695508696182,
                                    9.838577615361652e-05,
                                    0.9531883087454855,
                                    0.04461113592749119,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.8698693175510028,
                                    0.04071163904170744,
                                    0.0854211607453523,
                                    0.003997882661937375,
                                ],
                                [
                                    0.0002016139960545219,
                                    0.004096268438091006,
                                    0.046708463034613554,
                                    0.948993654531241,
                                ],
                                [
                                    0.04281380859257708,
                                    0.8698644751072555,
                                    0.004096268438090997,
                                    0.0832254478620764,
                                ],
                                [
                                    0.002200555327023212,
                                    0.04470952170364486,
                                    0.04470952170364486,
                                    0.9083804012656871,
                                ],
                                [
                                    0.8985469834806652,
                                    0.009833417785021958,
                                    0.09062779641185491,
                                    0.0009918023224579212,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.8677671480001333,
                                    0.042710580372676124,
                                    0.08532277496919863,
                                    0.004199496657991893,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979843,
                                    0.042710580372676124,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.01392968622311303,
                                    0.0006856044093966288,
                                    0.9391602367462188,
                                    0.04622447262127139,
                                ],
                                [
                                    0.6941076326169691,
                                    0.03904216551268439,
                                    0.25263972295445,
                                    0.014210478915896635,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.9023353641929824,
                                    0.05075455877634951,
                                    0.04441199137843652,
                                    0.0024980856522315107,
                                ],
                                [
                                    0.5719007400028322,
                                    0.17156646632518516,
                                    0.19733391505000922,
                                    0.05919887862197327,
                                ],
                                [
                                    0.7410863060661613,
                                    0.2223210251015347,
                                    0.0281483489866802,
                                    0.008444319845623756,
                                ],
                                [
                                    -0.08612203569094845,
                                    -0.025836045143348352,
                                    0.85535669074379,
                                    0.2566013900905068,
                                ],
                                [
                                    0.4215599302747463,
                                    0.05498503120991964,
                                    0.46305739725167444,
                                    0.06039764126365958,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.8431198605494926,
                                    0.10997006241983928,
                                    0.041497466976928105,
                                    0.005412610053739943,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    -0.14865503059116802,
                                    -0.14865503059116802,
                                    0.648655030591168,
                                    0.648655030591168,
                                ],
                                [
                                    0.18089795932699423,
                                    0.0390421655126844,
                                    0.6415893401544284,
                                    0.13847053500589301,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.7839043569060029,
                                    0.16918556606332902,
                                    0.038582942575419686,
                                    0.008327134455248375,
                                ],
                                [
                                    0.05869106671285752,
                                    0.19564117163210204,
                                    0.172074278234301,
                                    0.5735934834207395,
                                ],
                                [
                                    0.22787663277618656,
                                    0.7596054036984262,
                                    0.0028887121709719426,
                                    0.00962925135441533,
                                ],
                                [
                                    -0.11138167250665684,
                                    -0.37128036902371864,
                                    0.34214701745381537,
                                    1.1405150240765602,
                                ],
                                [
                                    0.03487610391862287,
                                    0.009833417785021965,
                                    0.7451837712416985,
                                    0.2101067070546566,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.7434672063280174,
                                    0.2096227166413145,
                                    0.036592668832304,
                                    0.010317408198364074,
                                ],
                                [
                                    0.004096268438090996,
                                    0.08322544786207639,
                                    0.04281380859257708,
                                    0.8698644751072555,
                                ],
                                [
                                    0.046708463034613554,
                                    0.948993654531241,
                                    0.00020161399605452123,
                                    0.0040962684380909916,
                                ],
                                [
                                    -0.028579280153508673,
                                    -0.5806561328436731,
                                    0.07548935718417675,
                                    1.533746055813005,
                                ],
                                [
                                    0.7252132901931455,
                                    0.007936507936507938,
                                    0.26396148969937466,
                                    0.0028887121709719405,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7694388214834482,
                                    0.008420498349850043,
                                    0.21973595840907192,
                                    0.0024047217576298368,
                                ],
                                [
                                    0.7003710213181528,
                                    0.03447152022940794,
                                    0.2527189016511791,
                                    0.012438556801260077,
                                ],
                                [
                                    0.7429832159146753,
                                    0.03656884733653024,
                                    0.2101067070546566,
                                    0.010341229694137775,
                                ],
                                [
                                    0.021764162677166268,
                                    0.0010712090465851158,
                                    0.9313257602921656,
                                    0.045838867984082904,
                                ],
                                [
                                    0.560211195688866,
                                    0.031510758845398154,
                                    0.386536159882553,
                                    0.02174188558318287,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7684389272648794,
                                    0.04322315210906328,
                                    0.17830842830653956,
                                    0.010029492319517747,
                                ],
                                [
                                    0.4615785539836194,
                                    0.13847053500589301,
                                    0.3076561010692221,
                                    0.09229480994126542,
                                ],
                                [
                                    0.6307641200469485,
                                    0.18922509378224256,
                                    0.13847053500589301,
                                    0.0415402511649159,
                                ],
                                [
                                    -0.05501637811477199,
                                    -0.01650455214153935,
                                    0.8242510331676135,
                                    0.2472698970886978,
                                ],
                                [
                                    0.3402391523967765,
                                    0.044378175129644364,
                                    0.5443781751296443,
                                    0.07100449734393485,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.7617990826715227,
                                    0.09936320633956398,
                                    0.12281824485489802,
                                    0.01601946613401523,
                                ],
                                [
                                    0.20132987799400748,
                                    0.20132987799400748,
                                    0.2986701220059925,
                                    0.2986701220059925,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    -0.10484737980715964,
                                    -0.10484737980715964,
                                    0.6048473798071596,
                                    0.6048473798071596,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.749008339252188,
                                    0.16165415939604277,
                                    0.0734789602292346,
                                    0.01585854112253461,
                                ],
                                [
                                    0.04736929996793278,
                                    0.15790112301858444,
                                    0.18339604497922574,
                                    0.6113335320342571,
                                ],
                                [
                                    0.21655486603126187,
                                    0.7218653550849088,
                                    0.014210478915896644,
                                    0.04736929996793278,
                                ],
                                [
                                    -0.08027601493048034,
                                    -0.26759257404184666,
                                    0.3110413598776388,
                                    1.036827229094688,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.7367394513960748,
                                    0.20772580679280048,
                                    0.04332042376424665,
                                    0.012214318046878093,
                                ],
                                [
                                    0.0033060801116875918,
                                    0.0671708903167813,
                                    0.04360399691898048,
                                    0.8859190326525506,
                                ],
                                [
                                    0.045918274708210145,
                                    0.9329390969859458,
                                    0.0009918023224579234,
                                    0.020150825983386036,
                                ],
                                [
                                    -0.020744803699455406,
                                    -0.4214800872529346,
                                    0.06765488073012348,
                                    1.3745700102222667,
                                ],
                                [
                                    0.47138625738548395,
                                    0.005158704099182031,
                                    0.5177885225070362,
                                    0.005666516008297848,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5156117886757867,
                                    0.005642694512524134,
                                    0.47356299121673345,
                                    0.005182525594955745,
                                ],
                                [
                                    0.4552388641864047,
                                    0.02240637496177286,
                                    0.49785105878292724,
                                    0.02450370206889516,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889516,
                                    0.4552388641864047,
                                    0.02240637496177286,
                                ],
                                [
                                    0.03323684219040562,
                                    0.0016358821868041654,
                                    0.9198530807789264,
                                    0.04527419484386385,
                                ],
                                [
                                    0.36413543774258517,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.03277075464474545,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5723631693185985,
                                    0.032194283047500695,
                                    0.3743841862528204,
                                    0.021058361381080328,
                                ],
                                [
                                    0.3000245444947562,
                                    0.09000539308540446,
                                    0.4692101105580853,
                                    0.140759951861754,
                                ],
                                [
                                    0.4692101105580853,
                                    0.140759951861754,
                                    0.3000245444947562,
                                    0.09000539308540446,
                                ],
                                [
                                    -0.009465760595791992,
                                    -0.0028396660170297537,
                                    0.7787004156486335,
                                    0.2336050109641882,
                                ],
                                [
                                    0.2211543318816052,
                                    0.028845668118394806,
                                    0.6634629956448156,
                                    0.08653700435518441,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.6427142621563515,
                                    0.08383069932831444,
                                    0.24190306537006925,
                                    0.031551973145264776,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    -0.0406961706459128,
                                    -0.0406961706459128,
                                    0.5406961706459128,
                                    0.5406961706459128,
                                ],
                                [
                                    0.09490078268974368,
                                    0.020481889783835576,
                                    0.727586516791679,
                                    0.15703081073474182,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.6979071802687524,
                                    0.1506252903344802,
                                    0.12458011921267025,
                                    0.026887410184097196,
                                ],
                                [
                                    0.030789889441914717,
                                    0.10263521149325863,
                                    0.1999754555052438,
                                    0.6665994435595829,
                                ],
                                [
                                    0.1999754555052438,
                                    0.6665994435595829,
                                    0.030789889441914717,
                                    0.10263521149325863,
                                ],
                                [
                                    -0.03472539741150022,
                                    -0.11575385855932924,
                                    0.2654907423586587,
                                    0.8849885136121707,
                                ],
                                [
                                    0.018296334416152,
                                    0.005158704099182037,
                                    0.7617635407441694,
                                    0.21478142074049653,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.7268874368255465,
                                    0.20494800295547455,
                                    0.05317243833477487,
                                    0.014992121884204,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                ],
                                [
                                    -0.009272124186216096,
                                    -0.1883852827746449,
                                    0.05618220121688417,
                                    1.1414752057439768,
                                ],
                                [
                                    0.2175592245778225,
                                    0.0023809002618561236,
                                    0.7716155553146976,
                                    0.008444319845623756,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.2617847558681252,
                                    0.002864890675198228,
                                    0.7273900240243949,
                                    0.007960329432281652,
                                ],
                                [
                                    0.2101067070546567,
                                    0.01034122969413778,
                                    0.7429832159146752,
                                    0.036568847336530236,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260083,
                                    0.7003710213181527,
                                    0.034471520229407936,
                                ],
                                [
                                    0.04470952170364486,
                                    0.0022005553270232096,
                                    0.9083804012656871,
                                    0.04470952170364481,
                                ],
                                [
                                    0.16805967979630448,
                                    0.009453020722272998,
                                    0.7786876757751144,
                                    0.04379962370630803,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.37628741137231786,
                                    0.02116541398593812,
                                    0.5704599441991011,
                                    0.03208723044264291,
                                ],
                                [
                                    0.13847053500589307,
                                    0.04154025116491592,
                                    0.6307641200469484,
                                    0.18922509378224253,
                                ],
                                [
                                    0.30765610106922214,
                                    0.09229480994126545,
                                    0.46157855398361936,
                                    0.138470535005893,
                                ],
                                [
                                    0.03608485692318818,
                                    0.010825220107479893,
                                    0.7331497981296533,
                                    0.21994012483967856,
                                ],
                                [
                                    0.10206951136643398,
                                    0.01331316110714526,
                                    0.7825478161599868,
                                    0.10206951136643397,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.5236294416411803,
                                    0.0682981923170649,
                                    0.36098788588524044,
                                    0.04708448015651433,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.023455038515334037,
                                    0.023455038515334037,
                                    0.47654496148466596,
                                    0.47654496148466596,
                                ],
                                [
                                    0.04379962370630803,
                                    0.009453020722272993,
                                    0.7786876757751146,
                                    0.1680596797963044,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.6468060212853167,
                                    0.1395964212729176,
                                    0.1756812781961059,
                                    0.03791627924565978,
                                ],
                                [
                                    0.014210478915896657,
                                    0.04736929996793283,
                                    0.21655486603126184,
                                    0.7218653550849087,
                                ],
                                [
                                    0.18339604497922574,
                                    0.6113335320342571,
                                    0.04736929996793279,
                                    0.15790112301858447,
                                ],
                                [
                                    0.010825220107479895,
                                    0.03608485692318818,
                                    0.21994012483967862,
                                    0.7331497981296533,
                                ],
                                [
                                    0.008444319845623757,
                                    0.002380900261856124,
                                    0.7716155553146976,
                                    0.21755922457782245,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.7170354222550183,
                                    0.20217019911814865,
                                    0.0630244529053031,
                                    0.017769925721529915,
                                ],
                                [
                                    0.000991802322457926,
                                    0.02015082598338609,
                                    0.045918274708210145,
                                    0.9329390969859458,
                                ],
                                [
                                    0.04360399691898048,
                                    0.8859190326525506,
                                    0.003306080111687594,
                                    0.06717089031678135,
                                ],
                                [
                                    0.002200555327023212,
                                    0.04470952170364486,
                                    0.04470952170364486,
                                    0.9083804012656871,
                                ],
                                [
                                    0.04422553129030273,
                                    0.00048399041334210415,
                                    0.9449492486022174,
                                    0.010341229694137775,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08845106258060546,
                                    0.0009679808266842083,
                                    0.9007237173119147,
                                    0.00985723928079567,
                                ],
                                [
                                    0.042710580372676187,
                                    0.002102169550869595,
                                    0.9103793425966558,
                                    0.044807907479798424,
                                ],
                                [
                                    0.08532277496919871,
                                    0.0041994966579918976,
                                    0.8677671480001332,
                                    0.04271058037267612,
                                ],
                                [
                                    0.0525439981576981,
                                    0.002586159964211697,
                                    0.9005459248116339,
                                    0.044323917066456324,
                                ],
                                [
                                    0.03416324286820143,
                                    0.0019216140549867611,
                                    0.9125841127032176,
                                    0.051331030373594266,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.2423909744442148,
                                    0.013634007318651883,
                                    0.7043563811272041,
                                    0.03961863710992915,
                                ],
                                [
                                    0.028148348986680272,
                                    0.008444319845623778,
                                    0.7410863060661612,
                                    0.22232102510153468,
                                ],
                                [
                                    0.19733391505000927,
                                    0.05919887862197328,
                                    0.5719007400028322,
                                    0.17156646632518516,
                                ],
                                [
                                    0.06719051449936464,
                                    0.020156713109288897,
                                    0.7020441405534769,
                                    0.21060863183786954,
                                ],
                                [
                                    0.020748733488464063,
                                    0.0027063050268699733,
                                    0.8638685940379567,
                                    0.11267636744670925,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.06726268929934248,
                                    0.06726268929934248,
                                    0.4327373107006575,
                                    0.4327373107006575,
                                ],
                                [
                                    0.008903606052493124,
                                    0.0019216140549867587,
                                    0.8135836934289296,
                                    0.17559108646359065,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.6119100036315018,
                                    0.1320650146056314,
                                    0.2105772958499208,
                                    0.04544768591294602,
                                ],
                                [
                                    0.0028887121709719383,
                                    0.009629251354415317,
                                    0.22787663277618656,
                                    0.7596054036984262,
                                ],
                                [
                                    0.17207427823430102,
                                    0.5735934834207397,
                                    0.05869106671285748,
                                    0.1956411716321019,
                                ],
                                [
                                    0.04193087768365636,
                                    0.13977265190506002,
                                    0.18883446726350214,
                                    0.6294620031477814,
                                ],
                                [
                                    0.0017165649136811247,
                                    0.00048399041334210995,
                                    0.7783433102466403,
                                    0.21945613442633646,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.7103076673230756,
                                    0.20027328926963464,
                                    0.06975220783724574,
                                    0.01966683557004393,
                                ],
                                [
                                    0.0002016139960545219,
                                    0.004096268438091006,
                                    0.046708463034613554,
                                    0.948993654531241,
                                ],
                                [
                                    0.04281380859257708,
                                    0.8698644751072555,
                                    0.004096268438090997,
                                    0.0832254478620764,
                                ],
                                [
                                    0.010035031781076491,
                                    0.20388556729438354,
                                    0.036875045249591586,
                                    0.7492043556749484,
                                ],
                                [
                                    0.8870743039674259,
                                    0.021306097298261256,
                                    0.08947065751724008,
                                    0.0021489412170727544,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.8677671480001333,
                                    0.042710580372676124,
                                    0.08532277496919863,
                                    0.004199496657991893,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979843,
                                    0.042710580372676124,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.025402365736352274,
                                    0.0012502775496156732,
                                    0.9276875572329797,
                                    0.045659799481052345,
                                ],
                                [
                                    0.6485570150979889,
                                    0.08459278303166452,
                                    0.23606031242843187,
                                    0.030789889441914697,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.8431198605494926,
                                    0.10997006241983928,
                                    0.04149746697692809,
                                    0.005412610053739941,
                                ],
                                [
                                    0.5719007400028322,
                                    0.17156646632518516,
                                    0.19733391505000922,
                                    0.05919887862197327,
                                ],
                                [
                                    0.7410863060661613,
                                    0.2223210251015347,
                                    0.0281483489866802,
                                    0.008444319845623756,
                                ],
                                [
                                    -0.04057141817196846,
                                    -0.012171159018838758,
                                    0.8098060732248099,
                                    0.2429365039659972,
                                ],
                                [
                                    0.3574087211134995,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.1308637596288335,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.714817442226999,
                                    0.23827248074233298,
                                    0.035182557773001034,
                                    0.011727519257667011,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    -0.0845038214299213,
                                    -0.0845038214299213,
                                    0.5845038214299213,
                                    0.5845038214299213,
                                ],
                                [
                                    0.13534734180801408,
                                    0.08459278303166454,
                                    0.4800353306655652,
                                    0.3000245444947562,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.5865150239045053,
                                    0.36657489906482665,
                                    0.028867648569073975,
                                    0.018042428461594085,
                                ],
                                [
                                    0.05869106671285752,
                                    0.19564117163210204,
                                    0.172074278234301,
                                    0.5735934834207395,
                                ],
                                [
                                    0.22787663277618656,
                                    0.7596054036984262,
                                    0.0028887121709719426,
                                    0.00962925135441533,
                                ],
                                [
                                    -0.06583105498767668,
                                    -0.21944165354120107,
                                    0.29659639993483516,
                                    0.9886763085940425,
                                ],
                                [
                                    0.023403424405383573,
                                    0.021306097298261266,
                                    0.5000516141099505,
                                    0.4552388641864047,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.4988997223364884,
                                    0.45419020063284354,
                                    0.024555316178845644,
                                    0.02235476085182243,
                                ],
                                [
                                    0.004096268438090996,
                                    0.08322544786207639,
                                    0.04281380859257708,
                                    0.8698644751072555,
                                ],
                                [
                                    0.046708463034613554,
                                    0.948993654531241,
                                    0.00020161399605452123,
                                    0.0040962684380909916,
                                ],
                                [
                                    -0.017106600640269375,
                                    -0.34756132836538356,
                                    0.06401667767093745,
                                    1.3006512513347155,
                                ],
                                [
                                    0.7159537413770131,
                                    0.017196056752640375,
                                    0.26059122010765295,
                                    0.006258981762693634,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7596145995270968,
                                    0.018244720306201525,
                                    0.2169303619575693,
                                    0.005210318209132483,
                                ],
                                [
                                    0.7003710213181528,
                                    0.03447152022940794,
                                    0.2527189016511791,
                                    0.012438556801260077,
                                ],
                                [
                                    0.7429832159146753,
                                    0.03656884733653024,
                                    0.2101067070546566,
                                    0.010341229694137775,
                                ],
                                [
                                    0.03323684219040562,
                                    0.0016358821868041654,
                                    0.9198530807789264,
                                    0.04527419484386385,
                                ],
                                [
                                    0.523447494058811,
                                    0.06827446047545313,
                                    0.3611698334676098,
                                    0.047108211998126086,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.7180103395103147,
                                    0.09365173986362789,
                                    0.16660698801610596,
                                    0.02173093260995133,
                                ],
                                [
                                    0.4615785539836194,
                                    0.13847053500589301,
                                    0.3076561010692221,
                                    0.09229480994126542,
                                ],
                                [
                                    0.6307641200469485,
                                    0.18922509378224256,
                                    0.13847053500589301,
                                    0.0415402511649159,
                                ],
                                [
                                    -0.009465760595791992,
                                    -0.0028396660170297537,
                                    0.7787004156486335,
                                    0.2336050109641882,
                                ],
                                [
                                    0.28846299564481565,
                                    0.09615433188160522,
                                    0.46153700435518435,
                                    0.15384566811839478,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.645871716758315,
                                    0.21529057225277168,
                                    0.10412828324168494,
                                    0.034709427747228315,
                                ],
                                [
                                    0.20132987799400748,
                                    0.20132987799400748,
                                    0.2986701220059925,
                                    0.2986701220059925,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    -0.0406961706459128,
                                    -0.0406961706459128,
                                    0.5406961706459128,
                                    0.5406961706459128,
                                ],
                                [
                                    0.10923824004312432,
                                    0.06827446047545316,
                                    0.5061444324304549,
                                    0.3163428670509676,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.5604059221396155,
                                    0.35025657650861525,
                                    0.054976750333963736,
                                    0.034360751017805474,
                                ],
                                [
                                    0.04736929996793278,
                                    0.15790112301858444,
                                    0.18339604497922574,
                                    0.6113335320342571,
                                ],
                                [
                                    0.21655486603126187,
                                    0.7218653550849088,
                                    0.014210478915896644,
                                    0.04736929996793278,
                                ],
                                [
                                    -0.03472539741150027,
                                    -0.1157538585593294,
                                    0.26549074235865877,
                                    0.8849885136121709,
                                ],
                                [
                                    0.018888800170547792,
                                    0.0171960567526404,
                                    0.5045662383447862,
                                    0.45934890473202555,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.4943850981016526,
                                    0.4500801600872227,
                                    0.02906994041368144,
                                    0.02646480139744331,
                                ],
                                [
                                    0.0033060801116875918,
                                    0.0671708903167813,
                                    0.04360399691898048,
                                    0.8859190326525506,
                                ],
                                [
                                    0.045918274708210145,
                                    0.9329390969859458,
                                    0.0009918023224579234,
                                    0.020150825983386036,
                                ],
                                [
                                    -0.009272124186216096,
                                    -0.1883852827746449,
                                    0.05618220121688417,
                                    1.1414752057439768,
                                ],
                                [
                                    0.46536758105875475,
                                    0.011177380425911203,
                                    0.5111773804259112,
                                    0.012277658089422806,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5090284392088384,
                                    0.012226043979472353,
                                    0.4675165222758275,
                                    0.011228994535861656,
                                ],
                                [
                                    0.4552388641864047,
                                    0.02240637496177286,
                                    0.49785105878292724,
                                    0.02450370206889516,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889516,
                                    0.4552388641864047,
                                    0.02240637496177286,
                                ],
                                [
                                    0.04470952170364486,
                                    0.0022005553270232096,
                                    0.9083804012656871,
                                    0.04470952170364481,
                                ],
                                [
                                    0.3402391523967764,
                                    0.04437817512964435,
                                    0.5443781751296444,
                                    0.07100449734393487,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.5348019978482801,
                                    0.0697554545178191,
                                    0.34981532967814055,
                                    0.045627217955760115,
                                ],
                                [
                                    0.3000245444947562,
                                    0.09000539308540446,
                                    0.4692101105580853,
                                    0.140759951861754,
                                ],
                                [
                                    0.4692101105580853,
                                    0.140759951861754,
                                    0.3000245444947562,
                                    0.09000539308540446,
                                ],
                                [
                                    0.03608485692318818,
                                    0.010825220107479893,
                                    0.7331497981296533,
                                    0.21994012483967856,
                                ],
                                [0.1875, 0.0625, 0.5625, 0.1875],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.5449087211134995,
                                    0.1816362403711665,
                                    0.20509127888650053,
                                    0.06836375962883351,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.023455038515334037,
                                    0.023455038515334037,
                                    0.47654496148466596,
                                    0.47654496148466596,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.522172179440426,
                                    0.32636029116280646,
                                    0.09321049303315318,
                                    0.05825703636361427,
                                ],
                                [
                                    0.030789889441914717,
                                    0.10263521149325863,
                                    0.1999754555052438,
                                    0.6665994435595829,
                                ],
                                [
                                    0.1999754555052438,
                                    0.6665994435595829,
                                    0.030789889441914717,
                                    0.10263521149325863,
                                ],
                                [
                                    0.010825220107479895,
                                    0.03608485692318818,
                                    0.21994012483967862,
                                    0.7331497981296533,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.48777395602052764,
                                    0.4440614837604935,
                                    0.03568108249480639,
                                    0.03248347772417248,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                ],
                                [
                                    0.002200555327023212,
                                    0.04470952170364486,
                                    0.04470952170364486,
                                    0.9083804012656871,
                                ],
                                [
                                    0.21478142074049658,
                                    0.0051587040991820324,
                                    0.7617635407441694,
                                    0.01829633441615198,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25844227889058025,
                                    0.006207367652743183,
                                    0.7181026825940857,
                                    0.017247670862590825,
                                ],
                                [
                                    0.2101067070546567,
                                    0.01034122969413778,
                                    0.7429832159146752,
                                    0.036568847336530236,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260083,
                                    0.7003710213181527,
                                    0.034471520229407936,
                                ],
                                [
                                    0.0561822012168841,
                                    0.0027652284672422542,
                                    0.8969077217524478,
                                    0.044144848563425765,
                                ],
                                [
                                    0.1570308107347419,
                                    0.020481889783835583,
                                    0.7275865167916789,
                                    0.09490078268974364,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.35159365618624566,
                                    0.045859169172010335,
                                    0.5330236713401751,
                                    0.0695235033015689,
                                ],
                                [
                                    0.13847053500589307,
                                    0.04154025116491592,
                                    0.6307641200469484,
                                    0.18922509378224253,
                                ],
                                [
                                    0.30765610106922214,
                                    0.09229480994126545,
                                    0.46157855398361936,
                                    0.138470535005893,
                                ],
                                [
                                    0.08163547444216826,
                                    0.024490106231989512,
                                    0.6875991806106733,
                                    0.20627523871516892,
                                ],
                                [
                                    0.08653700435518444,
                                    0.028845668118394813,
                                    0.6634629956448156,
                                    0.2211543318816052,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.44394572546868394,
                                    0.1479819084895613,
                                    0.30605427453131606,
                                    0.1020180915104387,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.08760624767658087,
                                    0.08760624767658087,
                                    0.4123937523234191,
                                    0.4123937523234191,
                                ],
                                [
                                    0.03277075464474545,
                                    0.020481889783835572,
                                    0.5826119178288338,
                                    0.36413543774258517,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.48393843674123665,
                                    0.30246400581699767,
                                    0.13144423573234262,
                                    0.08215332170942306,
                                ],
                                [
                                    0.014210478915896657,
                                    0.04736929996793283,
                                    0.21655486603126184,
                                    0.7218653550849087,
                                ],
                                [
                                    0.18339604497922574,
                                    0.6113335320342571,
                                    0.04736929996793279,
                                    0.15790112301858447,
                                ],
                                [
                                    0.05637583762646001,
                                    0.1879235724057056,
                                    0.1743895073206985,
                                    0.5813110826471359,
                                ],
                                [
                                    0.00566651600829785,
                                    0.0051587040991820324,
                                    0.5177885225070362,
                                    0.47138625738548395,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.4811628139394027,
                                    0.4380428074337643,
                                    0.04229222457593136,
                                    0.03850215405090167,
                                ],
                                [
                                    0.000991802322457926,
                                    0.02015082598338609,
                                    0.045918274708210145,
                                    0.9329390969859458,
                                ],
                                [
                                    0.04360399691898048,
                                    0.8859190326525506,
                                    0.003306080111687594,
                                    0.06717089031678135,
                                ],
                                [
                                    0.013673234840262522,
                                    0.2778043261819346,
                                    0.033236842190405555,
                                    0.6752855967873973,
                                ],
                                [
                                    0.043660858150083685,
                                    0.0010486635535611516,
                                    0.9328841033345823,
                                    0.02240637496177286,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08732171630016737,
                                    0.002097327107122303,
                                    0.8892232451844986,
                                    0.021357711408211705,
                                ],
                                [
                                    0.042710580372676187,
                                    0.002102169550869595,
                                    0.9103793425966558,
                                    0.044807907479798424,
                                ],
                                [
                                    0.08532277496919871,
                                    0.0041994966579918976,
                                    0.8677671480001332,
                                    0.04271058037267612,
                                ],
                                [
                                    0.06401667767093745,
                                    0.003150833104430746,
                                    0.8890732452983945,
                                    0.04375924392623727,
                                ],
                                [
                                    0.031921289695564,
                                    0.004163567227624191,
                                    0.8526960378308568,
                                    0.11121910524595503,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.22648413514706775,
                                    0.029540846615798942,
                                    0.658133192379353,
                                    0.08584182585778029,
                                ],
                                [
                                    0.028148348986680272,
                                    0.008444319845623778,
                                    0.7410863060661612,
                                    0.22232102510153468,
                                ],
                                [
                                    0.19733391505000927,
                                    0.05919887862197328,
                                    0.5719007400028322,
                                    0.17156646632518516,
                                ],
                                [
                                    0.11274113201834472,
                                    0.033821599233798516,
                                    0.6564935230344968,
                                    0.19694374571335993,
                                ],
                                [
                                    0.017591278886500528,
                                    0.005863759628833509,
                                    0.7324087211134995,
                                    0.2441362403711665,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.13141389846058932,
                                    0.13141389846058932,
                                    0.3685861015394107,
                                    0.3685861015394107,
                                ],
                                [
                                    0.006661652879855697,
                                    0.004163567227624186,
                                    0.6087210195937236,
                                    0.3804537602987966,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.45782933497634687,
                                    0.2861456832607863,
                                    0.15755333749723235,
                                    0.09847164426563444,
                                ],
                                [
                                    0.0028887121709719383,
                                    0.009629251354415317,
                                    0.22787663277618656,
                                    0.7596054036984262,
                                ],
                                [
                                    0.17207427823430102,
                                    0.5735934834207397,
                                    0.05869106671285748,
                                    0.1956411716321019,
                                ],
                                [
                                    0.08748149520263647,
                                    0.2916113673875774,
                                    0.14328384974452202,
                                    0.4776232876652641,
                                ],
                                [
                                    0.0011518917734620708,
                                    0.001048663553561164,
                                    0.522303146741872,
                                    0.4754962979311048,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.4766481897045669,
                                    0.4339327668881434,
                                    0.046806848810767146,
                                    0.04261219459652253,
                                ],
                                [
                                    0.0002016139960545219,
                                    0.004096268438091006,
                                    0.046708463034613554,
                                    0.948993654531241,
                                ],
                                [
                                    0.04281380859257708,
                                    0.8698644751072555,
                                    0.004096268438090997,
                                    0.0832254478620764,
                                ],
                                [
                                    0.0215077112943158,
                                    0.4369803717726733,
                                    0.025402365736352274,
                                    0.5161095511966587,
                                ],
                                [
                                    0.8756016244541865,
                                    0.03277877681150055,
                                    0.08831351862262524,
                                    0.0033060801116875874,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.8677671480001333,
                                    0.042710580372676124,
                                    0.08532277496919863,
                                    0.004199496657991893,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979843,
                                    0.042710580372676124,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.03687504524959162,
                                    0.0018149506898347228,
                                    0.9162148777197403,
                                    0.0450951263408333,
                                ],
                                [
                                    0.6030063975790088,
                                    0.13014340055064463,
                                    0.21948090190241384,
                                    0.04736929996793276,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7839043569060029,
                                    0.16918556606332902,
                                    0.038582942575419665,
                                    0.00832713445524837,
                                ],
                                [
                                    0.5719007400028322,
                                    0.17156646632518516,
                                    0.19733391505000922,
                                    0.05919887862197327,
                                ],
                                [
                                    0.7410863060661613,
                                    0.2223210251015347,
                                    0.0281483489866802,
                                    0.008444319845623756,
                                ],
                                [
                                    0.0049791993470117155,
                                    0.0014937271056708877,
                                    0.7642554557058298,
                                    0.22927161784148756,
                                ],
                                [
                                    0.29325751195225264,
                                    0.18328744953241333,
                                    0.3221251605213266,
                                    0.20132987799400742,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.5865150239045053,
                                    0.36657489906482665,
                                    0.028867648569073968,
                                    0.018042428461594078,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    -0.020352612268674464,
                                    -0.020352612268674464,
                                    0.5203526122686745,
                                    0.5203526122686745,
                                ],
                                [
                                    0.08979672428903396,
                                    0.13014340055064466,
                                    0.318481321176702,
                                    0.46157855398361936,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.3891256909030077,
                                    0.5639642320663242,
                                    0.01915235456272827,
                                    0.02775772246793979,
                                ],
                                [
                                    0.05869106671285752,
                                    0.19564117163210204,
                                    0.172074278234301,
                                    0.5735934834207395,
                                ],
                                [
                                    0.22787663277618656,
                                    0.7596054036984262,
                                    0.0028887121709719426,
                                    0.00962925135441533,
                                ],
                                [
                                    -0.02028043746869657,
                                    -0.06760293805868367,
                                    0.25104578241585507,
                                    0.8368375931115252,
                                ],
                                [
                                    0.011930744892144272,
                                    0.032778776811500564,
                                    0.2549194569782024,
                                    0.7003710213181528,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.2543322383449594,
                                    0.6987576846243725,
                                    0.01251796352538729,
                                    0.034392113505280784,
                                ],
                                [
                                    0.004096268438090996,
                                    0.08322544786207639,
                                    0.04281380859257708,
                                    0.8698644751072555,
                                ],
                                [
                                    0.046708463034613554,
                                    0.948993654531241,
                                    0.00020161399605452123,
                                    0.0040962684380909916,
                                ],
                                [
                                    -0.005633921127030066,
                                    -0.1144665238870938,
                                    0.05254399815769814,
                                    1.0675564468564258,
                                ],
                                [
                                    0.7066941925608806,
                                    0.026455605568772807,
                                    0.25722095051593125,
                                    0.009629251354415327,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.7497903775707452,
                                    0.028068942262553007,
                                    0.21412476550606663,
                                    0.008015914660635129,
                                ],
                                [
                                    0.7003710213181528,
                                    0.03447152022940794,
                                    0.2527189016511791,
                                    0.012438556801260077,
                                ],
                                [
                                    0.7429832159146753,
                                    0.03656884733653024,
                                    0.2101067070546566,
                                    0.010341229694137775,
                                ],
                                [
                                    0.04470952170364486,
                                    0.0022005553270232096,
                                    0.9083804012656871,
                                    0.04470952170364481,
                                ],
                                [
                                    0.48668379242875603,
                                    0.1050381621055081,
                                    0.3358035070526666,
                                    0.07247453841306929,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6675817517557502,
                                    0.14408032761819248,
                                    0.15490554772567242,
                                    0.033432372900384914,
                                ],
                                [
                                    0.4615785539836194,
                                    0.13847053500589301,
                                    0.3076561010692221,
                                    0.09229480994126542,
                                ],
                                [
                                    0.6307641200469485,
                                    0.18922509378224256,
                                    0.13847053500589301,
                                    0.0415402511649159,
                                ],
                                [
                                    0.03608485692318818,
                                    0.010825220107479893,
                                    0.7331497981296533,
                                    0.21994012483967856,
                                ],
                                [
                                    0.2366868388928548,
                                    0.14793048863356606,
                                    0.37869583358072445,
                                    0.2366868388928547,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.5299443508451074,
                                    0.33121793816597933,
                                    0.08543832162847187,
                                    0.0533993893604414,
                                ],
                                [
                                    0.20132987799400748,
                                    0.20132987799400748,
                                    0.2986701220059925,
                                    0.2986701220059925,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.023455038515334037,
                                    0.023455038515334037,
                                    0.47654496148466596,
                                    0.47654496148466596,
                                ],
                                [
                                    0.07247453841306935,
                                    0.10503816210550813,
                                    0.33580350705266665,
                                    0.48668379242875587,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.3718035050270431,
                                    0.5388589936211877,
                                    0.03647454043869288,
                                    0.05286296091307633,
                                ],
                                [
                                    0.04736929996793278,
                                    0.15790112301858444,
                                    0.18339604497922574,
                                    0.6113335320342571,
                                ],
                                [
                                    0.21655486603126187,
                                    0.7218653550849088,
                                    0.014210478915896644,
                                    0.04736929996793278,
                                ],
                                [
                                    0.010825220107479895,
                                    0.03608485692318818,
                                    0.21994012483967862,
                                    0.7331497981296533,
                                ],
                                [
                                    0.009629251354415346,
                                    0.026455605568772845,
                                    0.25722095051593136,
                                    0.7066941925608805,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.2520307448072305,
                                    0.6924345133816449,
                                    0.014819457063116222,
                                    0.04071528474800853,
                                ],
                                [
                                    0.0033060801116875918,
                                    0.0671708903167813,
                                    0.04360399691898048,
                                    0.8859190326525506,
                                ],
                                [
                                    0.045918274708210145,
                                    0.9329390969859458,
                                    0.0009918023224579234,
                                    0.020150825983386036,
                                ],
                                [
                                    0.002200555327023212,
                                    0.04470952170364486,
                                    0.04470952170364486,
                                    0.9083804012656871,
                                ],
                                [
                                    0.45934890473202555,
                                    0.01719605675264037,
                                    0.5045662383447862,
                                    0.018888800170547764,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.5024450897418902,
                                    0.01880939344642057,
                                    0.4614700533349216,
                                    0.017275463476767564,
                                ],
                                [
                                    0.4552388641864047,
                                    0.02240637496177286,
                                    0.49785105878292724,
                                    0.02450370206889516,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889516,
                                    0.4552388641864047,
                                    0.02240637496177286,
                                ],
                                [
                                    0.0561822012168841,
                                    0.0027652284672422542,
                                    0.8969077217524478,
                                    0.044144848563425765,
                                ],
                                [
                                    0.31634286705096765,
                                    0.06827446047545312,
                                    0.506144432430455,
                                    0.10923824004312428,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4972408263779618,
                                    0.1073166259881375,
                                    0.32524647310346083,
                                    0.07019607453043988,
                                ],
                                [
                                    0.3000245444947562,
                                    0.09000539308540446,
                                    0.4692101105580853,
                                    0.140759951861754,
                                ],
                                [
                                    0.4692101105580853,
                                    0.140759951861754,
                                    0.3000245444947562,
                                    0.09000539308540446,
                                ],
                                [
                                    0.08163547444216826,
                                    0.024490106231989512,
                                    0.6875991806106733,
                                    0.20627523871516892,
                                ],
                                [
                                    0.1538456681183948,
                                    0.09615433188160519,
                                    0.4615370043551844,
                                    0.2884629956448156,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.4471031800706474,
                                    0.27944178141401854,
                                    0.1682794924029318,
                                    0.10517554611240224,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.08760624767658087,
                                    0.08760624767658087,
                                    0.4123937523234191,
                                    0.4123937523234191,
                                ],
                                [
                                    0.047108211998126114,
                                    0.06827446047545314,
                                    0.3611698334676099,
                                    0.5234474940588109,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.3464371786120999,
                                    0.5020952919911327,
                                    0.06184086685363612,
                                    0.08962666254313133,
                                ],
                                [
                                    0.030789889441914717,
                                    0.10263521149325863,
                                    0.1999754555052438,
                                    0.6665994435595829,
                                ],
                                [
                                    0.1999754555052438,
                                    0.6665994435595829,
                                    0.030789889441914717,
                                    0.10263521149325863,
                                ],
                                [
                                    0.05637583762646001,
                                    0.1879235724057056,
                                    0.1743895073206985,
                                    0.5813110826471359,
                                ],
                                [
                                    0.006258981762693645,
                                    0.017196056752640392,
                                    0.26059122010765307,
                                    0.715953741377013,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.24866047521550877,
                                    0.6831749645655123,
                                    0.018189726654837916,
                                    0.04997483356414096,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                ],
                                [
                                    0.013673234840262522,
                                    0.2778043261819346,
                                    0.033236842190405555,
                                    0.6752855967873973,
                                ],
                                [
                                    0.21200361690317066,
                                    0.00793650793650794,
                                    0.7519115261736411,
                                    0.028148348986680196,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.25509980191303533,
                                    0.009549844630288138,
                                    0.7088153411637765,
                                    0.026535012292899996,
                                ],
                                [
                                    0.2101067070546567,
                                    0.01034122969413778,
                                    0.7429832159146752,
                                    0.036568847336530236,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260083,
                                    0.7003710213181527,
                                    0.034471520229407936,
                                ],
                                [
                                    0.06765488073012345,
                                    0.0033299016074613036,
                                    0.8854350422392084,
                                    0.04358017542320671,
                                ],
                                [
                                    0.14600194167317931,
                                    0.03151075884539816,
                                    0.6764853578082433,
                                    0.14600194167317923,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.32689990100017347,
                                    0.07055292435808254,
                                    0.49558739848124916,
                                    0.10695977616049486,
                                ],
                                [
                                    0.13847053500589307,
                                    0.04154025116491592,
                                    0.6307641200469484,
                                    0.18922509378224253,
                                ],
                                [
                                    0.30765610106922214,
                                    0.09229480994126545,
                                    0.46157855398361936,
                                    0.138470535005893,
                                ],
                                [
                                    0.12718609196114844,
                                    0.038154992356499155,
                                    0.6420485630916931,
                                    0.19261035259065928,
                                ],
                                [
                                    0.0710044973439349,
                                    0.044378175129644364,
                                    0.5443781751296444,
                                    0.3402391523967764,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3642620092961875,
                                    0.2276656246620577,
                                    0.25112066317739173,
                                    0.15695170286436305,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.1517574568378277,
                                    0.1517574568378277,
                                    0.3482425431621723,
                                    0.3482425431621723,
                                ],
                                [
                                    0.021741885583182873,
                                    0.03151075884539815,
                                    0.38653615988255313,
                                    0.5602111956888659,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.32107085219715664,
                                    0.4653315903610777,
                                    0.08720719326857936,
                                    0.1263903641731863,
                                ],
                                [
                                    0.014210478915896657,
                                    0.04736929996793283,
                                    0.21655486603126184,
                                    0.7218653550849087,
                                ],
                                [
                                    0.18339604497922574,
                                    0.6113335320342571,
                                    0.04736929996793279,
                                    0.15790112301858447,
                                ],
                                [
                                    0.10192645514544015,
                                    0.3397622878882231,
                                    0.12883888980171834,
                                    0.4294723671646184,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.24529020562378706,
                                    0.6739154157493799,
                                    0.021559996246559618,
                                    0.05923438238027341,
                                ],
                                [
                                    0.000991802322457926,
                                    0.02015082598338609,
                                    0.045918274708210145,
                                    0.9329390969859458,
                                ],
                                [
                                    0.04360399691898048,
                                    0.8859190326525506,
                                    0.003306080111687594,
                                    0.06717089031678135,
                                ],
                                [
                                    0.025145914353501823,
                                    0.5108991306602243,
                                    0.02176416267716625,
                                    0.4421907923091077,
                                ],
                                [
                                    0.04309618500986464,
                                    0.0016133366937801986,
                                    0.9208189580669471,
                                    0.034471520229407936,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.08619237001972928,
                                    0.003226673387560397,
                                    0.8777227730570826,
                                    0.032858183535627736,
                                ],
                                [
                                    0.042710580372676187,
                                    0.002102169550869595,
                                    0.9103793425966558,
                                    0.044807907479798424,
                                ],
                                [
                                    0.08532277496919871,
                                    0.0041994966579918976,
                                    0.8677671480001332,
                                    0.04271058037267612,
                                ],
                                [
                                    0.0754893571841767,
                                    0.003715506244649791,
                                    0.8776005657851552,
                                    0.043194570786018224,
                                ],
                                [
                                    0.02967933652292657,
                                    0.0064055204002616195,
                                    0.7928079629584961,
                                    0.17110718011831577,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.21057729584992071,
                                    0.045447685912946,
                                    0.6119100036315019,
                                    0.13206501460563141,
                                ],
                                [
                                    0.028148348986680272,
                                    0.008444319845623778,
                                    0.7410863060661612,
                                    0.22232102510153468,
                                ],
                                [
                                    0.19733391505000927,
                                    0.05919887862197328,
                                    0.5719007400028322,
                                    0.17156646632518516,
                                ],
                                [
                                    0.1582917495373249,
                                    0.04748648535830816,
                                    0.6109429055155166,
                                    0.1832788595888503,
                                ],
                                [
                                    0.014433824284536993,
                                    0.009021214230797044,
                                    0.6009488481890423,
                                    0.3755961132956237,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.19556510762183615,
                                    0.19556510762183615,
                                    0.30443489237816385,
                                    0.30443489237816385,
                                ],
                                [
                                    0.004419699707218271,
                                    0.006405520400261612,
                                    0.4038583457585177,
                                    0.5853164341340024,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.303748666321192,
                                    0.44022635191594117,
                                    0.10452937914454397,
                                    0.15149560261832284,
                                ],
                                [
                                    0.0028887121709719383,
                                    0.009629251354415317,
                                    0.22787663277618656,
                                    0.7596054036984262,
                                ],
                                [
                                    0.17207427823430102,
                                    0.5735934834207397,
                                    0.05869106671285748,
                                    0.1956411716321019,
                                ],
                                [
                                    0.1330321127216166,
                                    0.4434500828700949,
                                    0.0977332322255419,
                                    0.3257845721827466,
                                ],
                                [
                                    0.000587218633243017,
                                    0.0016133366937802177,
                                    0.2662629832371037,
                                    0.7315364614358731,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.24298871208605816,
                                    0.6675922445066522,
                                    0.023861489784288543,
                                    0.06555755362300113,
                                ],
                                [
                                    0.0002016139960545219,
                                    0.004096268438091006,
                                    0.046708463034613554,
                                    0.948993654531241,
                                ],
                                [
                                    0.04281380859257708,
                                    0.8698644751072555,
                                    0.004096268438090997,
                                    0.0832254478620764,
                                ],
                                [
                                    0.032980390807555104,
                                    0.6700751762509629,
                                    0.013929686223112971,
                                    0.283014746718369,
                                ],
                                [
                                    0.8677671480001333,
                                    0.040613253265553824,
                                    0.08752333029622184,
                                    0.004096268438090988,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.8677671480001333,
                                    0.042710580372676124,
                                    0.08532277496919863,
                                    0.004199496657991893,
                                ],
                                [
                                    0.9103793425966559,
                                    0.04480790747979843,
                                    0.042710580372676124,
                                    0.0021021695508695918,
                                ],
                                [
                                    0.04470952170364486,
                                    0.0022005553270232096,
                                    0.9083804012656871,
                                    0.04470952170364481,
                                ],
                                [
                                    0.5719007400028323,
                                    0.1612490581268211,
                                    0.2081591351574891,
                                    0.058691066712857454,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7434672063280174,
                                    0.2096227166413145,
                                    0.036592668832303964,
                                    0.010317408198364065,
                                ],
                                [
                                    0.5719007400028322,
                                    0.17156646632518516,
                                    0.19733391505000922,
                                    0.05919887862197327,
                                ],
                                [
                                    0.7410863060661613,
                                    0.2223210251015347,
                                    0.0281483489866802,
                                    0.008444319845623756,
                                ],
                                [
                                    0.03608485692318818,
                                    0.010825220107479893,
                                    0.7331497981296533,
                                    0.21994012483967856,
                                ],
                                [
                                    0.2494498611682442,
                                    0.22709510031642177,
                                    0.27400517734708985,
                                    0.2494498611682442,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.4988997223364884,
                                    0.45419020063284354,
                                    0.02455531617884563,
                                    0.022354760851822416,
                                ],
                                [
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.2505501388317558,
                                    0.2505501388317558,
                                ],
                                [
                                    0.4877223419105772,
                                    0.4877223419105772,
                                    0.012277658089422806,
                                    0.012277658089422806,
                                ],
                                [
                                    0.023455038515334037,
                                    0.023455038515334037,
                                    0.47654496148466596,
                                    0.47654496148466596,
                                ],
                                [
                                    0.058691066712857495,
                                    0.16124905812682114,
                                    0.2081591351574892,
                                    0.5719007400028322,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739452,
                                    0.00039062651874043086,
                                ],
                                [
                                    0.2543322383449594,
                                    0.6987576846243725,
                                    0.012517963525387286,
                                    0.03439211350528078,
                                ],
                                [
                                    0.05869106671285752,
                                    0.19564117163210204,
                                    0.172074278234301,
                                    0.5735934834207395,
                                ],
                                [
                                    0.22787663277618656,
                                    0.7596054036984262,
                                    0.0028887121709719426,
                                    0.00962925135441533,
                                ],
                                [
                                    0.010825220107479895,
                                    0.03608485692318818,
                                    0.21994012483967862,
                                    0.7331497981296533,
                                ],
                                [
                                    0.004096268438090994,
                                    0.040613253265553845,
                                    0.08752333029622192,
                                    0.8677671480001332,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.002102169550869594,
                                    9.838577615361539e-05,
                                ],
                                [
                                    0.0873217163001674,
                                    0.8657682066691645,
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                ],
                                [
                                    0.004096268438090996,
                                    0.08322544786207639,
                                    0.04281380859257708,
                                    0.8698644751072555,
                                ],
                                [
                                    0.046708463034613554,
                                    0.948993654531241,
                                    0.00020161399605452123,
                                    0.0040962684380909916,
                                ],
                                [
                                    0.002200555327023212,
                                    0.04470952170364486,
                                    0.04470952170364486,
                                    0.9083804012656871,
                                ],
                                [
                                    0.7003710213181529,
                                    0.03277877681150055,
                                    0.25491945697820234,
                                    0.01193074489214426,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.743081601690829,
                                    0.03477771814246924,
                                    0.2122088766055262,
                                    0.009931803561175572,
                                ],
                                [
                                    0.7003710213181528,
                                    0.03447152022940794,
                                    0.2527189016511791,
                                    0.012438556801260077,
                                ],
                                [
                                    0.7429832159146753,
                                    0.03656884733653024,
                                    0.2101067070546566,
                                    0.010341229694137775,
                                ],
                                [
                                    0.0525439981576981,
                                    0.002586159964211697,
                                    0.9005459248116339,
                                    0.044323917066456324,
                                ],
                                [
                                    0.46157855398361947,
                                    0.13014340055064466,
                                    0.3184813211767019,
                                    0.0897967242890339,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.6331450203088046,
                                    0.17851705906513804,
                                    0.14691485485151679,
                                    0.04142306577454052,
                                ],
                                [
                                    0.4615785539836194,
                                    0.13847053500589301,
                                    0.3076561010692221,
                                    0.09229480994126542,
                                ],
                                [
                                    0.6307641200469485,
                                    0.18922509378224256,
                                    0.13847053500589301,
                                    0.0415402511649159,
                                ],
                                [
                                    0.06719051449936464,
                                    0.020156713109288897,
                                    0.7020441405534769,
                                    0.21060863183786954,
                                ],
                                [
                                    0.20132987799400748,
                                    0.18328744953241338,
                                    0.32212516052132656,
                                    0.2932575119522526,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.4507797391622516,
                                    0.4103825498488351,
                                    0.07267529935308241,
                                    0.06616241163583085,
                                ],
                                [
                                    0.20132987799400748,
                                    0.20132987799400748,
                                    0.2986701220059925,
                                    0.2986701220059925,
                                ],
                                [
                                    0.4396023587363404,
                                    0.4396023587363404,
                                    0.06039764126365958,
                                    0.06039764126365958,
                                ],
                                [
                                    0.06726268929934248,
                                    0.06726268929934248,
                                    0.4327373107006575,
                                    0.4327373107006575,
                                ],
                                [
                                    0.0473692999679328,
                                    0.1301434005506447,
                                    0.2194809019024139,
                                    0.6030063975790086,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.04379962370630805,
                                    0.009453020722272996,
                                ],
                                [
                                    0.24301047160003472,
                                    0.667652027048196,
                                    0.023839730270311985,
                                    0.06549777108145723,
                                ],
                                [
                                    0.04736929996793278,
                                    0.15790112301858444,
                                    0.18339604497922574,
                                    0.6113335320342571,
                                ],
                                [
                                    0.21655486603126187,
                                    0.7218653550849088,
                                    0.014210478915896644,
                                    0.04736929996793278,
                                ],
                                [
                                    0.04193087768365636,
                                    0.13977265190506002,
                                    0.18883446726350214,
                                    0.6294620031477814,
                                ],
                                [
                                    0.0033060801116875952,
                                    0.0327787768115006,
                                    0.08831351862262532,
                                    0.8756016244541865,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623766,
                                    0.0023809002618561262,
                                ],
                                [
                                    0.086531527973764,
                                    0.8579337302151113,
                                    0.005088070760548919,
                                    0.05044667105057583,
                                ],
                                [
                                    0.0033060801116875918,
                                    0.0671708903167813,
                                    0.04360399691898048,
                                    0.8859190326525506,
                                ],
                                [
                                    0.045918274708210145,
                                    0.9329390969859458,
                                    0.0009918023224579234,
                                    0.020150825983386036,
                                ],
                                [
                                    0.010035031781076491,
                                    0.20388556729438354,
                                    0.036875045249591586,
                                    0.7492043556749484,
                                ],
                                [
                                    0.4552388641864047,
                                    0.021306097298261252,
                                    0.5000516141099505,
                                    0.02340342440538356,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.49794944455908086,
                                    0.023305038629229943,
                                    0.4573410337372743,
                                    0.02140448307441487,
                                ],
                                [
                                    0.4552388641864047,
                                    0.02240637496177286,
                                    0.49785105878292724,
                                    0.02450370206889516,
                                ],
                                [
                                    0.49785105878292724,
                                    0.02450370206889516,
                                    0.4552388641864047,
                                    0.02240637496177286,
                                ],
                                [
                                    0.06401667767093745,
                                    0.003150833104430746,
                                    0.8890732452983945,
                                    0.04375924392623727,
                                ],
                                [
                                    0.3000245444947562,
                                    0.08459278303166452,
                                    0.4800353306655652,
                                    0.13534734180801405,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.4715910108199413,
                                    0.1329664415461579,
                                    0.30846886434038,
                                    0.08697368329352065,
                                ],
                                [
                                    0.3000245444947562,
                                    0.09000539308540446,
                                    0.4692101105580853,
                                    0.140759951861754,
                                ],
                                [
                                    0.4692101105580853,
                                    0.140759951861754,
                                    0.3000245444947562,
                                    0.09000539308540446,
                                ],
                                [
                                    0.11274113201834472,
                                    0.033821599233798516,
                                    0.6564935230344968,
                                    0.19694374571335993,
                                ],
                                [
                                    0.1308637596288335,
                                    0.11913624037116649,
                                    0.3925912788865005,
                                    0.3574087211134995,
                                ],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.3803136207970777,
                                    0.34623134068758826,
                                    0.14314141771825634,
                                    0.1303136207970777,
                                ],
                                [
                                    0.1308637596288335,
                                    0.1308637596288335,
                                    0.3691362403711665,
                                    0.3691362403711665,
                                ],
                                [
                                    0.3691362403711665,
                                    0.3691362403711665,
                                    0.1308637596288335,
                                    0.1308637596288335,
                                ],
                                [
                                    0.13141389846058932,
                                    0.13141389846058932,
                                    0.3685861015394107,
                                    0.3685861015394107,
                                ],
                                [
                                    0.030789889441914717,
                                    0.08459278303166454,
                                    0.23606031242843198,
                                    0.6485570150979888,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.0710044973439349,
                                    0.044378175129644364,
                                ],
                                [
                                    0.22643106107401662,
                                    0.6221014095292159,
                                    0.040419140796330064,
                                    0.11104838860043738,
                                ],
                                [
                                    0.030789889441914717,
                                    0.10263521149325863,
                                    0.1999754555052438,
                                    0.6665994435595829,
                                ],
                                [
                                    0.1999754555052438,
                                    0.6665994435595829,
                                    0.030789889441914717,
                                    0.10263521149325863,
                                ],
                                [
                                    0.08748149520263647,
                                    0.2916113673875774,
                                    0.14328384974452202,
                                    0.4776232876652641,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.021306097298261276,
                                    0.08947065751724015,
                                    0.8870743039674258,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422822,
                                    0.011177380425911215,
                                ],
                                [
                                    0.08537438907914915,
                                    0.8464610507018719,
                                    0.006245209655163753,
                                    0.061919350563815125,
                                ],
                                [
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                    0.04476113581359532,
                                    0.9094290648192482,
                                ],
                                [
                                    0.04476113581359532,
                                    0.9094290648192482,
                                    0.0021489412170727588,
                                    0.0436608581500837,
                                ],
                                [
                                    0.0215077112943158,
                                    0.4369803717726733,
                                    0.025402365736352274,
                                    0.5161095511966587,
                                ],
                                [
                                    0.21010670705465664,
                                    0.009833417785021961,
                                    0.7451837712416985,
                                    0.03487610391862285,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.2528172874273328,
                                    0.011832359115990648,
                                    0.7024731908690224,
                                    0.03287716258765416,
                                ],
                                [
                                    0.2101067070546567,
                                    0.01034122969413778,
                                    0.7429832159146752,
                                    0.036568847336530236,
                                ],
                                [
                                    0.2527189016511792,
                                    0.012438556801260083,
                                    0.7003710213181527,
                                    0.034471520229407936,
                                ],
                                [
                                    0.0754893571841767,
                                    0.003715506244649791,
                                    0.8776005657851552,
                                    0.043194570786018224,
                                ],
                                [
                                    0.13847053500589307,
                                    0.039042165512684406,
                                    0.6415893401544284,
                                    0.18089795932699415,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.3100370013310782,
                                    0.08741582402717779,
                                    0.4700228738292432,
                                    0.13252430081250077,
                                ],
                                [
                                    0.13847053500589307,
                                    0.04154025116491592,
                                    0.6307641200469484,
                                    0.18922509378224253,
                                ],
                                [
                                    0.30765610106922214,
                                    0.09229480994126545,
                                    0.46157855398361936,
                                    0.138470535005893,
                                ],
                                [
                                    0.1582917495373249,
                                    0.04748648535830816,
                                    0.6109429055155166,
                                    0.1832788595888503,
                                ],
                                [
                                    0.060397641263659596,
                                    0.054985031209919655,
                                    0.46305739725167444,
                                    0.4215599302747463,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.3098475024319038,
                                    0.2820801315263414,
                                    0.21360753608343025,
                                    0.19446482995832454,
                                ],
                                [
                                    0.060397641263659596,
                                    0.060397641263659596,
                                    0.4396023587363404,
                                    0.4396023587363404,
                                ],
                                [
                                    0.2986701220059926,
                                    0.2986701220059926,
                                    0.20132987799400742,
                                    0.20132987799400742,
                                ],
                                [
                                    0.19556510762183615,
                                    0.19556510762183615,
                                    0.30443489237816385,
                                    0.30443489237816385,
                                ],
                                [
                                    0.014210478915896638,
                                    0.039042165512684385,
                                    0.25263972295445003,
                                    0.694107632616969,
                                ],
                                [
                                    0.33580350705266665,
                                    0.48668379242875587,
                                    0.07247453841306935,
                                    0.1050381621055081,
                                ],
                                [
                                    0.20985165054799854,
                                    0.5765507920102357,
                                    0.05699855132234814,
                                    0.15659900611941752,
                                ],
                                [
                                    0.014210478915896657,
                                    0.04736929996793283,
                                    0.21655486603126184,
                                    0.7218653550849087,
                                ],
                                [
                                    0.18339604497922574,
                                    0.6113335320342571,
                                    0.04736929996793279,
                                    0.15790112301858447,
                                ],
                                [
                                    0.1330321127216166,
                                    0.4434500828700949,
                                    0.0977332322255419,
                                    0.3257845721827466,
                                ],
                                [
                                    0.0009918023224579225,
                                    0.00983341778502196,
                                    0.09062779641185499,
                                    0.8985469834806651,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.009629251354415343,
                                    0.026455605568772834,
                                ],
                                [
                                    0.08421725018453433,
                                    0.8349883711886327,
                                    0.007402348549778589,
                                    0.07339203007705444,
                                ],
                                [
                                    0.000991802322457926,
                                    0.02015082598338609,
                                    0.045918274708210145,
                                    0.9329390969859458,
                                ],
                                [
                                    0.04360399691898048,
                                    0.8859190326525506,
                                    0.003306080111687594,
                                    0.06717089031678135,
                                ],
                                [
                                    0.032980390807555104,
                                    0.6700751762509629,
                                    0.013929686223112971,
                                    0.283014746718369,
                                ],
                                [
                                    0.04271058037267615,
                                    0.0019989413309686875,
                                    0.912579897923679,
                                    0.042710580372676124,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.0854211607453523,
                                    0.003997882661937375,
                                    0.8698693175510028,
                                    0.04071163904170744,
                                ],
                                [
                                    0.042710580372676187,
                                    0.002102169550869595,
                                    0.9103793425966558,
                                    0.044807907479798424,
                                ],
                                [
                                    0.08532277496919871,
                                    0.0041994966579918976,
                                    0.8677671480001332,
                                    0.04271058037267612,
                                ],
                                [
                                    0.08332383363823004,
                                    0.004101110881838283,
                                    0.8697660893311019,
                                    0.04280896614882974,
                                ],
                                [
                                    0.028148348986680238,
                                    0.00793650793650795,
                                    0.7519115261736411,
                                    0.2120036169031706,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.19971481531186536,
                                    0.05631016645100133,
                                    0.5803450598484561,
                                    0.16362995838867722,
                                ],
                                [
                                    0.028148348986680272,
                                    0.008444319845623778,
                                    0.7410863060661612,
                                    0.22232102510153468,
                                ],
                                [
                                    0.19733391505000927,
                                    0.05919887862197328,
                                    0.5719007400028322,
                                    0.17156646632518516,
                                ],
                                [
                                    0.18939740711350128,
                                    0.05681797836011714,
                                    0.5798372479393402,
                                    0.1739473665870413,
                                ],
                                [
                                    0.012277658089422822,
                                    0.011177380425911215,
                                    0.5111773804259112,
                                    0.46536758105875475,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.012277658089422827,
                                    0.012277658089422827,
                                    0.4877223419105772,
                                    0.4877223419105772,
                                ],
                                [
                                    0.2505501388317558,
                                    0.2505501388317558,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                ],
                                [
                                    0.2393727584058446,
                                    0.2393727584058446,
                                    0.2606272415941554,
                                    0.2606272415941554,
                                ],
                                [
                                    0.0028887121709719426,
                                    0.00793650793650794,
                                    0.2639614896993748,
                                    0.7252132901931454,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857495,
                                    0.16124905812682114,
                                ],
                                [
                                    0.19852988380307385,
                                    0.5454451344340593,
                                    0.06832031806727284,
                                    0.18770466369559397,
                                ],
                                [
                                    0.0028887121709719383,
                                    0.009629251354415317,
                                    0.22787663277618656,
                                    0.7596054036984262,
                                ],
                                [
                                    0.17207427823430102,
                                    0.5735934834207397,
                                    0.05869106671285748,
                                    0.1956411716321019,
                                ],
                                [
                                    0.16413777029779308,
                                    0.5471378778519668,
                                    0.06662757464936543,
                                    0.22209677720087473,
                                ],
                                [
                                    0.00020161399605452348,
                                    0.0019989413309687114,
                                    0.09141798473825839,
                                    0.9063814599347184,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.004096268438090996,
                                    0.040613253265553866,
                                ],
                                [
                                    0.08342706185813092,
                                    0.8271538947345795,
                                    0.008192536876181988,
                                    0.08122650653110769,
                                ],
                                [
                                    0.0002016139960545219,
                                    0.004096268438091006,
                                    0.046708463034613554,
                                    0.948993654531241,
                                ],
                                [
                                    0.04281380859257708,
                                    0.8698644751072555,
                                    0.004096268438090997,
                                    0.0832254478620764,
                                ],
                                [
                                    0.040814867261608385,
                                    0.8292512218417016,
                                    0.0060952097690596865,
                                    0.12383870112763025,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                2.0285190579120734e-08,
                                2.0285190579120734e-08,
                                2.0285190579120734e-08,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                9.831100172023885e-07,
                                9.831100172023885e-07,
                                9.831100172023885e-07,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.415628951691087e-06,
                                5.415628951691087e-06,
                                5.415628951691087e-06,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                1.0644968816443206e-05,
                                1.0644968816443206e-05,
                                1.0644968816443206e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.016905174423377e-06,
                                8.016905174423377e-06,
                                8.016905174423377e-06,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                4.870709175414403e-08,
                                4.870709175414403e-08,
                                4.870709175414403e-08,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                2.3605610026450347e-06,
                                2.3605610026450347e-06,
                                2.3605610026450347e-06,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                1.3003552282516942e-05,
                                1.3003552282516942e-05,
                                1.3003552282516942e-05,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                2.555980289365243e-05,
                                2.555980289365243e-05,
                                2.555980289365243e-05,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                1.9249517740140302e-05,
                                1.9249517740140302e-05,
                                1.9249517740140302e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                2.0285190579120734e-08,
                                2.0285190579120734e-08,
                                2.0285190579120734e-08,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                9.831100172023885e-07,
                                9.831100172023885e-07,
                                9.831100172023885e-07,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.415628951691087e-06,
                                5.415628951691087e-06,
                                5.415628951691087e-06,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                1.0644968816443206e-05,
                                1.0644968816443206e-05,
                                1.0644968816443206e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.016905174423377e-06,
                                8.016905174423377e-06,
                                8.016905174423377e-06,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                8.278426984104325e-08,
                                8.278426984104325e-08,
                                8.278426984104325e-08,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                4.012091709470294e-06,
                                4.012091709470294e-06,
                                4.012091709470294e-06,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                2.2101290433880363e-05,
                                2.2101290433880363e-05,
                                2.2101290433880363e-05,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                4.344233136547255e-05,
                                4.344233136547255e-05,
                                4.344233136547255e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.2717150901832336e-05,
                                3.2717150901832336e-05,
                                3.2717150901832336e-05,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                9.83958007325669e-08,
                                9.83958007325669e-08,
                                9.83958007325669e-08,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                4.768695515752438e-06,
                                4.768695515752438e-06,
                                4.768695515752438e-06,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                2.6269171349102207e-05,
                                2.6269171349102207e-05,
                                2.6269171349102207e-05,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                5.163472467176272e-05,
                                5.163472467176272e-05,
                                5.163472467176272e-05,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                3.888698018180706e-05,
                                3.888698018180706e-05,
                                3.888698018180706e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                8.278426984104325e-08,
                                8.278426984104325e-08,
                                8.278426984104325e-08,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                4.012091709470294e-06,
                                4.012091709470294e-06,
                                4.012091709470294e-06,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                2.2101290433880363e-05,
                                2.2101290433880363e-05,
                                2.2101290433880363e-05,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                4.344233136547255e-05,
                                4.344233136547255e-05,
                                4.344233136547255e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.2717150901832336e-05,
                                3.2717150901832336e-05,
                                3.2717150901832336e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                4.870709175414402e-08,
                                4.870709175414402e-08,
                                4.870709175414402e-08,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                2.3605610026450343e-06,
                                2.3605610026450343e-06,
                                2.3605610026450343e-06,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                1.3003552282516939e-05,
                                1.3003552282516939e-05,
                                1.3003552282516939e-05,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                2.555980289365242e-05,
                                2.555980289365242e-05,
                                2.555980289365242e-05,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                1.92495177401403e-05,
                                1.92495177401403e-05,
                                1.92495177401403e-05,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                9.839580073256688e-08,
                                9.839580073256688e-08,
                                9.839580073256688e-08,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                4.768695515752437e-06,
                                4.768695515752437e-06,
                                4.768695515752437e-06,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                2.62691713491022e-05,
                                2.62691713491022e-05,
                                2.62691713491022e-05,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                5.1634724671762716e-05,
                                5.1634724671762716e-05,
                                5.1634724671762716e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                3.8886980181807044e-05,
                                3.8886980181807044e-05,
                                3.8886980181807044e-05,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                1.1695136793974533e-07,
                                1.1695136793974533e-07,
                                1.1695136793974533e-07,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                5.667980337607928e-06,
                                5.667980337607928e-06,
                                5.667980337607928e-06,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                3.1223034936939446e-05,
                                3.1223034936939446e-05,
                                3.1223034936939446e-05,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                6.13720467600816e-05,
                                6.13720467600816e-05,
                                6.13720467600816e-05,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                4.6220321329250075e-05,
                                4.6220321329250075e-05,
                                4.6220321329250075e-05,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                9.839580073256688e-08,
                                9.839580073256688e-08,
                                9.839580073256688e-08,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                4.768695515752437e-06,
                                4.768695515752437e-06,
                                4.768695515752437e-06,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                2.62691713491022e-05,
                                2.62691713491022e-05,
                                2.62691713491022e-05,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                5.1634724671762716e-05,
                                5.1634724671762716e-05,
                                5.1634724671762716e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                3.8886980181807044e-05,
                                3.8886980181807044e-05,
                                3.8886980181807044e-05,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                4.870709175414402e-08,
                                4.870709175414402e-08,
                                4.870709175414402e-08,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                2.3605610026450343e-06,
                                2.3605610026450343e-06,
                                2.3605610026450343e-06,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                1.3003552282516939e-05,
                                1.3003552282516939e-05,
                                1.3003552282516939e-05,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                2.555980289365242e-05,
                                2.555980289365242e-05,
                                2.555980289365242e-05,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                1.92495177401403e-05,
                                1.92495177401403e-05,
                                1.92495177401403e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                8.278426984104325e-08,
                                8.278426984104325e-08,
                                8.278426984104325e-08,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                4.012091709470294e-06,
                                4.012091709470294e-06,
                                4.012091709470294e-06,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                2.2101290433880363e-05,
                                2.2101290433880363e-05,
                                2.2101290433880363e-05,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                4.344233136547255e-05,
                                4.344233136547255e-05,
                                4.344233136547255e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.2717150901832336e-05,
                                3.2717150901832336e-05,
                                3.2717150901832336e-05,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                9.83958007325669e-08,
                                9.83958007325669e-08,
                                9.83958007325669e-08,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                4.768695515752438e-06,
                                4.768695515752438e-06,
                                4.768695515752438e-06,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                2.6269171349102207e-05,
                                2.6269171349102207e-05,
                                2.6269171349102207e-05,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                5.163472467176272e-05,
                                5.163472467176272e-05,
                                5.163472467176272e-05,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                3.888698018180706e-05,
                                3.888698018180706e-05,
                                3.888698018180706e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                8.278426984104325e-08,
                                8.278426984104325e-08,
                                8.278426984104325e-08,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                4.012091709470294e-06,
                                4.012091709470294e-06,
                                4.012091709470294e-06,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                2.2101290433880363e-05,
                                2.2101290433880363e-05,
                                2.2101290433880363e-05,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                4.344233136547255e-05,
                                4.344233136547255e-05,
                                4.344233136547255e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.2717150901832336e-05,
                                3.2717150901832336e-05,
                                3.2717150901832336e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                2.0285190579120734e-08,
                                2.0285190579120734e-08,
                                2.0285190579120734e-08,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                9.831100172023885e-07,
                                9.831100172023885e-07,
                                9.831100172023885e-07,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.415628951691087e-06,
                                5.415628951691087e-06,
                                5.415628951691087e-06,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                1.0644968816443206e-05,
                                1.0644968816443206e-05,
                                1.0644968816443206e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.016905174423377e-06,
                                8.016905174423377e-06,
                                8.016905174423377e-06,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                4.870709175414403e-08,
                                4.870709175414403e-08,
                                4.870709175414403e-08,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                2.3605610026450347e-06,
                                2.3605610026450347e-06,
                                2.3605610026450347e-06,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                1.3003552282516942e-05,
                                1.3003552282516942e-05,
                                1.3003552282516942e-05,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                2.555980289365243e-05,
                                2.555980289365243e-05,
                                2.555980289365243e-05,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                1.9249517740140302e-05,
                                1.9249517740140302e-05,
                                1.9249517740140302e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                4.0979198267888545e-08,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                1.986033118937069e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                1.0940401653662253e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                2.1504470760728986e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                1.619537885809684e-05,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                2.0285190579120734e-08,
                                2.0285190579120734e-08,
                                2.0285190579120734e-08,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                9.831100172023885e-07,
                                9.831100172023885e-07,
                                9.831100172023885e-07,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.415628951691087e-06,
                                5.415628951691087e-06,
                                5.415628951691087e-06,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                1.0644968816443206e-05,
                                1.0644968816443206e-05,
                                1.0644968816443206e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.016905174423377e-06,
                                8.016905174423377e-06,
                                8.016905174423377e-06,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                1.9984702056171233e-07,
                                1.9984702056171233e-07,
                                1.9984702056171233e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                9.35086948931191e-06,
                                9.35086948931191e-06,
                                9.35086948931191e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                4.875295095670919e-05,
                                4.875295095670919e-05,
                                4.875295095670919e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                9.026587564844659e-05,
                                9.026587564844659e-05,
                                9.026587564844659e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                6.505610313033519e-05,
                                6.505610313033519e-05,
                                6.505610313033519e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                4.0372165333633193e-07,
                                4.0372165333633193e-07,
                                4.0372165333633193e-07,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                9.848844336005396e-05,
                                9.848844336005396e-05,
                                9.848844336005396e-05,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                4.798558401176998e-07,
                                4.798558401176998e-07,
                                4.798558401176998e-07,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                2.245252054302774e-05,
                                2.245252054302774e-05,
                                2.245252054302774e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00011706148119593592,
                                0.00011706148119593592,
                                0.00011706148119593592,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00021673882088159386,
                                0.00021673882088159386,
                                0.00021673882088159386,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                0.00015620723758926795,
                                0.00015620723758926795,
                                0.00015620723758926795,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                4.0372165333633193e-07,
                                4.0372165333633193e-07,
                                4.0372165333633193e-07,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                9.848844336005396e-05,
                                9.848844336005396e-05,
                                9.848844336005396e-05,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                1.9984702056171233e-07,
                                1.9984702056171233e-07,
                                1.9984702056171233e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                9.35086948931191e-06,
                                9.35086948931191e-06,
                                9.35086948931191e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                4.875295095670919e-05,
                                4.875295095670919e-05,
                                4.875295095670919e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                9.026587564844659e-05,
                                9.026587564844659e-05,
                                9.026587564844659e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                6.505610313033519e-05,
                                6.505610313033519e-05,
                                6.505610313033519e-05,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                4.0372165333633183e-07,
                                4.0372165333633183e-07,
                                4.0372165333633183e-07,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                9.848844336005395e-05,
                                9.848844336005395e-05,
                                9.848844336005395e-05,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                8.155797014861677e-07,
                                8.155797014861677e-07,
                                8.155797014861677e-07,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                3.816108604118075e-05,
                                3.816108604118075e-05,
                                3.816108604118075e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0001989617712392378,
                                0.0001989617712392378,
                                0.0001989617712392378,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00036837684999669153,
                                0.00036837684999669153,
                                0.00036837684999669153,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0002654952624350373,
                                0.0002654952624350373,
                                0.0002654952624350373,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                9.6938244358559e-07,
                                9.6938244358559e-07,
                                9.6938244358559e-07,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                4.535753742898557e-05,
                                4.535753742898557e-05,
                                4.535753742898557e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.00023648215819074126,
                                0.00023648215819074126,
                                0.00023648215819074126,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0004378456824752296,
                                0.0004378456824752296,
                                0.0004378456824752296,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00031556259405511806,
                                0.00031556259405511806,
                                0.00031556259405511806,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                8.155797014861677e-07,
                                8.155797014861677e-07,
                                8.155797014861677e-07,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                3.816108604118075e-05,
                                3.816108604118075e-05,
                                3.816108604118075e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0001989617712392378,
                                0.0001989617712392378,
                                0.0001989617712392378,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00036837684999669153,
                                0.00036837684999669153,
                                0.00036837684999669153,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0002654952624350373,
                                0.0002654952624350373,
                                0.0002654952624350373,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                4.0372165333633183e-07,
                                4.0372165333633183e-07,
                                4.0372165333633183e-07,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                9.848844336005395e-05,
                                9.848844336005395e-05,
                                9.848844336005395e-05,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                4.798558401176997e-07,
                                4.798558401176997e-07,
                                4.798558401176997e-07,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                2.2452520543027737e-05,
                                2.2452520543027737e-05,
                                2.2452520543027737e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00011706148119593592,
                                0.00011706148119593592,
                                0.00011706148119593592,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002167388208815938,
                                0.0002167388208815938,
                                0.0002167388208815938,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.0001562072375892679,
                                0.0001562072375892679,
                                0.0001562072375892679,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                9.6938244358559e-07,
                                9.6938244358559e-07,
                                9.6938244358559e-07,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                4.535753742898557e-05,
                                4.535753742898557e-05,
                                4.535753742898557e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.00023648215819074126,
                                0.00023648215819074126,
                                0.00023648215819074126,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0004378456824752296,
                                0.0004378456824752296,
                                0.0004378456824752296,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00031556259405511806,
                                0.00031556259405511806,
                                0.00031556259405511806,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                1.1521894429442304e-06,
                                1.1521894429442304e-06,
                                1.1521894429442304e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                5.391110199017208e-05,
                                5.391110199017208e-05,
                                5.391110199017208e-05,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.00028107817292853844,
                                0.00028107817292853844,
                                0.00028107817292853844,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.000520415008879959,
                                0.000520415008879959,
                                0.000520415008879959,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.00037507166739429444,
                                0.00037507166739429444,
                                0.00037507166739429444,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                9.6938244358559e-07,
                                9.6938244358559e-07,
                                9.6938244358559e-07,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                4.535753742898557e-05,
                                4.535753742898557e-05,
                                4.535753742898557e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.00023648215819074126,
                                0.00023648215819074126,
                                0.00023648215819074126,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0004378456824752296,
                                0.0004378456824752296,
                                0.0004378456824752296,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00031556259405511806,
                                0.00031556259405511806,
                                0.00031556259405511806,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                4.798558401176997e-07,
                                4.798558401176997e-07,
                                4.798558401176997e-07,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                2.2452520543027737e-05,
                                2.2452520543027737e-05,
                                2.2452520543027737e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00011706148119593592,
                                0.00011706148119593592,
                                0.00011706148119593592,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002167388208815938,
                                0.0002167388208815938,
                                0.0002167388208815938,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.0001562072375892679,
                                0.0001562072375892679,
                                0.0001562072375892679,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                4.0372165333633183e-07,
                                4.0372165333633183e-07,
                                4.0372165333633183e-07,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                9.848844336005395e-05,
                                9.848844336005395e-05,
                                9.848844336005395e-05,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                8.155797014861677e-07,
                                8.155797014861677e-07,
                                8.155797014861677e-07,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                3.816108604118075e-05,
                                3.816108604118075e-05,
                                3.816108604118075e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0001989617712392378,
                                0.0001989617712392378,
                                0.0001989617712392378,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00036837684999669153,
                                0.00036837684999669153,
                                0.00036837684999669153,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0002654952624350373,
                                0.0002654952624350373,
                                0.0002654952624350373,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                9.6938244358559e-07,
                                9.6938244358559e-07,
                                9.6938244358559e-07,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                4.535753742898557e-05,
                                4.535753742898557e-05,
                                4.535753742898557e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.00023648215819074126,
                                0.00023648215819074126,
                                0.00023648215819074126,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0004378456824752296,
                                0.0004378456824752296,
                                0.0004378456824752296,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00031556259405511806,
                                0.00031556259405511806,
                                0.00031556259405511806,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                8.155797014861677e-07,
                                8.155797014861677e-07,
                                8.155797014861677e-07,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                3.816108604118075e-05,
                                3.816108604118075e-05,
                                3.816108604118075e-05,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.0001989617712392378,
                                0.0001989617712392378,
                                0.0001989617712392378,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00036837684999669153,
                                0.00036837684999669153,
                                0.00036837684999669153,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0002654952624350373,
                                0.0002654952624350373,
                                0.0002654952624350373,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                4.0372165333633183e-07,
                                4.0372165333633183e-07,
                                4.0372165333633183e-07,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                9.848844336005395e-05,
                                9.848844336005395e-05,
                                9.848844336005395e-05,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                1.9984702056171233e-07,
                                1.9984702056171233e-07,
                                1.9984702056171233e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                9.35086948931191e-06,
                                9.35086948931191e-06,
                                9.35086948931191e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                4.875295095670919e-05,
                                4.875295095670919e-05,
                                4.875295095670919e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                9.026587564844659e-05,
                                9.026587564844659e-05,
                                9.026587564844659e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                6.505610313033519e-05,
                                6.505610313033519e-05,
                                6.505610313033519e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                4.0372165333633193e-07,
                                4.0372165333633193e-07,
                                4.0372165333633193e-07,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                9.848844336005396e-05,
                                9.848844336005396e-05,
                                9.848844336005396e-05,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                4.798558401176998e-07,
                                4.798558401176998e-07,
                                4.798558401176998e-07,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                2.245252054302774e-05,
                                2.245252054302774e-05,
                                2.245252054302774e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00011706148119593592,
                                0.00011706148119593592,
                                0.00011706148119593592,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00021673882088159386,
                                0.00021673882088159386,
                                0.00021673882088159386,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                0.00015620723758926795,
                                0.00015620723758926795,
                                0.00015620723758926795,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                4.0372165333633193e-07,
                                4.0372165333633193e-07,
                                4.0372165333633193e-07,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                1.8890191506215166e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                9.848844336005396e-05,
                                9.848844336005396e-05,
                                9.848844336005396e-05,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                0.0001823509224916831,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                0.00013142331289991584,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                1.9984702056171233e-07,
                                1.9984702056171233e-07,
                                1.9984702056171233e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                9.35086948931191e-06,
                                9.35086948931191e-06,
                                9.35086948931191e-06,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                4.875295095670919e-05,
                                4.875295095670919e-05,
                                4.875295095670919e-05,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                9.026587564844659e-05,
                                9.026587564844659e-05,
                                9.026587564844659e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                6.505610313033519e-05,
                                6.505610313033519e-05,
                                6.505610313033519e-05,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                5.080951425866894e-07,
                                5.080951425866894e-07,
                                5.080951425866894e-07,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                2.2500983089433784e-05,
                                2.2500983089433784e-05,
                                2.2500983089433784e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00010644735784282795,
                                0.00010644735784282795,
                                0.00010644735784282795,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00017392732560589228,
                                0.00017392732560589228,
                                0.00017392732560589228,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                0.00011242622989280595,
                                0.00011242622989280595,
                                0.00011242622989280595,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                1.2199952784903772e-06,
                                1.2199952784903772e-06,
                                1.2199952784903772e-06,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                5.4027466176410906e-05,
                                5.4027466176410906e-05,
                                5.4027466176410906e-05,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.00025559243356448457,
                                0.00025559243356448457,
                                0.00025559243356448457,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                0.00041761965083821653,
                                0.00041761965083821653,
                                0.00041761965083821653,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                0.00026994839775366534,
                                0.00026994839775366534,
                                0.00026994839775366534,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                5.080951425866894e-07,
                                5.080951425866894e-07,
                                5.080951425866894e-07,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                2.2500983089433784e-05,
                                2.2500983089433784e-05,
                                2.2500983089433784e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00010644735784282795,
                                0.00010644735784282795,
                                0.00010644735784282795,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00017392732560589228,
                                0.00017392732560589228,
                                0.00017392732560589228,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                0.00011242622989280595,
                                0.00011242622989280595,
                                0.00011242622989280595,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                2.073546473460988e-06,
                                2.073546473460988e-06,
                                2.073546473460988e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                9.182696354264068e-05,
                                9.182696354264068e-05,
                                9.182696354264068e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0004344138035654939,
                                0.0004344138035654939,
                                0.0004344138035654939,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0007098009062093459,
                                0.0007098009062093459,
                                0.0007098009062093459,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00045881370038676906,
                                0.00045881370038676906,
                                0.00045881370038676906,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                2.4645777030364036e-06,
                                2.4645777030364036e-06,
                                2.4645777030364036e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00010914377361746979,
                                0.00010914377361746979,
                                0.00010914377361746979,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0005163359432073494,
                                0.0005163359432073494,
                                0.0005163359432073494,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0008436557894546269,
                                0.0008436557894546269,
                                0.0008436557894546269,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.0005453371941712261,
                                0.0005453371941712261,
                                0.0005453371941712261,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                2.073546473460988e-06,
                                2.073546473460988e-06,
                                2.073546473460988e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                9.182696354264068e-05,
                                9.182696354264068e-05,
                                9.182696354264068e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0004344138035654939,
                                0.0004344138035654939,
                                0.0004344138035654939,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0007098009062093459,
                                0.0007098009062093459,
                                0.0007098009062093459,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00045881370038676906,
                                0.00045881370038676906,
                                0.00045881370038676906,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                2.381385910243316e-06,
                                2.381385910243316e-06,
                                2.381385910243316e-06,
                                1.2199952784903774e-06,
                                1.2199952784903774e-06,
                                1.2199952784903774e-06,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                5.4027466176410906e-05,
                                5.4027466176410906e-05,
                                5.4027466176410906e-05,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.00025559243356448457,
                                0.00025559243356448457,
                                0.00025559243356448457,
                                0.0003132104529203512,
                                0.0003132104529203512,
                                0.0003132104529203512,
                                0.0004176196508382166,
                                0.0004176196508382166,
                                0.0004176196508382166,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                0.00026994839775366534,
                                0.00026994839775366534,
                                0.00026994839775366534,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                2.4645777030364036e-06,
                                2.4645777030364036e-06,
                                2.4645777030364036e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00010914377361746979,
                                0.00010914377361746979,
                                0.00010914377361746979,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0005163359432073494,
                                0.0005163359432073494,
                                0.0005163359432073494,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0008436557894546269,
                                0.0008436557894546269,
                                0.0008436557894546269,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.0005453371941712261,
                                0.0005453371941712261,
                                0.0005453371941712261,
                                5.717983352428262e-06,
                                5.717983352428262e-06,
                                5.717983352428262e-06,
                                2.929349948046137e-06,
                                2.929349948046137e-06,
                                2.929349948046137e-06,
                                0.00022561143211105526,
                                0.00022561143211105526,
                                0.00022561143211105526,
                                0.00012972620306594244,
                                0.00012972620306594244,
                                0.00012972620306594244,
                                0.000818276043286085,
                                0.000818276043286085,
                                0.000818276043286085,
                                0.0006137070324645638,
                                0.0006137070324645638,
                                0.0006137070324645638,
                                0.0007520545695267414,
                                0.0007520545695267414,
                                0.0007520545695267414,
                                0.0010027531450775404,
                                0.0010027531450775404,
                                0.0010027531450775404,
                                0.00011617444817545152,
                                0.00011617444817545152,
                                0.00011617444817545152,
                                0.0006481773650086094,
                                0.0006481773650086094,
                                0.0006481773650086094,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                2.4645777030364036e-06,
                                2.4645777030364036e-06,
                                2.4645777030364036e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00010914377361746979,
                                0.00010914377361746979,
                                0.00010914377361746979,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0005163359432073494,
                                0.0005163359432073494,
                                0.0005163359432073494,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0008436557894546269,
                                0.0008436557894546269,
                                0.0008436557894546269,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.0005453371941712261,
                                0.0005453371941712261,
                                0.0005453371941712261,
                                2.381385910243316e-06,
                                2.381385910243316e-06,
                                2.381385910243316e-06,
                                1.2199952784903774e-06,
                                1.2199952784903774e-06,
                                1.2199952784903774e-06,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                5.4027466176410906e-05,
                                5.4027466176410906e-05,
                                5.4027466176410906e-05,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.0003407899114193128,
                                0.00025559243356448457,
                                0.00025559243356448457,
                                0.00025559243356448457,
                                0.0003132104529203512,
                                0.0003132104529203512,
                                0.0003132104529203512,
                                0.0004176196508382166,
                                0.0004176196508382166,
                                0.0004176196508382166,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                0.00026994839775366534,
                                0.00026994839775366534,
                                0.00026994839775366534,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                2.073546473460988e-06,
                                2.073546473460988e-06,
                                2.073546473460988e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                9.182696354264068e-05,
                                9.182696354264068e-05,
                                9.182696354264068e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0004344138035654939,
                                0.0004344138035654939,
                                0.0004344138035654939,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0007098009062093459,
                                0.0007098009062093459,
                                0.0007098009062093459,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00045881370038676906,
                                0.00045881370038676906,
                                0.00045881370038676906,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                2.4645777030364036e-06,
                                2.4645777030364036e-06,
                                2.4645777030364036e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00010914377361746979,
                                0.00010914377361746979,
                                0.00010914377361746979,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0005163359432073494,
                                0.0005163359432073494,
                                0.0005163359432073494,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0008436557894546269,
                                0.0008436557894546269,
                                0.0008436557894546269,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.0005453371941712261,
                                0.0005453371941712261,
                                0.0005453371941712261,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                2.073546473460988e-06,
                                2.073546473460988e-06,
                                2.073546473460988e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                9.182696354264068e-05,
                                9.182696354264068e-05,
                                9.182696354264068e-05,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0004344138035654939,
                                0.0004344138035654939,
                                0.0004344138035654939,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0007098009062093459,
                                0.0007098009062093459,
                                0.0007098009062093459,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00045881370038676906,
                                0.00045881370038676906,
                                0.00045881370038676906,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                5.080951425866894e-07,
                                5.080951425866894e-07,
                                5.080951425866894e-07,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                2.2500983089433784e-05,
                                2.2500983089433784e-05,
                                2.2500983089433784e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00010644735784282795,
                                0.00010644735784282795,
                                0.00010644735784282795,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00017392732560589228,
                                0.00017392732560589228,
                                0.00017392732560589228,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                0.00011242622989280595,
                                0.00011242622989280595,
                                0.00011242622989280595,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                1.2199952784903772e-06,
                                1.2199952784903772e-06,
                                1.2199952784903772e-06,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                5.4027466176410906e-05,
                                5.4027466176410906e-05,
                                5.4027466176410906e-05,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.00025559243356448457,
                                0.00025559243356448457,
                                0.00025559243356448457,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                0.00041761965083821653,
                                0.00041761965083821653,
                                0.00041761965083821653,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                0.00026994839775366534,
                                0.00026994839775366534,
                                0.00026994839775366534,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                1.0264301686394878e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                4.545543921058304e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.00021504000000000022,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                0.00035135989146405186,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                0.00022711823915672622,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                5.080951425866894e-07,
                                5.080951425866894e-07,
                                5.080951425866894e-07,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                2.2500983089433784e-05,
                                2.2500983089433784e-05,
                                2.2500983089433784e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00010644735784282795,
                                0.00010644735784282795,
                                0.00010644735784282795,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00017392732560589228,
                                0.00017392732560589228,
                                0.00017392732560589228,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                0.00011242622989280595,
                                0.00011242622989280595,
                                0.00011242622989280595,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                6.491599200430032e-07,
                                6.491599200430032e-07,
                                6.491599200430032e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                2.70791699179754e-05,
                                2.70791699179754e-05,
                                2.70791699179754e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011305219055292343,
                                0.00011305219055292343,
                                0.00011305219055292343,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00014936150401517043,
                                0.00014936150401517043,
                                0.00014936150401517043,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                7.418496464287944e-05,
                                7.418496464287944e-05,
                                7.418496464287944e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.3114026692157394e-06,
                                1.3114026692157394e-06,
                                1.3114026692157394e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0002283827757603535,
                                0.0002283827757603535,
                                0.0002283827757603535,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                1.558708145497634e-06,
                                1.558708145497634e-06,
                                1.558708145497634e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                6.502022293931314e-05,
                                6.502022293931314e-05,
                                6.502022293931314e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0002714514017894376,
                                0.0002714514017894376,
                                0.0002714514017894376,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00035863426829678787,
                                0.00035863426829678787,
                                0.00035863426829678787,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                0.00017812669126992647,
                                0.00017812669126992647,
                                0.00017812669126992647,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.3114026692157394e-06,
                                1.3114026692157394e-06,
                                1.3114026692157394e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0002283827757603535,
                                0.0002283827757603535,
                                0.0002283827757603535,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                6.491599200430032e-07,
                                6.491599200430032e-07,
                                6.491599200430032e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                2.70791699179754e-05,
                                2.70791699179754e-05,
                                2.70791699179754e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011305219055292343,
                                0.00011305219055292343,
                                0.00011305219055292343,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00014936150401517043,
                                0.00014936150401517043,
                                0.00014936150401517043,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                7.418496464287944e-05,
                                7.418496464287944e-05,
                                7.418496464287944e-05,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.311402669215739e-06,
                                1.311402669215739e-06,
                                1.311402669215739e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00022838277576035348,
                                0.00022838277576035348,
                                0.00022838277576035348,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                2.649234661179082e-06,
                                2.649234661179082e-06,
                                2.649234661179082e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00011051063586597592,
                                0.00011051063586597592,
                                0.00011051063586597592,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00046136825840262425,
                                0.00046136825840262425,
                                0.00046136825840262425,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.0006095472953053168,
                                0.0006095472953053168,
                                0.0006095472953053168,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0003027503294677245,
                                0.0003027503294677245,
                                0.0003027503294677245,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                3.1488296788232124e-06,
                                3.1488296788232124e-06,
                                3.1488296788232124e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.0001313508294072887,
                                0.0001313508294072887,
                                0.0001313508294072887,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005483734929991376,
                                0.0005483734929991376,
                                0.0005483734929991376,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0007244962638566557,
                                0.0007244962638566557,
                                0.0007244962638566557,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00035984325460893375,
                                0.00035984325460893375,
                                0.00035984325460893375,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                2.649234661179082e-06,
                                2.649234661179082e-06,
                                2.649234661179082e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00011051063586597592,
                                0.00011051063586597592,
                                0.00011051063586597592,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00046136825840262425,
                                0.00046136825840262425,
                                0.00046136825840262425,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.0006095472953053168,
                                0.0006095472953053168,
                                0.0006095472953053168,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0003027503294677245,
                                0.0003027503294677245,
                                0.0003027503294677245,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.311402669215739e-06,
                                1.311402669215739e-06,
                                1.311402669215739e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00022838277576035348,
                                0.00022838277576035348,
                                0.00022838277576035348,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.5587081454976336e-06,
                                1.5587081454976336e-06,
                                1.5587081454976336e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                6.502022293931311e-05,
                                6.502022293931311e-05,
                                6.502022293931311e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002714514017894375,
                                0.0002714514017894375,
                                0.0002714514017894375,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0003586342682967878,
                                0.0003586342682967878,
                                0.0003586342682967878,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00017812669126992641,
                                0.00017812669126992641,
                                0.00017812669126992641,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                3.1488296788232124e-06,
                                3.1488296788232124e-06,
                                3.1488296788232124e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.0001313508294072887,
                                0.0001313508294072887,
                                0.0001313508294072887,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005483734929991376,
                                0.0005483734929991376,
                                0.0005483734929991376,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0007244962638566557,
                                0.0007244962638566557,
                                0.0007244962638566557,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00035984325460893375,
                                0.00035984325460893375,
                                0.00035984325460893375,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                4.810765025232856e-06,
                                3.742638767161915e-06,
                                3.742638767161915e-06,
                                3.742638767161915e-06,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.00018981580043104517,
                                0.000156121085095435,
                                0.000156121085095435,
                                0.000156121085095435,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006884479242764659,
                                0.0006517862517573767,
                                0.0006517862517573767,
                                0.0006517862517573767,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.0006327331853125031,
                                0.000861122410656154,
                                0.000861122410656154,
                                0.000861122410656154,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                9.774214747771968e-05,
                                0.0004277028141148702,
                                0.0004277028141148702,
                                0.0004277028141148702,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                3.1488296788232124e-06,
                                3.1488296788232124e-06,
                                3.1488296788232124e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.0001313508294072887,
                                0.0001313508294072887,
                                0.0001313508294072887,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005483734929991376,
                                0.0005483734929991376,
                                0.0005483734929991376,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0007244962638566557,
                                0.0007244962638566557,
                                0.0007244962638566557,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00035984325460893375,
                                0.00035984325460893375,
                                0.00035984325460893375,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.5587081454976336e-06,
                                1.5587081454976336e-06,
                                1.5587081454976336e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                6.502022293931311e-05,
                                6.502022293931311e-05,
                                6.502022293931311e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002714514017894375,
                                0.0002714514017894375,
                                0.0002714514017894375,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0003586342682967878,
                                0.0003586342682967878,
                                0.0003586342682967878,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                0.00017812669126992641,
                                0.00017812669126992641,
                                0.00017812669126992641,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.311402669215739e-06,
                                1.311402669215739e-06,
                                1.311402669215739e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00022838277576035348,
                                0.00022838277576035348,
                                0.00022838277576035348,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                2.649234661179082e-06,
                                2.649234661179082e-06,
                                2.649234661179082e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00011051063586597592,
                                0.00011051063586597592,
                                0.00011051063586597592,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00046136825840262425,
                                0.00046136825840262425,
                                0.00046136825840262425,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.0006095472953053168,
                                0.0006095472953053168,
                                0.0006095472953053168,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0003027503294677245,
                                0.0003027503294677245,
                                0.0003027503294677245,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                4.047486447853216e-06,
                                3.1488296788232124e-06,
                                3.1488296788232124e-06,
                                3.1488296788232124e-06,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.00015969952300796044,
                                0.0001313508294072887,
                                0.0001313508294072887,
                                0.0001313508294072887,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005792184047539919,
                                0.0005483734929991376,
                                0.0005483734929991376,
                                0.0005483734929991376,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0005323433963676898,
                                0.0007244962638566557,
                                0.0007244962638566557,
                                0.0007244962638566557,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                8.223432556467296e-05,
                                0.00035984325460893375,
                                0.00035984325460893375,
                                0.00035984325460893375,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                3.405310061836265e-06,
                                2.649234661179082e-06,
                                2.649234661179082e-06,
                                2.649234661179082e-06,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00013436151042776315,
                                0.00011051063586597592,
                                0.00011051063586597592,
                                0.00011051063586597592,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00048731929979794954,
                                0.00046136825840262425,
                                0.00046136825840262425,
                                0.00046136825840262425,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.00044788150556118354,
                                0.0006095472953053168,
                                0.0006095472953053168,
                                0.0006095472953053168,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                6.918698305271152e-05,
                                0.0003027503294677245,
                                0.0003027503294677245,
                                0.0003027503294677245,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.6856689858541066e-06,
                                1.311402669215739e-06,
                                1.311402669215739e-06,
                                1.311402669215739e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.0002412288499316808,
                                0.00022838277576035348,
                                0.00022838277576035348,
                                0.00022838277576035348,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00022170667268255108,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                3.424837957160365e-05,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                6.491599200430032e-07,
                                6.491599200430032e-07,
                                6.491599200430032e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                2.70791699179754e-05,
                                2.70791699179754e-05,
                                2.70791699179754e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011305219055292343,
                                0.00011305219055292343,
                                0.00011305219055292343,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00014936150401517043,
                                0.00014936150401517043,
                                0.00014936150401517043,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                7.418496464287944e-05,
                                7.418496464287944e-05,
                                7.418496464287944e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.3114026692157394e-06,
                                1.3114026692157394e-06,
                                1.3114026692157394e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0002283827757603535,
                                0.0002283827757603535,
                                0.0002283827757603535,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                1.558708145497634e-06,
                                1.558708145497634e-06,
                                1.558708145497634e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                6.502022293931314e-05,
                                6.502022293931314e-05,
                                6.502022293931314e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.0002714514017894376,
                                0.0002714514017894376,
                                0.0002714514017894376,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00035863426829678787,
                                0.00035863426829678787,
                                0.00035863426829678787,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                0.00017812669126992647,
                                0.00017812669126992647,
                                0.00017812669126992647,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.3114026692157394e-06,
                                1.3114026692157394e-06,
                                1.3114026692157394e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                5.4704079247879394e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.0002283827757603535,
                                0.0002283827757603535,
                                0.0002283827757603535,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                0.00030173316157688294,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                0.00014986501422007488,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                6.491599200430032e-07,
                                6.491599200430032e-07,
                                6.491599200430032e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                2.70791699179754e-05,
                                2.70791699179754e-05,
                                2.70791699179754e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011305219055292343,
                                0.00011305219055292343,
                                0.00011305219055292343,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00014936150401517043,
                                0.00014936150401517043,
                                0.00014936150401517043,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                7.418496464287944e-05,
                                7.418496464287944e-05,
                                7.418496464287944e-05,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                3.9458358567900084e-07,
                                3.9458358567900084e-07,
                                3.9458358567900084e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.5751602989377934e-05,
                                1.5751602989377934e-05,
                                1.5751602989377934e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.897986495468569e-05,
                                5.897986495468569e-05,
                                5.897986495468569e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.9874356355993965e-05,
                                5.9874356355993965e-05,
                                5.9874356355993965e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                1.5621668396621174e-05,
                                1.5621668396621174e-05,
                                1.5621668396621174e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                9.474408848851591e-07,
                                9.474408848851591e-07,
                                9.474408848851591e-07,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                3.782142292851633e-05,
                                3.782142292851633e-05,
                                3.782142292851633e-05,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014161748605663922,
                                0.00014161748605663922,
                                0.00014161748605663922,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                0.00014376526349983755,
                                0.00014376526349983755,
                                0.00014376526349983755,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                3.750943492392963e-05,
                                3.750943492392963e-05,
                                3.750943492392963e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                3.9458358567900084e-07,
                                3.9458358567900084e-07,
                                3.9458358567900084e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.5751602989377934e-05,
                                1.5751602989377934e-05,
                                1.5751602989377934e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.897986495468569e-05,
                                5.897986495468569e-05,
                                5.897986495468569e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.9874356355993965e-05,
                                5.9874356355993965e-05,
                                5.9874356355993965e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                1.5621668396621174e-05,
                                1.5621668396621174e-05,
                                1.5621668396621174e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6103035317459015e-06,
                                1.6103035317459015e-06,
                                1.6103035317459015e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.428260790627326e-05,
                                6.428260790627326e-05,
                                6.428260790627326e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024069801250093198,
                                0.00024069801250093198,
                                0.00024069801250093198,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.00024434844986052055,
                                0.00024434844986052055,
                                0.00024434844986052055,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                6.375234222567705e-05,
                                6.375234222567705e-05,
                                6.375234222567705e-05,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                1.9139759972861733e-06,
                                1.9139759972861733e-06,
                                1.9139759972861733e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                7.640507901151385e-05,
                                7.640507901151385e-05,
                                7.640507901151385e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028608905677663624,
                                0.00028608905677663624,
                                0.00028608905677663624,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.0002904278968450513,
                                0.0002904278968450513,
                                0.0002904278968450513,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                7.577481535945232e-05,
                                7.577481535945232e-05,
                                7.577481535945232e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6103035317459015e-06,
                                1.6103035317459015e-06,
                                1.6103035317459015e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.428260790627326e-05,
                                6.428260790627326e-05,
                                6.428260790627326e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024069801250093198,
                                0.00024069801250093198,
                                0.00024069801250093198,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.00024434844986052055,
                                0.00024434844986052055,
                                0.00024434844986052055,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                6.375234222567705e-05,
                                6.375234222567705e-05,
                                6.375234222567705e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.47440884885159e-07,
                                9.47440884885159e-07,
                                9.47440884885159e-07,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.782142292851632e-05,
                                3.782142292851632e-05,
                                3.782142292851632e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014161748605663916,
                                0.00014161748605663916,
                                0.00014161748605663916,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.0001437652634998375,
                                0.0001437652634998375,
                                0.0001437652634998375,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                3.750943492392963e-05,
                                3.750943492392963e-05,
                                3.750943492392963e-05,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.913975997286173e-06,
                                1.913975997286173e-06,
                                1.913975997286173e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.640507901151383e-05,
                                7.640507901151383e-05,
                                7.640507901151383e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002860890567766362,
                                0.0002860890567766362,
                                0.0002860890567766362,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00029042789684505124,
                                0.00029042789684505124,
                                0.00029042789684505124,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                7.57748153594523e-05,
                                7.57748153594523e-05,
                                7.57748153594523e-05,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                2.3813859102433154e-06,
                                2.274915285204538e-06,
                                2.274915285204538e-06,
                                2.274915285204538e-06,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                9.396107902114147e-05,
                                9.081361644921653e-05,
                                9.081361644921653e-05,
                                9.081361644921653e-05,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.0003407899114193127,
                                0.00034003998436434317,
                                0.00034003998436434317,
                                0.00034003998436434317,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                0.00031321045292035114,
                                0.0003451970467338246,
                                0.0003451970467338246,
                                0.0003451970467338246,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                4.8383525617965406e-05,
                                9.00644971197074e-05,
                                9.00644971197074e-05,
                                9.00644971197074e-05,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                2.0035539354474854e-06,
                                1.913975997286173e-06,
                                1.913975997286173e-06,
                                1.913975997286173e-06,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.905316347171355e-05,
                                7.640507901151383e-05,
                                7.640507901151383e-05,
                                7.640507901151383e-05,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002867200000000003,
                                0.0002860890567766362,
                                0.0002860890567766362,
                                0.0002860890567766362,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.0002635163132831929,
                                0.00029042789684505124,
                                0.00029042789684505124,
                                0.00029042789684505124,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                4.070696930964633e-05,
                                7.57748153594523e-05,
                                7.57748153594523e-05,
                                7.57748153594523e-05,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.917830297804339e-07,
                                9.47440884885159e-07,
                                9.47440884885159e-07,
                                9.47440884885159e-07,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.913225623456594e-05,
                                3.782142292851632e-05,
                                3.782142292851632e-05,
                                3.782142292851632e-05,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014192981045710394,
                                0.00014161748605663916,
                                0.00014161748605663916,
                                0.00014161748605663916,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.00013044370953068618,
                                0.0001437652634998375,
                                0.0001437652634998375,
                                0.0001437652634998375,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                2.015043400670077e-05,
                                3.750943492392963e-05,
                                3.750943492392963e-05,
                                3.750943492392963e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6103035317459015e-06,
                                1.6103035317459015e-06,
                                1.6103035317459015e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.428260790627326e-05,
                                6.428260790627326e-05,
                                6.428260790627326e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024069801250093198,
                                0.00024069801250093198,
                                0.00024069801250093198,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.00024434844986052055,
                                0.00024434844986052055,
                                0.00024434844986052055,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                6.375234222567705e-05,
                                6.375234222567705e-05,
                                6.375234222567705e-05,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                2.003553935447486e-06,
                                1.9139759972861733e-06,
                                1.9139759972861733e-06,
                                1.9139759972861733e-06,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                7.905316347171357e-05,
                                7.640507901151385e-05,
                                7.640507901151385e-05,
                                7.640507901151385e-05,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028672000000000034,
                                0.00028608905677663624,
                                0.00028608905677663624,
                                0.00028608905677663624,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.00026351631328319294,
                                0.0002904278968450513,
                                0.0002904278968450513,
                                0.0002904278968450513,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                4.070696930964634e-05,
                                7.577481535945232e-05,
                                7.577481535945232e-05,
                                7.577481535945232e-05,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6856689858541068e-06,
                                1.6103035317459015e-06,
                                1.6103035317459015e-06,
                                1.6103035317459015e-06,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.651054585568708e-05,
                                6.428260790627326e-05,
                                6.428260790627326e-05,
                                6.428260790627326e-05,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024122884993168082,
                                0.00024069801250093198,
                                0.00024069801250093198,
                                0.00024069801250093198,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.0002217066726825511,
                                0.00024434844986052055,
                                0.00024434844986052055,
                                0.00024434844986052055,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                3.4248379571603655e-05,
                                6.375234222567705e-05,
                                6.375234222567705e-05,
                                6.375234222567705e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                3.9458358567900084e-07,
                                3.9458358567900084e-07,
                                3.9458358567900084e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.5751602989377934e-05,
                                1.5751602989377934e-05,
                                1.5751602989377934e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.897986495468569e-05,
                                5.897986495468569e-05,
                                5.897986495468569e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.9874356355993965e-05,
                                5.9874356355993965e-05,
                                5.9874356355993965e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                1.5621668396621174e-05,
                                1.5621668396621174e-05,
                                1.5621668396621174e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                9.91783029780434e-07,
                                9.474408848851591e-07,
                                9.474408848851591e-07,
                                9.474408848851591e-07,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                3.9132256234565945e-05,
                                3.782142292851633e-05,
                                3.782142292851633e-05,
                                3.782142292851633e-05,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014192981045710396,
                                0.00014161748605663922,
                                0.00014161748605663922,
                                0.00014161748605663922,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                0.00013044370953068624,
                                0.00014376526349983755,
                                0.00014376526349983755,
                                0.00014376526349983755,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                2.0150434006700775e-05,
                                3.750943492392963e-05,
                                3.750943492392963e-05,
                                3.750943492392963e-05,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                8.34426198575934e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                7.971194023406134e-07,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.2923511323577625e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                3.1820655537896505e-05,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011941115006831959,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00011914837922593077,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.00010974744011896495,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                0.0001209553891398954,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                1.6953355263185872e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                3.155816771863406e-05,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                4.1305089356976827e-07,
                                3.9458358567900084e-07,
                                3.9458358567900084e-07,
                                3.9458358567900084e-07,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.6297529721462346e-05,
                                1.5751602989377934e-05,
                                1.5751602989377934e-05,
                                1.5751602989377934e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.910993964725648e-05,
                                5.897986495468569e-05,
                                5.897986495468569e-05,
                                5.897986495468569e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.432628827510131e-05,
                                5.9874356355993965e-05,
                                5.9874356355993965e-05,
                                5.9874356355993965e-05,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                8.392112510867444e-06,
                                1.5621668396621174e-05,
                                1.5621668396621174e-05,
                                1.5621668396621174e-05,
                            ]
                        ),
                    )
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.VertexAdjacentTriangleAndQuadrilateral:
            match order:
                case 1:
                    return (
                        np.array([[0.75, 0.125, 0.125], [0.75, 0.125, 0.125], [0.5, 0.25, 0.25]]),
                        np.array(
                            [
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                            ]
                        ),
                        np.array([0.0625, 0.0625, 0.125]),
                    )
                case 2:
                    return (
                        np.array(
                            [
                                [0.9553418012614796, 0.03522081090086453, 0.009437387837655933],
                                [0.9553418012614796, 0.03522081090086453, 0.009437387837655933],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.9553418012614796, 0.009437387837655936, 0.03522081090086452],
                                [0.9553418012614796, 0.009437387837655936, 0.03522081090086452],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.37799153207185376, 0.4905626121623441, 0.13144585576580217],
                                [0.37799153207185376, 0.4905626121623441, 0.13144585576580217],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.37799153207185376, 0.13144585576580214, 0.4905626121623441],
                                [0.37799153207185376, 0.13144585576580214, 0.4905626121623441],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.9553418012614796, 0.03522081090086453, 0.009437387837655933],
                                [0.9553418012614796, 0.03522081090086453, 0.009437387837655933],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.9553418012614796, 0.009437387837655936, 0.03522081090086452],
                                [0.9553418012614796, 0.009437387837655936, 0.03522081090086452],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.37799153207185376, 0.4905626121623441, 0.13144585576580217],
                                [0.37799153207185376, 0.4905626121623441, 0.13144585576580217],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.37799153207185376, 0.13144585576580214, 0.4905626121623441],
                                [0.37799153207185376, 0.13144585576580214, 0.4905626121623441],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.9126779572375282,
                                    0.042663844023951264,
                                    0.042663844023951264,
                                    0.00199435471456919,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.9126779572375282,
                                    0.042663844023951264,
                                    0.042663844023951264,
                                    0.00199435471456919,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.7534543236939483,
                                    0.2018874775675312,
                                    0.03522081090086452,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7534543236939483,
                                    0.03522081090086452,
                                    0.2018874775675312,
                                    0.009437387837655933,
                                ],
                                [
                                    0.7961181677178996,
                                    0.03721516561543371,
                                    0.15922363354357993,
                                    0.007443033123086744,
                                ],
                                [
                                    0.1761040545043226,
                                    0.6572292788290106,
                                    0.03522081090086453,
                                    0.13144585576580217,
                                ],
                                [
                                    0.1761040545043226,
                                    0.03522081090086453,
                                    0.6572292788290106,
                                    0.13144585576580217,
                                ],
                                [
                                    0.31499294339321143,
                                    0.0629985886786423,
                                    0.5183403899401218,
                                    0.10366807798802438,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.7961181677178996,
                                    0.15922363354357993,
                                    0.03721516561543371,
                                    0.007443033123086744,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.31499294339321143,
                                    0.5183403899401218,
                                    0.0629985886786423,
                                    0.10366807798802438,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.14287759831802727,
                                    0.2351139337538265,
                                    0.2351139337538265,
                                    0.38689453417431974,
                                ],
                                [
                                    0.6572292788290106,
                                    0.1761040545043226,
                                    0.13144585576580217,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6572292788290106,
                                    0.13144585576580217,
                                    0.1761040545043226,
                                    0.03522081090086453,
                                ],
                                [
                                    0.6944444444444443,
                                    0.1388888888888889,
                                    0.1388888888888889,
                                    0.027777777777777783,
                                ],
                                [
                                    0.07987900963938498,
                                    0.2981125224324688,
                                    0.13144585576580217,
                                    0.4905626121623441,
                                ],
                                [
                                    0.07987900963938498,
                                    0.13144585576580217,
                                    0.2981125224324688,
                                    0.4905626121623441,
                                ],
                                [
                                    0.14287759831802727,
                                    0.2351139337538265,
                                    0.2351139337538265,
                                    0.38689453417431974,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                0.00012464716966057438,
                                0.00012464716966057438,
                                0.0005898367398534958,
                                0.006479254874251524,
                                0.006479254874251524,
                                0.030660163260146506,
                                0.00012464716966057438,
                                0.00012464716966057438,
                                0.0005898367398534958,
                                0.006479254874251524,
                                0.006479254874251524,
                                0.030660163260146506,
                                0.00046518957019292144,
                                0.00046518957019292144,
                                0.0005898367398534958,
                                0.02418090838589498,
                                0.02418090838589498,
                                0.030660163260146506,
                                0.00046518957019292144,
                                0.00046518957019292144,
                                0.0005898367398534958,
                                0.02418090838589498,
                                0.02418090838589498,
                                0.030660163260146506,
                                0.00012464716966057438,
                                0.00012464716966057438,
                                0.0005898367398534958,
                                0.006479254874251524,
                                0.006479254874251524,
                                0.030660163260146506,
                                0.00012464716966057438,
                                0.00012464716966057438,
                                0.0005898367398534958,
                                0.006479254874251524,
                                0.006479254874251524,
                                0.030660163260146506,
                                0.00046518957019292144,
                                0.00046518957019292144,
                                0.0005898367398534958,
                                0.02418090838589498,
                                0.02418090838589498,
                                0.030660163260146506,
                                0.00046518957019292144,
                                0.00046518957019292144,
                                0.0005898367398534958,
                                0.02418090838589498,
                                0.02418090838589498,
                                0.030660163260146506,
                            ]
                        ),
                    )
                case 3:
                    return (
                        np.array(
                            [
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.5, 0.25, 0.25],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.75, 0.125, 0.125],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5, 0.25, 0.25],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.5, 0.25, 0.25],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.75, 0.125, 0.125],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5, 0.25, 0.25],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.5, 0.25, 0.25],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.75, 0.125, 0.125],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5, 0.25, 0.25],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.97475800154489,
                                    0.012540333075851659,
                                    0.012540333075851659,
                                    0.0001613323034066491,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.9316632513517787,
                                    0.011985915958592068,
                                    0.05563508326896291,
                                    0.0007157494206662399,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.7077368754827782,
                                    0.04226312451722186,
                                    0.2359122918275927,
                                    0.014087708172407287,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.5007157494206662,
                                    0.05563508326896291,
                                    0.39928425057933375,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.8760281680828159,
                                    0.11127016653792582,
                                    0.011270166537925829,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8760281680828159,
                                    0.011270166537925829,
                                    0.11127016653792582,
                                    0.0014314988413324798,
                                ],
                                [
                                    0.8885685011586675,
                                    0.011431498841332478,
                                    0.09872983346207416,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.4718245836551854,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.028175416344814574,
                                ],
                                [
                                    0.4718245836551854,
                                    0.028175416344814574,
                                    0.4718245836551854,
                                    0.028175416344814574,
                                ],
                                [
                                    0.525,
                                    0.031350832689629154,
                                    0.41864916731037083,
                                    0.024999999999999998,
                                ],
                                [
                                    0.10143149884133247,
                                    0.7985685011586675,
                                    0.011270166537925829,
                                    0.08872983346207416,
                                ],
                                [
                                    0.10143149884133247,
                                    0.011270166537925829,
                                    0.7985685011586675,
                                    0.08872983346207416,
                                ],
                                [
                                    0.19143149884133245,
                                    0.021270166537925825,
                                    0.7085685011586675,
                                    0.07872983346207417,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.9316632513517787,
                                    0.05563508326896291,
                                    0.011985915958592068,
                                    0.0007157494206662399,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7077368754827782,
                                    0.2359122918275927,
                                    0.04226312451722186,
                                    0.014087708172407287,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.5007157494206662,
                                    0.39928425057933375,
                                    0.05563508326896291,
                                    0.04436491673103708,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8904737509655563,
                                    0.05317541634481457,
                                    0.05317541634481457,
                                    0.003175416344814577,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.8372983346207417,
                                    0.10635083268962914,
                                    0.049999999999999996,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8372983346207417,
                                    0.049999999999999996,
                                    0.10635083268962914,
                                    0.006350832689629154,
                                ],
                                [
                                    0.8492842505793338,
                                    0.050715749420666235,
                                    0.09436491673103707,
                                    0.005635083268962914,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.41726312451722186,
                                    0.1390877081724073,
                                    0.33273687548277814,
                                    0.11091229182759271,
                                ],
                                [
                                    0.06270166537925831,
                                    0.49364916731037084,
                                    0.049999999999999996,
                                    0.39364916731037086,
                                ],
                                [
                                    0.06270166537925831,
                                    0.049999999999999996,
                                    0.49364916731037084,
                                    0.39364916731037086,
                                ],
                                [
                                    0.1183367486482212,
                                    0.09436491673103707,
                                    0.43801408404140796,
                                    0.34928425057933377,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8885685011586675,
                                    0.09872983346207416,
                                    0.011431498841332478,
                                    0.0012701665379258307,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.525,
                                    0.41864916731037083,
                                    0.031350832689629154,
                                    0.024999999999999998,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.19143149884133245,
                                    0.7085685011586675,
                                    0.021270166537925825,
                                    0.07872983346207417,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [
                                    0.8492842505793338,
                                    0.09436491673103707,
                                    0.050715749420666235,
                                    0.005635083268962914,
                                ],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.41726312451722186,
                                    0.33273687548277814,
                                    0.1390877081724073,
                                    0.11091229182759271,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.1183367486482212,
                                    0.43801408404140796,
                                    0.09436491673103707,
                                    0.34928425057933377,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                                [
                                    0.7985685011586675,
                                    0.10143149884133247,
                                    0.08872983346207416,
                                    0.011270166537925829,
                                ],
                                [
                                    0.7985685011586675,
                                    0.08872983346207416,
                                    0.10143149884133247,
                                    0.011270166537925829,
                                ],
                                [0.81, 0.09, 0.09, 0.009999999999999998],
                                [
                                    0.2781754163448146,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.22182458365518543,
                                ],
                                [
                                    0.2781754163448146,
                                    0.22182458365518543,
                                    0.2781754163448146,
                                    0.22182458365518543,
                                ],
                                [
                                    0.3095262490344437,
                                    0.24682458365518542,
                                    0.24682458365518542,
                                    0.19682458365518543,
                                ],
                                [
                                    0.023971831917184137,
                                    0.18872983346207414,
                                    0.08872983346207416,
                                    0.6985685011586675,
                                ],
                                [
                                    0.023971831917184137,
                                    0.08872983346207416,
                                    0.18872983346207414,
                                    0.6985685011586675,
                                ],
                                [
                                    0.045241998455109955,
                                    0.16745966692414832,
                                    0.16745966692414832,
                                    0.6198386676965935,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                9.605308797168476e-07,
                                9.605308797168476e-07,
                                8.522774499245549e-06,
                                0.0001341993233920829,
                                0.0001341993233920829,
                                0.0011907483615302553,
                                0.00046873710099257357,
                                0.00046873710099257357,
                                0.00415909649085665,
                                1.5368494075469555e-06,
                                1.5368494075469555e-06,
                                1.3636439198792873e-05,
                                0.00021471891742733262,
                                0.00021471891742733262,
                                0.001905197378448408,
                                0.0007499793615881174,
                                0.0007499793615881174,
                                0.006654554385370637,
                                9.605308797168476e-07,
                                9.605308797168476e-07,
                                8.522774499245549e-06,
                                0.0001341993233920829,
                                0.0001341993233920829,
                                0.0011907483615302553,
                                0.00046873710099257357,
                                0.00046873710099257357,
                                0.00415909649085665,
                                6.818219599396437e-06,
                                6.818219599396437e-06,
                                1.3636439198792873e-05,
                                0.000952598689224204,
                                0.000952598689224204,
                                0.001905197378448408,
                                0.0033272771926853187,
                                0.0033272771926853187,
                                0.006654554385370637,
                                1.0909151359034296e-05,
                                1.0909151359034296e-05,
                                2.1818302718068593e-05,
                                0.0015241579027587258,
                                0.0015241579027587258,
                                0.0030483158055174516,
                                0.0053236435082965085,
                                0.0053236435082965085,
                                0.010647287016593017,
                                6.818219599396437e-06,
                                6.818219599396437e-06,
                                1.3636439198792873e-05,
                                0.000952598689224204,
                                0.000952598689224204,
                                0.001905197378448408,
                                0.0033272771926853187,
                                0.0033272771926853187,
                                0.006654554385370637,
                                7.562243619528701e-06,
                                7.562243619528701e-06,
                                8.522774499245549e-06,
                                0.0010565490381381725,
                                0.0010565490381381725,
                                0.0011907483615302553,
                                0.003690359389864076,
                                0.003690359389864076,
                                0.00415909649085665,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.3636439198792873e-05,
                                0.0016904784610210753,
                                0.0016904784610210753,
                                0.001905197378448408,
                                0.00590457502378252,
                                0.00590457502378252,
                                0.006654554385370637,
                                7.562243619528701e-06,
                                7.562243619528701e-06,
                                8.522774499245549e-06,
                                0.0010565490381381725,
                                0.0010565490381381725,
                                0.0011907483615302553,
                                0.003690359389864076,
                                0.003690359389864076,
                                0.00415909649085665,
                                1.5368494075469555e-06,
                                1.5368494075469555e-06,
                                1.3636439198792873e-05,
                                0.00021471891742733262,
                                0.00021471891742733262,
                                0.001905197378448408,
                                0.0007499793615881174,
                                0.0007499793615881174,
                                0.006654554385370637,
                                2.4589590520751282e-06,
                                2.4589590520751282e-06,
                                2.1818302718068593e-05,
                                0.00034355026788373204,
                                0.00034355026788373204,
                                0.0030483158055174516,
                                0.0011999669785409876,
                                0.0011999669785409876,
                                0.010647287016593017,
                                1.5368494075469555e-06,
                                1.5368494075469555e-06,
                                1.3636439198792873e-05,
                                0.00021471891742733262,
                                0.00021471891742733262,
                                0.001905197378448408,
                                0.0007499793615881174,
                                0.0007499793615881174,
                                0.006654554385370637,
                                1.0909151359034298e-05,
                                1.0909151359034298e-05,
                                2.1818302718068596e-05,
                                0.001524157902758726,
                                0.001524157902758726,
                                0.003048315805517452,
                                0.0053236435082965085,
                                0.0053236435082965085,
                                0.010647287016593017,
                                1.745464217445487e-05,
                                1.745464217445487e-05,
                                3.490928434890974e-05,
                                0.002438652644413961,
                                0.002438652644413961,
                                0.004877305288827922,
                                0.008517829613274411,
                                0.008517829613274411,
                                0.017035659226548823,
                                1.0909151359034298e-05,
                                1.0909151359034298e-05,
                                2.1818302718068596e-05,
                                0.001524157902758726,
                                0.001524157902758726,
                                0.003048315805517452,
                                0.0053236435082965085,
                                0.0053236435082965085,
                                0.010647287016593017,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.3636439198792873e-05,
                                0.0016904784610210753,
                                0.0016904784610210753,
                                0.001905197378448408,
                                0.00590457502378252,
                                0.00590457502378252,
                                0.006654554385370637,
                                1.9359343665993465e-05,
                                1.9359343665993465e-05,
                                2.1818302718068593e-05,
                                0.0027047655376337197,
                                0.0027047655376337197,
                                0.0030483158055174516,
                                0.009447320038052029,
                                0.009447320038052029,
                                0.010647287016593017,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.3636439198792873e-05,
                                0.0016904784610210753,
                                0.0016904784610210753,
                                0.001905197378448408,
                                0.00590457502378252,
                                0.00590457502378252,
                                0.006654554385370637,
                                9.605308797168476e-07,
                                9.605308797168476e-07,
                                8.522774499245549e-06,
                                0.0001341993233920829,
                                0.0001341993233920829,
                                0.0011907483615302553,
                                0.00046873710099257357,
                                0.00046873710099257357,
                                0.00415909649085665,
                                1.5368494075469555e-06,
                                1.5368494075469555e-06,
                                1.3636439198792873e-05,
                                0.00021471891742733262,
                                0.00021471891742733262,
                                0.001905197378448408,
                                0.0007499793615881174,
                                0.0007499793615881174,
                                0.006654554385370637,
                                9.605308797168476e-07,
                                9.605308797168476e-07,
                                8.522774499245549e-06,
                                0.0001341993233920829,
                                0.0001341993233920829,
                                0.0011907483615302553,
                                0.00046873710099257357,
                                0.00046873710099257357,
                                0.00415909649085665,
                                6.818219599396437e-06,
                                6.818219599396437e-06,
                                1.3636439198792873e-05,
                                0.000952598689224204,
                                0.000952598689224204,
                                0.001905197378448408,
                                0.0033272771926853187,
                                0.0033272771926853187,
                                0.006654554385370637,
                                1.0909151359034296e-05,
                                1.0909151359034296e-05,
                                2.1818302718068593e-05,
                                0.0015241579027587258,
                                0.0015241579027587258,
                                0.0030483158055174516,
                                0.0053236435082965085,
                                0.0053236435082965085,
                                0.010647287016593017,
                                6.818219599396437e-06,
                                6.818219599396437e-06,
                                1.3636439198792873e-05,
                                0.000952598689224204,
                                0.000952598689224204,
                                0.001905197378448408,
                                0.0033272771926853187,
                                0.0033272771926853187,
                                0.006654554385370637,
                                7.562243619528701e-06,
                                7.562243619528701e-06,
                                8.522774499245549e-06,
                                0.0010565490381381725,
                                0.0010565490381381725,
                                0.0011907483615302553,
                                0.003690359389864076,
                                0.003690359389864076,
                                0.00415909649085665,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.3636439198792873e-05,
                                0.0016904784610210753,
                                0.0016904784610210753,
                                0.001905197378448408,
                                0.00590457502378252,
                                0.00590457502378252,
                                0.006654554385370637,
                                7.562243619528701e-06,
                                7.562243619528701e-06,
                                8.522774499245549e-06,
                                0.0010565490381381725,
                                0.0010565490381381725,
                                0.0011907483615302553,
                                0.003690359389864076,
                                0.003690359389864076,
                                0.00415909649085665,
                            ]
                        ),
                    )
                case 4:
                    return (
                        np.array(
                            [
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9903816779504959,
                                    0.004797541060078003,
                                    0.004797541060078003,
                                    2.3239929348011262e-05,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9723765116924824,
                                    0.004710321631104814,
                                    0.022802707318091576,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.8706759648058681,
                                    0.020417779487298063,
                                    0.10641086851771914,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.7426635294802963,
                                    0.03623324801896565,
                                    0.21081779299314274,
                                    0.010285429507595284,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.6481344444522802,
                                    0.044769244016560635,
                                    0.287254492334172,
                                    0.019841819196987052,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9488847978402863,
                                    0.00459652463315273,
                                    0.04629442117028765,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.7610497858127007,
                                    0.017846991686561387,
                                    0.21603704751088665,
                                    0.005066174989851391,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.525475666703268,
                                    0.025637034005041956,
                                    0.4280056557701712,
                                    0.02088164352151898,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.3522002712623143,
                                    0.02432788447181859,
                                    0.583188665524138,
                                    0.0402831787417291,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.9260820905221947,
                                    0.06909712848837922,
                                    0.00448606527483153,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9260820905221947,
                                    0.00448606527483153,
                                    0.06909712848837922,
                                    0.0003347157145944845,
                                ],
                                [
                                    0.9308796315822727,
                                    0.004509305204179541,
                                    0.06429958742830122,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.6546389172949815,
                                    0.3224479160286058,
                                    0.015351604497446674,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6546389172949815,
                                    0.015351604497446674,
                                    0.3224479160286058,
                                    0.007561562178966105,
                                ],
                                [
                                    0.6770270707642532,
                                    0.015876617704587745,
                                    0.30005976255933403,
                                    0.007036548971825031,
                                ],
                                [
                                    0.3146578737101252,
                                    0.6388234487633139,
                                    0.015351604497446674,
                                    0.03116707302911426,
                                ],
                                [
                                    0.3146578737101252,
                                    0.015351604497446674,
                                    0.6388234487633139,
                                    0.03116707302911426,
                                ],
                                [
                                    0.35901256387786606,
                                    0.017515591856266843,
                                    0.594468758595573,
                                    0.029003085670294092,
                                ],
                                [
                                    0.06494577892814224,
                                    0.8704431578583101,
                                    0.0044860652748315325,
                                    0.06012499793871616,
                                ],
                                [
                                    0.06494577892814224,
                                    0.0044860652748315325,
                                    0.8704431578583101,
                                    0.06012499793871616,
                                ],
                                [
                                    0.12538225265210487,
                                    0.00866065476441659,
                                    0.8100066841343474,
                                    0.0559504084491311,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9723765116924824,
                                    0.022802707318091576,
                                    0.004710321631104814,
                                    0.00011045935832120038,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.8706759648058681,
                                    0.10641086851771914,
                                    0.020417779487298063,
                                    0.0024953871891147143,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.7426635294802963,
                                    0.21081779299314274,
                                    0.03623324801896565,
                                    0.010285429507595284,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.6481344444522802,
                                    0.287254492334172,
                                    0.044769244016560635,
                                    0.019841819196987052,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9546986798543156,
                                    0.022388153469271706,
                                    0.022388153469271706,
                                    0.000525013207141073,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.7940480611184145,
                                    0.09704568317475157,
                                    0.09704568317475157,
                                    0.01186057253208228,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9316340460087588,
                                    0.02184727646468039,
                                    0.04545278731482855,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6940700458796984,
                                    0.0848267316195635,
                                    0.19702369841346767,
                                    0.024079524087270356,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.4292599066206178,
                                    0.12185279408769208,
                                    0.3496368708786442,
                                    0.09925042841304595,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.2608977479205508,
                                    0.11563040781358205,
                                    0.43200594054829006,
                                    0.19146590371757702,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.909245892539487,
                                    0.06784094078410026,
                                    0.021322263257539317,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.909245892539487,
                                    0.021322263257539317,
                                    0.06784094078410026,
                                    0.0015909034188734612,
                                ],
                                [
                                    0.9139562141705918,
                                    0.021432722615860517,
                                    0.06313061915299543,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.5970243627049469,
                                    0.2940693815882192,
                                    0.07296615908748122,
                                    0.035940096619352636,
                                ],
                                [
                                    0.5970243627049469,
                                    0.07296615908748122,
                                    0.2940693815882192,
                                    0.035940096619352636,
                                ],
                                [
                                    0.6174421421922449,
                                    0.07546154627659593,
                                    0.27365160210092115,
                                    0.03344470943023792,
                                ],
                                [
                                    0.25704331912009065,
                                    0.5218534583791713,
                                    0.07296615908748122,
                                    0.1481370634132568,
                                ],
                                [
                                    0.25704331912009065,
                                    0.07296615908748122,
                                    0.5218534583791713,
                                    0.1481370634132568,
                                ],
                                [
                                    0.29327656713905637,
                                    0.08325158859507652,
                                    0.48562021036020564,
                                    0.1378516339056615,
                                ],
                                [
                                    0.04810958094543443,
                                    0.6447941075234065,
                                    0.021322263257539335,
                                    0.28577404827361974,
                                ],
                                [
                                    0.04810958094543443,
                                    0.021322263257539335,
                                    0.6447941075234065,
                                    0.28577404827361974,
                                ],
                                [
                                    0.09287882496199508,
                                    0.04116408245452639,
                                    0.6000248635068458,
                                    0.26593222907663266,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9488847978402863,
                                    0.04629442117028765,
                                    0.00459652463315273,
                                    0.00022425635627328414,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.7610497858127007,
                                    0.21603704751088665,
                                    0.017846991686561387,
                                    0.005066174989851391,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.525475666703268,
                                    0.4280056557701712,
                                    0.025637034005041956,
                                    0.02088164352151898,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.3522002712623143,
                                    0.583188665524138,
                                    0.02432788447181859,
                                    0.0402831787417291,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9316340460087588,
                                    0.04545278731482855,
                                    0.02184727646468039,
                                    0.001065890211732388,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6940700458796984,
                                    0.19702369841346767,
                                    0.0848267316195635,
                                    0.024079524087270356,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.4292599066206178,
                                    0.3496368708786442,
                                    0.12185279408769208,
                                    0.09925042841304595,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.2608977479205508,
                                    0.43200594054829006,
                                    0.11563040781358205,
                                    0.19146590371757702,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.9091266323056983,
                                    0.04435469016774077,
                                    0.04435469016774077,
                                    0.0021639873588201654,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.6066801899987349,
                                    0.17221658750052715,
                                    0.17221658750052715,
                                    0.048886635000210864,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.3037252088820071,
                                    0.24738749182630274,
                                    0.24738749182630274,
                                    0.2014998074653874,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8872793558410179,
                                    0.06620196663242116,
                                    0.04328879995600838,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8872793558410179,
                                    0.04328879995600838,
                                    0.06620196663242116,
                                    0.0032298775705525535,
                                ],
                                [
                                    0.8918758804741707,
                                    0.04351305631228167,
                                    0.06160544199926842,
                                    0.003005621214279269,
                                ],
                                [
                                    0.5218534583791713,
                                    0.25704331912009065,
                                    0.1481370634132568,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5218534583791713,
                                    0.1481370634132568,
                                    0.25704331912009065,
                                    0.07296615908748122,
                                ],
                                [
                                    0.5397004500657328,
                                    0.15320323840310818,
                                    0.23919632743352925,
                                    0.06789998409762982,
                                ],
                                [
                                    0.18187241479431507,
                                    0.3692402859139948,
                                    0.1481370634132568,
                                    0.3007502358784333,
                                ],
                                [
                                    0.18187241479431507,
                                    0.1481370634132568,
                                    0.3692402859139948,
                                    0.3007502358784333,
                                ],
                                [
                                    0.20750944879935707,
                                    0.16901870693477583,
                                    0.3436032519089528,
                                    0.2798685923569143,
                                ],
                                [
                                    0.02614304424696536,
                                    0.35038511148716756,
                                    0.04328879995600841,
                                    0.5801830443098587,
                                ],
                                [
                                    0.02614304424696536,
                                    0.04328879995600841,
                                    0.35038511148716756,
                                    0.5801830443098587,
                                ],
                                [
                                    0.050470928718783954,
                                    0.08357197869773751,
                                    0.32605722701534895,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9308796315822727,
                                    0.06429958742830122,
                                    0.004509305204179541,
                                    0.0003114757852464732,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6770270707642532,
                                    0.30005976255933403,
                                    0.015876617704587745,
                                    0.007036548971825031,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.35901256387786606,
                                    0.594468758595573,
                                    0.017515591856266843,
                                    0.029003085670294092,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.12538225265210487,
                                    0.8100066841343474,
                                    0.00866065476441659,
                                    0.0559504084491311,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.9139562141705918,
                                    0.06313061915299543,
                                    0.021432722615860517,
                                    0.0014804440605522605,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.6174421421922449,
                                    0.27365160210092115,
                                    0.07546154627659593,
                                    0.03344470943023792,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.29327656713905637,
                                    0.48562021036020564,
                                    0.08325158859507652,
                                    0.1378516339056615,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.09287882496199508,
                                    0.6000248635068458,
                                    0.04116408245452639,
                                    0.26593222907663266,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8918758804741707,
                                    0.06160544199926842,
                                    0.04351305631228167,
                                    0.003005621214279269,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.5397004500657328,
                                    0.23919632743352925,
                                    0.15320323840310818,
                                    0.06789998409762982,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.20750944879935707,
                                    0.3436032519089528,
                                    0.16901870693477583,
                                    0.2798685923569143,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.050470928718783954,
                                    0.32605722701534895,
                                    0.08357197869773751,
                                    0.5398998655681296,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06494577892814218,
                                    0.06012499793871616,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8704431578583101,
                                    0.06012499793871616,
                                    0.06494577892814218,
                                    0.004486065274831529,
                                ],
                                [
                                    0.8749524630624896,
                                    0.06043647372396263,
                                    0.06043647372396263,
                                    0.004174589489585056,
                                ],
                                [
                                    0.46423890378913674,
                                    0.2286647846797041,
                                    0.20575161800329134,
                                    0.10134469352786774,
                                ],
                                [
                                    0.46423890378913674,
                                    0.20575161800329134,
                                    0.2286647846797041,
                                    0.10134469352786774,
                                ],
                                [
                                    0.4801155214937245,
                                    0.21278816697511635,
                                    0.21278816697511635,
                                    0.09430814455604271,
                                ],
                                [
                                    0.12425786020428056,
                                    0.25227029552985236,
                                    0.2057516180032913,
                                    0.41772022626257577,
                                ],
                                [
                                    0.12425786020428056,
                                    0.2057516180032913,
                                    0.25227029552985236,
                                    0.41772022626257577,
                                ],
                                [
                                    0.14177345206054742,
                                    0.23475470367358547,
                                    0.23475470367358547,
                                    0.38871714059228163,
                                ],
                                [
                                    0.009306846264257556,
                                    0.12473606115226392,
                                    0.060124997938716215,
                                    0.8058320946447624,
                                ],
                                [
                                    0.009306846264257556,
                                    0.060124997938716215,
                                    0.12473606115226392,
                                    0.8058320946447624,
                                ],
                                [
                                    0.017967501028674147,
                                    0.11607540638784733,
                                    0.11607540638784733,
                                    0.7498816861956312,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                2.1267040013685393e-08,
                                2.1267040013685393e-08,
                                3.063009525069556e-07,
                                4.281110140388254e-06,
                                4.281110140388254e-06,
                                6.165917367646267e-05,
                                3.582474744517011e-05,
                                3.582474744517011e-05,
                                0.0005159699825982119,
                                5.120065373053888e-05,
                                5.120065373053888e-05,
                                0.000737423214351924,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                5.742414829043489e-07,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                0.00011559629520193758,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                0.0009673210792075479,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                0.0013824932527035615,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                5.742414829043489e-07,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                0.00011559629520193758,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                0.0009673210792075479,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                0.0013824932527035615,
                                2.1267040013685393e-08,
                                2.1267040013685393e-08,
                                3.063009525069556e-07,
                                4.281110140388254e-06,
                                4.281110140388254e-06,
                                6.165917367646267e-05,
                                3.582474744517011e-05,
                                3.582474744517011e-05,
                                0.0005159699825982119,
                                5.120065373053888e-05,
                                5.120065373053888e-05,
                                0.000737423214351924,
                                1.8950513213840648e-07,
                                1.8950513213840648e-07,
                                5.742414829043489e-07,
                                3.814787306231987e-05,
                                3.814787306231987e-05,
                                0.00011559629520193758,
                                0.0003192251246084682,
                                0.0003192251246084682,
                                0.0009673210792075479,
                                0.0004562358769501911,
                                0.0004562358769501911,
                                0.0013824932527035615,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                1.0765662920382115e-06,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.00021671557803432592,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0018134971061056799,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                0.0025918462513423684,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                1.0765662920382115e-06,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.00021671557803432592,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0018134971061056799,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                0.0025918462513423684,
                                1.8950513213840648e-07,
                                1.8950513213840648e-07,
                                5.742414829043489e-07,
                                3.814787306231987e-05,
                                3.814787306231987e-05,
                                0.00011559629520193758,
                                0.0003192251246084682,
                                0.0003192251246084682,
                                0.0009673210792075479,
                                0.0004562358769501911,
                                0.0004562358769501911,
                                0.0013824932527035615,
                                3.847363507659424e-07,
                                3.847363507659424e-07,
                                5.742414829043489e-07,
                                7.744842213961772e-05,
                                7.744842213961772e-05,
                                0.00011559629520193758,
                                0.0006480959545990797,
                                0.0006480959545990797,
                                0.0009673210792075479,
                                0.0009262573757533704,
                                0.0009262573757533704,
                                0.0013824932527035615,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                1.0765662920382115e-06,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.00021671557803432592,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0018134971061056799,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                0.0025918462513423684,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                1.0765662920382115e-06,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.00021671557803432592,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0018134971061056799,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                0.0025918462513423684,
                                3.847363507659424e-07,
                                3.847363507659424e-07,
                                5.742414829043489e-07,
                                7.744842213961772e-05,
                                7.744842213961772e-05,
                                0.00011559629520193758,
                                0.0006480959545990797,
                                0.0006480959545990797,
                                0.0009673210792075479,
                                0.0009262573757533704,
                                0.0009262573757533704,
                                0.0013824932527035615,
                                2.8503391249327023e-07,
                                2.8503391249327023e-07,
                                3.063009525069556e-07,
                                5.737806353607441e-05,
                                5.737806353607441e-05,
                                6.165917367646267e-05,
                                0.00048014523515304175,
                                0.00048014523515304175,
                                0.0005159699825982119,
                                0.000686222560621385,
                                0.000686222560621385,
                                0.000737423214351924,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                5.742414829043489e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.00011559629520193758,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0009673210792075479,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                0.0013824932527035615,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                5.742414829043489e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.00011559629520193758,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0009673210792075479,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                0.0013824932527035615,
                                2.8503391249327023e-07,
                                2.8503391249327023e-07,
                                3.063009525069556e-07,
                                5.737806353607441e-05,
                                5.737806353607441e-05,
                                6.165917367646267e-05,
                                0.00048014523515304175,
                                0.00048014523515304175,
                                0.0005159699825982119,
                                0.000686222560621385,
                                0.000686222560621385,
                                0.000737423214351924,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                5.742414829043489e-07,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                0.00011559629520193758,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                0.0009673210792075479,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                0.0013824932527035615,
                                7.47479830629702e-08,
                                7.47479830629702e-08,
                                1.0765662920382115e-06,
                                1.504696225043671e-05,
                                1.504696225043671e-05,
                                0.00021671557803432592,
                                0.00012591444853367326,
                                0.00012591444853367326,
                                0.0018134971061056799,
                                0.00017995666512126478,
                                0.00017995666512126478,
                                0.0025918462513423684,
                                7.47479830629702e-08,
                                7.47479830629702e-08,
                                1.0765662920382115e-06,
                                1.504696225043671e-05,
                                1.504696225043671e-05,
                                0.00021671557803432592,
                                0.00012591444853367326,
                                0.00012591444853367326,
                                0.0018134971061056799,
                                0.00017995666512126478,
                                0.00017995666512126478,
                                0.0025918462513423684,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                5.742414829043489e-07,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                0.00011559629520193758,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                0.0009673210792075479,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                0.0013824932527035615,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                1.0765662920382115e-06,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.00021671557803432592,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0018134971061056799,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                0.0025918462513423684,
                                6.660600816245342e-07,
                                6.660600816245342e-07,
                                2.0183059142488954e-06,
                                0.00013407961652000887,
                                0.00013407961652000887,
                                0.00040629019883990864,
                                0.0011219913157709503,
                                0.0011219913157709503,
                                0.003399876033455111,
                                0.0016035476296206268,
                                0.0016035476296206268,
                                0.004859095679100511,
                                6.660600816245342e-07,
                                6.660600816245342e-07,
                                2.0183059142488954e-06,
                                0.00013407961652000887,
                                0.00013407961652000887,
                                0.00040629019883990864,
                                0.0011219913157709503,
                                0.0011219913157709503,
                                0.003399876033455111,
                                0.0016035476296206268,
                                0.0016035476296206268,
                                0.004859095679100511,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                1.0765662920382115e-06,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.00021671557803432592,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0018134971061056799,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                0.0025918462513423684,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                1.0765662920382115e-06,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.00021671557803432592,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0018134971061056799,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                0.0025918462513423684,
                                1.352245832624361e-06,
                                1.352245832624361e-06,
                                2.0183059142488954e-06,
                                0.00027221058231989976,
                                0.00027221058231989976,
                                0.00040629019883990864,
                                0.002277884717684161,
                                0.002277884717684161,
                                0.003399876033455111,
                                0.003255548049479884,
                                0.003255548049479884,
                                0.004859095679100511,
                                1.352245832624361e-06,
                                1.352245832624361e-06,
                                2.0183059142488954e-06,
                                0.00027221058231989976,
                                0.00027221058231989976,
                                0.00040629019883990864,
                                0.002277884717684161,
                                0.002277884717684161,
                                0.003399876033455111,
                                0.003255548049479884,
                                0.003255548049479884,
                                0.004859095679100511,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                1.0765662920382115e-06,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.00021671557803432592,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0018134971061056799,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                0.0025918462513423684,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                5.742414829043489e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.00011559629520193758,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0009673210792075479,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                0.0013824932527035615,
                                1.0018183089752411e-06,
                                1.0018183089752411e-06,
                                1.0765662920382115e-06,
                                0.0002016686157838892,
                                0.0002016686157838892,
                                0.00021671557803432592,
                                0.0016875826575720066,
                                0.0016875826575720066,
                                0.0018134971061056799,
                                0.0024118895862211033,
                                0.0024118895862211033,
                                0.0025918462513423684,
                                1.0018183089752411e-06,
                                1.0018183089752411e-06,
                                1.0765662920382115e-06,
                                0.0002016686157838892,
                                0.0002016686157838892,
                                0.00021671557803432592,
                                0.0016875826575720066,
                                0.0016875826575720066,
                                0.0018134971061056799,
                                0.0024118895862211033,
                                0.0024118895862211033,
                                0.0025918462513423684,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                5.742414829043489e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.00011559629520193758,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0009673210792075479,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                0.0013824932527035615,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                5.742414829043489e-07,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                0.00011559629520193758,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                0.0009673210792075479,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                0.0013824932527035615,
                                7.47479830629702e-08,
                                7.47479830629702e-08,
                                1.0765662920382115e-06,
                                1.504696225043671e-05,
                                1.504696225043671e-05,
                                0.00021671557803432592,
                                0.00012591444853367326,
                                0.00012591444853367326,
                                0.0018134971061056799,
                                0.00017995666512126478,
                                0.00017995666512126478,
                                0.0025918462513423684,
                                7.47479830629702e-08,
                                7.47479830629702e-08,
                                1.0765662920382115e-06,
                                1.504696225043671e-05,
                                1.504696225043671e-05,
                                0.00021671557803432592,
                                0.00012591444853367326,
                                0.00012591444853367326,
                                0.0018134971061056799,
                                0.00017995666512126478,
                                0.00017995666512126478,
                                0.0025918462513423684,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                5.742414829043489e-07,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                0.00011559629520193758,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                0.0009673210792075479,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                0.0013824932527035615,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                1.0765662920382115e-06,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.00021671557803432592,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0018134971061056799,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                0.0025918462513423684,
                                6.660600816245342e-07,
                                6.660600816245342e-07,
                                2.0183059142488954e-06,
                                0.00013407961652000887,
                                0.00013407961652000887,
                                0.00040629019883990864,
                                0.0011219913157709503,
                                0.0011219913157709503,
                                0.003399876033455111,
                                0.0016035476296206268,
                                0.0016035476296206268,
                                0.004859095679100511,
                                6.660600816245342e-07,
                                6.660600816245342e-07,
                                2.0183059142488954e-06,
                                0.00013407961652000887,
                                0.00013407961652000887,
                                0.00040629019883990864,
                                0.0011219913157709503,
                                0.0011219913157709503,
                                0.003399876033455111,
                                0.0016035476296206268,
                                0.0016035476296206268,
                                0.004859095679100511,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                1.0765662920382115e-06,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.00021671557803432592,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0018134971061056799,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                0.0025918462513423684,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                1.0765662920382115e-06,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.00021671557803432592,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0018134971061056799,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                0.0025918462513423684,
                                1.352245832624361e-06,
                                1.352245832624361e-06,
                                2.0183059142488954e-06,
                                0.00027221058231989976,
                                0.00027221058231989976,
                                0.00040629019883990864,
                                0.002277884717684161,
                                0.002277884717684161,
                                0.003399876033455111,
                                0.003255548049479884,
                                0.003255548049479884,
                                0.004859095679100511,
                                1.352245832624361e-06,
                                1.352245832624361e-06,
                                2.0183059142488954e-06,
                                0.00027221058231989976,
                                0.00027221058231989976,
                                0.00040629019883990864,
                                0.002277884717684161,
                                0.002277884717684161,
                                0.003399876033455111,
                                0.003255548049479884,
                                0.003255548049479884,
                                0.004859095679100511,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                1.0765662920382115e-06,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.00021671557803432592,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0018134971061056799,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                0.0025918462513423684,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                5.742414829043489e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.00011559629520193758,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0009673210792075479,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                0.0013824932527035615,
                                1.0018183089752411e-06,
                                1.0018183089752411e-06,
                                1.0765662920382115e-06,
                                0.0002016686157838892,
                                0.0002016686157838892,
                                0.00021671557803432592,
                                0.0016875826575720066,
                                0.0016875826575720066,
                                0.0018134971061056799,
                                0.0024118895862211033,
                                0.0024118895862211033,
                                0.0025918462513423684,
                                1.0018183089752411e-06,
                                1.0018183089752411e-06,
                                1.0765662920382115e-06,
                                0.0002016686157838892,
                                0.0002016686157838892,
                                0.00021671557803432592,
                                0.0016875826575720066,
                                0.0016875826575720066,
                                0.0018134971061056799,
                                0.0024118895862211033,
                                0.0024118895862211033,
                                0.0025918462513423684,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                5.742414829043489e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.00011559629520193758,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0009673210792075479,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                0.0013824932527035615,
                                2.1267040013685393e-08,
                                2.1267040013685393e-08,
                                3.063009525069556e-07,
                                4.281110140388254e-06,
                                4.281110140388254e-06,
                                6.165917367646267e-05,
                                3.582474744517011e-05,
                                3.582474744517011e-05,
                                0.0005159699825982119,
                                5.120065373053888e-05,
                                5.120065373053888e-05,
                                0.000737423214351924,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                5.742414829043489e-07,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                0.00011559629520193758,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                0.0009673210792075479,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                0.0013824932527035615,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                5.742414829043489e-07,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                0.00011559629520193758,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                0.0009673210792075479,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                0.0013824932527035615,
                                2.1267040013685393e-08,
                                2.1267040013685393e-08,
                                3.063009525069556e-07,
                                4.281110140388254e-06,
                                4.281110140388254e-06,
                                6.165917367646267e-05,
                                3.582474744517011e-05,
                                3.582474744517011e-05,
                                0.0005159699825982119,
                                5.120065373053888e-05,
                                5.120065373053888e-05,
                                0.000737423214351924,
                                1.8950513213840648e-07,
                                1.8950513213840648e-07,
                                5.742414829043489e-07,
                                3.814787306231987e-05,
                                3.814787306231987e-05,
                                0.00011559629520193758,
                                0.0003192251246084682,
                                0.0003192251246084682,
                                0.0009673210792075479,
                                0.0004562358769501911,
                                0.0004562358769501911,
                                0.0013824932527035615,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                1.0765662920382115e-06,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.00021671557803432592,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0018134971061056799,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                0.0025918462513423684,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                1.0765662920382115e-06,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.00021671557803432592,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0018134971061056799,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                0.0025918462513423684,
                                1.8950513213840648e-07,
                                1.8950513213840648e-07,
                                5.742414829043489e-07,
                                3.814787306231987e-05,
                                3.814787306231987e-05,
                                0.00011559629520193758,
                                0.0003192251246084682,
                                0.0003192251246084682,
                                0.0009673210792075479,
                                0.0004562358769501911,
                                0.0004562358769501911,
                                0.0013824932527035615,
                                3.847363507659424e-07,
                                3.847363507659424e-07,
                                5.742414829043489e-07,
                                7.744842213961772e-05,
                                7.744842213961772e-05,
                                0.00011559629520193758,
                                0.0006480959545990797,
                                0.0006480959545990797,
                                0.0009673210792075479,
                                0.0009262573757533704,
                                0.0009262573757533704,
                                0.0013824932527035615,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                1.0765662920382115e-06,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.00021671557803432592,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0018134971061056799,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                0.0025918462513423684,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                1.0765662920382115e-06,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.00021671557803432592,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0018134971061056799,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                0.0025918462513423684,
                                3.847363507659424e-07,
                                3.847363507659424e-07,
                                5.742414829043489e-07,
                                7.744842213961772e-05,
                                7.744842213961772e-05,
                                0.00011559629520193758,
                                0.0006480959545990797,
                                0.0006480959545990797,
                                0.0009673210792075479,
                                0.0009262573757533704,
                                0.0009262573757533704,
                                0.0013824932527035615,
                                2.8503391249327023e-07,
                                2.8503391249327023e-07,
                                3.063009525069556e-07,
                                5.737806353607441e-05,
                                5.737806353607441e-05,
                                6.165917367646267e-05,
                                0.00048014523515304175,
                                0.00048014523515304175,
                                0.0005159699825982119,
                                0.000686222560621385,
                                0.000686222560621385,
                                0.000737423214351924,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                5.742414829043489e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.00011559629520193758,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0009673210792075479,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                0.0013824932527035615,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                5.742414829043489e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.00011559629520193758,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0009673210792075479,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                0.0013824932527035615,
                                2.8503391249327023e-07,
                                2.8503391249327023e-07,
                                3.063009525069556e-07,
                                5.737806353607441e-05,
                                5.737806353607441e-05,
                                6.165917367646267e-05,
                                0.00048014523515304175,
                                0.00048014523515304175,
                                0.0005159699825982119,
                                0.000686222560621385,
                                0.000686222560621385,
                                0.000737423214351924,
                            ]
                        ),
                    )
                case 5:
                    return (
                        np.array(
                            [
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.75, 0.125, 0.125],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.75, 0.125, 0.125],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.75, 0.125, 0.125],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.75, 0.125, 0.125],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.75, 0.125, 0.125],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                            ]
                        ),
                        np.array(
                            [
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9956037317897009,
                                    0.0021957128832759167,
                                    0.0021957128832759167,
                                    4.842443747290214e-06,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9869980460612706,
                                    0.0021767338312494934,
                                    0.010801398611706165,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.9364986070611838,
                                    0.010248748510235127,
                                    0.05267617283133628,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.8638685940379567,
                                    0.02074873348846404,
                                    0.11267636744670925,
                                    0.00270630502686997,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.7928079629584961,
                                    0.029679336522926526,
                                    0.17110718011831577,
                                    0.00640552040026161,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.7451837712416985,
                                    0.03487610391862285,
                                    0.2101067070546566,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9743960202675932,
                                    0.002148941217072754,
                                    0.023403424405383556,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8750411502450566,
                                    0.009576177281364125,
                                    0.11413362964746347,
                                    0.001249042826115755,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.7324087211134995,
                                    0.017591278886500507,
                                    0.2441362403711665,
                                    0.005863759628833502,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.5931766767843609,
                                    0.022205995689218255,
                                    0.37073846629245083,
                                    0.013878861233969883,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.5000516141099505,
                                    0.02340342440538356,
                                    0.4552388641864047,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9617939944739158,
                                    0.002121148602896015,
                                    0.03600545019906094,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.8135836934289296,
                                    0.00890360605249312,
                                    0.17559108646359065,
                                    0.001921614054986758,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.6009488481890423,
                                    0.014433824284536975,
                                    0.3755961132956237,
                                    0.009021214230797034,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.393545390610226,
                                    0.014732654855509984,
                                    0.5703697524665858,
                                    0.021352202067678152,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.2549194569782024,
                                    0.011930744892144265,
                                    0.7003710213181528,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9509925958622096,
                                    0.04680684881076711,
                                    0.0020973271071223014,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9509925958622096,
                                    0.0020973271071223014,
                                    0.04680684881076711,
                                    0.00010322821990090549,
                                ],
                                [
                                    0.9531883087454855,
                                    0.0021021695508695918,
                                    0.04461113592749119,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.7609075205975931,
                                    0.22826725929492694,
                                    0.008327134455248368,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7609075205975931,
                                    0.008327134455248368,
                                    0.22826725929492694,
                                    0.00249808565223151,
                                ],
                                [
                                    0.7716155553146976,
                                    0.008444319845623756,
                                    0.21755922457782245,
                                    0.002380900261856123,
                                ],
                                [
                                    0.488272480742333,
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.011727519257667005,
                                ],
                                [
                                    0.488272480742333,
                                    0.011727519257667005,
                                    0.488272480742333,
                                    0.011727519257667005,
                                ],
                                [
                                    0.5111773804259112,
                                    0.012277658089422806,
                                    0.46536758105875475,
                                    0.011177380425911203,
                                ],
                                [
                                    0.22243821049191012,
                                    0.7414769325849017,
                                    0.00832713445524837,
                                    0.027757722467939765,
                                ],
                                [
                                    0.22243821049191012,
                                    0.00832713445524837,
                                    0.7414769325849017,
                                    0.027757722467939765,
                                ],
                                [
                                    0.25722095051593136,
                                    0.00962925135441533,
                                    0.7066941925608805,
                                    0.026455605568772803,
                                ],
                                [
                                    0.04481274992354577,
                                    0.9104777283728094,
                                    0.002097327107122304,
                                    0.042612194596522504,
                                ],
                                [
                                    0.04481274992354577,
                                    0.002097327107122304,
                                    0.9104777283728094,
                                    0.042612194596522504,
                                ],
                                [
                                    0.08752333029622192,
                                    0.0040962684380909916,
                                    0.8677671480001332,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9869980460612706,
                                    0.010801398611706165,
                                    0.0021767338312494934,
                                    2.382149577371358e-05,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.9364986070611838,
                                    0.05267617283133628,
                                    0.010248748510235127,
                                    0.0005764715972447517,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.8638685940379567,
                                    0.11267636744670925,
                                    0.02074873348846404,
                                    0.00270630502686997,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.7928079629584961,
                                    0.17110718011831577,
                                    0.029679336522926526,
                                    0.00640552040026161,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.7451837712416985,
                                    0.2101067070546566,
                                    0.03487610391862285,
                                    0.009833417785021958,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9784667451754157,
                                    0.010708034717104492,
                                    0.010708034717104492,
                                    0.00011718539037538669,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8963305552814749,
                                    0.05041680028994414,
                                    0.05041680028994414,
                                    0.002835844138636882,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.965973647331744,
                                    0.01057131415292197,
                                    0.023201132560776102,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.8375091155282947,
                                    0.047108211998126086,
                                    0.10923824004312428,
                                    0.006144432430454938,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.6634629956448156,
                                    0.08653700435518441,
                                    0.2211543318816052,
                                    0.028845668118394806,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.506144432430455,
                                    0.10923824004312428,
                                    0.31634286705096765,
                                    0.06827446047545312,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.40832627199631266,
                                    0.11512876651902132,
                                    0.3717336031640087,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9534805494880724,
                                    0.010434593588739449,
                                    0.035694230404447705,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7786876757751146,
                                    0.043799623706308036,
                                    0.1680596797963044,
                                    0.009453020722272993,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.5443781751296444,
                                    0.07100449734393487,
                                    0.3402391523967764,
                                    0.04437817512964435,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.33580350705266665,
                                    0.07247453841306932,
                                    0.486683792428756,
                                    0.10503816210550808,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.2081591351574892,
                                    0.058691066712857475,
                                    0.5719007400028322,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9427725147709679,
                                    0.046402265121552204,
                                    0.010317408198364061,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9427725147709679,
                                    0.010317408198364061,
                                    0.046402265121552204,
                                    0.0005078119091158175,
                                ],
                                [
                                    0.9449492486022174,
                                    0.010341229694137775,
                                    0.044225531290302704,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.7282708754851703,
                                    0.21847648008624856,
                                    0.040963779567671145,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7282708754851703,
                                    0.040963779567671145,
                                    0.21847648008624856,
                                    0.012288864860909876,
                                ],
                                [
                                    0.7385196239954055,
                                    0.0415402511649159,
                                    0.20822773157601343,
                                    0.011712393263665124,
                                ],
                                [
                                    0.4423086637632104,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.05769133623678961,
                                ],
                                [
                                    0.4423086637632104,
                                    0.05769133623678961,
                                    0.4423086637632104,
                                    0.05769133623678961,
                                ],
                                [
                                    0.46305739725167444,
                                    0.06039764126365958,
                                    0.4215599302747463,
                                    0.05498503120991964,
                                ],
                                [
                                    0.18980156537948736,
                                    0.6326857341019353,
                                    0.04096377956767115,
                                    0.13654892095090623,
                                ],
                                [
                                    0.18980156537948736,
                                    0.04096377956767115,
                                    0.6326857341019353,
                                    0.13654892095090623,
                                ],
                                [
                                    0.21948090190241393,
                                    0.04736929996793277,
                                    0.6030063975790088,
                                    0.13014340055064463,
                                ],
                                [
                                    0.036592668832304,
                                    0.7434672063280174,
                                    0.010317408198364074,
                                    0.2096227166413145,
                                ],
                                [
                                    0.036592668832304,
                                    0.010317408198364074,
                                    0.7434672063280174,
                                    0.2096227166413145,
                                ],
                                [
                                    0.07146877275092688,
                                    0.020150825983386036,
                                    0.7085911024093945,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9743960202675932,
                                    0.023403424405383556,
                                    0.002148941217072754,
                                    5.1614109950452745e-05,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8750411502450566,
                                    0.11413362964746347,
                                    0.009576177281364125,
                                    0.001249042826115755,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.7324087211134995,
                                    0.2441362403711665,
                                    0.017591278886500507,
                                    0.005863759628833502,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.5931766767843609,
                                    0.37073846629245083,
                                    0.022205995689218255,
                                    0.013878861233969883,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.5000516141099505,
                                    0.4552388641864047,
                                    0.02340342440538356,
                                    0.021306097298261252,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.965973647331744,
                                    0.023201132560776102,
                                    0.01057131415292197,
                                    0.00025390595455790875,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.8375091155282947,
                                    0.10923824004312428,
                                    0.047108211998126086,
                                    0.006144432430454938,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.6634629956448156,
                                    0.2211543318816052,
                                    0.08653700435518441,
                                    0.028845668118394806,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.506144432430455,
                                    0.31634286705096765,
                                    0.10923824004312428,
                                    0.06827446047545312,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.40832627199631266,
                                    0.3717336031640087,
                                    0.11512876651902132,
                                    0.10481135832065724,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9536400618010877,
                                    0.022904899683578207,
                                    0.022904899683578207,
                                    0.0005501388317558017,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.7825478161599868,
                                    0.10206951136643397,
                                    0.10206951136643397,
                                    0.013313161107145257,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [0.5625, 0.1875, 0.1875, 0.0625],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9413064762704315,
                                    0.022608666806380313,
                                    0.03523848521423444,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.727586516791679,
                                    0.09490078268974365,
                                    0.15703081073474182,
                                    0.020481889783835572,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.4615370043551844,
                                    0.1538456681183948,
                                    0.2884629956448156,
                                    0.09615433188160519,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.2512472347309941,
                                    0.15703081073474187,
                                    0.36413543774258517,
                                    0.22758651679167888,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.139684082697867,
                                    0.1271661191724797,
                                    0.38377095581746706,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9307351621175095,
                                    0.045809799367156415,
                                    0.022354760851822406,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9307351621175095,
                                    0.022354760851822406,
                                    0.045809799367156415,
                                    0.0011002776635116035,
                                ],
                                [
                                    0.9328841033345823,
                                    0.02240637496177286,
                                    0.04366085815008366,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6804783047935528,
                                    0.20413902273286794,
                                    0.0887563502592887,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6804783047935528,
                                    0.0887563502592887,
                                    0.20413902273286794,
                                    0.026626322214290513,
                                ],
                                [
                                    0.6900544820749169,
                                    0.09000539308540446,
                                    0.1945628454515038,
                                    0.02537727938817476,
                                ],
                                [0.375, 0.375, 0.125, 0.125],
                                [0.375, 0.125, 0.375, 0.125],
                                [
                                    0.3925912788865005,
                                    0.1308637596288335,
                                    0.3574087211134995,
                                    0.11913624037116649,
                                ],
                                [
                                    0.1420089946878698,
                                    0.4733736777857095,
                                    0.08875635025928873,
                                    0.295860977267132,
                                ],
                                [
                                    0.1420089946878698,
                                    0.08875635025928873,
                                    0.4733736777857095,
                                    0.295860977267132,
                                ],
                                [
                                    0.16421499037708806,
                                    0.10263521149325863,
                                    0.45116768209649116,
                                    0.28198211603316214,
                                ],
                                [
                                    0.024555316178845644,
                                    0.4988997223364884,
                                    0.02235476085182243,
                                    0.45419020063284354,
                                ],
                                [
                                    0.024555316178845644,
                                    0.02235476085182243,
                                    0.4988997223364884,
                                    0.45419020063284354,
                                ],
                                [
                                    0.04795874058422921,
                                    0.0436608581500837,
                                    0.4754962979311048,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9617939944739158,
                                    0.03600545019906094,
                                    0.002121148602896015,
                                    7.94067241271919e-05,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.8135836934289296,
                                    0.17559108646359065,
                                    0.00890360605249312,
                                    0.001921614054986758,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.6009488481890423,
                                    0.3755961132956237,
                                    0.014433824284536975,
                                    0.009021214230797034,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.393545390610226,
                                    0.5703697524665858,
                                    0.014732654855509984,
                                    0.021352202067678152,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2549194569782024,
                                    0.7003710213181528,
                                    0.011930744892144265,
                                    0.03277877681150055,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9534805494880724,
                                    0.035694230404447705,
                                    0.010434593588739449,
                                    0.00039062651874043075,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.7786876757751146,
                                    0.1680596797963044,
                                    0.043799623706308036,
                                    0.009453020722272993,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.5443781751296444,
                                    0.3402391523967764,
                                    0.07100449734393487,
                                    0.04437817512964435,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.33580350705266665,
                                    0.486683792428756,
                                    0.07247453841306932,
                                    0.10503816210550808,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.2081591351574892,
                                    0.5719007400028322,
                                    0.058691066712857475,
                                    0.16124905812682108,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9413064762704315,
                                    0.03523848521423444,
                                    0.022608666806380313,
                                    0.0008463717089536947,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.727586516791679,
                                    0.15703081073474182,
                                    0.09490078268974365,
                                    0.020481889783835572,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.4615370043551844,
                                    0.2884629956448156,
                                    0.1538456681183948,
                                    0.09615433188160519,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.2512472347309941,
                                    0.36413543774258517,
                                    0.15703081073474187,
                                    0.22758651679167888,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.139684082697867,
                                    0.38377095581746706,
                                    0.1271661191724797,
                                    0.34937884231218624,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9291324030527905,
                                    0.03478274002402117,
                                    0.03478274002402117,
                                    0.0013021168991669586,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6764853578082434,
                                    0.14600194167317926,
                                    0.14600194167317926,
                                    0.03151075884539815,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3786958335807245,
                                    0.23668683889285475,
                                    0.23668683889285475,
                                    0.147930488633566,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.16669096240932157,
                                    0.2415870830564144,
                                    0.2415870830564144,
                                    0.3501348714778496,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.9186978094640511,
                                    0.045217333612760625,
                                    0.03439211350528074,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9186978094640511,
                                    0.03439211350528074,
                                    0.045217333612760625,
                                    0.0016927434179073895,
                                ],
                                [
                                    0.9208189580669471,
                                    0.034471520229407936,
                                    0.04309618500986461,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6326857341019353,
                                    0.1898015653794873,
                                    0.13654892095090623,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6326857341019353,
                                    0.13654892095090623,
                                    0.1898015653794873,
                                    0.040963779567671145,
                                ],
                                [
                                    0.6415893401544284,
                                    0.13847053500589301,
                                    0.18089795932699418,
                                    0.039042165512684385,
                                ],
                                [
                                    0.3076913362367896,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3076913362367896,
                                    0.19230866376321037,
                                    0.3076913362367896,
                                    0.19230866376321037,
                                ],
                                [
                                    0.3221251605213266,
                                    0.20132987799400742,
                                    0.29325751195225264,
                                    0.18328744953241333,
                                ],
                                [
                                    0.09421642399625223,
                                    0.31406162146948374,
                                    0.1365489209509063,
                                    0.45517303358335776,
                                ],
                                [
                                    0.09421642399625223,
                                    0.1365489209509063,
                                    0.31406162146948374,
                                    0.45517303358335776,
                                ],
                                [
                                    0.10894907885176223,
                                    0.15790112301858447,
                                    0.29932896661397373,
                                    0.4338208315156796,
                                ],
                                [
                                    0.01251796352538729,
                                    0.2543322383449594,
                                    0.034392113505280784,
                                    0.6987576846243725,
                                ],
                                [
                                    0.01251796352538729,
                                    0.034392113505280784,
                                    0.2543322383449594,
                                    0.6987576846243725,
                                ],
                                [
                                    0.02444870841753156,
                                    0.06717089031678135,
                                    0.24240149345281514,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9531883087454855,
                                    0.04461113592749119,
                                    0.0021021695508695918,
                                    9.838577615361528e-05,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7716155553146976,
                                    0.21755922457782245,
                                    0.008444319845623756,
                                    0.002380900261856123,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.5111773804259112,
                                    0.46536758105875475,
                                    0.012277658089422806,
                                    0.011177380425911203,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.25722095051593136,
                                    0.7066941925608805,
                                    0.00962925135441533,
                                    0.026455605568772803,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.08752333029622192,
                                    0.8677671480001332,
                                    0.0040962684380909916,
                                    0.04061325326555382,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9449492486022174,
                                    0.044225531290302704,
                                    0.010341229694137775,
                                    0.0004839904133421039,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.7385196239954055,
                                    0.20822773157601343,
                                    0.0415402511649159,
                                    0.011712393263665124,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.46305739725167444,
                                    0.4215599302747463,
                                    0.06039764126365958,
                                    0.05498503120991964,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.21948090190241393,
                                    0.6030063975790088,
                                    0.04736929996793277,
                                    0.13014340055064463,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.07146877275092688,
                                    0.7085911024093945,
                                    0.020150825983386036,
                                    0.1997892988562925,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9328841033345823,
                                    0.04366085815008366,
                                    0.02240637496177286,
                                    0.001048663553561151,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6900544820749169,
                                    0.1945628454515038,
                                    0.09000539308540446,
                                    0.02537727938817476,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3925912788865005,
                                    0.3574087211134995,
                                    0.1308637596288335,
                                    0.11913624037116649,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.16421499037708806,
                                    0.45116768209649116,
                                    0.10263521149325863,
                                    0.28198211603316214,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.04795874058422921,
                                    0.4754962979311048,
                                    0.0436608581500837,
                                    0.43288410333458227,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9208189580669471,
                                    0.04309618500986461,
                                    0.034471520229407936,
                                    0.0016133366937801977,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6415893401544284,
                                    0.18089795932699418,
                                    0.13847053500589301,
                                    0.039042165512684385,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.3221251605213266,
                                    0.29325751195225264,
                                    0.20132987799400742,
                                    0.18328744953241333,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.10894907885176223,
                                    0.29932896661397373,
                                    0.15790112301858447,
                                    0.4338208315156796,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.02444870841753156,
                                    0.24240149345281514,
                                    0.06717089031678135,
                                    0.665978907812872,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                                [
                                    0.9104777283728094,
                                    0.04481274992354572,
                                    0.042612194596522504,
                                    0.002097327107122302,
                                ],
                                [
                                    0.9104777283728094,
                                    0.042612194596522504,
                                    0.04481274992354572,
                                    0.002097327107122302,
                                ],
                                [
                                    0.912579897923679,
                                    0.042710580372676124,
                                    0.042710580372676124,
                                    0.0019989413309686862,
                                ],
                                [
                                    0.6000490889895124,
                                    0.18001078617080893,
                                    0.16918556606332905,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6000490889895124,
                                    0.16918556606332905,
                                    0.18001078617080893,
                                    0.05075455877634952,
                                ],
                                [
                                    0.6084934088351361,
                                    0.17156646632518516,
                                    0.17156646632518516,
                                    0.04837365851449339,
                                ],
                                [
                                    0.261727519257667,
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.23827248074233298,
                                ],
                                [
                                    0.261727519257667,
                                    0.23827248074233298,
                                    0.261727519257667,
                                    0.23827248074233298,
                                ],
                                [
                                    0.27400517734708985,
                                    0.2494498611682442,
                                    0.2494498611682442,
                                    0.22709510031642177,
                                ],
                                [
                                    0.061579778883829435,
                                    0.20527042298651726,
                                    0.16918556606332907,
                                    0.5639642320663243,
                                ],
                                [
                                    0.061579778883829435,
                                    0.16918556606332907,
                                    0.20527042298651726,
                                    0.5639642320663243,
                                ],
                                [
                                    0.07120903023824478,
                                    0.1956411716321019,
                                    0.1956411716321019,
                                    0.5375086264975514,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.0873217163001674,
                                    0.04261219459652255,
                                    0.8657682066691645,
                                ],
                                [
                                    0.0042978824341455175,
                                    0.04261219459652255,
                                    0.0873217163001674,
                                    0.8657682066691645,
                                ],
                                [
                                    0.008394150872236512,
                                    0.0832254478620764,
                                    0.0832254478620764,
                                    0.8251549534036107,
                                ],
                            ]
                        ),
                        np.array(
                            [
                                9.53678474896536e-10,
                                9.53678474896536e-10,
                                2.0329927709840623e-08,
                                2.293504917961684e-07,
                                2.293504917961684e-07,
                                4.889151890461143e-06,
                                2.772851822130939e-06,
                                2.772851822130939e-06,
                                5.910993964725648e-05,
                                8.49502051542355e-06,
                                8.49502051542355e-06,
                                0.0001810915916823123,
                                7.998437866532609e-06,
                                7.998437866532609e-06,
                                0.0001705057499970323,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.106957413803658e-08,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                9.876837188172655e-06,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                0.00011941115006831959,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                0.00036583280848420083,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                0.00034444778360304097,
                                2.2898924611804724e-09,
                                2.2898924611804724e-09,
                                4.8814510785889953e-08,
                                5.506970912697355e-07,
                                5.506970912697355e-07,
                                1.173941988860327e-05,
                                6.6579383414908584e-06,
                                6.6579383414908584e-06,
                                0.00014192981045710396,
                                2.03975280431408e-05,
                                2.03975280431408e-05,
                                0.00043482188336219687,
                                1.9205175595245023e-05,
                                1.9205175595245023e-05,
                                0.0004094040515578223,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.106957413803658e-08,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                9.876837188172655e-06,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                0.00011941115006831959,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                0.00036583280848420083,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                0.00034444778360304097,
                                9.53678474896536e-10,
                                9.53678474896536e-10,
                                2.0329927709840623e-08,
                                2.293504917961684e-07,
                                2.293504917961684e-07,
                                4.889151890461143e-06,
                                2.772851822130939e-06,
                                2.772851822130939e-06,
                                5.910993964725648e-05,
                                8.49502051542355e-06,
                                8.49502051542355e-06,
                                0.0001810915916823123,
                                7.998437866532609e-06,
                                7.998437866532609e-06,
                                0.0001705057499970323,
                                9.477434442796908e-09,
                                9.477434442796908e-09,
                                4.106957413803658e-08,
                                2.2792317407155854e-06,
                                2.2792317407155854e-06,
                                9.876837188172655e-06,
                                2.7555955236052672e-05,
                                2.7555955236052672e-05,
                                0.00011941115006831959,
                                8.442153424284435e-05,
                                8.442153424284435e-05,
                                0.00036583280848420083,
                                7.948661159943993e-05,
                                7.948661159943993e-05,
                                0.00034444778360304097,
                                1.9145872136988548e-08,
                                1.9145872136988548e-08,
                                8.296684296930566e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                1.9952726981543877e-05,
                                5.5667258765690645e-05,
                                5.5667258765690645e-05,
                                0.00024122884993168082,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0007390384198412779,
                                0.00016057515475002683,
                                0.00016057515475002683,
                                0.0006958373874846588,
                                2.275641765349403e-08,
                                2.275641765349403e-08,
                                9.861280366298018e-08,
                                5.472699361190984e-06,
                                5.472699361190984e-06,
                                2.371542989890507e-05,
                                6.616503970324934e-05,
                                6.616503970324934e-05,
                                0.00028672000000000034,
                                0.00020270588034919338,
                                0.00020270588034919338,
                                0.0008784069392898218,
                                0.00019085655958218478,
                                0.00019085655958218478,
                                0.0008270590180076123,
                                1.9145872136988548e-08,
                                1.9145872136988548e-08,
                                8.296684296930566e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                1.9952726981543877e-05,
                                5.5667258765690645e-05,
                                5.5667258765690645e-05,
                                0.00024122884993168082,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0007390384198412779,
                                0.00016057515475002683,
                                0.00016057515475002683,
                                0.0006958373874846588,
                                9.477434442796908e-09,
                                9.477434442796908e-09,
                                4.106957413803658e-08,
                                2.2792317407155854e-06,
                                2.2792317407155854e-06,
                                9.876837188172655e-06,
                                2.7555955236052672e-05,
                                2.7555955236052672e-05,
                                0.00011941115006831959,
                                8.442153424284435e-05,
                                8.442153424284435e-05,
                                0.00036583280848420083,
                                7.948661159943993e-05,
                                7.948661159943993e-05,
                                0.00034444778360304097,
                                2.440725539294497e-08,
                                2.440725539294497e-08,
                                4.881451078588994e-08,
                                5.869709944301633e-06,
                                5.869709944301633e-06,
                                1.1739419888603266e-05,
                                7.096490522855197e-05,
                                7.096490522855197e-05,
                                0.00014192981045710394,
                                0.00021741094168109835,
                                0.00021741094168109835,
                                0.0004348218833621967,
                                0.00020470202577891112,
                                0.00020470202577891112,
                                0.00040940405155782223,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                9.861280366298015e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                2.3715429898905068e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.0002867200000000003,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.0008784069392898217,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                0.0008270590180076121,
                                5.8604646737439054e-08,
                                5.8604646737439054e-08,
                                1.1720929347487811e-07,
                                1.4093853331680334e-05,
                                1.4093853331680334e-05,
                                2.8187706663360667e-05,
                                0.00017039495570965636,
                                0.00017039495570965636,
                                0.0003407899114193127,
                                0.0005220288487560819,
                                0.0005220288487560819,
                                0.0010440576975121638,
                                0.0004915132698893654,
                                0.0004915132698893654,
                                0.0009830265397787307,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                9.861280366298015e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                2.3715429898905068e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.0002867200000000003,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.0008784069392898217,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                0.0008270590180076121,
                                2.440725539294497e-08,
                                2.440725539294497e-08,
                                4.881451078588994e-08,
                                5.869709944301633e-06,
                                5.869709944301633e-06,
                                1.1739419888603266e-05,
                                7.096490522855197e-05,
                                7.096490522855197e-05,
                                0.00014192981045710394,
                                0.00021741094168109835,
                                0.00021741094168109835,
                                0.0004348218833621967,
                                0.00020470202577891112,
                                0.00020470202577891112,
                                0.00040940405155782223,
                                3.159213969523967e-08,
                                3.159213969523967e-08,
                                4.106957413803658e-08,
                                7.597605447457069e-06,
                                7.597605447457069e-06,
                                9.876837188172655e-06,
                                9.18551948322669e-05,
                                9.18551948322669e-05,
                                0.00011941115006831959,
                                0.0002814112742413565,
                                0.0002814112742413565,
                                0.00036583280848420083,
                                0.000264961172003601,
                                0.000264961172003601,
                                0.00034444778360304097,
                                6.382097083231711e-08,
                                6.382097083231711e-08,
                                8.296684296930566e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                1.9952726981543877e-05,
                                0.00018556159116599018,
                                0.00018556159116599018,
                                0.00024122884993168082,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0007390384198412779,
                                0.0005352622327346319,
                                0.0005352622327346319,
                                0.0006958373874846588,
                                7.585638600948615e-08,
                                7.585638600948615e-08,
                                9.861280366298018e-08,
                                1.8242730537714085e-05,
                                1.8242730537714085e-05,
                                2.371542989890507e-05,
                                0.00022055496029675098,
                                0.00022055496029675098,
                                0.00028672000000000034,
                                0.0006757010589406283,
                                0.0006757010589406283,
                                0.0008784069392898218,
                                0.0006362024584254275,
                                0.0006362024584254275,
                                0.0008270590180076123,
                                6.382097083231711e-08,
                                6.382097083231711e-08,
                                8.296684296930566e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                1.9952726981543877e-05,
                                0.00018556159116599018,
                                0.00018556159116599018,
                                0.00024122884993168082,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0007390384198412779,
                                0.0005352622327346319,
                                0.0005352622327346319,
                                0.0006958373874846588,
                                3.159213969523967e-08,
                                3.159213969523967e-08,
                                4.106957413803658e-08,
                                7.597605447457069e-06,
                                7.597605447457069e-06,
                                9.876837188172655e-06,
                                9.18551948322669e-05,
                                9.18551948322669e-05,
                                0.00011941115006831959,
                                0.0002814112742413565,
                                0.0002814112742413565,
                                0.00036583280848420083,
                                0.000264961172003601,
                                0.000264961172003601,
                                0.00034444778360304097,
                                1.9376249234944087e-08,
                                1.9376249234944087e-08,
                                2.0329927709840623e-08,
                                4.659801398664974e-06,
                                4.659801398664974e-06,
                                4.889151890461143e-06,
                                5.6337087825125535e-05,
                                5.6337087825125535e-05,
                                5.910993964725648e-05,
                                0.00017259657116688875,
                                0.00017259657116688875,
                                0.0001810915916823123,
                                0.0001625073121304997,
                                0.0001625073121304997,
                                0.0001705057499970323,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                4.106957413803658e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                9.876837188172655e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.00011941115006831959,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00036583280848420083,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                0.00034444778360304097,
                                4.652461832470948e-08,
                                4.652461832470948e-08,
                                4.8814510785889953e-08,
                                1.1188722797333533e-05,
                                1.1188722797333533e-05,
                                1.173941988860327e-05,
                                0.0001352718721156131,
                                0.0001352718721156131,
                                0.00014192981045710396,
                                0.00041442435531905607,
                                0.00041442435531905607,
                                0.00043482188336219687,
                                0.00039019887596257723,
                                0.00039019887596257723,
                                0.0004094040515578223,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                4.106957413803658e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                9.876837188172655e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.00011941115006831959,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00036583280848420083,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                0.00034444778360304097,
                                1.9376249234944087e-08,
                                1.9376249234944087e-08,
                                2.0329927709840623e-08,
                                4.659801398664974e-06,
                                4.659801398664974e-06,
                                4.889151890461143e-06,
                                5.6337087825125535e-05,
                                5.6337087825125535e-05,
                                5.910993964725648e-05,
                                0.00017259657116688875,
                                0.00017259657116688875,
                                0.0001810915916823123,
                                0.0001625073121304997,
                                0.0001625073121304997,
                                0.0001705057499970323,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.106957413803658e-08,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                9.876837188172655e-06,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                0.00011941115006831959,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                0.00036583280848420083,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                0.00034444778360304097,
                                3.891980994681466e-09,
                                3.891980994681466e-09,
                                8.296684296930566e-08,
                                9.359839596761115e-07,
                                9.359839596761115e-07,
                                1.9952726981543877e-05,
                                1.1316063932314603e-05,
                                1.1316063932314603e-05,
                                0.00024122884993168082,
                                3.466834920337752e-05,
                                3.466834920337752e-05,
                                0.0007390384198412779,
                                3.2641785447724135e-05,
                                3.2641785447724135e-05,
                                0.0006958373874846588,
                                4.625934216040542e-09,
                                4.625934216040542e-09,
                                9.861280366298018e-08,
                                1.1124926433730444e-06,
                                1.1124926433730444e-06,
                                2.371542989890507e-05,
                                1.345005728623315e-05,
                                1.345005728623315e-05,
                                0.00028672000000000034,
                                4.120613718635886e-05,
                                4.120613718635886e-05,
                                0.0008784069392898218,
                                3.879740224364574e-05,
                                3.879740224364574e-05,
                                0.0008270590180076123,
                                3.891980994681466e-09,
                                3.891980994681466e-09,
                                8.296684296930566e-08,
                                9.359839596761115e-07,
                                9.359839596761115e-07,
                                1.9952726981543877e-05,
                                1.1316063932314603e-05,
                                1.1316063932314603e-05,
                                0.00024122884993168082,
                                3.466834920337752e-05,
                                3.466834920337752e-05,
                                0.0007390384198412779,
                                3.2641785447724135e-05,
                                3.2641785447724135e-05,
                                0.0006958373874846588,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.106957413803658e-08,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                9.876837188172655e-06,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                0.00011941115006831959,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                0.00036583280848420083,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                0.00034444778360304097,
                                1.9145872136988545e-08,
                                1.9145872136988545e-08,
                                8.296684296930565e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                1.9952726981543877e-05,
                                5.566725876569064e-05,
                                5.566725876569064e-05,
                                0.0002412288499316808,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0007390384198412779,
                                0.0001605751547500268,
                                0.0001605751547500268,
                                0.0006958373874846587,
                                3.867760015628625e-08,
                                3.867760015628625e-08,
                                1.6760575625054447e-07,
                                9.301590473982536e-06,
                                9.301590473982536e-06,
                                4.030757077546653e-05,
                                0.00011245640631728155,
                                0.00011245640631728155,
                                0.00048731929979794954,
                                0.0003445259754349043,
                                0.0003445259754349043,
                                0.0014929710330370237,
                                0.00032438645709206127,
                                0.00032438645709206127,
                                0.0014056983173376424,
                                4.597145623316258e-08,
                                4.597145623316258e-08,
                                1.9921299813752063e-07,
                                1.1055692639813157e-05,
                                1.1055692639813157e-05,
                                4.7908808154641816e-05,
                                0.00013366353497279776,
                                0.00013366353497279776,
                                0.0005792184047539919,
                                0.0004094969888745578,
                                0.0004094969888745578,
                                0.001774516832102004,
                                0.00038555954233408254,
                                0.00038555954233408254,
                                0.0016707861504177304,
                                3.867760015628625e-08,
                                3.867760015628625e-08,
                                1.6760575625054447e-07,
                                9.301590473982536e-06,
                                9.301590473982536e-06,
                                4.030757077546653e-05,
                                0.00011245640631728155,
                                0.00011245640631728155,
                                0.00048731929979794954,
                                0.0003445259754349043,
                                0.0003445259754349043,
                                0.0014929710330370237,
                                0.00032438645709206127,
                                0.00032438645709206127,
                                0.0014056983173376424,
                                1.9145872136988545e-08,
                                1.9145872136988545e-08,
                                8.296684296930565e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                1.9952726981543877e-05,
                                5.566725876569064e-05,
                                5.566725876569064e-05,
                                0.0002412288499316808,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0007390384198412779,
                                0.0001605751547500268,
                                0.0001605751547500268,
                                0.0006958373874846587,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                9.861280366298015e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                2.3715429898905068e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.0002867200000000003,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.0008784069392898217,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                0.0008270590180076121,
                                9.960649906876032e-08,
                                9.960649906876032e-08,
                                1.9921299813752063e-07,
                                2.3954404077320908e-05,
                                2.3954404077320908e-05,
                                4.7908808154641816e-05,
                                0.00028960920237699594,
                                0.00028960920237699594,
                                0.0005792184047539919,
                                0.000887258416051002,
                                0.000887258416051002,
                                0.001774516832102004,
                                0.0008353930752088652,
                                0.0008353930752088652,
                                0.0016707861504177304,
                                1.1839038083995065e-07,
                                1.1839038083995065e-07,
                                2.367807616799013e-07,
                                2.8471746803894416e-05,
                                2.8471746803894416e-05,
                                5.694349360778883e-05,
                                0.00034422396213823296,
                                0.00034422396213823296,
                                0.0006884479242764659,
                                0.0010545783935967507,
                                0.0010545783935967507,
                                0.0021091567871935014,
                                0.0009929322408647324,
                                0.0009929322408647324,
                                0.001985864481729465,
                                9.960649906876032e-08,
                                9.960649906876032e-08,
                                1.9921299813752063e-07,
                                2.3954404077320908e-05,
                                2.3954404077320908e-05,
                                4.7908808154641816e-05,
                                0.00028960920237699594,
                                0.00028960920237699594,
                                0.0005792184047539919,
                                0.000887258416051002,
                                0.000887258416051002,
                                0.001774516832102004,
                                0.0008353930752088652,
                                0.0008353930752088652,
                                0.0016707861504177304,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                9.861280366298015e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                2.3715429898905068e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.0002867200000000003,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.0008784069392898217,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                0.0008270590180076121,
                                6.38209708323171e-08,
                                6.38209708323171e-08,
                                8.296684296930565e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                1.9952726981543877e-05,
                                0.00018556159116599015,
                                0.00018556159116599015,
                                0.0002412288499316808,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0007390384198412779,
                                0.0005352622327346318,
                                0.0005352622327346318,
                                0.0006958373874846587,
                                1.289281560942582e-07,
                                1.289281560942582e-07,
                                1.6760575625054447e-07,
                                3.100598030148399e-05,
                                3.100598030148399e-05,
                                4.030757077546653e-05,
                                0.000374862893480668,
                                0.000374862893480668,
                                0.00048731929979794954,
                                0.0011484450576021194,
                                0.0011484450576021194,
                                0.0014929710330370237,
                                0.001081311860245581,
                                0.001081311860245581,
                                0.0014056983173376424,
                                1.5324154190435804e-07,
                                1.5324154190435804e-07,
                                1.9921299813752063e-07,
                                3.6853115514828654e-05,
                                3.6853115514828654e-05,
                                4.7908808154641816e-05,
                                0.0004455548697811941,
                                0.0004455548697811941,
                                0.0005792184047539919,
                                0.001365019843227446,
                                0.001365019843227446,
                                0.001774516832102004,
                                0.0012852266080836479,
                                0.0012852266080836479,
                                0.0016707861504177304,
                                1.289281560942582e-07,
                                1.289281560942582e-07,
                                1.6760575625054447e-07,
                                3.100598030148399e-05,
                                3.100598030148399e-05,
                                4.030757077546653e-05,
                                0.000374862893480668,
                                0.000374862893480668,
                                0.00048731929979794954,
                                0.0011484450576021194,
                                0.0011484450576021194,
                                0.0014929710330370237,
                                0.001081311860245581,
                                0.001081311860245581,
                                0.0014056983173376424,
                                6.38209708323171e-08,
                                6.38209708323171e-08,
                                8.296684296930565e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                1.9952726981543877e-05,
                                0.00018556159116599015,
                                0.00018556159116599015,
                                0.0002412288499316808,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0007390384198412779,
                                0.0005352622327346318,
                                0.0005352622327346318,
                                0.0006958373874846587,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                4.106957413803658e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                9.876837188172655e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.00011941115006831959,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00036583280848420083,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                0.00034444778360304097,
                                7.907486197462419e-08,
                                7.907486197462419e-08,
                                8.296684296930566e-08,
                                1.9016743021867766e-05,
                                1.9016743021867766e-05,
                                1.9952726981543877e-05,
                                0.0002299127859993662,
                                0.0002299127859993662,
                                0.00024122884993168082,
                                0.0007043700706379003,
                                0.0007043700706379003,
                                0.0007390384198412779,
                                0.0006631956020369346,
                                0.0006631956020369346,
                                0.0006958373874846588,
                                9.398686944693963e-08,
                                9.398686944693963e-08,
                                9.861280366298018e-08,
                                2.2602937255532027e-05,
                                2.2602937255532027e-05,
                                2.371542989890507e-05,
                                0.00027326994271376716,
                                0.00027326994271376716,
                                0.00028672000000000034,
                                0.0008372008021034628,
                                0.0008372008021034628,
                                0.0008784069392898218,
                                0.0007882616157639666,
                                0.0007882616157639666,
                                0.0008270590180076123,
                                7.907486197462419e-08,
                                7.907486197462419e-08,
                                8.296684296930566e-08,
                                1.9016743021867766e-05,
                                1.9016743021867766e-05,
                                1.9952726981543877e-05,
                                0.0002299127859993662,
                                0.0002299127859993662,
                                0.00024122884993168082,
                                0.0007043700706379003,
                                0.0007043700706379003,
                                0.0007390384198412779,
                                0.0006631956020369346,
                                0.0006631956020369346,
                                0.0006958373874846588,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                4.106957413803658e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                9.876837188172655e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.00011941115006831959,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00036583280848420083,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                0.00034444778360304097,
                                2.289892461180472e-09,
                                2.289892461180472e-09,
                                4.881451078588994e-08,
                                5.506970912697354e-07,
                                5.506970912697354e-07,
                                1.1739419888603266e-05,
                                6.657938341490857e-06,
                                6.657938341490857e-06,
                                0.00014192981045710394,
                                2.0397528043140793e-05,
                                2.0397528043140793e-05,
                                0.0004348218833621967,
                                1.9205175595245023e-05,
                                1.9205175595245023e-05,
                                0.00040940405155782223,
                                4.62593421604054e-09,
                                4.62593421604054e-09,
                                9.861280366298015e-08,
                                1.1124926433730441e-06,
                                1.1124926433730441e-06,
                                2.3715429898905068e-05,
                                1.3450057286233147e-05,
                                1.3450057286233147e-05,
                                0.0002867200000000003,
                                4.120613718635886e-05,
                                4.120613718635886e-05,
                                0.0008784069392898217,
                                3.879740224364573e-05,
                                3.879740224364573e-05,
                                0.0008270590180076121,
                                5.498296985616707e-09,
                                5.498296985616707e-09,
                                1.1720929347487811e-07,
                                1.3222874908961231e-06,
                                1.3222874908961231e-06,
                                2.8187706663360667e-05,
                                1.598648099595449e-05,
                                1.598648099595449e-05,
                                0.0003407899114193127,
                                4.897682701475749e-05,
                                4.897682701475749e-05,
                                0.0010440576975121638,
                                4.6113850704211296e-05,
                                4.6113850704211296e-05,
                                0.0009830265397787307,
                                4.62593421604054e-09,
                                4.62593421604054e-09,
                                9.861280366298015e-08,
                                1.1124926433730441e-06,
                                1.1124926433730441e-06,
                                2.3715429898905068e-05,
                                1.3450057286233147e-05,
                                1.3450057286233147e-05,
                                0.0002867200000000003,
                                4.120613718635886e-05,
                                4.120613718635886e-05,
                                0.0008784069392898217,
                                3.879740224364573e-05,
                                3.879740224364573e-05,
                                0.0008270590180076121,
                                2.289892461180472e-09,
                                2.289892461180472e-09,
                                4.881451078588994e-08,
                                5.506970912697354e-07,
                                5.506970912697354e-07,
                                1.1739419888603266e-05,
                                6.657938341490857e-06,
                                6.657938341490857e-06,
                                0.00014192981045710394,
                                2.0397528043140793e-05,
                                2.0397528043140793e-05,
                                0.0004348218833621967,
                                1.9205175595245023e-05,
                                1.9205175595245023e-05,
                                0.00040940405155782223,
                                2.2756417653494025e-08,
                                2.2756417653494025e-08,
                                9.861280366298015e-08,
                                5.472699361190983e-06,
                                5.472699361190983e-06,
                                2.3715429898905068e-05,
                                6.616503970324934e-05,
                                6.616503970324934e-05,
                                0.0002867200000000003,
                                0.00020270588034919336,
                                0.00020270588034919336,
                                0.0008784069392898217,
                                0.00019085655958218472,
                                0.00019085655958218472,
                                0.0008270590180076121,
                                4.597145623316258e-08,
                                4.597145623316258e-08,
                                1.9921299813752063e-07,
                                1.1055692639813157e-05,
                                1.1055692639813157e-05,
                                4.7908808154641816e-05,
                                0.00013366353497279776,
                                0.00013366353497279776,
                                0.0005792184047539919,
                                0.0004094969888745578,
                                0.0004094969888745578,
                                0.001774516832102004,
                                0.00038555954233408254,
                                0.00038555954233408254,
                                0.0016707861504177304,
                                5.4640794145913336e-08,
                                5.4640794145913336e-08,
                                2.367807616799013e-07,
                                1.3140584944897701e-05,
                                1.3140584944897701e-05,
                                5.694349360778883e-05,
                                0.00015886992272381387,
                                0.00015886992272381387,
                                0.0006884479242764659,
                                0.0004867202935443488,
                                0.0004867202935443488,
                                0.0021091567871935014,
                                0.00045826870214461,
                                0.00045826870214461,
                                0.001985864481729465,
                                4.597145623316258e-08,
                                4.597145623316258e-08,
                                1.9921299813752063e-07,
                                1.1055692639813157e-05,
                                1.1055692639813157e-05,
                                4.7908808154641816e-05,
                                0.00013366353497279776,
                                0.00013366353497279776,
                                0.0005792184047539919,
                                0.0004094969888745578,
                                0.0004094969888745578,
                                0.001774516832102004,
                                0.00038555954233408254,
                                0.00038555954233408254,
                                0.0016707861504177304,
                                2.2756417653494025e-08,
                                2.2756417653494025e-08,
                                9.861280366298015e-08,
                                5.472699361190983e-06,
                                5.472699361190983e-06,
                                2.3715429898905068e-05,
                                6.616503970324934e-05,
                                6.616503970324934e-05,
                                0.0002867200000000003,
                                0.00020270588034919336,
                                0.00020270588034919336,
                                0.0008784069392898217,
                                0.00019085655958218472,
                                0.00019085655958218472,
                                0.0008270590180076121,
                                5.860464673743906e-08,
                                5.860464673743906e-08,
                                1.1720929347487812e-07,
                                1.4093853331680334e-05,
                                1.4093853331680334e-05,
                                2.8187706663360667e-05,
                                0.0001703949557096564,
                                0.0001703949557096564,
                                0.0003407899114193128,
                                0.000522028848756082,
                                0.000522028848756082,
                                0.001044057697512164,
                                0.0004915132698893654,
                                0.0004915132698893654,
                                0.0009830265397787307,
                                1.1839038083995065e-07,
                                1.1839038083995065e-07,
                                2.367807616799013e-07,
                                2.8471746803894416e-05,
                                2.8471746803894416e-05,
                                5.694349360778883e-05,
                                0.00034422396213823296,
                                0.00034422396213823296,
                                0.0006884479242764659,
                                0.0010545783935967507,
                                0.0010545783935967507,
                                0.0021091567871935014,
                                0.0009929322408647324,
                                0.0009929322408647324,
                                0.001985864481729465,
                                1.4071654366401172e-07,
                                1.4071654366401172e-07,
                                2.8143308732802344e-07,
                                3.3840974020829617e-05,
                                3.3840974020829617e-05,
                                6.768194804165923e-05,
                                0.0004091380216430425,
                                0.0004091380216430425,
                                0.000818276043286085,
                                0.0012534517206283392,
                                0.0012534517206283392,
                                0.0025069034412566783,
                                0.0011801802818417674,
                                0.0011801802818417674,
                                0.002360360563683535,
                                1.1839038083995065e-07,
                                1.1839038083995065e-07,
                                2.367807616799013e-07,
                                2.8471746803894416e-05,
                                2.8471746803894416e-05,
                                5.694349360778883e-05,
                                0.00034422396213823296,
                                0.00034422396213823296,
                                0.0006884479242764659,
                                0.0010545783935967507,
                                0.0010545783935967507,
                                0.0021091567871935014,
                                0.0009929322408647324,
                                0.0009929322408647324,
                                0.001985864481729465,
                                5.860464673743906e-08,
                                5.860464673743906e-08,
                                1.1720929347487812e-07,
                                1.4093853331680334e-05,
                                1.4093853331680334e-05,
                                2.8187706663360667e-05,
                                0.0001703949557096564,
                                0.0001703949557096564,
                                0.0003407899114193128,
                                0.000522028848756082,
                                0.000522028848756082,
                                0.001044057697512164,
                                0.0004915132698893654,
                                0.0004915132698893654,
                                0.0009830265397787307,
                                7.585638600948612e-08,
                                7.585638600948612e-08,
                                9.861280366298015e-08,
                                1.8242730537714085e-05,
                                1.8242730537714085e-05,
                                2.3715429898905068e-05,
                                0.00022055496029675095,
                                0.00022055496029675095,
                                0.0002867200000000003,
                                0.0006757010589406282,
                                0.0006757010589406282,
                                0.0008784069392898217,
                                0.0006362024584254273,
                                0.0006362024584254273,
                                0.0008270590180076121,
                                1.5324154190435804e-07,
                                1.5324154190435804e-07,
                                1.9921299813752063e-07,
                                3.6853115514828654e-05,
                                3.6853115514828654e-05,
                                4.7908808154641816e-05,
                                0.0004455548697811941,
                                0.0004455548697811941,
                                0.0005792184047539919,
                                0.001365019843227446,
                                0.001365019843227446,
                                0.001774516832102004,
                                0.0012852266080836479,
                                0.0012852266080836479,
                                0.0016707861504177304,
                                1.8213996753398794e-07,
                                1.8213996753398794e-07,
                                2.367807616799013e-07,
                                4.3802908662891124e-05,
                                4.3802908662891124e-05,
                                5.694349360778883e-05,
                                0.000529578001552652,
                                0.000529578001552652,
                                0.0006884479242764659,
                                0.0016224364936491525,
                                0.0016224364936491525,
                                0.0021091567871935014,
                                0.0015275957795848547,
                                0.0015275957795848547,
                                0.001985864481729465,
                                1.5324154190435804e-07,
                                1.5324154190435804e-07,
                                1.9921299813752063e-07,
                                3.6853115514828654e-05,
                                3.6853115514828654e-05,
                                4.7908808154641816e-05,
                                0.0004455548697811941,
                                0.0004455548697811941,
                                0.0005792184047539919,
                                0.001365019843227446,
                                0.001365019843227446,
                                0.001774516832102004,
                                0.0012852266080836479,
                                0.0012852266080836479,
                                0.0016707861504177304,
                                7.585638600948612e-08,
                                7.585638600948612e-08,
                                9.861280366298015e-08,
                                1.8242730537714085e-05,
                                1.8242730537714085e-05,
                                2.3715429898905068e-05,
                                0.00022055496029675095,
                                0.00022055496029675095,
                                0.0002867200000000003,
                                0.0006757010589406282,
                                0.0006757010589406282,
                                0.0008784069392898217,
                                0.0006362024584254273,
                                0.0006362024584254273,
                                0.0008270590180076121,
                                4.6524618324709464e-08,
                                4.6524618324709464e-08,
                                4.881451078588994e-08,
                                1.118872279733353e-05,
                                1.118872279733353e-05,
                                1.1739419888603266e-05,
                                0.00013527187211561308,
                                0.00013527187211561308,
                                0.00014192981045710394,
                                0.0004144243553190559,
                                0.0004144243553190559,
                                0.0004348218833621967,
                                0.0003901988759625772,
                                0.0003901988759625772,
                                0.00040940405155782223,
                                9.39868694469396e-08,
                                9.39868694469396e-08,
                                9.861280366298015e-08,
                                2.2602937255532023e-05,
                                2.2602937255532023e-05,
                                2.3715429898905068e-05,
                                0.0002732699427137671,
                                0.0002732699427137671,
                                0.0002867200000000003,
                                0.0008372008021034628,
                                0.0008372008021034628,
                                0.0008784069392898217,
                                0.0007882616157639664,
                                0.0007882616157639664,
                                0.0008270590180076121,
                                1.117109964892614e-07,
                                1.117109964892614e-07,
                                1.1720929347487811e-07,
                                2.686541917246454e-05,
                                2.686541917246454e-05,
                                2.8187706663360667e-05,
                                0.0003248034304233582,
                                0.0003248034304233582,
                                0.0003407899114193127,
                                0.0009950808704974063,
                                0.0009950808704974063,
                                0.0010440576975121638,
                                0.0009369126890745194,
                                0.0009369126890745194,
                                0.0009830265397787307,
                                9.39868694469396e-08,
                                9.39868694469396e-08,
                                9.861280366298015e-08,
                                2.2602937255532023e-05,
                                2.2602937255532023e-05,
                                2.3715429898905068e-05,
                                0.0002732699427137671,
                                0.0002732699427137671,
                                0.0002867200000000003,
                                0.0008372008021034628,
                                0.0008372008021034628,
                                0.0008784069392898217,
                                0.0007882616157639664,
                                0.0007882616157639664,
                                0.0008270590180076121,
                                4.6524618324709464e-08,
                                4.6524618324709464e-08,
                                4.881451078588994e-08,
                                1.118872279733353e-05,
                                1.118872279733353e-05,
                                1.1739419888603266e-05,
                                0.00013527187211561308,
                                0.00013527187211561308,
                                0.00014192981045710394,
                                0.0004144243553190559,
                                0.0004144243553190559,
                                0.0004348218833621967,
                                0.0003901988759625772,
                                0.0003901988759625772,
                                0.00040940405155782223,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.106957413803658e-08,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                9.876837188172655e-06,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                0.00011941115006831959,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                0.00036583280848420083,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                0.00034444778360304097,
                                3.891980994681466e-09,
                                3.891980994681466e-09,
                                8.296684296930566e-08,
                                9.359839596761115e-07,
                                9.359839596761115e-07,
                                1.9952726981543877e-05,
                                1.1316063932314603e-05,
                                1.1316063932314603e-05,
                                0.00024122884993168082,
                                3.466834920337752e-05,
                                3.466834920337752e-05,
                                0.0007390384198412779,
                                3.2641785447724135e-05,
                                3.2641785447724135e-05,
                                0.0006958373874846588,
                                4.625934216040542e-09,
                                4.625934216040542e-09,
                                9.861280366298018e-08,
                                1.1124926433730444e-06,
                                1.1124926433730444e-06,
                                2.371542989890507e-05,
                                1.345005728623315e-05,
                                1.345005728623315e-05,
                                0.00028672000000000034,
                                4.120613718635886e-05,
                                4.120613718635886e-05,
                                0.0008784069392898218,
                                3.879740224364574e-05,
                                3.879740224364574e-05,
                                0.0008270590180076123,
                                3.891980994681466e-09,
                                3.891980994681466e-09,
                                8.296684296930566e-08,
                                9.359839596761115e-07,
                                9.359839596761115e-07,
                                1.9952726981543877e-05,
                                1.1316063932314603e-05,
                                1.1316063932314603e-05,
                                0.00024122884993168082,
                                3.466834920337752e-05,
                                3.466834920337752e-05,
                                0.0007390384198412779,
                                3.2641785447724135e-05,
                                3.2641785447724135e-05,
                                0.0006958373874846588,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.106957413803658e-08,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                9.876837188172655e-06,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                0.00011941115006831959,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                0.00036583280848420083,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                0.00034444778360304097,
                                1.9145872136988545e-08,
                                1.9145872136988545e-08,
                                8.296684296930565e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                1.9952726981543877e-05,
                                5.566725876569064e-05,
                                5.566725876569064e-05,
                                0.0002412288499316808,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0007390384198412779,
                                0.0001605751547500268,
                                0.0001605751547500268,
                                0.0006958373874846587,
                                3.867760015628625e-08,
                                3.867760015628625e-08,
                                1.6760575625054447e-07,
                                9.301590473982536e-06,
                                9.301590473982536e-06,
                                4.030757077546653e-05,
                                0.00011245640631728155,
                                0.00011245640631728155,
                                0.00048731929979794954,
                                0.0003445259754349043,
                                0.0003445259754349043,
                                0.0014929710330370237,
                                0.00032438645709206127,
                                0.00032438645709206127,
                                0.0014056983173376424,
                                4.597145623316258e-08,
                                4.597145623316258e-08,
                                1.9921299813752063e-07,
                                1.1055692639813157e-05,
                                1.1055692639813157e-05,
                                4.7908808154641816e-05,
                                0.00013366353497279776,
                                0.00013366353497279776,
                                0.0005792184047539919,
                                0.0004094969888745578,
                                0.0004094969888745578,
                                0.001774516832102004,
                                0.00038555954233408254,
                                0.00038555954233408254,
                                0.0016707861504177304,
                                3.867760015628625e-08,
                                3.867760015628625e-08,
                                1.6760575625054447e-07,
                                9.301590473982536e-06,
                                9.301590473982536e-06,
                                4.030757077546653e-05,
                                0.00011245640631728155,
                                0.00011245640631728155,
                                0.00048731929979794954,
                                0.0003445259754349043,
                                0.0003445259754349043,
                                0.0014929710330370237,
                                0.00032438645709206127,
                                0.00032438645709206127,
                                0.0014056983173376424,
                                1.9145872136988545e-08,
                                1.9145872136988545e-08,
                                8.296684296930565e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                1.9952726981543877e-05,
                                5.566725876569064e-05,
                                5.566725876569064e-05,
                                0.0002412288499316808,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0007390384198412779,
                                0.0001605751547500268,
                                0.0001605751547500268,
                                0.0006958373874846587,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                9.861280366298015e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                2.3715429898905068e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.0002867200000000003,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.0008784069392898217,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                0.0008270590180076121,
                                9.960649906876032e-08,
                                9.960649906876032e-08,
                                1.9921299813752063e-07,
                                2.3954404077320908e-05,
                                2.3954404077320908e-05,
                                4.7908808154641816e-05,
                                0.00028960920237699594,
                                0.00028960920237699594,
                                0.0005792184047539919,
                                0.000887258416051002,
                                0.000887258416051002,
                                0.001774516832102004,
                                0.0008353930752088652,
                                0.0008353930752088652,
                                0.0016707861504177304,
                                1.1839038083995065e-07,
                                1.1839038083995065e-07,
                                2.367807616799013e-07,
                                2.8471746803894416e-05,
                                2.8471746803894416e-05,
                                5.694349360778883e-05,
                                0.00034422396213823296,
                                0.00034422396213823296,
                                0.0006884479242764659,
                                0.0010545783935967507,
                                0.0010545783935967507,
                                0.0021091567871935014,
                                0.0009929322408647324,
                                0.0009929322408647324,
                                0.001985864481729465,
                                9.960649906876032e-08,
                                9.960649906876032e-08,
                                1.9921299813752063e-07,
                                2.3954404077320908e-05,
                                2.3954404077320908e-05,
                                4.7908808154641816e-05,
                                0.00028960920237699594,
                                0.00028960920237699594,
                                0.0005792184047539919,
                                0.000887258416051002,
                                0.000887258416051002,
                                0.001774516832102004,
                                0.0008353930752088652,
                                0.0008353930752088652,
                                0.0016707861504177304,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                9.861280366298015e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                2.3715429898905068e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.0002867200000000003,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.0008784069392898217,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                0.0008270590180076121,
                                6.38209708323171e-08,
                                6.38209708323171e-08,
                                8.296684296930565e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                1.9952726981543877e-05,
                                0.00018556159116599015,
                                0.00018556159116599015,
                                0.0002412288499316808,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0007390384198412779,
                                0.0005352622327346318,
                                0.0005352622327346318,
                                0.0006958373874846587,
                                1.289281560942582e-07,
                                1.289281560942582e-07,
                                1.6760575625054447e-07,
                                3.100598030148399e-05,
                                3.100598030148399e-05,
                                4.030757077546653e-05,
                                0.000374862893480668,
                                0.000374862893480668,
                                0.00048731929979794954,
                                0.0011484450576021194,
                                0.0011484450576021194,
                                0.0014929710330370237,
                                0.001081311860245581,
                                0.001081311860245581,
                                0.0014056983173376424,
                                1.5324154190435804e-07,
                                1.5324154190435804e-07,
                                1.9921299813752063e-07,
                                3.6853115514828654e-05,
                                3.6853115514828654e-05,
                                4.7908808154641816e-05,
                                0.0004455548697811941,
                                0.0004455548697811941,
                                0.0005792184047539919,
                                0.001365019843227446,
                                0.001365019843227446,
                                0.001774516832102004,
                                0.0012852266080836479,
                                0.0012852266080836479,
                                0.0016707861504177304,
                                1.289281560942582e-07,
                                1.289281560942582e-07,
                                1.6760575625054447e-07,
                                3.100598030148399e-05,
                                3.100598030148399e-05,
                                4.030757077546653e-05,
                                0.000374862893480668,
                                0.000374862893480668,
                                0.00048731929979794954,
                                0.0011484450576021194,
                                0.0011484450576021194,
                                0.0014929710330370237,
                                0.001081311860245581,
                                0.001081311860245581,
                                0.0014056983173376424,
                                6.38209708323171e-08,
                                6.38209708323171e-08,
                                8.296684296930565e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                1.9952726981543877e-05,
                                0.00018556159116599015,
                                0.00018556159116599015,
                                0.0002412288499316808,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0007390384198412779,
                                0.0005352622327346318,
                                0.0005352622327346318,
                                0.0006958373874846587,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                4.106957413803658e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                9.876837188172655e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.00011941115006831959,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00036583280848420083,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                0.00034444778360304097,
                                7.907486197462419e-08,
                                7.907486197462419e-08,
                                8.296684296930566e-08,
                                1.9016743021867766e-05,
                                1.9016743021867766e-05,
                                1.9952726981543877e-05,
                                0.0002299127859993662,
                                0.0002299127859993662,
                                0.00024122884993168082,
                                0.0007043700706379003,
                                0.0007043700706379003,
                                0.0007390384198412779,
                                0.0006631956020369346,
                                0.0006631956020369346,
                                0.0006958373874846588,
                                9.398686944693963e-08,
                                9.398686944693963e-08,
                                9.861280366298018e-08,
                                2.2602937255532027e-05,
                                2.2602937255532027e-05,
                                2.371542989890507e-05,
                                0.00027326994271376716,
                                0.00027326994271376716,
                                0.00028672000000000034,
                                0.0008372008021034628,
                                0.0008372008021034628,
                                0.0008784069392898218,
                                0.0007882616157639666,
                                0.0007882616157639666,
                                0.0008270590180076123,
                                7.907486197462419e-08,
                                7.907486197462419e-08,
                                8.296684296930566e-08,
                                1.9016743021867766e-05,
                                1.9016743021867766e-05,
                                1.9952726981543877e-05,
                                0.0002299127859993662,
                                0.0002299127859993662,
                                0.00024122884993168082,
                                0.0007043700706379003,
                                0.0007043700706379003,
                                0.0007390384198412779,
                                0.0006631956020369346,
                                0.0006631956020369346,
                                0.0006958373874846588,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                4.106957413803658e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                9.876837188172655e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.00011941115006831959,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00036583280848420083,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                0.00034444778360304097,
                                9.53678474896536e-10,
                                9.53678474896536e-10,
                                2.0329927709840623e-08,
                                2.293504917961684e-07,
                                2.293504917961684e-07,
                                4.889151890461143e-06,
                                2.772851822130939e-06,
                                2.772851822130939e-06,
                                5.910993964725648e-05,
                                8.49502051542355e-06,
                                8.49502051542355e-06,
                                0.0001810915916823123,
                                7.998437866532609e-06,
                                7.998437866532609e-06,
                                0.0001705057499970323,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.106957413803658e-08,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                9.876837188172655e-06,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                0.00011941115006831959,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                0.00036583280848420083,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                0.00034444778360304097,
                                2.2898924611804724e-09,
                                2.2898924611804724e-09,
                                4.8814510785889953e-08,
                                5.506970912697355e-07,
                                5.506970912697355e-07,
                                1.173941988860327e-05,
                                6.6579383414908584e-06,
                                6.6579383414908584e-06,
                                0.00014192981045710396,
                                2.03975280431408e-05,
                                2.03975280431408e-05,
                                0.00043482188336219687,
                                1.9205175595245023e-05,
                                1.9205175595245023e-05,
                                0.0004094040515578223,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.106957413803658e-08,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                9.876837188172655e-06,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                0.00011941115006831959,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                0.00036583280848420083,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                0.00034444778360304097,
                                9.53678474896536e-10,
                                9.53678474896536e-10,
                                2.0329927709840623e-08,
                                2.293504917961684e-07,
                                2.293504917961684e-07,
                                4.889151890461143e-06,
                                2.772851822130939e-06,
                                2.772851822130939e-06,
                                5.910993964725648e-05,
                                8.49502051542355e-06,
                                8.49502051542355e-06,
                                0.0001810915916823123,
                                7.998437866532609e-06,
                                7.998437866532609e-06,
                                0.0001705057499970323,
                                9.477434442796908e-09,
                                9.477434442796908e-09,
                                4.106957413803658e-08,
                                2.2792317407155854e-06,
                                2.2792317407155854e-06,
                                9.876837188172655e-06,
                                2.7555955236052672e-05,
                                2.7555955236052672e-05,
                                0.00011941115006831959,
                                8.442153424284435e-05,
                                8.442153424284435e-05,
                                0.00036583280848420083,
                                7.948661159943993e-05,
                                7.948661159943993e-05,
                                0.00034444778360304097,
                                1.9145872136988548e-08,
                                1.9145872136988548e-08,
                                8.296684296930566e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                1.9952726981543877e-05,
                                5.5667258765690645e-05,
                                5.5667258765690645e-05,
                                0.00024122884993168082,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0007390384198412779,
                                0.00016057515475002683,
                                0.00016057515475002683,
                                0.0006958373874846588,
                                2.275641765349403e-08,
                                2.275641765349403e-08,
                                9.861280366298018e-08,
                                5.472699361190984e-06,
                                5.472699361190984e-06,
                                2.371542989890507e-05,
                                6.616503970324934e-05,
                                6.616503970324934e-05,
                                0.00028672000000000034,
                                0.00020270588034919338,
                                0.00020270588034919338,
                                0.0008784069392898218,
                                0.00019085655958218478,
                                0.00019085655958218478,
                                0.0008270590180076123,
                                1.9145872136988548e-08,
                                1.9145872136988548e-08,
                                8.296684296930566e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                1.9952726981543877e-05,
                                5.5667258765690645e-05,
                                5.5667258765690645e-05,
                                0.00024122884993168082,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0007390384198412779,
                                0.00016057515475002683,
                                0.00016057515475002683,
                                0.0006958373874846588,
                                9.477434442796908e-09,
                                9.477434442796908e-09,
                                4.106957413803658e-08,
                                2.2792317407155854e-06,
                                2.2792317407155854e-06,
                                9.876837188172655e-06,
                                2.7555955236052672e-05,
                                2.7555955236052672e-05,
                                0.00011941115006831959,
                                8.442153424284435e-05,
                                8.442153424284435e-05,
                                0.00036583280848420083,
                                7.948661159943993e-05,
                                7.948661159943993e-05,
                                0.00034444778360304097,
                                2.440725539294497e-08,
                                2.440725539294497e-08,
                                4.881451078588994e-08,
                                5.869709944301633e-06,
                                5.869709944301633e-06,
                                1.1739419888603266e-05,
                                7.096490522855197e-05,
                                7.096490522855197e-05,
                                0.00014192981045710394,
                                0.00021741094168109835,
                                0.00021741094168109835,
                                0.0004348218833621967,
                                0.00020470202577891112,
                                0.00020470202577891112,
                                0.00040940405155782223,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                9.861280366298015e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                2.3715429898905068e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.0002867200000000003,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.0008784069392898217,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                0.0008270590180076121,
                                5.8604646737439054e-08,
                                5.8604646737439054e-08,
                                1.1720929347487811e-07,
                                1.4093853331680334e-05,
                                1.4093853331680334e-05,
                                2.8187706663360667e-05,
                                0.00017039495570965636,
                                0.00017039495570965636,
                                0.0003407899114193127,
                                0.0005220288487560819,
                                0.0005220288487560819,
                                0.0010440576975121638,
                                0.0004915132698893654,
                                0.0004915132698893654,
                                0.0009830265397787307,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                9.861280366298015e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                2.3715429898905068e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.0002867200000000003,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.0008784069392898217,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                0.0008270590180076121,
                                2.440725539294497e-08,
                                2.440725539294497e-08,
                                4.881451078588994e-08,
                                5.869709944301633e-06,
                                5.869709944301633e-06,
                                1.1739419888603266e-05,
                                7.096490522855197e-05,
                                7.096490522855197e-05,
                                0.00014192981045710394,
                                0.00021741094168109835,
                                0.00021741094168109835,
                                0.0004348218833621967,
                                0.00020470202577891112,
                                0.00020470202577891112,
                                0.00040940405155782223,
                                3.159213969523967e-08,
                                3.159213969523967e-08,
                                4.106957413803658e-08,
                                7.597605447457069e-06,
                                7.597605447457069e-06,
                                9.876837188172655e-06,
                                9.18551948322669e-05,
                                9.18551948322669e-05,
                                0.00011941115006831959,
                                0.0002814112742413565,
                                0.0002814112742413565,
                                0.00036583280848420083,
                                0.000264961172003601,
                                0.000264961172003601,
                                0.00034444778360304097,
                                6.382097083231711e-08,
                                6.382097083231711e-08,
                                8.296684296930566e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                1.9952726981543877e-05,
                                0.00018556159116599018,
                                0.00018556159116599018,
                                0.00024122884993168082,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0007390384198412779,
                                0.0005352622327346319,
                                0.0005352622327346319,
                                0.0006958373874846588,
                                7.585638600948615e-08,
                                7.585638600948615e-08,
                                9.861280366298018e-08,
                                1.8242730537714085e-05,
                                1.8242730537714085e-05,
                                2.371542989890507e-05,
                                0.00022055496029675098,
                                0.00022055496029675098,
                                0.00028672000000000034,
                                0.0006757010589406283,
                                0.0006757010589406283,
                                0.0008784069392898218,
                                0.0006362024584254275,
                                0.0006362024584254275,
                                0.0008270590180076123,
                                6.382097083231711e-08,
                                6.382097083231711e-08,
                                8.296684296930566e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                1.9952726981543877e-05,
                                0.00018556159116599018,
                                0.00018556159116599018,
                                0.00024122884993168082,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0007390384198412779,
                                0.0005352622327346319,
                                0.0005352622327346319,
                                0.0006958373874846588,
                                3.159213969523967e-08,
                                3.159213969523967e-08,
                                4.106957413803658e-08,
                                7.597605447457069e-06,
                                7.597605447457069e-06,
                                9.876837188172655e-06,
                                9.18551948322669e-05,
                                9.18551948322669e-05,
                                0.00011941115006831959,
                                0.0002814112742413565,
                                0.0002814112742413565,
                                0.00036583280848420083,
                                0.000264961172003601,
                                0.000264961172003601,
                                0.00034444778360304097,
                                1.9376249234944087e-08,
                                1.9376249234944087e-08,
                                2.0329927709840623e-08,
                                4.659801398664974e-06,
                                4.659801398664974e-06,
                                4.889151890461143e-06,
                                5.6337087825125535e-05,
                                5.6337087825125535e-05,
                                5.910993964725648e-05,
                                0.00017259657116688875,
                                0.00017259657116688875,
                                0.0001810915916823123,
                                0.0001625073121304997,
                                0.0001625073121304997,
                                0.0001705057499970323,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                4.106957413803658e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                9.876837188172655e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.00011941115006831959,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00036583280848420083,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                0.00034444778360304097,
                                4.652461832470948e-08,
                                4.652461832470948e-08,
                                4.8814510785889953e-08,
                                1.1188722797333533e-05,
                                1.1188722797333533e-05,
                                1.173941988860327e-05,
                                0.0001352718721156131,
                                0.0001352718721156131,
                                0.00014192981045710396,
                                0.00041442435531905607,
                                0.00041442435531905607,
                                0.00043482188336219687,
                                0.00039019887596257723,
                                0.00039019887596257723,
                                0.0004094040515578223,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                4.106957413803658e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                9.876837188172655e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.00011941115006831959,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00036583280848420083,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                0.00034444778360304097,
                                1.9376249234944087e-08,
                                1.9376249234944087e-08,
                                2.0329927709840623e-08,
                                4.659801398664974e-06,
                                4.659801398664974e-06,
                                4.889151890461143e-06,
                                5.6337087825125535e-05,
                                5.6337087825125535e-05,
                                5.910993964725648e-05,
                                0.00017259657116688875,
                                0.00017259657116688875,
                                0.0001810915916823123,
                                0.0001625073121304997,
                                0.0001625073121304997,
                                0.0001705057499970323,
                            ]
                        ),
                    )
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.EdgeAdjacentTriangles:
            match order:
                case 1:
                    return (
                        np.array(
                            [
                                [0.5, 0.375, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.625, 0.25, 0.125],
                                [0.5625, 0.375, 0.0625],
                                [0.5625, 0.25, 0.1875],
                            ]
                        ),
                        np.array(
                            [
                                [0.625, 0.125, 0.25],
                                [0.5625, 0.0625, 0.375],
                                [0.5, 0.0625, 0.4375],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.125, 0.375],
                            ]
                        ),
                        np.array([0.03125, 0.015625, 0.015625, 0.015625, 0.015625]),
                    )
                case 2:
                    return (
                        np.array(
                            [
                                [0.7886751345948129, 0.2018874775675312, 0.009437387837655933],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.7981125224324688, 0.16666666666666669, 0.03522081090086453],
                                [0.7906694893093821, 0.2018874775675312, 0.007443033123086744],
                                [0.790669489309382, 0.16666666666666669, 0.042663844023951264],
                                [0.21132486540518713, 0.7534543236939484, 0.03522081090086453],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.24654567630605173, 0.6220084679281461, 0.13144585576580217],
                                [0.21876789852827383, 0.7534543236939484, 0.027777777777777783],
                                [0.21876789852827383, 0.6220084679281462, 0.15922363354357993],
                                [0.7886751345948129, 0.17610405450432262, 0.03522081090086452],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.7981125224324688, 0.16666666666666669, 0.03522081090086453],
                                [0.7961181677178996, 0.20188747756753123, 0.0019943547145691905],
                                [0.7961181677178997, 0.16666666666666669, 0.03721516561543372],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580217],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.24654567630605173, 0.6220084679281461, 0.13144585576580217],
                                [0.23910264318296492, 0.7534543236939484, 0.007443033123086746],
                                [0.23910264318296504, 0.6220084679281461, 0.1388888888888889],
                                [0.7886751345948129, 0.2018874775675312, 0.009437387837655933],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.8238959454956775, 0.16666666666666666, 0.009437387837655933],
                                [0.7961181677178996, 0.17610405450432262, 0.02777777777777778],
                                [0.7961181677178997, 0.16666666666666669, 0.03721516561543371],
                                [0.21132486540518713, 0.7534543236939484, 0.03522081090086453],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.3427707211709894, 0.6220084679281461, 0.03522081090086452],
                                [0.23910264318296492, 0.6572292788290107, 0.10366807798802437],
                                [0.23910264318296504, 0.6220084679281461, 0.1388888888888889],
                                [0.7886751345948129, 0.17610405450432262, 0.03522081090086452],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.8238959454956775, 0.16666666666666666, 0.009437387837655933],
                                [0.8164529123725908, 0.1761040545043226, 0.007443033123086741],
                                [0.8164529123725905, 0.16666666666666669, 0.016880420960742673],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580217],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.3427707211709894, 0.6220084679281461, 0.03522081090086452],
                                [0.3149929433932115, 0.6572292788290107, 0.027777777777777773],
                                [0.3149929433932115, 0.6220084679281462, 0.06299858867864229],
                                [0.7886751345948129, 0.1761040545043226, 0.03522081090086453],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.8238959454956774, 0.04465819873852045, 0.13144585576580214],
                                [0.7961181677178996, 0.17610405450432262, 0.02777777777777778],
                                [0.7961181677178996, 0.04465819873852048, 0.15922363354357993],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580217],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.3427707211709894, 0.16666666666666663, 0.490562612162344],
                                [0.23910264318296492, 0.6572292788290107, 0.10366807798802437],
                                [0.23910264318296492, 0.16666666666666663, 0.5942306901503684],
                                [0.7886751345948129, 0.07987900963938496, 0.13144585576580217],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.8238959454956774, 0.04465819873852045, 0.13144585576580214],
                                [0.8164529123725908, 0.1761040545043226, 0.007443033123086741],
                                [0.8164529123725908, 0.04465819873852045, 0.1388888888888889],
                                [0.21132486540518713, 0.2981125224324688, 0.4905626121623441],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.3427707211709894, 0.16666666666666663, 0.490562612162344],
                                [0.3149929433932115, 0.6572292788290107, 0.027777777777777773],
                                [0.3149929433932115, 0.16666666666666674, 0.5183403899401218],
                                [0.7886751345948129, 0.1761040545043226, 0.03522081090086453],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.920120990360615, 0.04465819873852046, 0.03522081090086451],
                                [0.8164529123725907, 0.07987900963938496, 0.10366807798802438],
                                [0.8164529123725908, 0.04465819873852045, 0.1388888888888889],
                                [0.21132486540518713, 0.6572292788290107, 0.13144585576580217],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.7018874775675312, 0.16666666666666666, 0.13144585576580212],
                                [0.31499294339321143, 0.29811252243246883, 0.3868945341743197],
                                [0.3149929433932115, 0.16666666666666674, 0.5183403899401218],
                                [0.7886751345948129, 0.07987900963938496, 0.13144585576580217],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.920120990360615, 0.04465819873852046, 0.03522081090086451],
                                [0.8923432125828372, 0.07987900963938498, 0.02777777777777778],
                                [0.8923432125828372, 0.04465819873852046, 0.06299858867864229],
                                [0.21132486540518713, 0.2981125224324688, 0.4905626121623441],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.7018874775675312, 0.16666666666666666, 0.13144585576580212],
                                [0.5982193995795069, 0.29811252243246883, 0.10366807798802437],
                                [0.5982193995795068, 0.1666666666666667, 0.23511393375382647],
                            ]
                        ),
                        np.array(
                            [
                                [0.7981125224324688, 0.03522081090086453, 0.16666666666666669],
                                [0.7906694893093821, 0.007443033123086744, 0.2018874775675312],
                                [0.7886751345948129, 0.00199435471456919, 0.20933051069061795],
                                [0.7886751345948128, 0.044658198738520456, 0.16666666666666669],
                                [0.7886751345948129, 0.009437387837655933, 0.2018874775675312],
                                [0.2465456763060517, 0.13144585576580217, 0.6220084679281461],
                                [0.21876789852827383, 0.027777777777777783, 0.7534543236939484],
                                [0.21132486540518708, 0.007443033123086743, 0.7812321014717262],
                                [0.2113248654051872, 0.16666666666666669, 0.6220084679281461],
                                [0.2113248654051871, 0.03522081090086452, 0.7534543236939484],
                                [0.7981125224324688, 0.03522081090086453, 0.16666666666666669],
                                [0.7961181677178996, 0.0019943547145691905, 0.20188747756753123],
                                [0.788675134594813, 0.007443033123086742, 0.20388183228210038],
                                [0.7886751345948128, 0.044658198738520456, 0.16666666666666669],
                                [0.7886751345948129, 0.009437387837655933, 0.2018874775675312],
                                [0.2465456763060517, 0.13144585576580217, 0.6220084679281461],
                                [0.23910264318296487, 0.007443033123086746, 0.7534543236939484],
                                [0.21132486540518713, 0.027777777777777776, 0.7608973568170351],
                                [0.2113248654051872, 0.16666666666666669, 0.6220084679281461],
                                [0.2113248654051871, 0.03522081090086452, 0.7534543236939484],
                                [0.8238959454956775, 0.009437387837655933, 0.16666666666666666],
                                [0.7961181677178996, 0.02777777777777778, 0.17610405450432262],
                                [0.788675134594813, 0.007443033123086744, 0.20388183228210038],
                                [0.7886751345948128, 0.044658198738520456, 0.16666666666666669],
                                [0.7886751345948129, 0.03522081090086453, 0.1761040545043226],
                                [0.34277072117098933, 0.03522081090086452, 0.6220084679281461],
                                [0.23910264318296492, 0.10366807798802437, 0.6572292788290107],
                                [0.21132486540518713, 0.027777777777777783, 0.7608973568170351],
                                [0.2113248654051872, 0.16666666666666669, 0.6220084679281461],
                                [0.2113248654051871, 0.13144585576580217, 0.6572292788290107],
                                [0.8238959454956775, 0.009437387837655933, 0.16666666666666666],
                                [0.8164529123725907, 0.007443033123086741, 0.1761040545043226],
                                [0.7886751345948129, 0.027777777777777787, 0.18354708762740934],
                                [0.7886751345948128, 0.044658198738520456, 0.16666666666666669],
                                [0.7886751345948129, 0.03522081090086453, 0.1761040545043226],
                                [0.34277072117098933, 0.03522081090086452, 0.6220084679281461],
                                [0.3149929433932115, 0.027777777777777773, 0.6572292788290107],
                                [0.2113248654051871, 0.10366807798802438, 0.6850070566067885],
                                [0.2113248654051872, 0.16666666666666669, 0.6220084679281461],
                                [0.2113248654051871, 0.13144585576580217, 0.6572292788290107],
                                [0.8238959454956775, 0.13144585576580214, 0.04465819873852045],
                                [0.7961181677178996, 0.02777777777777778, 0.17610405450432262],
                                [0.788675134594813, 0.007443033123086744, 0.20388183228210038],
                                [0.7886751345948129, 0.16666666666666669, 0.04465819873852045],
                                [0.7886751345948129, 0.03522081090086453, 0.1761040545043226],
                                [0.3427707211709894, 0.490562612162344, 0.16666666666666663],
                                [0.23910264318296492, 0.10366807798802437, 0.6572292788290107],
                                [0.21132486540518713, 0.027777777777777783, 0.7608973568170351],
                                [0.21132486540518713, 0.6220084679281462, 0.16666666666666663],
                                [0.2113248654051871, 0.13144585576580217, 0.6572292788290107],
                                [0.8238959454956775, 0.13144585576580214, 0.04465819873852045],
                                [0.8164529123725907, 0.007443033123086741, 0.1761040545043226],
                                [0.7886751345948129, 0.027777777777777787, 0.18354708762740934],
                                [0.7886751345948129, 0.16666666666666669, 0.04465819873852045],
                                [0.7886751345948129, 0.03522081090086453, 0.1761040545043226],
                                [0.3427707211709894, 0.490562612162344, 0.16666666666666663],
                                [0.3149929433932115, 0.027777777777777773, 0.6572292788290107],
                                [0.2113248654051871, 0.10366807798802438, 0.6850070566067885],
                                [0.21132486540518713, 0.6220084679281462, 0.16666666666666663],
                                [0.2113248654051871, 0.13144585576580217, 0.6572292788290107],
                                [0.920120990360615, 0.03522081090086451, 0.04465819873852046],
                                [0.8164529123725907, 0.10366807798802438, 0.07987900963938496],
                                [0.7886751345948129, 0.027777777777777787, 0.18354708762740934],
                                [0.7886751345948129, 0.16666666666666669, 0.04465819873852045],
                                [0.7886751345948129, 0.13144585576580217, 0.07987900963938496],
                                [0.7018874775675312, 0.13144585576580212, 0.16666666666666666],
                                [0.31499294339321154, 0.3868945341743197, 0.29811252243246883],
                                [0.2113248654051871, 0.10366807798802438, 0.6850070566067885],
                                [0.21132486540518713, 0.6220084679281462, 0.16666666666666663],
                                [0.21132486540518713, 0.4905626121623441, 0.2981125224324688],
                                [0.920120990360615, 0.03522081090086451, 0.04465819873852046],
                                [0.8923432125828372, 0.02777777777777778, 0.07987900963938498],
                                [0.7886751345948129, 0.10366807798802438, 0.10765678741716275],
                                [0.7886751345948129, 0.16666666666666669, 0.04465819873852045],
                                [0.7886751345948129, 0.13144585576580217, 0.07987900963938496],
                                [0.7018874775675312, 0.13144585576580212, 0.16666666666666666],
                                [0.5982193995795069, 0.10366807798802437, 0.29811252243246883],
                                [0.2113248654051872, 0.3868945341743197, 0.4017806004204932],
                                [0.21132486540518713, 0.6220084679281462, 0.16666666666666663],
                                [0.21132486540518713, 0.4905626121623441, 0.2981125224324688],
                            ]
                        ),
                        np.array(
                            [
                                2.6341046351658406e-05,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                0.001369227664227106,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                2.6341046351658406e-05,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                5.5665180748960085e-06,
                                0.001369227664227106,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                0.00028935185185185194,
                                2.6341046351658406e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                0.001369227664227106,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                2.6341046351658406e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                2.0774528276762397e-05,
                                0.001369227664227106,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.001079875812375254,
                                0.00036688344688400547,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                0.019070881175870563,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.00036688344688400547,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                7.753159503215358e-05,
                                0.019070881175870563,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.004030151397649164,
                                0.00036688344688400547,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.019070881175870563,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.00036688344688400547,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.0002893518518518519,
                                0.019070881175870563,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                                0.0150407297782214,
                            ]
                        ),
                    )
                case 3:
                    return (
                        np.array(
                            [
                                [0.8872983346207417, 0.11127016653792582, 0.0014314988413324798],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.8887298334620742, 0.09999999999999999, 0.011270166537925829],
                                [0.8874596669241485, 0.1112701665379258, 0.0012701665379258307],
                                [0.8874596669241483, 0.09999999999999998, 0.012540333075851659],
                                [0.5, 0.49364916731037084, 0.006350832689629154],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.5007157494206662, 0.49364916731037084, 0.005635083268962914],
                                [0.5007157494206662, 0.44364916731037085, 0.05563508326896291],
                                [0.1127016653792583, 0.8760281680828159, 0.011270166537925829],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.12397183191718408, 0.7872983346207417, 0.08872983346207416],
                                [0.11397183191718419, 0.8760281680828158, 0.009999999999999998],
                                [0.11397183191718419, 0.7872983346207416, 0.09872983346207416],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.8887298334620742, 0.09999999999999999, 0.011270166537925829],
                                [0.8880140840414079, 0.11127016653792582, 0.0007157494206662399],
                                [0.8880140840414079, 0.09999999999999999, 0.011985915958592068],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.5031754163448146, 0.4936491673103709, 0.003175416344814577],
                                [0.5031754163448146, 0.44364916731037085, 0.05317541634481457],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.12397183191718408, 0.7872983346207417, 0.08872983346207416],
                                [0.11833674864822119, 0.8760281680828159, 0.005635083268962914],
                                [0.11833674864822119, 0.7872983346207417, 0.09436491673103707],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.8887298334620742, 0.09999999999999999, 0.011270166537925829],
                                [0.8885685011586675, 0.11127016653792582, 0.00016133230340664904],
                                [0.8885685011586676, 0.09999999999999999, 0.011431498841332478],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.5056350832689629, 0.4936491673103709, 0.0007157494206662396],
                                [0.5056350832689629, 0.44364916731037085, 0.050715749420666235],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.12397183191718408, 0.7872983346207417, 0.08872983346207416],
                                [0.1227016653792583, 0.8760281680828159, 0.00127016653792583],
                                [0.1227016653792583, 0.7872983346207417, 0.09],
                                [0.8872983346207417, 0.11127016653792582, 0.0014314988413324798],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.8936491673103709, 0.09999999999999998, 0.006350832689629154],
                                [0.8880140840414079, 0.10635083268962914, 0.005635083268962914],
                                [0.8880140840414079, 0.09999999999999999, 0.011985915958592068],
                                [0.5, 0.49364916731037084, 0.006350832689629154],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5281754163448146, 0.44364916731037085, 0.028175416344814574],
                                [0.5031754163448146, 0.4718245836551854, 0.024999999999999998],
                                [0.5031754163448146, 0.44364916731037085, 0.05317541634481457],
                                [0.1127016653792583, 0.8760281680828159, 0.011270166537925829],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.16270166537925834, 0.7872983346207416, 0.049999999999999996],
                                [0.11833674864822119, 0.8372983346207418, 0.04436491673103708],
                                [0.11833674864822119, 0.7872983346207417, 0.09436491673103707],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.8936491673103709, 0.09999999999999998, 0.006350832689629154],
                                [0.8904737509655563, 0.10635083268962914, 0.003175416344814577],
                                [0.8904737509655563, 0.09999999999999999, 0.009526249034443731],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5281754163448146, 0.44364916731037085, 0.028175416344814574],
                                [0.5140877081724072, 0.4718245836551854, 0.014087708172407287],
                                [0.5140877081724073, 0.44364916731037085, 0.04226312451722186],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.16270166537925834, 0.7872983346207416, 0.049999999999999996],
                                [0.13770166537925832, 0.8372983346207417, 0.024999999999999998],
                                [0.13770166537925832, 0.7872983346207417, 0.075],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.8936491673103709, 0.09999999999999998, 0.006350832689629154],
                                [0.8929334178897046, 0.10635083268962914, 0.0007157494206662398],
                                [0.8929334178897046, 0.09999999999999998, 0.007066582110295394],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5281754163448146, 0.44364916731037085, 0.028175416344814574],
                                [0.525, 0.4718245836551854, 0.0031754163448145765],
                                [0.525, 0.44364916731037085, 0.031350832689629154],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.16270166537925834, 0.7872983346207416, 0.049999999999999996],
                                [0.15706658211029545, 0.8372983346207417, 0.0056350832689629135],
                                [0.15706658211029545, 0.7872983346207416, 0.055635083268962916],
                                [0.8872983346207417, 0.11127016653792582, 0.0014314988413324798],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.8985685011586675, 0.09999999999999999, 0.0014314988413324796],
                                [0.8885685011586675, 0.10143149884133247, 0.009999999999999998],
                                [0.8885685011586676, 0.09999999999999999, 0.011431498841332478],
                                [0.5, 0.49364916731037084, 0.006350832689629154],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.55, 0.44364916731037085, 0.006350832689629153],
                                [0.5056350832689629, 0.45, 0.04436491673103708],
                                [0.5056350832689629, 0.44364916731037085, 0.050715749420666235],
                                [0.1127016653792583, 0.8760281680828159, 0.011270166537925829],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.2014314988413325, 0.7872983346207417, 0.011270166537925827],
                                [0.1227016653792583, 0.7985685011586675, 0.07872983346207417],
                                [0.1227016653792583, 0.7872983346207417, 0.09],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.8985685011586675, 0.09999999999999999, 0.0014314988413324796],
                                [0.8929334178897046, 0.10143149884133246, 0.005635083268962914],
                                [0.8929334178897046, 0.09999999999999998, 0.007066582110295394],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.55, 0.44364916731037085, 0.006350832689629153],
                                [0.525, 0.44999999999999996, 0.024999999999999998],
                                [0.525, 0.44364916731037085, 0.031350832689629154],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.2014314988413325, 0.7872983346207417, 0.011270166537925827],
                                [0.15706658211029545, 0.7985685011586675, 0.04436491673103708],
                                [0.15706658211029545, 0.7872983346207416, 0.055635083268962916],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.8985685011586675, 0.09999999999999999, 0.0014314988413324796],
                                [0.8972983346207417, 0.10143149884133247, 0.0012701665379258305],
                                [0.8972983346207417, 0.09999999999999999, 0.00270166537925831],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.55, 0.44364916731037085, 0.006350832689629153],
                                [0.5443649167310372, 0.45, 0.0056350832689629135],
                                [0.544364916731037, 0.44364916731037085, 0.011985915958592067],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.2014314988413325, 0.7872983346207417, 0.011270166537925827],
                                [0.19143149884133248, 0.7985685011586675, 0.009999999999999997],
                                [0.19143149884133248, 0.7872983346207417, 0.021270166537925822],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8936491673103708, 0.05635083268962914, 0.049999999999999996],
                                [0.8880140840414079, 0.10635083268962914, 0.005635083268962914],
                                [0.8880140840414079, 0.05635083268962915, 0.05563508326896291],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.5, 0.25, 0.25],
                                [0.5281754163448146, 0.25, 0.22182458365518543],
                                [0.5031754163448146, 0.4718245836551854, 0.024999999999999998],
                                [0.5031754163448146, 0.25, 0.24682458365518542],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.1627016653792584, 0.4436491673103708, 0.39364916731037086],
                                [0.11833674864822119, 0.8372983346207418, 0.04436491673103708],
                                [0.11833674864822119, 0.44364916731037085, 0.43801408404140796],
                                [0.8872983346207417, 0.08452624903444372, 0.028175416344814574],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8936491673103708, 0.05635083268962914, 0.049999999999999996],
                                [0.8904737509655563, 0.10635083268962914, 0.003175416344814577],
                                [0.8904737509655563, 0.05635083268962915, 0.05317541634481457],
                                [0.5, 0.375, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.5281754163448146, 0.25, 0.22182458365518543],
                                [0.5140877081724072, 0.4718245836551854, 0.014087708172407287],
                                [0.5140877081724073, 0.25, 0.2359122918275927],
                                [0.1127016653792583, 0.6654737509655563, 0.22182458365518543],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.1627016653792584, 0.4436491673103708, 0.39364916731037086],
                                [0.13770166537925832, 0.8372983346207417, 0.024999999999999998],
                                [0.13770166537925832, 0.44364916731037085, 0.41864916731037083],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8936491673103708, 0.05635083268962914, 0.049999999999999996],
                                [0.8929334178897046, 0.10635083268962914, 0.0007157494206662398],
                                [0.8929334178897046, 0.05635083268962914, 0.050715749420666235],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.5, 0.25, 0.25],
                                [0.5281754163448146, 0.25, 0.22182458365518543],
                                [0.525, 0.4718245836551854, 0.0031754163448145765],
                                [0.525, 0.24999999999999997, 0.225],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.1627016653792584, 0.4436491673103708, 0.39364916731037086],
                                [0.15706658211029545, 0.8372983346207417, 0.0056350832689629135],
                                [0.1570665821102955, 0.4436491673103708, 0.39928425057933375],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9154737509655563, 0.05635083268962915, 0.028175416344814574],
                                [0.8904737509655563, 0.08452624903444372, 0.024999999999999998],
                                [0.8904737509655563, 0.05635083268962915, 0.05317541634481457],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.5, 0.25, 0.25],
                                [0.625, 0.25, 0.125],
                                [0.5140877081724073, 0.375, 0.11091229182759271],
                                [0.5140877081724073, 0.25, 0.2359122918275927],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.3345262490344437, 0.44364916731037085, 0.22182458365518543],
                                [0.13770166537925832, 0.6654737509655563, 0.19682458365518543],
                                [0.13770166537925832, 0.44364916731037085, 0.41864916731037083],
                                [0.8872983346207417, 0.08452624903444372, 0.028175416344814574],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9154737509655563, 0.05635083268962915, 0.028175416344814574],
                                [0.9013860427931489, 0.08452624903444372, 0.014087708172407287],
                                [0.901386042793149, 0.05635083268962915, 0.04226312451722186],
                                [0.5, 0.375, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.625, 0.25, 0.125],
                                [0.5625, 0.375, 0.0625],
                                [0.5625, 0.25, 0.1875],
                                [0.1127016653792583, 0.6654737509655563, 0.22182458365518543],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.3345262490344437, 0.44364916731037085, 0.22182458365518543],
                                [0.22361395720685096, 0.6654737509655564, 0.11091229182759271],
                                [0.2236139572068509, 0.4436491673103709, 0.33273687548277814],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9154737509655563, 0.05635083268962915, 0.028175416344814574],
                                [0.9122983346207417, 0.08452624903444372, 0.003175416344814577],
                                [0.9122983346207417, 0.05635083268962915, 0.031350832689629154],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.5, 0.25, 0.25],
                                [0.625, 0.25, 0.125],
                                [0.6109122918275927, 0.375, 0.014087708172407287],
                                [0.6109122918275927, 0.25, 0.1390877081724073],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.3345262490344437, 0.44364916731037085, 0.22182458365518543],
                                [0.3095262490344437, 0.6654737509655563, 0.024999999999999998],
                                [0.3095262490344437, 0.44364916731037085, 0.24682458365518542],
                                [0.8872983346207417, 0.10635083268962914, 0.006350832689629154],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9372983346207417, 0.056350832689629156, 0.006350832689629154],
                                [0.8929334178897047, 0.0627016653792583, 0.04436491673103708],
                                [0.8929334178897046, 0.05635083268962914, 0.050715749420666235],
                                [0.5, 0.4718245836551854, 0.028175416344814574],
                                [0.5, 0.25, 0.25],
                                [0.7218245836551854, 0.25, 0.028175416344814574],
                                [0.525, 0.2781754163448146, 0.19682458365518543],
                                [0.525, 0.24999999999999997, 0.225],
                                [0.1127016653792583, 0.8372983346207417, 0.049999999999999996],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.15706658211029545, 0.4936491673103708, 0.34928425057933377],
                                [0.1570665821102955, 0.4436491673103708, 0.39928425057933375],
                                [0.8872983346207417, 0.08452624903444372, 0.028175416344814574],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9372983346207417, 0.056350832689629156, 0.006350832689629154],
                                [0.9122983346207416, 0.06270166537925831, 0.024999999999999998],
                                [0.9122983346207417, 0.05635083268962915, 0.031350832689629154],
                                [0.5, 0.375, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.7218245836551854, 0.25, 0.028175416344814574],
                                [0.6109122918275928, 0.2781754163448146, 0.11091229182759271],
                                [0.6109122918275927, 0.25, 0.1390877081724073],
                                [0.1127016653792583, 0.6654737509655563, 0.22182458365518543],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.3095262490344437, 0.4936491673103709, 0.19682458365518543],
                                [0.3095262490344437, 0.44364916731037085, 0.24682458365518542],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9372983346207417, 0.056350832689629156, 0.006350832689629154],
                                [0.9316632513517789, 0.06270166537925831, 0.0056350832689629135],
                                [0.9316632513517787, 0.05635083268962916, 0.011985915958592068],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.5, 0.25, 0.25],
                                [0.7218245836551854, 0.25, 0.028175416344814574],
                                [0.6968245836551854, 0.2781754163448146, 0.024999999999999994],
                                [0.6968245836551854, 0.25, 0.05317541634481457],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.5063508326896291, 0.44364916731037085, 0.049999999999999996],
                                [0.4619859159585921, 0.49364916731037084, 0.044364916731037075],
                                [0.46198591595859206, 0.44364916731037085, 0.09436491673103707],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.8985685011586675, 0.012701665379258306, 0.08872983346207416],
                                [0.8885685011586675, 0.10143149884133247, 0.009999999999999998],
                                [0.8885685011586675, 0.012701665379258306, 0.09872983346207416],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.55, 0.05635083268962915, 0.39364916731037086],
                                [0.5056350832689629, 0.45, 0.04436491673103708],
                                [0.5056350832689629, 0.05635083268962915, 0.43801408404140796],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.2014314988413325, 0.09999999999999998, 0.6985685011586675],
                                [0.1227016653792583, 0.7985685011586675, 0.07872983346207417],
                                [0.1227016653792583, 0.09999999999999998, 0.7772983346207417],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.8985685011586675, 0.012701665379258306, 0.08872983346207416],
                                [0.8929334178897046, 0.10143149884133246, 0.005635083268962914],
                                [0.8929334178897046, 0.012701665379258306, 0.09436491673103707],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.55, 0.05635083268962915, 0.39364916731037086],
                                [0.525, 0.44999999999999996, 0.024999999999999998],
                                [0.525, 0.05635083268962915, 0.41864916731037083],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.2014314988413325, 0.09999999999999998, 0.6985685011586675],
                                [0.15706658211029545, 0.7985685011586675, 0.04436491673103708],
                                [0.15706658211029545, 0.09999999999999998, 0.7429334178897046],
                                [0.8872983346207417, 0.023971831917184133, 0.08872983346207416],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.8985685011586675, 0.012701665379258306, 0.08872983346207416],
                                [0.8972983346207417, 0.10143149884133247, 0.0012701665379258305],
                                [0.8972983346207417, 0.01270166537925832, 0.08999999999999998],
                                [0.5, 0.10635083268962914, 0.39364916731037086],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.55, 0.05635083268962915, 0.39364916731037086],
                                [0.5443649167310372, 0.45, 0.0056350832689629135],
                                [0.5443649167310372, 0.05635083268962915, 0.39928425057933375],
                                [0.1127016653792583, 0.18872983346207417, 0.6985685011586675],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.2014314988413325, 0.09999999999999998, 0.6985685011586675],
                                [0.19143149884133248, 0.7985685011586675, 0.009999999999999997],
                                [0.19143149884133248, 0.09999999999999998, 0.7085685011586675],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9372983346207416, 0.012701665379258313, 0.049999999999999996],
                                [0.8929334178897047, 0.0627016653792583, 0.04436491673103708],
                                [0.8929334178897046, 0.012701665379258306, 0.09436491673103707],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.7218245836551854, 0.05635083268962915, 0.22182458365518543],
                                [0.525, 0.2781754163448146, 0.19682458365518543],
                                [0.525, 0.05635083268962915, 0.41864916731037083],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.5063508326896292, 0.09999999999999998, 0.39364916731037086],
                                [0.15706658211029545, 0.4936491673103708, 0.34928425057933377],
                                [0.15706658211029545, 0.09999999999999998, 0.7429334178897046],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9372983346207416, 0.012701665379258313, 0.049999999999999996],
                                [0.9122983346207416, 0.06270166537925831, 0.024999999999999998],
                                [0.9122983346207417, 0.012701665379258306, 0.075],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.7218245836551854, 0.05635083268962915, 0.22182458365518543],
                                [0.6109122918275928, 0.2781754163448146, 0.11091229182759271],
                                [0.6109122918275927, 0.05635083268962915, 0.33273687548277814],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.5063508326896292, 0.09999999999999998, 0.39364916731037086],
                                [0.3095262490344437, 0.4936491673103709, 0.19682458365518543],
                                [0.3095262490344437, 0.09999999999999998, 0.5904737509655563],
                                [0.8872983346207417, 0.023971831917184133, 0.08872983346207416],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9372983346207416, 0.012701665379258313, 0.049999999999999996],
                                [0.9316632513517789, 0.06270166537925831, 0.0056350832689629135],
                                [0.9316632513517787, 0.01270166537925832, 0.05563508326896291],
                                [0.5, 0.10635083268962914, 0.39364916731037086],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.7218245836551854, 0.05635083268962915, 0.22182458365518543],
                                [0.6968245836551854, 0.2781754163448146, 0.024999999999999994],
                                [0.6968245836551854, 0.05635083268962918, 0.24682458365518542],
                                [0.1127016653792583, 0.18872983346207417, 0.6985685011586675],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.5063508326896292, 0.09999999999999998, 0.39364916731037086],
                                [0.4619859159585921, 0.49364916731037084, 0.044364916731037075],
                                [0.46198591595859206, 0.09999999999999998, 0.43801408404140796],
                                [0.8872983346207417, 0.10143149884133247, 0.011270166537925829],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9760281680828159, 0.01270166537925831, 0.011270166537925827],
                                [0.8972983346207417, 0.023971831917184147, 0.07872983346207416],
                                [0.8972983346207417, 0.01270166537925832, 0.08999999999999998],
                                [0.49999999999999994, 0.45, 0.049999999999999996],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.8936491673103708, 0.05635083268962915, 0.04999999999999999],
                                [0.5443649167310372, 0.10635083268962914, 0.34928425057933377],
                                [0.5443649167310372, 0.05635083268962915, 0.39928425057933375],
                                [0.1127016653792583, 0.7985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.8112701665379258, 0.09999999999999999, 0.08872983346207415],
                                [0.19143149884133248, 0.18872983346207417, 0.6198386676965933],
                                [0.19143149884133248, 0.09999999999999998, 0.7085685011586675],
                                [0.8872983346207417, 0.06270166537925831, 0.049999999999999996],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9760281680828159, 0.01270166537925831, 0.011270166537925827],
                                [0.9316632513517789, 0.023971831917184147, 0.04436491673103708],
                                [0.9316632513517787, 0.01270166537925832, 0.05563508326896291],
                                [0.5, 0.2781754163448146, 0.22182458365518543],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.8936491673103708, 0.05635083268962915, 0.04999999999999999],
                                [0.6968245836551854, 0.10635083268962917, 0.19682458365518543],
                                [0.6968245836551854, 0.05635083268962918, 0.24682458365518542],
                                [0.11270166537925835, 0.49364916731037084, 0.39364916731037086],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.8112701665379258, 0.09999999999999999, 0.08872983346207415],
                                [0.46198591595859206, 0.18872983346207417, 0.34928425057933377],
                                [0.46198591595859206, 0.09999999999999998, 0.43801408404140796],
                                [0.8872983346207417, 0.023971831917184133, 0.08872983346207416],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9760281680828159, 0.01270166537925831, 0.011270166537925827],
                                [0.9660281680828159, 0.023971831917184133, 0.010000000000000002],
                                [0.9660281680828159, 0.012701665379258306, 0.02127016653792583],
                                [0.5, 0.10635083268962914, 0.39364916731037086],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.8936491673103708, 0.05635083268962915, 0.04999999999999999],
                                [0.8492842505793337, 0.10635083268962914, 0.044364916731037096],
                                [0.8492842505793338, 0.05635083268962915, 0.09436491673103709],
                                [0.1127016653792583, 0.18872983346207417, 0.6985685011586675],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.8112701665379258, 0.09999999999999999, 0.08872983346207415],
                                [0.7325403330758516, 0.18872983346207417, 0.0787298334620742],
                                [0.7325403330758516, 0.1, 0.16745966692414835],
                            ]
                        ),
                        np.array(
                            [
                                [0.8887298334620742, 0.011270166537925829, 0.09999999999999999],
                                [0.8874596669241485, 0.0012701665379258307, 0.1112701665379258],
                                [0.8872983346207417, 0.00016133230340664912, 0.11254033307585165],
                                [0.8872983346207417, 0.012701665379258308, 0.09999999999999999],
                                [0.8872983346207416, 0.0014314988413324798, 0.11127016653792582],
                                [0.5063508326896291, 0.049999999999999996, 0.44364916731037085],
                                [0.5007157494206662, 0.005635083268962914, 0.49364916731037084],
                                [0.49999999999999994, 0.0007157494206662399, 0.49928425057933373],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.49999999999999994, 0.006350832689629154, 0.49364916731037084],
                                [0.12397183191718411, 0.08872983346207416, 0.7872983346207417],
                                [0.1139718319171842, 0.009999999999999998, 0.8760281680828158],
                                [0.11270166537925824, 0.0012701665379258307, 0.8860281680828159],
                                [0.11270166537925828, 0.09999999999999999, 0.7872983346207417],
                                [0.11270166537925826, 0.011270166537925829, 0.8760281680828159],
                                [0.8887298334620742, 0.011270166537925829, 0.09999999999999999],
                                [0.8880140840414079, 0.0007157494206662399, 0.11127016653792582],
                                [0.8872983346207417, 0.0007157494206662399, 0.11198591595859206],
                                [0.8872983346207417, 0.012701665379258308, 0.09999999999999999],
                                [0.8872983346207416, 0.0014314988413324798, 0.11127016653792582],
                                [0.5063508326896291, 0.049999999999999996, 0.44364916731037085],
                                [0.5031754163448146, 0.003175416344814577, 0.4936491673103709],
                                [0.5, 0.003175416344814577, 0.49682458365518545],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.49999999999999994, 0.006350832689629154, 0.49364916731037084],
                                [0.12397183191718411, 0.08872983346207416, 0.7872983346207417],
                                [0.11833674864822116, 0.005635083268962914, 0.8760281680828159],
                                [0.11270166537925827, 0.005635083268962914, 0.8816632513517788],
                                [0.11270166537925828, 0.09999999999999999, 0.7872983346207417],
                                [0.11270166537925826, 0.011270166537925829, 0.8760281680828159],
                                [0.8887298334620742, 0.011270166537925829, 0.09999999999999999],
                                [0.8885685011586675, 0.00016133230340664904, 0.11127016653792582],
                                [0.8872983346207417, 0.0012701665379258307, 0.11143149884133247],
                                [0.8872983346207417, 0.012701665379258308, 0.09999999999999999],
                                [0.8872983346207416, 0.0014314988413324798, 0.11127016653792582],
                                [0.5063508326896291, 0.049999999999999996, 0.44364916731037085],
                                [0.5056350832689629, 0.0007157494206662396, 0.4936491673103709],
                                [0.5, 0.005635083268962914, 0.4943649167310371],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.49999999999999994, 0.006350832689629154, 0.49364916731037084],
                                [0.12397183191718411, 0.08872983346207416, 0.7872983346207417],
                                [0.12270166537925825, 0.00127016653792583, 0.8760281680828159],
                                [0.11270166537925831, 0.009999999999999998, 0.8772983346207417],
                                [0.11270166537925828, 0.09999999999999999, 0.7872983346207417],
                                [0.11270166537925826, 0.011270166537925829, 0.8760281680828159],
                                [0.8936491673103709, 0.006350832689629154, 0.09999999999999998],
                                [0.8880140840414079, 0.005635083268962914, 0.10635083268962914],
                                [0.8872983346207417, 0.0007157494206662399, 0.11198591595859206],
                                [0.8872983346207417, 0.012701665379258308, 0.09999999999999999],
                                [0.8872983346207417, 0.006350832689629154, 0.10635083268962914],
                                [0.5281754163448146, 0.028175416344814574, 0.44364916731037085],
                                [0.5031754163448146, 0.024999999999999998, 0.4718245836551854],
                                [0.5, 0.003175416344814577, 0.49682458365518545],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.1627016653792584, 0.049999999999999996, 0.7872983346207416],
                                [0.11833674864822115, 0.04436491673103708, 0.8372983346207418],
                                [0.11270166537925827, 0.005635083268962914, 0.8816632513517788],
                                [0.11270166537925828, 0.09999999999999999, 0.7872983346207417],
                                [0.11270166537925835, 0.049999999999999996, 0.8372983346207417],
                                [0.8936491673103709, 0.006350832689629154, 0.09999999999999998],
                                [0.8904737509655563, 0.003175416344814577, 0.10635083268962914],
                                [0.8872983346207417, 0.003175416344814577, 0.10952624903444372],
                                [0.8872983346207417, 0.012701665379258308, 0.09999999999999999],
                                [0.8872983346207417, 0.006350832689629154, 0.10635083268962914],
                                [0.5281754163448146, 0.028175416344814574, 0.44364916731037085],
                                [0.5140877081724073, 0.014087708172407287, 0.4718245836551854],
                                [0.5, 0.014087708172407287, 0.4859122918275927],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.1627016653792584, 0.049999999999999996, 0.7872983346207416],
                                [0.13770166537925835, 0.024999999999999998, 0.8372983346207417],
                                [0.11270166537925833, 0.024999999999999998, 0.8622983346207417],
                                [0.11270166537925828, 0.09999999999999999, 0.7872983346207417],
                                [0.11270166537925835, 0.049999999999999996, 0.8372983346207417],
                                [0.8936491673103709, 0.006350832689629154, 0.09999999999999998],
                                [0.8929334178897046, 0.0007157494206662398, 0.10635083268962914],
                                [0.8872983346207417, 0.005635083268962914, 0.10706658211029538],
                                [0.8872983346207417, 0.012701665379258308, 0.09999999999999999],
                                [0.8872983346207417, 0.006350832689629154, 0.10635083268962914],
                                [0.5281754163448146, 0.028175416344814574, 0.44364916731037085],
                                [0.525, 0.0031754163448145765, 0.4718245836551854],
                                [0.5, 0.024999999999999998, 0.475],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.1627016653792584, 0.049999999999999996, 0.7872983346207416],
                                [0.15706658211029542, 0.0056350832689629135, 0.8372983346207417],
                                [0.11270166537925826, 0.04436491673103708, 0.8429334178897047],
                                [0.11270166537925828, 0.09999999999999999, 0.7872983346207417],
                                [0.11270166537925835, 0.049999999999999996, 0.8372983346207417],
                                [0.8985685011586675, 0.0014314988413324796, 0.09999999999999999],
                                [0.8885685011586675, 0.009999999999999998, 0.10143149884133247],
                                [0.8872983346207417, 0.0012701665379258307, 0.11143149884133247],
                                [0.8872983346207417, 0.012701665379258308, 0.09999999999999999],
                                [0.8872983346207417, 0.011270166537925829, 0.10143149884133247],
                                [0.55, 0.006350832689629153, 0.44364916731037085],
                                [0.505635083268963, 0.04436491673103708, 0.45],
                                [0.5, 0.005635083268962914, 0.4943649167310371],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5, 0.049999999999999996, 0.45],
                                [0.20143149884133243, 0.011270166537925827, 0.7872983346207417],
                                [0.12270166537925832, 0.07872983346207417, 0.7985685011586675],
                                [0.11270166537925831, 0.009999999999999998, 0.8772983346207417],
                                [0.11270166537925828, 0.09999999999999999, 0.7872983346207417],
                                [0.11270166537925833, 0.08872983346207416, 0.7985685011586675],
                                [0.8985685011586675, 0.0014314988413324796, 0.09999999999999999],
                                [0.8929334178897046, 0.005635083268962914, 0.10143149884133246],
                                [0.8872983346207417, 0.005635083268962914, 0.10706658211029538],
                                [0.8872983346207417, 0.012701665379258308, 0.09999999999999999],
                                [0.8872983346207417, 0.011270166537925829, 0.10143149884133247],
                                [0.55, 0.006350832689629153, 0.44364916731037085],
                                [0.525, 0.024999999999999998, 0.44999999999999996],
                                [0.5, 0.024999999999999998, 0.475],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5, 0.049999999999999996, 0.45],
                                [0.20143149884133243, 0.011270166537925827, 0.7872983346207417],
                                [0.1570665821102954, 0.04436491673103708, 0.7985685011586675],
                                [0.11270166537925826, 0.04436491673103708, 0.8429334178897047],
                                [0.11270166537925828, 0.09999999999999999, 0.7872983346207417],
                                [0.11270166537925833, 0.08872983346207416, 0.7985685011586675],
                                [0.8985685011586675, 0.0014314988413324796, 0.09999999999999999],
                                [0.8972983346207417, 0.0012701665379258305, 0.10143149884133247],
                                [0.8872983346207417, 0.009999999999999998, 0.1027016653792583],
                                [0.8872983346207417, 0.012701665379258308, 0.09999999999999999],
                                [0.8872983346207417, 0.011270166537925829, 0.10143149884133247],
                                [0.55, 0.006350832689629153, 0.44364916731037085],
                                [0.5443649167310372, 0.0056350832689629135, 0.45],
                                [0.5000000000000001, 0.04436491673103708, 0.4556350832689629],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5, 0.049999999999999996, 0.45],
                                [0.20143149884133243, 0.011270166537925827, 0.7872983346207417],
                                [0.19143149884133248, 0.009999999999999997, 0.7985685011586675],
                                [0.11270166537925831, 0.07872983346207417, 0.8085685011586675],
                                [0.11270166537925828, 0.09999999999999999, 0.7872983346207417],
                                [0.11270166537925833, 0.08872983346207416, 0.7985685011586675],
                                [0.8936491673103708, 0.049999999999999996, 0.05635083268962914],
                                [0.8880140840414079, 0.005635083268962914, 0.10635083268962914],
                                [0.8872983346207417, 0.0007157494206662399, 0.11198591595859206],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8872983346207417, 0.006350832689629154, 0.10635083268962914],
                                [0.5281754163448146, 0.22182458365518543, 0.25],
                                [0.5031754163448146, 0.024999999999999998, 0.4718245836551854],
                                [0.5, 0.003175416344814577, 0.49682458365518545],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.1627016653792583, 0.39364916731037086, 0.4436491673103708],
                                [0.11833674864822115, 0.04436491673103708, 0.8372983346207418],
                                [0.11270166537925827, 0.005635083268962914, 0.8816632513517788],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.11270166537925835, 0.049999999999999996, 0.8372983346207417],
                                [0.8936491673103708, 0.049999999999999996, 0.05635083268962914],
                                [0.8904737509655563, 0.003175416344814577, 0.10635083268962914],
                                [0.8872983346207417, 0.003175416344814577, 0.10952624903444372],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8872983346207417, 0.006350832689629154, 0.10635083268962914],
                                [0.5281754163448146, 0.22182458365518543, 0.25],
                                [0.5140877081724073, 0.014087708172407287, 0.4718245836551854],
                                [0.5, 0.014087708172407287, 0.4859122918275927],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.1627016653792583, 0.39364916731037086, 0.4436491673103708],
                                [0.13770166537925835, 0.024999999999999998, 0.8372983346207417],
                                [0.11270166537925833, 0.024999999999999998, 0.8622983346207417],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.11270166537925835, 0.049999999999999996, 0.8372983346207417],
                                [0.8936491673103708, 0.049999999999999996, 0.05635083268962914],
                                [0.8929334178897046, 0.0007157494206662398, 0.10635083268962914],
                                [0.8872983346207417, 0.005635083268962914, 0.10706658211029538],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8872983346207417, 0.006350832689629154, 0.10635083268962914],
                                [0.5281754163448146, 0.22182458365518543, 0.25],
                                [0.525, 0.0031754163448145765, 0.4718245836551854],
                                [0.5, 0.024999999999999998, 0.475],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.028175416344814574, 0.4718245836551854],
                                [0.1627016653792583, 0.39364916731037086, 0.4436491673103708],
                                [0.15706658211029542, 0.0056350832689629135, 0.8372983346207417],
                                [0.11270166537925826, 0.04436491673103708, 0.8429334178897047],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.11270166537925835, 0.049999999999999996, 0.8372983346207417],
                                [0.9154737509655563, 0.028175416344814574, 0.05635083268962915],
                                [0.8904737509655563, 0.024999999999999998, 0.08452624903444372],
                                [0.8872983346207417, 0.003175416344814577, 0.10952624903444372],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8872983346207417, 0.028175416344814574, 0.08452624903444372],
                                [0.625, 0.125, 0.25],
                                [0.5140877081724073, 0.11091229182759271, 0.375],
                                [0.5, 0.014087708172407287, 0.4859122918275927],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.3345262490344437, 0.22182458365518543, 0.44364916731037085],
                                [0.1377016653792583, 0.19682458365518543, 0.6654737509655563],
                                [0.11270166537925833, 0.024999999999999998, 0.8622983346207417],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.1127016653792583, 0.22182458365518543, 0.6654737509655563],
                                [0.9154737509655563, 0.028175416344814574, 0.05635083268962915],
                                [0.901386042793149, 0.014087708172407287, 0.08452624903444372],
                                [0.8872983346207417, 0.014087708172407287, 0.09861395720685101],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8872983346207417, 0.028175416344814574, 0.08452624903444372],
                                [0.625, 0.125, 0.25],
                                [0.5625, 0.0625, 0.375],
                                [0.5, 0.0625, 0.4375],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.3345262490344437, 0.22182458365518543, 0.44364916731037085],
                                [0.2236139572068509, 0.11091229182759271, 0.6654737509655564],
                                [0.11270166537925824, 0.11091229182759271, 0.776386042793149],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.1127016653792583, 0.22182458365518543, 0.6654737509655563],
                                [0.9154737509655563, 0.028175416344814574, 0.05635083268962915],
                                [0.9122983346207417, 0.003175416344814577, 0.08452624903444372],
                                [0.8872983346207417, 0.024999999999999998, 0.0877016653792583],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8872983346207417, 0.028175416344814574, 0.08452624903444372],
                                [0.625, 0.125, 0.25],
                                [0.6109122918275927, 0.014087708172407287, 0.375],
                                [0.49999999999999994, 0.11091229182759271, 0.3890877081724073],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.3345262490344437, 0.22182458365518543, 0.44364916731037085],
                                [0.3095262490344437, 0.024999999999999998, 0.6654737509655563],
                                [0.11270166537925827, 0.19682458365518543, 0.6904737509655563],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.1127016653792583, 0.22182458365518543, 0.6654737509655563],
                                [0.9372983346207417, 0.006350832689629154, 0.056350832689629156],
                                [0.8929334178897047, 0.04436491673103708, 0.0627016653792583],
                                [0.8872983346207417, 0.005635083268962914, 0.10706658211029538],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8872983346207417, 0.049999999999999996, 0.06270166537925831],
                                [0.7218245836551854, 0.028175416344814574, 0.25],
                                [0.525, 0.19682458365518543, 0.2781754163448146],
                                [0.5, 0.024999999999999998, 0.475],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.5063508326896291, 0.049999999999999996, 0.44364916731037085],
                                [0.15706658211029545, 0.34928425057933377, 0.4936491673103708],
                                [0.11270166537925826, 0.04436491673103708, 0.8429334178897047],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.9372983346207417, 0.006350832689629154, 0.056350832689629156],
                                [0.9122983346207417, 0.024999999999999998, 0.06270166537925831],
                                [0.8872983346207417, 0.024999999999999998, 0.0877016653792583],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8872983346207417, 0.049999999999999996, 0.06270166537925831],
                                [0.7218245836551854, 0.028175416344814574, 0.25],
                                [0.6109122918275927, 0.11091229182759271, 0.2781754163448146],
                                [0.49999999999999994, 0.11091229182759271, 0.3890877081724073],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.5063508326896291, 0.049999999999999996, 0.44364916731037085],
                                [0.3095262490344437, 0.19682458365518543, 0.4936491673103709],
                                [0.11270166537925827, 0.19682458365518543, 0.6904737509655563],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.9372983346207417, 0.006350832689629154, 0.056350832689629156],
                                [0.9316632513517789, 0.0056350832689629135, 0.06270166537925831],
                                [0.8872983346207417, 0.04436491673103708, 0.06833674864822122],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8872983346207417, 0.049999999999999996, 0.06270166537925831],
                                [0.7218245836551854, 0.028175416344814574, 0.25],
                                [0.6968245836551854, 0.024999999999999994, 0.2781754163448146],
                                [0.5, 0.19682458365518543, 0.3031754163448146],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.5063508326896291, 0.049999999999999996, 0.44364916731037085],
                                [0.461985915958592, 0.044364916731037075, 0.49364916731037084],
                                [0.1127016653792583, 0.34928425057933377, 0.5380140840414079],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.8985685011586675, 0.08872983346207416, 0.012701665379258306],
                                [0.8885685011586675, 0.009999999999999998, 0.10143149884133247],
                                [0.8872983346207417, 0.0012701665379258307, 0.11143149884133247],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258306],
                                [0.8872983346207417, 0.011270166537925829, 0.10143149884133247],
                                [0.55, 0.39364916731037086, 0.05635083268962915],
                                [0.505635083268963, 0.04436491673103708, 0.45],
                                [0.5, 0.005635083268962914, 0.4943649167310371],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5, 0.049999999999999996, 0.45],
                                [0.2014314988413325, 0.6985685011586675, 0.09999999999999998],
                                [0.12270166537925832, 0.07872983346207417, 0.7985685011586675],
                                [0.11270166537925831, 0.009999999999999998, 0.8772983346207417],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999998],
                                [0.11270166537925833, 0.08872983346207416, 0.7985685011586675],
                                [0.8985685011586675, 0.08872983346207416, 0.012701665379258306],
                                [0.8929334178897046, 0.005635083268962914, 0.10143149884133246],
                                [0.8872983346207417, 0.005635083268962914, 0.10706658211029538],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258306],
                                [0.8872983346207417, 0.011270166537925829, 0.10143149884133247],
                                [0.55, 0.39364916731037086, 0.05635083268962915],
                                [0.525, 0.024999999999999998, 0.44999999999999996],
                                [0.5, 0.024999999999999998, 0.475],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5, 0.049999999999999996, 0.45],
                                [0.2014314988413325, 0.6985685011586675, 0.09999999999999998],
                                [0.1570665821102954, 0.04436491673103708, 0.7985685011586675],
                                [0.11270166537925826, 0.04436491673103708, 0.8429334178897047],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999998],
                                [0.11270166537925833, 0.08872983346207416, 0.7985685011586675],
                                [0.8985685011586675, 0.08872983346207416, 0.012701665379258306],
                                [0.8972983346207417, 0.0012701665379258305, 0.10143149884133247],
                                [0.8872983346207417, 0.009999999999999998, 0.1027016653792583],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258306],
                                [0.8872983346207417, 0.011270166537925829, 0.10143149884133247],
                                [0.55, 0.39364916731037086, 0.05635083268962915],
                                [0.5443649167310372, 0.0056350832689629135, 0.45],
                                [0.5000000000000001, 0.04436491673103708, 0.4556350832689629],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5, 0.049999999999999996, 0.45],
                                [0.2014314988413325, 0.6985685011586675, 0.09999999999999998],
                                [0.19143149884133248, 0.009999999999999997, 0.7985685011586675],
                                [0.11270166537925831, 0.07872983346207417, 0.8085685011586675],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999998],
                                [0.11270166537925833, 0.08872983346207416, 0.7985685011586675],
                                [0.9372983346207416, 0.049999999999999996, 0.012701665379258313],
                                [0.8929334178897047, 0.04436491673103708, 0.0627016653792583],
                                [0.8872983346207417, 0.005635083268962914, 0.10706658211029538],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258306],
                                [0.8872983346207417, 0.049999999999999996, 0.06270166537925831],
                                [0.7218245836551854, 0.22182458365518543, 0.05635083268962915],
                                [0.525, 0.19682458365518543, 0.2781754163448146],
                                [0.5, 0.024999999999999998, 0.475],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.5063508326896291, 0.39364916731037086, 0.09999999999999998],
                                [0.15706658211029545, 0.34928425057933377, 0.4936491673103708],
                                [0.11270166537925826, 0.04436491673103708, 0.8429334178897047],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999998],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.9372983346207416, 0.049999999999999996, 0.012701665379258313],
                                [0.9122983346207417, 0.024999999999999998, 0.06270166537925831],
                                [0.8872983346207417, 0.024999999999999998, 0.0877016653792583],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258306],
                                [0.8872983346207417, 0.049999999999999996, 0.06270166537925831],
                                [0.7218245836551854, 0.22182458365518543, 0.05635083268962915],
                                [0.6109122918275927, 0.11091229182759271, 0.2781754163448146],
                                [0.49999999999999994, 0.11091229182759271, 0.3890877081724073],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.5063508326896291, 0.39364916731037086, 0.09999999999999998],
                                [0.3095262490344437, 0.19682458365518543, 0.4936491673103709],
                                [0.11270166537925827, 0.19682458365518543, 0.6904737509655563],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999998],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.9372983346207416, 0.049999999999999996, 0.012701665379258313],
                                [0.9316632513517789, 0.0056350832689629135, 0.06270166537925831],
                                [0.8872983346207417, 0.04436491673103708, 0.06833674864822122],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258306],
                                [0.8872983346207417, 0.049999999999999996, 0.06270166537925831],
                                [0.7218245836551854, 0.22182458365518543, 0.05635083268962915],
                                [0.6968245836551854, 0.024999999999999994, 0.2781754163448146],
                                [0.5, 0.19682458365518543, 0.3031754163448146],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5, 0.22182458365518543, 0.2781754163448146],
                                [0.5063508326896291, 0.39364916731037086, 0.09999999999999998],
                                [0.461985915958592, 0.044364916731037075, 0.49364916731037084],
                                [0.1127016653792583, 0.34928425057933377, 0.5380140840414079],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999998],
                                [0.11270166537925824, 0.39364916731037086, 0.49364916731037084],
                                [0.9760281680828159, 0.011270166537925827, 0.01270166537925831],
                                [0.8972983346207417, 0.07872983346207416, 0.023971831917184147],
                                [0.8872983346207417, 0.009999999999999998, 0.1027016653792583],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258306],
                                [0.8872983346207417, 0.08872983346207416, 0.023971831917184133],
                                [0.8936491673103708, 0.04999999999999999, 0.05635083268962915],
                                [0.544364916731037, 0.34928425057933377, 0.10635083268962914],
                                [0.5000000000000001, 0.04436491673103708, 0.4556350832689629],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.49999999999999994, 0.39364916731037086, 0.10635083268962914],
                                [0.8112701665379258, 0.08872983346207415, 0.09999999999999999],
                                [0.19143149884133248, 0.6198386676965933, 0.18872983346207417],
                                [0.11270166537925831, 0.07872983346207417, 0.8085685011586675],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999998],
                                [0.1127016653792583, 0.6985685011586675, 0.18872983346207417],
                                [0.9760281680828159, 0.011270166537925827, 0.01270166537925831],
                                [0.9316632513517789, 0.04436491673103708, 0.023971831917184147],
                                [0.8872983346207417, 0.04436491673103708, 0.06833674864822122],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258306],
                                [0.8872983346207417, 0.08872983346207416, 0.023971831917184133],
                                [0.8936491673103708, 0.04999999999999999, 0.05635083268962915],
                                [0.6968245836551854, 0.19682458365518543, 0.10635083268962917],
                                [0.5, 0.19682458365518543, 0.3031754163448146],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.49999999999999994, 0.39364916731037086, 0.10635083268962914],
                                [0.8112701665379258, 0.08872983346207415, 0.09999999999999999],
                                [0.46198591595859206, 0.34928425057933377, 0.18872983346207417],
                                [0.1127016653792583, 0.34928425057933377, 0.5380140840414079],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999998],
                                [0.1127016653792583, 0.6985685011586675, 0.18872983346207417],
                                [0.9760281680828159, 0.011270166537925827, 0.01270166537925831],
                                [0.9660281680828159, 0.010000000000000002, 0.023971831917184133],
                                [0.8872983346207417, 0.07872983346207416, 0.03397183191718414],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258306],
                                [0.8872983346207417, 0.08872983346207416, 0.023971831917184133],
                                [0.8936491673103708, 0.04999999999999999, 0.05635083268962915],
                                [0.8492842505793337, 0.044364916731037096, 0.10635083268962914],
                                [0.5, 0.34928425057933377, 0.15071574942066623],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.49999999999999994, 0.39364916731037086, 0.10635083268962914],
                                [0.8112701665379258, 0.08872983346207415, 0.09999999999999999],
                                [0.7325403330758516, 0.0787298334620742, 0.18872983346207417],
                                [0.1127016653792583, 0.6198386676965933, 0.26745966692414835],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999998],
                                [0.1127016653792583, 0.6985685011586675, 0.18872983346207417],
                            ]
                        ),
                        np.array(
                            [
                                1.0825342979229276e-07,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.5124487239057399e-05,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                5.282745190690863e-05,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                1.7320548766766834e-07,
                                1.9520546912972805e-08,
                                1.9520546912972805e-08,
                                1.9520546912972805e-08,
                                1.9520546912972805e-08,
                                2.4199179582491835e-05,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                8.452392305105377e-05,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                1.0825342979229276e-07,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.220034182060801e-08,
                                1.5124487239057399e-05,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                1.7045548998491092e-06,
                                5.282745190690863e-05,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                1.7320548766766834e-07,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                2.4199179582491835e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                8.452392305105377e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                2.7712878026826927e-07,
                                1.3856439013413464e-07,
                                1.3856439013413464e-07,
                                1.3856439013413464e-07,
                                1.3856439013413464e-07,
                                3.871868733198692e-05,
                                1.935934366599346e-05,
                                1.935934366599346e-05,
                                1.935934366599346e-05,
                                1.935934366599346e-05,
                                0.00013523827688168602,
                                6.761913844084301e-05,
                                6.761913844084301e-05,
                                6.761913844084301e-05,
                                6.761913844084301e-05,
                                1.7320548766766834e-07,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                8.660274383383417e-08,
                                2.4199179582491835e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                8.452392305105377e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                4.2261961525526884e-05,
                                1.0825342979229276e-07,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                1.5124487239057399e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                5.282745190690863e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                1.7320548766766834e-07,
                                1.5368494075469554e-07,
                                1.5368494075469554e-07,
                                1.5368494075469554e-07,
                                1.5368494075469554e-07,
                                2.4199179582491835e-05,
                                2.147189174273326e-05,
                                2.147189174273326e-05,
                                2.147189174273326e-05,
                                2.147189174273326e-05,
                                8.452392305105377e-05,
                                7.499793615881173e-05,
                                7.499793615881173e-05,
                                7.499793615881173e-05,
                                7.499793615881173e-05,
                                1.0825342979229276e-07,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                9.605308797168476e-08,
                                1.5124487239057399e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                1.341993233920829e-05,
                                5.282745190690863e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                4.687371009925735e-05,
                                3.4091097996982183e-06,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                0.000476299344612102,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                0.0016636385963426593,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                5.454575679517148e-06,
                                6.147397630187821e-07,
                                6.147397630187821e-07,
                                6.147397630187821e-07,
                                6.147397630187821e-07,
                                0.0007620789513793629,
                                8.588756697093301e-05,
                                8.588756697093301e-05,
                                8.588756697093301e-05,
                                8.588756697093301e-05,
                                0.0026618217541482542,
                                0.0002999917446352469,
                                0.0002999917446352469,
                                0.0002999917446352469,
                                0.0002999917446352469,
                                3.4091097996982183e-06,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                3.8421235188673886e-07,
                                0.000476299344612102,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                5.3679729356833154e-05,
                                0.0016636385963426593,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                0.00018749484039702936,
                                5.454575679517149e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                0.000762078951379363,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0026618217541482542,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                8.727321087227435e-06,
                                4.363660543613718e-06,
                                4.363660543613718e-06,
                                4.363660543613718e-06,
                                4.363660543613718e-06,
                                0.0012193263222069805,
                                0.0006096631611034902,
                                0.0006096631611034902,
                                0.0006096631611034902,
                                0.0006096631611034902,
                                0.004258914806637206,
                                0.002129457403318603,
                                0.002129457403318603,
                                0.002129457403318603,
                                0.002129457403318603,
                                5.454575679517149e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                2.7272878397585745e-06,
                                0.000762078951379363,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0003810394756896815,
                                0.0026618217541482542,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                3.4091097996982183e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                0.000476299344612102,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0016636385963426593,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                5.454575679517148e-06,
                                4.839835916498366e-06,
                                4.839835916498366e-06,
                                4.839835916498366e-06,
                                4.839835916498366e-06,
                                0.0007620789513793629,
                                0.0006761913844084299,
                                0.0006761913844084299,
                                0.0006761913844084299,
                                0.0006761913844084299,
                                0.0026618217541482542,
                                0.0023618300095130072,
                                0.0023618300095130072,
                                0.0023618300095130072,
                                0.0023618300095130072,
                                3.4091097996982183e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                3.0248974478114794e-06,
                                0.000476299344612102,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0004226196152552688,
                                0.0016636385963426593,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                0.00147614375594563,
                                6.709966169604147e-06,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                0.0009374742019851469,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.0032744497407784113,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                1.073594587136663e-05,
                                1.2099589791245916e-06,
                                1.2099589791245916e-06,
                                1.2099589791245916e-06,
                                1.2099589791245916e-06,
                                0.0014999587231762346,
                                0.00016904784610210754,
                                0.00016904784610210754,
                                0.00016904784610210754,
                                0.00016904784610210754,
                                0.005239119585245456,
                                0.0005904575023782519,
                                0.0005904575023782519,
                                0.0005904575023782519,
                                0.0005904575023782519,
                                6.709966169604147e-06,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                7.562243619528701e-07,
                                0.0009374742019851469,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.00010565490381381723,
                                0.0032744497407784113,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                0.0003690359389864076,
                                1.073594587136663e-05,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                0.0014999587231762346,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.005239119585245456,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                1.7177513394186608e-05,
                                8.588756697093304e-06,
                                8.588756697093304e-06,
                                8.588756697093304e-06,
                                8.588756697093304e-06,
                                0.0023999339570819744,
                                0.0011999669785409872,
                                0.0011999669785409872,
                                0.0011999669785409872,
                                0.0011999669785409872,
                                0.008382591336392728,
                                0.004191295668196364,
                                0.004191295668196364,
                                0.004191295668196364,
                                0.004191295668196364,
                                1.073594587136663e-05,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                5.367972935683315e-06,
                                0.0014999587231762346,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.0007499793615881173,
                                0.005239119585245456,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                0.002619559792622728,
                                6.709966169604147e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                0.0009374742019851469,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0032744497407784113,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                                1.073594587136663e-05,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                9.525986892242038e-06,
                                0.0014999587231762346,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.0013309108770741271,
                                0.005239119585245456,
                                0.004648662082867204,
                                0.004648662082867204,
                                0.004648662082867204,
                                0.004648662082867204,
                                6.709966169604147e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                5.953741807651277e-06,
                                0.0009374742019851469,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0008318192981713297,
                                0.0032744497407784113,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                                0.002905413801792004,
                            ]
                        ),
                    )
                case 4:
                    return (
                        np.array(
                            [
                                [0.9305681557970262, 0.06909712848837923, 0.0003347157145944845],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9305913957263743, 0.06909712848837923, 0.00031147578524647323],
                                [0.9305913957263743, 0.0646110632135477, 0.004797541060078003],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734612],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.6701009811507493, 0.3284185747886984, 0.0014804440605522607],
                                [0.6701009811507495, 0.30709631153115907, 0.02280270731809158],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525535],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.3302337345638452, 0.6667606442218755, 0.0030056212142792692],
                                [0.3302337345638452, 0.6234718442658671, 0.046294421170287654],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831529],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.06974331998822025, 0.9260820905221947, 0.004174589489585057],
                                [0.06974331998822025, 0.8659570925834785, 0.06429958742830123],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9306786151553474, 0.06909712848837923, 0.0002242563562732841],
                                [0.9306786151553474, 0.0646110632135477, 0.004710321631104814],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.6705155349995692, 0.3284185747886984, 0.001065890211732388],
                                [0.6705155349995693, 0.30709631153115907, 0.02238815346927171],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.3310753684193043, 0.6667606442218755, 0.002163987358820165],
                                [0.3310753684193043, 0.6234718442658671, 0.045452787314828554],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539314],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.07091228826352602, 0.9260820905221947, 0.003005621214279269],
                                [0.07091228826352602, 0.8659570925834785, 0.06313061915299543],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9307924121532996, 0.06909712848837923, 0.00011045935832120037],
                                [0.9307924121532996, 0.0646110632135477, 0.00459652463315273],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.6710564120041607, 0.32841857478869835, 0.000525013207141073],
                                [0.6710564120041604, 0.30709631153115907, 0.02184727646468039],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.33217346556639205, 0.6667606442218755, 0.001065890211732388],
                                [0.33217346556639205, 0.6234718442658672, 0.04435469016774077],
                                [0.06943184420297377, 0.8872793558410179, 0.04328879995600837],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.07243746541725304, 0.9260820905221947, 0.0014804440605522605],
                                [0.07243746541725304, 0.8659570925834785, 0.06160544199926842],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9309028715116208, 0.06461106321354769, 0.00448606527483153],
                                [0.9308796315822727, 0.06909712848837923, 2.323992934801126e-05],
                                [0.9308796315822727, 0.0646110632135477, 0.004509305204179541],
                                [0.6699905217924282, 0.30868721495003254, 0.021322263257539317],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6715814252113017, 0.30709631153115907, 0.02132226325753932],
                                [0.6714709658529804, 0.3284185747886984, 0.00011045935832120037],
                                [0.6714709658529805, 0.30709631153115907, 0.02143272261586052],
                                [0.33000947820757187, 0.6267017218364197, 0.04328879995600838],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.33323935577812447, 0.6234718442658671, 0.043288799956008386],
                                [0.33301509942185115, 0.6667606442218755, 0.0002242563562732841],
                                [0.33301509942185115, 0.6234718442658672, 0.04351305631228167],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871616],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.0739179094778053, 0.8659570925834785, 0.06012499793871617],
                                [0.07360643369255881, 0.9260820905221947, 0.0003114757852464732],
                                [0.07360643369255881, 0.8659570925834785, 0.06043647372396264],
                                [0.9305681557970262, 0.06909712848837923, 0.0003347157145944845],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9306786151553474, 0.06784094078410026, 0.0014804440605522607],
                                [0.9306786151553474, 0.0646110632135477, 0.004710321631104814],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734612],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6705155349995693, 0.32244791602860573, 0.007036548971825032],
                                [0.6705155349995693, 0.30709631153115907, 0.02238815346927171],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525535],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.3310753684193043, 0.6546389172949815, 0.014285714285714285],
                                [0.3310753684193043, 0.6234718442658671, 0.045452787314828554],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831529],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.07091228826352602, 0.909245892539487, 0.019841819196987055],
                                [0.07091228826352602, 0.8659570925834785, 0.06313061915299543],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9310931690041673, 0.06784094078410026, 0.001065890211732388],
                                [0.9310931690041674, 0.0646110632135477, 0.0042957677822849415],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6724859089815428, 0.3224479160286058, 0.005066174989851391],
                                [0.6724859089815428, 0.3070963115311591, 0.020417779487298063],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.3350756531974233, 0.6546389172949815, 0.010285429507595284],
                                [0.3350756531974233, 0.6234718442658672, 0.04145250253670954],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539314],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.07646839317479881, 0.909245892539487, 0.014285714285714285],
                                [0.07646839317479881, 0.8659570925834785, 0.05757451424172266],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9316340460087587, 0.06784094078410026, 0.000525013207141073],
                                [0.9316340460087587, 0.0646110632135477, 0.0037548907776936264],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6750566967822795, 0.32244791602860573, 0.0024953871891147143],
                                [0.6750566967822795, 0.30709631153115907, 0.01784699168656139],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.3402949077151671, 0.6546389172949815, 0.005066174989851391],
                                [0.3402949077151671, 0.6234718442658672, 0.03623324801896565],
                                [0.06943184420297377, 0.8872793558410179, 0.04328879995600837],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.083717558488688, 0.909245892539487, 0.007036548971825031],
                                [0.083717558488688, 0.8659570925834785, 0.05032534892783341],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9321590592158997, 0.0646110632135477, 0.0032298775705525535],
                                [0.9320485998575785, 0.06784094078410026, 0.0001104593583212004],
                                [0.9320485998575786, 0.0646110632135477, 0.0033403369288737537],
                                [0.6699905217924282, 0.30868721495003254, 0.021322263257539317],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6775520839713942, 0.3070963115311591, 0.015351604497446674],
                                [0.6770270707642532, 0.32244791602860573, 0.0005250132071410731],
                                [0.6770270707642532, 0.30709631153115907, 0.01587661770458775],
                                [0.33000947820757187, 0.6267017218364197, 0.04328879995600838],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.34536108270501853, 0.6234718442658672, 0.03116707302911426],
                                [0.3442951924932861, 0.6546389172949815, 0.0010658902117323882],
                                [0.3442951924932861, 0.6234718442658672, 0.03223296324084665],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871616],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.09075410746051304, 0.8659570925834785, 0.04328879995600838],
                                [0.08927366339996079, 0.909245892539487, 0.001480444060552261],
                                [0.08927366339996079, 0.8659570925834785, 0.04476924401656064],
                                [0.9305681557970262, 0.06909712848837923, 0.0003347157145944845],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9307924121532996, 0.06620196663242116, 0.0030056212142792692],
                                [0.9307924121532996, 0.0646110632135477, 0.00459652463315273],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734612],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.6710564120041607, 0.31465787371012516, 0.014285714285714285],
                                [0.6710564120041604, 0.30709631153115907, 0.02184727646468039],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525535],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.33217346556639205, 0.6388234487633139, 0.029003085670294092],
                                [0.33217346556639205, 0.6234718442658672, 0.04435469016774077],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831529],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.07243746541725304, 0.8872793558410178, 0.040283178741729105],
                                [0.07243746541725304, 0.8659570925834785, 0.06160544199926842],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9316340460087587, 0.06620196663242117, 0.0021639873588201654],
                                [0.9316340460087587, 0.0646110632135477, 0.0037548907776936264],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.6750566967822795, 0.3146578737101252, 0.010285429507595284],
                                [0.6750566967822795, 0.30709631153115907, 0.01784699168656139],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.3402949077151671, 0.6388234487633139, 0.02088164352151898],
                                [0.3402949077151671, 0.6234718442658672, 0.03623324801896565],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539314],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.083717558488688, 0.8872793558410179, 0.029003085670294096],
                                [0.083717558488688, 0.8659570925834785, 0.05032534892783341],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9327321431558464, 0.06620196663242117, 0.0010658902117323882],
                                [0.9327321431558464, 0.0646110632135477, 0.0026567936306058494],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.6802759513000234, 0.3146578737101252, 0.005066174989851391],
                                [0.6802759513000234, 0.3070963115311591, 0.012627737168817496],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.35089112172909087, 0.6388234487633139, 0.010285429507595284],
                                [0.35089112172909087, 0.6234718442658672, 0.02563703400504196],
                                [0.06943184420297377, 0.8872793558410179, 0.04328879995600837],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.09843492987326785, 0.8872793558410179, 0.014285714285714287],
                                [0.09843492987326785, 0.8659570925834785, 0.03560797754325361],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9337980333675788, 0.0646110632135477, 0.0015909034188734612],
                                [0.9335737770113055, 0.06620196663242116, 0.00022425635627328427],
                                [0.9335737770113055, 0.06461106321354769, 0.0018151597751467454],
                                [0.6699905217924282, 0.30868721495003254, 0.021322263257539317],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6853421262898748, 0.3070963115311591, 0.007561562178966105],
                                [0.6842762360781424, 0.3146578737101252, 0.001065890211732389],
                                [0.6842762360781425, 0.30709631153115907, 0.008627452390698493],
                                [0.33000947820757187, 0.6267017218364197, 0.04328879995600838],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3611765512366861, 0.6234718442658672, 0.015351604497446674],
                                [0.35901256387786595, 0.6388234487633139, 0.0021639873588201668],
                                [0.35901256387786595, 0.6234718442658672, 0.01751559185626684],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871616],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.11272064415898209, 0.8659570925834786, 0.021322263257539317],
                                [0.10971502294470292, 0.8872793558410178, 0.0030056212142792714],
                                [0.10971502294470292, 0.8659570925834785, 0.02432788447181859],
                                [0.9305681557970262, 0.06909712848837923, 0.0003347157145944845],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9308796315822727, 0.06494577892814218, 0.004174589489585056],
                                [0.9308796315822727, 0.0646110632135477, 0.004509305204179541],
                                [0.6699905217924281, 0.3284185747886984, 0.0015909034188734612],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6714709658529805, 0.30868721495003254, 0.019841819196987055],
                                [0.6714709658529805, 0.30709631153115907, 0.02143272261586052],
                                [0.33000947820757187, 0.6667606442218755, 0.0032298775705525535],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.33301509942185115, 0.6267017218364197, 0.040283178741729105],
                                [0.33301509942185115, 0.6234718442658672, 0.04351305631228167],
                                [0.06943184420297377, 0.9260820905221947, 0.004486065274831529],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.07360643369255881, 0.8704431578583101, 0.0559504084491311],
                                [0.07360643369255881, 0.8659570925834785, 0.06043647372396264],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9320485998575785, 0.06494577892814218, 0.003005621214279269],
                                [0.9320485998575786, 0.0646110632135477, 0.0033403369288737537],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6770270707642532, 0.30868721495003254, 0.014285714285714284],
                                [0.6770270707642532, 0.30709631153115907, 0.01587661770458775],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.3442951924932861, 0.6267017218364198, 0.02900308567029409],
                                [0.3442951924932861, 0.6234718442658672, 0.03223296324084665],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539314],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.08927366339996079, 0.8704431578583101, 0.040283178741729105],
                                [0.08927366339996079, 0.8659570925834785, 0.04476924401656064],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9335737770113055, 0.0649457789281422, 0.0014804440605522607],
                                [0.9335737770113055, 0.0646110632135477, 0.0018151597751467458],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6842762360781425, 0.30868721495003254, 0.007036548971825032],
                                [0.6842762360781425, 0.30709631153115907, 0.008627452390698495],
                                [0.33000947820757187, 0.6388234487633139, 0.03116707302911426],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.35901256387786595, 0.6267017218364198, 0.014285714285714285],
                                [0.35901256387786595, 0.6234718442658672, 0.017515591856266846],
                                [0.06943184420297377, 0.8872793558410179, 0.04328879995600837],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.10971502294470281, 0.8704431578583102, 0.019841819196987055],
                                [0.10971502294470281, 0.8659570925834786, 0.024327884471818596],
                                [0.9305681557970262, 0.06494577892814218, 0.00448606527483153],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9350542210718578, 0.0646110632135477, 0.00033471571459448517],
                                [0.9347427452866113, 0.06494577892814218, 0.00031147578524647323],
                                [0.9347427452866114, 0.06461106321354769, 0.0006461914998409584],
                                [0.6699905217924282, 0.30868721495003254, 0.021322263257539317],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6913127850499674, 0.30709631153115907, 0.0015909034188734642],
                                [0.6898323409894151, 0.30868721495003254, 0.0014804440605522607],
                                [0.6898323409894151, 0.30709631153115907, 0.003071347479425725],
                                [0.33000947820757187, 0.6267017218364197, 0.04328879995600838],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3732982781635803, 0.6234718442658671, 0.0032298775705525595],
                                [0.370292656949301, 0.6267017218364197, 0.0030056212142792692],
                                [0.370292656949301, 0.6234718442658671, 0.006235498784831829],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871616],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.12955684214168994, 0.8659570925834785, 0.004486065274831539],
                                [0.1253822526521049, 0.8704431578583101, 0.004174589489585057],
                                [0.1253822526521049, 0.8659570925834785, 0.008660654764416595],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9306786151553474, 0.06784094078410026, 0.0014804440605522607],
                                [0.9306786151553476, 0.046518677526560935, 0.02280270731809158],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.6705155349995693, 0.32244791602860573, 0.007036548971825032],
                                [0.6705155349995692, 0.221103222500738, 0.10838124249969278],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.3310753684193043, 0.6546389172949815, 0.014285714285714285],
                                [0.33107536841930424, 0.4488872992916901, 0.22003733228900563],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.07091228826352602, 0.909245892539487, 0.019841819196987055],
                                [0.07091228826352602, 0.6234718442658671, 0.3056158674706068],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9310931690041673, 0.06784094078410026, 0.001065890211732388],
                                [0.9310931690041674, 0.046518677526560935, 0.022388153469271706],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.6724859089815428, 0.3224479160286058, 0.005066174989851391],
                                [0.6724859089815427, 0.22110322250073805, 0.10641086851771915],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.3350756531974233, 0.6546389172949815, 0.010285429507595284],
                                [0.33507565319742333, 0.4488872992916901, 0.21603704751088665],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.07646839317479881, 0.909245892539487, 0.014285714285714285],
                                [0.07646839317479881, 0.6234718442658671, 0.3000597625593341],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9316340460087587, 0.06784094078410026, 0.000525013207141073],
                                [0.9316340460087587, 0.04651867752656094, 0.021847276464680394],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.6750566967822795, 0.32244791602860573, 0.0024953871891147143],
                                [0.6750566967822795, 0.221103222500738, 0.10384008071698247],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.3402949077151671, 0.6546389172949815, 0.005066174989851391],
                                [0.3402949077151671, 0.44888729929169013, 0.21081779299314274],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.083717558488688, 0.909245892539487, 0.007036548971825031],
                                [0.083717558488688, 0.6234718442658672, 0.2928105972454448],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9321590592158998, 0.04651867752656094, 0.021322263257539317],
                                [0.9320485998575785, 0.06784094078410026, 0.0001104593583212004],
                                [0.9320485998575786, 0.04651867752656094, 0.021432722615860517],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6775520839713942, 0.22110322250073805, 0.10134469352786774],
                                [0.6770270707642532, 0.32244791602860573, 0.0005250132071410731],
                                [0.6770270707642532, 0.221103222500738, 0.10186970673500882],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.34536108270501853, 0.44888729929169013, 0.20575161800329134],
                                [0.3442951924932861, 0.6546389172949815, 0.0010658902117323882],
                                [0.3442951924932861, 0.44888729929169013, 0.20681750821502373],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.09075410746051304, 0.6234718442658672, 0.28577404827361974],
                                [0.08927366339996079, 0.909245892539487, 0.001480444060552261],
                                [0.08927366339996079, 0.6234718442658672, 0.287254492334172],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.9310931690041674, 0.06187028202400761, 0.007036548971825032],
                                [0.9310931690041674, 0.046518677526560935, 0.022388153469271706],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.6724859089815428, 0.29406938158821927, 0.033444709430237925],
                                [0.6724859089815427, 0.22110322250073805, 0.10641086851771915],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.3350756531974233, 0.5970243627049469, 0.06789998409762983],
                                [0.33507565319742333, 0.4488872992916901, 0.21603704751088665],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.07646839317479881, 0.8292234622691584, 0.09430814455604271],
                                [0.07646839317479881, 0.6234718442658671, 0.3000597625593341],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.933063542986141, 0.061870282024007614, 0.005066174989851391],
                                [0.933063542986141, 0.04651867752656094, 0.020417779487298063],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.6818510943245104, 0.2940693815882192, 0.024079524087270356],
                                [0.6818510943245104, 0.22110322250073802, 0.09704568317475157],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.3540890022948422, 0.597024362704947, 0.048886635000210864],
                                [0.3540890022948422, 0.44888729929169013, 0.19702369841346765],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.10287655363321169, 0.8292234622691584, 0.06789998409762983],
                                [0.10287655363321169, 0.6234718442658671, 0.27365160210092115],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.9356343307868777, 0.061870282024007614, 0.002495387189114714],
                                [0.9356343307868777, 0.04651867752656094, 0.017846991686561387],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.6940700458796984, 0.2940693815882192, 0.011860572532082279],
                                [0.6940700458796986, 0.221103222500738, 0.0848267316195635],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.3788961132077828, 0.5970243627049469, 0.024079524087270352],
                                [0.3788961132077828, 0.44888729929169, 0.17221658750052715],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.13733182830060364, 0.8292234622691584, 0.03344470943023791],
                                [0.13733182830060364, 0.6234718442658671, 0.23919632743352925],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9381297179759924, 0.046518677526560935, 0.015351604497446674],
                                [0.9376047047688514, 0.061870282024007614, 0.0005250132071410737],
                                [0.9376047047688514, 0.04651867752656094, 0.01587661770458775],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7059306184117807, 0.221103222500738, 0.07296615908748122],
                                [0.7034352312226662, 0.2940693815882192, 0.0024953871891147173],
                                [0.703435231222666, 0.22110322250073802, 0.07546154627659593],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.40297563729505315, 0.44888729929169, 0.1481370634132568],
                                [0.39790946230520163, 0.597024362704947, 0.005066174989851396],
                                [0.39790946230520163, 0.44888729929169013, 0.1532032384031082],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.17077653773084156, 0.6234718442658671, 0.20575161800329134],
                                [0.1637399887590164, 0.8292234622691586, 0.00703654897182504],
                                [0.1637399887590164, 0.6234718442658672, 0.21278816697511638],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9316340460087588, 0.05408023970552705, 0.014285714285714285],
                                [0.9316340460087587, 0.04651867752656094, 0.021847276464680394],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.6750566967822795, 0.25704331912009065, 0.06789998409762983],
                                [0.6750566967822795, 0.221103222500738, 0.10384008071698247],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.3402949077151671, 0.5218534583791714, 0.13785163390566152],
                                [0.3402949077151671, 0.44888729929169013, 0.21081779299314274],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.083717558488688, 0.724816537793735, 0.19146590371757705],
                                [0.083717558488688, 0.6234718442658672, 0.2928105972454448],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9356343307868777, 0.05408023970552704, 0.010285429507595284],
                                [0.9356343307868777, 0.04651867752656094, 0.017846991686561387],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.6940700458796984, 0.25704331912009065, 0.048886635000210864],
                                [0.6940700458796986, 0.221103222500738, 0.0848267316195635],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.3788961132077828, 0.5218534583791712, 0.09925042841304595],
                                [0.3788961132077828, 0.44888729929169, 0.17221658750052715],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.13733182830060375, 0.7248165377937348, 0.13785163390566152],
                                [0.13733182830060364, 0.6234718442658671, 0.23919632743352925],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9408535853046216, 0.05408023970552704, 0.005066174989851391],
                                [0.9408535853046216, 0.046518677526560935, 0.012627737168817495],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.7188771567926391, 0.2570433191200906, 0.024079524087270356],
                                [0.718877156792639, 0.221103222500738, 0.06001962070662299],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.42925990662061786, 0.5218534583791713, 0.048886635000210864],
                                [0.4292599066206178, 0.4488872992916901, 0.12185279408769208],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.20728347810863534, 0.7248165377937348, 0.06789998409762983],
                                [0.20728347810863534, 0.6234718442658671, 0.16924467762549755],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.945919760294473, 0.046518677526560935, 0.007561562178966105],
                                [0.9448538700827406, 0.05408023970552704, 0.001065890211732389],
                                [0.9448538700827406, 0.046518677526560935, 0.008627452390698493],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7429566808799094, 0.22110322250073802, 0.035940096619352636],
                                [0.737890505890058, 0.25704331912009065, 0.005066174989851394],
                                [0.737890505890058, 0.22110322250073802, 0.04100627160920403],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.47814654162082865, 0.4488872992916901, 0.07296615908748122],
                                [0.46786111211323334, 0.5218534583791714, 0.010285429507595291],
                                [0.46786111211323334, 0.44888729929169013, 0.0832515885950765],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.2751834622062652, 0.6234718442658671, 0.10134469352786774],
                                [0.26089774792055076, 0.7248165377937349, 0.014285714285714296],
                                [0.26089774792055076, 0.6234718442658672, 0.11563040781358204],
                                [0.9305681557970262, 0.06784094078410026, 0.0015909034188734612],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9320485998575786, 0.0481095809454344, 0.019841819196987055],
                                [0.9320485998575786, 0.04651867752656094, 0.021432722615860517],
                                [0.6699905217924281, 0.3224479160286058, 0.007561562178966105],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.6770270707642532, 0.22866478467970414, 0.09430814455604271],
                                [0.6770270707642532, 0.221103222500738, 0.10186970673500882],
                                [0.33000947820757187, 0.6546389172949815, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.34429519249328616, 0.46423890378913685, 0.19146590371757705],
                                [0.3442951924932861, 0.44888729929169013, 0.20681750821502373],
                                [0.06943184420297377, 0.909245892539487, 0.021322263257539317],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.0892736633999609, 0.6447941075234065, 0.26593222907663266],
                                [0.08927366339996079, 0.6234718442658672, 0.287254492334172],
                                [0.9305681557970263, 0.06187028202400761, 0.007561562178966105],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9376047047688514, 0.0481095809454344, 0.014285714285714285],
                                [0.9376047047688514, 0.04651867752656094, 0.01587661770458775],
                                [0.6699905217924282, 0.2940693815882192, 0.035940096619352636],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.7034352312226659, 0.22866478467970414, 0.06789998409762983],
                                [0.703435231222666, 0.22110322250073802, 0.07546154627659593],
                                [0.33000947820757176, 0.597024362704947, 0.07296615908748122],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.3979094623052017, 0.46423890378913685, 0.13785163390566152],
                                [0.39790946230520163, 0.44888729929169013, 0.1532032384031082],
                                [0.06943184420297377, 0.8292234622691586, 0.10134469352786774],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.16373998875901652, 0.6447941075234065, 0.19146590371757705],
                                [0.1637399887590164, 0.6234718442658672, 0.21278816697511638],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9448538700827406, 0.048109580945434396, 0.007036548971825031],
                                [0.9448538700827406, 0.046518677526560935, 0.008627452390698493],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.737890505890058, 0.22866478467970414, 0.03344470943023792],
                                [0.737890505890058, 0.22110322250073802, 0.04100627160920403],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.4678611121132334, 0.46423890378913685, 0.06789998409762982],
                                [0.46786111211323334, 0.44888729929169013, 0.0832515885950765],
                                [0.06943184420297377, 0.7248165377937349, 0.20575161800329134],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.26089774792055076, 0.6447941075234065, 0.0943081445560427],
                                [0.26089774792055076, 0.6234718442658672, 0.11563040781358204],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539317],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9518904190545656, 0.046518677526560935, 0.0015909034188734625],
                                [0.9504099749940134, 0.048109580945434396, 0.0014804440605522616],
                                [0.9504099749940134, 0.046518677526560935, 0.0030713474794257243],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7713352153202959, 0.221103222500738, 0.007561562178966112],
                                [0.7642986663484708, 0.22866478467970414, 0.007036548971825036],
                                [0.7642986663484709, 0.22110322250073802, 0.014598111150791147],
                                [0.33000947820757187, 0.4642389037891368, 0.20575161800329134],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.5357610962108633, 0.44888729929169, 0.015351604497446688],
                                [0.5214753819251489, 0.4642389037891368, 0.014285714285714296],
                                [0.521475381925149, 0.4488872992916901, 0.029637318783160983],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.3552058924765935, 0.6234718442658671, 0.021322263257539335],
                                [0.3353640732796065, 0.6447941075234065, 0.01984181919698707],
                                [0.3353640732796065, 0.6234718442658671, 0.04116408245452641],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9307924121532996, 0.06620196663242116, 0.0030056212142792692],
                                [0.9307924121532997, 0.022913166676412786, 0.04629442117028765],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6710564120041607, 0.31465787371012516, 0.014285714285714285],
                                [0.6710564120041604, 0.10890625570683382, 0.22003733228900563],
                                [0.33000947820757187, 0.6388234487633139, 0.031167073029114263],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.33217346556639205, 0.6388234487633139, 0.029003085670294092],
                                [0.332173465566392, 0.22110322250073805, 0.4467233119328699],
                                [0.06943184420297377, 0.8872793558410179, 0.04328879995600837],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.07243746541725304, 0.8872793558410178, 0.040283178741729105],
                                [0.07243746541725304, 0.3070963115311591, 0.6204662230515878],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9316340460087587, 0.06620196663242117, 0.0021639873588201654],
                                [0.9316340460087588, 0.022913166676412786, 0.04545278731482855],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6750566967822795, 0.3146578737101252, 0.010285429507595284],
                                [0.6750566967822795, 0.10890625570683385, 0.21603704751088662],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.3402949077151671, 0.6388234487633139, 0.02088164352151898],
                                [0.3402949077151672, 0.22110322250073805, 0.4386018697840948],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.083717558488688, 0.8872793558410179, 0.029003085670294096],
                                [0.083717558488688, 0.3070963115311591, 0.6091861299801529],
                                [0.9305681557970262, 0.03826477117385946, 0.03116707302911426],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9327321431558464, 0.06620196663242117, 0.0010658902117323882],
                                [0.9327321431558465, 0.022913166676412786, 0.04435469016774077],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6802759513000234, 0.3146578737101252, 0.005066174989851391],
                                [0.6802759513000234, 0.10890625570683388, 0.21081779299314274],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.35089112172909087, 0.6388234487633139, 0.010285429507595284],
                                [0.35089112172909087, 0.221103222500738, 0.42800565577017113],
                                [0.06943184420297377, 0.5128479295344505, 0.41772022626257577],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.09843492987326785, 0.8872793558410179, 0.014285714285714287],
                                [0.09843492987326785, 0.3070963115311591, 0.594468758595573],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9337980333675788, 0.02291316667641278, 0.04328879995600838],
                                [0.9335737770113055, 0.06620196663242116, 0.00022425635627328427],
                                [0.9335737770113056, 0.02291316667641278, 0.04351305631228166],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6853421262898748, 0.10890625570683388, 0.20575161800329134],
                                [0.6842762360781424, 0.3146578737101252, 0.001065890211732389],
                                [0.6842762360781425, 0.10890625570683388, 0.2068175082150237],
                                [0.3300094782075718, 0.2522702955298523, 0.4177202262625758],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3611765512366861, 0.221103222500738, 0.4177202262625759],
                                [0.35901256387786595, 0.6388234487633139, 0.0021639873588201668],
                                [0.3590125638778659, 0.22110322250073805, 0.419884213621396],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.11272064415898209, 0.3070963115311591, 0.5801830443098588],
                                [0.10971502294470292, 0.8872793558410178, 0.0030056212142792714],
                                [0.10971502294470292, 0.3070963115311591, 0.583188665524138],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9316340460087588, 0.05408023970552705, 0.014285714285714285],
                                [0.9316340460087588, 0.022913166676412786, 0.04545278731482855],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.6750566967822795, 0.25704331912009065, 0.06789998409762983],
                                [0.6750566967822795, 0.10890625570683385, 0.21603704751088662],
                                [0.33000947820757187, 0.6388234487633139, 0.031167073029114263],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.3402949077151671, 0.5218534583791714, 0.13785163390566152],
                                [0.3402949077151672, 0.22110322250073805, 0.4386018697840948],
                                [0.06943184420297377, 0.8872793558410179, 0.04328879995600837],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.083717558488688, 0.724816537793735, 0.19146590371757705],
                                [0.083717558488688, 0.3070963115311591, 0.6091861299801529],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9356343307868777, 0.05408023970552704, 0.010285429507595284],
                                [0.9356343307868777, 0.02291316667641278, 0.04145250253670955],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.6940700458796984, 0.25704331912009065, 0.048886635000210864],
                                [0.6940700458796984, 0.10890625570683382, 0.19702369841346767],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.3788961132077828, 0.5218534583791712, 0.09925042841304595],
                                [0.3788961132077828, 0.22110322250073788, 0.4000006642914793],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.13733182830060375, 0.7248165377937348, 0.13785163390566152],
                                [0.13733182830060364, 0.307096311531159, 0.5555718601682373],
                                [0.9305681557970262, 0.03826477117385946, 0.03116707302911426],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9408535853046216, 0.05408023970552704, 0.005066174989851391],
                                [0.9408535853046216, 0.02291316667641278, 0.03623324801896565],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.7188771567926391, 0.2570433191200906, 0.024079524087270356],
                                [0.7188771567926391, 0.10890625570683382, 0.17221658750052715],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.42925990662061786, 0.5218534583791713, 0.048886635000210864],
                                [0.42925990662061786, 0.221103222500738, 0.34963687087864415],
                                [0.06943184420297377, 0.5128479295344505, 0.41772022626257577],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.20728347810863534, 0.7248165377937348, 0.06789998409762983],
                                [0.20728347810863534, 0.307096311531159, 0.48562021036020564],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.945919760294473, 0.02291316667641278, 0.031167073029114263],
                                [0.9448538700827406, 0.05408023970552704, 0.001065890211732389],
                                [0.9448538700827406, 0.02291316667641278, 0.03223296324084665],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7429566808799093, 0.10890625570683385, 0.1481370634132568],
                                [0.737890505890058, 0.25704331912009065, 0.005066174989851394],
                                [0.7378905058900579, 0.10890625570683385, 0.1532032384031082],
                                [0.3300094782075718, 0.2522702955298523, 0.4177202262625758],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.4781465416208287, 0.221103222500738, 0.3007502358784333],
                                [0.46786111211323334, 0.5218534583791714, 0.010285429507595291],
                                [0.4678611121132333, 0.22110322250073805, 0.3110356653860286],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.27518346220626505, 0.30709631153115907, 0.4177202262625758],
                                [0.26089774792055076, 0.7248165377937349, 0.014285714285714296],
                                [0.26089774792055076, 0.3070963115311591, 0.4320059405482901],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9327321431558464, 0.03826477117385946, 0.029003085670294096],
                                [0.9327321431558465, 0.022913166676412786, 0.04435469016774077],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.6802759513000234, 0.1818724147943151, 0.13785163390566152],
                                [0.6802759513000234, 0.10890625570683388, 0.21081779299314274],
                                [0.33000947820757187, 0.6388234487633139, 0.031167073029114263],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.3508911217290908, 0.36924028591399477, 0.27986859235691436],
                                [0.35089112172909087, 0.221103222500738, 0.42800565577017113],
                                [0.06943184420297377, 0.8872793558410179, 0.04328879995600837],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.09843492987326785, 0.5128479295344504, 0.38871714059228174],
                                [0.09843492987326785, 0.3070963115311591, 0.594468758595573],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9408535853046216, 0.03826477117385946, 0.020881643521518976],
                                [0.9408535853046216, 0.02291316667641278, 0.03623324801896565],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.718877156792639, 0.18187241479431504, 0.09925042841304593],
                                [0.7188771567926391, 0.10890625570683382, 0.17221658750052715],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.4292599066206179, 0.36924028591399477, 0.20149980746538737],
                                [0.42925990662061786, 0.221103222500738, 0.34963687087864415],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.20728347810863534, 0.5128479295344504, 0.2798685923569143],
                                [0.20728347810863534, 0.307096311531159, 0.48562021036020564],
                                [0.9305681557970262, 0.03826477117385946, 0.03116707302911426],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9514497993185453, 0.03826477117385945, 0.010285429507595286],
                                [0.9514497993185453, 0.022913166676412775, 0.02563703400504196],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.7692409502054741, 0.18187241479431507, 0.04888663500021087],
                                [0.769240950205474, 0.10890625570683386, 0.12185279408769208],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.5315092856729592, 0.3692402859139948, 0.09925042841304596],
                                [0.5315092856729593, 0.22110322250073802, 0.24738749182630274],
                                [0.06943184420297377, 0.5128479295344505, 0.41772022626257577],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.3493004365598881, 0.5128479295344504, 0.13785163390566155],
                                [0.349300436559888, 0.30709631153115907, 0.34360325190895286],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9617352288261406, 0.02291316667641278, 0.015351604497446672],
                                [0.9595712414673204, 0.03826477117385945, 0.002163987358820169],
                                [0.9595712414673204, 0.022913166676412775, 0.017515591856266843],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.818127585205685, 0.10890625570683386, 0.0729661590874812],
                                [0.8078421556980897, 0.18187241479431504, 0.010285429507595301],
                                [0.8078421556980896, 0.10890625570683383, 0.08325158859507652],
                                [0.3300094782075718, 0.2522702955298523, 0.4177202262625758],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.6307597140860051, 0.22110322250073805, 0.14813706341325678],
                                [0.6098780705644862, 0.36924028591399477, 0.02088164352151901],
                                [0.6098780705644862, 0.22110322250073797, 0.1690187069347758],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.48715207046554965, 0.307096311531159, 0.2057516180032913],
                                [0.45814898479525556, 0.5128479295344502, 0.02900308567029414],
                                [0.45814898479525556, 0.307096311531159, 0.23475470367358545],
                                [0.9305681557970262, 0.06620196663242116, 0.0032298775705525535],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9335737770113055, 0.02614304424696534, 0.04028317874172911],
                                [0.9335737770113056, 0.022913166676412793, 0.04351305631228166],
                                [0.6699905217924281, 0.3146578737101252, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.6842762360781425, 0.12425786020428053, 0.19146590371757705],
                                [0.6842762360781425, 0.10890625570683388, 0.2068175082150237],
                                [0.33000947820757187, 0.6388234487633139, 0.031167073029114263],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.3590125638778659, 0.2522702955298523, 0.38871714059228174],
                                [0.3590125638778659, 0.22110322250073805, 0.419884213621396],
                                [0.06943184420297377, 0.8872793558410179, 0.04328879995600837],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.10971502294470281, 0.35038511148716756, 0.5398998655681296],
                                [0.10971502294470281, 0.30709631153115924, 0.583188665524138],
                                [0.9305681557970263, 0.05408023970552704, 0.015351604497446674],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9448538700827406, 0.02614304424696534, 0.02900308567029409],
                                [0.9448538700827406, 0.02291316667641278, 0.03223296324084665],
                                [0.669990521792428, 0.25704331912009065, 0.07296615908748122],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.737890505890058, 0.12425786020428056, 0.1378516339056615],
                                [0.7378905058900579, 0.10890625570683385, 0.1532032384031082],
                                [0.33000947820757187, 0.5218534583791713, 0.1481370634132568],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.46786111211323334, 0.25227029552985236, 0.2798685923569143],
                                [0.4678611121132333, 0.22110322250073805, 0.3110356653860286],
                                [0.06943184420297377, 0.7248165377937349, 0.2057516180032913],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.2608977479205508, 0.3503851114871676, 0.38871714059228163],
                                [0.26089774792055076, 0.3070963115311591, 0.4320059405482901],
                                [0.9305681557970262, 0.03826477117385946, 0.03116707302911426],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9595712414673204, 0.02614304424696534, 0.014285714285714285],
                                [0.9595712414673204, 0.02291316667641278, 0.017515591856266846],
                                [0.6699905217924281, 0.18187241479431507, 0.1481370634132568],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.8078421556980896, 0.12425786020428055, 0.06789998409762983],
                                [0.8078421556980896, 0.10890625570683385, 0.08325158859507653],
                                [0.33000947820757187, 0.3692402859139948, 0.3007502358784333],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.6098780705644862, 0.2522702955298523, 0.13785163390566152],
                                [0.6098780705644862, 0.221103222500738, 0.16901870693477583],
                                [0.06943184420297377, 0.5128479295344505, 0.41772022626257577],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.4581489847952555, 0.3503851114871675, 0.19146590371757705],
                                [0.45814898479525545, 0.307096311531159, 0.2347547036735855],
                                [0.9305681557970262, 0.026143044246965334, 0.04328879995600838],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9738569557530347, 0.02291316667641278, 0.0032298775705525595],
                                [0.9708513345387554, 0.02614304424696534, 0.0030056212142792727],
                                [0.9708513345387554, 0.02291316667641278, 0.006235498784831832],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.8757421397957195, 0.10890625570683386, 0.015351604497446703],
                                [0.8614564255100051, 0.12425786020428055, 0.014285714285714301],
                                [0.8614564255100051, 0.10890625570683385, 0.029637318783161004],
                                [0.3300094782075718, 0.2522702955298523, 0.4177202262625758],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.7477297044701476, 0.22110322250073805, 0.031167073029114322],
                                [0.7187266187998536, 0.2522702955298523, 0.029003085670294127],
                                [0.7187266187998536, 0.221103222500738, 0.06017015869940845],
                                [0.06943184420297377, 0.35038511148716756, 0.5801830443098587],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.6496148885128326, 0.30709631153115907, 0.04328879995600846],
                                [0.6093317097711033, 0.35038511148716756, 0.04028317874172915],
                                [0.6093317097711033, 0.30709631153115907, 0.08357197869773762],
                                [0.9305681557970262, 0.06494577892814218, 0.004486065274831529],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9308796315822727, 0.06494577892814218, 0.004174589489585056],
                                [0.9308796315822727, 0.004820780989426024, 0.06429958742830122],
                                [0.6699905217924282, 0.30868721495003254, 0.021322263257539317],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.6714709658529805, 0.30868721495003254, 0.019841819196987055],
                                [0.6714709658529803, 0.0229131666764128, 0.3056158674706068],
                                [0.330009478207572, 0.6267017218364197, 0.04328879995600837],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.33301509942185115, 0.6267017218364197, 0.040283178741729105],
                                [0.33301509942185115, 0.046518677526560914, 0.6204662230515879],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.07360643369255881, 0.8704431578583101, 0.0559504084491311],
                                [0.07360643369255881, 0.0646110632135477, 0.8617825030938935],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539314],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9320485998575785, 0.06494577892814218, 0.003005621214279269],
                                [0.9320485998575785, 0.004820780989426024, 0.06313061915299543],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.6770270707642532, 0.30868721495003254, 0.014285714285714284],
                                [0.6770270707642532, 0.0229131666764128, 0.30005976255933403],
                                [0.33000947820757187, 0.4642389037891368, 0.2057516180032913],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.3442951924932861, 0.6267017218364198, 0.02900308567029409],
                                [0.3442951924932861, 0.046518677526561025, 0.6091861299801529],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.08927366339996079, 0.8704431578583101, 0.040283178741729105],
                                [0.08927366339996079, 0.0646110632135477, 0.8461152733864915],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9335737770113055, 0.0649457789281422, 0.0014804440605522607],
                                [0.9335737770113055, 0.004820780989426024, 0.06160544199926843],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.6842762360781425, 0.30868721495003254, 0.007036548971825032],
                                [0.6842762360781425, 0.0229131666764128, 0.2928105972454448],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.35901256387786595, 0.6267017218364198, 0.014285714285714285],
                                [0.35901256387786595, 0.046518677526560914, 0.5944687585955731],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.10971502294470281, 0.8704431578583102, 0.019841819196987055],
                                [0.10971502294470281, 0.0646110632135477, 0.8256739138417495],
                                [0.9305681557970262, 0.009306846264257554, 0.06012499793871616],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9350542210718578, 0.004820780989426017, 0.06012499793871617],
                                [0.9347427452866113, 0.06494577892814218, 0.00031147578524647323],
                                [0.9347427452866113, 0.004820780989426017, 0.06043647372396264],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.6913127850499674, 0.0229131666764128, 0.28577404827361974],
                                [0.6898323409894151, 0.30868721495003254, 0.0014804440605522607],
                                [0.6898323409894151, 0.0229131666764128, 0.287254492334172],
                                [0.33000947820757187, 0.08980747748256945, 0.5801830443098587],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3732982781635803, 0.046518677526560914, 0.5801830443098588],
                                [0.370292656949301, 0.6267017218364197, 0.0030056212142792692],
                                [0.370292656949301, 0.046518677526560914, 0.5831886655241381],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.12955684214168994, 0.0646110632135477, 0.8058320946447624],
                                [0.1253822526521049, 0.8704431578583101, 0.004174589489585057],
                                [0.1253822526521049, 0.0646110632135477, 0.8100066841343474],
                                [0.9305681557970262, 0.06494577892814218, 0.004486065274831529],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9320485998575786, 0.0481095809454344, 0.019841819196987055],
                                [0.9320485998575785, 0.004820780989426024, 0.06313061915299543],
                                [0.6699905217924282, 0.30868721495003254, 0.021322263257539317],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.6770270707642532, 0.22866478467970414, 0.09430814455604271],
                                [0.6770270707642532, 0.0229131666764128, 0.30005976255933403],
                                [0.330009478207572, 0.6267017218364197, 0.04328879995600837],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.34429519249328616, 0.46423890378913685, 0.19146590371757705],
                                [0.3442951924932861, 0.046518677526561025, 0.6091861299801529],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.0892736633999609, 0.6447941075234065, 0.26593222907663266],
                                [0.08927366339996079, 0.0646110632135477, 0.8461152733864915],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539314],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9376047047688514, 0.0481095809454344, 0.014285714285714285],
                                [0.9376047047688513, 0.004820780989426017, 0.05757451424172267],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.7034352312226659, 0.22866478467970414, 0.06789998409762983],
                                [0.7034352312226659, 0.0229131666764128, 0.27365160210092115],
                                [0.33000947820757187, 0.4642389037891368, 0.2057516180032913],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.3979094623052017, 0.46423890378913685, 0.13785163390566152],
                                [0.39790946230520163, 0.046518677526561025, 0.5555718601682373],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.16373998875901652, 0.6447941075234065, 0.19146590371757705],
                                [0.1637399887590164, 0.0646110632135477, 0.7716489480274359],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9448538700827406, 0.048109580945434396, 0.007036548971825031],
                                [0.9448538700827405, 0.004820780989426017, 0.05032534892783341],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.737890505890058, 0.22866478467970414, 0.03344470943023792],
                                [0.737890505890058, 0.0229131666764128, 0.23919632743352925],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.4678611121132334, 0.46423890378913685, 0.06789998409762982],
                                [0.46786111211323334, 0.046518677526561025, 0.48562021036020564],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.26089774792055076, 0.6447941075234065, 0.0943081445560427],
                                [0.26089774792055076, 0.06461106321354781, 0.6744911888659014],
                                [0.9305681557970262, 0.009306846264257554, 0.06012499793871616],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9518904190545656, 0.004820780989426024, 0.04328879995600837],
                                [0.9504099749940134, 0.048109580945434396, 0.0014804440605522616],
                                [0.9504099749940133, 0.004820780989426017, 0.04476924401656064],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.7713352153202959, 0.0229131666764128, 0.2057516180032913],
                                [0.7642986663484708, 0.22866478467970414, 0.007036548971825036],
                                [0.7642986663484708, 0.0229131666764128, 0.21278816697511638],
                                [0.33000947820757187, 0.08980747748256945, 0.5801830443098587],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.5357610962108632, 0.04651867752656097, 0.41772022626257577],
                                [0.5214753819251489, 0.4642389037891368, 0.014285714285714296],
                                [0.521475381925149, 0.04651867752656097, 0.4320059405482901],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.3552058924765935, 0.06461106321354781, 0.5801830443098587],
                                [0.3353640732796065, 0.6447941075234065, 0.01984181919698707],
                                [0.3353640732796065, 0.0646110632135477, 0.6000248635068458],
                                [0.9305681557970262, 0.06494577892814218, 0.004486065274831529],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9335737770113055, 0.02614304424696534, 0.04028317874172911],
                                [0.9335737770113055, 0.004820780989426024, 0.06160544199926843],
                                [0.6699905217924282, 0.30868721495003254, 0.021322263257539317],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.6842762360781425, 0.12425786020428053, 0.19146590371757705],
                                [0.6842762360781425, 0.0229131666764128, 0.2928105972454448],
                                [0.330009478207572, 0.6267017218364197, 0.04328879995600837],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.3590125638778659, 0.2522702955298523, 0.38871714059228174],
                                [0.35901256387786595, 0.046518677526560914, 0.5944687585955731],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.10971502294470281, 0.35038511148716756, 0.5398998655681296],
                                [0.10971502294470281, 0.0646110632135477, 0.8256739138417495],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539314],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9448538700827406, 0.02614304424696534, 0.02900308567029409],
                                [0.9448538700827405, 0.004820780989426017, 0.05032534892783341],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.737890505890058, 0.12425786020428056, 0.1378516339056615],
                                [0.737890505890058, 0.0229131666764128, 0.23919632743352925],
                                [0.33000947820757187, 0.4642389037891368, 0.2057516180032913],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.46786111211323334, 0.25227029552985236, 0.2798685923569143],
                                [0.46786111211323334, 0.046518677526561025, 0.48562021036020564],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.2608977479205508, 0.3503851114871676, 0.38871714059228163],
                                [0.26089774792055076, 0.06461106321354781, 0.6744911888659014],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9595712414673204, 0.02614304424696534, 0.014285714285714285],
                                [0.9595712414673203, 0.004820780989426017, 0.03560797754325361],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.8078421556980896, 0.12425786020428055, 0.06789998409762983],
                                [0.8078421556980897, 0.0229131666764128, 0.16924467762549758],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.6098780705644862, 0.2522702955298523, 0.13785163390566152],
                                [0.6098780705644862, 0.04651867752656097, 0.34360325190895286],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.4581489847952555, 0.3503851114871675, 0.19146590371757705],
                                [0.45814898479525545, 0.0646110632135477, 0.47723995199119684],
                                [0.9305681557970262, 0.009306846264257554, 0.06012499793871616],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9738569557530347, 0.004820780989426017, 0.02132226325753932],
                                [0.9708513345387554, 0.02614304424696534, 0.0030056212142792727],
                                [0.9708513345387554, 0.0048207809894260205, 0.024327884471818592],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.8757421397957195, 0.0229131666764128, 0.10134469352786776],
                                [0.8614564255100051, 0.12425786020428055, 0.014285714285714301],
                                [0.8614564255100052, 0.022913166676412786, 0.11563040781358207],
                                [0.33000947820757187, 0.08980747748256945, 0.5801830443098587],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.7477297044701476, 0.046518677526561, 0.20575161800329136],
                                [0.7187266187998536, 0.2522702955298523, 0.029003085670294127],
                                [0.7187266187998536, 0.04651867752656094, 0.2347547036735855],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.6496148885128326, 0.06461106321354776, 0.2857740482736198],
                                [0.6093317097711033, 0.35038511148716756, 0.04028317874172915],
                                [0.6093317097711033, 0.06461106321354776, 0.32605722701534895],
                                [0.9305681557970262, 0.06494577892814218, 0.004486065274831529],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9347427452866113, 0.009306846264257547, 0.05595040844913111],
                                [0.9347427452866113, 0.004820780989426017, 0.06043647372396264],
                                [0.6699905217924282, 0.30868721495003254, 0.021322263257539317],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.6898323409894151, 0.044235429933952075, 0.2659322290766327],
                                [0.6898323409894151, 0.0229131666764128, 0.287254492334172],
                                [0.330009478207572, 0.6267017218364197, 0.04328879995600837],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.370292656949301, 0.08980747748256934, 0.5398998655681296],
                                [0.370292656949301, 0.046518677526560914, 0.5831886655241381],
                                [0.06943184420297377, 0.8704431578583101, 0.06012499793871617],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.1253822526521049, 0.12473606115226388, 0.7498816861956312],
                                [0.1253822526521049, 0.0646110632135477, 0.8100066841343474],
                                [0.9305681557970263, 0.048109580945434396, 0.021322263257539314],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9504099749940133, 0.009306846264257547, 0.04028317874172911],
                                [0.9504099749940133, 0.004820780989426017, 0.04476924401656064],
                                [0.6699905217924282, 0.22866478467970414, 0.10134469352786774],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.7642986663484709, 0.04423542993395213, 0.19146590371757705],
                                [0.7642986663484708, 0.0229131666764128, 0.21278816697511638],
                                [0.33000947820757187, 0.4642389037891368, 0.2057516180032913],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.5214753819251489, 0.08980747748256934, 0.38871714059228174],
                                [0.521475381925149, 0.04651867752656097, 0.4320059405482901],
                                [0.06943184420297377, 0.6447941075234065, 0.28577404827361974],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.3353640732796065, 0.12473606115226388, 0.5398998655681296],
                                [0.3353640732796065, 0.0646110632135477, 0.6000248635068458],
                                [0.9305681557970263, 0.02614304424696534, 0.04328879995600837],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9708513345387554, 0.009306846264257547, 0.019841819196987055],
                                [0.9708513345387554, 0.004820780989426017, 0.024327884471818585],
                                [0.6699905217924281, 0.12425786020428053, 0.20575161800329134],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.8614564255100051, 0.04423542993395212, 0.09430814455604271],
                                [0.8614564255100052, 0.0229131666764128, 0.11563040781358203],
                                [0.33000947820757187, 0.25227029552985236, 0.41772022626257577],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.7187266187998537, 0.08980747748256934, 0.19146590371757705],
                                [0.7187266187998536, 0.04651867752656097, 0.23475470367358542],
                                [0.06943184420297377, 0.35038511148716744, 0.5801830443098588],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.6093317097711035, 0.12473606115226393, 0.26593222907663266],
                                [0.6093317097711035, 0.06461106321354776, 0.32605722701534884],
                                [0.9305681557970262, 0.009306846264257554, 0.06012499793871616],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9906931537357424, 0.004820780989426019, 0.00448606527483153],
                                [0.9865185642461574, 0.00930684626425755, 0.004174589489585057],
                                [0.9865185642461574, 0.004820780989426019, 0.008660654764416588],
                                [0.6699905217924281, 0.04423542993395213, 0.28577404827361974],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.955764570066048, 0.022913166676412796, 0.02132226325753932],
                                [0.9359227508690608, 0.04423542993395212, 0.01984181919698706],
                                [0.9359227508690608, 0.0229131666764128, 0.04116408245452638],
                                [0.33000947820757187, 0.08980747748256945, 0.5801830443098587],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9101925225174305, 0.04651867752656097, 0.043288799956008386],
                                [0.8699093437757015, 0.08980747748256936, 0.04028317874172911],
                                [0.8699093437757015, 0.04651867752656097, 0.0835719786977375],
                                [0.06943184420297377, 0.12473606115226388, 0.8058320946447624],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.8752639388477361, 0.06461106321354776, 0.06012499793871617],
                                [0.819313530398605, 0.12473606115226392, 0.055950408449131114],
                                [0.819313530398605, 0.06461106321354775, 0.11607540638784729],
                            ]
                        ),
                        np.array(
                            [
                                [0.9309028715116208, 0.00448606527483153, 0.06461106321354769],
                                [0.9305913957263743, 0.00031147578524647323, 0.06909712848837923],
                                [0.9305681557970262, 2.3239929348011266e-05, 0.0694086042736257],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0003347157145944845, 0.06909712848837923],
                                [0.6715814252113016, 0.02132226325753932, 0.30709631153115907],
                                [0.6701009811507493, 0.0014804440605522607, 0.3284185747886984],
                                [0.6699905217924281, 0.00011045935832120038, 0.32989901884925066],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.0015909034188734612, 0.3284185747886984],
                                [0.3332393557781245, 0.043288799956008386, 0.6234718442658671],
                                [0.3302337345638452, 0.0030056212142792692, 0.6667606442218755],
                                [0.3300094782075719, 0.00022425635627328414, 0.6697662654361548],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.3300094782075719, 0.0032298775705525535, 0.6667606442218755],
                                [0.0739179094778053, 0.06012499793871617, 0.8659570925834785],
                                [0.06974331998822024, 0.004174589489585057, 0.9260820905221947],
                                [0.06943184420297378, 0.00031147578524647323, 0.9302566800117797],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.9309028715116208, 0.00448606527483153, 0.06461106321354769],
                                [0.9306786151553474, 0.0002242563562732841, 0.06909712848837923],
                                [0.9305681557970262, 0.00011045935832120038, 0.06932138484465251],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0003347157145944845, 0.06909712848837923],
                                [0.6715814252113016, 0.02132226325753932, 0.30709631153115907],
                                [0.6705155349995692, 0.001065890211732388, 0.3284185747886984],
                                [0.6699905217924282, 0.000525013207141073, 0.32948446500043077],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.0015909034188734612, 0.3284185747886984],
                                [0.3332393557781245, 0.043288799956008386, 0.6234718442658671],
                                [0.3310753684193043, 0.002163987358820165, 0.6667606442218755],
                                [0.3300094782075719, 0.001065890211732388, 0.6689246315806957],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.3300094782075719, 0.0032298775705525535, 0.6667606442218755],
                                [0.0739179094778053, 0.06012499793871617, 0.8659570925834785],
                                [0.07091228826352602, 0.003005621214279269, 0.9260820905221947],
                                [0.06943184420297377, 0.0014804440605522607, 0.929087711736474],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.9309028715116208, 0.00448606527483153, 0.06461106321354769],
                                [0.9307924121532996, 0.00011045935832120037, 0.06909712848837923],
                                [0.9305681557970262, 0.00022425635627328414, 0.06920758784670043],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0003347157145944845, 0.06909712848837923],
                                [0.6715814252113016, 0.02132226325753932, 0.30709631153115907],
                                [0.6710564120041607, 0.000525013207141073, 0.32841857478869835],
                                [0.669990521792428, 0.001065890211732388, 0.3289435879958395],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.0015909034188734612, 0.3284185747886984],
                                [0.3332393557781245, 0.043288799956008386, 0.6234718442658671],
                                [0.3321734655663921, 0.001065890211732388, 0.6667606442218755],
                                [0.33000947820757187, 0.0021639873588201654, 0.667826534433608],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.3300094782075719, 0.0032298775705525535, 0.6667606442218755],
                                [0.0739179094778053, 0.06012499793871617, 0.8659570925834785],
                                [0.07243746541725304, 0.0014804440605522605, 0.9260820905221947],
                                [0.06943184420297377, 0.0030056212142792692, 0.927562534582747],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.9309028715116208, 0.00448606527483153, 0.06461106321354769],
                                [0.9308796315822727, 2.323992934801126e-05, 0.06909712848837923],
                                [0.9305681557970262, 0.00031147578524647323, 0.06912036841772724],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0003347157145944845, 0.06909712848837923],
                                [0.6715814252113016, 0.02132226325753932, 0.30709631153115907],
                                [0.6714709658529804, 0.00011045935832120037, 0.3284185747886984],
                                [0.6699905217924281, 0.0014804440605522607, 0.3285290341470196],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.0015909034188734612, 0.3284185747886984],
                                [0.3332393557781245, 0.043288799956008386, 0.6234718442658671],
                                [0.3330150994218512, 0.0002242563562732841, 0.6667606442218755],
                                [0.33000947820757187, 0.0030056212142792692, 0.6669849005781489],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.3300094782075719, 0.0032298775705525535, 0.6667606442218755],
                                [0.0739179094778053, 0.06012499793871617, 0.8659570925834785],
                                [0.07360643369255883, 0.0003114757852464732, 0.9260820905221947],
                                [0.06943184420297376, 0.004174589489585057, 0.9263935663074412],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297377, 0.00448606527483153, 0.9260820905221947],
                                [0.9321590592158997, 0.0032298775705525535, 0.0646110632135477],
                                [0.9306786151553474, 0.0014804440605522607, 0.06784094078410026],
                                [0.9305681557970262, 0.00011045935832120038, 0.06932138484465251],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0015909034188734612, 0.06784094078410026],
                                [0.6775520839713942, 0.015351604497446674, 0.3070963115311591],
                                [0.6705155349995692, 0.007036548971825032, 0.32244791602860573],
                                [0.6699905217924282, 0.000525013207141073, 0.32948446500043077],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.007561562178966105, 0.3224479160286058],
                                [0.34536108270501853, 0.03116707302911426, 0.6234718442658672],
                                [0.33107536841930424, 0.014285714285714285, 0.6546389172949815],
                                [0.3300094782075719, 0.001065890211732388, 0.6689246315806957],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.33000947820757187, 0.015351604497446674, 0.6546389172949815],
                                [0.0907541074605131, 0.04328879995600838, 0.8659570925834785],
                                [0.070912288263526, 0.019841819196987055, 0.909245892539487],
                                [0.06943184420297377, 0.0014804440605522607, 0.929087711736474],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297373, 0.021322263257539317, 0.909245892539487],
                                [0.9321590592158997, 0.0032298775705525535, 0.0646110632135477],
                                [0.9310931690041673, 0.001065890211732388, 0.06784094078410026],
                                [0.9305681557970263, 0.000525013207141073, 0.06890683099583264],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0015909034188734612, 0.06784094078410026],
                                [0.6775520839713942, 0.015351604497446674, 0.3070963115311591],
                                [0.6724859089815428, 0.005066174989851391, 0.3224479160286058],
                                [0.6699905217924282, 0.0024953871891147143, 0.32751409101845713],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.007561562178966105, 0.3224479160286058],
                                [0.34536108270501853, 0.03116707302911426, 0.6234718442658672],
                                [0.3350756531974233, 0.010285429507595284, 0.6546389172949815],
                                [0.33000947820757187, 0.005066174989851391, 0.6649243468025767],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.33000947820757187, 0.015351604497446674, 0.6546389172949815],
                                [0.0907541074605131, 0.04328879995600838, 0.8659570925834785],
                                [0.07646839317479875, 0.014285714285714285, 0.909245892539487],
                                [0.06943184420297378, 0.007036548971825031, 0.9235316068252012],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297373, 0.021322263257539317, 0.909245892539487],
                                [0.9321590592158997, 0.0032298775705525535, 0.0646110632135477],
                                [0.9316340460087587, 0.000525013207141073, 0.06784094078410026],
                                [0.9305681557970262, 0.001065890211732388, 0.06836595399124133],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0015909034188734612, 0.06784094078410026],
                                [0.6775520839713942, 0.015351604497446674, 0.3070963115311591],
                                [0.6750566967822795, 0.0024953871891147143, 0.32244791602860573],
                                [0.6699905217924281, 0.005066174989851391, 0.32494330321772047],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.007561562178966105, 0.3224479160286058],
                                [0.34536108270501853, 0.03116707302911426, 0.6234718442658672],
                                [0.3402949077151671, 0.005066174989851391, 0.6546389172949815],
                                [0.33000947820757187, 0.010285429507595284, 0.6597050922848329],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.33000947820757187, 0.015351604497446674, 0.6546389172949815],
                                [0.0907541074605131, 0.04328879995600838, 0.8659570925834785],
                                [0.08371755848868802, 0.007036548971825031, 0.909245892539487],
                                [0.06943184420297371, 0.014285714285714285, 0.916282441511312],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297373, 0.021322263257539317, 0.909245892539487],
                                [0.9321590592158997, 0.0032298775705525535, 0.0646110632135477],
                                [0.9320485998575785, 0.0001104593583212004, 0.06784094078410026],
                                [0.9305681557970262, 0.0014804440605522607, 0.06795140014242146],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0015909034188734612, 0.06784094078410026],
                                [0.6775520839713942, 0.015351604497446674, 0.3070963115311591],
                                [0.6770270707642532, 0.0005250132071410731, 0.32244791602860573],
                                [0.6699905217924281, 0.007036548971825032, 0.32297292923574683],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.007561562178966105, 0.3224479160286058],
                                [0.34536108270501853, 0.03116707302911426, 0.6234718442658672],
                                [0.34429519249328616, 0.0010658902117323882, 0.6546389172949815],
                                [0.3300094782075718, 0.014285714285714285, 0.6557048075067139],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.33000947820757187, 0.015351604497446674, 0.6546389172949815],
                                [0.0907541074605131, 0.04328879995600838, 0.8659570925834785],
                                [0.08927366339996079, 0.001480444060552261, 0.909245892539487],
                                [0.06943184420297374, 0.019841819196987055, 0.9107263366000392],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297373, 0.021322263257539317, 0.909245892539487],
                                [0.9337980333675788, 0.0015909034188734612, 0.0646110632135477],
                                [0.9307924121532996, 0.0030056212142792692, 0.06620196663242116],
                                [0.9305681557970262, 0.00022425635627328414, 0.06920758784670043],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0032298775705525535, 0.06620196663242116],
                                [0.6853421262898748, 0.007561562178966105, 0.3070963115311591],
                                [0.6710564120041607, 0.014285714285714285, 0.31465787371012516],
                                [0.669990521792428, 0.001065890211732388, 0.3289435879958395],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.015351604497446674, 0.3146578737101252],
                                [0.3611765512366861, 0.015351604497446674, 0.6234718442658672],
                                [0.33217346556639205, 0.029003085670294092, 0.6388234487633139],
                                [0.33000947820757187, 0.0021639873588201654, 0.667826534433608],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.33000947820757187, 0.03116707302911426, 0.6388234487633139],
                                [0.11272064415898204, 0.021322263257539317, 0.8659570925834786],
                                [0.0724374654172531, 0.040283178741729105, 0.8872793558410178],
                                [0.06943184420297377, 0.0030056212142792692, 0.927562534582747],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297382, 0.04328879995600838, 0.8872793558410178],
                                [0.9337980333675788, 0.0015909034188734612, 0.0646110632135477],
                                [0.9316340460087587, 0.0021639873588201654, 0.06620196663242117],
                                [0.9305681557970262, 0.001065890211732388, 0.06836595399124133],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0032298775705525535, 0.06620196663242116],
                                [0.6853421262898748, 0.007561562178966105, 0.3070963115311591],
                                [0.6750566967822795, 0.010285429507595284, 0.3146578737101252],
                                [0.6699905217924281, 0.005066174989851391, 0.32494330321772047],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.015351604497446674, 0.3146578737101252],
                                [0.3611765512366861, 0.015351604497446674, 0.6234718442658672],
                                [0.3402949077151671, 0.02088164352151898, 0.6388234487633139],
                                [0.33000947820757187, 0.010285429507595284, 0.6597050922848329],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.33000947820757187, 0.03116707302911426, 0.6388234487633139],
                                [0.11272064415898204, 0.021322263257539317, 0.8659570925834786],
                                [0.08371755848868799, 0.029003085670294096, 0.8872793558410179],
                                [0.06943184420297371, 0.014285714285714285, 0.916282441511312],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297382, 0.04328879995600838, 0.8872793558410178],
                                [0.9337980333675788, 0.0015909034188734612, 0.0646110632135477],
                                [0.9327321431558464, 0.0010658902117323882, 0.06620196663242117],
                                [0.9305681557970262, 0.0021639873588201654, 0.06726785684415355],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0032298775705525535, 0.06620196663242116],
                                [0.6853421262898748, 0.007561562178966105, 0.3070963115311591],
                                [0.6802759513000234, 0.005066174989851391, 0.3146578737101252],
                                [0.6699905217924281, 0.010285429507595284, 0.3197240486999766],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.015351604497446674, 0.3146578737101252],
                                [0.3611765512366861, 0.015351604497446674, 0.6234718442658672],
                                [0.35089112172909087, 0.010285429507595284, 0.6388234487633139],
                                [0.33000947820757187, 0.020881643521518976, 0.6491088782709091],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.33000947820757187, 0.03116707302911426, 0.6388234487633139],
                                [0.11272064415898204, 0.021322263257539317, 0.8659570925834786],
                                [0.0984349298732678, 0.014285714285714287, 0.8872793558410179],
                                [0.06943184420297376, 0.029003085670294092, 0.9015650701267321],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297382, 0.04328879995600838, 0.8872793558410178],
                                [0.9337980333675788, 0.0015909034188734612, 0.0646110632135477],
                                [0.9335737770113055, 0.00022425635627328427, 0.06620196663242116],
                                [0.9305681557970262, 0.0030056212142792692, 0.06642622298869444],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.0032298775705525535, 0.06620196663242116],
                                [0.6853421262898748, 0.007561562178966105, 0.3070963115311591],
                                [0.6842762360781424, 0.001065890211732389, 0.3146578737101252],
                                [0.6699905217924282, 0.014285714285714285, 0.3157237639218576],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.015351604497446674, 0.3146578737101252],
                                [0.3611765512366861, 0.015351604497446674, 0.6234718442658672],
                                [0.35901256387786595, 0.0021639873588201668, 0.6388234487633139],
                                [0.33000947820757187, 0.029003085670294092, 0.640987436122134],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.33000947820757187, 0.03116707302911426, 0.6388234487633139],
                                [0.11272064415898204, 0.021322263257539317, 0.8659570925834786],
                                [0.10971502294470292, 0.0030056212142792714, 0.8872793558410178],
                                [0.06943184420297382, 0.040283178741729105, 0.8902849770552971],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297382, 0.04328879995600838, 0.8872793558410178],
                                [0.9350542210718578, 0.00033471571459448517, 0.0646110632135477],
                                [0.9308796315822727, 0.004174589489585056, 0.06494577892814218],
                                [0.9305681557970262, 0.0003114757852464732, 0.06912036841772724],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.004486065274831529, 0.06494577892814218],
                                [0.6913127850499674, 0.0015909034188734642, 0.30709631153115907],
                                [0.6714709658529804, 0.019841819196987055, 0.30868721495003254],
                                [0.6699905217924281, 0.0014804440605522605, 0.3285290341470196],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.021322263257539314, 0.30868721495003254],
                                [0.37329827816358035, 0.0032298775705525595, 0.6234718442658671],
                                [0.3330150994218512, 0.040283178741729105, 0.6267017218364197],
                                [0.33000947820757187, 0.003005621214279269, 0.6669849005781489],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.3300094782075719, 0.04328879995600837, 0.6267017218364197],
                                [0.12955684214168994, 0.004486065274831539, 0.8659570925834785],
                                [0.07360643369255884, 0.0559504084491311, 0.8704431578583101],
                                [0.06943184420297376, 0.004174589489585056, 0.9263935663074412],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297378, 0.06012499793871616, 0.8704431578583101],
                                [0.9350542210718578, 0.00033471571459448517, 0.0646110632135477],
                                [0.9320485998575785, 0.003005621214279269, 0.06494577892814218],
                                [0.9305681557970262, 0.0014804440605522605, 0.06795140014242146],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.004486065274831529, 0.06494577892814218],
                                [0.6913127850499674, 0.0015909034188734642, 0.30709631153115907],
                                [0.6770270707642532, 0.014285714285714284, 0.30868721495003254],
                                [0.6699905217924281, 0.00703654897182503, 0.32297292923574683],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.021322263257539314, 0.30868721495003254],
                                [0.37329827816358035, 0.0032298775705525595, 0.6234718442658671],
                                [0.3442951924932861, 0.02900308567029409, 0.6267017218364198],
                                [0.3300094782075718, 0.014285714285714284, 0.6557048075067139],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.3300094782075719, 0.04328879995600837, 0.6267017218364197],
                                [0.12955684214168994, 0.004486065274831539, 0.8659570925834785],
                                [0.08927366339996085, 0.040283178741729105, 0.8704431578583101],
                                [0.06943184420297374, 0.019841819196987052, 0.9107263366000392],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297378, 0.06012499793871616, 0.8704431578583101],
                                [0.9350542210718578, 0.00033471571459448517, 0.0646110632135477],
                                [0.9335737770113055, 0.0014804440605522607, 0.0649457789281422],
                                [0.9305681557970262, 0.003005621214279269, 0.06642622298869444],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.004486065274831529, 0.06494577892814218],
                                [0.6913127850499674, 0.0015909034188734642, 0.30709631153115907],
                                [0.6842762360781424, 0.007036548971825032, 0.30868721495003254],
                                [0.6699905217924282, 0.014285714285714284, 0.3157237639218576],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.021322263257539314, 0.30868721495003254],
                                [0.37329827816358035, 0.0032298775705525595, 0.6234718442658671],
                                [0.3590125638778659, 0.014285714285714285, 0.6267017218364198],
                                [0.33000947820757187, 0.02900308567029409, 0.640987436122134],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.3300094782075719, 0.04328879995600837, 0.6267017218364197],
                                [0.12955684214168994, 0.004486065274831539, 0.8659570925834785],
                                [0.10971502294470278, 0.019841819196987055, 0.8704431578583102],
                                [0.06943184420297382, 0.040283178741729105, 0.8902849770552971],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297378, 0.06012499793871616, 0.8704431578583101],
                                [0.9350542210718578, 0.00033471571459448517, 0.0646110632135477],
                                [0.9347427452866113, 0.00031147578524647323, 0.06494577892814218],
                                [0.9305681557970263, 0.004174589489585056, 0.06525725471338865],
                                [0.9305681557970262, 0.004820780989426014, 0.0646110632135477],
                                [0.9305681557970262, 0.004486065274831529, 0.06494577892814218],
                                [0.6913127850499674, 0.0015909034188734642, 0.30709631153115907],
                                [0.6898323409894151, 0.0014804440605522607, 0.30868721495003254],
                                [0.6699905217924281, 0.019841819196987055, 0.3101676590105848],
                                [0.6699905217924281, 0.02291316667641278, 0.30709631153115907],
                                [0.6699905217924281, 0.021322263257539314, 0.30868721495003254],
                                [0.37329827816358035, 0.0032298775705525595, 0.6234718442658671],
                                [0.370292656949301, 0.0030056212142792692, 0.6267017218364197],
                                [0.3300094782075719, 0.040283178741729105, 0.629707343050699],
                                [0.33000947820757187, 0.046518677526560935, 0.6234718442658672],
                                [0.3300094782075719, 0.04328879995600837, 0.6267017218364197],
                                [0.12955684214168994, 0.004486065274831539, 0.8659570925834785],
                                [0.1253822526521049, 0.004174589489585057, 0.8704431578583101],
                                [0.0694318442029738, 0.0559504084491311, 0.8746177473478951],
                                [0.06943184420297378, 0.06461106321354769, 0.8659570925834785],
                                [0.06943184420297378, 0.06012499793871616, 0.8704431578583101],
                                [0.9321590592158998, 0.021322263257539317, 0.04651867752656094],
                                [0.9306786151553474, 0.0014804440605522607, 0.06784094078410026],
                                [0.9305681557970262, 0.00011045935832120038, 0.06932138484465251],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970262, 0.0015909034188734612, 0.06784094078410026],
                                [0.6775520839713942, 0.10134469352786774, 0.22110322250073805],
                                [0.6705155349995692, 0.007036548971825032, 0.32244791602860573],
                                [0.6699905217924282, 0.000525013207141073, 0.32948446500043077],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924281, 0.007561562178966105, 0.3224479160286058],
                                [0.34536108270501853, 0.20575161800329134, 0.44888729929169013],
                                [0.33107536841930424, 0.014285714285714285, 0.6546389172949815],
                                [0.3300094782075719, 0.001065890211732388, 0.6689246315806957],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.015351604497446674, 0.6546389172949815],
                                [0.09075410746051304, 0.28577404827361974, 0.6234718442658672],
                                [0.070912288263526, 0.019841819196987055, 0.909245892539487],
                                [0.06943184420297377, 0.0014804440605522607, 0.929087711736474],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297373, 0.021322263257539317, 0.909245892539487],
                                [0.9321590592158998, 0.021322263257539317, 0.04651867752656094],
                                [0.9310931690041673, 0.001065890211732388, 0.06784094078410026],
                                [0.9305681557970263, 0.000525013207141073, 0.06890683099583264],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970262, 0.0015909034188734612, 0.06784094078410026],
                                [0.6775520839713942, 0.10134469352786774, 0.22110322250073805],
                                [0.6724859089815428, 0.005066174989851391, 0.3224479160286058],
                                [0.6699905217924282, 0.0024953871891147143, 0.32751409101845713],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924281, 0.007561562178966105, 0.3224479160286058],
                                [0.34536108270501853, 0.20575161800329134, 0.44888729929169013],
                                [0.3350756531974233, 0.010285429507595284, 0.6546389172949815],
                                [0.33000947820757187, 0.005066174989851391, 0.6649243468025767],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.015351604497446674, 0.6546389172949815],
                                [0.09075410746051304, 0.28577404827361974, 0.6234718442658672],
                                [0.07646839317479875, 0.014285714285714285, 0.909245892539487],
                                [0.06943184420297378, 0.007036548971825031, 0.9235316068252012],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297373, 0.021322263257539317, 0.909245892539487],
                                [0.9321590592158998, 0.021322263257539317, 0.04651867752656094],
                                [0.9316340460087587, 0.000525013207141073, 0.06784094078410026],
                                [0.9305681557970262, 0.001065890211732388, 0.06836595399124133],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970262, 0.0015909034188734612, 0.06784094078410026],
                                [0.6775520839713942, 0.10134469352786774, 0.22110322250073805],
                                [0.6750566967822795, 0.0024953871891147143, 0.32244791602860573],
                                [0.6699905217924281, 0.005066174989851391, 0.32494330321772047],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924281, 0.007561562178966105, 0.3224479160286058],
                                [0.34536108270501853, 0.20575161800329134, 0.44888729929169013],
                                [0.3402949077151671, 0.005066174989851391, 0.6546389172949815],
                                [0.33000947820757187, 0.010285429507595284, 0.6597050922848329],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.015351604497446674, 0.6546389172949815],
                                [0.09075410746051304, 0.28577404827361974, 0.6234718442658672],
                                [0.08371755848868802, 0.007036548971825031, 0.909245892539487],
                                [0.06943184420297371, 0.014285714285714285, 0.916282441511312],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297373, 0.021322263257539317, 0.909245892539487],
                                [0.9321590592158998, 0.021322263257539317, 0.04651867752656094],
                                [0.9320485998575785, 0.0001104593583212004, 0.06784094078410026],
                                [0.9305681557970262, 0.0014804440605522607, 0.06795140014242146],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970262, 0.0015909034188734612, 0.06784094078410026],
                                [0.6775520839713942, 0.10134469352786774, 0.22110322250073805],
                                [0.6770270707642532, 0.0005250132071410731, 0.32244791602860573],
                                [0.6699905217924281, 0.007036548971825032, 0.32297292923574683],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924281, 0.007561562178966105, 0.3224479160286058],
                                [0.34536108270501853, 0.20575161800329134, 0.44888729929169013],
                                [0.34429519249328616, 0.0010658902117323882, 0.6546389172949815],
                                [0.3300094782075718, 0.014285714285714285, 0.6557048075067139],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.015351604497446674, 0.6546389172949815],
                                [0.09075410746051304, 0.28577404827361974, 0.6234718442658672],
                                [0.08927366339996079, 0.001480444060552261, 0.909245892539487],
                                [0.06943184420297374, 0.019841819196987055, 0.9107263366000392],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297373, 0.021322263257539317, 0.909245892539487],
                                [0.9381297179759924, 0.015351604497446674, 0.046518677526560935],
                                [0.9310931690041674, 0.007036548971825032, 0.06187028202400761],
                                [0.9305681557970263, 0.000525013207141073, 0.06890683099583264],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.007561562178966105, 0.06187028202400761],
                                [0.7059306184117808, 0.07296615908748122, 0.221103222500738],
                                [0.6724859089815428, 0.033444709430237925, 0.29406938158821927],
                                [0.6699905217924282, 0.0024953871891147143, 0.32751409101845713],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924282, 0.035940096619352636, 0.2940693815882192],
                                [0.40297563729505315, 0.1481370634132568, 0.44888729929169],
                                [0.33507565319742333, 0.06789998409762983, 0.5970243627049469],
                                [0.33000947820757187, 0.005066174989851391, 0.6649243468025767],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.3300094782075718, 0.07296615908748122, 0.597024362704947],
                                [0.17077653773084156, 0.20575161800329134, 0.6234718442658671],
                                [0.07646839317479885, 0.09430814455604271, 0.8292234622691584],
                                [0.06943184420297378, 0.007036548971825031, 0.9235316068252012],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297371, 0.10134469352786774, 0.8292234622691586],
                                [0.9381297179759924, 0.015351604497446674, 0.046518677526560935],
                                [0.933063542986141, 0.005066174989851391, 0.061870282024007614],
                                [0.9305681557970263, 0.0024953871891147147, 0.066936457013859],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.007561562178966105, 0.06187028202400761],
                                [0.7059306184117808, 0.07296615908748122, 0.221103222500738],
                                [0.6818510943245105, 0.024079524087270356, 0.2940693815882192],
                                [0.6699905217924281, 0.01186057253208228, 0.3181489056754896],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924282, 0.035940096619352636, 0.2940693815882192],
                                [0.40297563729505315, 0.1481370634132568, 0.44888729929169],
                                [0.3540890022948422, 0.048886635000210864, 0.597024362704947],
                                [0.3300094782075718, 0.024079524087270356, 0.6459109977051578],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.3300094782075718, 0.07296615908748122, 0.597024362704947],
                                [0.17077653773084156, 0.20575161800329134, 0.6234718442658671],
                                [0.10287655363321173, 0.06789998409762983, 0.8292234622691584],
                                [0.06943184420297377, 0.03344470943023792, 0.8971234463667883],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297371, 0.10134469352786774, 0.8292234622691586],
                                [0.9381297179759924, 0.015351604497446674, 0.046518677526560935],
                                [0.9356343307868777, 0.002495387189114714, 0.061870282024007614],
                                [0.9305681557970262, 0.005066174989851391, 0.06436566921312233],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.007561562178966105, 0.06187028202400761],
                                [0.7059306184117808, 0.07296615908748122, 0.221103222500738],
                                [0.6940700458796986, 0.011860572532082279, 0.2940693815882192],
                                [0.6699905217924281, 0.024079524087270356, 0.3059299541203015],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924282, 0.035940096619352636, 0.2940693815882192],
                                [0.40297563729505315, 0.1481370634132568, 0.44888729929169],
                                [0.37889611320778277, 0.024079524087270352, 0.5970243627049469],
                                [0.33000947820757187, 0.048886635000210864, 0.6211038867922173],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.3300094782075718, 0.07296615908748122, 0.597024362704947],
                                [0.17077653773084156, 0.20575161800329134, 0.6234718442658671],
                                [0.13733182830060364, 0.03344470943023791, 0.8292234622691584],
                                [0.06943184420297381, 0.06789998409762983, 0.8626681716993964],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297371, 0.10134469352786774, 0.8292234622691586],
                                [0.9381297179759924, 0.015351604497446674, 0.046518677526560935],
                                [0.9376047047688514, 0.0005250132071410737, 0.061870282024007614],
                                [0.9305681557970262, 0.007036548971825031, 0.06239529523114868],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.007561562178966105, 0.06187028202400761],
                                [0.7059306184117808, 0.07296615908748122, 0.221103222500738],
                                [0.7034352312226662, 0.0024953871891147173, 0.2940693815882192],
                                [0.6699905217924281, 0.03344470943023792, 0.29656476877733395],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924282, 0.035940096619352636, 0.2940693815882192],
                                [0.40297563729505315, 0.1481370634132568, 0.44888729929169],
                                [0.39790946230520163, 0.005066174989851396, 0.597024362704947],
                                [0.3300094782075719, 0.06789998409762982, 0.6020905376947983],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.3300094782075718, 0.07296615908748122, 0.597024362704947],
                                [0.17077653773084156, 0.20575161800329134, 0.6234718442658671],
                                [0.1637399887590164, 0.00703654897182504, 0.8292234622691586],
                                [0.06943184420297382, 0.0943081445560427, 0.8362600112409835],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297371, 0.10134469352786774, 0.8292234622691586],
                                [0.945919760294473, 0.007561562178966105, 0.046518677526560935],
                                [0.9316340460087588, 0.014285714285714285, 0.05408023970552705],
                                [0.9305681557970262, 0.001065890211732388, 0.06836595399124133],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.015351604497446674, 0.05408023970552704],
                                [0.7429566808799094, 0.035940096619352636, 0.22110322250073802],
                                [0.6750566967822794, 0.06789998409762983, 0.25704331912009065],
                                [0.6699905217924281, 0.005066174989851391, 0.32494330321772047],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.47814654162082865, 0.07296615908748122, 0.4488872992916901],
                                [0.34029490771516707, 0.13785163390566152, 0.5218534583791714],
                                [0.33000947820757187, 0.010285429507595284, 0.6597050922848329],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.1481370634132568, 0.5218534583791713],
                                [0.27518346220626516, 0.10134469352786774, 0.6234718442658671],
                                [0.08371755848868795, 0.19146590371757705, 0.724816537793735],
                                [0.06943184420297371, 0.014285714285714285, 0.916282441511312],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.945919760294473, 0.007561562178966105, 0.046518677526560935],
                                [0.9356343307868777, 0.010285429507595284, 0.05408023970552704],
                                [0.9305681557970262, 0.005066174989851391, 0.06436566921312233],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.015351604497446674, 0.05408023970552704],
                                [0.7429566808799094, 0.035940096619352636, 0.22110322250073802],
                                [0.6940700458796984, 0.048886635000210864, 0.25704331912009065],
                                [0.6699905217924281, 0.024079524087270356, 0.3059299541203015],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.47814654162082865, 0.07296615908748122, 0.4488872992916901],
                                [0.3788961132077829, 0.09925042841304595, 0.5218534583791712],
                                [0.33000947820757187, 0.048886635000210864, 0.6211038867922173],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.1481370634132568, 0.5218534583791713],
                                [0.27518346220626516, 0.10134469352786774, 0.6234718442658671],
                                [0.1373318283006037, 0.13785163390566152, 0.7248165377937348],
                                [0.06943184420297381, 0.06789998409762983, 0.8626681716993964],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.945919760294473, 0.007561562178966105, 0.046518677526560935],
                                [0.9408535853046216, 0.005066174989851391, 0.05408023970552704],
                                [0.9305681557970263, 0.010285429507595284, 0.05914641469537843],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.015351604497446674, 0.05408023970552704],
                                [0.7429566808799094, 0.035940096619352636, 0.22110322250073802],
                                [0.7188771567926391, 0.024079524087270356, 0.2570433191200906],
                                [0.6699905217924281, 0.048886635000210864, 0.28112284320736103],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.47814654162082865, 0.07296615908748122, 0.4488872992916901],
                                [0.42925990662061786, 0.048886635000210864, 0.5218534583791713],
                                [0.3300094782075719, 0.09925042841304595, 0.5707400933793821],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.1481370634132568, 0.5218534583791713],
                                [0.27518346220626516, 0.10134469352786774, 0.6234718442658671],
                                [0.2072834781086354, 0.06789998409762983, 0.7248165377937348],
                                [0.06943184420297371, 0.13785163390566152, 0.7927165218913648],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.945919760294473, 0.007561562178966105, 0.046518677526560935],
                                [0.9448538700827406, 0.001065890211732389, 0.05408023970552704],
                                [0.9305681557970263, 0.014285714285714285, 0.05514612991725943],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.015351604497446674, 0.05408023970552704],
                                [0.7429566808799094, 0.035940096619352636, 0.22110322250073802],
                                [0.7378905058900579, 0.005066174989851394, 0.25704331912009065],
                                [0.6699905217924281, 0.06789998409762983, 0.26210949410994205],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.47814654162082865, 0.07296615908748122, 0.4488872992916901],
                                [0.4678611121132333, 0.010285429507595291, 0.5218534583791714],
                                [0.3300094782075719, 0.13785163390566152, 0.5321388878867666],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.1481370634132568, 0.5218534583791713],
                                [0.27518346220626516, 0.10134469352786774, 0.6234718442658671],
                                [0.2608977479205508, 0.014285714285714296, 0.7248165377937349],
                                [0.06943184420297371, 0.19146590371757705, 0.7391022520794492],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.9518904190545656, 0.0015909034188734625, 0.046518677526560935],
                                [0.9320485998575786, 0.019841819196987055, 0.0481095809454344],
                                [0.9305681557970262, 0.0014804440605522607, 0.06795140014242146],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.7713352153202959, 0.007561562178966112, 0.221103222500738],
                                [0.6770270707642532, 0.09430814455604271, 0.22866478467970414],
                                [0.6699905217924281, 0.007036548971825032, 0.32297292923574683],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924282, 0.10134469352786774, 0.22866478467970414],
                                [0.5357610962108633, 0.015351604497446688, 0.44888729929169],
                                [0.34429519249328616, 0.19146590371757705, 0.46423890378913685],
                                [0.3300094782075718, 0.014285714285714285, 0.6557048075067139],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.20575161800329134, 0.4642389037891368],
                                [0.35520589247659357, 0.021322263257539335, 0.6234718442658671],
                                [0.08927366339996085, 0.26593222907663266, 0.6447941075234065],
                                [0.06943184420297374, 0.019841819196987055, 0.9107263366000392],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.9518904190545656, 0.0015909034188734625, 0.046518677526560935],
                                [0.9376047047688514, 0.014285714285714285, 0.0481095809454344],
                                [0.9305681557970262, 0.007036548971825031, 0.06239529523114868],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.7713352153202959, 0.007561562178966112, 0.221103222500738],
                                [0.703435231222666, 0.06789998409762983, 0.22866478467970414],
                                [0.6699905217924281, 0.03344470943023792, 0.29656476877733395],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924282, 0.10134469352786774, 0.22866478467970414],
                                [0.5357610962108633, 0.015351604497446688, 0.44888729929169],
                                [0.3979094623052017, 0.13785163390566152, 0.46423890378913685],
                                [0.3300094782075719, 0.06789998409762982, 0.6020905376947983],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.20575161800329134, 0.4642389037891368],
                                [0.35520589247659357, 0.021322263257539335, 0.6234718442658671],
                                [0.16373998875901646, 0.19146590371757705, 0.6447941075234065],
                                [0.06943184420297382, 0.0943081445560427, 0.8362600112409835],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.9518904190545656, 0.0015909034188734625, 0.046518677526560935],
                                [0.9448538700827406, 0.007036548971825031, 0.048109580945434396],
                                [0.9305681557970263, 0.014285714285714285, 0.05514612991725943],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.7713352153202959, 0.007561562178966112, 0.221103222500738],
                                [0.737890505890058, 0.03344470943023792, 0.22866478467970414],
                                [0.6699905217924281, 0.06789998409762983, 0.26210949410994205],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924282, 0.10134469352786774, 0.22866478467970414],
                                [0.5357610962108633, 0.015351604497446688, 0.44888729929169],
                                [0.4678611121132334, 0.06789998409762982, 0.46423890378913685],
                                [0.3300094782075719, 0.13785163390566152, 0.5321388878867666],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.20575161800329134, 0.4642389037891368],
                                [0.35520589247659357, 0.021322263257539335, 0.6234718442658671],
                                [0.2608977479205508, 0.0943081445560427, 0.6447941075234065],
                                [0.06943184420297371, 0.19146590371757705, 0.7391022520794492],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.9518904190545656, 0.0015909034188734625, 0.046518677526560935],
                                [0.9504099749940134, 0.0014804440605522616, 0.048109580945434396],
                                [0.9305681557970263, 0.019841819196987055, 0.04959002500598666],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.7713352153202959, 0.007561562178966112, 0.221103222500738],
                                [0.7642986663484709, 0.007036548971825036, 0.22866478467970414],
                                [0.669990521792428, 0.09430814455604271, 0.23570133365152918],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6699905217924282, 0.10134469352786774, 0.22866478467970414],
                                [0.5357610962108633, 0.015351604497446688, 0.44888729929169],
                                [0.5214753819251489, 0.014285714285714296, 0.4642389037891368],
                                [0.3300094782075719, 0.19146590371757705, 0.4785246180748511],
                                [0.33000947820757187, 0.22110322250073802, 0.44888729929169013],
                                [0.33000947820757187, 0.20575161800329134, 0.4642389037891368],
                                [0.35520589247659357, 0.021322263257539335, 0.6234718442658671],
                                [0.33536407327960643, 0.01984181919698707, 0.6447941075234065],
                                [0.06943184420297371, 0.26593222907663266, 0.6646359267203936],
                                [0.06943184420297382, 0.30709631153115907, 0.6234718442658671],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.9337980333675788, 0.04328879995600838, 0.02291316667641278],
                                [0.9307924121532996, 0.0030056212142792692, 0.06620196663242116],
                                [0.9305681557970262, 0.00022425635627328414, 0.06920758784670043],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970262, 0.0032298775705525535, 0.06620196663242116],
                                [0.6853421262898748, 0.20575161800329134, 0.10890625570683388],
                                [0.6710564120041607, 0.014285714285714285, 0.31465787371012516],
                                [0.669990521792428, 0.001065890211732388, 0.3289435879958395],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.015351604497446674, 0.3146578737101252],
                                [0.3611765512366861, 0.4177202262625759, 0.221103222500738],
                                [0.33217346556639205, 0.029003085670294092, 0.6388234487633139],
                                [0.33000947820757187, 0.0021639873588201654, 0.667826534433608],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.03116707302911426, 0.6388234487633139],
                                [0.11272064415898209, 0.5801830443098588, 0.3070963115311591],
                                [0.0724374654172531, 0.040283178741729105, 0.8872793558410178],
                                [0.06943184420297377, 0.0030056212142792692, 0.927562534582747],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297382, 0.04328879995600838, 0.8872793558410178],
                                [0.9337980333675788, 0.04328879995600838, 0.02291316667641278],
                                [0.9316340460087587, 0.0021639873588201654, 0.06620196663242117],
                                [0.9305681557970262, 0.001065890211732388, 0.06836595399124133],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970262, 0.0032298775705525535, 0.06620196663242116],
                                [0.6853421262898748, 0.20575161800329134, 0.10890625570683388],
                                [0.6750566967822795, 0.010285429507595284, 0.3146578737101252],
                                [0.6699905217924281, 0.005066174989851391, 0.32494330321772047],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.015351604497446674, 0.3146578737101252],
                                [0.3611765512366861, 0.4177202262625759, 0.221103222500738],
                                [0.3402949077151671, 0.02088164352151898, 0.6388234487633139],
                                [0.33000947820757187, 0.010285429507595284, 0.6597050922848329],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.03116707302911426, 0.6388234487633139],
                                [0.11272064415898209, 0.5801830443098588, 0.3070963115311591],
                                [0.08371755848868799, 0.029003085670294096, 0.8872793558410179],
                                [0.06943184420297371, 0.014285714285714285, 0.916282441511312],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297382, 0.04328879995600838, 0.8872793558410178],
                                [0.9337980333675788, 0.04328879995600838, 0.02291316667641278],
                                [0.9327321431558464, 0.0010658902117323882, 0.06620196663242117],
                                [0.9305681557970262, 0.0021639873588201654, 0.06726785684415355],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970262, 0.0032298775705525535, 0.06620196663242116],
                                [0.6853421262898748, 0.20575161800329134, 0.10890625570683388],
                                [0.6802759513000234, 0.005066174989851391, 0.3146578737101252],
                                [0.6699905217924281, 0.010285429507595284, 0.3197240486999766],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.015351604497446674, 0.3146578737101252],
                                [0.3611765512366861, 0.4177202262625759, 0.221103222500738],
                                [0.35089112172909087, 0.010285429507595284, 0.6388234487633139],
                                [0.33000947820757187, 0.020881643521518976, 0.6491088782709091],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.03116707302911426, 0.6388234487633139],
                                [0.11272064415898209, 0.5801830443098588, 0.3070963115311591],
                                [0.0984349298732678, 0.014285714285714287, 0.8872793558410179],
                                [0.06943184420297376, 0.029003085670294092, 0.9015650701267321],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297382, 0.04328879995600838, 0.8872793558410178],
                                [0.9337980333675788, 0.04328879995600838, 0.02291316667641278],
                                [0.9335737770113055, 0.00022425635627328427, 0.06620196663242116],
                                [0.9305681557970262, 0.0030056212142792692, 0.06642622298869444],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970262, 0.0032298775705525535, 0.06620196663242116],
                                [0.6853421262898748, 0.20575161800329134, 0.10890625570683388],
                                [0.6842762360781424, 0.001065890211732389, 0.3146578737101252],
                                [0.6699905217924282, 0.014285714285714285, 0.3157237639218576],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.015351604497446674, 0.3146578737101252],
                                [0.3611765512366861, 0.4177202262625759, 0.221103222500738],
                                [0.35901256387786595, 0.0021639873588201668, 0.6388234487633139],
                                [0.33000947820757187, 0.029003085670294092, 0.640987436122134],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.03116707302911426, 0.6388234487633139],
                                [0.11272064415898209, 0.5801830443098588, 0.3070963115311591],
                                [0.10971502294470292, 0.0030056212142792714, 0.8872793558410178],
                                [0.06943184420297382, 0.040283178741729105, 0.8902849770552971],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297382, 0.04328879995600838, 0.8872793558410178],
                                [0.945919760294473, 0.031167073029114263, 0.02291316667641278],
                                [0.9316340460087588, 0.014285714285714285, 0.05408023970552705],
                                [0.9305681557970262, 0.001065890211732388, 0.06836595399124133],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970263, 0.015351604497446674, 0.05408023970552704],
                                [0.7429566808799093, 0.1481370634132568, 0.10890625570683385],
                                [0.6750566967822794, 0.06789998409762983, 0.25704331912009065],
                                [0.6699905217924281, 0.005066174989851391, 0.32494330321772047],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.4781465416208287, 0.3007502358784333, 0.221103222500738],
                                [0.34029490771516707, 0.13785163390566152, 0.5218534583791714],
                                [0.33000947820757187, 0.010285429507595284, 0.6597050922848329],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.1481370634132568, 0.5218534583791713],
                                [0.27518346220626505, 0.4177202262625758, 0.30709631153115907],
                                [0.08371755848868795, 0.19146590371757705, 0.724816537793735],
                                [0.06943184420297371, 0.014285714285714285, 0.916282441511312],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.945919760294473, 0.031167073029114263, 0.02291316667641278],
                                [0.9356343307868777, 0.010285429507595284, 0.05408023970552704],
                                [0.9305681557970262, 0.005066174989851391, 0.06436566921312233],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970263, 0.015351604497446674, 0.05408023970552704],
                                [0.7429566808799093, 0.1481370634132568, 0.10890625570683385],
                                [0.6940700458796984, 0.048886635000210864, 0.25704331912009065],
                                [0.6699905217924281, 0.024079524087270356, 0.3059299541203015],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.4781465416208287, 0.3007502358784333, 0.221103222500738],
                                [0.3788961132077829, 0.09925042841304595, 0.5218534583791712],
                                [0.33000947820757187, 0.048886635000210864, 0.6211038867922173],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.1481370634132568, 0.5218534583791713],
                                [0.27518346220626505, 0.4177202262625758, 0.30709631153115907],
                                [0.1373318283006037, 0.13785163390566152, 0.7248165377937348],
                                [0.06943184420297381, 0.06789998409762983, 0.8626681716993964],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.945919760294473, 0.031167073029114263, 0.02291316667641278],
                                [0.9408535853046216, 0.005066174989851391, 0.05408023970552704],
                                [0.9305681557970263, 0.010285429507595284, 0.05914641469537843],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970263, 0.015351604497446674, 0.05408023970552704],
                                [0.7429566808799093, 0.1481370634132568, 0.10890625570683385],
                                [0.7188771567926391, 0.024079524087270356, 0.2570433191200906],
                                [0.6699905217924281, 0.048886635000210864, 0.28112284320736103],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.4781465416208287, 0.3007502358784333, 0.221103222500738],
                                [0.42925990662061786, 0.048886635000210864, 0.5218534583791713],
                                [0.3300094782075719, 0.09925042841304595, 0.5707400933793821],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.1481370634132568, 0.5218534583791713],
                                [0.27518346220626505, 0.4177202262625758, 0.30709631153115907],
                                [0.2072834781086354, 0.06789998409762983, 0.7248165377937348],
                                [0.06943184420297371, 0.13785163390566152, 0.7927165218913648],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.945919760294473, 0.031167073029114263, 0.02291316667641278],
                                [0.9448538700827406, 0.001065890211732389, 0.05408023970552704],
                                [0.9305681557970263, 0.014285714285714285, 0.05514612991725943],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970263, 0.015351604497446674, 0.05408023970552704],
                                [0.7429566808799093, 0.1481370634132568, 0.10890625570683385],
                                [0.7378905058900579, 0.005066174989851394, 0.25704331912009065],
                                [0.6699905217924281, 0.06789998409762983, 0.26210949410994205],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.669990521792428, 0.07296615908748122, 0.25704331912009065],
                                [0.4781465416208287, 0.3007502358784333, 0.221103222500738],
                                [0.4678611121132333, 0.010285429507595291, 0.5218534583791714],
                                [0.3300094782075719, 0.13785163390566152, 0.5321388878867666],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.1481370634132568, 0.5218534583791713],
                                [0.27518346220626505, 0.4177202262625758, 0.30709631153115907],
                                [0.2608977479205508, 0.014285714285714296, 0.7248165377937349],
                                [0.06943184420297371, 0.19146590371757705, 0.7391022520794492],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297377, 0.20575161800329134, 0.7248165377937349],
                                [0.9617352288261406, 0.015351604497446672, 0.02291316667641278],
                                [0.9327321431558464, 0.029003085670294096, 0.03826477117385946],
                                [0.9305681557970262, 0.0021639873588201654, 0.06726785684415355],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.818127585205685, 0.0729661590874812, 0.10890625570683386],
                                [0.6802759513000234, 0.13785163390566152, 0.1818724147943151],
                                [0.6699905217924281, 0.010285429507595284, 0.3197240486999766],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.6307597140860051, 0.14813706341325678, 0.22110322250073805],
                                [0.3508911217290909, 0.27986859235691436, 0.36924028591399477],
                                [0.33000947820757187, 0.02088164352151898, 0.6491088782709091],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.48715207046554965, 0.2057516180032913, 0.307096311531159],
                                [0.0984349298732679, 0.38871714059228174, 0.5128479295344504],
                                [0.06943184420297376, 0.029003085670294096, 0.9015650701267321],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297382, 0.4177202262625758, 0.5128479295344504],
                                [0.9617352288261406, 0.015351604497446672, 0.02291316667641278],
                                [0.9408535853046215, 0.020881643521518976, 0.03826477117385946],
                                [0.9305681557970263, 0.010285429507595284, 0.05914641469537843],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.818127585205685, 0.0729661590874812, 0.10890625570683386],
                                [0.7188771567926391, 0.09925042841304593, 0.18187241479431504],
                                [0.6699905217924281, 0.048886635000210864, 0.28112284320736103],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.6307597140860051, 0.14813706341325678, 0.22110322250073805],
                                [0.4292599066206179, 0.20149980746538737, 0.36924028591399477],
                                [0.3300094782075719, 0.09925042841304595, 0.5707400933793821],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.48715207046554965, 0.2057516180032913, 0.307096311531159],
                                [0.20728347810863534, 0.2798685923569143, 0.5128479295344504],
                                [0.06943184420297371, 0.13785163390566152, 0.7927165218913648],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297382, 0.4177202262625758, 0.5128479295344504],
                                [0.9617352288261406, 0.015351604497446672, 0.02291316667641278],
                                [0.9514497993185453, 0.010285429507595286, 0.03826477117385945],
                                [0.9305681557970262, 0.020881643521518976, 0.04855020068145474],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.818127585205685, 0.0729661590874812, 0.10890625570683386],
                                [0.7692409502054741, 0.04888663500021087, 0.18187241479431507],
                                [0.669990521792428, 0.09925042841304593, 0.23075904979452594],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.6307597140860051, 0.14813706341325678, 0.22110322250073805],
                                [0.5315092856729592, 0.09925042841304596, 0.3692402859139948],
                                [0.3300094782075719, 0.20149980746538737, 0.46849071432704076],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.48715207046554965, 0.2057516180032913, 0.307096311531159],
                                [0.3493004365598881, 0.13785163390566155, 0.5128479295344504],
                                [0.06943184420297377, 0.2798685923569143, 0.6506995634401119],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297382, 0.4177202262625758, 0.5128479295344504],
                                [0.9617352288261406, 0.015351604497446672, 0.02291316667641278],
                                [0.9595712414673204, 0.002163987358820169, 0.03826477117385945],
                                [0.9305681557970263, 0.029003085670294092, 0.04042875853267962],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970263, 0.031167073029114263, 0.03826477117385945],
                                [0.818127585205685, 0.0729661590874812, 0.10890625570683386],
                                [0.8078421556980897, 0.010285429507595301, 0.18187241479431504],
                                [0.6699905217924282, 0.13785163390566152, 0.19215784430191035],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.1481370634132568, 0.18187241479431507],
                                [0.6307597140860051, 0.14813706341325678, 0.22110322250073805],
                                [0.6098780705644863, 0.02088164352151901, 0.36924028591399477],
                                [0.33000947820757187, 0.2798685923569143, 0.3901219294355138],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.3007502358784333, 0.3692402859139948],
                                [0.48715207046554965, 0.2057516180032913, 0.307096311531159],
                                [0.4581489847952556, 0.02900308567029414, 0.5128479295344502],
                                [0.06943184420297377, 0.3887171405922817, 0.5418510152047445],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297382, 0.4177202262625758, 0.5128479295344504],
                                [0.9738569557530347, 0.0032298775705525595, 0.02291316667641278],
                                [0.9335737770113055, 0.04028317874172911, 0.02614304424696534],
                                [0.9305681557970262, 0.003005621214279269, 0.06642622298869444],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970262, 0.04328879995600837, 0.02614304424696534],
                                [0.8757421397957195, 0.015351604497446703, 0.10890625570683386],
                                [0.6842762360781425, 0.19146590371757705, 0.12425786020428053],
                                [0.6699905217924282, 0.014285714285714284, 0.3157237639218576],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.2057516180032913, 0.12425786020428056],
                                [0.7477297044701475, 0.031167073029114322, 0.22110322250073805],
                                [0.3590125638778659, 0.38871714059228174, 0.2522702955298523],
                                [0.33000947820757187, 0.02900308567029409, 0.640987436122134],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.41772022626257577, 0.25227029552985236],
                                [0.6496148885128324, 0.04328879995600846, 0.30709631153115907],
                                [0.10971502294470281, 0.5398998655681296, 0.35038511148716756],
                                [0.06943184420297382, 0.040283178741729105, 0.8902849770552971],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297377, 0.5801830443098587, 0.35038511148716756],
                                [0.9738569557530347, 0.0032298775705525595, 0.02291316667641278],
                                [0.9448538700827406, 0.02900308567029409, 0.02614304424696534],
                                [0.9305681557970263, 0.014285714285714284, 0.05514612991725943],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970262, 0.04328879995600837, 0.02614304424696534],
                                [0.8757421397957195, 0.015351604497446703, 0.10890625570683386],
                                [0.737890505890058, 0.1378516339056615, 0.12425786020428056],
                                [0.6699905217924282, 0.06789998409762982, 0.26210949410994205],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.2057516180032913, 0.12425786020428056],
                                [0.7477297044701475, 0.031167073029114322, 0.22110322250073805],
                                [0.46786111211323334, 0.2798685923569143, 0.25227029552985236],
                                [0.33000947820757187, 0.1378516339056615, 0.5321388878867667],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.41772022626257577, 0.25227029552985236],
                                [0.6496148885128324, 0.04328879995600846, 0.30709631153115907],
                                [0.2608977479205507, 0.38871714059228163, 0.3503851114871676],
                                [0.06943184420297374, 0.19146590371757702, 0.7391022520794492],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297377, 0.5801830443098587, 0.35038511148716756],
                                [0.9738569557530347, 0.0032298775705525595, 0.02291316667641278],
                                [0.9595712414673204, 0.014285714285714285, 0.02614304424696534],
                                [0.9305681557970263, 0.02900308567029409, 0.040428758532679625],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970262, 0.04328879995600837, 0.02614304424696534],
                                [0.8757421397957195, 0.015351604497446703, 0.10890625570683386],
                                [0.8078421556980896, 0.06789998409762983, 0.12425786020428055],
                                [0.6699905217924281, 0.1378516339056615, 0.19215784430191038],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.2057516180032913, 0.12425786020428056],
                                [0.7477297044701475, 0.031167073029114322, 0.22110322250073805],
                                [0.6098780705644862, 0.13785163390566152, 0.2522702955298523],
                                [0.33000947820757187, 0.2798685923569143, 0.3901219294355138],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.41772022626257577, 0.25227029552985236],
                                [0.6496148885128324, 0.04328879995600846, 0.30709631153115907],
                                [0.4581489847952555, 0.19146590371757705, 0.3503851114871675],
                                [0.06943184420297371, 0.38871714059228163, 0.5418510152047447],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297377, 0.5801830443098587, 0.35038511148716756],
                                [0.9738569557530347, 0.0032298775705525595, 0.02291316667641278],
                                [0.9708513345387554, 0.0030056212142792727, 0.02614304424696534],
                                [0.9305681557970262, 0.040283178741729105, 0.02914866546124461],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9305681557970262, 0.04328879995600837, 0.02614304424696534],
                                [0.8757421397957195, 0.015351604497446703, 0.10890625570683386],
                                [0.8614564255100051, 0.014285714285714301, 0.12425786020428055],
                                [0.6699905217924281, 0.19146590371757702, 0.13854357448999485],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6699905217924281, 0.2057516180032913, 0.12425786020428056],
                                [0.7477297044701475, 0.031167073029114322, 0.22110322250073805],
                                [0.7187266187998536, 0.029003085670294127, 0.2522702955298523],
                                [0.33000947820757187, 0.3887171405922817, 0.28127338120014644],
                                [0.33000947820757187, 0.44888729929169013, 0.221103222500738],
                                [0.33000947820757187, 0.41772022626257577, 0.25227029552985236],
                                [0.6496148885128324, 0.04328879995600846, 0.30709631153115907],
                                [0.6093317097711033, 0.04028317874172915, 0.35038511148716756],
                                [0.06943184420297377, 0.5398998655681295, 0.3906682902288967],
                                [0.06943184420297377, 0.6234718442658671, 0.3070963115311591],
                                [0.06943184420297377, 0.5801830443098587, 0.35038511148716756],
                                [0.9350542210718578, 0.06012499793871617, 0.004820780989426017],
                                [0.9308796315822727, 0.004174589489585056, 0.06494577892814218],
                                [0.9305681557970262, 0.0003114757852464732, 0.06912036841772724],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.004486065274831529, 0.06494577892814218],
                                [0.6913127850499674, 0.28577404827361974, 0.0229131666764128],
                                [0.6714709658529804, 0.019841819196987055, 0.30868721495003254],
                                [0.6699905217924281, 0.0014804440605522605, 0.3285290341470196],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.021322263257539314, 0.30868721495003254],
                                [0.3732982781635803, 0.5801830443098588, 0.046518677526560914],
                                [0.3330150994218512, 0.040283178741729105, 0.6267017218364197],
                                [0.33000947820757187, 0.003005621214279269, 0.6669849005781489],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.3300094782075719, 0.04328879995600837, 0.6267017218364197],
                                [0.12955684214168994, 0.8058320946447624, 0.0646110632135477],
                                [0.07360643369255884, 0.0559504084491311, 0.8704431578583101],
                                [0.06943184420297376, 0.004174589489585056, 0.9263935663074412],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297378, 0.06012499793871616, 0.8704431578583101],
                                [0.9350542210718578, 0.06012499793871617, 0.004820780989426017],
                                [0.9320485998575785, 0.003005621214279269, 0.06494577892814218],
                                [0.9305681557970262, 0.0014804440605522605, 0.06795140014242146],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.004486065274831529, 0.06494577892814218],
                                [0.6913127850499674, 0.28577404827361974, 0.0229131666764128],
                                [0.6770270707642532, 0.014285714285714284, 0.30868721495003254],
                                [0.6699905217924281, 0.00703654897182503, 0.32297292923574683],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.021322263257539314, 0.30868721495003254],
                                [0.3732982781635803, 0.5801830443098588, 0.046518677526560914],
                                [0.3442951924932861, 0.02900308567029409, 0.6267017218364198],
                                [0.3300094782075718, 0.014285714285714284, 0.6557048075067139],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.3300094782075719, 0.04328879995600837, 0.6267017218364197],
                                [0.12955684214168994, 0.8058320946447624, 0.0646110632135477],
                                [0.08927366339996085, 0.040283178741729105, 0.8704431578583101],
                                [0.06943184420297374, 0.019841819196987052, 0.9107263366000392],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297378, 0.06012499793871616, 0.8704431578583101],
                                [0.9350542210718578, 0.06012499793871617, 0.004820780989426017],
                                [0.9335737770113055, 0.0014804440605522607, 0.0649457789281422],
                                [0.9305681557970262, 0.003005621214279269, 0.06642622298869444],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.004486065274831529, 0.06494577892814218],
                                [0.6913127850499674, 0.28577404827361974, 0.0229131666764128],
                                [0.6842762360781424, 0.007036548971825032, 0.30868721495003254],
                                [0.6699905217924282, 0.014285714285714284, 0.3157237639218576],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.021322263257539314, 0.30868721495003254],
                                [0.3732982781635803, 0.5801830443098588, 0.046518677526560914],
                                [0.3590125638778659, 0.014285714285714285, 0.6267017218364198],
                                [0.33000947820757187, 0.02900308567029409, 0.640987436122134],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.3300094782075719, 0.04328879995600837, 0.6267017218364197],
                                [0.12955684214168994, 0.8058320946447624, 0.0646110632135477],
                                [0.10971502294470278, 0.019841819196987055, 0.8704431578583102],
                                [0.06943184420297382, 0.040283178741729105, 0.8902849770552971],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297378, 0.06012499793871616, 0.8704431578583101],
                                [0.9350542210718578, 0.06012499793871617, 0.004820780989426017],
                                [0.9347427452866113, 0.00031147578524647323, 0.06494577892814218],
                                [0.9305681557970263, 0.004174589489585056, 0.06525725471338865],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.004486065274831529, 0.06494577892814218],
                                [0.6913127850499674, 0.28577404827361974, 0.0229131666764128],
                                [0.6898323409894151, 0.0014804440605522607, 0.30868721495003254],
                                [0.6699905217924281, 0.019841819196987055, 0.3101676590105848],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.021322263257539314, 0.30868721495003254],
                                [0.3732982781635803, 0.5801830443098588, 0.046518677526560914],
                                [0.370292656949301, 0.0030056212142792692, 0.6267017218364197],
                                [0.3300094782075719, 0.040283178741729105, 0.629707343050699],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.3300094782075719, 0.04328879995600837, 0.6267017218364197],
                                [0.12955684214168994, 0.8058320946447624, 0.0646110632135477],
                                [0.1253822526521049, 0.004174589489585057, 0.8704431578583101],
                                [0.0694318442029738, 0.0559504084491311, 0.8746177473478951],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297378, 0.06012499793871616, 0.8704431578583101],
                                [0.9518904190545656, 0.04328879995600837, 0.004820780989426024],
                                [0.9320485998575786, 0.019841819196987055, 0.0481095809454344],
                                [0.9305681557970262, 0.0014804440605522607, 0.06795140014242146],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.7713352153202958, 0.2057516180032913, 0.0229131666764128],
                                [0.6770270707642532, 0.09430814455604271, 0.22866478467970414],
                                [0.6699905217924281, 0.007036548971825032, 0.32297292923574683],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924282, 0.10134469352786774, 0.22866478467970414],
                                [0.5357610962108633, 0.41772022626257577, 0.04651867752656097],
                                [0.34429519249328616, 0.19146590371757705, 0.46423890378913685],
                                [0.3300094782075718, 0.014285714285714285, 0.6557048075067139],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.20575161800329134, 0.4642389037891368],
                                [0.3552058924765935, 0.5801830443098587, 0.06461106321354781],
                                [0.08927366339996085, 0.26593222907663266, 0.6447941075234065],
                                [0.06943184420297374, 0.019841819196987055, 0.9107263366000392],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.9518904190545656, 0.04328879995600837, 0.004820780989426024],
                                [0.9376047047688514, 0.014285714285714285, 0.0481095809454344],
                                [0.9305681557970262, 0.007036548971825031, 0.06239529523114868],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.7713352153202958, 0.2057516180032913, 0.0229131666764128],
                                [0.703435231222666, 0.06789998409762983, 0.22866478467970414],
                                [0.6699905217924281, 0.03344470943023792, 0.29656476877733395],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924282, 0.10134469352786774, 0.22866478467970414],
                                [0.5357610962108633, 0.41772022626257577, 0.04651867752656097],
                                [0.3979094623052017, 0.13785163390566152, 0.46423890378913685],
                                [0.3300094782075719, 0.06789998409762982, 0.6020905376947983],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.20575161800329134, 0.4642389037891368],
                                [0.3552058924765935, 0.5801830443098587, 0.06461106321354781],
                                [0.16373998875901646, 0.19146590371757705, 0.6447941075234065],
                                [0.06943184420297382, 0.0943081445560427, 0.8362600112409835],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.9518904190545656, 0.04328879995600837, 0.004820780989426024],
                                [0.9448538700827406, 0.007036548971825031, 0.048109580945434396],
                                [0.9305681557970263, 0.014285714285714285, 0.05514612991725943],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.7713352153202958, 0.2057516180032913, 0.0229131666764128],
                                [0.737890505890058, 0.03344470943023792, 0.22866478467970414],
                                [0.6699905217924281, 0.06789998409762983, 0.26210949410994205],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924282, 0.10134469352786774, 0.22866478467970414],
                                [0.5357610962108633, 0.41772022626257577, 0.04651867752656097],
                                [0.4678611121132334, 0.06789998409762982, 0.46423890378913685],
                                [0.3300094782075719, 0.13785163390566152, 0.5321388878867666],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.20575161800329134, 0.4642389037891368],
                                [0.3552058924765935, 0.5801830443098587, 0.06461106321354781],
                                [0.2608977479205508, 0.0943081445560427, 0.6447941075234065],
                                [0.06943184420297371, 0.19146590371757705, 0.7391022520794492],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.9518904190545656, 0.04328879995600837, 0.004820780989426024],
                                [0.9504099749940134, 0.0014804440605522616, 0.048109580945434396],
                                [0.9305681557970263, 0.019841819196987055, 0.04959002500598666],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970263, 0.021322263257539317, 0.048109580945434396],
                                [0.7713352153202958, 0.2057516180032913, 0.0229131666764128],
                                [0.7642986663484709, 0.007036548971825036, 0.22866478467970414],
                                [0.669990521792428, 0.09430814455604271, 0.23570133365152918],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924282, 0.10134469352786774, 0.22866478467970414],
                                [0.5357610962108633, 0.41772022626257577, 0.04651867752656097],
                                [0.5214753819251489, 0.014285714285714296, 0.4642389037891368],
                                [0.3300094782075719, 0.19146590371757705, 0.4785246180748511],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.20575161800329134, 0.4642389037891368],
                                [0.3552058924765935, 0.5801830443098587, 0.06461106321354781],
                                [0.33536407327960643, 0.01984181919698707, 0.6447941075234065],
                                [0.06943184420297371, 0.26593222907663266, 0.6646359267203936],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.28577404827361974, 0.6447941075234065],
                                [0.9738569557530347, 0.02132226325753932, 0.004820780989426017],
                                [0.9335737770113055, 0.04028317874172911, 0.02614304424696534],
                                [0.9305681557970262, 0.003005621214279269, 0.06642622298869444],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.04328879995600837, 0.02614304424696534],
                                [0.8757421397957194, 0.10134469352786776, 0.0229131666764128],
                                [0.6842762360781425, 0.19146590371757705, 0.12425786020428053],
                                [0.6699905217924282, 0.014285714285714284, 0.3157237639218576],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.2057516180032913, 0.12425786020428056],
                                [0.7477297044701476, 0.20575161800329136, 0.046518677526561],
                                [0.3590125638778659, 0.38871714059228174, 0.2522702955298523],
                                [0.33000947820757187, 0.02900308567029409, 0.640987436122134],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.41772022626257577, 0.25227029552985236],
                                [0.6496148885128326, 0.2857740482736198, 0.06461106321354776],
                                [0.10971502294470281, 0.5398998655681296, 0.35038511148716756],
                                [0.06943184420297382, 0.040283178741729105, 0.8902849770552971],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.5801830443098587, 0.35038511148716756],
                                [0.9738569557530347, 0.02132226325753932, 0.004820780989426017],
                                [0.9448538700827406, 0.02900308567029409, 0.02614304424696534],
                                [0.9305681557970263, 0.014285714285714284, 0.05514612991725943],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.04328879995600837, 0.02614304424696534],
                                [0.8757421397957194, 0.10134469352786776, 0.0229131666764128],
                                [0.737890505890058, 0.1378516339056615, 0.12425786020428056],
                                [0.6699905217924282, 0.06789998409762982, 0.26210949410994205],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.2057516180032913, 0.12425786020428056],
                                [0.7477297044701476, 0.20575161800329136, 0.046518677526561],
                                [0.46786111211323334, 0.2798685923569143, 0.25227029552985236],
                                [0.33000947820757187, 0.1378516339056615, 0.5321388878867667],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.41772022626257577, 0.25227029552985236],
                                [0.6496148885128326, 0.2857740482736198, 0.06461106321354776],
                                [0.2608977479205507, 0.38871714059228163, 0.3503851114871676],
                                [0.06943184420297374, 0.19146590371757702, 0.7391022520794492],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.5801830443098587, 0.35038511148716756],
                                [0.9738569557530347, 0.02132226325753932, 0.004820780989426017],
                                [0.9595712414673204, 0.014285714285714285, 0.02614304424696534],
                                [0.9305681557970263, 0.02900308567029409, 0.040428758532679625],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.04328879995600837, 0.02614304424696534],
                                [0.8757421397957194, 0.10134469352786776, 0.0229131666764128],
                                [0.8078421556980896, 0.06789998409762983, 0.12425786020428055],
                                [0.6699905217924281, 0.1378516339056615, 0.19215784430191038],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.2057516180032913, 0.12425786020428056],
                                [0.7477297044701476, 0.20575161800329136, 0.046518677526561],
                                [0.6098780705644862, 0.13785163390566152, 0.2522702955298523],
                                [0.33000947820757187, 0.2798685923569143, 0.3901219294355138],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.41772022626257577, 0.25227029552985236],
                                [0.6496148885128326, 0.2857740482736198, 0.06461106321354776],
                                [0.4581489847952555, 0.19146590371757705, 0.3503851114871675],
                                [0.06943184420297371, 0.38871714059228163, 0.5418510152047447],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.5801830443098587, 0.35038511148716756],
                                [0.9738569557530347, 0.02132226325753932, 0.004820780989426017],
                                [0.9708513345387554, 0.0030056212142792727, 0.02614304424696534],
                                [0.9305681557970262, 0.040283178741729105, 0.02914866546124461],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.04328879995600837, 0.02614304424696534],
                                [0.8757421397957194, 0.10134469352786776, 0.0229131666764128],
                                [0.8614564255100051, 0.014285714285714301, 0.12425786020428055],
                                [0.6699905217924281, 0.19146590371757702, 0.13854357448999485],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.2057516180032913, 0.12425786020428056],
                                [0.7477297044701476, 0.20575161800329136, 0.046518677526561],
                                [0.7187266187998536, 0.029003085670294127, 0.2522702955298523],
                                [0.33000947820757187, 0.3887171405922817, 0.28127338120014644],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.41772022626257577, 0.25227029552985236],
                                [0.6496148885128326, 0.2857740482736198, 0.06461106321354776],
                                [0.6093317097711033, 0.04028317874172915, 0.35038511148716756],
                                [0.06943184420297377, 0.5398998655681295, 0.3906682902288967],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.5801830443098587, 0.35038511148716756],
                                [0.9906931537357424, 0.00448606527483153, 0.004820780989426019],
                                [0.9347427452866113, 0.05595040844913111, 0.009306846264257547],
                                [0.9305681557970263, 0.004174589489585057, 0.06525725471338865],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257547],
                                [0.955764570066048, 0.02132226325753932, 0.022913166676412796],
                                [0.6898323409894153, 0.2659322290766327, 0.044235429933952075],
                                [0.6699905217924281, 0.019841819196987055, 0.3101676590105848],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395213],
                                [0.9101925225174307, 0.043288799956008386, 0.04651867752656097],
                                [0.370292656949301, 0.5398998655681296, 0.08980747748256934],
                                [0.3300094782075719, 0.04028317874172911, 0.629707343050699],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256934],
                                [0.8752639388477361, 0.06012499793871617, 0.06461106321354776],
                                [0.1253822526521049, 0.7498816861956312, 0.12473606115226388],
                                [0.0694318442029738, 0.05595040844913111, 0.8746177473478951],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226388],
                                [0.9906931537357424, 0.00448606527483153, 0.004820780989426019],
                                [0.9504099749940133, 0.04028317874172911, 0.009306846264257547],
                                [0.9305681557970263, 0.019841819196987055, 0.04959002500598666],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257547],
                                [0.955764570066048, 0.02132226325753932, 0.022913166676412796],
                                [0.7642986663484708, 0.19146590371757705, 0.04423542993395213],
                                [0.669990521792428, 0.09430814455604271, 0.23570133365152918],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395213],
                                [0.9101925225174307, 0.043288799956008386, 0.04651867752656097],
                                [0.521475381925149, 0.38871714059228174, 0.08980747748256934],
                                [0.3300094782075719, 0.19146590371757705, 0.4785246180748511],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256934],
                                [0.8752639388477361, 0.06012499793871617, 0.06461106321354776],
                                [0.3353640732796065, 0.5398998655681296, 0.12473606115226388],
                                [0.06943184420297371, 0.26593222907663266, 0.6646359267203936],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226388],
                                [0.9906931537357424, 0.00448606527483153, 0.004820780989426019],
                                [0.9708513345387554, 0.019841819196987055, 0.009306846264257547],
                                [0.9305681557970262, 0.04028317874172911, 0.029148665461244602],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257547],
                                [0.955764570066048, 0.02132226325753932, 0.022913166676412796],
                                [0.8614564255100051, 0.09430814455604271, 0.04423542993395212],
                                [0.6699905217924282, 0.19146590371757705, 0.13854357448999483],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395213],
                                [0.9101925225174307, 0.043288799956008386, 0.04651867752656097],
                                [0.7187266187998536, 0.19146590371757705, 0.08980747748256934],
                                [0.3300094782075718, 0.38871714059228174, 0.2812733812001464],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256934],
                                [0.8752639388477361, 0.06012499793871617, 0.06461106321354776],
                                [0.6093317097711035, 0.26593222907663266, 0.12473606115226393],
                                [0.06943184420297377, 0.5398998655681296, 0.3906682902288966],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226388],
                                [0.9906931537357424, 0.00448606527483153, 0.004820780989426019],
                                [0.9865185642461574, 0.004174589489585057, 0.00930684626425755],
                                [0.9305681557970262, 0.05595040844913111, 0.013481435753842606],
                                [0.9305681557970262, 0.06461106321354769, 0.004820780989426024],
                                [0.9305681557970262, 0.06012499793871617, 0.009306846264257547],
                                [0.955764570066048, 0.02132226325753932, 0.022913166676412796],
                                [0.9359227508690608, 0.01984181919698706, 0.04423542993395212],
                                [0.6699905217924281, 0.2659322290766327, 0.06407724913093915],
                                [0.669990521792428, 0.30709631153115907, 0.0229131666764128],
                                [0.6699905217924281, 0.28577404827361974, 0.04423542993395213],
                                [0.9101925225174307, 0.043288799956008386, 0.04651867752656097],
                                [0.8699093437757015, 0.04028317874172911, 0.08980747748256936],
                                [0.33000947820757187, 0.5398998655681296, 0.1300906562242985],
                                [0.33000947820757187, 0.6234718442658671, 0.046518677526561025],
                                [0.33000947820757187, 0.5801830443098588, 0.08980747748256934],
                                [0.8752639388477361, 0.06012499793871617, 0.06461106321354776],
                                [0.819313530398605, 0.055950408449131114, 0.12473606115226392],
                                [0.06943184420297377, 0.7498816861956312, 0.180686469601395],
                                [0.06943184420297377, 0.8659570925834785, 0.0646110632135477],
                                [0.06943184420297377, 0.8058320946447624, 0.12473606115226388],
                            ]
                        ),
                        np.array(
                            [
                                1.4766098088886122e-09,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                2.9724537228320815e-07,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.4873782832239316e-06,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                3.5549558129091802e-06,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.7682924241250887e-09,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                5.572644223575783e-07,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                4.663243069314803e-06,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                6.664697190643064e-06,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                2.7682924241250887e-09,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                1.922076483001256e-10,
                                5.572644223575783e-07,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                3.8691896552991514e-08,
                                4.663243069314803e-06,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                6.664697190643064e-06,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                4.627422170007258e-07,
                                1.4766098088886122e-09,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                1.0252374219933692e-10,
                                2.9724537228320815e-07,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.063829437842263e-08,
                                2.4873782832239316e-06,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                1.7270326143466425e-07,
                                3.5549558129091802e-06,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.4682713815036597e-07,
                                2.7682924241250887e-09,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                5.572644223575783e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                4.663243069314803e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                6.664697190643064e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                5.189890314514664e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.0447383387003483e-06,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                8.742472373493354e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                1.249472313598637e-05,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                5.189890314514664e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.7127129946475154e-09,
                                1.0447383387003483e-06,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                3.447735540179474e-07,
                                8.742472373493354e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                2.8850987462206542e-06,
                                1.249472313598637e-05,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                4.123377062454938e-06,
                                2.7682924241250887e-09,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                9.135627384114948e-10,
                                5.572644223575783e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                1.8390254124586836e-07,
                                4.663243069314803e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                1.5389144120596542e-06,
                                6.664697190643064e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.199413242295588e-06,
                                2.7682924241250887e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                5.572644223575783e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                4.663243069314803e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                6.664697190643064e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                5.189890314514664e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                1.0447383387003483e-06,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                8.742472373493354e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                1.249472313598637e-05,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                5.189890314514664e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                3.477177319867149e-09,
                                1.0447383387003483e-06,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                6.999647846824009e-07,
                                8.742472373493354e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                5.8573736272727e-06,
                                1.249472313598637e-05,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                8.371346073531431e-06,
                                2.7682924241250887e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                1.8547296857135938e-09,
                                5.572644223575783e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                3.7336188111170993e-07,
                                4.663243069314803e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                3.124328657255149e-06,
                                6.664697190643064e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                4.465283948347477e-06,
                                1.4766098088886122e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                2.9724537228320815e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.4873782832239316e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                3.5549558129091802e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                2.7682924241250887e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                5.572644223575783e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                4.663243069314803e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                6.664697190643064e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                2.7682924241250887e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                2.576084775824963e-09,
                                5.572644223575783e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                5.185725258045867e-07,
                                4.663243069314803e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                4.33946550304554e-06,
                                6.664697190643064e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                6.201954973642338e-06,
                                1.4766098088886122e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                1.3740860666892752e-09,
                                2.9724537228320815e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.7660707790478553e-07,
                                2.4873782832239316e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                2.3146750217892674e-06,
                                3.5549558129091802e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                3.3081286747588142e-06,
                                6.253848977465249e-08,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                1.2589159684024866e-05,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                0.0001053473168027877,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                0.00015056216369190655,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.1724480388607143e-07,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                2.3601682157060602e-05,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                0.00019750117956114839,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                0.0002822682706014907,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.1724480388607143e-07,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                8.140522957025919e-09,
                                2.3601682157060602e-05,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                1.6387083184571362e-06,
                                0.00019750117956114839,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                1.3712871129193192e-05,
                                0.0002822682706014907,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                1.959840658784553e-05,
                                6.253848977465249e-08,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                4.342162678722936e-09,
                                1.2589159684024866e-05,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                8.740885738275722e-07,
                                0.0001053473168027877,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                7.3144584874524705e-06,
                                0.00015056216369190655,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.0453808692319081e-05,
                                1.1724480388607143e-07,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                2.3601682157060602e-05,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                0.00019750117956114839,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                0.0002822682706014907,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                2.1980613999180528e-07,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                4.424754428603946e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                0.0003702677686709983,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.0005291859165320918,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                2.1980613999180528e-07,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                7.253810956551616e-08,
                                4.424754428603946e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                1.4602109001802312e-05,
                                0.0003702677686709983,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.00012219187313619806,
                                0.0005291859165320918,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                0.0001746363681895513,
                                1.1724480388607143e-07,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                3.869189655299153e-08,
                                2.3601682157060602e-05,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                7.788778813472528e-06,
                                0.00019750117956114839,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                0.0002822682706014907,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                9.315120469575166e-05,
                                1.1724480388607143e-07,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                2.3601682157060602e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                0.00019750117956114839,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.0002822682706014907,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                2.1980613999180528e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                4.424754428603946e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                0.0003702677686709983,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.0005291859165320918,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                2.1980613999180528e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                1.4726803042628913e-07,
                                4.424754428603946e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                2.964543528423715e-05,
                                0.0003702677686709983,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.00024807589553480023,
                                0.0005291859165320918,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                0.0003545495483425405,
                                1.1724480388607143e-07,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                7.85529073330799e-08,
                                2.3601682157060602e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                1.5812903343588074e-05,
                                0.00019750117956114839,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.00013232391834879385,
                                0.0002822682706014907,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                0.00018911706590573908,
                                6.253848977465249e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                1.2589159684024866e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                0.0001053473168027877,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                0.00015056216369190655,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                1.1724480388607143e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                2.3601682157060602e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                0.00019750117956114839,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.0002822682706014907,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                1.1724480388607143e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                1.091042809290455e-07,
                                2.3601682157060602e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                2.1962973838603464e-05,
                                0.00019750117956114839,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.00018378830843195518,
                                0.0002822682706014907,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                0.0002626698640136452,
                                6.253848977465249e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                5.819632709592955e-08,
                                1.2589159684024866e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                1.1715071110197292e-05,
                                0.0001053473168027877,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                9.803285831533523e-05,
                                0.00015056216369190655,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                0.00014010835499958746,
                                2.577697084021884e-07,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                5.1889708761322714e-05,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                0.0004342181467933992,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                0.0006205836624950858,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.832569353415016e-07,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                9.728087053826607e-05,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                0.0008140558182330742,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                0.0011634468639443668,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                4.832569353415016e-07,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                3.3553420244637684e-08,
                                9.728087053826607e-05,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                6.7543902471425454e-06,
                                0.0008140558182330742,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                5.65213967440831e-05,
                                0.0011634468639443668,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                8.078026139582363e-05,
                                2.577697084021884e-07,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                1.789742623402671e-08,
                                5.1889708761322714e-05,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                3.602798174453839e-06,
                                0.0004342181467933992,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                3.0148566718263263e-05,
                                0.0006205836624950858,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.308826816926962e-05,
                                4.832569353415016e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                9.728087053826607e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                0.0008140558182330742,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0011634468639443668,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                9.059918909916322e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                0.00018237851008593036,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                0.0015261611705842087,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.002181186336391349,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                9.059918909916322e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                2.9898591120643987e-07,
                                0.00018237851008593036,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                6.018663694973226e-05,
                                0.0015261611705842087,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.0005036476515651518,
                                0.002181186336391349,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                0.0007198121647459944,
                                4.832569353415016e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                1.5947936907223924e-07,
                                9.728087053826607e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                3.210360932591154e-05,
                                0.0008140558182330742,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0002686461358069348,
                                0.0011634468639443668,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                0.0003839484924925164,
                                4.832569353415016e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                9.728087053826607e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                0.0008140558182330742,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0011634468639443668,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                9.059918909916322e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                0.00018237851008593036,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0015261611705842087,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.002181186336391349,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                9.059918909916322e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                6.070059797851923e-07,
                                0.00018237851008593036,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0001221918731361981,
                                0.0015261611705842087,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.001022513519019057,
                                0.002181186336391349,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                0.0014613741716453547,
                                4.832569353415016e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                3.2377756626926237e-07,
                                9.728087053826607e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                6.517726121235454e-05,
                                0.0008140558182330742,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0005454096824261394,
                                0.0011634468639443668,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                0.0007794983714518505,
                                2.577697084021884e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                5.1889708761322714e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                0.0004342181467933992,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.0006205836624950858,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                4.832569353415016e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                9.728087053826607e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                0.0008140558182330742,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0011634468639443668,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                4.832569353415016e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                4.497035150968639e-07,
                                9.728087053826607e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                9.052648029112352e-05,
                                0.0008140558182330742,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0007575344214889911,
                                0.0011634468639443668,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                0.001082666602548543,
                                2.577697084021884e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                2.3987228216816167e-07,
                                5.1889708761322714e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                4.828691058686887e-05,
                                0.0004342181467933992,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.00040406958007513594,
                                0.0006205836624950858,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                0.0005774953943258162,
                                2.652434822884734e-07,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                5.339419876796936e-05,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                0.00044680786599109553,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                0.0006385768627037553,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.972684849766753e-07,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                0.00010010143170649138,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                0.0008376585493452809,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                0.0011971798376274525,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                4.972684849766753e-07,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                3.4526267975949294e-08,
                                0.00010010143170649138,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                6.950227010739723e-06,
                                0.0008376585493452809,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                5.816017789343051e-05,
                                0.0011971798376274525,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                8.312240396909065e-05,
                                2.652434822884734e-07,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                1.8416344138107503e-08,
                                5.339419876796936e-05,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                3.7072576902002594e-06,
                                0.00044680786599109553,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                3.10226941401569e-05,
                                0.0006385768627037553,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.433756924287087e-05,
                                4.972684849766753e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                0.00010010143170649138,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                0.0008376585493452809,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.0011971798376274525,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                9.322602162267855e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                0.00018766639187215283,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                0.0015704106814118267,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0022444276442358246,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                9.322602162267855e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                3.076547075106796e-07,
                                0.00018766639187215283,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                6.193168805882686e-05,
                                0.0015704106814118267,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0005182504095443143,
                                0.0022444276442358246,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                0.0007406823957489142,
                                4.972684849766753e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                1.641033132562224e-07,
                                0.00010010143170649138,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                3.303442124529011e-05,
                                0.0008376585493452809,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.00027643526078554773,
                                0.0011971798376274525,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                0.00039508069353606123,
                                4.972684849766753e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                0.00010010143170649138,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                0.0008376585493452809,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0011971798376274525,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                9.322602162267855e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                0.00018766639187215283,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.0015704106814118267,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0022444276442358246,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                9.322602162267855e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                6.246055087161059e-07,
                                0.00018766639187215283,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.00012573470381332596,
                                0.0015704106814118267,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0010521602718675123,
                                0.0022444276442358246,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                0.0015037452484869104,
                                4.972684849766753e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                3.331651717204529e-07,
                                0.00010010143170649138,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                6.706701046120127e-05,
                                0.0008376585493452809,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0005612232885597331,
                                0.0011971798376274525,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                0.0008020991440913913,
                                2.652434822884734e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                5.339419876796936e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                0.00044680786599109553,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0006385768627037553,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                4.972684849766753e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                0.00010010143170649138,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                0.0008376585493452809,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0011971798376274525,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                4.972684849766753e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                4.6274221700072593e-07,
                                0.00010010143170649138,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                9.315120469575164e-05,
                                0.0008376585493452809,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0007794983714518503,
                                0.0011971798376274525,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                0.0011140574336583617,
                                2.652434822884734e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                2.468271381503659e-07,
                                5.339419876796936e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                4.9686941077769096e-05,
                                0.00044680786599109553,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0004157851718509386,
                                0.0006385768627037553,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                                0.0005942392934608844,
                            ]
                        ),
                    )
                case 5:
                    return (
                        np.array(
                            [
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9530947654130792, 0.04680684881076711, 9.838577615361527e-05],
                                [0.9530947654130792, 0.044709521703644804, 0.002195712883275917],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7692584765486152, 0.2302575330380426, 0.0004839904133421038],
                                [0.7692584765486153, 0.21994012483967854, 0.010801398611706165],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5000516141099505, 0.4988997223364884, 0.0010486635535611507],
                                [0.5000516141099505, 0.47654496148466596, 0.023403424405383556],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.2308447516712857, 0.7675419116349341, 0.0016133366937801975],
                                [0.2308447516712857, 0.7331497981296533, 0.03600545019906094],
                                [0.046910077030668074, 0.9509925958622096, 0.002097327107122302],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.047008462806821694, 0.9509925958622096, 0.0019989413309686862],
                                [0.047008462806821694, 0.9083804012656871, 0.04461113592749119],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158174],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9531137444651057, 0.04680684881076711, 7.940672412719192e-05],
                                [0.9531137444651057, 0.04470952170364481, 0.002176733831249494],
                                [0.7692346550528415, 0.22826725929492694, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7693518404432169, 0.2302575330380426, 0.00039062651874043075],
                                [0.7693518404432169, 0.21994012483967856, 0.010708034717104494],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5002539059545579, 0.4988997223364884, 0.0008463717089536949],
                                [0.500253905954558, 0.47654496148466596, 0.023201132560776102],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.23115597146589895, 0.7675419116349341, 0.0013021168991669589],
                                [0.23115597146589895, 0.7331497981296533, 0.035694230404447705],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.0473940674440102, 0.9509925958622096, 0.0016133366937801977],
                                [0.0473940674440102, 0.9083804012656871, 0.04422553129030271],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9531415370792824, 0.04680684881076712, 5.1614109950452745e-05],
                                [0.9531415370792824, 0.04470952170364481, 0.0021489412170727544],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7694885610073995, 0.23025753303804264, 0.0002539059545579087],
                                [0.7694885610073994, 0.21994012483967856, 0.01057131415292197],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5005501388317558, 0.4988997223364884, 0.0005501388317558017],
                                [0.5005501388317558, 0.47654496148466596, 0.022904899683578207],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.23161171665611224, 0.767541911634934, 0.0008463717089536947],
                                [0.23161171665611224, 0.7331497981296533, 0.03523848521423444],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.04795874058422922, 0.9509925958622096, 0.0010486635535611507],
                                [0.04795874058422922, 0.9083804012656871, 0.04366085815008366],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9531693296934591, 0.04680684881076711, 2.3821495773713587e-05],
                                [0.9531693296934591, 0.04470952170364481, 0.002121148602896015],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7696252815715819, 0.23025753303804264, 0.0001171853903753867],
                                [0.7696252815715819, 0.2199401248396786, 0.010434593588739449],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5008463717089537, 0.4988997223364884, 0.00025390595455790875],
                                [0.5008463717089537, 0.476544961484666, 0.022608666806380313],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.23206746184632543, 0.7675419116349341, 0.0003906265187404308],
                                [0.23206746184632543, 0.7331497981296534, 0.03478274002402117],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528075],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.04852341372444824, 0.9509925958622096, 0.0004839904133421039],
                                [0.04852341372444824, 0.9083804012656872, 0.043096185009864604],
                                [0.953089922969332, 0.04481274992354572, 0.0020973271071223014],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9531931511892329, 0.04470952170364481, 0.002097327107122302],
                                [0.9531883087454855, 0.04680684881076712, 4.842443747290217e-06],
                                [0.9531883087454855, 0.04470952170364481, 0.0021021695508695918],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7697424669619575, 0.21994012483967856, 0.010317408198364061],
                                [0.7697186454661836, 0.23025753303804264, 2.3821495773713598e-05],
                                [0.7697186454661837, 0.21994012483967856, 0.010341229694137775],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5011002776635116, 0.47654496148466596, 0.022354760851822406],
                                [0.5010486635535611, 0.4988997223364884, 5.161410995045278e-05],
                                [0.5010486635535611, 0.476544961484666, 0.02240637496177286],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.23245808836506587, 0.7331497981296534, 0.03439211350528075],
                                [0.23237868164093867, 0.7675419116349341, 7.940672412719196e-05],
                                [0.23237868164093867, 0.7331497981296534, 0.03447152022940794],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.04900740413779037, 0.9083804012656871, 0.042612194596522504],
                                [0.04890901836163675, 0.9509925958622096, 9.838577615361534e-05],
                                [0.04890901836163675, 0.9083804012656871, 0.042710580372676124],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.9531137444651057, 0.0464022651215522, 0.0004839904133421039],
                                [0.9531137444651057, 0.04470952170364481, 0.002176733831249494],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7693518404432169, 0.22826725929492694, 0.002380900261856123],
                                [0.7693518404432169, 0.21994012483967856, 0.010708034717104494],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5002539059545579, 0.49458738994626006, 0.005158704099182031],
                                [0.500253905954558, 0.47654496148466596, 0.023201132560776102],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.23115597146589895, 0.7609075205975931, 0.007936507936507938],
                                [0.23115597146589895, 0.7331497981296533, 0.035694230404447705],
                                [0.046910077030668074, 0.9509925958622096, 0.002097327107122302],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.0473940674440102, 0.9427725147709678, 0.009833417785021958],
                                [0.0473940674440102, 0.9083804012656871, 0.04422553129030271],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158174],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.9532071083597073, 0.0464022651215522, 0.0003906265187404308],
                                [0.9532071083597073, 0.044709521703644804, 0.0020833699366478203],
                                [0.7692346550528415, 0.22826725929492694, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7698111266500862, 0.22826725929492694, 0.0019216140549867585],
                                [0.7698111266500862, 0.21994012483967856, 0.010248748510235129],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5012490428261157, 0.49458738994626006, 0.004163567227624185],
                                [0.5012490428261158, 0.47654496148466596, 0.022205995689218255],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.2326869590021453, 0.760907520597593, 0.006405520400261612],
                                [0.2326869590021453, 0.7331497981296533, 0.034163242868201375],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.049290977292524185, 0.9427725147709679, 0.00793650793650794],
                                [0.049290977292524185, 0.9083804012656871, 0.042328621441788686],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.9533438289238899, 0.0464022651215522, 0.00025390595455790875],
                                [0.9533438289238899, 0.04470952170364481, 0.0019466493724652984],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7704836978789573, 0.22826725929492692, 0.001249042826115755],
                                [0.7704836978789573, 0.21994012483967856, 0.009576177281364125],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.50270630502687, 0.49458738994626006, 0.00270630502686997],
                                [0.50270630502687, 0.47654496148466596, 0.02074873348846404],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.23492891217478273, 0.760907520597593, 0.004163567227624184],
                                [0.23492891217478273, 0.7331497981296533, 0.03192128969556395],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.05206878112985014, 0.9427725147709678, 0.005158704099182031],
                                [0.05206878112985014, 0.9083804012656871, 0.039550817604462774],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.9534805494880724, 0.046402265121552204, 0.00011718539037538673],
                                [0.9534805494880724, 0.04470952170364481, 0.0018099288082827766],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7711562691078283, 0.22826725929492694, 0.0005764715972447519],
                                [0.7711562691078284, 0.21994012483967856, 0.008903606052493122],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5041635672276242, 0.49458738994626006, 0.0012490428261157554],
                                [0.5041635672276241, 0.476544961484666, 0.019291471287709826],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.23717086534742005, 0.7609075205975931, 0.0019216140549867587],
                                [0.23717086534742005, 0.7331497981296534, 0.02967933652292653],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528075],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.05484658496717598, 0.9427725147709679, 0.002380900261856124],
                                [0.05484658496717598, 0.9083804012656871, 0.036773013767136875],
                                [0.953089922969332, 0.04481274992354572, 0.0020973271071223014],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9535977348784478, 0.04470952170364481, 0.0016927434179073895],
                                [0.953573913382674, 0.046402265121552204, 2.3821495773713598e-05],
                                [0.953573913382674, 0.04470952170364481, 0.0017165649136811033],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7717327407050731, 0.21994012483967856, 0.008327134455248368],
                                [0.7716155553146976, 0.22826725929492694, 0.00011718539037538676],
                                [0.7716155553146976, 0.2199401248396786, 0.008444319845623756],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5054126100537399, 0.47654496148466596, 0.018042428461594068],
                                [0.5051587040991821, 0.49458738994626006, 0.00025390595455790886],
                                [0.5051587040991821, 0.476544961484666, 0.01829633441615198],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.23909247940240685, 0.7331497981296534, 0.027757722467939765],
                                [0.2387018528836664, 0.7609075205975931, 0.00039062651874043096],
                                [0.2387018528836664, 0.7331497981296534, 0.0281483489866802],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.05722748522903209, 0.9083804012656872, 0.03439211350528074],
                                [0.056743494815689965, 0.9427725147709679, 0.0004839904133421041],
                                [0.056743494815689965, 0.9083804012656872, 0.03487610391862285],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9531415370792824, 0.045809799367156415, 0.001048663553561151],
                                [0.9531415370792824, 0.04470952170364481, 0.0021489412170727544],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7694885610073994, 0.2253527348934185, 0.005158704099182031],
                                [0.7694885610073994, 0.21994012483967856, 0.01057131415292197],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.5005501388317558, 0.488272480742333, 0.011177380425911203],
                                [0.5005501388317558, 0.47654496148466596, 0.022904899683578207],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.23161171665611224, 0.7511922265912474, 0.017196056752640375],
                                [0.23161171665611224, 0.7331497981296533, 0.03523848521423444],
                                [0.046910077030668074, 0.9509925958622096, 0.002097327107122302],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.04795874058422922, 0.9307351621175095, 0.021306097298261252],
                                [0.04795874058422922, 0.9083804012656871, 0.04366085815008366],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158174],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9533438289238898, 0.045809799367156415, 0.0008463717089536947],
                                [0.9533438289238899, 0.04470952170364481, 0.0019466493724652984],
                                [0.7692346550528415, 0.22826725929492694, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7704836978789573, 0.2253527348934185, 0.004163567227624184],
                                [0.7704836978789573, 0.21994012483967856, 0.009576177281364125],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.50270630502687, 0.488272480742333, 0.009021214230797034],
                                [0.50270630502687, 0.47654496148466596, 0.02074873348846404],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.23492891217478273, 0.7511922265912474, 0.013878861233969883],
                                [0.23492891217478273, 0.7331497981296533, 0.03192128969556395],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.05206878112985014, 0.9307351621175095, 0.01719605675264037],
                                [0.05206878112985014, 0.9083804012656871, 0.039550817604462774],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9536400618010877, 0.045809799367156415, 0.0005501388317558017],
                                [0.9536400618010877, 0.04470952170364481, 0.0016504164952674055],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7719409600797116, 0.2253527348934185, 0.00270630502686997],
                                [0.7719409600797116, 0.21994012483967856, 0.00811891508060991],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.5058637596288336, 0.488272480742333, 0.005863759628833502],
                                [0.5058637596288336, 0.47654496148466596, 0.017591278886500507],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.23978655917795555, 0.7511922265912474, 0.009021214230797034],
                                [0.23978655917795555, 0.7331497981296533, 0.0270636426923911],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.05808745745657928, 0.9307351621175095, 0.011177380425911203],
                                [0.05808745745657928, 0.9083804012656871, 0.03353214127773361],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9539362946782857, 0.045809799367156415, 0.0002539059545579088],
                                [0.9539362946782857, 0.04470952170364481, 0.0013541836180695124],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7733982222804658, 0.22535273489341848, 0.0012490428261157554],
                                [0.7733982222804658, 0.21994012483967854, 0.006661652879855695],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.509021214230797, 0.488272480742333, 0.0027063050268699707],
                                [0.509021214230797, 0.47654496148466596, 0.014433824284536975],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.24464420618112837, 0.7511922265912474, 0.004163567227624186],
                                [0.24464420618112837, 0.7331497981296534, 0.022205995689218255],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528075],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.06410613378330843, 0.9307351621175095, 0.0051587040991820324],
                                [0.06410613378330843, 0.9083804012656871, 0.027513464951004436],
                                [0.953089922969332, 0.04481274992354572, 0.0020973271071223014],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9541902006328435, 0.04470952170364481, 0.0011002776635116035],
                                [0.9541385865228931, 0.045809799367156415, 5.1614109950452745e-05],
                                [0.9541385865228931, 0.04470952170364481, 0.0011518917734620563],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7746472651065814, 0.21994012483967856, 0.00541261005373994],
                                [0.7743933591520236, 0.2253527348934185, 0.0002539059545579087],
                                [0.7743933591520236, 0.21994012483967856, 0.005666516008297848],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.511727519257667, 0.47654496148466596, 0.011727519257667005],
                                [0.5111773804259112, 0.488272480742333, 0.0005501388317558017],
                                [0.5111773804259112, 0.47654496148466596, 0.012277658089422806],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2488077734087526, 0.7331497981296533, 0.018042428461594068],
                                [0.24796140169979886, 0.7511922265912474, 0.0008463717089536947],
                                [0.24796140169979886, 0.7331497981296534, 0.018888800170547764],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.0692648378824905, 0.9083804012656871, 0.022354760851822406],
                                [0.06821617432892935, 0.9307351621175095, 0.0010486635535611507],
                                [0.06821617432892935, 0.9083804012656871, 0.023403424405383556],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.9531693296934592, 0.045217333612760625, 0.0016133366937801975],
                                [0.9531693296934591, 0.04470952170364481, 0.002121148602896015],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.769625281571582, 0.2224382104919101, 0.007936507936507938],
                                [0.7696252815715819, 0.2199401248396786, 0.010434593588739449],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.5008463717089537, 0.48195757153840596, 0.01719605675264037],
                                [0.5008463717089537, 0.476544961484666, 0.022608666806380313],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.23206746184632543, 0.7414769325849018, 0.026455605568772803],
                                [0.23206746184632543, 0.7331497981296534, 0.03478274002402117],
                                [0.046910077030668074, 0.9509925958622096, 0.002097327107122302],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.04852341372444824, 0.9186978094640512, 0.03277877681150054],
                                [0.04852341372444824, 0.9083804012656872, 0.043096185009864604],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158174],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.9534805494880725, 0.045217333612760625, 0.0013021168991669589],
                                [0.9534805494880724, 0.04470952170364481, 0.0018099288082827766],
                                [0.7692346550528415, 0.22826725929492694, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7711562691078282, 0.2224382104919101, 0.006405520400261611],
                                [0.7711562691078284, 0.21994012483967856, 0.008903606052493122],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.5041635672276241, 0.48195757153840596, 0.013878861233969884],
                                [0.5041635672276241, 0.476544961484666, 0.019291471287709826],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.23717086534742005, 0.7414769325849018, 0.021352202067678155],
                                [0.23717086534742005, 0.7331497981296534, 0.02967933652292653],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.05484658496717598, 0.9186978094640512, 0.026455605568772807],
                                [0.05484658496717598, 0.9083804012656871, 0.036773013767136875],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.9539362946782857, 0.04521733361276063, 0.0008463717089536947],
                                [0.9539362946782857, 0.04470952170364481, 0.0013541836180695124],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7733982222804657, 0.22243821049191007, 0.004163567227624184],
                                [0.7733982222804658, 0.21994012483967854, 0.006661652879855695],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.509021214230797, 0.4819575715384059, 0.009021214230797034],
                                [0.509021214230797, 0.47654496148466596, 0.014433824284536975],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.24464420618112837, 0.7414769325849018, 0.013878861233969883],
                                [0.24464420618112837, 0.7331497981296534, 0.022205995689218255],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.06410613378330843, 0.9186978094640512, 0.01719605675264037],
                                [0.06410613378330843, 0.9083804012656871, 0.027513464951004436],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.954392039868499, 0.04521733361276063, 0.0003906265187404308],
                                [0.954392039868499, 0.04470952170364481, 0.0008984384278562485],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.775640175453103, 0.2224382104919101, 0.0019216140549867585],
                                [0.7756401754531033, 0.21994012483967856, 0.004419699707218269],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.5138788612339698, 0.48195757153840596, 0.004163567227624185],
                                [0.5138788612339698, 0.476544961484666, 0.009576177281364126],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.2521175470148366, 0.7414769325849018, 0.006405520400261612],
                                [0.2521175470148366, 0.7331497981296534, 0.014732654855509982],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528075],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.07336568259944087, 0.9186978094640512, 0.00793650793650794],
                                [0.07336568259944087, 0.9083804012656871, 0.018253916134872004],
                                [0.953089922969332, 0.04481274992354572, 0.0020973271071223014],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9547826663872393, 0.04470952170364481, 0.0005078119091158176],
                                [0.9547032596631122, 0.04521733361276063, 7.940672412719205e-05],
                                [0.9547032596631122, 0.04470952170364482, 0.0005872186332430097],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.77756178950809, 0.21994012483967856, 0.0024980856522315107],
                                [0.7771711629893495, 0.22243821049191007, 0.00039062651874043145],
                                [0.7771711629893494, 0.21994012483967856, 0.002888712170971942],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5180424284615941, 0.47654496148466596, 0.005412610053739941],
                                [0.5171960567526404, 0.48195757153840596, 0.0008463717089536964],
                                [0.5171960567526404, 0.476544961484666, 0.006258981762693638],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.25852306741509834, 0.7331497981296533, 0.008327134455248372],
                                [0.2572209505159313, 0.7414769325849018, 0.0013021168991669612],
                                [0.2572209505159313, 0.7331497981296534, 0.009629251354415332],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.08130219053594889, 0.9083804012656871, 0.010317408198364065],
                                [0.07968885384216862, 0.9186978094640512, 0.0016133366937802005],
                                [0.07968885384216862, 0.9083804012656871, 0.011930744892144265],
                                [0.9530899229693319, 0.04680684881076711, 0.00010322821990090549],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9531883087454857, 0.04481274992354572, 0.0019989413309686867],
                                [0.9531883087454855, 0.04470952170364481, 0.0021021695508695918],
                                [0.7692346550528415, 0.23025753303804264, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7697186454661836, 0.2204479367487944, 0.009833417785021958],
                                [0.7697186454661837, 0.21994012483967856, 0.010341229694137775],
                                [0.5, 0.4988997223364884, 0.0011002776635116035],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5010486635535611, 0.4776452391481776, 0.021306097298261256],
                                [0.5010486635535611, 0.476544961484666, 0.02240637496177286],
                                [0.2307653449471585, 0.7675419116349341, 0.0016927434179073895],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.23237868164093867, 0.7348425415475608, 0.03277877681150055],
                                [0.23237868164093867, 0.7331497981296534, 0.03447152022940794],
                                [0.046910077030668074, 0.9509925958622096, 0.002097327107122302],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.04890901836163675, 0.9104777283728094, 0.040613253265553824],
                                [0.04890901836163675, 0.9083804012656871, 0.042710580372676124],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158174],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9535739133826742, 0.04481274992354572, 0.001613336693780198],
                                [0.953573913382674, 0.04470952170364481, 0.0017165649136811033],
                                [0.7692346550528415, 0.22826725929492694, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7716155553146977, 0.2204479367487944, 0.00793650793650794],
                                [0.7716155553146976, 0.2199401248396786, 0.008444319845623756],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5051587040991821, 0.47764523914817764, 0.017196056752640375],
                                [0.5051587040991821, 0.476544961484666, 0.01829633441615198],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.2387018528836664, 0.7348425415475608, 0.02645560556877281],
                                [0.2387018528836664, 0.7331497981296534, 0.0281483489866802],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.056743494815689965, 0.9104777283728095, 0.03277877681150055],
                                [0.056743494815689965, 0.9083804012656872, 0.03487610391862285],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9541385865228932, 0.04481274992354571, 0.001048663553561151],
                                [0.9541385865228931, 0.04470952170364481, 0.0011518917734620563],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7743933591520236, 0.22044793674879437, 0.005158704099182031],
                                [0.7743933591520236, 0.21994012483967856, 0.005666516008297848],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5111773804259112, 0.4776452391481776, 0.011177380425911203],
                                [0.5111773804259112, 0.47654496148466596, 0.012277658089422806],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.24796140169979886, 0.7348425415475608, 0.017196056752640375],
                                [0.24796140169979886, 0.7331497981296534, 0.018888800170547764],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.06821617432892935, 0.9104777283728094, 0.021306097298261252],
                                [0.06821617432892935, 0.9083804012656871, 0.023403424405383556],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9547032596631122, 0.04481274992354572, 0.0004839904133421039],
                                [0.9547032596631122, 0.04470952170364482, 0.0005872186332430094],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7771711629893495, 0.2204479367487944, 0.002380900261856123],
                                [0.7771711629893494, 0.21994012483967856, 0.0028887121709719405],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5171960567526404, 0.47764523914817764, 0.005158704099182031],
                                [0.5171960567526404, 0.476544961484666, 0.006258981762693634],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.2572209505159313, 0.7348425415475608, 0.007936507936507938],
                                [0.2572209505159313, 0.7331497981296534, 0.009629251354415327],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528075],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.07968885384216862, 0.9104777283728094, 0.009833417785021958],
                                [0.07968885384216862, 0.9083804012656871, 0.011930744892144258],
                                [0.953089922969332, 0.04481274992354572, 0.0020973271071223014],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9551872500764542, 0.04470952170364481, 0.00010322821990090549],
                                [0.9550888643003007, 0.04481274992354572, 9.838577615361554e-05],
                                [0.9550888643003006, 0.04470952170364481, 0.00020161399605452102],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7795520632512056, 0.21994012483967856, 0.0005078119091158174],
                                [0.7790680728378635, 0.22044793674879437, 0.0004839904133421051],
                                [0.7790680728378636, 0.21994012483967854, 0.0009918023224579225],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.5223547608518224, 0.47654496148466596, 0.0011002776635116035],
                                [0.5213060972982613, 0.4776452391481776, 0.0010486635535611535],
                                [0.5213060972982613, 0.47654496148466596, 0.002148941217072757],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2651574584524393, 0.7331497981296533, 0.0016927434179073895],
                                [0.26354412175865904, 0.7348425415475608, 0.0016133366937802018],
                                [0.26354412175865904, 0.7331497981296534, 0.0033060801116875913],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.08952227162719062, 0.9083804012656871, 0.0020973271071223014],
                                [0.08752333029622195, 0.9104777283728094, 0.0019989413309686914],
                                [0.08752333029622195, 0.9083804012656871, 0.004096268438090992],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158175],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.9531137444651057, 0.0464022651215522, 0.0004839904133421039],
                                [0.9531137444651057, 0.036084856923188136, 0.010801398611706167],
                                [0.7692346550528415, 0.22826725929492694, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7693518404432169, 0.22826725929492694, 0.002380900261856123],
                                [0.7693518404432169, 0.17751270051857743, 0.05313545903820564],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5002539059545579, 0.49458738994626006, 0.005158704099182031],
                                [0.500253905954558, 0.38461732752642075, 0.11512876651902132],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.23115597146589895, 0.7609075205975931, 0.007936507936507938],
                                [0.23115597146589906, 0.591721954534264, 0.17712207399983698],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.0473940674440102, 0.9427725147709678, 0.009833417785021958],
                                [0.0473940674440102, 0.7331497981296533, 0.21945613442633646],
                                [0.9530899229693319, 0.04441199137843651, 0.00249808565223151],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.9532071083597073, 0.0464022651215522, 0.0003906265187404308],
                                [0.9532071083597073, 0.036084856923188136, 0.010708034717104494],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909876],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7698111266500862, 0.22826725929492694, 0.0019216140549867585],
                                [0.7698111266500862, 0.17751270051857743, 0.05267617283133628],
                                [0.5, 0.4733736777857095, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5012490428261157, 0.49458738994626006, 0.004163567227624185],
                                [0.5012490428261158, 0.38461732752642075, 0.11413362964746347],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671145],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.2326869590021453, 0.760907520597593, 0.006405520400261612],
                                [0.2326869590021453, 0.591721954534264, 0.17559108646359065],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634952],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.049290977292524185, 0.9427725147709679, 0.00793650793650794],
                                [0.049290977292524296, 0.7331497981296533, 0.21755922457782245],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.9533438289238899, 0.0464022651215522, 0.00025390595455790875],
                                [0.9533438289238898, 0.036084856923188136, 0.01057131415292197],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7704836978789573, 0.22826725929492692, 0.001249042826115755],
                                [0.7704836978789573, 0.17751270051857743, 0.05200360160246527],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.50270630502687, 0.49458738994626006, 0.00270630502686997],
                                [0.50270630502687, 0.38461732752642075, 0.11267636744670925],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.23492891217478273, 0.760907520597593, 0.004163567227624184],
                                [0.23492891217478273, 0.591721954534264, 0.17334913329095322],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.05206878112985014, 0.9427725147709678, 0.005158704099182031],
                                [0.05206878112985014, 0.7331497981296533, 0.21478142074049653],
                                [0.953089922969332, 0.03858294257541965, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.9534805494880724, 0.046402265121552204, 0.00011718539037538673],
                                [0.9534805494880725, 0.036084856923188136, 0.010434593588739449],
                                [0.7692346550528415, 0.1898015653794873, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7711562691078283, 0.22826725929492694, 0.0005764715972447519],
                                [0.7711562691078282, 0.17751270051857743, 0.051331030373594266],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5041635672276242, 0.49458738994626006, 0.0012490428261157554],
                                [0.5041635672276241, 0.3846173275264208, 0.11121910524595503],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.23717086534742005, 0.7609075205975931, 0.0019216140549867587],
                                [0.23717086534742005, 0.5917219545342641, 0.1711071801183158],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.05484658496717598, 0.9427725147709679, 0.002380900261856124],
                                [0.05484658496717598, 0.7331497981296534, 0.2120036169031706],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9535977348784478, 0.03608485692318814, 0.010317408198364061],
                                [0.953573913382674, 0.046402265121552204, 2.3821495773713598e-05],
                                [0.953573913382674, 0.03608485692318814, 0.010341229694137775],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634951],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7717327407050731, 0.17751270051857743, 0.05075455877634952],
                                [0.7716155553146976, 0.22826725929492694, 0.00011718539037538676],
                                [0.7716155553146977, 0.17751270051857743, 0.0508717441667249],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5054126100537399, 0.38461732752642075, 0.10997006241983928],
                                [0.5051587040991821, 0.49458738994626006, 0.00025390595455790886],
                                [0.5051587040991821, 0.3846173275264208, 0.11022396837439719],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.23909247940240685, 0.5917219545342641, 0.16918556606332905],
                                [0.2387018528836664, 0.7609075205975931, 0.00039062651874043096],
                                [0.2387018528836664, 0.5917219545342641, 0.16957619258206946],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.05722748522903209, 0.7331497981296534, 0.2096227166413145],
                                [0.056743494815689965, 0.9427725147709679, 0.0004839904133421041],
                                [0.056743494815689965, 0.7331497981296534, 0.2101067070546566],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158175],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9532071083597073, 0.0444119913784365, 0.002380900261856123],
                                [0.9532071083597073, 0.036084856923188136, 0.010708034717104494],
                                [0.7692346550528415, 0.22826725929492694, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7698111266500863, 0.21847648008624856, 0.011712393263665124],
                                [0.7698111266500862, 0.17751270051857743, 0.05267617283133628],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5012490428261157, 0.4733736777857095, 0.02537727938817476],
                                [0.5012490428261158, 0.38461732752642075, 0.11413362964746347],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.2326869590021453, 0.7282708754851703, 0.03904216551268439],
                                [0.2326869590021453, 0.591721954534264, 0.17559108646359065],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.049290977292524185, 0.9023353641929824, 0.04837365851449339],
                                [0.049290977292524296, 0.7331497981296533, 0.21755922457782245],
                                [0.9530899229693319, 0.04441199137843651, 0.00249808565223151],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9536663945665766, 0.04441199137843651, 0.0019216140549867583],
                                [0.9536663945665766, 0.03608485692318814, 0.010248748510235127],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909876],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7720704991914785, 0.21847648008624856, 0.009453020722272994],
                                [0.7720704991914784, 0.17751270051857743, 0.05041680028994414],
                                [0.5, 0.4733736777857095, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5061444324304549, 0.4733736777857095, 0.020481889783835576],
                                [0.5061444324304549, 0.3846173275264208, 0.10923824004312428],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671145],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.24021836566943144, 0.7282708754851704, 0.031510758845398154],
                                [0.24021836566943144, 0.5917219545342641, 0.1680596797963044],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634952],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.05862247029433321, 0.9023353641929824, 0.03904216551268439],
                                [0.05862247029433321, 0.7331497981296533, 0.20822773157601343],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9543389657954477, 0.0444119913784365, 0.001249042826115755],
                                [0.9543389657954477, 0.036084856923188136, 0.009576177281364125],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7753790874832964, 0.2184764800862486, 0.006144432430454938],
                                [0.7753790874832964, 0.17751270051857743, 0.047108211998126086],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5133131611071452, 0.4733736777857095, 0.013313161107145257],
                                [0.5133131611071453, 0.38461732752642075, 0.10206951136643397],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.2512472347309941, 0.7282708754851703, 0.020481889783835572],
                                [0.2512472347309942, 0.591721954534264, 0.15703081073474184],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.07228735641884287, 0.9023353641929823, 0.025377279388174755],
                                [0.07228735641884287, 0.7331497981296533, 0.1945628454515038],
                                [0.953089922969332, 0.03858294257541965, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.9550115370243187, 0.04441199137843651, 0.000576471597244752],
                                [0.9550115370243188, 0.036084856923188136, 0.008903606052493122],
                                [0.7692346550528415, 0.1898015653794873, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7786876757751146, 0.21847648008624856, 0.002835844138636883],
                                [0.7786876757751144, 0.17751270051857743, 0.043799623706308036],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5204818897838356, 0.4733736777857095, 0.006144432430454941],
                                [0.5204818897838356, 0.38461732752642075, 0.09490078268974365],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.2622761037925567, 0.7282708754851703, 0.009453020722272998],
                                [0.2622761037925566, 0.5917219545342641, 0.14600194167317926],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.08595224254335243, 0.9023353641929824, 0.01171239326366513],
                                [0.08595224254335243, 0.7331497981296534, 0.18089795932699418],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9555880086215636, 0.036084856923188136, 0.00832713445524837],
                                [0.955470823231188, 0.04441199137843651, 0.00011718539037538697],
                                [0.9554708232311881, 0.036084856923188136, 0.008444319845623756],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634951],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7815235199137514, 0.17751270051857743, 0.04096377956767115],
                                [0.7809470483165066, 0.2184764800862486, 0.0005764715972447531],
                                [0.7809470483165066, 0.17751270051857743, 0.0415402511649159],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928871],
                                [0.5253772793881748, 0.4733736777857095, 0.001249042826115758],
                                [0.5253772793881748, 0.3846173275264208, 0.09000539308540446],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.27172912451482967, 0.591721954534264, 0.13654892095090626],
                                [0.26980751045984286, 0.7282708754851703, 0.0019216140549867626],
                                [0.26980751045984286, 0.5917219545342641, 0.13847053500589301],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.09766463580701756, 0.7331497981296534, 0.16918556606332905],
                                [0.09528373554516145, 0.9023353641929824, 0.002380900261856129],
                                [0.09528373554516145, 0.7331497981296534, 0.17156646632518516],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158175],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.9533438289238898, 0.04149746697692808, 0.005158704099182031],
                                [0.9533438289238898, 0.036084856923188136, 0.01057131415292197],
                                [0.7692346550528415, 0.22826725929492694, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7704836978789573, 0.20413902273286794, 0.02537727938817476],
                                [0.7704836978789573, 0.17751270051857743, 0.05200360160246527],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5027063050268701, 0.4423086637632104, 0.05498503120991964],
                                [0.50270630502687, 0.38461732752642075, 0.11267636744670925],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.23492891217478273, 0.6804783047935528, 0.08459278303166452],
                                [0.23492891217478273, 0.591721954534264, 0.17334913329095322],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.05206878112985014, 0.8431198605494926, 0.10481135832065724],
                                [0.05206878112985014, 0.7331497981296533, 0.21478142074049653],
                                [0.9530899229693319, 0.04441199137843651, 0.00249808565223151],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.9543389657954477, 0.04149746697692808, 0.004163567227624185],
                                [0.9543389657954477, 0.036084856923188136, 0.009576177281364125],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909876],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7753790874832964, 0.20413902273286794, 0.020481889783835576],
                                [0.7753790874832964, 0.17751270051857743, 0.047108211998126086],
                                [0.5, 0.4733736777857095, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5133131611071453, 0.4423086637632104, 0.04437817512964436],
                                [0.5133131611071453, 0.38461732752642075, 0.10206951136643397],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671145],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.2512472347309941, 0.6804783047935528, 0.06827446047545313],
                                [0.2512472347309942, 0.591721954534264, 0.15703081073474184],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634952],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.07228735641884287, 0.8431198605494926, 0.08459278303166452],
                                [0.07228735641884287, 0.7331497981296533, 0.1945628454515038],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.955796227996202, 0.04149746697692808, 0.00270630502686997],
                                [0.955796227996202, 0.036084856923188136, 0.008118915080609908],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7825478161599868, 0.20413902273286794, 0.013313161107145257],
                                [0.7825478161599868, 0.17751270051857743, 0.039939483321435765],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5288456681183947, 0.44230866376321043, 0.028845668118394806],
                                [0.5288456681183948, 0.3846173275264208, 0.08653700435518441],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.27514352007680287, 0.6804783047935528, 0.04437817512964435],
                                [0.27514352007680287, 0.591721954534264, 0.13313452538893306],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.10189510824058767, 0.8431198605494927, 0.05498503120991964],
                                [0.10189510824058767, 0.7331497981296534, 0.1649550936297589],
                                [0.953089922969332, 0.03858294257541965, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.9572534901969563, 0.04149746697692808, 0.0012490428261157556],
                                [0.9572534901969563, 0.036084856923188136, 0.006661652879855696],
                                [0.7692346550528415, 0.1898015653794873, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7897165448366772, 0.20413902273286794, 0.006144432430454941],
                                [0.7897165448366772, 0.1775127005185774, 0.03277075464474546],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5443781751296444, 0.4423086637632104, 0.013313161107145262],
                                [0.5443781751296444, 0.38461732752642075, 0.07100449734393488],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.29903980542261166, 0.6804783047935528, 0.020481889783835583],
                                [0.29903980542261166, 0.591721954534264, 0.1092382400431243],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.13150286006233258, 0.8431198605494926, 0.025377279388174766],
                                [0.1315028600623327, 0.7331497981296533, 0.13534734180801405],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9585025330230719, 0.036084856923188136, 0.00541261005373994],
                                [0.958248627068514, 0.04149746697692808, 0.0002539059545579088],
                                [0.958248627068514, 0.036084856923188136, 0.005666516008297848],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634951],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7958609772671321, 0.17751270051857743, 0.026626322214290513],
                                [0.7946119344410164, 0.2041390227328679, 0.0012490428261157554],
                                [0.7946119344410164, 0.1775127005185774, 0.027875365040406268],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5576913362367897, 0.38461732752642075, 0.05769133623678961],
                                [0.5549850312099196, 0.4423086637632104, 0.0027063050268699707],
                                [0.5549850312099197, 0.38461732752642075, 0.06039764126365958],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.31952169520644724, 0.591721954534264, 0.0887563502592887],
                                [0.315358127978823, 0.6804783047935528, 0.004163567227624186],
                                [0.315358127978823, 0.5917219545342641, 0.09291991748691289],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.15688013945050738, 0.7331497981296533, 0.10997006241983928],
                                [0.15172143535132532, 0.8431198605494926, 0.0051587040991820324],
                                [0.15172143535132532, 0.7331497981296534, 0.1151287665190213],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158175],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.9534805494880725, 0.03858294257541965, 0.007936507936507938],
                                [0.9534805494880725, 0.036084856923188136, 0.010434593588739449],
                                [0.7692346550528415, 0.22826725929492694, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.7711562691078283, 0.1898015653794873, 0.039042165512684385],
                                [0.7711562691078282, 0.17751270051857743, 0.051331030373594266],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5041635672276241, 0.4112436497407113, 0.08459278303166451],
                                [0.5041635672276241, 0.3846173275264208, 0.11121910524595503],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.23717086534742005, 0.6326857341019353, 0.13014340055064463],
                                [0.23717086534742005, 0.5917219545342641, 0.1711071801183158],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.05484658496717598, 0.7839043569060029, 0.16124905812682108],
                                [0.05484658496717598, 0.7331497981296534, 0.2120036169031706],
                                [0.9530899229693319, 0.04441199137843651, 0.00249808565223151],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.9550115370243187, 0.038582942575419645, 0.006405520400261611],
                                [0.9550115370243188, 0.036084856923188136, 0.008903606052493122],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909876],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.7786876757751147, 0.18980156537948728, 0.031510758845398154],
                                [0.7786876757751144, 0.17751270051857743, 0.043799623706308036],
                                [0.5, 0.4733736777857095, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5204818897838356, 0.41124364974071126, 0.06827446047545313],
                                [0.5204818897838356, 0.38461732752642075, 0.09490078268974365],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671145],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.2622761037925566, 0.6326857341019353, 0.10503816210550809],
                                [0.2622761037925566, 0.5917219545342641, 0.14600194167317926],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634952],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.08595224254335243, 0.7839043569060029, 0.13014340055064463],
                                [0.08595224254335243, 0.7331497981296534, 0.18089795932699418],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.9572534901969562, 0.03858294257541965, 0.004163567227624184],
                                [0.9572534901969563, 0.036084856923188136, 0.006661652879855696],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.7897165448366772, 0.18980156537948728, 0.020481889783835572],
                                [0.7897165448366772, 0.1775127005185774, 0.03277075464474546],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5443781751296444, 0.41124364974071126, 0.04437817512964435],
                                [0.5443781751296444, 0.38461732752642075, 0.07100449734393488],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.29903980542261166, 0.6326857341019352, 0.06827446047545312],
                                [0.29903980542261166, 0.591721954534264, 0.1092382400431243],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.13150286006233258, 0.7839043569060029, 0.08459278303166451],
                                [0.1315028600623327, 0.7331497981296533, 0.13534734180801405],
                                [0.953089922969332, 0.03858294257541965, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.9594954433695936, 0.03858294257541965, 0.001921614054986759],
                                [0.9594954433695936, 0.03608485692318814, 0.00441969970721827],
                                [0.7692346550528415, 0.1898015653794873, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.8007454138982397, 0.1898015653794873, 0.009453020722272998],
                                [0.8007454138982397, 0.17751270051857743, 0.02174188558318288],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.568274460475453, 0.4112436497407113, 0.020481889783835583],
                                [0.568274460475453, 0.3846173275264208, 0.04710821199812611],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.3358035070526666, 0.6326857341019352, 0.03151075884539817],
                                [0.3358035070526666, 0.591721954534264, 0.07247453841306933],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.17705347758131262, 0.783904356906003, 0.039042165512684406],
                                [0.17705347758131262, 0.7331497981296534, 0.08979672428903394],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9614170574245803, 0.03608485692318814, 0.002498085652231511],
                                [0.96102643090584, 0.03858294257541965, 0.0003906265187404313],
                                [0.9610264309058398, 0.03608485692318814, 0.002888712170971942],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634951],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8101984346205127, 0.17751270051857743, 0.012288864860909882],
                                [0.8082768205655259, 0.1898015653794873, 0.001921614054986761],
                                [0.808276820565526, 0.17751270051857743, 0.014210478915896642],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.5887563502592887, 0.3846173275264208, 0.026626322214290524],
                                [0.5845927830316644, 0.4112436497407113, 0.00416356722762419],
                                [0.5845927830316645, 0.38461732752642075, 0.030789889441914714],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.3673142658980647, 0.5917219545342641, 0.040963779567671166],
                                [0.36090874549780316, 0.6326857341019352, 0.0064055204002616195],
                                [0.36090874549780316, 0.591721954534264, 0.047369299967932786],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.2160956430939971, 0.7331497981296534, 0.05075455877634953],
                                [0.20815913515748918, 0.7839043569060029, 0.007936507936507948],
                                [0.20815913515748918, 0.7331497981296533, 0.05869106671285748],
                                [0.9530899229693319, 0.046402265121552204, 0.0005078119091158175],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.953573913382674, 0.03659266883230396, 0.009833417785021958],
                                [0.953573913382674, 0.03608485692318814, 0.010341229694137775],
                                [0.7692346550528415, 0.22826725929492694, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.7716155553146977, 0.18001078617080896, 0.04837365851449339],
                                [0.7716155553146977, 0.17751270051857743, 0.0508717441667249],
                                [0.5, 0.49458738994626006, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.5051587040991821, 0.39002993758016075, 0.10481135832065724],
                                [0.5051587040991821, 0.3846173275264208, 0.11022396837439719],
                                [0.2307653449471585, 0.7609075205975931, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.2387018528836664, 0.6000490889895125, 0.16124905812682108],
                                [0.2387018528836664, 0.5917219545342641, 0.16957619258206946],
                                [0.046910077030668074, 0.9427725147709679, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.056743494815689965, 0.7434672063280175, 0.1997892988562925],
                                [0.056743494815689965, 0.7331497981296534, 0.2101067070546566],
                                [0.9530899229693319, 0.04441199137843651, 0.00249808565223151],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.9554708232311881, 0.03659266883230396, 0.007936507936507938],
                                [0.9554708232311881, 0.036084856923188136, 0.008444319845623756],
                                [0.7692346550528416, 0.21847648008624856, 0.012288864860909876],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.7809470483165066, 0.18001078617080896, 0.03904216551268439],
                                [0.7809470483165066, 0.17751270051857743, 0.0415402511649159],
                                [0.5, 0.4733736777857095, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.5253772793881748, 0.39002993758016075, 0.08459278303166452],
                                [0.5253772793881748, 0.3846173275264208, 0.09000539308540446],
                                [0.2307653449471585, 0.7282708754851703, 0.040963779567671145],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.26980751045984286, 0.6000490889895125, 0.13014340055064463],
                                [0.26980751045984286, 0.5917219545342641, 0.13847053500589301],
                                [0.046910077030668074, 0.9023353641929824, 0.05075455877634952],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.09528373554516145, 0.7434672063280174, 0.1612490581268211],
                                [0.09528373554516145, 0.7331497981296534, 0.17156646632518516],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.958248627068514, 0.03659266883230396, 0.005158704099182031],
                                [0.958248627068514, 0.036084856923188136, 0.005666516008297848],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.7946119344410163, 0.1800107861708089, 0.02537727938817476],
                                [0.7946119344410164, 0.1775127005185774, 0.027875365040406268],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.5549850312099197, 0.3900299375801607, 0.05498503120991964],
                                [0.5549850312099197, 0.38461732752642075, 0.06039764126365958],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.315358127978823, 0.6000490889895125, 0.08459278303166452],
                                [0.315358127978823, 0.5917219545342641, 0.09291991748691289],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.15172143535132532, 0.7434672063280174, 0.10481135832065724],
                                [0.15172143535132532, 0.7331497981296534, 0.1151287665190213],
                                [0.953089922969332, 0.03858294257541965, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.96102643090584, 0.03659266883230396, 0.002380900261856123],
                                [0.9610264309058398, 0.03608485692318814, 0.002888712170971941],
                                [0.7692346550528415, 0.1898015653794873, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.808276820565526, 0.18001078617080893, 0.011712393263665124],
                                [0.808276820565526, 0.17751270051857743, 0.014210478915896635],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.5845927830316644, 0.39002993758016075, 0.02537727938817476],
                                [0.5845927830316644, 0.3846173275264208, 0.0307898894419147],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.36090874549780316, 0.6000490889895125, 0.03904216551268439],
                                [0.36090874549780316, 0.5917219545342641, 0.04736929996793276],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332905],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.20815913515748918, 0.7434672063280174, 0.04837365851449339],
                                [0.20815913515748918, 0.7331497981296533, 0.058691066712857454],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.963407331167696, 0.03608485692318814, 0.0005078119091158176],
                                [0.9629233407543539, 0.03659266883230396, 0.00048399041334210453],
                                [0.9629233407543539, 0.03608485692318814, 0.000991802322457922],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634951],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8199892138291911, 0.17751270051857743, 0.0024980856522315107],
                                [0.817608313567335, 0.18001078617080893, 0.0023809002618561262],
                                [0.8176083135673349, 0.17751270051857743, 0.004878985914087637],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6099700624198393, 0.38461732752642075, 0.005412610053739941],
                                [0.6048113583206572, 0.3900299375801607, 0.005158704099182038],
                                [0.6048113583206572, 0.38461732752642075, 0.010571314152921979],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.39995091101048763, 0.591721954534264, 0.008327134455248372],
                                [0.3920144030739796, 0.6000490889895125, 0.007936507936507948],
                                [0.3920144030739796, 0.591721954534264, 0.01626364239175632],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.25653279367198256, 0.7331497981296534, 0.010317408198364065],
                                [0.24669937588696056, 0.7434672063280174, 0.00983341778502197],
                                [0.24669937588696056, 0.7331497981296534, 0.020150825983386033],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9531415370792824, 0.045809799367156415, 0.001048663553561151],
                                [0.9531415370792824, 0.023455038515334013, 0.023403424405383556],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7694885610073994, 0.2253527348934185, 0.005158704099182031],
                                [0.7694885610073995, 0.11538267247357924, 0.1151287665190213],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.5005501388317558, 0.488272480742333, 0.011177380425911203],
                                [0.5005501388317558, 0.25, 0.2494498611682442],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.23161171665611224, 0.7511922265912474, 0.017196056752640375],
                                [0.2316117166561122, 0.3846173275264207, 0.38377095581746706],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.04795874058422922, 0.9307351621175095, 0.021306097298261252],
                                [0.04795874058422922, 0.47654496148466596, 0.4754962979311048],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9533438289238898, 0.045809799367156415, 0.0008463717089536947],
                                [0.9533438289238899, 0.023455038515334006, 0.023201132560776102],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7704836978789573, 0.2253527348934185, 0.004163567227624184],
                                [0.7704836978789573, 0.11538267247357921, 0.11413362964746347],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.50270630502687, 0.488272480742333, 0.009021214230797034],
                                [0.50270630502687, 0.25, 0.24729369497313003],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.23492891217478273, 0.7511922265912474, 0.013878861233969883],
                                [0.2349289121747828, 0.3846173275264207, 0.3804537602987966],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.05206878112985014, 0.9307351621175095, 0.01719605675264037],
                                [0.052068781129850195, 0.4765449614846659, 0.47138625738548395],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9536400618010877, 0.045809799367156415, 0.0005501388317558017],
                                [0.9536400618010877, 0.02345503851533401, 0.022904899683578207],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7719409600797116, 0.2253527348934185, 0.00270630502686997],
                                [0.7719409600797115, 0.11538267247357922, 0.11267636744670925],
                                [0.5, 0.375, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.5058637596288336, 0.488272480742333, 0.005863759628833502],
                                [0.5058637596288336, 0.25, 0.2441362403711665],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.23978655917795555, 0.7511922265912474, 0.009021214230797034],
                                [0.23978655917795555, 0.38461732752642075, 0.3755961132956237],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.05808745745657928, 0.9307351621175095, 0.011177380425911203],
                                [0.05808745745657928, 0.47654496148466596, 0.46536758105875475],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9539362946782857, 0.045809799367156415, 0.0002539059545579088],
                                [0.9539362946782857, 0.023455038515334013, 0.022608666806380313],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7733982222804658, 0.22535273489341848, 0.0012490428261157554],
                                [0.7733982222804657, 0.11538267247357921, 0.11121910524595503],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.509021214230797, 0.488272480742333, 0.0027063050268699707],
                                [0.509021214230797, 0.25, 0.24097878576920295],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.24464420618112837, 0.7511922265912474, 0.004163567227624186],
                                [0.2446442061811283, 0.3846173275264208, 0.37073846629245083],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.06410613378330843, 0.9307351621175095, 0.0051587040991820324],
                                [0.06410613378330837, 0.476544961484666, 0.45934890473202555],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9541902006328435, 0.02345503851533401, 0.022354760851822406],
                                [0.9541385865228931, 0.045809799367156415, 5.1614109950452745e-05],
                                [0.9541385865228931, 0.023455038515334006, 0.02240637496177286],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7746472651065814, 0.11538267247357922, 0.10997006241983928],
                                [0.7743933591520236, 0.2253527348934185, 0.0002539059545579087],
                                [0.7743933591520236, 0.11538267247357922, 0.11022396837439719],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.511727519257667, 0.25, 0.23827248074233298],
                                [0.5111773804259112, 0.488272480742333, 0.0005501388317558017],
                                [0.5111773804259112, 0.25, 0.2388226195740888],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2488077734087526, 0.38461732752642075, 0.36657489906482665],
                                [0.24796140169979886, 0.7511922265912474, 0.0008463717089536947],
                                [0.2479614016997989, 0.3846173275264208, 0.36742127077378034],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.0692648378824905, 0.47654496148466596, 0.45419020063284354],
                                [0.06821617432892935, 0.9307351621175095, 0.0010486635535611507],
                                [0.06821617432892935, 0.47654496148466596, 0.4552388641864047],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.9533438289238898, 0.04149746697692808, 0.005158704099182031],
                                [0.9533438289238899, 0.023455038515334006, 0.023201132560776102],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7704836978789573, 0.20413902273286794, 0.02537727938817476],
                                [0.7704836978789573, 0.11538267247357921, 0.11413362964746347],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5027063050268701, 0.4423086637632104, 0.05498503120991964],
                                [0.50270630502687, 0.25, 0.24729369497313003],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.23492891217478273, 0.6804783047935528, 0.08459278303166452],
                                [0.2349289121747828, 0.3846173275264207, 0.3804537602987966],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.05206878112985014, 0.8431198605494926, 0.10481135832065724],
                                [0.052068781129850195, 0.4765449614846659, 0.47138625738548395],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.9543389657954477, 0.04149746697692808, 0.004163567227624185],
                                [0.9543389657954477, 0.023455038515334006, 0.022205995689218255],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7753790874832964, 0.20413902273286794, 0.020481889783835576],
                                [0.7753790874832964, 0.11538267247357924, 0.10923824004312428],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5133131611071453, 0.4423086637632104, 0.04437817512964436],
                                [0.5133131611071453, 0.25, 0.23668683889285475],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.2512472347309941, 0.6804783047935528, 0.06827446047545313],
                                [0.2512472347309941, 0.38461732752642075, 0.36413543774258517],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.07228735641884287, 0.8431198605494926, 0.08459278303166452],
                                [0.07228735641884293, 0.4765449614846659, 0.4511676820964912],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.955796227996202, 0.04149746697692808, 0.00270630502686997],
                                [0.9557962279962019, 0.02345503851533401, 0.02074873348846404],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7825478161599868, 0.20413902273286794, 0.013313161107145257],
                                [0.7825478161599868, 0.11538267247357922, 0.10206951136643397],
                                [0.5, 0.375, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5288456681183947, 0.44230866376321043, 0.028845668118394806],
                                [0.5288456681183948, 0.25, 0.2211543318816052],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.27514352007680287, 0.6804783047935528, 0.04437817512964435],
                                [0.27514352007680287, 0.38461732752642075, 0.3402391523967764],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.10189510824058767, 0.8431198605494927, 0.05498503120991964],
                                [0.10189510824058762, 0.476544961484666, 0.4215599302747463],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.9572534901969563, 0.04149746697692808, 0.0012490428261157556],
                                [0.9572534901969562, 0.02345503851533401, 0.019291471287709826],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7897165448366772, 0.20413902273286794, 0.006144432430454941],
                                [0.7897165448366771, 0.11538267247357921, 0.09490078268974365],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5443781751296444, 0.4423086637632104, 0.013313161107145262],
                                [0.5443781751296444, 0.24999999999999997, 0.20562182487035566],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.29903980542261166, 0.6804783047935528, 0.020481889783835583],
                                [0.2990398054226117, 0.3846173275264207, 0.31634286705096765],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.13150286006233258, 0.8431198605494926, 0.025377279388174766],
                                [0.13150286006233258, 0.47654496148466596, 0.39195217845300145],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9585025330230719, 0.02345503851533401, 0.018042428461594068],
                                [0.958248627068514, 0.04149746697692808, 0.0002539059545579088],
                                [0.958248627068514, 0.02345503851533401, 0.01829633441615198],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.795860977267132, 0.11538267247357924, 0.0887563502592887],
                                [0.7946119344410164, 0.2041390227328679, 0.0012490428261157554],
                                [0.7946119344410163, 0.11538267247357921, 0.09000539308540446],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.5576913362367897, 0.25, 0.19230866376321037],
                                [0.5549850312099196, 0.4423086637632104, 0.0027063050268699707],
                                [0.5549850312099196, 0.25, 0.19501496879008035],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.31952169520644724, 0.38461732752642075, 0.295860977267132],
                                [0.315358127978823, 0.6804783047935528, 0.004163567227624186],
                                [0.31535812797882296, 0.3846173275264208, 0.3000245444947562],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.15688013945050738, 0.47654496148466596, 0.36657489906482665],
                                [0.15172143535132532, 0.8431198605494926, 0.0051587040991820324],
                                [0.15172143535132532, 0.47654496148466596, 0.3717336031640087],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9536400618010877, 0.035182557773001014, 0.011177380425911203],
                                [0.9536400618010877, 0.02345503851533401, 0.022904899683578207],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.7719409600797116, 0.17307400871036882, 0.05498503120991964],
                                [0.7719409600797115, 0.11538267247357922, 0.11267636744670925],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.625, 0.25, 0.125],
                                [0.5058637596288336, 0.375, 0.11913624037116649],
                                [0.5058637596288336, 0.25, 0.2441362403711665],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.23978655917795555, 0.5769259912896312, 0.18328744953241333],
                                [0.23978655917795555, 0.38461732752642075, 0.3755961132956237],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.05808745745657928, 0.714817442226999, 0.22709510031642177],
                                [0.05808745745657928, 0.47654496148466596, 0.46536758105875475],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9557962279962019, 0.035182557773001014, 0.009021214230797034],
                                [0.9557962279962019, 0.02345503851533401, 0.02074873348846404],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.7825478161599868, 0.17307400871036885, 0.04437817512964435],
                                [0.7825478161599868, 0.11538267247357922, 0.10206951136643397],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.625, 0.25, 0.125],
                                [0.5288456681183948, 0.375, 0.09615433188160519],
                                [0.5288456681183948, 0.25, 0.2211543318816052],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.27514352007680287, 0.5769259912896312, 0.147930488633566],
                                [0.27514352007680287, 0.38461732752642075, 0.3402391523967764],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.10189510824058767, 0.7148174422269991, 0.18328744953241333],
                                [0.10189510824058762, 0.476544961484666, 0.4215599302747463],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9589536825981655, 0.035182557773001014, 0.005863759628833502],
                                [0.9589536825981655, 0.02345503851533401, 0.017591278886500507],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.7980803231712363, 0.17307400871036882, 0.028845668118394806],
                                [0.7980803231712363, 0.11538267247357922, 0.08653700435518441],
                                [0.5, 0.375, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.625, 0.25, 0.125],
                                [0.5625, 0.375, 0.0625],
                                [0.5625, 0.25, 0.1875],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.32691967682876366, 0.5769259912896312, 0.09615433188160519],
                                [0.32691967682876366, 0.38461732752642075, 0.2884629956448156],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.1660463174018345, 0.7148174422269991, 0.11913624037116649],
                                [0.16604631740183445, 0.476544961484666, 0.3574087211134995],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.962111137200129, 0.035182557773001014, 0.0027063050268699707],
                                [0.962111137200129, 0.02345503851533401, 0.014433824284536975],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.8136128301824859, 0.17307400871036885, 0.01331316110714526],
                                [0.8136128301824859, 0.11538267247357924, 0.07100449734393487],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.625, 0.25, 0.125],
                                [0.5961543318816052, 0.375, 0.028845668118394813],
                                [0.5961543318816052, 0.25, 0.1538456681183948],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.37869583358072445, 0.5769259912896312, 0.044378175129644364],
                                [0.3786958335807245, 0.3846173275264208, 0.23668683889285475],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.23019752656308134, 0.7148174422269991, 0.054985031209919655],
                                [0.2301975265630813, 0.476544961484666, 0.29325751195225264],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.964817442226999, 0.02345503851533401, 0.011727519257667005],
                                [0.9642673033952431, 0.035182557773001014, 0.0005501388317558024],
                                [0.9642673033952431, 0.02345503851533401, 0.012277658089422806],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8269259912896312, 0.11538267247357921, 0.05769133623678961],
                                [0.8242196862627612, 0.17307400871036885, 0.0027063050268699733],
                                [0.8242196862627612, 0.11538267247357924, 0.06039764126365958],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.625, 0.25, 0.125],
                                [0.6191362403711664, 0.375, 0.005863759628833509],
                                [0.6191362403711664, 0.25, 0.1308637596288335],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.4230740087103689, 0.3846173275264208, 0.19230866376321037],
                                [0.4140527944795719, 0.5769259912896311, 0.009021214230797044],
                                [0.41405279447957194, 0.3846173275264207, 0.20132987799400742],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.28518255777300106, 0.47654496148466596, 0.23827248074233298],
                                [0.27400517734708985, 0.714817442226999, 0.011177380425911215],
                                [0.27400517734708985, 0.47654496148466596, 0.2494498611682442],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.9539362946782857, 0.028867648569073954, 0.01719605675264037],
                                [0.9539362946782857, 0.023455038515334013, 0.022608666806380313],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.7733982222804657, 0.14200899468786973, 0.08459278303166451],
                                [0.7733982222804657, 0.11538267247357921, 0.11121910524595503],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.509021214230797, 0.3076913362367896, 0.18328744953241333],
                                [0.509021214230797, 0.25, 0.24097878576920295],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.24464420618112837, 0.4733736777857095, 0.28198211603316214],
                                [0.2446442061811283, 0.3846173275264208, 0.37073846629245083],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.06410613378330843, 0.5865150239045054, 0.34937884231218624],
                                [0.06410613378330837, 0.476544961484666, 0.45934890473202555],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.9572534901969562, 0.02886764856907395, 0.013878861233969884],
                                [0.9572534901969562, 0.02345503851533401, 0.019291471287709826],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.7897165448366771, 0.14200899468786973, 0.06827446047545313],
                                [0.7897165448366771, 0.11538267247357921, 0.09490078268974365],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.5443781751296444, 0.30769133623678957, 0.14793048863356603],
                                [0.5443781751296444, 0.24999999999999997, 0.20562182487035566],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.2990398054226117, 0.47337367778570943, 0.2275865167916789],
                                [0.2990398054226117, 0.3846173275264207, 0.31634286705096765],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.13150286006233258, 0.5865150239045053, 0.28198211603316214],
                                [0.13150286006233258, 0.47654496148466596, 0.39195217845300145],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.962111137200129, 0.02886764856907395, 0.009021214230797034],
                                [0.962111137200129, 0.02345503851533401, 0.014433824284536975],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.8136128301824859, 0.14200899468786976, 0.04437817512964435],
                                [0.8136128301824859, 0.11538267247357924, 0.07100449734393487],
                                [0.5, 0.375, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.5961543318816052, 0.3076913362367897, 0.09615433188160519],
                                [0.5961543318816052, 0.25, 0.1538456681183948],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.3786958335807245, 0.47337367778570955, 0.147930488633566],
                                [0.3786958335807245, 0.3846173275264208, 0.23668683889285475],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.23019752656308134, 0.5865150239045054, 0.18328744953241333],
                                [0.2301975265630813, 0.476544961484666, 0.29325751195225264],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.9669687842033018, 0.028867648569073947, 0.004163567227624186],
                                [0.9669687842033018, 0.02345503851533401, 0.009576177281364126],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.8375091155282947, 0.14200899468786973, 0.020481889783835583],
                                [0.8375091155282947, 0.11538267247357922, 0.0471082119981261],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.647930488633566, 0.3076913362367896, 0.04437817512964437],
                                [0.647930488633566, 0.25, 0.102069511366434],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.45835186173883735, 0.4733736777857095, 0.06827446047545316],
                                [0.45835186173883735, 0.38461732752642075, 0.15703081073474187],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.3288921930638302, 0.5865150239045053, 0.08459278303166455],
                                [0.3288921930638302, 0.47654496148466596, 0.19456284545150385],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.971132351430926, 0.02345503851533401, 0.005412610053739941],
                                [0.9702859797219723, 0.02886764856907395, 0.000846371708953696],
                                [0.9702859797219723, 0.02345503851533401, 0.006258981762693637],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8579910053121302, 0.11538267247357921, 0.02662632221429052],
                                [0.853827438084506, 0.14200899468786973, 0.004163567227624191],
                                [0.853827438084506, 0.11538267247357922, 0.03078988944191471],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.6923086637632103, 0.25, 0.057691336236789625],
                                [0.6832874495324133, 0.3076913362367896, 0.009021214230797048],
                                [0.6832874495324133, 0.25, 0.06671255046758667],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.5266263222142905, 0.38461732752642075, 0.08875635025928873],
                                [0.5127474609803206, 0.47337367778570943, 0.013878861233969903],
                                [0.5127474609803206, 0.38461732752642075, 0.10263521149325863],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.4134849760954947, 0.47654496148466596, 0.10997006241983931],
                                [0.3962889193428544, 0.5865150239045053, 0.0171960567526404],
                                [0.3962889193428544, 0.47654496148466596, 0.1271661191724797],
                                [0.9530899229693319, 0.045809799367156415, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9541385865228931, 0.024555316178845613, 0.021306097298261252],
                                [0.9541385865228931, 0.023455038515334006, 0.02240637496177286],
                                [0.7692346550528415, 0.2253527348934185, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.7743933591520236, 0.12079528252731916, 0.10481135832065724],
                                [0.7743933591520236, 0.11538267247357922, 0.11022396837439719],
                                [0.5, 0.488272480742333, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.5111773804259112, 0.261727519257667, 0.22709510031642177],
                                [0.5111773804259112, 0.25, 0.2388226195740888],
                                [0.2307653449471585, 0.7511922265912474, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.24796140169979886, 0.40265975598801484, 0.3493788423121863],
                                [0.2479614016997989, 0.3846173275264208, 0.36742127077378034],
                                [0.046910077030668074, 0.9307351621175095, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.06821617432892935, 0.4988997223364884, 0.43288410333458227],
                                [0.06821617432892935, 0.47654496148466596, 0.4552388641864047],
                                [0.9530899229693319, 0.04149746697692808, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.958248627068514, 0.024555316178845616, 0.01719605675264037],
                                [0.958248627068514, 0.02345503851533401, 0.01829633441615198],
                                [0.7692346550528415, 0.20413902273286794, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.7946119344410163, 0.12079528252731916, 0.08459278303166451],
                                [0.7946119344410163, 0.11538267247357921, 0.09000539308540446],
                                [0.5, 0.4423086637632104, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.5549850312099197, 0.261727519257667, 0.18328744953241333],
                                [0.5549850312099196, 0.25, 0.19501496879008035],
                                [0.2307653449471585, 0.6804783047935528, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.315358127978823, 0.40265975598801484, 0.28198211603316214],
                                [0.31535812797882296, 0.3846173275264208, 0.3000245444947562],
                                [0.046910077030668074, 0.8431198605494926, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.15172143535132537, 0.49889972233648844, 0.34937884231218624],
                                [0.15172143535132532, 0.47654496148466596, 0.3717336031640087],
                                [0.9530899229693319, 0.035182557773001014, 0.011727519257667005],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9642673033952431, 0.024555316178845613, 0.011177380425911203],
                                [0.9642673033952431, 0.02345503851533401, 0.012277658089422806],
                                [0.7692346550528416, 0.17307400871036882, 0.05769133623678961],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.8242196862627612, 0.12079528252731918, 0.05498503120991964],
                                [0.8242196862627612, 0.11538267247357924, 0.06039764126365958],
                                [0.5, 0.375, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.6191362403711665, 0.261727519257667, 0.11913624037116649],
                                [0.6191362403711664, 0.25, 0.1308637596288335],
                                [0.2307653449471585, 0.5769259912896312, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.41405279447957194, 0.4026597559880148, 0.18328744953241333],
                                [0.41405279447957194, 0.3846173275264207, 0.20132987799400742],
                                [0.046910077030668074, 0.714817442226999, 0.23827248074233298],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.27400517734708985, 0.4988997223364884, 0.22709510031642177],
                                [0.27400517734708985, 0.47654496148466596, 0.2494498611682442],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9702859797219723, 0.024555316178845613, 0.0051587040991820324],
                                [0.9702859797219723, 0.02345503851533401, 0.006258981762693637],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.853827438084506, 0.12079528252731916, 0.025377279388174766],
                                [0.853827438084506, 0.11538267247357922, 0.03078988944191471],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.6832874495324134, 0.261727519257667, 0.054985031209919655],
                                [0.6832874495324133, 0.25, 0.06671255046758667],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.5127474609803206, 0.40265975598801484, 0.08459278303166454],
                                [0.5127474609803206, 0.38461732752642075, 0.10263521149325863],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.3962889193428544, 0.4988997223364884, 0.10481135832065727],
                                [0.3962889193428544, 0.47654496148466596, 0.1271661191724797],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9754446838211543, 0.02345503851533401, 0.0011002776635116048],
                                [0.9743960202675932, 0.024555316178845616, 0.0010486635535611516],
                                [0.9743960202675932, 0.02345503851533401, 0.0021489412170727566],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8792047174726808, 0.11538267247357922, 0.0054126100537399465],
                                [0.8740460133734987, 0.12079528252731916, 0.005158704099182034],
                                [0.8740460133734987, 0.11538267247357922, 0.01057131415292198],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.738272480742333, 0.25, 0.011727519257667018],
                                [0.7270951003164218, 0.261727519257667, 0.01117738042591121],
                                [0.7270951003164218, 0.25, 0.022904899683578228],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.5973402440119852, 0.38461732752642075, 0.01804242846159409],
                                [0.5801441872593449, 0.4026597559880148, 0.017196056752640385],
                                [0.5801441872593448, 0.38461732752642075, 0.03523848521423447],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.5011002776635116, 0.47654496148466596, 0.02235476085182243],
                                [0.47979418036525034, 0.4988997223364884, 0.021306097298261266],
                                [0.47979418036525034, 0.47654496148466596, 0.0436608581500837],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.9531693296934592, 0.045217333612760625, 0.0016133366937801975],
                                [0.9531693296934591, 0.010825220107479883, 0.03600545019906094],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.769625281571582, 0.2224382104919101, 0.007936507936507938],
                                [0.769625281571582, 0.05325264442858105, 0.17712207399983698],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5008463717089537, 0.48195757153840596, 0.01719605675264037],
                                [0.5008463717089536, 0.11538267247357925, 0.38377095581746706],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.23206746184632543, 0.7414769325849018, 0.026455605568772803],
                                [0.23206746184632543, 0.17751270051857748, 0.5904198376350971],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.04852341372444824, 0.9186978094640512, 0.03277877681150054],
                                [0.04852341372444824, 0.21994012483967862, 0.7315364614358731],
                                [0.953089922969332, 0.03858294257541965, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.9534805494880725, 0.045217333612760625, 0.0013021168991669589],
                                [0.9534805494880724, 0.010825220107479883, 0.035694230404447705],
                                [0.7692346550528415, 0.1898015653794873, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7711562691078282, 0.2224382104919101, 0.006405520400261611],
                                [0.7711562691078283, 0.05325264442858105, 0.17559108646359065],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5041635672276241, 0.48195757153840596, 0.013878861233969884],
                                [0.5041635672276242, 0.11538267247357925, 0.3804537602987966],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.23717086534742005, 0.7414769325849018, 0.021352202067678155],
                                [0.23717086534742005, 0.17751270051857748, 0.5853164341340025],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332902],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.05484658496717598, 0.9186978094640512, 0.026455605568772807],
                                [0.05484658496717598, 0.21994012483967862, 0.7252132901931454],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.9539362946782857, 0.04521733361276063, 0.0008463717089536947],
                                [0.9539362946782857, 0.010825220107479883, 0.03523848521423444],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7733982222804657, 0.22243821049191007, 0.004163567227624184],
                                [0.7733982222804657, 0.05325264442858102, 0.17334913329095322],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.509021214230797, 0.4819575715384059, 0.009021214230797034],
                                [0.509021214230797, 0.11538267247357925, 0.3755961132956237],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.24464420618112837, 0.7414769325849018, 0.013878861233969883],
                                [0.24464420618112837, 0.17751270051857748, 0.5778430933002942],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.06410613378330843, 0.9186978094640512, 0.01719605675264037],
                                [0.06410613378330843, 0.21994012483967862, 0.715953741377013],
                                [0.953089922969332, 0.019152354562728253, 0.027757722467939765],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.954392039868499, 0.04521733361276063, 0.0003906265187404308],
                                [0.954392039868499, 0.010825220107479883, 0.03478274002402118],
                                [0.7692346550528416, 0.09421642399625221, 0.13654892095090623],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.775640175453103, 0.2224382104919101, 0.0019216140549867585],
                                [0.7756401754531032, 0.05325264442858105, 0.1711071801183158],
                                [0.5, 0.204139022732868, 0.295860977267132],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5138788612339698, 0.48195757153840596, 0.004163567227624185],
                                [0.5138788612339699, 0.11538267247357925, 0.3707384662924509],
                                [0.23076534494715856, 0.31406162146948374, 0.45517303358335776],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.2521175470148366, 0.7414769325849018, 0.006405520400261612],
                                [0.2521175470148366, 0.17751270051857748, 0.5703697524665859],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.07336568259944087, 0.9186978094640512, 0.00793650793650794],
                                [0.07336568259944087, 0.21994012483967862, 0.7066941925608805],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9547826663872394, 0.010825220107479883, 0.03439211350528074],
                                [0.9547032596631122, 0.04521733361276063, 7.940672412719205e-05],
                                [0.9547032596631122, 0.010825220107479883, 0.03447152022940794],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.77756178950809, 0.05325264442858105, 0.16918556606332902],
                                [0.7771711629893495, 0.22243821049191007, 0.00039062651874043145],
                                [0.7771711629893495, 0.05325264442858102, 0.1695761925820695],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.5180424284615941, 0.11538267247357925, 0.36657489906482665],
                                [0.5171960567526404, 0.48195757153840596, 0.0008463717089536964],
                                [0.5171960567526404, 0.11538267247357925, 0.3674212707737804],
                                [0.2307653449471585, 0.20527042298651732, 0.5639642320663242],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.25852306741509834, 0.17751270051857737, 0.5639642320663243],
                                [0.2572209505159313, 0.7414769325849018, 0.0013021168991669612],
                                [0.2572209505159313, 0.17751270051857748, 0.5652663489654912],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.08130219053594889, 0.21994012483967862, 0.6987576846243725],
                                [0.07968885384216862, 0.9186978094640512, 0.0016133366937802005],
                                [0.07968885384216862, 0.21994012483967862, 0.7003710213181528],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9534805494880725, 0.03858294257541965, 0.007936507936507938],
                                [0.9534805494880724, 0.010825220107479883, 0.035694230404447705],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.7711562691078283, 0.1898015653794873, 0.039042165512684385],
                                [0.7711562691078283, 0.05325264442858105, 0.17559108646359065],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5041635672276241, 0.4112436497407113, 0.08459278303166451],
                                [0.5041635672276242, 0.11538267247357925, 0.3804537602987966],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.23717086534742005, 0.6326857341019353, 0.13014340055064463],
                                [0.23717086534742005, 0.17751270051857748, 0.5853164341340025],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.05484658496717598, 0.7839043569060029, 0.16124905812682108],
                                [0.05484658496717598, 0.21994012483967862, 0.7252132901931454],
                                [0.953089922969332, 0.03858294257541965, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9550115370243187, 0.038582942575419645, 0.006405520400261611],
                                [0.9550115370243187, 0.010825220107479883, 0.034163242868201375],
                                [0.7692346550528415, 0.1898015653794873, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.7786876757751147, 0.18980156537948728, 0.031510758845398154],
                                [0.7786876757751146, 0.05325264442858105, 0.1680596797963044],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5204818897838356, 0.41124364974071126, 0.06827446047545313],
                                [0.5204818897838356, 0.11538267247357925, 0.36413543774258517],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.2622761037925566, 0.6326857341019353, 0.10503816210550809],
                                [0.2622761037925566, 0.17751270051857748, 0.5602111956888659],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332902],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.08595224254335243, 0.7839043569060029, 0.13014340055064463],
                                [0.08595224254335243, 0.21994012483967862, 0.694107632616969],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9572534901969562, 0.03858294257541965, 0.004163567227624184],
                                [0.9572534901969562, 0.010825220107479883, 0.03192128969556395],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.7897165448366772, 0.18980156537948728, 0.020481889783835572],
                                [0.7897165448366772, 0.05325264442858105, 0.15703081073474182],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5443781751296444, 0.41124364974071126, 0.04437817512964435],
                                [0.5443781751296444, 0.11538267247357925, 0.3402391523967764],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.29903980542261166, 0.6326857341019352, 0.06827446047545312],
                                [0.29903980542261166, 0.17751270051857748, 0.5234474940588109],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.13150286006233258, 0.7839043569060029, 0.08459278303166451],
                                [0.13150286006233258, 0.21994012483967862, 0.6485570150979888],
                                [0.953089922969332, 0.019152354562728253, 0.027757722467939765],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.9594954433695936, 0.03858294257541965, 0.001921614054986759],
                                [0.9594954433695936, 0.010825220107479883, 0.02967933652292653],
                                [0.7692346550528416, 0.09421642399625221, 0.13654892095090623],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.8007454138982397, 0.1898015653794873, 0.009453020722272998],
                                [0.8007454138982397, 0.05325264442858105, 0.14600194167317926],
                                [0.5, 0.204139022732868, 0.295860977267132],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.568274460475453, 0.4112436497407113, 0.020481889783835583],
                                [0.5682744604754532, 0.11538267247357925, 0.31634286705096765],
                                [0.23076534494715856, 0.31406162146948374, 0.45517303358335776],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.3358035070526666, 0.6326857341019352, 0.03151075884539817],
                                [0.33580350705266665, 0.17751270051857743, 0.486683792428756],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.17705347758131262, 0.783904356906003, 0.039042165512684406],
                                [0.17705347758131262, 0.21994012483967862, 0.6030063975790088],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9614170574245804, 0.010825220107479883, 0.02775772246793977],
                                [0.96102643090584, 0.03858294257541965, 0.0003906265187404313],
                                [0.96102643090584, 0.010825220107479883, 0.0281483489866802],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8101984346205127, 0.05325264442858105, 0.13654892095090626],
                                [0.8082768205655259, 0.1898015653794873, 0.001921614054986761],
                                [0.808276820565526, 0.05325264442858105, 0.13847053500589301],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.5887563502592886, 0.11538267247357925, 0.29586097726713206],
                                [0.5845927830316644, 0.4112436497407113, 0.00416356722762419],
                                [0.5845927830316645, 0.11538267247357925, 0.30002454449475624],
                                [0.2307653449471585, 0.20527042298651732, 0.5639642320663242],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.3673142658980647, 0.17751270051857748, 0.4551730335833578],
                                [0.36090874549780316, 0.6326857341019352, 0.0064055204002616195],
                                [0.3609087454978031, 0.17751270051857743, 0.4615785539836194],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.2160956430939971, 0.21994012483967862, 0.5639642320663243],
                                [0.20815913515748918, 0.7839043569060029, 0.007936507936507948],
                                [0.20815913515748918, 0.21994012483967862, 0.5719007400028322],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.9539362946782857, 0.028867648569073954, 0.01719605675264037],
                                [0.9539362946782857, 0.010825220107479883, 0.03523848521423444],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.7733982222804657, 0.14200899468786973, 0.08459278303166451],
                                [0.7733982222804657, 0.05325264442858102, 0.17334913329095322],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.509021214230797, 0.3076913362367896, 0.18328744953241333],
                                [0.509021214230797, 0.11538267247357925, 0.3755961132956237],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.24464420618112837, 0.4733736777857095, 0.28198211603316214],
                                [0.24464420618112837, 0.17751270051857748, 0.5778430933002942],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.06410613378330843, 0.5865150239045054, 0.34937884231218624],
                                [0.06410613378330843, 0.21994012483967862, 0.715953741377013],
                                [0.953089922969332, 0.03858294257541965, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.9572534901969562, 0.02886764856907395, 0.013878861233969884],
                                [0.9572534901969562, 0.010825220107479883, 0.03192128969556395],
                                [0.7692346550528415, 0.1898015653794873, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.7897165448366771, 0.14200899468786973, 0.06827446047545313],
                                [0.7897165448366772, 0.05325264442858105, 0.15703081073474182],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.5443781751296444, 0.30769133623678957, 0.14793048863356603],
                                [0.5443781751296444, 0.11538267247357925, 0.3402391523967764],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.2990398054226117, 0.47337367778570943, 0.2275865167916789],
                                [0.29903980542261166, 0.17751270051857748, 0.5234474940588109],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332902],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.13150286006233258, 0.5865150239045053, 0.28198211603316214],
                                [0.13150286006233258, 0.21994012483967862, 0.6485570150979888],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.962111137200129, 0.02886764856907395, 0.009021214230797034],
                                [0.962111137200129, 0.01082522010747988, 0.027063642692391105],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.8136128301824859, 0.14200899468786976, 0.04437817512964435],
                                [0.8136128301824859, 0.05325264442858105, 0.13313452538893306],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.5961543318816052, 0.3076913362367897, 0.09615433188160519],
                                [0.5961543318816052, 0.11538267247357925, 0.2884629956448156],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.3786958335807245, 0.47337367778570955, 0.147930488633566],
                                [0.37869583358072445, 0.17751270051857748, 0.44379146590069807],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.23019752656308134, 0.5865150239045054, 0.18328744953241333],
                                [0.23019752656308134, 0.21994012483967862, 0.54986234859724],
                                [0.953089922969332, 0.019152354562728253, 0.027757722467939765],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.9669687842033018, 0.028867648569073947, 0.004163567227624186],
                                [0.9669687842033019, 0.01082522010747988, 0.022205995689218255],
                                [0.7692346550528416, 0.09421642399625221, 0.13654892095090623],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.8375091155282947, 0.14200899468786973, 0.020481889783835583],
                                [0.8375091155282947, 0.053252644428581034, 0.10923824004312428],
                                [0.5, 0.204139022732868, 0.295860977267132],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.647930488633566, 0.3076913362367896, 0.04437817512964437],
                                [0.6479304886335661, 0.11538267247357925, 0.23668683889285475],
                                [0.23076534494715856, 0.31406162146948374, 0.45517303358335776],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.45835186173883735, 0.4733736777857095, 0.06827446047545316],
                                [0.45835186173883735, 0.17751270051857748, 0.36413543774258517],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.3288921930638302, 0.5865150239045053, 0.08459278303166455],
                                [0.3288921930638303, 0.21994012483967856, 0.4511676820964912],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.971132351430926, 0.010825220107479883, 0.018042428461594068],
                                [0.9702859797219723, 0.02886764856907395, 0.000846371708953696],
                                [0.9702859797219724, 0.010825220107479883, 0.018888800170547764],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8579910053121302, 0.053252644428581034, 0.0887563502592887],
                                [0.853827438084506, 0.14200899468786973, 0.004163567227624191],
                                [0.8538274380845061, 0.05325264442858105, 0.09291991748691289],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6923086637632104, 0.11538267247357925, 0.19230866376321037],
                                [0.6832874495324133, 0.3076913362367896, 0.009021214230797048],
                                [0.6832874495324134, 0.11538267247357925, 0.20132987799400742],
                                [0.2307653449471585, 0.20527042298651732, 0.5639642320663242],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.5266263222142905, 0.17751270051857748, 0.295860977267132],
                                [0.5127474609803206, 0.47337367778570943, 0.013878861233969903],
                                [0.5127474609803206, 0.17751270051857743, 0.3097398385011019],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.4134849760954947, 0.21994012483967862, 0.36657489906482665],
                                [0.3962889193428544, 0.5865150239045053, 0.0171960567526404],
                                [0.3962889193428543, 0.21994012483967856, 0.38377095581746706],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.954392039868499, 0.019152354562728256, 0.026455605568772807],
                                [0.954392039868499, 0.010825220107479883, 0.03478274002402118],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.7756401754531032, 0.09421642399625221, 0.13014340055064463],
                                [0.7756401754531032, 0.05325264442858105, 0.1711071801183158],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.5138788612339699, 0.204139022732868, 0.28198211603316214],
                                [0.5138788612339699, 0.11538267247357925, 0.3707384662924509],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.2521175470148366, 0.3140616214694838, 0.43382083151567963],
                                [0.2521175470148366, 0.17751270051857748, 0.5703697524665859],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.07336568259944087, 0.38912569090300764, 0.5375086264975515],
                                [0.07336568259944087, 0.21994012483967862, 0.7066941925608805],
                                [0.953089922969332, 0.03858294257541965, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.9594954433695936, 0.019152354562728256, 0.021352202067678155],
                                [0.9594954433695936, 0.010825220107479883, 0.02967933652292653],
                                [0.7692346550528415, 0.1898015653794873, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.8007454138982397, 0.0942164239962522, 0.1050381621055081],
                                [0.8007454138982397, 0.05325264442858105, 0.14600194167317926],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.5682744604754532, 0.204139022732868, 0.2275865167916789],
                                [0.5682744604754532, 0.11538267247357925, 0.31634286705096765],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.33580350705266665, 0.31406162146948374, 0.35013487147784966],
                                [0.33580350705266665, 0.17751270051857743, 0.486683792428756],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332902],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.17705347758131262, 0.38912569090300775, 0.43382083151567963],
                                [0.17705347758131262, 0.21994012483967862, 0.6030063975790088],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.9669687842033019, 0.01915235456272825, 0.013878861233969883],
                                [0.9669687842033019, 0.01082522010747988, 0.022205995689218255],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.8375091155282947, 0.0942164239962522, 0.06827446047545312],
                                [0.8375091155282947, 0.053252644428581034, 0.10923824004312428],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.6479304886335661, 0.204139022732868, 0.147930488633566],
                                [0.6479304886335661, 0.11538267247357925, 0.23668683889285475],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.45835186173883735, 0.3140616214694838, 0.22758651679167888],
                                [0.45835186173883735, 0.17751270051857748, 0.36413543774258517],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.32889219306383016, 0.3891256909030077, 0.2819821160331621],
                                [0.3288921930638303, 0.21994012483967856, 0.4511676820964912],
                                [0.953089922969332, 0.019152354562728253, 0.027757722467939765],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.9744421250370101, 0.019152354562728256, 0.006405520400261611],
                                [0.9744421250370101, 0.010825220107479883, 0.014732654855509984],
                                [0.7692346550528416, 0.09421642399625221, 0.13654892095090623],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.8742728171583497, 0.09421642399625223, 0.031510758845398154],
                                [0.8742728171583497, 0.05325264442858106, 0.07247453841306932],
                                [0.5, 0.204139022732868, 0.295860977267132],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.7275865167916789, 0.20413902273286802, 0.06827446047545313],
                                [0.7275865167916789, 0.11538267247357928, 0.15703081073474187],
                                [0.23076534494715856, 0.31406162146948374, 0.45517303358335776],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.5809002164250081, 0.3140616214694838, 0.10503816210550809],
                                [0.5809002164250081, 0.17751270051857748, 0.2415870830564144],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.4807309085463476, 0.38912569090300775, 0.13014340055064463],
                                [0.48073090854634754, 0.21994012483967867, 0.29932896661397373],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9808476454372718, 0.010825220107479881, 0.008327134455248372],
                                [0.9795455285381048, 0.019152354562728253, 0.001302116899166962],
                                [0.9795455285381048, 0.010825220107479881, 0.009629251354415334],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9057835760037478, 0.053252644428581034, 0.040963779567671166],
                                [0.8993780556034862, 0.0942164239962522, 0.006405520400261627],
                                [0.8993780556034862, 0.053252644428581034, 0.04736929996793279],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.795860977267132, 0.11538267247357925, 0.08875635025928874],
                                [0.781982116033162, 0.204139022732868, 0.013878861233969919],
                                [0.781982116033162, 0.11538267247357925, 0.10263521149325866],
                                [0.2307653449471585, 0.20527042298651732, 0.5639642320663242],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.6859383785305162, 0.17751270051857743, 0.13654892095090632],
                                [0.664586176462838, 0.3140616214694838, 0.02135220206767821],
                                [0.664586176462838, 0.17751270051857745, 0.15790112301858453],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.6108743090969923, 0.2199401248396786, 0.1691855660633291],
                                [0.5844187035282193, 0.38912569090300775, 0.026455605568772876],
                                [0.5844187035282193, 0.21994012483967862, 0.19564117163210198],
                                [0.953089922969332, 0.045217333612760625, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.9547032596631122, 0.012517963525387275, 0.03277877681150055],
                                [0.9547032596631122, 0.010825220107479883, 0.03447152022940794],
                                [0.7692346550528416, 0.22243821049191007, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.7771711629893495, 0.0615797788838294, 0.1612490581268211],
                                [0.7771711629893495, 0.05325264442858102, 0.1695761925820695],
                                [0.5, 0.4819575715384059, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.5171960567526404, 0.13342510093517335, 0.3493788423121863],
                                [0.5171960567526404, 0.11538267247357925, 0.3674212707737804],
                                [0.2307653449471585, 0.7414769325849018, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.2572209505159313, 0.2052704229865172, 0.5375086264975515],
                                [0.2572209505159313, 0.17751270051857748, 0.5652663489654912],
                                [0.046910077030668074, 0.9186978094640512, 0.03439211350528074],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.07968885384216862, 0.2543322383449593, 0.6659789078128721],
                                [0.07968885384216862, 0.21994012483967862, 0.7003710213181528],
                                [0.953089922969332, 0.03858294257541965, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.96102643090584, 0.012517963525387275, 0.026455605568772807],
                                [0.96102643090584, 0.010825220107479883, 0.0281483489866802],
                                [0.7692346550528415, 0.1898015653794873, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.808276820565526, 0.06157977888382943, 0.13014340055064463],
                                [0.808276820565526, 0.05325264442858105, 0.13847053500589301],
                                [0.49999999999999994, 0.4112436497407113, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.5845927830316645, 0.13342510093517335, 0.28198211603316214],
                                [0.5845927830316645, 0.11538267247357925, 0.30002454449475624],
                                [0.2307653449471585, 0.6326857341019353, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.36090874549780316, 0.2052704229865172, 0.43382083151567963],
                                [0.3609087454978031, 0.17751270051857743, 0.4615785539836194],
                                [0.046910077030668074, 0.7839043569060029, 0.16918556606332902],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.20815913515748918, 0.2543322383449593, 0.5375086264975515],
                                [0.20815913515748918, 0.21994012483967862, 0.5719007400028322],
                                [0.9530899229693319, 0.02886764856907395, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.9702859797219724, 0.012517963525387275, 0.01719605675264037],
                                [0.9702859797219724, 0.010825220107479883, 0.018888800170547764],
                                [0.7692346550528415, 0.14200899468786976, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.8538274380845061, 0.06157977888382943, 0.08459278303166451],
                                [0.8538274380845061, 0.05325264442858105, 0.09291991748691289],
                                [0.5, 0.3076913362367896, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.6832874495324134, 0.13342510093517335, 0.18328744953241333],
                                [0.6832874495324134, 0.11538267247357925, 0.20132987799400742],
                                [0.2307653449471585, 0.4733736777857095, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.5127474609803206, 0.2052704229865172, 0.28198211603316214],
                                [0.5127474609803206, 0.17751270051857743, 0.3097398385011019],
                                [0.046910077030668074, 0.5865150239045053, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.39628891934285443, 0.2543322383449594, 0.34937884231218624],
                                [0.3962889193428543, 0.21994012483967856, 0.38377095581746706],
                                [0.953089922969332, 0.019152354562728253, 0.027757722467939765],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.9795455285381048, 0.012517963525387274, 0.007936507936507938],
                                [0.9795455285381048, 0.010825220107479883, 0.009629251354415329],
                                [0.7692346550528416, 0.09421642399625221, 0.13654892095090623],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.8993780556034863, 0.061579778883829414, 0.039042165512684385],
                                [0.8993780556034863, 0.053252644428581034, 0.047369299967932765],
                                [0.5, 0.204139022732868, 0.295860977267132],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.7819821160331621, 0.13342510093517335, 0.08459278303166451],
                                [0.7819821160331621, 0.11538267247357925, 0.1026352114932586],
                                [0.23076534494715856, 0.31406162146948374, 0.45517303358335776],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.6645861764628381, 0.20527042298651724, 0.13014340055064463],
                                [0.664586176462838, 0.17751270051857743, 0.15790112301858444],
                                [0.046910077030668074, 0.38912569090300764, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.5844187035282195, 0.25433223834495944, 0.16124905812682108],
                                [0.5844187035282196, 0.21994012483967862, 0.19564117163210187],
                                [0.953089922969332, 0.012517963525387275, 0.03439211350528074],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9874820364746127, 0.010825220107479881, 0.001692743417907392],
                                [0.9858686997808326, 0.012517963525387274, 0.0016133366937802012],
                                [0.9858686997808325, 0.010825220107479883, 0.003306080111687593],
                                [0.7692346550528415, 0.06157977888382943, 0.16918556606332902],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9384202211161706, 0.05325264442858104, 0.008327134455248382],
                                [0.9304837131796627, 0.06157977888382942, 0.007936507936507955],
                                [0.9304837131796626, 0.05325264442858104, 0.016263642391756337],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8665748990648267, 0.11538267247357925, 0.018042428461594096],
                                [0.8493788423121863, 0.13342510093517335, 0.01719605675264041],
                                [0.8493788423121863, 0.11538267247357925, 0.035238485214234505],
                                [0.2307653449471585, 0.20527042298651732, 0.5639642320663242],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7947295770134827, 0.17751270051857745, 0.027757722467939807],
                                [0.7682739714447098, 0.20527042298651726, 0.026455605568772862],
                                [0.7682739714447099, 0.17751270051857745, 0.05421332803671267],
                                [0.046910077030668074, 0.25433223834495944, 0.6987576846243725],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.7456677616550406, 0.2199401248396786, 0.0343921135052808],
                                [0.7128889848435399, 0.25433223834495944, 0.03277877681150062],
                                [0.71288898484354, 0.21994012483967862, 0.06717089031678142],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9531883087454857, 0.04481274992354572, 0.0019989413309686867],
                                [0.9531883087454855, 0.002200555327023214, 0.04461113592749119],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7697186454661836, 0.2204479367487944, 0.009833417785021958],
                                [0.7697186454661836, 0.010825220107479883, 0.21945613442633646],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5010486635535611, 0.4776452391481776, 0.021306097298261256],
                                [0.5010486635535611, 0.023455038515334037, 0.4754962979311048],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.23237868164093867, 0.7348425415475608, 0.03277877681150055],
                                [0.23237868164093867, 0.03608485692318819, 0.7315364614358731],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.04890901836163675, 0.9104777283728094, 0.040613253265553824],
                                [0.04890901836163675, 0.04470952170364484, 0.9063814599347184],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9535739133826742, 0.04481274992354572, 0.001613336693780198],
                                [0.953573913382674, 0.002200555327023214, 0.044225531290302704],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7716155553146977, 0.2204479367487944, 0.00793650793650794],
                                [0.7716155553146977, 0.010825220107479883, 0.21755922457782245],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5051587040991821, 0.47764523914817764, 0.017196056752640375],
                                [0.5051587040991821, 0.023455038515334037, 0.47138625738548395],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.2387018528836664, 0.7348425415475608, 0.02645560556877281],
                                [0.2387018528836664, 0.03608485692318819, 0.7252132901931454],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.056743494815689965, 0.9104777283728095, 0.03277877681150055],
                                [0.056743494815689965, 0.04470952170364484, 0.8985469834806652],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9541385865228932, 0.04481274992354571, 0.001048663553561151],
                                [0.9541385865228931, 0.002200555327023207, 0.04366085815008366],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7743933591520236, 0.22044793674879437, 0.005158704099182031],
                                [0.7743933591520236, 0.010825220107479883, 0.21478142074049653],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5111773804259112, 0.4776452391481776, 0.011177380425911203],
                                [0.5111773804259112, 0.023455038515334037, 0.46536758105875475],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.24796140169979886, 0.7348425415475608, 0.017196056752640375],
                                [0.24796140169979886, 0.03608485692318819, 0.715953741377013],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.06821617432892935, 0.9104777283728094, 0.021306097298261252],
                                [0.06821617432892935, 0.04470952170364484, 0.8870743039674258],
                                [0.953089922969332, 0.012517963525387268, 0.03439211350528075],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9547032596631122, 0.04481274992354572, 0.0004839904133421039],
                                [0.9547032596631122, 0.002200555327023214, 0.04309618500986461],
                                [0.7692346550528416, 0.0615797788838294, 0.16918556606332905],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7771711629893495, 0.2204479367487944, 0.002380900261856123],
                                [0.7771711629893495, 0.010825220107479883, 0.21200361690317063],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5171960567526404, 0.47764523914817764, 0.005158704099182031],
                                [0.5171960567526404, 0.023455038515334037, 0.4593489047320256],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.2572209505159313, 0.7348425415475608, 0.007936507936507938],
                                [0.2572209505159313, 0.03608485692318819, 0.7066941925608805],
                                [0.046910077030668074, 0.2543322383449593, 0.6987576846243726],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.07968885384216862, 0.9104777283728094, 0.009833417785021958],
                                [0.07968885384216862, 0.04470952170364484, 0.8756016244541865],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9551872500764542, 0.002200555327023214, 0.042612194596522504],
                                [0.9550888643003007, 0.04481274992354572, 9.838577615361554e-05],
                                [0.9550888643003006, 0.002200555327023214, 0.04271058037267612],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.7795520632512056, 0.010825220107479883, 0.2096227166413145],
                                [0.7790680728378635, 0.22044793674879437, 0.0004839904133421051],
                                [0.7790680728378635, 0.010825220107479883, 0.2101067070546566],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.5223547608518224, 0.023455038515334037, 0.45419020063284354],
                                [0.5213060972982613, 0.4776452391481776, 0.0010486635535611535],
                                [0.5213060972982613, 0.023455038515334037, 0.4552388641864047],
                                [0.2307653449471585, 0.07047697042846901, 0.6987576846243725],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2651574584524393, 0.03608485692318808, 0.6987576846243726],
                                [0.26354412175865904, 0.7348425415475608, 0.0016133366937802018],
                                [0.26354412175865904, 0.03608485692318819, 0.7003710213181528],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.08952227162719062, 0.04470952170364484, 0.8657682066691645],
                                [0.08752333029622195, 0.9104777283728094, 0.0019989413309686914],
                                [0.08752333029622195, 0.04470952170364484, 0.8677671480001332],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.953573913382674, 0.03659266883230396, 0.009833417785021958],
                                [0.953573913382674, 0.002200555327023214, 0.044225531290302704],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.7716155553146977, 0.18001078617080896, 0.04837365851449339],
                                [0.7716155553146977, 0.010825220107479883, 0.21755922457782245],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5051587040991821, 0.39002993758016075, 0.10481135832065724],
                                [0.5051587040991821, 0.023455038515334037, 0.47138625738548395],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.2387018528836664, 0.6000490889895125, 0.16124905812682108],
                                [0.2387018528836664, 0.03608485692318819, 0.7252132901931454],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.056743494815689965, 0.7434672063280175, 0.1997892988562925],
                                [0.056743494815689965, 0.04470952170364484, 0.8985469834806652],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.9554708232311881, 0.03659266883230396, 0.007936507936507938],
                                [0.955470823231188, 0.002200555327023207, 0.042328621441788686],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.7809470483165066, 0.18001078617080896, 0.03904216551268439],
                                [0.7809470483165066, 0.01082522010747991, 0.20822773157601343],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5253772793881748, 0.39002993758016075, 0.08459278303166452],
                                [0.5253772793881748, 0.023455038515334037, 0.4511676820964912],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.26980751045984286, 0.6000490889895125, 0.13014340055064463],
                                [0.26980751045984286, 0.03608485692318819, 0.694107632616969],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.09528373554516145, 0.7434672063280174, 0.1612490581268211],
                                [0.09528373554516145, 0.04470952170364484, 0.8600067427511937],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.958248627068514, 0.03659266883230396, 0.005158704099182031],
                                [0.958248627068514, 0.002200555327023214, 0.039550817604462774],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.7946119344410163, 0.1800107861708089, 0.02537727938817476],
                                [0.7946119344410163, 0.010825220107479883, 0.1945628454515038],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5549850312099197, 0.3900299375801607, 0.05498503120991964],
                                [0.5549850312099196, 0.023455038515334037, 0.4215599302747463],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.315358127978823, 0.6000490889895125, 0.08459278303166452],
                                [0.315358127978823, 0.03608485692318819, 0.6485570150979888],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.15172143535132532, 0.7434672063280174, 0.10481135832065724],
                                [0.15172143535132532, 0.04470952170364484, 0.8035690429450298],
                                [0.953089922969332, 0.012517963525387268, 0.03439211350528075],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.96102643090584, 0.03659266883230396, 0.002380900261856123],
                                [0.96102643090584, 0.002200555327023214, 0.03677301376713687],
                                [0.7692346550528416, 0.0615797788838294, 0.16918556606332905],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.808276820565526, 0.18001078617080893, 0.011712393263665124],
                                [0.808276820565526, 0.010825220107479883, 0.18089795932699418],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.5845927830316644, 0.39002993758016075, 0.02537727938817476],
                                [0.5845927830316645, 0.023455038515334037, 0.39195217845300145],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.36090874549780316, 0.6000490889895125, 0.03904216551268439],
                                [0.36090874549780316, 0.03608485692318819, 0.6030063975790086],
                                [0.046910077030668074, 0.2543322383449593, 0.6987576846243726],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.20815913515748918, 0.7434672063280174, 0.04837365851449339],
                                [0.20815913515748918, 0.04470952170364484, 0.747131343138866],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9634073311676961, 0.002200555327023214, 0.03439211350528074],
                                [0.9629233407543539, 0.03659266883230396, 0.00048399041334210453],
                                [0.9629233407543539, 0.002200555327023214, 0.03487610391862285],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8199892138291911, 0.01082522010747991, 0.16918556606332902],
                                [0.817608313567335, 0.18001078617080893, 0.0023809002618561262],
                                [0.817608313567335, 0.01082522010747991, 0.17156646632518516],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6099700624198393, 0.023455038515334037, 0.36657489906482665],
                                [0.6048113583206572, 0.3900299375801607, 0.005158704099182038],
                                [0.6048113583206572, 0.023455038515334037, 0.3717336031640087],
                                [0.2307653449471585, 0.07047697042846901, 0.6987576846243725],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.39995091101048763, 0.03608485692318808, 0.5639642320663243],
                                [0.3920144030739796, 0.6000490889895125, 0.007936507936507948],
                                [0.3920144030739796, 0.03608485692318819, 0.5719007400028322],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.25653279367198256, 0.04470952170364495, 0.6987576846243725],
                                [0.24669937588696056, 0.7434672063280174, 0.00983341778502197],
                                [0.24669937588696056, 0.04470952170364495, 0.7085911024093945],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9541385865228931, 0.024555316178845613, 0.021306097298261252],
                                [0.9541385865228931, 0.002200555327023207, 0.04366085815008366],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.7743933591520236, 0.12079528252731916, 0.10481135832065724],
                                [0.7743933591520236, 0.010825220107479883, 0.21478142074049653],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.5111773804259112, 0.261727519257667, 0.22709510031642177],
                                [0.5111773804259112, 0.023455038515334037, 0.46536758105875475],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.24796140169979886, 0.40265975598801484, 0.3493788423121863],
                                [0.24796140169979886, 0.03608485692318819, 0.715953741377013],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.06821617432892935, 0.4988997223364884, 0.43288410333458227],
                                [0.06821617432892935, 0.04470952170364484, 0.8870743039674258],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.958248627068514, 0.024555316178845616, 0.01719605675264037],
                                [0.958248627068514, 0.002200555327023214, 0.039550817604462774],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.7946119344410163, 0.12079528252731916, 0.08459278303166451],
                                [0.7946119344410163, 0.010825220107479883, 0.1945628454515038],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.5549850312099197, 0.261727519257667, 0.18328744953241333],
                                [0.5549850312099196, 0.023455038515334037, 0.4215599302747463],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.315358127978823, 0.40265975598801484, 0.28198211603316214],
                                [0.315358127978823, 0.03608485692318819, 0.6485570150979888],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.15172143535132537, 0.49889972233648844, 0.34937884231218624],
                                [0.15172143535132532, 0.04470952170364484, 0.8035690429450298],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9642673033952431, 0.024555316178845613, 0.011177380425911203],
                                [0.9642673033952431, 0.002200555327023207, 0.03353214127773361],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.8242196862627612, 0.12079528252731918, 0.05498503120991964],
                                [0.8242196862627612, 0.01082522010747991, 0.1649550936297589],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.6191362403711665, 0.261727519257667, 0.11913624037116649],
                                [0.6191362403711664, 0.023455038515334037, 0.3574087211134995],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.41405279447957194, 0.4026597559880148, 0.18328744953241333],
                                [0.4140527944795719, 0.03608485692318808, 0.54986234859724],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.27400517734708985, 0.4988997223364884, 0.22709510031642177],
                                [0.27400517734708985, 0.04470952170364484, 0.6812853009492653],
                                [0.953089922969332, 0.012517963525387268, 0.03439211350528075],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9702859797219723, 0.024555316178845613, 0.0051587040991820324],
                                [0.9702859797219723, 0.0022005553270232105, 0.027513464951004436],
                                [0.7692346550528416, 0.0615797788838294, 0.16918556606332905],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.853827438084506, 0.12079528252731916, 0.025377279388174766],
                                [0.8538274380845061, 0.010825220107479883, 0.13534734180801405],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.6832874495324134, 0.261727519257667, 0.054985031209919655],
                                [0.6832874495324133, 0.023455038515334037, 0.29325751195225264],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.5127474609803206, 0.40265975598801484, 0.08459278303166454],
                                [0.5127474609803206, 0.036084856923188136, 0.4511676820964912],
                                [0.046910077030668074, 0.2543322383449593, 0.6987576846243726],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.3962889193428544, 0.4988997223364884, 0.10481135832065727],
                                [0.3962889193428544, 0.04470952170364484, 0.5590015589535008],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9754446838211543, 0.002200555327023207, 0.022354760851822406],
                                [0.9743960202675932, 0.024555316178845616, 0.0010486635535611516],
                                [0.9743960202675932, 0.0022005553270232105, 0.023403424405383556],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8792047174726808, 0.010825220107479883, 0.10997006241983928],
                                [0.8740460133734987, 0.12079528252731916, 0.005158704099182034],
                                [0.8740460133734989, 0.010825220107479896, 0.1151287665190213],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.738272480742333, 0.023455038515334037, 0.23827248074233298],
                                [0.7270951003164218, 0.261727519257667, 0.01117738042591121],
                                [0.7270951003164218, 0.023455038515334037, 0.2494498611682442],
                                [0.2307653449471585, 0.07047697042846901, 0.6987576846243725],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.5973402440119852, 0.03608485692318819, 0.36657489906482665],
                                [0.5801441872593449, 0.4026597559880148, 0.017196056752640385],
                                [0.5801441872593447, 0.036084856923188136, 0.38377095581746706],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.5011002776635116, 0.04470952170364484, 0.45419020063284354],
                                [0.47979418036525034, 0.4988997223364884, 0.021306097298261266],
                                [0.47979418036525034, 0.04470952170364484, 0.4754962979311048],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.9547032596631122, 0.012517963525387275, 0.03277877681150055],
                                [0.9547032596631122, 0.002200555327023214, 0.04309618500986461],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.7771711629893495, 0.0615797788838294, 0.1612490581268211],
                                [0.7771711629893495, 0.010825220107479883, 0.21200361690317063],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.5171960567526404, 0.13342510093517335, 0.3493788423121863],
                                [0.5171960567526404, 0.023455038515334037, 0.4593489047320256],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.2572209505159313, 0.2052704229865172, 0.5375086264975515],
                                [0.2572209505159313, 0.03608485692318819, 0.7066941925608805],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.07968885384216862, 0.2543322383449593, 0.6659789078128721],
                                [0.07968885384216862, 0.04470952170364484, 0.8756016244541865],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.96102643090584, 0.012517963525387275, 0.026455605568772807],
                                [0.96102643090584, 0.002200555327023214, 0.03677301376713687],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.808276820565526, 0.06157977888382943, 0.13014340055064463],
                                [0.808276820565526, 0.010825220107479883, 0.18089795932699418],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.5845927830316645, 0.13342510093517335, 0.28198211603316214],
                                [0.5845927830316645, 0.023455038515334037, 0.39195217845300145],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.36090874549780316, 0.2052704229865172, 0.43382083151567963],
                                [0.36090874549780316, 0.03608485692318819, 0.6030063975790086],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.20815913515748918, 0.2543322383449593, 0.5375086264975515],
                                [0.20815913515748918, 0.04470952170364484, 0.747131343138866],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.9702859797219724, 0.012517963525387275, 0.01719605675264037],
                                [0.9702859797219723, 0.0022005553270232105, 0.027513464951004436],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.8538274380845061, 0.06157977888382943, 0.08459278303166451],
                                [0.8538274380845061, 0.010825220107479883, 0.13534734180801405],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.6832874495324134, 0.13342510093517335, 0.18328744953241333],
                                [0.6832874495324133, 0.023455038515334037, 0.29325751195225264],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.5127474609803206, 0.2052704229865172, 0.28198211603316214],
                                [0.5127474609803206, 0.036084856923188136, 0.4511676820964912],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.39628891934285443, 0.2543322383449594, 0.34937884231218624],
                                [0.3962889193428544, 0.04470952170364484, 0.5590015589535008],
                                [0.953089922969332, 0.012517963525387268, 0.03439211350528075],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.9795455285381048, 0.012517963525387274, 0.007936507936507938],
                                [0.9795455285381047, 0.0022005553270232105, 0.018253916134872],
                                [0.7692346550528416, 0.0615797788838294, 0.16918556606332905],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.8993780556034863, 0.061579778883829414, 0.039042165512684385],
                                [0.8993780556034862, 0.010825220107479883, 0.08979672428903392],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.7819821160331621, 0.13342510093517335, 0.08459278303166451],
                                [0.7819821160331621, 0.023455038515334037, 0.19456284545150382],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.6645861764628381, 0.20527042298651724, 0.13014340055064463],
                                [0.6645861764628381, 0.03608485692318819, 0.2993289666139737],
                                [0.046910077030668074, 0.2543322383449593, 0.6987576846243726],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.5844187035282195, 0.25433223834495944, 0.16124905812682108],
                                [0.5844187035282196, 0.044709521703644894, 0.3708717747681356],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9874820364746127, 0.0022005553270232087, 0.010317408198364065],
                                [0.9858686997808326, 0.012517963525387274, 0.0016133366937802012],
                                [0.9858686997808325, 0.0022005553270232105, 0.011930744892144265],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9384202211161706, 0.01082522010747989, 0.05075455877634953],
                                [0.9304837131796627, 0.06157977888382942, 0.007936507936507955],
                                [0.9304837131796626, 0.010825220107479896, 0.05869106671285748],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8665748990648267, 0.023455038515334037, 0.10997006241983931],
                                [0.8493788423121863, 0.13342510093517335, 0.01719605675264041],
                                [0.8493788423121862, 0.023455038515334037, 0.12716611917247972],
                                [0.2307653449471585, 0.07047697042846901, 0.6987576846243725],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7947295770134828, 0.03608485692318819, 0.16918556606332907],
                                [0.7682739714447098, 0.20527042298651726, 0.026455605568772862],
                                [0.7682739714447099, 0.03608485692318819, 0.19564117163210193],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.7456677616550407, 0.04470952170364484, 0.20962271664131454],
                                [0.7128889848435399, 0.25433223834495944, 0.03277877681150062],
                                [0.71288898484354, 0.04470952170364487, 0.24240149345281517],
                                [0.953089922969332, 0.04481274992354572, 0.002097327107122302],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9550888643003006, 0.004297882434145514, 0.04061325326555382],
                                [0.9550888643003006, 0.002200555327023214, 0.04271058037267612],
                                [0.7692346550528416, 0.22044793674879437, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.7790680728378636, 0.021142628305843958, 0.1997892988562925],
                                [0.7790680728378635, 0.010825220107479883, 0.2101067070546566],
                                [0.5, 0.4776452391481776, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.5213060972982613, 0.045809799367156456, 0.43288410333458227],
                                [0.5213060972982613, 0.023455038515334037, 0.4552388641864047],
                                [0.2307653449471585, 0.7348425415475608, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.26354412175865904, 0.07047697042846901, 0.665978907812872],
                                [0.26354412175865904, 0.03608485692318819, 0.7003710213181528],
                                [0.046910077030668074, 0.9104777283728094, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.08752333029622195, 0.08732171630016738, 0.8251549534036107],
                                [0.08752333029622195, 0.04470952170364484, 0.8677671480001332],
                                [0.953089922969332, 0.03659266883230396, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9629233407543539, 0.004297882434145514, 0.03277877681150055],
                                [0.9629233407543539, 0.002200555327023214, 0.03487610391862285],
                                [0.7692346550528416, 0.18001078617080893, 0.05075455877634952],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.8176083135673349, 0.021142628305843958, 0.1612490581268211],
                                [0.817608313567335, 0.01082522010747991, 0.17156646632518516],
                                [0.5, 0.3900299375801607, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.6048113583206572, 0.045809799367156456, 0.3493788423121863],
                                [0.6048113583206572, 0.023455038515334037, 0.3717336031640087],
                                [0.2307653449471585, 0.6000490889895125, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.3920144030739796, 0.0704769704284689, 0.5375086264975515],
                                [0.3920144030739796, 0.03608485692318819, 0.5719007400028322],
                                [0.046910077030668074, 0.7434672063280174, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.24669937588696056, 0.08732171630016738, 0.6659789078128721],
                                [0.24669937588696056, 0.04470952170364495, 0.7085911024093945],
                                [0.9530899229693319, 0.024555316178845613, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9743960202675932, 0.004297882434145514, 0.021306097298261252],
                                [0.9743960202675932, 0.0022005553270232105, 0.023403424405383556],
                                [0.7692346550528415, 0.12079528252731916, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.8740460133734989, 0.021142628305843958, 0.10481135832065724],
                                [0.8740460133734989, 0.010825220107479896, 0.1151287665190213],
                                [0.5, 0.261727519257667, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.7270951003164218, 0.045809799367156456, 0.22709510031642177],
                                [0.7270951003164218, 0.023455038515334037, 0.2494498611682442],
                                [0.2307653449471585, 0.40265975598801484, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.5801441872593448, 0.0704769704284689, 0.3493788423121863],
                                [0.5801441872593447, 0.036084856923188136, 0.38377095581746706],
                                [0.046910077030668074, 0.4988997223364884, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.47979418036525034, 0.08732171630016738, 0.43288410333458227],
                                [0.47979418036525034, 0.04470952170364484, 0.4754962979311048],
                                [0.953089922969332, 0.012517963525387268, 0.03439211350528075],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9858686997808325, 0.004297882434145512, 0.009833417785021958],
                                [0.9858686997808325, 0.0022005553270232105, 0.01193074489214426],
                                [0.7692346550528416, 0.0615797788838294, 0.16918556606332905],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.9304837131796626, 0.021142628305843958, 0.04837365851449339],
                                [0.9304837131796626, 0.01082522010747989, 0.05869106671285746],
                                [0.5, 0.13342510093517335, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.8493788423121863, 0.045809799367156456, 0.10481135832065724],
                                [0.8493788423121863, 0.023455038515334037, 0.12716611917247966],
                                [0.2307653449471585, 0.2052704229865172, 0.5639642320663243],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.76827397144471, 0.07047697042846895, 0.16124905812682108],
                                [0.76827397144471, 0.03608485692318819, 0.19564117163210185],
                                [0.046910077030668074, 0.2543322383449593, 0.6987576846243726],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.7128889848435401, 0.08732171630016741, 0.1997892988562925],
                                [0.7128889848435401, 0.04470952170364487, 0.24240149345281506],
                                [0.9530899229693319, 0.004297882434145514, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9957021175658545, 0.00220055532702321, 0.002097327107122303],
                                [0.9937031762348858, 0.004297882434145513, 0.001998941330968688],
                                [0.9937031762348858, 0.0022005553270232105, 0.004096268438090991],
                                [0.7692346550528415, 0.021142628305843958, 0.2096227166413145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9788573716941561, 0.010825220107479893, 0.010317408198364068],
                                [0.9690239539091341, 0.021142628305843958, 0.009833417785021966],
                                [0.9690239539091341, 0.01082522010747989, 0.020150825983386036],
                                [0.5, 0.045809799367156456, 0.45419020063284354],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9541902006328435, 0.023455038515334037, 0.02235476085182242],
                                [0.9328841033345823, 0.045809799367156456, 0.021306097298261273],
                                [0.9328841033345823, 0.023455038515334037, 0.04366085815008369],
                                [0.2307653449471585, 0.07047697042846901, 0.6987576846243725],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.929523029571531, 0.03608485692318817, 0.03439211350528077],
                                [0.8967442527600304, 0.07047697042846895, 0.03277877681150058],
                                [0.8967442527600304, 0.03608485692318818, 0.06717089031678135],
                                [0.046910077030668074, 0.08732171630016738, 0.8657682066691645],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9126782836998326, 0.04470952170364487, 0.04261219459652253],
                                [0.8720650304342787, 0.0873217163001674, 0.04061325326555386],
                                [0.8720650304342787, 0.04470952170364487, 0.08322544786207639],
                            ]
                        ),
                        np.array(
                            [
                                [0.9531931511892329, 0.002097327107122302, 0.04470952170364481],
                                [0.9530947654130792, 9.838577615361527e-05, 0.04680684881076711],
                                [0.9530899229693319, 4.842443747290214e-06, 0.04690523458692073],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.00010322821990090549, 0.04680684881076711],
                                [0.7697424669619574, 0.010317408198364061, 0.21994012483967856],
                                [0.7692584765486152, 0.0004839904133421038, 0.2302575330380426],
                                [0.7692346550528415, 2.382149577371358e-05, 0.23074152345138474],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.0005078119091158174, 0.23025753303804264],
                                [0.5011002776635116, 0.022354760851822406, 0.47654496148466596],
                                [0.5000516141099505, 0.0010486635535611507, 0.4988997223364884],
                                [0.5, 5.1614109950452745e-05, 0.49994838589004953],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.0011002776635116035, 0.4988997223364884],
                                [0.23245808836506582, 0.03439211350528075, 0.7331497981296534],
                                [0.23084475167128568, 0.0016133366937801975, 0.7675419116349341],
                                [0.23076534494715853, 7.94067241271919e-05, 0.7691552483287143],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.0016927434179073895, 0.7675419116349341],
                                [0.04900740413779041, 0.042612194596522504, 0.9083804012656871],
                                [0.04700846280682168, 0.0019989413309686862, 0.9509925958622096],
                                [0.04691007703066808, 9.838577615361527e-05, 0.9529915371931783],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066807, 0.0020973271071223014, 0.9509925958622096],
                                [0.9531931511892329, 0.002097327107122302, 0.04470952170364481],
                                [0.9531137444651057, 7.940672412719192e-05, 0.04680684881076711],
                                [0.9530899229693319, 2.382149577371358e-05, 0.046886255534894304],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.00010322821990090549, 0.04680684881076711],
                                [0.7697424669619574, 0.010317408198364061, 0.21994012483967856],
                                [0.7693518404432169, 0.00039062651874043075, 0.2302575330380426],
                                [0.7692346550528415, 0.00011718539037538668, 0.23064815955678306],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.0005078119091158174, 0.23025753303804264],
                                [0.5011002776635116, 0.022354760851822406, 0.47654496148466596],
                                [0.5002539059545579, 0.0008463717089536949, 0.4988997223364884],
                                [0.49999999999999994, 0.0002539059545579087, 0.49974609404544207],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.0011002776635116035, 0.4988997223364884],
                                [0.23245808836506582, 0.03439211350528075, 0.7331497981296534],
                                [0.23115597146589892, 0.0013021168991669589, 0.7675419116349341],
                                [0.2307653449471585, 0.0003906265187404307, 0.768844028534101],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.0016927434179073895, 0.7675419116349341],
                                [0.04900740413779041, 0.042612194596522504, 0.9083804012656871],
                                [0.04739406744401017, 0.0016133366937801977, 0.9509925958622096],
                                [0.046910077030668094, 0.00048399041334210377, 0.9526059325559898],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066807, 0.0020973271071223014, 0.9509925958622096],
                                [0.9531931511892329, 0.002097327107122302, 0.04470952170364481],
                                [0.9531415370792824, 5.1614109950452745e-05, 0.04680684881076712],
                                [0.9530899229693319, 5.1614109950452745e-05, 0.04685846292071757],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.00010322821990090549, 0.04680684881076711],
                                [0.7697424669619574, 0.010317408198364061, 0.21994012483967856],
                                [0.7694885610073995, 0.0002539059545579087, 0.23025753303804264],
                                [0.7692346550528416, 0.0002539059545579087, 0.23051143899260054],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.0005078119091158174, 0.23025753303804264],
                                [0.5011002776635116, 0.022354760851822406, 0.47654496148466596],
                                [0.5005501388317558, 0.0005501388317558017, 0.4988997223364884],
                                [0.5, 0.0005501388317558017, 0.4994498611682442],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.0011002776635116035, 0.4988997223364884],
                                [0.23245808836506582, 0.03439211350528075, 0.7331497981296534],
                                [0.2316117166561123, 0.0008463717089536947, 0.767541911634934],
                                [0.23076534494715856, 0.0008463717089536947, 0.7683882833438878],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.0016927434179073895, 0.7675419116349341],
                                [0.04900740413779041, 0.042612194596522504, 0.9083804012656871],
                                [0.04795874058422921, 0.0010486635535611507, 0.9509925958622096],
                                [0.04691007703066807, 0.0010486635535611507, 0.9520412594157708],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066807, 0.0020973271071223014, 0.9509925958622096],
                                [0.9531931511892329, 0.002097327107122302, 0.04470952170364481],
                                [0.9531693296934591, 2.3821495773713587e-05, 0.04680684881076711],
                                [0.9530899229693319, 7.94067241271919e-05, 0.046830670306540825],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.00010322821990090549, 0.04680684881076711],
                                [0.7697424669619574, 0.010317408198364061, 0.21994012483967856],
                                [0.7696252815715819, 0.0001171853903753867, 0.23025753303804264],
                                [0.7692346550528416, 0.00039062651874043075, 0.230374718428418],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.0005078119091158174, 0.23025753303804264],
                                [0.5011002776635116, 0.022354760851822406, 0.47654496148466596],
                                [0.5008463717089537, 0.00025390595455790875, 0.4988997223364884],
                                [0.5, 0.0008463717089536947, 0.4991536282910463],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.0011002776635116035, 0.4988997223364884],
                                [0.23245808836506582, 0.03439211350528075, 0.7331497981296534],
                                [0.23206746184632543, 0.0003906265187404308, 0.7675419116349341],
                                [0.23076534494715847, 0.0013021168991669586, 0.7679325381536746],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.0016927434179073895, 0.7675419116349341],
                                [0.04900740413779041, 0.042612194596522504, 0.9083804012656871],
                                [0.04852341372444826, 0.0004839904133421039, 0.9509925958622096],
                                [0.04691007703066804, 0.0016133366937801975, 0.9514765862755518],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066807, 0.0020973271071223014, 0.9509925958622096],
                                [0.9531931511892329, 0.002097327107122302, 0.04470952170364481],
                                [0.9531883087454855, 4.842443747290217e-06, 0.04680684881076712],
                                [0.9530899229693319, 9.838577615361527e-05, 0.046811691254514405],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.00010322821990090549, 0.04680684881076711],
                                [0.7697424669619574, 0.010317408198364061, 0.21994012483967856],
                                [0.7697186454661836, 2.3821495773713598e-05, 0.23025753303804264],
                                [0.7692346550528415, 0.0004839904133421038, 0.23028135453381635],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.0005078119091158174, 0.23025753303804264],
                                [0.5011002776635116, 0.022354760851822406, 0.47654496148466596],
                                [0.5010486635535611, 5.161410995045278e-05, 0.4988997223364884],
                                [0.5, 0.0010486635535611507, 0.49895133644643885],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.0011002776635116035, 0.4988997223364884],
                                [0.23245808836506582, 0.03439211350528075, 0.7331497981296534],
                                [0.2323786816409387, 7.940672412719196e-05, 0.7675419116349341],
                                [0.23076534494715847, 0.0016133366937801975, 0.7676213183590613],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.0016927434179073895, 0.7675419116349341],
                                [0.04900740413779041, 0.042612194596522504, 0.9083804012656871],
                                [0.048909018361636754, 9.838577615361534e-05, 0.9509925958622096],
                                [0.04691007703066806, 0.0019989413309686862, 0.9510909816383633],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066807, 0.0020973271071223014, 0.9509925958622096],
                                [0.9535977348784478, 0.0016927434179073895, 0.04470952170364481],
                                [0.9531137444651057, 0.0004839904133421039, 0.0464022651215522],
                                [0.9530899229693319, 2.3821495773713587e-05, 0.046886255534894304],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.0005078119091158175, 0.046402265121552204],
                                [0.771732740705073, 0.008327134455248368, 0.21994012483967856],
                                [0.7693518404432169, 0.002380900261856123, 0.22826725929492694],
                                [0.7692346550528415, 0.0001171853903753867, 0.23064815955678306],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.00249808565223151, 0.22826725929492694],
                                [0.5054126100537399, 0.018042428461594068, 0.47654496148466596],
                                [0.5002539059545579, 0.005158704099182031, 0.49458738994626006],
                                [0.49999999999999994, 0.00025390595455790875, 0.49974609404544207],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.00541261005373994, 0.49458738994626006],
                                [0.23909247940240683, 0.027757722467939765, 0.7331497981296534],
                                [0.23115597146589892, 0.007936507936507938, 0.7609075205975931],
                                [0.2307653449471585, 0.0003906265187404308, 0.768844028534101],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.008327134455248368, 0.7609075205975931],
                                [0.05722748522903206, 0.03439211350528074, 0.9083804012656872],
                                [0.04739406744401024, 0.009833417785021958, 0.9427725147709678],
                                [0.046910077030668094, 0.0004839904133421039, 0.9526059325559898],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066803, 0.010317408198364061, 0.9427725147709679],
                                [0.9535977348784478, 0.0016927434179073895, 0.04470952170364481],
                                [0.9532071083597073, 0.0003906265187404308, 0.0464022651215522],
                                [0.9530899229693319, 0.00011718539037538669, 0.046792891640292635],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.0005078119091158175, 0.046402265121552204],
                                [0.771732740705073, 0.008327134455248368, 0.21994012483967856],
                                [0.7698111266500862, 0.0019216140549867585, 0.22826725929492694],
                                [0.7692346550528416, 0.0005764715972447517, 0.2301888733499137],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.00249808565223151, 0.22826725929492694],
                                [0.5054126100537399, 0.018042428461594068, 0.47654496148466596],
                                [0.5012490428261157, 0.004163567227624185, 0.49458738994626006],
                                [0.5000000000000001, 0.001249042826115755, 0.49875095717388424],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.00541261005373994, 0.49458738994626006],
                                [0.23909247940240683, 0.027757722467939765, 0.7331497981296534],
                                [0.23268695900214537, 0.006405520400261612, 0.760907520597593],
                                [0.23076534494715856, 0.001921614054986758, 0.7673130409978547],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.008327134455248368, 0.7609075205975931],
                                [0.05722748522903206, 0.03439211350528074, 0.9083804012656872],
                                [0.04929097729252416, 0.00793650793650794, 0.9427725147709679],
                                [0.04691007703066806, 0.002380900261856123, 0.9507090227074758],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066803, 0.010317408198364061, 0.9427725147709679],
                                [0.9535977348784478, 0.0016927434179073895, 0.04470952170364481],
                                [0.9533438289238899, 0.00025390595455790875, 0.0464022651215522],
                                [0.953089922969332, 0.00025390595455790875, 0.04665617107611011],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.0005078119091158175, 0.046402265121552204],
                                [0.771732740705073, 0.008327134455248368, 0.21994012483967856],
                                [0.7704836978789574, 0.001249042826115755, 0.22826725929492692],
                                [0.7692346550528416, 0.001249042826115755, 0.22951630212104268],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.00249808565223151, 0.22826725929492694],
                                [0.5054126100537399, 0.018042428461594068, 0.47654496148466596],
                                [0.50270630502687, 0.00270630502686997, 0.49458738994626006],
                                [0.5, 0.00270630502686997, 0.49729369497313003],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.00541261005373994, 0.49458738994626006],
                                [0.23909247940240683, 0.027757722467939765, 0.7331497981296534],
                                [0.2349289121747828, 0.004163567227624184, 0.760907520597593],
                                [0.23076534494715856, 0.004163567227624184, 0.7650710878252173],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.008327134455248368, 0.7609075205975931],
                                [0.05722748522903206, 0.03439211350528074, 0.9083804012656872],
                                [0.052068781129850174, 0.005158704099182031, 0.9427725147709678],
                                [0.04691007703066811, 0.005158704099182031, 0.9479312188701499],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066803, 0.010317408198364061, 0.9427725147709679],
                                [0.9535977348784478, 0.0016927434179073895, 0.04470952170364481],
                                [0.9534805494880724, 0.00011718539037538673, 0.046402265121552204],
                                [0.9530899229693319, 0.00039062651874043075, 0.04651945051192759],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.0005078119091158175, 0.046402265121552204],
                                [0.771732740705073, 0.008327134455248368, 0.21994012483967856],
                                [0.7711562691078283, 0.0005764715972447519, 0.22826725929492694],
                                [0.7692346550528415, 0.001921614054986758, 0.2288437308921717],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.00249808565223151, 0.22826725929492694],
                                [0.5054126100537399, 0.018042428461594068, 0.47654496148466596],
                                [0.5041635672276242, 0.0012490428261157554, 0.49458738994626006],
                                [0.49999999999999994, 0.004163567227624184, 0.4958364327723758],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.00541261005373994, 0.49458738994626006],
                                [0.23909247940240683, 0.027757722467939765, 0.7331497981296534],
                                [0.2371708653474201, 0.0019216140549867587, 0.7609075205975931],
                                [0.23076534494715856, 0.00640552040026161, 0.7628291346525798],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.008327134455248368, 0.7609075205975931],
                                [0.05722748522903206, 0.03439211350528074, 0.9083804012656872],
                                [0.05484658496717597, 0.002380900261856124, 0.9427725147709679],
                                [0.046910077030668046, 0.007936507936507938, 0.945153415032824],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066803, 0.010317408198364061, 0.9427725147709679],
                                [0.9535977348784478, 0.0016927434179073895, 0.04470952170364481],
                                [0.953573913382674, 2.3821495773713598e-05, 0.046402265121552204],
                                [0.9530899229693319, 0.0004839904133421039, 0.04642608661732591],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.0005078119091158175, 0.046402265121552204],
                                [0.771732740705073, 0.008327134455248368, 0.21994012483967856],
                                [0.7716155553146976, 0.00011718539037538676, 0.22826725929492694],
                                [0.7692346550528416, 0.002380900261856123, 0.22838444468530233],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.00249808565223151, 0.22826725929492694],
                                [0.5054126100537399, 0.018042428461594068, 0.47654496148466596],
                                [0.5051587040991821, 0.00025390595455790886, 0.49458738994626006],
                                [0.5, 0.005158704099182031, 0.494841295900818],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.00541261005373994, 0.49458738994626006],
                                [0.23909247940240683, 0.027757722467939765, 0.7331497981296534],
                                [0.2387018528836664, 0.00039062651874043096, 0.7609075205975931],
                                [0.23076534494715847, 0.007936507936507938, 0.7612981471163336],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.008327134455248368, 0.7609075205975931],
                                [0.05722748522903206, 0.03439211350528074, 0.9083804012656872],
                                [0.056743494815689986, 0.0004839904133421041, 0.9427725147709679],
                                [0.046910077030668115, 0.009833417785021958, 0.9432565051843099],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066803, 0.010317408198364061, 0.9427725147709679],
                                [0.9541902006328435, 0.0011002776635116035, 0.04470952170364481],
                                [0.9531415370792824, 0.001048663553561151, 0.045809799367156415],
                                [0.9530899229693319, 5.1614109950452745e-05, 0.04685846292071757],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.7746472651065814, 0.00541261005373994, 0.21994012483967856],
                                [0.7694885610073994, 0.005158704099182031, 0.2253527348934185],
                                [0.7692346550528416, 0.0002539059545579087, 0.23051143899260054],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.00541261005373994, 0.2253527348934185],
                                [0.511727519257667, 0.011727519257667005, 0.47654496148466596],
                                [0.5005501388317558, 0.011177380425911203, 0.488272480742333],
                                [0.5, 0.0005501388317558017, 0.4994498611682442],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.011727519257667005, 0.488272480742333],
                                [0.24880777340875262, 0.018042428461594068, 0.7331497981296533],
                                [0.23161171665611222, 0.017196056752640375, 0.7511922265912474],
                                [0.23076534494715856, 0.0008463717089536947, 0.7683882833438878],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715853, 0.018042428461594068, 0.7511922265912474],
                                [0.06926483788249051, 0.022354760851822406, 0.9083804012656871],
                                [0.04795874058422924, 0.021306097298261252, 0.9307351621175095],
                                [0.04691007703066807, 0.0010486635535611507, 0.9520412594157708],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066809, 0.022354760851822406, 0.9307351621175095],
                                [0.9541902006328435, 0.0011002776635116035, 0.04470952170364481],
                                [0.9533438289238898, 0.0008463717089536947, 0.045809799367156415],
                                [0.953089922969332, 0.00025390595455790875, 0.04665617107611011],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.7746472651065814, 0.00541261005373994, 0.21994012483967856],
                                [0.7704836978789572, 0.004163567227624184, 0.2253527348934185],
                                [0.7692346550528416, 0.001249042826115755, 0.22951630212104268],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.00541261005373994, 0.2253527348934185],
                                [0.511727519257667, 0.011727519257667005, 0.47654496148466596],
                                [0.50270630502687, 0.009021214230797034, 0.488272480742333],
                                [0.5, 0.00270630502686997, 0.49729369497313003],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.011727519257667005, 0.488272480742333],
                                [0.24880777340875262, 0.018042428461594068, 0.7331497981296533],
                                [0.2349289121747827, 0.013878861233969883, 0.7511922265912474],
                                [0.23076534494715856, 0.004163567227624184, 0.7650710878252173],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715853, 0.018042428461594068, 0.7511922265912474],
                                [0.06926483788249051, 0.022354760851822406, 0.9083804012656871],
                                [0.052068781129850125, 0.01719605675264037, 0.9307351621175095],
                                [0.04691007703066811, 0.005158704099182031, 0.9479312188701499],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066809, 0.022354760851822406, 0.9307351621175095],
                                [0.9541902006328435, 0.0011002776635116035, 0.04470952170364481],
                                [0.9536400618010877, 0.0005501388317558017, 0.045809799367156415],
                                [0.9530899229693319, 0.0005501388317558017, 0.046359938198912216],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.7746472651065814, 0.00541261005373994, 0.21994012483967856],
                                [0.7719409600797115, 0.00270630502686997, 0.2253527348934185],
                                [0.7692346550528416, 0.00270630502686997, 0.22805903992028848],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.00541261005373994, 0.2253527348934185],
                                [0.511727519257667, 0.011727519257667005, 0.47654496148466596],
                                [0.5058637596288336, 0.005863759628833502, 0.488272480742333],
                                [0.5000000000000001, 0.005863759628833502, 0.4941362403711665],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.011727519257667005, 0.488272480742333],
                                [0.24880777340875262, 0.018042428461594068, 0.7331497981296533],
                                [0.23978655917795555, 0.009021214230797034, 0.7511922265912474],
                                [0.2307653449471585, 0.009021214230797034, 0.7602134408220445],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715853, 0.018042428461594068, 0.7511922265912474],
                                [0.06926483788249051, 0.022354760851822406, 0.9083804012656871],
                                [0.05808745745657929, 0.011177380425911203, 0.9307351621175095],
                                [0.04691007703066808, 0.011177380425911203, 0.9419125425434207],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066809, 0.022354760851822406, 0.9307351621175095],
                                [0.9541902006328435, 0.0011002776635116035, 0.04470952170364481],
                                [0.9539362946782857, 0.0002539059545579088, 0.045809799367156415],
                                [0.9530899229693319, 0.0008463717089536947, 0.046063705321714325],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.7746472651065814, 0.00541261005373994, 0.21994012483967856],
                                [0.7733982222804658, 0.0012490428261157554, 0.22535273489341848],
                                [0.7692346550528415, 0.004163567227624184, 0.22660177771953427],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.00541261005373994, 0.2253527348934185],
                                [0.511727519257667, 0.011727519257667005, 0.47654496148466596],
                                [0.509021214230797, 0.0027063050268699707, 0.488272480742333],
                                [0.5, 0.009021214230797034, 0.49097878576920295],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.011727519257667005, 0.488272480742333],
                                [0.24880777340875262, 0.018042428461594068, 0.7331497981296533],
                                [0.24464420618112842, 0.004163567227624186, 0.7511922265912474],
                                [0.23076534494715847, 0.013878861233969883, 0.7553557938188716],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715853, 0.018042428461594068, 0.7511922265912474],
                                [0.06926483788249051, 0.022354760851822406, 0.9083804012656871],
                                [0.06410613378330846, 0.0051587040991820324, 0.9307351621175095],
                                [0.04691007703066806, 0.01719605675264037, 0.9358938662166916],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066809, 0.022354760851822406, 0.9307351621175095],
                                [0.9541902006328435, 0.0011002776635116035, 0.04470952170364481],
                                [0.9541385865228931, 5.1614109950452745e-05, 0.045809799367156415],
                                [0.953089922969332, 0.001048663553561151, 0.045861413477106865],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.7746472651065814, 0.00541261005373994, 0.21994012483967856],
                                [0.7743933591520236, 0.0002539059545579087, 0.2253527348934185],
                                [0.7692346550528415, 0.005158704099182031, 0.2256066408479764],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528415, 0.00541261005373994, 0.2253527348934185],
                                [0.511727519257667, 0.011727519257667005, 0.47654496148466596],
                                [0.5111773804259112, 0.0005501388317558017, 0.488272480742333],
                                [0.5, 0.011177380425911203, 0.4888226195740888],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.011727519257667005, 0.488272480742333],
                                [0.24880777340875262, 0.018042428461594068, 0.7331497981296533],
                                [0.2479614016997989, 0.0008463717089536947, 0.7511922265912474],
                                [0.23076534494715847, 0.017196056752640375, 0.7520385983002011],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715853, 0.018042428461594068, 0.7511922265912474],
                                [0.06926483788249051, 0.022354760851822406, 0.9083804012656871],
                                [0.06821617432892935, 0.0010486635535611507, 0.9307351621175095],
                                [0.046910077030668094, 0.021306097298261252, 0.9317838256710707],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066809, 0.022354760851822406, 0.9307351621175095],
                                [0.9547826663872393, 0.0005078119091158176, 0.04470952170364481],
                                [0.9531693296934592, 0.0016133366937801975, 0.045217333612760625],
                                [0.9530899229693319, 7.94067241271919e-05, 0.046830670306540825],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.953089922969332, 0.0016927434179073895, 0.045217333612760625],
                                [0.7775617895080899, 0.0024980856522315107, 0.21994012483967856],
                                [0.769625281571582, 0.007936507936507938, 0.2224382104919101],
                                [0.7692346550528416, 0.00039062651874043075, 0.230374718428418],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528416, 0.008327134455248368, 0.22243821049191007],
                                [0.5180424284615941, 0.005412610053739941, 0.47654496148466596],
                                [0.5008463717089537, 0.01719605675264037, 0.48195757153840596],
                                [0.5, 0.0008463717089536947, 0.4991536282910463],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.018042428461594068, 0.4819575715384059],
                                [0.25852306741509834, 0.008327134455248372, 0.7331497981296533],
                                [0.23206746184632543, 0.026455605568772803, 0.7414769325849018],
                                [0.23076534494715847, 0.0013021168991669586, 0.7679325381536746],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.027757722467939765, 0.7414769325849018],
                                [0.08130219053594885, 0.010317408198364065, 0.9083804012656871],
                                [0.04852341372444824, 0.03277877681150054, 0.9186978094640512],
                                [0.04691007703066804, 0.0016133366937801975, 0.9514765862755518],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066804, 0.03439211350528074, 0.9186978094640512],
                                [0.9547826663872393, 0.0005078119091158176, 0.04470952170364481],
                                [0.9534805494880725, 0.0013021168991669589, 0.045217333612760625],
                                [0.9530899229693319, 0.00039062651874043075, 0.04651945051192759],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.953089922969332, 0.0016927434179073895, 0.045217333612760625],
                                [0.7775617895080899, 0.0024980856522315107, 0.21994012483967856],
                                [0.7711562691078283, 0.006405520400261611, 0.2224382104919101],
                                [0.7692346550528415, 0.001921614054986758, 0.2288437308921717],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528416, 0.008327134455248368, 0.22243821049191007],
                                [0.5180424284615941, 0.005412610053739941, 0.47654496148466596],
                                [0.5041635672276242, 0.013878861233969884, 0.48195757153840596],
                                [0.49999999999999994, 0.004163567227624184, 0.4958364327723758],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.018042428461594068, 0.4819575715384059],
                                [0.25852306741509834, 0.008327134455248372, 0.7331497981296533],
                                [0.23717086534742007, 0.021352202067678155, 0.7414769325849018],
                                [0.23076534494715856, 0.00640552040026161, 0.7628291346525798],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.027757722467939765, 0.7414769325849018],
                                [0.08130219053594885, 0.010317408198364065, 0.9083804012656871],
                                [0.054846584967175975, 0.026455605568772807, 0.9186978094640512],
                                [0.046910077030668046, 0.007936507936507938, 0.945153415032824],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066804, 0.03439211350528074, 0.9186978094640512],
                                [0.9547826663872393, 0.0005078119091158176, 0.04470952170364481],
                                [0.9539362946782857, 0.0008463717089536947, 0.04521733361276063],
                                [0.9530899229693319, 0.0008463717089536947, 0.046063705321714325],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.953089922969332, 0.0016927434179073895, 0.045217333612760625],
                                [0.7775617895080899, 0.0024980856522315107, 0.21994012483967856],
                                [0.7733982222804657, 0.004163567227624184, 0.22243821049191007],
                                [0.7692346550528415, 0.004163567227624184, 0.22660177771953427],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528416, 0.008327134455248368, 0.22243821049191007],
                                [0.5180424284615941, 0.005412610053739941, 0.47654496148466596],
                                [0.509021214230797, 0.009021214230797034, 0.4819575715384059],
                                [0.5, 0.009021214230797034, 0.49097878576920295],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.018042428461594068, 0.4819575715384059],
                                [0.25852306741509834, 0.008327134455248372, 0.7331497981296533],
                                [0.24464420618112834, 0.013878861233969883, 0.7414769325849018],
                                [0.23076534494715847, 0.013878861233969883, 0.7553557938188716],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.027757722467939765, 0.7414769325849018],
                                [0.08130219053594885, 0.010317408198364065, 0.9083804012656871],
                                [0.06410613378330841, 0.01719605675264037, 0.9186978094640512],
                                [0.04691007703066806, 0.01719605675264037, 0.9358938662166916],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066804, 0.03439211350528074, 0.9186978094640512],
                                [0.9547826663872393, 0.0005078119091158176, 0.04470952170364481],
                                [0.954392039868499, 0.0003906265187404308, 0.04521733361276063],
                                [0.953089922969332, 0.0013021168991669589, 0.045607960131501056],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.953089922969332, 0.0016927434179073895, 0.045217333612760625],
                                [0.7775617895080899, 0.0024980856522315107, 0.21994012483967856],
                                [0.7756401754531032, 0.0019216140549867585, 0.2224382104919101],
                                [0.7692346550528415, 0.00640552040026161, 0.22435982454689685],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528416, 0.008327134455248368, 0.22243821049191007],
                                [0.5180424284615941, 0.005412610053739941, 0.47654496148466596],
                                [0.5138788612339699, 0.004163567227624185, 0.48195757153840596],
                                [0.5, 0.013878861233969883, 0.48612113876603014],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.018042428461594068, 0.4819575715384059],
                                [0.25852306741509834, 0.008327134455248372, 0.7331497981296533],
                                [0.25211754701483663, 0.006405520400261612, 0.7414769325849018],
                                [0.23076534494715853, 0.021352202067678152, 0.7478824529851633],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.027757722467939765, 0.7414769325849018],
                                [0.08130219053594885, 0.010317408198364065, 0.9083804012656871],
                                [0.07336568259944085, 0.00793650793650794, 0.9186978094640512],
                                [0.04691007703066807, 0.026455605568772807, 0.9266343174005591],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066804, 0.03439211350528074, 0.9186978094640512],
                                [0.9547826663872393, 0.0005078119091158176, 0.04470952170364481],
                                [0.9547032596631122, 7.940672412719205e-05, 0.04521733361276063],
                                [0.953089922969332, 0.0016133366937801975, 0.04529674033688782],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.953089922969332, 0.0016927434179073895, 0.045217333612760625],
                                [0.7775617895080899, 0.0024980856522315107, 0.21994012483967856],
                                [0.7771711629893495, 0.00039062651874043145, 0.22243821049191007],
                                [0.7692346550528416, 0.007936507936507938, 0.2228288370106505],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528416, 0.008327134455248368, 0.22243821049191007],
                                [0.5180424284615941, 0.005412610053739941, 0.47654496148466596],
                                [0.5171960567526404, 0.0008463717089536964, 0.48195757153840596],
                                [0.5, 0.01719605675264037, 0.48280394324735965],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.018042428461594068, 0.4819575715384059],
                                [0.25852306741509834, 0.008327134455248372, 0.7331497981296533],
                                [0.25722095051593125, 0.0013021168991669612, 0.7414769325849018],
                                [0.2307653449471585, 0.026455605568772803, 0.7427790494840687],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715847, 0.027757722467939765, 0.7414769325849018],
                                [0.08130219053594885, 0.010317408198364065, 0.9083804012656871],
                                [0.07968885384216857, 0.0016133366937802005, 0.9186978094640512],
                                [0.046910077030668074, 0.03277877681150054, 0.9203111461578314],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.04691007703066804, 0.03439211350528074, 0.9186978094640512],
                                [0.9551872500764542, 0.00010322821990090549, 0.04470952170364481],
                                [0.9531883087454857, 0.0019989413309686867, 0.04481274992354572],
                                [0.9530899229693319, 9.83857761536153e-05, 0.046811691254514405],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.953089922969332, 0.002097327107122302, 0.04481274992354572],
                                [0.7795520632512055, 0.0005078119091158174, 0.21994012483967856],
                                [0.7697186454661836, 0.009833417785021958, 0.2204479367487944],
                                [0.7692346550528415, 0.00048399041334210393, 0.23028135453381635],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528416, 0.010317408198364061, 0.22044793674879437],
                                [0.5223547608518224, 0.0011002776635116035, 0.47654496148466596],
                                [0.5010486635535611, 0.021306097298261256, 0.4776452391481776],
                                [0.5, 0.001048663553561151, 0.49895133644643885],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.022354760851822406, 0.4776452391481776],
                                [0.2651574584524393, 0.0016927434179073895, 0.7331497981296533],
                                [0.23237868164093867, 0.03277877681150055, 0.7348425415475608],
                                [0.23076534494715847, 0.0016133366937801977, 0.7676213183590613],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715845, 0.03439211350528075, 0.7348425415475608],
                                [0.0895222716271906, 0.0020973271071223014, 0.9083804012656871],
                                [0.048909018361636795, 0.040613253265553824, 0.9104777283728094],
                                [0.04691007703066806, 0.0019989413309686867, 0.9510909816383633],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.046910077030668115, 0.042612194596522504, 0.9104777283728094],
                                [0.9551872500764542, 0.00010322821990090549, 0.04470952170364481],
                                [0.9535739133826742, 0.001613336693780198, 0.04481274992354572],
                                [0.9530899229693319, 0.0004839904133421039, 0.04642608661732591],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.953089922969332, 0.002097327107122302, 0.04481274992354572],
                                [0.7795520632512055, 0.0005078119091158174, 0.21994012483967856],
                                [0.7716155553146977, 0.00793650793650794, 0.2204479367487944],
                                [0.7692346550528416, 0.002380900261856123, 0.22838444468530233],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528416, 0.010317408198364061, 0.22044793674879437],
                                [0.5223547608518224, 0.0011002776635116035, 0.47654496148466596],
                                [0.5051587040991821, 0.017196056752640375, 0.47764523914817764],
                                [0.5, 0.005158704099182031, 0.494841295900818],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.022354760851822406, 0.4776452391481776],
                                [0.2651574584524393, 0.0016927434179073895, 0.7331497981296533],
                                [0.2387018528836664, 0.02645560556877281, 0.7348425415475608],
                                [0.23076534494715847, 0.007936507936507938, 0.7612981471163336],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715845, 0.03439211350528075, 0.7348425415475608],
                                [0.0895222716271906, 0.0020973271071223014, 0.9083804012656871],
                                [0.05674349481568996, 0.03277877681150055, 0.9104777283728095],
                                [0.046910077030668115, 0.009833417785021958, 0.9432565051843099],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.046910077030668115, 0.042612194596522504, 0.9104777283728094],
                                [0.9551872500764542, 0.00010322821990090549, 0.04470952170364481],
                                [0.9541385865228932, 0.001048663553561151, 0.04481274992354571],
                                [0.953089922969332, 0.001048663553561151, 0.045861413477106865],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.953089922969332, 0.002097327107122302, 0.04481274992354572],
                                [0.7795520632512055, 0.0005078119091158174, 0.21994012483967856],
                                [0.7743933591520236, 0.005158704099182031, 0.22044793674879437],
                                [0.7692346550528415, 0.005158704099182031, 0.2256066408479764],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528416, 0.010317408198364061, 0.22044793674879437],
                                [0.5223547608518224, 0.0011002776635116035, 0.47654496148466596],
                                [0.5111773804259112, 0.011177380425911203, 0.4776452391481776],
                                [0.5, 0.011177380425911203, 0.4888226195740888],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.022354760851822406, 0.4776452391481776],
                                [0.2651574584524393, 0.0016927434179073895, 0.7331497981296533],
                                [0.24796140169979883, 0.017196056752640375, 0.7348425415475608],
                                [0.23076534494715847, 0.017196056752640375, 0.7520385983002011],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715845, 0.03439211350528075, 0.7348425415475608],
                                [0.0895222716271906, 0.0020973271071223014, 0.9083804012656871],
                                [0.06821617432892937, 0.021306097298261252, 0.9104777283728094],
                                [0.046910077030668094, 0.021306097298261252, 0.9317838256710707],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.046910077030668115, 0.042612194596522504, 0.9104777283728094],
                                [0.9551872500764542, 0.00010322821990090549, 0.04470952170364481],
                                [0.9547032596631122, 0.0004839904133421039, 0.04481274992354572],
                                [0.953089922969332, 0.001613336693780198, 0.04529674033688782],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.953089922969332, 0.002097327107122302, 0.04481274992354572],
                                [0.7795520632512055, 0.0005078119091158174, 0.21994012483967856],
                                [0.7771711629893495, 0.002380900261856123, 0.2204479367487944],
                                [0.7692346550528416, 0.00793650793650794, 0.2228288370106505],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528416, 0.010317408198364061, 0.22044793674879437],
                                [0.5223547608518224, 0.0011002776635116035, 0.47654496148466596],
                                [0.5171960567526404, 0.005158704099182031, 0.47764523914817764],
                                [0.5, 0.017196056752640375, 0.48280394324735965],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.022354760851822406, 0.4776452391481776],
                                [0.2651574584524393, 0.0016927434179073895, 0.7331497981296533],
                                [0.25722095051593125, 0.007936507936507938, 0.7348425415475608],
                                [0.2307653449471585, 0.02645560556877281, 0.7427790494840687],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715845, 0.03439211350528075, 0.7348425415475608],
                                [0.0895222716271906, 0.0020973271071223014, 0.9083804012656871],
                                [0.07968885384216866, 0.009833417785021958, 0.9104777283728094],
                                [0.04691007703066807, 0.03277877681150055, 0.9203111461578314],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.046910077030668115, 0.042612194596522504, 0.9104777283728094],
                                [0.9551872500764542, 0.00010322821990090549, 0.04470952170364481],
                                [0.9550888643003007, 9.838577615361554e-05, 0.04481274992354572],
                                [0.953089922969332, 0.0019989413309686862, 0.04491113569969933],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.953089922969332, 0.002097327107122302, 0.04481274992354572],
                                [0.7795520632512055, 0.0005078119091158174, 0.21994012483967856],
                                [0.7790680728378635, 0.0004839904133421051, 0.22044793674879437],
                                [0.7692346550528415, 0.009833417785021958, 0.2209319271621365],
                                [0.7692346550528415, 0.01082522010747988, 0.21994012483967856],
                                [0.7692346550528416, 0.010317408198364061, 0.22044793674879437],
                                [0.5223547608518224, 0.0011002776635116035, 0.47654496148466596],
                                [0.5213060972982613, 0.0010486635535611535, 0.4776452391481776],
                                [0.5, 0.021306097298261252, 0.4786939027017387],
                                [0.5, 0.02345503851533401, 0.47654496148466596],
                                [0.5, 0.022354760851822406, 0.4776452391481776],
                                [0.2651574584524393, 0.0016927434179073895, 0.7331497981296533],
                                [0.263544121758659, 0.0016133366937802018, 0.7348425415475608],
                                [0.2307653449471585, 0.03277877681150054, 0.736455878241341],
                                [0.23076534494715856, 0.036084856923188136, 0.7331497981296533],
                                [0.23076534494715845, 0.03439211350528075, 0.7348425415475608],
                                [0.0895222716271906, 0.0020973271071223014, 0.9083804012656871],
                                [0.08752333029622193, 0.0019989413309686914, 0.9104777283728094],
                                [0.04691007703066813, 0.04061325326555382, 0.912476669703778],
                                [0.0469100770306681, 0.04470952170364481, 0.9083804012656871],
                                [0.046910077030668115, 0.042612194596522504, 0.9104777283728094],
                                [0.9535977348784478, 0.010317408198364061, 0.03608485692318814],
                                [0.9531137444651057, 0.0004839904133421039, 0.0464022651215522],
                                [0.9530899229693319, 2.3821495773713587e-05, 0.046886255534894304],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.0005078119091158175, 0.046402265121552204],
                                [0.771732740705073, 0.05075455877634952, 0.17751270051857743],
                                [0.7693518404432169, 0.002380900261856123, 0.22826725929492694],
                                [0.7692346550528415, 0.0001171853903753867, 0.23064815955678306],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528415, 0.00249808565223151, 0.22826725929492694],
                                [0.5054126100537399, 0.10997006241983928, 0.38461732752642075],
                                [0.5002539059545579, 0.005158704099182031, 0.49458738994626006],
                                [0.49999999999999994, 0.00025390595455790875, 0.49974609404544207],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.00541261005373994, 0.49458738994626006],
                                [0.23909247940240683, 0.16918556606332905, 0.5917219545342641],
                                [0.23115597146589892, 0.007936507936507938, 0.7609075205975931],
                                [0.2307653449471585, 0.0003906265187404308, 0.768844028534101],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.008327134455248368, 0.7609075205975931],
                                [0.05722748522903209, 0.2096227166413145, 0.7331497981296534],
                                [0.04739406744401024, 0.009833417785021958, 0.9427725147709678],
                                [0.046910077030668094, 0.0004839904133421039, 0.9526059325559898],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.04691007703066803, 0.010317408198364061, 0.9427725147709679],
                                [0.9535977348784478, 0.010317408198364061, 0.03608485692318814],
                                [0.9532071083597073, 0.0003906265187404308, 0.0464022651215522],
                                [0.9530899229693319, 0.00011718539037538669, 0.046792891640292635],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.0005078119091158175, 0.046402265121552204],
                                [0.771732740705073, 0.05075455877634952, 0.17751270051857743],
                                [0.7698111266500862, 0.0019216140549867585, 0.22826725929492694],
                                [0.7692346550528416, 0.0005764715972447517, 0.2301888733499137],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528415, 0.00249808565223151, 0.22826725929492694],
                                [0.5054126100537399, 0.10997006241983928, 0.38461732752642075],
                                [0.5012490428261157, 0.004163567227624185, 0.49458738994626006],
                                [0.5000000000000001, 0.001249042826115755, 0.49875095717388424],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.00541261005373994, 0.49458738994626006],
                                [0.23909247940240683, 0.16918556606332905, 0.5917219545342641],
                                [0.23268695900214537, 0.006405520400261612, 0.760907520597593],
                                [0.23076534494715856, 0.001921614054986758, 0.7673130409978547],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.008327134455248368, 0.7609075205975931],
                                [0.05722748522903209, 0.2096227166413145, 0.7331497981296534],
                                [0.04929097729252416, 0.00793650793650794, 0.9427725147709679],
                                [0.04691007703066806, 0.002380900261856123, 0.9507090227074758],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.04691007703066803, 0.010317408198364061, 0.9427725147709679],
                                [0.9535977348784478, 0.010317408198364061, 0.03608485692318814],
                                [0.9533438289238899, 0.00025390595455790875, 0.0464022651215522],
                                [0.953089922969332, 0.00025390595455790875, 0.04665617107611011],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.0005078119091158175, 0.046402265121552204],
                                [0.771732740705073, 0.05075455877634952, 0.17751270051857743],
                                [0.7704836978789574, 0.001249042826115755, 0.22826725929492692],
                                [0.7692346550528416, 0.001249042826115755, 0.22951630212104268],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528415, 0.00249808565223151, 0.22826725929492694],
                                [0.5054126100537399, 0.10997006241983928, 0.38461732752642075],
                                [0.50270630502687, 0.00270630502686997, 0.49458738994626006],
                                [0.5, 0.00270630502686997, 0.49729369497313003],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.00541261005373994, 0.49458738994626006],
                                [0.23909247940240683, 0.16918556606332905, 0.5917219545342641],
                                [0.2349289121747828, 0.004163567227624184, 0.760907520597593],
                                [0.23076534494715856, 0.004163567227624184, 0.7650710878252173],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.008327134455248368, 0.7609075205975931],
                                [0.05722748522903209, 0.2096227166413145, 0.7331497981296534],
                                [0.052068781129850174, 0.005158704099182031, 0.9427725147709678],
                                [0.04691007703066811, 0.005158704099182031, 0.9479312188701499],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.04691007703066803, 0.010317408198364061, 0.9427725147709679],
                                [0.9535977348784478, 0.010317408198364061, 0.03608485692318814],
                                [0.9534805494880724, 0.00011718539037538673, 0.046402265121552204],
                                [0.9530899229693319, 0.00039062651874043075, 0.04651945051192759],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.0005078119091158175, 0.046402265121552204],
                                [0.771732740705073, 0.05075455877634952, 0.17751270051857743],
                                [0.7711562691078283, 0.0005764715972447519, 0.22826725929492694],
                                [0.7692346550528415, 0.001921614054986758, 0.2288437308921717],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528415, 0.00249808565223151, 0.22826725929492694],
                                [0.5054126100537399, 0.10997006241983928, 0.38461732752642075],
                                [0.5041635672276242, 0.0012490428261157554, 0.49458738994626006],
                                [0.49999999999999994, 0.004163567227624184, 0.4958364327723758],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.00541261005373994, 0.49458738994626006],
                                [0.23909247940240683, 0.16918556606332905, 0.5917219545342641],
                                [0.2371708653474201, 0.0019216140549867587, 0.7609075205975931],
                                [0.23076534494715856, 0.00640552040026161, 0.7628291346525798],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.008327134455248368, 0.7609075205975931],
                                [0.05722748522903209, 0.2096227166413145, 0.7331497981296534],
                                [0.05484658496717597, 0.002380900261856124, 0.9427725147709679],
                                [0.046910077030668046, 0.007936507936507938, 0.945153415032824],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.04691007703066803, 0.010317408198364061, 0.9427725147709679],
                                [0.9535977348784478, 0.010317408198364061, 0.03608485692318814],
                                [0.953573913382674, 2.3821495773713598e-05, 0.046402265121552204],
                                [0.9530899229693319, 0.0004839904133421039, 0.04642608661732591],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.0005078119091158175, 0.046402265121552204],
                                [0.771732740705073, 0.05075455877634952, 0.17751270051857743],
                                [0.7716155553146976, 0.00011718539037538676, 0.22826725929492694],
                                [0.7692346550528416, 0.002380900261856123, 0.22838444468530233],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528415, 0.00249808565223151, 0.22826725929492694],
                                [0.5054126100537399, 0.10997006241983928, 0.38461732752642075],
                                [0.5051587040991821, 0.00025390595455790886, 0.49458738994626006],
                                [0.5, 0.005158704099182031, 0.494841295900818],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.00541261005373994, 0.49458738994626006],
                                [0.23909247940240683, 0.16918556606332905, 0.5917219545342641],
                                [0.2387018528836664, 0.00039062651874043096, 0.7609075205975931],
                                [0.23076534494715847, 0.007936507936507938, 0.7612981471163336],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.008327134455248368, 0.7609075205975931],
                                [0.05722748522903209, 0.2096227166413145, 0.7331497981296534],
                                [0.056743494815689986, 0.0004839904133421041, 0.9427725147709679],
                                [0.046910077030668115, 0.009833417785021958, 0.9432565051843099],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.04691007703066803, 0.010317408198364061, 0.9427725147709679],
                                [0.9555880086215635, 0.00832713445524837, 0.036084856923188136],
                                [0.9532071083597073, 0.002380900261856123, 0.0444119913784365],
                                [0.9530899229693319, 0.00011718539037538669, 0.046792891640292635],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.00249808565223151, 0.04441199137843651],
                                [0.7815235199137514, 0.04096377956767115, 0.17751270051857743],
                                [0.7698111266500863, 0.011712393263665124, 0.21847648008624856],
                                [0.7692346550528416, 0.0005764715972447517, 0.2301888733499137],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.012288864860909876, 0.21847648008624856],
                                [0.5266263222142905, 0.08875635025928871, 0.38461732752642075],
                                [0.5012490428261157, 0.02537727938817476, 0.4733736777857095],
                                [0.5000000000000001, 0.001249042826115755, 0.49875095717388424],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.026626322214290513, 0.4733736777857095],
                                [0.2717291245148297, 0.13654892095090626, 0.591721954534264],
                                [0.23268695900214528, 0.03904216551268439, 0.7282708754851703],
                                [0.23076534494715856, 0.001921614054986758, 0.7673130409978547],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715853, 0.040963779567671145, 0.7282708754851703],
                                [0.09766463580701754, 0.16918556606332905, 0.7331497981296534],
                                [0.04929097729252417, 0.04837365851449339, 0.9023353641929824],
                                [0.04691007703066806, 0.002380900261856123, 0.9507090227074758],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.04691007703066805, 0.05075455877634951, 0.9023353641929824],
                                [0.9555880086215635, 0.00832713445524837, 0.036084856923188136],
                                [0.9536663945665766, 0.0019216140549867583, 0.04441199137843651],
                                [0.953089922969332, 0.0005764715972447518, 0.04633360543342327],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.00249808565223151, 0.04441199137843651],
                                [0.7815235199137514, 0.04096377956767115, 0.17751270051857743],
                                [0.7720704991914785, 0.009453020722272994, 0.21847648008624856],
                                [0.7692346550528415, 0.002835844138636882, 0.22792950080852156],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.012288864860909876, 0.21847648008624856],
                                [0.5266263222142905, 0.08875635025928871, 0.38461732752642075],
                                [0.5061444324304549, 0.020481889783835576, 0.4733736777857095],
                                [0.5, 0.006144432430454938, 0.4938555675695451],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.026626322214290513, 0.4733736777857095],
                                [0.2717291245148297, 0.13654892095090626, 0.591721954534264],
                                [0.2402183656694314, 0.031510758845398154, 0.7282708754851704],
                                [0.23076534494715845, 0.009453020722272994, 0.7597816343305686],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715853, 0.040963779567671145, 0.7282708754851703],
                                [0.09766463580701754, 0.16918556606332905, 0.7331497981296534],
                                [0.05862247029433317, 0.03904216551268439, 0.9023353641929824],
                                [0.04691007703066808, 0.011712393263665124, 0.9413775297056668],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.04691007703066805, 0.05075455877634951, 0.9023353641929824],
                                [0.9555880086215635, 0.00832713445524837, 0.036084856923188136],
                                [0.9543389657954477, 0.001249042826115755, 0.0444119913784365],
                                [0.953089922969332, 0.001249042826115755, 0.04566103420455226],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.00249808565223151, 0.04441199137843651],
                                [0.7815235199137514, 0.04096377956767115, 0.17751270051857743],
                                [0.7753790874832964, 0.006144432430454938, 0.2184764800862486],
                                [0.7692346550528415, 0.006144432430454938, 0.22462091251670352],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.012288864860909876, 0.21847648008624856],
                                [0.5266263222142905, 0.08875635025928871, 0.38461732752642075],
                                [0.5133131611071452, 0.013313161107145257, 0.4733736777857095],
                                [0.5, 0.013313161107145257, 0.48668683889285475],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.026626322214290513, 0.4733736777857095],
                                [0.2717291245148297, 0.13654892095090626, 0.591721954534264],
                                [0.2512472347309941, 0.020481889783835572, 0.7282708754851703],
                                [0.2307653449471585, 0.020481889783835572, 0.7487527652690059],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715853, 0.040963779567671145, 0.7282708754851703],
                                [0.09766463580701754, 0.16918556606332905, 0.7331497981296534],
                                [0.07228735641884292, 0.025377279388174755, 0.9023353641929823],
                                [0.046910077030668115, 0.025377279388174755, 0.9277126435811571],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.04691007703066805, 0.05075455877634951, 0.9023353641929824],
                                [0.9555880086215635, 0.00832713445524837, 0.036084856923188136],
                                [0.9550115370243187, 0.000576471597244752, 0.04441199137843651],
                                [0.9530899229693319, 0.001921614054986758, 0.04498846297568126],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.00249808565223151, 0.04441199137843651],
                                [0.7815235199137514, 0.04096377956767115, 0.17751270051857743],
                                [0.7786876757751146, 0.002835844138636883, 0.21847648008624856],
                                [0.7692346550528416, 0.009453020722272993, 0.22131232422488545],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.012288864860909876, 0.21847648008624856],
                                [0.5266263222142905, 0.08875635025928871, 0.38461732752642075],
                                [0.5204818897838356, 0.006144432430454941, 0.4733736777857095],
                                [0.5, 0.020481889783835572, 0.4795181102161644],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.026626322214290513, 0.4733736777857095],
                                [0.2717291245148297, 0.13654892095090626, 0.591721954534264],
                                [0.26227610379255667, 0.009453020722272998, 0.7282708754851703],
                                [0.23076534494715847, 0.03151075884539815, 0.7377238962074434],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715853, 0.040963779567671145, 0.7282708754851703],
                                [0.09766463580701754, 0.16918556606332905, 0.7331497981296534],
                                [0.08595224254335243, 0.01171239326366513, 0.9023353641929824],
                                [0.046910077030668046, 0.039042165512684385, 0.9140477574566476],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.04691007703066805, 0.05075455877634951, 0.9023353641929824],
                                [0.9555880086215635, 0.00832713445524837, 0.036084856923188136],
                                [0.955470823231188, 0.00011718539037538697, 0.04441199137843651],
                                [0.953089922969332, 0.002380900261856123, 0.04452917676881189],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.00249808565223151, 0.04441199137843651],
                                [0.7815235199137514, 0.04096377956767115, 0.17751270051857743],
                                [0.7809470483165066, 0.0005764715972447531, 0.2184764800862486],
                                [0.7692346550528415, 0.011712393263665122, 0.2190529516834933],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.012288864860909876, 0.21847648008624856],
                                [0.5266263222142905, 0.08875635025928871, 0.38461732752642075],
                                [0.5253772793881748, 0.001249042826115758, 0.4733736777857095],
                                [0.5, 0.025377279388174755, 0.47462272061182526],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.026626322214290513, 0.4733736777857095],
                                [0.2717291245148297, 0.13654892095090626, 0.591721954534264],
                                [0.2698075104598429, 0.0019216140549867626, 0.7282708754851703],
                                [0.23076534494715847, 0.039042165512684385, 0.7301924895401571],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715853, 0.040963779567671145, 0.7282708754851703],
                                [0.09766463580701754, 0.16918556606332905, 0.7331497981296534],
                                [0.09528373554516144, 0.002380900261856129, 0.9023353641929824],
                                [0.04691007703066807, 0.048373658514493385, 0.9047162644548385],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.04691007703066805, 0.05075455877634951, 0.9023353641929824],
                                [0.9585025330230719, 0.00541261005373994, 0.036084856923188136],
                                [0.9533438289238898, 0.005158704099182031, 0.04149746697692808],
                                [0.953089922969332, 0.00025390595455790875, 0.04665617107611011],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.00541261005373994, 0.04149746697692808],
                                [0.795860977267132, 0.026626322214290513, 0.17751270051857743],
                                [0.7704836978789573, 0.02537727938817476, 0.20413902273286794],
                                [0.7692346550528416, 0.001249042826115755, 0.22951630212104268],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.026626322214290513, 0.20413902273286794],
                                [0.5576913362367897, 0.05769133623678961, 0.38461732752642075],
                                [0.5027063050268701, 0.05498503120991964, 0.4423086637632104],
                                [0.5, 0.00270630502686997, 0.49729369497313003],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5000000000000001, 0.05769133623678961, 0.4423086637632104],
                                [0.3195216952064473, 0.0887563502592887, 0.591721954534264],
                                [0.23492891217478273, 0.08459278303166452, 0.6804783047935528],
                                [0.23076534494715856, 0.004163567227624184, 0.7650710878252173],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715856, 0.0887563502592887, 0.6804783047935528],
                                [0.1568801394505074, 0.10997006241983928, 0.7331497981296533],
                                [0.05206878112985014, 0.10481135832065724, 0.8431198605494926],
                                [0.04691007703066811, 0.005158704099182031, 0.9479312188701499],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.0469100770306681, 0.10997006241983928, 0.8431198605494926],
                                [0.9585025330230719, 0.00541261005373994, 0.036084856923188136],
                                [0.9543389657954476, 0.004163567227624185, 0.04149746697692808],
                                [0.953089922969332, 0.001249042826115755, 0.04566103420455226],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.00541261005373994, 0.04149746697692808],
                                [0.795860977267132, 0.026626322214290513, 0.17751270051857743],
                                [0.7753790874832965, 0.020481889783835576, 0.20413902273286794],
                                [0.7692346550528415, 0.006144432430454938, 0.22462091251670352],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.026626322214290513, 0.20413902273286794],
                                [0.5576913362367897, 0.05769133623678961, 0.38461732752642075],
                                [0.5133131611071453, 0.04437817512964436, 0.4423086637632104],
                                [0.5, 0.013313161107145257, 0.48668683889285475],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5000000000000001, 0.05769133623678961, 0.4423086637632104],
                                [0.3195216952064473, 0.0887563502592887, 0.591721954534264],
                                [0.2512472347309941, 0.06827446047545313, 0.6804783047935528],
                                [0.2307653449471585, 0.020481889783835572, 0.7487527652690059],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715856, 0.0887563502592887, 0.6804783047935528],
                                [0.1568801394505074, 0.10997006241983928, 0.7331497981296533],
                                [0.07228735641884286, 0.08459278303166452, 0.8431198605494926],
                                [0.046910077030668115, 0.025377279388174755, 0.9277126435811571],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.0469100770306681, 0.10997006241983928, 0.8431198605494926],
                                [0.9585025330230719, 0.00541261005373994, 0.036084856923188136],
                                [0.9557962279962019, 0.00270630502686997, 0.04149746697692808],
                                [0.953089922969332, 0.00270630502686997, 0.04420377200379805],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.00541261005373994, 0.04149746697692808],
                                [0.795860977267132, 0.026626322214290513, 0.17751270051857743],
                                [0.7825478161599868, 0.013313161107145257, 0.20413902273286794],
                                [0.7692346550528415, 0.013313161107145257, 0.2174521838400132],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.026626322214290513, 0.20413902273286794],
                                [0.5576913362367897, 0.05769133623678961, 0.38461732752642075],
                                [0.5288456681183947, 0.028845668118394806, 0.44230866376321043],
                                [0.5, 0.028845668118394806, 0.4711543318816052],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5000000000000001, 0.05769133623678961, 0.4423086637632104],
                                [0.3195216952064473, 0.0887563502592887, 0.591721954534264],
                                [0.27514352007680287, 0.04437817512964435, 0.6804783047935528],
                                [0.23076534494715853, 0.04437817512964435, 0.7248564799231971],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715856, 0.0887563502592887, 0.6804783047935528],
                                [0.1568801394505074, 0.10997006241983928, 0.7331497981296533],
                                [0.10189510824058763, 0.05498503120991964, 0.8431198605494927],
                                [0.04691007703066803, 0.05498503120991964, 0.8981048917594123],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.0469100770306681, 0.10997006241983928, 0.8431198605494926],
                                [0.9585025330230719, 0.00541261005373994, 0.036084856923188136],
                                [0.9572534901969562, 0.0012490428261157556, 0.04149746697692808],
                                [0.9530899229693319, 0.004163567227624184, 0.042746509803043835],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.00541261005373994, 0.04149746697692808],
                                [0.795860977267132, 0.026626322214290513, 0.17751270051857743],
                                [0.7897165448366772, 0.006144432430454941, 0.20413902273286794],
                                [0.7692346550528416, 0.020481889783835572, 0.21028345516332286],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.026626322214290513, 0.20413902273286794],
                                [0.5576913362367897, 0.05769133623678961, 0.38461732752642075],
                                [0.5443781751296444, 0.013313161107145262, 0.4423086637632104],
                                [0.5, 0.04437817512964435, 0.45562182487035563],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5000000000000001, 0.05769133623678961, 0.4423086637632104],
                                [0.3195216952064473, 0.0887563502592887, 0.591721954534264],
                                [0.29903980542261166, 0.020481889783835583, 0.6804783047935528],
                                [0.23076534494715856, 0.06827446047545312, 0.7009601945773883],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715856, 0.0887563502592887, 0.6804783047935528],
                                [0.1568801394505074, 0.10997006241983928, 0.7331497981296533],
                                [0.1315028600623326, 0.025377279388174766, 0.8431198605494926],
                                [0.046910077030668074, 0.08459278303166451, 0.8684971399376674],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.0469100770306681, 0.10997006241983928, 0.8431198605494926],
                                [0.9585025330230719, 0.00541261005373994, 0.036084856923188136],
                                [0.958248627068514, 0.0002539059545579088, 0.04149746697692808],
                                [0.9530899229693319, 0.005158704099182031, 0.04175137293148599],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.9530899229693319, 0.00541261005373994, 0.04149746697692808],
                                [0.795860977267132, 0.026626322214290513, 0.17751270051857743],
                                [0.7946119344410164, 0.0012490428261157554, 0.2041390227328679],
                                [0.7692346550528415, 0.02537727938817476, 0.2053880655589837],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.026626322214290513, 0.20413902273286794],
                                [0.5576913362367897, 0.05769133623678961, 0.38461732752642075],
                                [0.5549850312099197, 0.0027063050268699707, 0.4423086637632104],
                                [0.49999999999999994, 0.05498503120991964, 0.44501496879008035],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5000000000000001, 0.05769133623678961, 0.4423086637632104],
                                [0.3195216952064473, 0.0887563502592887, 0.591721954534264],
                                [0.31535812797882307, 0.004163567227624186, 0.6804783047935528],
                                [0.2307653449471585, 0.08459278303166452, 0.684641872021177],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715856, 0.0887563502592887, 0.6804783047935528],
                                [0.1568801394505074, 0.10997006241983928, 0.7331497981296533],
                                [0.15172143535132535, 0.0051587040991820324, 0.8431198605494926],
                                [0.046910077030668074, 0.10481135832065724, 0.8482785646486747],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.0469100770306681, 0.10997006241983928, 0.8431198605494926],
                                [0.9614170574245803, 0.002498085652231511, 0.03608485692318814],
                                [0.9534805494880725, 0.007936507936507938, 0.03858294257541965],
                                [0.9530899229693319, 0.00039062651874043075, 0.04651945051192759],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.953089922969332, 0.008327134455248368, 0.03858294257541965],
                                [0.8101984346205127, 0.012288864860909882, 0.17751270051857743],
                                [0.7711562691078283, 0.039042165512684385, 0.1898015653794873],
                                [0.7692346550528415, 0.001921614054986758, 0.2288437308921717],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528415, 0.040963779567671145, 0.1898015653794873],
                                [0.5887563502592886, 0.026626322214290524, 0.3846173275264208],
                                [0.5041635672276242, 0.08459278303166451, 0.4112436497407113],
                                [0.49999999999999994, 0.004163567227624184, 0.4958364327723758],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.0887563502592887, 0.4112436497407113],
                                [0.3673142658980647, 0.040963779567671166, 0.5917219545342641],
                                [0.23717086534742007, 0.13014340055064463, 0.6326857341019353],
                                [0.23076534494715856, 0.00640552040026161, 0.7628291346525798],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.13654892095090623, 0.6326857341019353],
                                [0.21609564309399704, 0.05075455877634953, 0.7331497981296534],
                                [0.05484658496717601, 0.16124905812682108, 0.7839043569060029],
                                [0.046910077030668046, 0.007936507936507938, 0.945153415032824],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.046910077030668074, 0.16918556606332902, 0.7839043569060029],
                                [0.9614170574245803, 0.002498085652231511, 0.03608485692318814],
                                [0.9550115370243187, 0.006405520400261611, 0.038582942575419645],
                                [0.9530899229693319, 0.001921614054986758, 0.04498846297568126],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.953089922969332, 0.008327134455248368, 0.03858294257541965],
                                [0.8101984346205127, 0.012288864860909882, 0.17751270051857743],
                                [0.7786876757751146, 0.031510758845398154, 0.18980156537948728],
                                [0.7692346550528416, 0.009453020722272993, 0.22131232422488545],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528415, 0.040963779567671145, 0.1898015653794873],
                                [0.5887563502592886, 0.026626322214290524, 0.3846173275264208],
                                [0.5204818897838356, 0.06827446047545313, 0.41124364974071126],
                                [0.5, 0.020481889783835572, 0.4795181102161644],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.0887563502592887, 0.4112436497407113],
                                [0.3673142658980647, 0.040963779567671166, 0.5917219545342641],
                                [0.2622761037925566, 0.10503816210550809, 0.6326857341019353],
                                [0.23076534494715847, 0.03151075884539815, 0.7377238962074434],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.13654892095090623, 0.6326857341019353],
                                [0.21609564309399704, 0.05075455877634953, 0.7331497981296534],
                                [0.08595224254335246, 0.13014340055064463, 0.7839043569060029],
                                [0.046910077030668046, 0.039042165512684385, 0.9140477574566476],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.046910077030668074, 0.16918556606332902, 0.7839043569060029],
                                [0.9614170574245803, 0.002498085652231511, 0.03608485692318814],
                                [0.9572534901969562, 0.004163567227624184, 0.03858294257541965],
                                [0.9530899229693319, 0.004163567227624184, 0.042746509803043835],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.953089922969332, 0.008327134455248368, 0.03858294257541965],
                                [0.8101984346205127, 0.012288864860909882, 0.17751270051857743],
                                [0.7897165448366771, 0.020481889783835572, 0.18980156537948728],
                                [0.7692346550528416, 0.020481889783835572, 0.21028345516332286],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528415, 0.040963779567671145, 0.1898015653794873],
                                [0.5887563502592886, 0.026626322214290524, 0.3846173275264208],
                                [0.5443781751296444, 0.04437817512964435, 0.41124364974071126],
                                [0.5, 0.04437817512964435, 0.45562182487035563],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.0887563502592887, 0.4112436497407113],
                                [0.3673142658980647, 0.040963779567671166, 0.5917219545342641],
                                [0.2990398054226117, 0.06827446047545312, 0.6326857341019352],
                                [0.23076534494715856, 0.06827446047545312, 0.7009601945773883],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.13654892095090623, 0.6326857341019353],
                                [0.21609564309399704, 0.05075455877634953, 0.7331497981296534],
                                [0.13150286006233258, 0.08459278303166451, 0.7839043569060029],
                                [0.046910077030668074, 0.08459278303166451, 0.8684971399376674],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.046910077030668074, 0.16918556606332902, 0.7839043569060029],
                                [0.9614170574245803, 0.002498085652231511, 0.03608485692318814],
                                [0.9594954433695936, 0.001921614054986759, 0.03858294257541965],
                                [0.9530899229693319, 0.006405520400261609, 0.04050455663040641],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.953089922969332, 0.008327134455248368, 0.03858294257541965],
                                [0.8101984346205127, 0.012288864860909882, 0.17751270051857743],
                                [0.8007454138982397, 0.009453020722272998, 0.1898015653794873],
                                [0.7692346550528416, 0.03151075884539815, 0.1992545861017603],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528415, 0.040963779567671145, 0.1898015653794873],
                                [0.5887563502592886, 0.026626322214290524, 0.3846173275264208],
                                [0.5682744604754532, 0.020481889783835583, 0.4112436497407113],
                                [0.49999999999999994, 0.06827446047545312, 0.4317255395245469],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.0887563502592887, 0.4112436497407113],
                                [0.3673142658980647, 0.040963779567671166, 0.5917219545342641],
                                [0.33580350705266665, 0.03151075884539817, 0.6326857341019352],
                                [0.2307653449471585, 0.10503816210550808, 0.6641964929473334],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.13654892095090623, 0.6326857341019353],
                                [0.21609564309399704, 0.05075455877634953, 0.7331497981296534],
                                [0.17705347758131257, 0.039042165512684406, 0.783904356906003],
                                [0.04691007703066802, 0.1301434005506446, 0.8229465224186874],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.046910077030668074, 0.16918556606332902, 0.7839043569060029],
                                [0.9614170574245803, 0.002498085652231511, 0.03608485692318814],
                                [0.96102643090584, 0.0003906265187404313, 0.03858294257541965],
                                [0.953089922969332, 0.007936507936507938, 0.03897356909416008],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.953089922969332, 0.008327134455248368, 0.03858294257541965],
                                [0.8101984346205127, 0.012288864860909882, 0.17751270051857743],
                                [0.8082768205655259, 0.001921614054986761, 0.1898015653794873],
                                [0.7692346550528416, 0.039042165512684385, 0.19172317943447406],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528415, 0.040963779567671145, 0.1898015653794873],
                                [0.5887563502592886, 0.026626322214290524, 0.3846173275264208],
                                [0.5845927830316645, 0.00416356722762419, 0.4112436497407113],
                                [0.5, 0.08459278303166451, 0.4154072169683355],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.0887563502592887, 0.4112436497407113],
                                [0.3673142658980647, 0.040963779567671166, 0.5917219545342641],
                                [0.3609087454978032, 0.0064055204002616195, 0.6326857341019352],
                                [0.23076534494715853, 0.13014340055064463, 0.6390912545021968],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.13654892095090623, 0.6326857341019353],
                                [0.21609564309399704, 0.05075455877634953, 0.7331497981296534],
                                [0.20815913515748916, 0.007936507936507948, 0.7839043569060029],
                                [0.0469100770306681, 0.16124905812682108, 0.7918408648425108],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.046910077030668074, 0.16918556606332902, 0.7839043569060029],
                                [0.963407331167696, 0.0005078119091158176, 0.03608485692318814],
                                [0.953573913382674, 0.009833417785021958, 0.03659266883230396],
                                [0.9530899229693319, 0.0004839904133421039, 0.04642608661732591],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.819989213829191, 0.0024980856522315107, 0.17751270051857743],
                                [0.7716155553146977, 0.04837365851449339, 0.18001078617080896],
                                [0.7692346550528416, 0.002380900261856123, 0.22838444468530233],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.6099700624198393, 0.005412610053739941, 0.38461732752642075],
                                [0.505158704099182, 0.10481135832065724, 0.39002993758016075],
                                [0.5, 0.005158704099182031, 0.494841295900818],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.10997006241983928, 0.3900299375801607],
                                [0.39995091101048763, 0.008327134455248372, 0.591721954534264],
                                [0.23870185288366644, 0.16124905812682108, 0.6000490889895125],
                                [0.23076534494715847, 0.007936507936507938, 0.7612981471163336],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.16918556606332905, 0.6000490889895125],
                                [0.2565327936719825, 0.010317408198364065, 0.7331497981296534],
                                [0.05674349481568994, 0.1997892988562925, 0.7434672063280175],
                                [0.046910077030668115, 0.009833417785021958, 0.9432565051843099],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.963407331167696, 0.0005078119091158176, 0.03608485692318814],
                                [0.9554708232311881, 0.007936507936507938, 0.03659266883230396],
                                [0.953089922969332, 0.002380900261856123, 0.04452917676881189],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.819989213829191, 0.0024980856522315107, 0.17751270051857743],
                                [0.7809470483165067, 0.03904216551268439, 0.18001078617080896],
                                [0.7692346550528415, 0.011712393263665124, 0.2190529516834933],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.6099700624198393, 0.005412610053739941, 0.38461732752642075],
                                [0.5253772793881747, 0.08459278303166452, 0.39002993758016075],
                                [0.5, 0.02537727938817476, 0.47462272061182526],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.10997006241983928, 0.3900299375801607],
                                [0.39995091101048763, 0.008327134455248372, 0.591721954534264],
                                [0.26980751045984286, 0.13014340055064463, 0.6000490889895125],
                                [0.23076534494715847, 0.03904216551268439, 0.7301924895401571],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.16918556606332905, 0.6000490889895125],
                                [0.2565327936719825, 0.010317408198364065, 0.7331497981296534],
                                [0.09528373554516145, 0.1612490581268211, 0.7434672063280174],
                                [0.04691007703066806, 0.04837365851449339, 0.9047162644548385],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.963407331167696, 0.0005078119091158176, 0.03608485692318814],
                                [0.958248627068514, 0.005158704099182031, 0.03659266883230396],
                                [0.9530899229693319, 0.005158704099182031, 0.04175137293148599],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.819989213829191, 0.0024980856522315107, 0.17751270051857743],
                                [0.7946119344410163, 0.02537727938817476, 0.1800107861708089],
                                [0.7692346550528415, 0.02537727938817476, 0.2053880655589837],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.6099700624198393, 0.005412610053739941, 0.38461732752642075],
                                [0.5549850312099197, 0.05498503120991964, 0.3900299375801607],
                                [0.49999999999999994, 0.05498503120991964, 0.44501496879008035],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.10997006241983928, 0.3900299375801607],
                                [0.39995091101048763, 0.008327134455248372, 0.591721954534264],
                                [0.315358127978823, 0.08459278303166452, 0.6000490889895125],
                                [0.2307653449471585, 0.08459278303166452, 0.684641872021177],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.16918556606332905, 0.6000490889895125],
                                [0.2565327936719825, 0.010317408198364065, 0.7331497981296534],
                                [0.15172143535132532, 0.10481135832065724, 0.7434672063280174],
                                [0.046910077030668074, 0.10481135832065724, 0.8482785646486747],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.963407331167696, 0.0005078119091158176, 0.03608485692318814],
                                [0.96102643090584, 0.002380900261856123, 0.03659266883230396],
                                [0.953089922969332, 0.007936507936507938, 0.03897356909416008],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.819989213829191, 0.0024980856522315107, 0.17751270051857743],
                                [0.808276820565526, 0.011712393263665124, 0.18001078617080893],
                                [0.7692346550528416, 0.03904216551268439, 0.19172317943447406],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.6099700624198393, 0.005412610053739941, 0.38461732752642075],
                                [0.5845927830316644, 0.02537727938817476, 0.39002993758016075],
                                [0.5, 0.08459278303166452, 0.4154072169683355],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.10997006241983928, 0.3900299375801607],
                                [0.39995091101048763, 0.008327134455248372, 0.591721954534264],
                                [0.3609087454978031, 0.03904216551268439, 0.6000490889895125],
                                [0.23076534494715853, 0.13014340055064463, 0.6390912545021968],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.16918556606332905, 0.6000490889895125],
                                [0.2565327936719825, 0.010317408198364065, 0.7331497981296534],
                                [0.20815913515748918, 0.04837365851449339, 0.7434672063280174],
                                [0.046910077030668074, 0.1612490581268211, 0.7918408648425108],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.963407331167696, 0.0005078119091158176, 0.03608485692318814],
                                [0.9629233407543539, 0.00048399041334210453, 0.03659266883230396],
                                [0.9530899229693319, 0.009833417785021958, 0.03707665924564606],
                                [0.9530899229693319, 0.01082522010747988, 0.036084856923188136],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.819989213829191, 0.0024980856522315107, 0.17751270051857743],
                                [0.817608313567335, 0.0023809002618561262, 0.18001078617080893],
                                [0.7692346550528415, 0.04837365851449339, 0.18239168643266507],
                                [0.7692346550528415, 0.05325264442858103, 0.17751270051857743],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.6099700624198393, 0.005412610053739941, 0.38461732752642075],
                                [0.6048113583206572, 0.005158704099182038, 0.3900299375801607],
                                [0.5, 0.10481135832065724, 0.39518864167934276],
                                [0.5, 0.11538267247357922, 0.38461732752642075],
                                [0.5, 0.10997006241983928, 0.3900299375801607],
                                [0.39995091101048763, 0.008327134455248372, 0.591721954534264],
                                [0.39201440307397956, 0.007936507936507948, 0.6000490889895125],
                                [0.23076534494715853, 0.16124905812682108, 0.6079855969260204],
                                [0.23076534494715847, 0.1775127005185774, 0.5917219545342641],
                                [0.23076534494715847, 0.16918556606332905, 0.6000490889895125],
                                [0.2565327936719825, 0.010317408198364065, 0.7331497981296534],
                                [0.2466993758869606, 0.00983341778502197, 0.7434672063280174],
                                [0.046910077030668046, 0.1997892988562925, 0.7533006241130394],
                                [0.04691007703066813, 0.21994012483967856, 0.7331497981296533],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.9541902006328435, 0.022354760851822406, 0.02345503851533401],
                                [0.9531415370792824, 0.001048663553561151, 0.045809799367156415],
                                [0.9530899229693319, 5.1614109950452745e-05, 0.04685846292071757],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.7746472651065814, 0.10997006241983928, 0.11538267247357922],
                                [0.7694885610073994, 0.005158704099182031, 0.2253527348934185],
                                [0.7692346550528416, 0.0002539059545579087, 0.23051143899260054],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.00541261005373994, 0.2253527348934185],
                                [0.511727519257667, 0.23827248074233298, 0.25],
                                [0.5005501388317558, 0.011177380425911203, 0.488272480742333],
                                [0.5, 0.0005501388317558017, 0.4994498611682442],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.011727519257667005, 0.488272480742333],
                                [0.2488077734087526, 0.36657489906482665, 0.38461732752642075],
                                [0.23161171665611222, 0.017196056752640375, 0.7511922265912474],
                                [0.23076534494715856, 0.0008463717089536947, 0.7683882833438878],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715853, 0.018042428461594068, 0.7511922265912474],
                                [0.0692648378824905, 0.45419020063284354, 0.47654496148466596],
                                [0.04795874058422924, 0.021306097298261252, 0.9307351621175095],
                                [0.04691007703066807, 0.0010486635535611507, 0.9520412594157708],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.04691007703066809, 0.022354760851822406, 0.9307351621175095],
                                [0.9541902006328435, 0.022354760851822406, 0.02345503851533401],
                                [0.9533438289238898, 0.0008463717089536947, 0.045809799367156415],
                                [0.953089922969332, 0.00025390595455790875, 0.04665617107611011],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.7746472651065814, 0.10997006241983928, 0.11538267247357922],
                                [0.7704836978789572, 0.004163567227624184, 0.2253527348934185],
                                [0.7692346550528416, 0.001249042826115755, 0.22951630212104268],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.00541261005373994, 0.2253527348934185],
                                [0.511727519257667, 0.23827248074233298, 0.25],
                                [0.50270630502687, 0.009021214230797034, 0.488272480742333],
                                [0.5, 0.00270630502686997, 0.49729369497313003],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.011727519257667005, 0.488272480742333],
                                [0.2488077734087526, 0.36657489906482665, 0.38461732752642075],
                                [0.2349289121747827, 0.013878861233969883, 0.7511922265912474],
                                [0.23076534494715856, 0.004163567227624184, 0.7650710878252173],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715853, 0.018042428461594068, 0.7511922265912474],
                                [0.0692648378824905, 0.45419020063284354, 0.47654496148466596],
                                [0.052068781129850125, 0.01719605675264037, 0.9307351621175095],
                                [0.04691007703066811, 0.005158704099182031, 0.9479312188701499],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.04691007703066809, 0.022354760851822406, 0.9307351621175095],
                                [0.9541902006328435, 0.022354760851822406, 0.02345503851533401],
                                [0.9536400618010877, 0.0005501388317558017, 0.045809799367156415],
                                [0.9530899229693319, 0.0005501388317558017, 0.046359938198912216],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.7746472651065814, 0.10997006241983928, 0.11538267247357922],
                                [0.7719409600797115, 0.00270630502686997, 0.2253527348934185],
                                [0.7692346550528416, 0.00270630502686997, 0.22805903992028848],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.00541261005373994, 0.2253527348934185],
                                [0.511727519257667, 0.23827248074233298, 0.25],
                                [0.5058637596288336, 0.005863759628833502, 0.488272480742333],
                                [0.5000000000000001, 0.005863759628833502, 0.4941362403711665],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.011727519257667005, 0.488272480742333],
                                [0.2488077734087526, 0.36657489906482665, 0.38461732752642075],
                                [0.23978655917795555, 0.009021214230797034, 0.7511922265912474],
                                [0.2307653449471585, 0.009021214230797034, 0.7602134408220445],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715853, 0.018042428461594068, 0.7511922265912474],
                                [0.0692648378824905, 0.45419020063284354, 0.47654496148466596],
                                [0.05808745745657929, 0.011177380425911203, 0.9307351621175095],
                                [0.04691007703066808, 0.011177380425911203, 0.9419125425434207],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.04691007703066809, 0.022354760851822406, 0.9307351621175095],
                                [0.9541902006328435, 0.022354760851822406, 0.02345503851533401],
                                [0.9539362946782857, 0.0002539059545579088, 0.045809799367156415],
                                [0.9530899229693319, 0.0008463717089536947, 0.046063705321714325],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.7746472651065814, 0.10997006241983928, 0.11538267247357922],
                                [0.7733982222804658, 0.0012490428261157554, 0.22535273489341848],
                                [0.7692346550528415, 0.004163567227624184, 0.22660177771953427],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.00541261005373994, 0.2253527348934185],
                                [0.511727519257667, 0.23827248074233298, 0.25],
                                [0.509021214230797, 0.0027063050268699707, 0.488272480742333],
                                [0.5, 0.009021214230797034, 0.49097878576920295],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.011727519257667005, 0.488272480742333],
                                [0.2488077734087526, 0.36657489906482665, 0.38461732752642075],
                                [0.24464420618112842, 0.004163567227624186, 0.7511922265912474],
                                [0.23076534494715847, 0.013878861233969883, 0.7553557938188716],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715853, 0.018042428461594068, 0.7511922265912474],
                                [0.0692648378824905, 0.45419020063284354, 0.47654496148466596],
                                [0.06410613378330846, 0.0051587040991820324, 0.9307351621175095],
                                [0.04691007703066806, 0.01719605675264037, 0.9358938662166916],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.04691007703066809, 0.022354760851822406, 0.9307351621175095],
                                [0.9541902006328435, 0.022354760851822406, 0.02345503851533401],
                                [0.9541385865228931, 5.1614109950452745e-05, 0.045809799367156415],
                                [0.953089922969332, 0.001048663553561151, 0.045861413477106865],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.0011002776635116035, 0.045809799367156415],
                                [0.7746472651065814, 0.10997006241983928, 0.11538267247357922],
                                [0.7743933591520236, 0.0002539059545579087, 0.2253527348934185],
                                [0.7692346550528415, 0.005158704099182031, 0.2256066408479764],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.00541261005373994, 0.2253527348934185],
                                [0.511727519257667, 0.23827248074233298, 0.25],
                                [0.5111773804259112, 0.0005501388317558017, 0.488272480742333],
                                [0.5, 0.011177380425911203, 0.4888226195740888],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.011727519257667005, 0.488272480742333],
                                [0.2488077734087526, 0.36657489906482665, 0.38461732752642075],
                                [0.2479614016997989, 0.0008463717089536947, 0.7511922265912474],
                                [0.23076534494715847, 0.017196056752640375, 0.7520385983002011],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715853, 0.018042428461594068, 0.7511922265912474],
                                [0.0692648378824905, 0.45419020063284354, 0.47654496148466596],
                                [0.06821617432892935, 0.0010486635535611507, 0.9307351621175095],
                                [0.046910077030668094, 0.021306097298261252, 0.9317838256710707],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.04691007703066809, 0.022354760851822406, 0.9307351621175095],
                                [0.9585025330230719, 0.018042428461594068, 0.02345503851533401],
                                [0.9533438289238898, 0.005158704099182031, 0.04149746697692808],
                                [0.953089922969332, 0.00025390595455790875, 0.04665617107611011],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.00541261005373994, 0.04149746697692808],
                                [0.795860977267132, 0.0887563502592887, 0.11538267247357924],
                                [0.7704836978789573, 0.02537727938817476, 0.20413902273286794],
                                [0.7692346550528416, 0.001249042826115755, 0.22951630212104268],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528416, 0.026626322214290513, 0.20413902273286794],
                                [0.5576913362367897, 0.19230866376321037, 0.25],
                                [0.5027063050268701, 0.05498503120991964, 0.4423086637632104],
                                [0.5, 0.00270630502686997, 0.49729369497313003],
                                [0.5, 0.25, 0.25],
                                [0.5000000000000001, 0.05769133623678961, 0.4423086637632104],
                                [0.31952169520644724, 0.295860977267132, 0.38461732752642075],
                                [0.23492891217478273, 0.08459278303166452, 0.6804783047935528],
                                [0.23076534494715856, 0.004163567227624184, 0.7650710878252173],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715856, 0.0887563502592887, 0.6804783047935528],
                                [0.15688013945050738, 0.36657489906482665, 0.47654496148466596],
                                [0.05206878112985014, 0.10481135832065724, 0.8431198605494926],
                                [0.04691007703066811, 0.005158704099182031, 0.9479312188701499],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.0469100770306681, 0.10997006241983928, 0.8431198605494926],
                                [0.9585025330230719, 0.018042428461594068, 0.02345503851533401],
                                [0.9543389657954476, 0.004163567227624185, 0.04149746697692808],
                                [0.953089922969332, 0.001249042826115755, 0.04566103420455226],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.00541261005373994, 0.04149746697692808],
                                [0.795860977267132, 0.0887563502592887, 0.11538267247357924],
                                [0.7753790874832965, 0.020481889783835576, 0.20413902273286794],
                                [0.7692346550528415, 0.006144432430454938, 0.22462091251670352],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528416, 0.026626322214290513, 0.20413902273286794],
                                [0.5576913362367897, 0.19230866376321037, 0.25],
                                [0.5133131611071453, 0.04437817512964436, 0.4423086637632104],
                                [0.5, 0.013313161107145257, 0.48668683889285475],
                                [0.5, 0.25, 0.25],
                                [0.5000000000000001, 0.05769133623678961, 0.4423086637632104],
                                [0.31952169520644724, 0.295860977267132, 0.38461732752642075],
                                [0.2512472347309941, 0.06827446047545313, 0.6804783047935528],
                                [0.2307653449471585, 0.020481889783835572, 0.7487527652690059],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715856, 0.0887563502592887, 0.6804783047935528],
                                [0.15688013945050738, 0.36657489906482665, 0.47654496148466596],
                                [0.07228735641884286, 0.08459278303166452, 0.8431198605494926],
                                [0.046910077030668115, 0.025377279388174755, 0.9277126435811571],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.0469100770306681, 0.10997006241983928, 0.8431198605494926],
                                [0.9585025330230719, 0.018042428461594068, 0.02345503851533401],
                                [0.9557962279962019, 0.00270630502686997, 0.04149746697692808],
                                [0.953089922969332, 0.00270630502686997, 0.04420377200379805],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.00541261005373994, 0.04149746697692808],
                                [0.795860977267132, 0.0887563502592887, 0.11538267247357924],
                                [0.7825478161599868, 0.013313161107145257, 0.20413902273286794],
                                [0.7692346550528415, 0.013313161107145257, 0.2174521838400132],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528416, 0.026626322214290513, 0.20413902273286794],
                                [0.5576913362367897, 0.19230866376321037, 0.25],
                                [0.5288456681183947, 0.028845668118394806, 0.44230866376321043],
                                [0.5, 0.028845668118394806, 0.4711543318816052],
                                [0.5, 0.25, 0.25],
                                [0.5000000000000001, 0.05769133623678961, 0.4423086637632104],
                                [0.31952169520644724, 0.295860977267132, 0.38461732752642075],
                                [0.27514352007680287, 0.04437817512964435, 0.6804783047935528],
                                [0.23076534494715853, 0.04437817512964435, 0.7248564799231971],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715856, 0.0887563502592887, 0.6804783047935528],
                                [0.15688013945050738, 0.36657489906482665, 0.47654496148466596],
                                [0.10189510824058763, 0.05498503120991964, 0.8431198605494927],
                                [0.04691007703066803, 0.05498503120991964, 0.8981048917594123],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.0469100770306681, 0.10997006241983928, 0.8431198605494926],
                                [0.9585025330230719, 0.018042428461594068, 0.02345503851533401],
                                [0.9572534901969562, 0.0012490428261157556, 0.04149746697692808],
                                [0.9530899229693319, 0.004163567227624184, 0.042746509803043835],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.00541261005373994, 0.04149746697692808],
                                [0.795860977267132, 0.0887563502592887, 0.11538267247357924],
                                [0.7897165448366772, 0.006144432430454941, 0.20413902273286794],
                                [0.7692346550528416, 0.020481889783835572, 0.21028345516332286],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528416, 0.026626322214290513, 0.20413902273286794],
                                [0.5576913362367897, 0.19230866376321037, 0.25],
                                [0.5443781751296444, 0.013313161107145262, 0.4423086637632104],
                                [0.5, 0.04437817512964435, 0.45562182487035563],
                                [0.5, 0.25, 0.25],
                                [0.5000000000000001, 0.05769133623678961, 0.4423086637632104],
                                [0.31952169520644724, 0.295860977267132, 0.38461732752642075],
                                [0.29903980542261166, 0.020481889783835583, 0.6804783047935528],
                                [0.23076534494715856, 0.06827446047545312, 0.7009601945773883],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715856, 0.0887563502592887, 0.6804783047935528],
                                [0.15688013945050738, 0.36657489906482665, 0.47654496148466596],
                                [0.1315028600623326, 0.025377279388174766, 0.8431198605494926],
                                [0.046910077030668074, 0.08459278303166451, 0.8684971399376674],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.0469100770306681, 0.10997006241983928, 0.8431198605494926],
                                [0.9585025330230719, 0.018042428461594068, 0.02345503851533401],
                                [0.958248627068514, 0.0002539059545579088, 0.04149746697692808],
                                [0.9530899229693319, 0.005158704099182031, 0.04175137293148599],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.00541261005373994, 0.04149746697692808],
                                [0.795860977267132, 0.0887563502592887, 0.11538267247357924],
                                [0.7946119344410164, 0.0012490428261157554, 0.2041390227328679],
                                [0.7692346550528415, 0.02537727938817476, 0.2053880655589837],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528416, 0.026626322214290513, 0.20413902273286794],
                                [0.5576913362367897, 0.19230866376321037, 0.25],
                                [0.5549850312099197, 0.0027063050268699707, 0.4423086637632104],
                                [0.49999999999999994, 0.05498503120991964, 0.44501496879008035],
                                [0.5, 0.25, 0.25],
                                [0.5000000000000001, 0.05769133623678961, 0.4423086637632104],
                                [0.31952169520644724, 0.295860977267132, 0.38461732752642075],
                                [0.31535812797882307, 0.004163567227624186, 0.6804783047935528],
                                [0.2307653449471585, 0.08459278303166452, 0.684641872021177],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715856, 0.0887563502592887, 0.6804783047935528],
                                [0.15688013945050738, 0.36657489906482665, 0.47654496148466596],
                                [0.15172143535132535, 0.0051587040991820324, 0.8431198605494926],
                                [0.046910077030668074, 0.10481135832065724, 0.8482785646486747],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.0469100770306681, 0.10997006241983928, 0.8431198605494926],
                                [0.964817442226999, 0.011727519257667005, 0.02345503851533401],
                                [0.9536400618010877, 0.011177380425911203, 0.035182557773001014],
                                [0.9530899229693319, 0.0005501388317558017, 0.046359938198912216],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.8269259912896312, 0.05769133623678961, 0.11538267247357921],
                                [0.7719409600797116, 0.05498503120991964, 0.17307400871036882],
                                [0.7692346550528416, 0.00270630502686997, 0.22805903992028848],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528416, 0.05769133623678961, 0.17307400871036882],
                                [0.625, 0.125, 0.25],
                                [0.5058637596288336, 0.11913624037116649, 0.375],
                                [0.5000000000000001, 0.005863759628833502, 0.4941362403711665],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.42307400871036877, 0.19230866376321037, 0.3846173275264208],
                                [0.2397865591779555, 0.18328744953241333, 0.5769259912896312],
                                [0.2307653449471585, 0.009021214230797034, 0.7602134408220445],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715845, 0.19230866376321037, 0.5769259912896312],
                                [0.28518255777300106, 0.23827248074233298, 0.47654496148466596],
                                [0.05808745745657928, 0.22709510031642177, 0.714817442226999],
                                [0.04691007703066808, 0.011177380425911203, 0.9419125425434207],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.964817442226999, 0.011727519257667005, 0.02345503851533401],
                                [0.9557962279962019, 0.009021214230797034, 0.035182557773001014],
                                [0.953089922969332, 0.00270630502686997, 0.04420377200379805],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.8269259912896312, 0.05769133623678961, 0.11538267247357921],
                                [0.7825478161599868, 0.04437817512964435, 0.17307400871036885],
                                [0.7692346550528415, 0.013313161107145257, 0.2174521838400132],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528416, 0.05769133623678961, 0.17307400871036882],
                                [0.625, 0.125, 0.25],
                                [0.5288456681183948, 0.09615433188160519, 0.375],
                                [0.5, 0.028845668118394806, 0.4711543318816052],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.42307400871036877, 0.19230866376321037, 0.3846173275264208],
                                [0.2751435200768028, 0.147930488633566, 0.5769259912896312],
                                [0.23076534494715853, 0.04437817512964435, 0.7248564799231971],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715845, 0.19230866376321037, 0.5769259912896312],
                                [0.28518255777300106, 0.23827248074233298, 0.47654496148466596],
                                [0.10189510824058762, 0.18328744953241333, 0.7148174422269991],
                                [0.04691007703066803, 0.05498503120991964, 0.8981048917594123],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.964817442226999, 0.011727519257667005, 0.02345503851533401],
                                [0.9589536825981655, 0.005863759628833502, 0.035182557773001014],
                                [0.953089922969332, 0.005863759628833502, 0.041046317401834516],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.8269259912896312, 0.05769133623678961, 0.11538267247357921],
                                [0.7980803231712363, 0.028845668118394806, 0.17307400871036882],
                                [0.7692346550528415, 0.028845668118394806, 0.20191967682876363],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528416, 0.05769133623678961, 0.17307400871036882],
                                [0.625, 0.125, 0.25],
                                [0.5625, 0.0625, 0.375],
                                [0.5, 0.0625, 0.4375],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.42307400871036877, 0.19230866376321037, 0.3846173275264208],
                                [0.32691967682876366, 0.09615433188160519, 0.5769259912896312],
                                [0.23076534494715847, 0.09615433188160519, 0.6730803231712363],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715845, 0.19230866376321037, 0.5769259912896312],
                                [0.28518255777300106, 0.23827248074233298, 0.47654496148466596],
                                [0.16604631740183445, 0.11913624037116649, 0.7148174422269991],
                                [0.04691007703066802, 0.11913624037116649, 0.8339536825981655],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.964817442226999, 0.011727519257667005, 0.02345503851533401],
                                [0.962111137200129, 0.0027063050268699707, 0.035182557773001014],
                                [0.9530899229693319, 0.009021214230797034, 0.037888862799870984],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.8269259912896312, 0.05769133623678961, 0.11538267247357921],
                                [0.8136128301824859, 0.01331316110714526, 0.17307400871036885],
                                [0.7692346550528415, 0.04437817512964435, 0.1863871698175141],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528416, 0.05769133623678961, 0.17307400871036882],
                                [0.625, 0.125, 0.25],
                                [0.5961543318816052, 0.028845668118394813, 0.375],
                                [0.5, 0.09615433188160519, 0.40384566811839484],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.42307400871036877, 0.19230866376321037, 0.3846173275264208],
                                [0.37869583358072445, 0.044378175129644364, 0.5769259912896312],
                                [0.23076534494715845, 0.147930488633566, 0.6213041664192755],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715845, 0.19230866376321037, 0.5769259912896312],
                                [0.28518255777300106, 0.23827248074233298, 0.47654496148466596],
                                [0.2301975265630813, 0.054985031209919655, 0.7148174422269991],
                                [0.04691007703066802, 0.18328744953241333, 0.7698024734369187],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.964817442226999, 0.011727519257667005, 0.02345503851533401],
                                [0.9642673033952431, 0.0005501388317558024, 0.035182557773001014],
                                [0.9530899229693319, 0.011177380425911203, 0.035732696604756815],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.011727519257667005, 0.035182557773001014],
                                [0.8269259912896312, 0.05769133623678961, 0.11538267247357921],
                                [0.8242196862627612, 0.0027063050268699733, 0.17307400871036885],
                                [0.7692346550528416, 0.05498503120991964, 0.1757803137372388],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528416, 0.05769133623678961, 0.17307400871036882],
                                [0.625, 0.125, 0.25],
                                [0.6191362403711664, 0.005863759628833509, 0.375],
                                [0.49999999999999994, 0.11913624037116649, 0.3808637596288335],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.125, 0.375],
                                [0.42307400871036877, 0.19230866376321037, 0.3846173275264208],
                                [0.4140527944795719, 0.009021214230797044, 0.5769259912896311],
                                [0.23076534494715845, 0.18328744953241333, 0.5859472055204282],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.23076534494715845, 0.19230866376321037, 0.5769259912896312],
                                [0.28518255777300106, 0.23827248074233298, 0.47654496148466596],
                                [0.27400517734708985, 0.011177380425911215, 0.714817442226999],
                                [0.046910077030668074, 0.22709510031642177, 0.7259948226529102],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.23827248074233298, 0.714817442226999],
                                [0.971132351430926, 0.005412610053739941, 0.02345503851533401],
                                [0.9539362946782857, 0.01719605675264037, 0.028867648569073954],
                                [0.9530899229693319, 0.0008463717089536947, 0.046063705321714325],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.8579910053121302, 0.02662632221429052, 0.11538267247357921],
                                [0.7733982222804657, 0.08459278303166451, 0.14200899468786973],
                                [0.7692346550528415, 0.004163567227624184, 0.22660177771953427],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.0887563502592887, 0.14200899468786976],
                                [0.6923086637632103, 0.057691336236789625, 0.25],
                                [0.509021214230797, 0.18328744953241333, 0.3076913362367896],
                                [0.5, 0.009021214230797034, 0.49097878576920295],
                                [0.5, 0.25, 0.25],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5266263222142905, 0.08875635025928873, 0.38461732752642075],
                                [0.24464420618112837, 0.28198211603316214, 0.4733736777857095],
                                [0.23076534494715847, 0.013878861233969883, 0.7553557938188716],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.4134849760954947, 0.10997006241983931, 0.47654496148466596],
                                [0.06410613378330837, 0.34937884231218624, 0.5865150239045054],
                                [0.04691007703066806, 0.01719605675264037, 0.9358938662166916],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.971132351430926, 0.005412610053739941, 0.02345503851533401],
                                [0.9572534901969562, 0.013878861233969884, 0.02886764856907395],
                                [0.9530899229693319, 0.004163567227624184, 0.042746509803043835],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.8579910053121302, 0.02662632221429052, 0.11538267247357921],
                                [0.7897165448366771, 0.06827446047545313, 0.14200899468786973],
                                [0.7692346550528416, 0.020481889783835572, 0.21028345516332286],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.0887563502592887, 0.14200899468786976],
                                [0.6923086637632103, 0.057691336236789625, 0.25],
                                [0.5443781751296444, 0.14793048863356603, 0.30769133623678957],
                                [0.5, 0.04437817512964435, 0.45562182487035563],
                                [0.5, 0.25, 0.25],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5266263222142905, 0.08875635025928873, 0.38461732752642075],
                                [0.2990398054226117, 0.2275865167916789, 0.47337367778570943],
                                [0.23076534494715856, 0.06827446047545312, 0.7009601945773883],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.4134849760954947, 0.10997006241983931, 0.47654496148466596],
                                [0.13150286006233258, 0.28198211603316214, 0.5865150239045053],
                                [0.046910077030668074, 0.08459278303166451, 0.8684971399376674],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.971132351430926, 0.005412610053739941, 0.02345503851533401],
                                [0.962111137200129, 0.009021214230797034, 0.02886764856907395],
                                [0.9530899229693319, 0.009021214230797034, 0.037888862799870984],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.8579910053121302, 0.02662632221429052, 0.11538267247357921],
                                [0.8136128301824859, 0.04437817512964435, 0.14200899468786976],
                                [0.7692346550528415, 0.04437817512964435, 0.1863871698175141],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.0887563502592887, 0.14200899468786976],
                                [0.6923086637632103, 0.057691336236789625, 0.25],
                                [0.5961543318816052, 0.09615433188160519, 0.3076913362367897],
                                [0.5, 0.09615433188160519, 0.40384566811839484],
                                [0.5, 0.25, 0.25],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5266263222142905, 0.08875635025928873, 0.38461732752642075],
                                [0.3786958335807244, 0.147930488633566, 0.47337367778570955],
                                [0.23076534494715845, 0.147930488633566, 0.6213041664192755],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.4134849760954947, 0.10997006241983931, 0.47654496148466596],
                                [0.2301975265630813, 0.18328744953241333, 0.5865150239045054],
                                [0.04691007703066802, 0.18328744953241333, 0.7698024734369187],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.971132351430926, 0.005412610053739941, 0.02345503851533401],
                                [0.9669687842033018, 0.004163567227624186, 0.028867648569073947],
                                [0.953089922969332, 0.013878861233969883, 0.033031215796698134],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.8579910053121302, 0.02662632221429052, 0.11538267247357921],
                                [0.8375091155282947, 0.020481889783835583, 0.14200899468786973],
                                [0.7692346550528415, 0.06827446047545312, 0.16249088447170534],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.0887563502592887, 0.14200899468786976],
                                [0.6923086637632103, 0.057691336236789625, 0.25],
                                [0.647930488633566, 0.04437817512964437, 0.3076913362367896],
                                [0.49999999999999994, 0.147930488633566, 0.352069511366434],
                                [0.5, 0.25, 0.25],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5266263222142905, 0.08875635025928873, 0.38461732752642075],
                                [0.45835186173883735, 0.06827446047545316, 0.4733736777857095],
                                [0.23076534494715847, 0.22758651679167888, 0.5416481382611626],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.4134849760954947, 0.10997006241983931, 0.47654496148466596],
                                [0.32889219306383016, 0.08459278303166455, 0.5865150239045053],
                                [0.04691007703066813, 0.2819821160331621, 0.6711078069361698],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.971132351430926, 0.005412610053739941, 0.02345503851533401],
                                [0.9702859797219723, 0.000846371708953696, 0.02886764856907395],
                                [0.953089922969332, 0.01719605675264037, 0.029714020278027647],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.8579910053121302, 0.02662632221429052, 0.11538267247357921],
                                [0.853827438084506, 0.004163567227624191, 0.14200899468786973],
                                [0.7692346550528416, 0.08459278303166451, 0.14617256191549394],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.0887563502592887, 0.14200899468786976],
                                [0.6923086637632103, 0.057691336236789625, 0.25],
                                [0.6832874495324133, 0.009021214230797048, 0.3076913362367896],
                                [0.49999999999999994, 0.18328744953241333, 0.3167125504675867],
                                [0.5, 0.25, 0.25],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5266263222142905, 0.08875635025928873, 0.38461732752642075],
                                [0.5127474609803208, 0.013878861233969903, 0.47337367778570943],
                                [0.2307653449471585, 0.28198211603316214, 0.48725253901967935],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.4134849760954947, 0.10997006241983931, 0.47654496148466596],
                                [0.3962889193428543, 0.0171960567526404, 0.5865150239045053],
                                [0.04691007703066802, 0.34937884231218624, 0.6037110806571457],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.9754446838211543, 0.0011002776635116048, 0.02345503851533401],
                                [0.9541385865228931, 0.021306097298261252, 0.024555316178845613],
                                [0.953089922969332, 0.001048663553561151, 0.045861413477106865],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.8792047174726808, 0.0054126100537399465, 0.11538267247357922],
                                [0.7743933591520236, 0.10481135832065724, 0.12079528252731916],
                                [0.7692346550528415, 0.005158704099182031, 0.2256066408479764],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.738272480742333, 0.011727519257667018, 0.25],
                                [0.5111773804259112, 0.22709510031642177, 0.261727519257667],
                                [0.5, 0.011177380425911203, 0.4888226195740888],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5973402440119852, 0.01804242846159409, 0.38461732752642075],
                                [0.24796140169979886, 0.3493788423121863, 0.40265975598801484],
                                [0.23076534494715847, 0.017196056752640375, 0.7520385983002011],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5011002776635116, 0.02235476085182243, 0.47654496148466596],
                                [0.06821617432892935, 0.43288410333458227, 0.4988997223364884],
                                [0.046910077030668094, 0.021306097298261252, 0.9317838256710707],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.9754446838211543, 0.0011002776635116048, 0.02345503851533401],
                                [0.958248627068514, 0.01719605675264037, 0.024555316178845616],
                                [0.9530899229693319, 0.005158704099182031, 0.04175137293148599],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.8792047174726808, 0.0054126100537399465, 0.11538267247357922],
                                [0.7946119344410163, 0.08459278303166451, 0.12079528252731916],
                                [0.7692346550528415, 0.02537727938817476, 0.2053880655589837],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.738272480742333, 0.011727519257667018, 0.25],
                                [0.5549850312099196, 0.18328744953241333, 0.261727519257667],
                                [0.49999999999999994, 0.05498503120991964, 0.44501496879008035],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5973402440119852, 0.01804242846159409, 0.38461732752642075],
                                [0.315358127978823, 0.28198211603316214, 0.40265975598801484],
                                [0.2307653449471585, 0.08459278303166452, 0.684641872021177],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5011002776635116, 0.02235476085182243, 0.47654496148466596],
                                [0.15172143535132537, 0.34937884231218624, 0.49889972233648844],
                                [0.046910077030668074, 0.10481135832065724, 0.8482785646486747],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.9754446838211543, 0.0011002776635116048, 0.02345503851533401],
                                [0.9642673033952431, 0.011177380425911203, 0.024555316178845613],
                                [0.9530899229693319, 0.011177380425911203, 0.035732696604756815],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.8792047174726808, 0.0054126100537399465, 0.11538267247357922],
                                [0.8242196862627612, 0.05498503120991964, 0.12079528252731918],
                                [0.7692346550528416, 0.05498503120991964, 0.1757803137372388],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.738272480742333, 0.011727519257667018, 0.25],
                                [0.6191362403711664, 0.11913624037116649, 0.261727519257667],
                                [0.49999999999999994, 0.11913624037116649, 0.3808637596288335],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5973402440119852, 0.01804242846159409, 0.38461732752642075],
                                [0.41405279447957194, 0.18328744953241333, 0.4026597559880148],
                                [0.23076534494715845, 0.18328744953241333, 0.5859472055204282],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5011002776635116, 0.02235476085182243, 0.47654496148466596],
                                [0.27400517734708985, 0.22709510031642177, 0.4988997223364884],
                                [0.046910077030668074, 0.22709510031642177, 0.7259948226529102],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.9754446838211543, 0.0011002776635116048, 0.02345503851533401],
                                [0.9702859797219723, 0.0051587040991820324, 0.024555316178845613],
                                [0.953089922969332, 0.01719605675264037, 0.029714020278027647],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.8792047174726808, 0.0054126100537399465, 0.11538267247357922],
                                [0.853827438084506, 0.025377279388174766, 0.12079528252731916],
                                [0.7692346550528416, 0.08459278303166451, 0.14617256191549394],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.738272480742333, 0.011727519257667018, 0.25],
                                [0.6832874495324133, 0.054985031209919655, 0.261727519257667],
                                [0.49999999999999994, 0.18328744953241333, 0.3167125504675867],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5973402440119852, 0.01804242846159409, 0.38461732752642075],
                                [0.5127474609803206, 0.08459278303166454, 0.40265975598801484],
                                [0.2307653449471585, 0.28198211603316214, 0.48725253901967935],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5011002776635116, 0.02235476085182243, 0.47654496148466596],
                                [0.3962889193428544, 0.10481135832065727, 0.4988997223364884],
                                [0.04691007703066802, 0.34937884231218624, 0.6037110806571457],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.9754446838211543, 0.0011002776635116048, 0.02345503851533401],
                                [0.9743960202675932, 0.0010486635535611516, 0.024555316178845616],
                                [0.9530899229693319, 0.021306097298261252, 0.025603979732406766],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.8792047174726808, 0.0054126100537399465, 0.11538267247357922],
                                [0.8740460133734987, 0.005158704099182034, 0.12079528252731916],
                                [0.7692346550528416, 0.10481135832065724, 0.1259539866265012],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.738272480742333, 0.011727519257667018, 0.25],
                                [0.7270951003164218, 0.01117738042591121, 0.261727519257667],
                                [0.5, 0.22709510031642177, 0.27290489968357823],
                                [0.5, 0.25, 0.25],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5973402440119852, 0.01804242846159409, 0.38461732752642075],
                                [0.5801441872593449, 0.017196056752640385, 0.4026597559880148],
                                [0.2307653449471585, 0.3493788423121863, 0.4198558127406552],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5011002776635116, 0.02235476085182243, 0.47654496148466596],
                                [0.47979418036525034, 0.021306097298261266, 0.4988997223364884],
                                [0.046910077030668074, 0.43288410333458227, 0.5202058196347497],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.9547826663872394, 0.03439211350528074, 0.010825220107479883],
                                [0.9531693296934592, 0.0016133366937801975, 0.045217333612760625],
                                [0.9530899229693319, 7.94067241271919e-05, 0.046830670306540825],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.0016927434179073895, 0.045217333612760625],
                                [0.77756178950809, 0.16918556606332902, 0.05325264442858105],
                                [0.769625281571582, 0.007936507936507938, 0.2224382104919101],
                                [0.7692346550528416, 0.00039062651874043075, 0.230374718428418],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528416, 0.008327134455248368, 0.22243821049191007],
                                [0.5180424284615941, 0.36657489906482665, 0.11538267247357925],
                                [0.5008463717089537, 0.01719605675264037, 0.48195757153840596],
                                [0.5, 0.0008463717089536947, 0.4991536282910463],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.018042428461594068, 0.4819575715384059],
                                [0.25852306741509834, 0.5639642320663243, 0.17751270051857737],
                                [0.23206746184632543, 0.026455605568772803, 0.7414769325849018],
                                [0.23076534494715847, 0.0013021168991669586, 0.7679325381536746],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715847, 0.027757722467939765, 0.7414769325849018],
                                [0.08130219053594889, 0.6987576846243725, 0.21994012483967862],
                                [0.04852341372444824, 0.03277877681150054, 0.9186978094640512],
                                [0.04691007703066804, 0.0016133366937801975, 0.9514765862755518],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.04691007703066804, 0.03439211350528074, 0.9186978094640512],
                                [0.9547826663872394, 0.03439211350528074, 0.010825220107479883],
                                [0.9534805494880725, 0.0013021168991669589, 0.045217333612760625],
                                [0.9530899229693319, 0.00039062651874043075, 0.04651945051192759],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.0016927434179073895, 0.045217333612760625],
                                [0.77756178950809, 0.16918556606332902, 0.05325264442858105],
                                [0.7711562691078283, 0.006405520400261611, 0.2224382104919101],
                                [0.7692346550528415, 0.001921614054986758, 0.2288437308921717],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528416, 0.008327134455248368, 0.22243821049191007],
                                [0.5180424284615941, 0.36657489906482665, 0.11538267247357925],
                                [0.5041635672276242, 0.013878861233969884, 0.48195757153840596],
                                [0.49999999999999994, 0.004163567227624184, 0.4958364327723758],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.018042428461594068, 0.4819575715384059],
                                [0.25852306741509834, 0.5639642320663243, 0.17751270051857737],
                                [0.23717086534742007, 0.021352202067678155, 0.7414769325849018],
                                [0.23076534494715856, 0.00640552040026161, 0.7628291346525798],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715847, 0.027757722467939765, 0.7414769325849018],
                                [0.08130219053594889, 0.6987576846243725, 0.21994012483967862],
                                [0.054846584967175975, 0.026455605568772807, 0.9186978094640512],
                                [0.046910077030668046, 0.007936507936507938, 0.945153415032824],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.04691007703066804, 0.03439211350528074, 0.9186978094640512],
                                [0.9547826663872394, 0.03439211350528074, 0.010825220107479883],
                                [0.9539362946782857, 0.0008463717089536947, 0.04521733361276063],
                                [0.9530899229693319, 0.0008463717089536947, 0.046063705321714325],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.0016927434179073895, 0.045217333612760625],
                                [0.77756178950809, 0.16918556606332902, 0.05325264442858105],
                                [0.7733982222804657, 0.004163567227624184, 0.22243821049191007],
                                [0.7692346550528415, 0.004163567227624184, 0.22660177771953427],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528416, 0.008327134455248368, 0.22243821049191007],
                                [0.5180424284615941, 0.36657489906482665, 0.11538267247357925],
                                [0.509021214230797, 0.009021214230797034, 0.4819575715384059],
                                [0.5, 0.009021214230797034, 0.49097878576920295],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.018042428461594068, 0.4819575715384059],
                                [0.25852306741509834, 0.5639642320663243, 0.17751270051857737],
                                [0.24464420618112834, 0.013878861233969883, 0.7414769325849018],
                                [0.23076534494715847, 0.013878861233969883, 0.7553557938188716],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715847, 0.027757722467939765, 0.7414769325849018],
                                [0.08130219053594889, 0.6987576846243725, 0.21994012483967862],
                                [0.06410613378330841, 0.01719605675264037, 0.9186978094640512],
                                [0.04691007703066806, 0.01719605675264037, 0.9358938662166916],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.04691007703066804, 0.03439211350528074, 0.9186978094640512],
                                [0.9547826663872394, 0.03439211350528074, 0.010825220107479883],
                                [0.954392039868499, 0.0003906265187404308, 0.04521733361276063],
                                [0.953089922969332, 0.0013021168991669589, 0.045607960131501056],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.0016927434179073895, 0.045217333612760625],
                                [0.77756178950809, 0.16918556606332902, 0.05325264442858105],
                                [0.7756401754531032, 0.0019216140549867585, 0.2224382104919101],
                                [0.7692346550528415, 0.00640552040026161, 0.22435982454689685],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528416, 0.008327134455248368, 0.22243821049191007],
                                [0.5180424284615941, 0.36657489906482665, 0.11538267247357925],
                                [0.5138788612339699, 0.004163567227624185, 0.48195757153840596],
                                [0.5, 0.013878861233969883, 0.48612113876603014],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.018042428461594068, 0.4819575715384059],
                                [0.25852306741509834, 0.5639642320663243, 0.17751270051857737],
                                [0.25211754701483663, 0.006405520400261612, 0.7414769325849018],
                                [0.23076534494715853, 0.021352202067678152, 0.7478824529851633],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715847, 0.027757722467939765, 0.7414769325849018],
                                [0.08130219053594889, 0.6987576846243725, 0.21994012483967862],
                                [0.07336568259944085, 0.00793650793650794, 0.9186978094640512],
                                [0.04691007703066807, 0.026455605568772807, 0.9266343174005591],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.04691007703066804, 0.03439211350528074, 0.9186978094640512],
                                [0.9547826663872394, 0.03439211350528074, 0.010825220107479883],
                                [0.9547032596631122, 7.940672412719205e-05, 0.04521733361276063],
                                [0.953089922969332, 0.0016133366937801975, 0.04529674033688782],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.0016927434179073895, 0.045217333612760625],
                                [0.77756178950809, 0.16918556606332902, 0.05325264442858105],
                                [0.7771711629893495, 0.00039062651874043145, 0.22243821049191007],
                                [0.7692346550528416, 0.007936507936507938, 0.2228288370106505],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528416, 0.008327134455248368, 0.22243821049191007],
                                [0.5180424284615941, 0.36657489906482665, 0.11538267247357925],
                                [0.5171960567526404, 0.0008463717089536964, 0.48195757153840596],
                                [0.5, 0.01719605675264037, 0.48280394324735965],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.018042428461594068, 0.4819575715384059],
                                [0.25852306741509834, 0.5639642320663243, 0.17751270051857737],
                                [0.25722095051593125, 0.0013021168991669612, 0.7414769325849018],
                                [0.2307653449471585, 0.026455605568772803, 0.7427790494840687],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715847, 0.027757722467939765, 0.7414769325849018],
                                [0.08130219053594889, 0.6987576846243725, 0.21994012483967862],
                                [0.07968885384216857, 0.0016133366937802005, 0.9186978094640512],
                                [0.046910077030668074, 0.03277877681150054, 0.9203111461578314],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.04691007703066804, 0.03439211350528074, 0.9186978094640512],
                                [0.9614170574245804, 0.02775772246793977, 0.010825220107479883],
                                [0.9534805494880725, 0.007936507936507938, 0.03858294257541965],
                                [0.9530899229693319, 0.00039062651874043075, 0.04651945051192759],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.008327134455248368, 0.03858294257541965],
                                [0.8101984346205127, 0.13654892095090626, 0.05325264442858105],
                                [0.7711562691078283, 0.039042165512684385, 0.1898015653794873],
                                [0.7692346550528415, 0.001921614054986758, 0.2288437308921717],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.040963779567671145, 0.1898015653794873],
                                [0.5887563502592887, 0.29586097726713206, 0.11538267247357925],
                                [0.5041635672276242, 0.08459278303166451, 0.4112436497407113],
                                [0.49999999999999994, 0.004163567227624184, 0.4958364327723758],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.0887563502592887, 0.4112436497407113],
                                [0.3673142658980647, 0.4551730335833578, 0.17751270051857748],
                                [0.23717086534742007, 0.13014340055064463, 0.6326857341019353],
                                [0.23076534494715856, 0.00640552040026161, 0.7628291346525798],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715847, 0.13654892095090623, 0.6326857341019353],
                                [0.2160956430939971, 0.5639642320663243, 0.21994012483967862],
                                [0.05484658496717601, 0.16124905812682108, 0.7839043569060029],
                                [0.046910077030668046, 0.007936507936507938, 0.945153415032824],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.16918556606332902, 0.7839043569060029],
                                [0.9614170574245804, 0.02775772246793977, 0.010825220107479883],
                                [0.9550115370243187, 0.006405520400261611, 0.038582942575419645],
                                [0.9530899229693319, 0.001921614054986758, 0.04498846297568126],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.008327134455248368, 0.03858294257541965],
                                [0.8101984346205127, 0.13654892095090626, 0.05325264442858105],
                                [0.7786876757751146, 0.031510758845398154, 0.18980156537948728],
                                [0.7692346550528416, 0.009453020722272993, 0.22131232422488545],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.040963779567671145, 0.1898015653794873],
                                [0.5887563502592887, 0.29586097726713206, 0.11538267247357925],
                                [0.5204818897838356, 0.06827446047545313, 0.41124364974071126],
                                [0.5, 0.020481889783835572, 0.4795181102161644],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.0887563502592887, 0.4112436497407113],
                                [0.3673142658980647, 0.4551730335833578, 0.17751270051857748],
                                [0.2622761037925566, 0.10503816210550809, 0.6326857341019353],
                                [0.23076534494715847, 0.03151075884539815, 0.7377238962074434],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715847, 0.13654892095090623, 0.6326857341019353],
                                [0.2160956430939971, 0.5639642320663243, 0.21994012483967862],
                                [0.08595224254335246, 0.13014340055064463, 0.7839043569060029],
                                [0.046910077030668046, 0.039042165512684385, 0.9140477574566476],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.16918556606332902, 0.7839043569060029],
                                [0.9614170574245804, 0.02775772246793977, 0.010825220107479883],
                                [0.9572534901969562, 0.004163567227624184, 0.03858294257541965],
                                [0.9530899229693319, 0.004163567227624184, 0.042746509803043835],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.008327134455248368, 0.03858294257541965],
                                [0.8101984346205127, 0.13654892095090626, 0.05325264442858105],
                                [0.7897165448366771, 0.020481889783835572, 0.18980156537948728],
                                [0.7692346550528416, 0.020481889783835572, 0.21028345516332286],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.040963779567671145, 0.1898015653794873],
                                [0.5887563502592887, 0.29586097726713206, 0.11538267247357925],
                                [0.5443781751296444, 0.04437817512964435, 0.41124364974071126],
                                [0.5, 0.04437817512964435, 0.45562182487035563],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.0887563502592887, 0.4112436497407113],
                                [0.3673142658980647, 0.4551730335833578, 0.17751270051857748],
                                [0.2990398054226117, 0.06827446047545312, 0.6326857341019352],
                                [0.23076534494715856, 0.06827446047545312, 0.7009601945773883],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715847, 0.13654892095090623, 0.6326857341019353],
                                [0.2160956430939971, 0.5639642320663243, 0.21994012483967862],
                                [0.13150286006233258, 0.08459278303166451, 0.7839043569060029],
                                [0.046910077030668074, 0.08459278303166451, 0.8684971399376674],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.16918556606332902, 0.7839043569060029],
                                [0.9614170574245804, 0.02775772246793977, 0.010825220107479883],
                                [0.9594954433695936, 0.001921614054986759, 0.03858294257541965],
                                [0.9530899229693319, 0.006405520400261609, 0.04050455663040641],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.008327134455248368, 0.03858294257541965],
                                [0.8101984346205127, 0.13654892095090626, 0.05325264442858105],
                                [0.8007454138982397, 0.009453020722272998, 0.1898015653794873],
                                [0.7692346550528416, 0.03151075884539815, 0.1992545861017603],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.040963779567671145, 0.1898015653794873],
                                [0.5887563502592887, 0.29586097726713206, 0.11538267247357925],
                                [0.5682744604754532, 0.020481889783835583, 0.4112436497407113],
                                [0.49999999999999994, 0.06827446047545312, 0.4317255395245469],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.0887563502592887, 0.4112436497407113],
                                [0.3673142658980647, 0.4551730335833578, 0.17751270051857748],
                                [0.33580350705266665, 0.03151075884539817, 0.6326857341019352],
                                [0.2307653449471585, 0.10503816210550808, 0.6641964929473334],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715847, 0.13654892095090623, 0.6326857341019353],
                                [0.2160956430939971, 0.5639642320663243, 0.21994012483967862],
                                [0.17705347758131257, 0.039042165512684406, 0.783904356906003],
                                [0.04691007703066802, 0.1301434005506446, 0.8229465224186874],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.16918556606332902, 0.7839043569060029],
                                [0.9614170574245804, 0.02775772246793977, 0.010825220107479883],
                                [0.96102643090584, 0.0003906265187404313, 0.03858294257541965],
                                [0.953089922969332, 0.007936507936507938, 0.03897356909416008],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.008327134455248368, 0.03858294257541965],
                                [0.8101984346205127, 0.13654892095090626, 0.05325264442858105],
                                [0.8082768205655259, 0.001921614054986761, 0.1898015653794873],
                                [0.7692346550528416, 0.039042165512684385, 0.19172317943447406],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.040963779567671145, 0.1898015653794873],
                                [0.5887563502592887, 0.29586097726713206, 0.11538267247357925],
                                [0.5845927830316645, 0.00416356722762419, 0.4112436497407113],
                                [0.5, 0.08459278303166451, 0.4154072169683355],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.0887563502592887, 0.4112436497407113],
                                [0.3673142658980647, 0.4551730335833578, 0.17751270051857748],
                                [0.3609087454978032, 0.0064055204002616195, 0.6326857341019352],
                                [0.23076534494715853, 0.13014340055064463, 0.6390912545021968],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715847, 0.13654892095090623, 0.6326857341019353],
                                [0.2160956430939971, 0.5639642320663243, 0.21994012483967862],
                                [0.20815913515748916, 0.007936507936507948, 0.7839043569060029],
                                [0.0469100770306681, 0.16124905812682108, 0.7918408648425108],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.16918556606332902, 0.7839043569060029],
                                [0.971132351430926, 0.018042428461594068, 0.010825220107479883],
                                [0.9539362946782857, 0.01719605675264037, 0.028867648569073954],
                                [0.9530899229693319, 0.0008463717089536947, 0.046063705321714325],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.8579910053121302, 0.0887563502592887, 0.053252644428581034],
                                [0.7733982222804657, 0.08459278303166451, 0.14200899468786973],
                                [0.7692346550528415, 0.004163567227624184, 0.22660177771953427],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.0887563502592887, 0.14200899468786976],
                                [0.6923086637632103, 0.19230866376321037, 0.11538267247357925],
                                [0.509021214230797, 0.18328744953241333, 0.3076913362367896],
                                [0.5, 0.009021214230797034, 0.49097878576920295],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5266263222142905, 0.295860977267132, 0.17751270051857748],
                                [0.24464420618112837, 0.28198211603316214, 0.4733736777857095],
                                [0.23076534494715847, 0.013878861233969883, 0.7553557938188716],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.4134849760954947, 0.36657489906482665, 0.21994012483967862],
                                [0.06410613378330837, 0.34937884231218624, 0.5865150239045054],
                                [0.04691007703066806, 0.01719605675264037, 0.9358938662166916],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.971132351430926, 0.018042428461594068, 0.010825220107479883],
                                [0.9572534901969562, 0.013878861233969884, 0.02886764856907395],
                                [0.9530899229693319, 0.004163567227624184, 0.042746509803043835],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.8579910053121302, 0.0887563502592887, 0.053252644428581034],
                                [0.7897165448366771, 0.06827446047545313, 0.14200899468786973],
                                [0.7692346550528416, 0.020481889783835572, 0.21028345516332286],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.0887563502592887, 0.14200899468786976],
                                [0.6923086637632103, 0.19230866376321037, 0.11538267247357925],
                                [0.5443781751296444, 0.14793048863356603, 0.30769133623678957],
                                [0.5, 0.04437817512964435, 0.45562182487035563],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5266263222142905, 0.295860977267132, 0.17751270051857748],
                                [0.2990398054226117, 0.2275865167916789, 0.47337367778570943],
                                [0.23076534494715856, 0.06827446047545312, 0.7009601945773883],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.4134849760954947, 0.36657489906482665, 0.21994012483967862],
                                [0.13150286006233258, 0.28198211603316214, 0.5865150239045053],
                                [0.046910077030668074, 0.08459278303166451, 0.8684971399376674],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.971132351430926, 0.018042428461594068, 0.010825220107479883],
                                [0.962111137200129, 0.009021214230797034, 0.02886764856907395],
                                [0.9530899229693319, 0.009021214230797034, 0.037888862799870984],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.8579910053121302, 0.0887563502592887, 0.053252644428581034],
                                [0.8136128301824859, 0.04437817512964435, 0.14200899468786976],
                                [0.7692346550528415, 0.04437817512964435, 0.1863871698175141],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.0887563502592887, 0.14200899468786976],
                                [0.6923086637632103, 0.19230866376321037, 0.11538267247357925],
                                [0.5961543318816052, 0.09615433188160519, 0.3076913362367897],
                                [0.5, 0.09615433188160519, 0.40384566811839484],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5266263222142905, 0.295860977267132, 0.17751270051857748],
                                [0.3786958335807244, 0.147930488633566, 0.47337367778570955],
                                [0.23076534494715845, 0.147930488633566, 0.6213041664192755],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.4134849760954947, 0.36657489906482665, 0.21994012483967862],
                                [0.2301975265630813, 0.18328744953241333, 0.5865150239045054],
                                [0.04691007703066802, 0.18328744953241333, 0.7698024734369187],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.971132351430926, 0.018042428461594068, 0.010825220107479883],
                                [0.9669687842033018, 0.004163567227624186, 0.028867648569073947],
                                [0.953089922969332, 0.013878861233969883, 0.033031215796698134],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.8579910053121302, 0.0887563502592887, 0.053252644428581034],
                                [0.8375091155282947, 0.020481889783835583, 0.14200899468786973],
                                [0.7692346550528415, 0.06827446047545312, 0.16249088447170534],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.0887563502592887, 0.14200899468786976],
                                [0.6923086637632103, 0.19230866376321037, 0.11538267247357925],
                                [0.647930488633566, 0.04437817512964437, 0.3076913362367896],
                                [0.49999999999999994, 0.147930488633566, 0.352069511366434],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5266263222142905, 0.295860977267132, 0.17751270051857748],
                                [0.45835186173883735, 0.06827446047545316, 0.4733736777857095],
                                [0.23076534494715847, 0.22758651679167888, 0.5416481382611626],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.4134849760954947, 0.36657489906482665, 0.21994012483967862],
                                [0.32889219306383016, 0.08459278303166455, 0.5865150239045053],
                                [0.04691007703066813, 0.2819821160331621, 0.6711078069361698],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.971132351430926, 0.018042428461594068, 0.010825220107479883],
                                [0.9702859797219723, 0.000846371708953696, 0.02886764856907395],
                                [0.953089922969332, 0.01719605675264037, 0.029714020278027647],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.9530899229693319, 0.018042428461594068, 0.02886764856907395],
                                [0.8579910053121302, 0.0887563502592887, 0.053252644428581034],
                                [0.853827438084506, 0.004163567227624191, 0.14200899468786973],
                                [0.7692346550528416, 0.08459278303166451, 0.14617256191549394],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.0887563502592887, 0.14200899468786976],
                                [0.6923086637632103, 0.19230866376321037, 0.11538267247357925],
                                [0.6832874495324133, 0.009021214230797048, 0.3076913362367896],
                                [0.49999999999999994, 0.18328744953241333, 0.3167125504675867],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.49999999999999994, 0.19230866376321037, 0.3076913362367896],
                                [0.5266263222142905, 0.295860977267132, 0.17751270051857748],
                                [0.5127474609803208, 0.013878861233969903, 0.47337367778570943],
                                [0.2307653449471585, 0.28198211603316214, 0.48725253901967935],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.2307653449471585, 0.295860977267132, 0.4733736777857095],
                                [0.4134849760954947, 0.36657489906482665, 0.21994012483967862],
                                [0.3962889193428543, 0.0171960567526404, 0.5865150239045053],
                                [0.04691007703066802, 0.34937884231218624, 0.6037110806571457],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.36657489906482665, 0.5865150239045053],
                                [0.9808476454372718, 0.008327134455248372, 0.010825220107479881],
                                [0.954392039868499, 0.026455605568772807, 0.019152354562728256],
                                [0.953089922969332, 0.0013021168991669589, 0.045607960131501056],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.027757722467939765, 0.019152354562728253],
                                [0.9057835760037478, 0.040963779567671166, 0.053252644428581034],
                                [0.7756401754531032, 0.13014340055064463, 0.09421642399625221],
                                [0.7692346550528415, 0.00640552040026161, 0.22435982454689685],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528416, 0.13654892095090623, 0.09421642399625221],
                                [0.795860977267132, 0.08875635025928874, 0.11538267247357925],
                                [0.5138788612339699, 0.28198211603316214, 0.204139022732868],
                                [0.5, 0.013878861233969883, 0.48612113876603014],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.295860977267132, 0.204139022732868],
                                [0.6859383785305162, 0.13654892095090632, 0.17751270051857743],
                                [0.2521175470148366, 0.43382083151567963, 0.3140616214694838],
                                [0.23076534494715853, 0.021352202067678152, 0.7478824529851633],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715845, 0.45517303358335776, 0.31406162146948374],
                                [0.6108743090969923, 0.1691855660633291, 0.2199401248396786],
                                [0.07336568259944087, 0.5375086264975515, 0.38912569090300764],
                                [0.04691007703066807, 0.026455605568772807, 0.9266343174005591],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.5639642320663242, 0.38912569090300775],
                                [0.9808476454372718, 0.008327134455248372, 0.010825220107479881],
                                [0.9594954433695936, 0.021352202067678155, 0.019152354562728256],
                                [0.9530899229693319, 0.006405520400261609, 0.04050455663040641],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.027757722467939765, 0.019152354562728253],
                                [0.9057835760037478, 0.040963779567671166, 0.053252644428581034],
                                [0.8007454138982397, 0.1050381621055081, 0.0942164239962522],
                                [0.7692346550528416, 0.03151075884539815, 0.1992545861017603],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528416, 0.13654892095090623, 0.09421642399625221],
                                [0.795860977267132, 0.08875635025928874, 0.11538267247357925],
                                [0.568274460475453, 0.2275865167916789, 0.204139022732868],
                                [0.49999999999999994, 0.06827446047545312, 0.4317255395245469],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.295860977267132, 0.204139022732868],
                                [0.6859383785305162, 0.13654892095090632, 0.17751270051857743],
                                [0.33580350705266654, 0.35013487147784966, 0.31406162146948374],
                                [0.2307653449471585, 0.10503816210550808, 0.6641964929473334],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715845, 0.45517303358335776, 0.31406162146948374],
                                [0.6108743090969923, 0.1691855660633291, 0.2199401248396786],
                                [0.17705347758131262, 0.43382083151567963, 0.38912569090300775],
                                [0.04691007703066802, 0.1301434005506446, 0.8229465224186874],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.5639642320663242, 0.38912569090300775],
                                [0.9808476454372718, 0.008327134455248372, 0.010825220107479881],
                                [0.9669687842033019, 0.013878861233969883, 0.01915235456272825],
                                [0.953089922969332, 0.013878861233969883, 0.033031215796698134],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.027757722467939765, 0.019152354562728253],
                                [0.9057835760037478, 0.040963779567671166, 0.053252644428581034],
                                [0.8375091155282947, 0.06827446047545312, 0.0942164239962522],
                                [0.7692346550528415, 0.06827446047545312, 0.16249088447170534],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528416, 0.13654892095090623, 0.09421642399625221],
                                [0.795860977267132, 0.08875635025928874, 0.11538267247357925],
                                [0.647930488633566, 0.147930488633566, 0.204139022732868],
                                [0.49999999999999994, 0.147930488633566, 0.352069511366434],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.295860977267132, 0.204139022732868],
                                [0.6859383785305162, 0.13654892095090632, 0.17751270051857743],
                                [0.45835186173883735, 0.22758651679167888, 0.3140616214694838],
                                [0.23076534494715847, 0.22758651679167888, 0.5416481382611626],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715845, 0.45517303358335776, 0.31406162146948374],
                                [0.6108743090969923, 0.1691855660633291, 0.2199401248396786],
                                [0.3288921930638303, 0.2819821160331621, 0.3891256909030077],
                                [0.04691007703066813, 0.2819821160331621, 0.6711078069361698],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.5639642320663242, 0.38912569090300775],
                                [0.9808476454372718, 0.008327134455248372, 0.010825220107479881],
                                [0.9744421250370101, 0.006405520400261611, 0.019152354562728256],
                                [0.9530899229693319, 0.021352202067678152, 0.025557874962989866],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.027757722467939765, 0.019152354562728253],
                                [0.9057835760037478, 0.040963779567671166, 0.053252644428581034],
                                [0.8742728171583497, 0.031510758845398154, 0.09421642399625223],
                                [0.7692346550528415, 0.10503816210550809, 0.12572718284165035],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528416, 0.13654892095090623, 0.09421642399625221],
                                [0.795860977267132, 0.08875635025928874, 0.11538267247357925],
                                [0.7275865167916789, 0.06827446047545313, 0.20413902273286802],
                                [0.5, 0.22758651679167888, 0.27241348320832115],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.295860977267132, 0.204139022732868],
                                [0.6859383785305162, 0.13654892095090632, 0.17751270051857743],
                                [0.5809002164250081, 0.10503816210550809, 0.3140616214694838],
                                [0.23076534494715845, 0.35013487147784966, 0.41909978357499184],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715845, 0.45517303358335776, 0.31406162146948374],
                                [0.6108743090969923, 0.1691855660633291, 0.2199401248396786],
                                [0.4807309085463476, 0.13014340055064463, 0.38912569090300775],
                                [0.04691007703066802, 0.4338208315156796, 0.5192690914536524],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.5639642320663242, 0.38912569090300775],
                                [0.9808476454372718, 0.008327134455248372, 0.010825220107479881],
                                [0.9795455285381048, 0.001302116899166962, 0.019152354562728253],
                                [0.953089922969332, 0.026455605568772803, 0.020454471461895215],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.027757722467939765, 0.019152354562728253],
                                [0.9057835760037478, 0.040963779567671166, 0.053252644428581034],
                                [0.8993780556034862, 0.006405520400261627, 0.0942164239962522],
                                [0.7692346550528415, 0.1301434005506446, 0.10062194439651384],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528416, 0.13654892095090623, 0.09421642399625221],
                                [0.795860977267132, 0.08875635025928874, 0.11538267247357925],
                                [0.7819821160331621, 0.013878861233969919, 0.204139022732868],
                                [0.5, 0.2819821160331621, 0.2180178839668379],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.295860977267132, 0.204139022732868],
                                [0.6859383785305162, 0.13654892095090632, 0.17751270051857743],
                                [0.664586176462838, 0.02135220206767821, 0.3140616214694838],
                                [0.2307653449471585, 0.4338208315156795, 0.335413823537162],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.23076534494715845, 0.45517303358335776, 0.31406162146948374],
                                [0.6108743090969923, 0.1691855660633291, 0.2199401248396786],
                                [0.5844187035282193, 0.026455605568772876, 0.38912569090300775],
                                [0.046910077030668074, 0.5375086264975514, 0.41558129647178055],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.5639642320663242, 0.38912569090300775],
                                [0.9874820364746127, 0.001692743417907392, 0.010825220107479881],
                                [0.9547032596631122, 0.03277877681150055, 0.012517963525387275],
                                [0.953089922969332, 0.0016133366937801975, 0.04529674033688782],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.03439211350528074, 0.012517963525387275],
                                [0.9384202211161706, 0.008327134455248382, 0.05325264442858104],
                                [0.7771711629893495, 0.1612490581268211, 0.0615797788838294],
                                [0.7692346550528416, 0.007936507936507938, 0.2228288370106505],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.16918556606332902, 0.06157977888382943],
                                [0.8665748990648267, 0.018042428461594096, 0.11538267247357925],
                                [0.5171960567526404, 0.3493788423121863, 0.13342510093517335],
                                [0.5, 0.01719605675264037, 0.48280394324735965],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.36657489906482665, 0.13342510093517335],
                                [0.7947295770134827, 0.027757722467939807, 0.17751270051857745],
                                [0.2572209505159313, 0.5375086264975515, 0.2052704229865172],
                                [0.2307653449471585, 0.026455605568772803, 0.7427790494840687],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.7456677616550406, 0.0343921135052808, 0.2199401248396786],
                                [0.07968885384216862, 0.6659789078128721, 0.2543322383449593],
                                [0.046910077030668074, 0.03277877681150054, 0.9203111461578314],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.6987576846243725, 0.25433223834495944],
                                [0.9874820364746127, 0.001692743417907392, 0.010825220107479881],
                                [0.96102643090584, 0.026455605568772807, 0.012517963525387275],
                                [0.953089922969332, 0.007936507936507938, 0.03897356909416008],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.03439211350528074, 0.012517963525387275],
                                [0.9384202211161706, 0.008327134455248382, 0.05325264442858104],
                                [0.8082768205655259, 0.13014340055064463, 0.06157977888382943],
                                [0.7692346550528416, 0.039042165512684385, 0.19172317943447406],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.16918556606332902, 0.06157977888382943],
                                [0.8665748990648267, 0.018042428461594096, 0.11538267247357925],
                                [0.5845927830316645, 0.28198211603316214, 0.13342510093517335],
                                [0.5, 0.08459278303166451, 0.4154072169683355],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.36657489906482665, 0.13342510093517335],
                                [0.7947295770134827, 0.027757722467939807, 0.17751270051857745],
                                [0.36090874549780316, 0.43382083151567963, 0.2052704229865172],
                                [0.23076534494715853, 0.13014340055064463, 0.6390912545021968],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.7456677616550406, 0.0343921135052808, 0.2199401248396786],
                                [0.20815913515748918, 0.5375086264975515, 0.2543322383449593],
                                [0.0469100770306681, 0.16124905812682108, 0.7918408648425108],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.6987576846243725, 0.25433223834495944],
                                [0.9874820364746127, 0.001692743417907392, 0.010825220107479881],
                                [0.9702859797219724, 0.01719605675264037, 0.012517963525387275],
                                [0.953089922969332, 0.01719605675264037, 0.029714020278027647],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.03439211350528074, 0.012517963525387275],
                                [0.9384202211161706, 0.008327134455248382, 0.05325264442858104],
                                [0.853827438084506, 0.08459278303166451, 0.06157977888382943],
                                [0.7692346550528416, 0.08459278303166451, 0.14617256191549394],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.16918556606332902, 0.06157977888382943],
                                [0.8665748990648267, 0.018042428461594096, 0.11538267247357925],
                                [0.6832874495324133, 0.18328744953241333, 0.13342510093517335],
                                [0.49999999999999994, 0.18328744953241333, 0.3167125504675867],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.36657489906482665, 0.13342510093517335],
                                [0.7947295770134827, 0.027757722467939807, 0.17751270051857745],
                                [0.5127474609803206, 0.28198211603316214, 0.2052704229865172],
                                [0.2307653449471585, 0.28198211603316214, 0.48725253901967935],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.7456677616550406, 0.0343921135052808, 0.2199401248396786],
                                [0.39628891934285443, 0.34937884231218624, 0.2543322383449594],
                                [0.04691007703066802, 0.34937884231218624, 0.6037110806571457],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.6987576846243725, 0.25433223834495944],
                                [0.9874820364746127, 0.001692743417907392, 0.010825220107479881],
                                [0.9795455285381048, 0.007936507936507938, 0.012517963525387274],
                                [0.953089922969332, 0.026455605568772807, 0.02045447146189521],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.03439211350528074, 0.012517963525387275],
                                [0.9384202211161706, 0.008327134455248382, 0.05325264442858104],
                                [0.8993780556034863, 0.039042165512684385, 0.061579778883829414],
                                [0.7692346550528415, 0.13014340055064463, 0.10062194439651381],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.16918556606332902, 0.06157977888382943],
                                [0.8665748990648267, 0.018042428461594096, 0.11538267247357925],
                                [0.7819821160331621, 0.08459278303166451, 0.13342510093517335],
                                [0.5, 0.28198211603316214, 0.21801788396683786],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.36657489906482665, 0.13342510093517335],
                                [0.7947295770134827, 0.027757722467939807, 0.17751270051857745],
                                [0.6645861764628381, 0.13014340055064463, 0.20527042298651724],
                                [0.2307653449471585, 0.43382083151567963, 0.33541382353716187],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.7456677616550406, 0.0343921135052808, 0.2199401248396786],
                                [0.5844187035282195, 0.16124905812682108, 0.25433223834495944],
                                [0.046910077030668074, 0.5375086264975515, 0.41558129647178044],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.6987576846243725, 0.25433223834495944],
                                [0.9874820364746127, 0.001692743417907392, 0.010825220107479881],
                                [0.9858686997808326, 0.0016133366937802012, 0.012517963525387274],
                                [0.953089922969332, 0.03277877681150054, 0.014131300219167475],
                                [0.9530899229693319, 0.036084856923188136, 0.010825220107479883],
                                [0.953089922969332, 0.03439211350528074, 0.012517963525387275],
                                [0.9384202211161706, 0.008327134455248382, 0.05325264442858104],
                                [0.9304837131796627, 0.007936507936507955, 0.06157977888382942],
                                [0.7692346550528415, 0.16124905812682108, 0.06951628682033736],
                                [0.7692346550528416, 0.1775127005185774, 0.05325264442858105],
                                [0.7692346550528415, 0.16918556606332902, 0.06157977888382943],
                                [0.8665748990648267, 0.018042428461594096, 0.11538267247357925],
                                [0.8493788423121862, 0.01719605675264041, 0.13342510093517335],
                                [0.49999999999999994, 0.34937884231218624, 0.15062115768781376],
                                [0.5, 0.38461732752642075, 0.11538267247357925],
                                [0.5, 0.36657489906482665, 0.13342510093517335],
                                [0.7947295770134827, 0.027757722467939807, 0.17751270051857745],
                                [0.7682739714447099, 0.026455605568772862, 0.20527042298651726],
                                [0.2307653449471585, 0.5375086264975514, 0.23172602855529012],
                                [0.2307653449471585, 0.591721954534264, 0.17751270051857748],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.7456677616550406, 0.0343921135052808, 0.2199401248396786],
                                [0.7128889848435399, 0.03277877681150062, 0.25433223834495944],
                                [0.046910077030668074, 0.665978907812872, 0.28711101515646],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967862],
                                [0.046910077030668074, 0.6987576846243725, 0.25433223834495944],
                                [0.9551872500764542, 0.042612194596522504, 0.002200555327023214],
                                [0.9531883087454857, 0.0019989413309686867, 0.04481274992354572],
                                [0.9530899229693319, 9.83857761536153e-05, 0.046811691254514405],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.002097327107122302, 0.04481274992354572],
                                [0.7795520632512056, 0.2096227166413145, 0.010825220107479883],
                                [0.7697186454661836, 0.009833417785021958, 0.2204479367487944],
                                [0.7692346550528415, 0.00048399041334210393, 0.23028135453381635],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528416, 0.010317408198364061, 0.22044793674879437],
                                [0.5223547608518224, 0.45419020063284354, 0.023455038515334037],
                                [0.5010486635535611, 0.021306097298261256, 0.4776452391481776],
                                [0.5, 0.001048663553561151, 0.49895133644643885],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.022354760851822406, 0.4776452391481776],
                                [0.2651574584524393, 0.6987576846243726, 0.03608485692318808],
                                [0.23237868164093867, 0.03277877681150055, 0.7348425415475608],
                                [0.23076534494715847, 0.0016133366937801977, 0.7676213183590613],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.23076534494715845, 0.03439211350528075, 0.7348425415475608],
                                [0.08952227162719062, 0.8657682066691645, 0.04470952170364484],
                                [0.048909018361636795, 0.040613253265553824, 0.9104777283728094],
                                [0.04691007703066806, 0.0019989413309686867, 0.9510909816383633],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668115, 0.042612194596522504, 0.9104777283728094],
                                [0.9551872500764542, 0.042612194596522504, 0.002200555327023214],
                                [0.9535739133826742, 0.001613336693780198, 0.04481274992354572],
                                [0.9530899229693319, 0.0004839904133421039, 0.04642608661732591],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.002097327107122302, 0.04481274992354572],
                                [0.7795520632512056, 0.2096227166413145, 0.010825220107479883],
                                [0.7716155553146977, 0.00793650793650794, 0.2204479367487944],
                                [0.7692346550528416, 0.002380900261856123, 0.22838444468530233],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528416, 0.010317408198364061, 0.22044793674879437],
                                [0.5223547608518224, 0.45419020063284354, 0.023455038515334037],
                                [0.5051587040991821, 0.017196056752640375, 0.47764523914817764],
                                [0.5, 0.005158704099182031, 0.494841295900818],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.022354760851822406, 0.4776452391481776],
                                [0.2651574584524393, 0.6987576846243726, 0.03608485692318808],
                                [0.2387018528836664, 0.02645560556877281, 0.7348425415475608],
                                [0.23076534494715847, 0.007936507936507938, 0.7612981471163336],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.23076534494715845, 0.03439211350528075, 0.7348425415475608],
                                [0.08952227162719062, 0.8657682066691645, 0.04470952170364484],
                                [0.05674349481568996, 0.03277877681150055, 0.9104777283728095],
                                [0.046910077030668115, 0.009833417785021958, 0.9432565051843099],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668115, 0.042612194596522504, 0.9104777283728094],
                                [0.9551872500764542, 0.042612194596522504, 0.002200555327023214],
                                [0.9541385865228932, 0.001048663553561151, 0.04481274992354571],
                                [0.953089922969332, 0.001048663553561151, 0.045861413477106865],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.002097327107122302, 0.04481274992354572],
                                [0.7795520632512056, 0.2096227166413145, 0.010825220107479883],
                                [0.7743933591520236, 0.005158704099182031, 0.22044793674879437],
                                [0.7692346550528415, 0.005158704099182031, 0.2256066408479764],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528416, 0.010317408198364061, 0.22044793674879437],
                                [0.5223547608518224, 0.45419020063284354, 0.023455038515334037],
                                [0.5111773804259112, 0.011177380425911203, 0.4776452391481776],
                                [0.5, 0.011177380425911203, 0.4888226195740888],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.022354760851822406, 0.4776452391481776],
                                [0.2651574584524393, 0.6987576846243726, 0.03608485692318808],
                                [0.24796140169979883, 0.017196056752640375, 0.7348425415475608],
                                [0.23076534494715847, 0.017196056752640375, 0.7520385983002011],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.23076534494715845, 0.03439211350528075, 0.7348425415475608],
                                [0.08952227162719062, 0.8657682066691645, 0.04470952170364484],
                                [0.06821617432892937, 0.021306097298261252, 0.9104777283728094],
                                [0.046910077030668094, 0.021306097298261252, 0.9317838256710707],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668115, 0.042612194596522504, 0.9104777283728094],
                                [0.9551872500764542, 0.042612194596522504, 0.002200555327023214],
                                [0.9547032596631122, 0.0004839904133421039, 0.04481274992354572],
                                [0.953089922969332, 0.001613336693780198, 0.04529674033688782],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.002097327107122302, 0.04481274992354572],
                                [0.7795520632512056, 0.2096227166413145, 0.010825220107479883],
                                [0.7771711629893495, 0.002380900261856123, 0.2204479367487944],
                                [0.7692346550528416, 0.00793650793650794, 0.2228288370106505],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528416, 0.010317408198364061, 0.22044793674879437],
                                [0.5223547608518224, 0.45419020063284354, 0.023455038515334037],
                                [0.5171960567526404, 0.005158704099182031, 0.47764523914817764],
                                [0.5, 0.017196056752640375, 0.48280394324735965],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.022354760851822406, 0.4776452391481776],
                                [0.2651574584524393, 0.6987576846243726, 0.03608485692318808],
                                [0.25722095051593125, 0.007936507936507938, 0.7348425415475608],
                                [0.2307653449471585, 0.02645560556877281, 0.7427790494840687],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.23076534494715845, 0.03439211350528075, 0.7348425415475608],
                                [0.08952227162719062, 0.8657682066691645, 0.04470952170364484],
                                [0.07968885384216866, 0.009833417785021958, 0.9104777283728094],
                                [0.04691007703066807, 0.03277877681150055, 0.9203111461578314],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668115, 0.042612194596522504, 0.9104777283728094],
                                [0.9551872500764542, 0.042612194596522504, 0.002200555327023214],
                                [0.9550888643003007, 9.838577615361554e-05, 0.04481274992354572],
                                [0.953089922969332, 0.0019989413309686862, 0.04491113569969933],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.002097327107122302, 0.04481274992354572],
                                [0.7795520632512056, 0.2096227166413145, 0.010825220107479883],
                                [0.7790680728378635, 0.0004839904133421051, 0.22044793674879437],
                                [0.7692346550528415, 0.009833417785021958, 0.2209319271621365],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528416, 0.010317408198364061, 0.22044793674879437],
                                [0.5223547608518224, 0.45419020063284354, 0.023455038515334037],
                                [0.5213060972982613, 0.0010486635535611535, 0.4776452391481776],
                                [0.5, 0.021306097298261252, 0.4786939027017387],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.022354760851822406, 0.4776452391481776],
                                [0.2651574584524393, 0.6987576846243726, 0.03608485692318808],
                                [0.263544121758659, 0.0016133366937802018, 0.7348425415475608],
                                [0.2307653449471585, 0.03277877681150054, 0.736455878241341],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.23076534494715845, 0.03439211350528075, 0.7348425415475608],
                                [0.08952227162719062, 0.8657682066691645, 0.04470952170364484],
                                [0.08752333029622193, 0.0019989413309686914, 0.9104777283728094],
                                [0.04691007703066813, 0.04061325326555382, 0.912476669703778],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668115, 0.042612194596522504, 0.9104777283728094],
                                [0.9634073311676961, 0.03439211350528074, 0.002200555327023214],
                                [0.953573913382674, 0.009833417785021958, 0.03659266883230396],
                                [0.9530899229693319, 0.0004839904133421039, 0.04642608661732591],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.8199892138291911, 0.16918556606332902, 0.01082522010747991],
                                [0.7716155553146977, 0.04837365851449339, 0.18001078617080896],
                                [0.7692346550528416, 0.002380900261856123, 0.22838444468530233],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.6099700624198393, 0.36657489906482665, 0.023455038515334037],
                                [0.505158704099182, 0.10481135832065724, 0.39002993758016075],
                                [0.5, 0.005158704099182031, 0.494841295900818],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.10997006241983928, 0.3900299375801607],
                                [0.39995091101048763, 0.5639642320663243, 0.03608485692318808],
                                [0.23870185288366644, 0.16124905812682108, 0.6000490889895125],
                                [0.23076534494715847, 0.007936507936507938, 0.7612981471163336],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.23076534494715847, 0.16918556606332905, 0.6000490889895125],
                                [0.25653279367198256, 0.6987576846243725, 0.04470952170364495],
                                [0.05674349481568994, 0.1997892988562925, 0.7434672063280175],
                                [0.046910077030668115, 0.009833417785021958, 0.9432565051843099],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.9634073311676961, 0.03439211350528074, 0.002200555327023214],
                                [0.9554708232311881, 0.007936507936507938, 0.03659266883230396],
                                [0.953089922969332, 0.002380900261856123, 0.04452917676881189],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.8199892138291911, 0.16918556606332902, 0.01082522010747991],
                                [0.7809470483165067, 0.03904216551268439, 0.18001078617080896],
                                [0.7692346550528415, 0.011712393263665124, 0.2190529516834933],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.6099700624198393, 0.36657489906482665, 0.023455038515334037],
                                [0.5253772793881747, 0.08459278303166452, 0.39002993758016075],
                                [0.5, 0.02537727938817476, 0.47462272061182526],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.10997006241983928, 0.3900299375801607],
                                [0.39995091101048763, 0.5639642320663243, 0.03608485692318808],
                                [0.26980751045984286, 0.13014340055064463, 0.6000490889895125],
                                [0.23076534494715847, 0.03904216551268439, 0.7301924895401571],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.23076534494715847, 0.16918556606332905, 0.6000490889895125],
                                [0.25653279367198256, 0.6987576846243725, 0.04470952170364495],
                                [0.09528373554516145, 0.1612490581268211, 0.7434672063280174],
                                [0.04691007703066806, 0.04837365851449339, 0.9047162644548385],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.9634073311676961, 0.03439211350528074, 0.002200555327023214],
                                [0.958248627068514, 0.005158704099182031, 0.03659266883230396],
                                [0.9530899229693319, 0.005158704099182031, 0.04175137293148599],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.8199892138291911, 0.16918556606332902, 0.01082522010747991],
                                [0.7946119344410163, 0.02537727938817476, 0.1800107861708089],
                                [0.7692346550528415, 0.02537727938817476, 0.2053880655589837],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.6099700624198393, 0.36657489906482665, 0.023455038515334037],
                                [0.5549850312099197, 0.05498503120991964, 0.3900299375801607],
                                [0.49999999999999994, 0.05498503120991964, 0.44501496879008035],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.10997006241983928, 0.3900299375801607],
                                [0.39995091101048763, 0.5639642320663243, 0.03608485692318808],
                                [0.315358127978823, 0.08459278303166452, 0.6000490889895125],
                                [0.2307653449471585, 0.08459278303166452, 0.684641872021177],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.23076534494715847, 0.16918556606332905, 0.6000490889895125],
                                [0.25653279367198256, 0.6987576846243725, 0.04470952170364495],
                                [0.15172143535132532, 0.10481135832065724, 0.7434672063280174],
                                [0.046910077030668074, 0.10481135832065724, 0.8482785646486747],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.9634073311676961, 0.03439211350528074, 0.002200555327023214],
                                [0.96102643090584, 0.002380900261856123, 0.03659266883230396],
                                [0.953089922969332, 0.007936507936507938, 0.03897356909416008],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.8199892138291911, 0.16918556606332902, 0.01082522010747991],
                                [0.808276820565526, 0.011712393263665124, 0.18001078617080893],
                                [0.7692346550528416, 0.03904216551268439, 0.19172317943447406],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.6099700624198393, 0.36657489906482665, 0.023455038515334037],
                                [0.5845927830316644, 0.02537727938817476, 0.39002993758016075],
                                [0.5, 0.08459278303166452, 0.4154072169683355],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.10997006241983928, 0.3900299375801607],
                                [0.39995091101048763, 0.5639642320663243, 0.03608485692318808],
                                [0.3609087454978031, 0.03904216551268439, 0.6000490889895125],
                                [0.23076534494715853, 0.13014340055064463, 0.6390912545021968],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.23076534494715847, 0.16918556606332905, 0.6000490889895125],
                                [0.25653279367198256, 0.6987576846243725, 0.04470952170364495],
                                [0.20815913515748918, 0.04837365851449339, 0.7434672063280174],
                                [0.046910077030668074, 0.1612490581268211, 0.7918408648425108],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.9634073311676961, 0.03439211350528074, 0.002200555327023214],
                                [0.9629233407543539, 0.00048399041334210453, 0.03659266883230396],
                                [0.9530899229693319, 0.009833417785021958, 0.03707665924564606],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.010317408198364061, 0.03659266883230396],
                                [0.8199892138291911, 0.16918556606332902, 0.01082522010747991],
                                [0.817608313567335, 0.0023809002618561262, 0.18001078617080893],
                                [0.7692346550528415, 0.04837365851449339, 0.18239168643266507],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528416, 0.05075455877634952, 0.18001078617080893],
                                [0.6099700624198393, 0.36657489906482665, 0.023455038515334037],
                                [0.6048113583206572, 0.005158704099182038, 0.3900299375801607],
                                [0.5, 0.10481135832065724, 0.39518864167934276],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.10997006241983928, 0.3900299375801607],
                                [0.39995091101048763, 0.5639642320663243, 0.03608485692318808],
                                [0.39201440307397956, 0.007936507936507948, 0.6000490889895125],
                                [0.23076534494715853, 0.16124905812682108, 0.6079855969260204],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.23076534494715847, 0.16918556606332905, 0.6000490889895125],
                                [0.25653279367198256, 0.6987576846243725, 0.04470952170364495],
                                [0.2466993758869606, 0.00983341778502197, 0.7434672063280174],
                                [0.046910077030668046, 0.1997892988562925, 0.7533006241130394],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.2096227166413145, 0.7434672063280174],
                                [0.9754446838211543, 0.022354760851822406, 0.002200555327023207],
                                [0.9541385865228931, 0.021306097298261252, 0.024555316178845613],
                                [0.953089922969332, 0.001048663553561151, 0.045861413477106865],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.8792047174726808, 0.10997006241983928, 0.010825220107479883],
                                [0.7743933591520236, 0.10481135832065724, 0.12079528252731916],
                                [0.7692346550528415, 0.005158704099182031, 0.2256066408479764],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.738272480742333, 0.23827248074233298, 0.023455038515334037],
                                [0.5111773804259112, 0.22709510031642177, 0.261727519257667],
                                [0.5, 0.011177380425911203, 0.4888226195740888],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5973402440119852, 0.36657489906482665, 0.03608485692318819],
                                [0.24796140169979886, 0.3493788423121863, 0.40265975598801484],
                                [0.23076534494715847, 0.017196056752640375, 0.7520385983002011],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5011002776635116, 0.45419020063284354, 0.04470952170364484],
                                [0.06821617432892935, 0.43288410333458227, 0.4988997223364884],
                                [0.046910077030668094, 0.021306097298261252, 0.9317838256710707],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.9754446838211543, 0.022354760851822406, 0.002200555327023207],
                                [0.958248627068514, 0.01719605675264037, 0.024555316178845616],
                                [0.9530899229693319, 0.005158704099182031, 0.04175137293148599],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.8792047174726808, 0.10997006241983928, 0.010825220107479883],
                                [0.7946119344410163, 0.08459278303166451, 0.12079528252731916],
                                [0.7692346550528415, 0.02537727938817476, 0.2053880655589837],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.738272480742333, 0.23827248074233298, 0.023455038515334037],
                                [0.5549850312099196, 0.18328744953241333, 0.261727519257667],
                                [0.49999999999999994, 0.05498503120991964, 0.44501496879008035],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5973402440119852, 0.36657489906482665, 0.03608485692318819],
                                [0.315358127978823, 0.28198211603316214, 0.40265975598801484],
                                [0.2307653449471585, 0.08459278303166452, 0.684641872021177],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5011002776635116, 0.45419020063284354, 0.04470952170364484],
                                [0.15172143535132537, 0.34937884231218624, 0.49889972233648844],
                                [0.046910077030668074, 0.10481135832065724, 0.8482785646486747],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.9754446838211543, 0.022354760851822406, 0.002200555327023207],
                                [0.9642673033952431, 0.011177380425911203, 0.024555316178845613],
                                [0.9530899229693319, 0.011177380425911203, 0.035732696604756815],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.8792047174726808, 0.10997006241983928, 0.010825220107479883],
                                [0.8242196862627612, 0.05498503120991964, 0.12079528252731918],
                                [0.7692346550528416, 0.05498503120991964, 0.1757803137372388],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.738272480742333, 0.23827248074233298, 0.023455038515334037],
                                [0.6191362403711664, 0.11913624037116649, 0.261727519257667],
                                [0.49999999999999994, 0.11913624037116649, 0.3808637596288335],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5973402440119852, 0.36657489906482665, 0.03608485692318819],
                                [0.41405279447957194, 0.18328744953241333, 0.4026597559880148],
                                [0.23076534494715845, 0.18328744953241333, 0.5859472055204282],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5011002776635116, 0.45419020063284354, 0.04470952170364484],
                                [0.27400517734708985, 0.22709510031642177, 0.4988997223364884],
                                [0.046910077030668074, 0.22709510031642177, 0.7259948226529102],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.9754446838211543, 0.022354760851822406, 0.002200555327023207],
                                [0.9702859797219723, 0.0051587040991820324, 0.024555316178845613],
                                [0.953089922969332, 0.01719605675264037, 0.029714020278027647],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.8792047174726808, 0.10997006241983928, 0.010825220107479883],
                                [0.853827438084506, 0.025377279388174766, 0.12079528252731916],
                                [0.7692346550528416, 0.08459278303166451, 0.14617256191549394],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.738272480742333, 0.23827248074233298, 0.023455038515334037],
                                [0.6832874495324133, 0.054985031209919655, 0.261727519257667],
                                [0.49999999999999994, 0.18328744953241333, 0.3167125504675867],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5973402440119852, 0.36657489906482665, 0.03608485692318819],
                                [0.5127474609803206, 0.08459278303166454, 0.40265975598801484],
                                [0.2307653449471585, 0.28198211603316214, 0.48725253901967935],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5011002776635116, 0.45419020063284354, 0.04470952170364484],
                                [0.3962889193428544, 0.10481135832065727, 0.4988997223364884],
                                [0.04691007703066802, 0.34937884231218624, 0.6037110806571457],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.9754446838211543, 0.022354760851822406, 0.002200555327023207],
                                [0.9743960202675932, 0.0010486635535611516, 0.024555316178845616],
                                [0.9530899229693319, 0.021306097298261252, 0.025603979732406766],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9530899229693319, 0.022354760851822406, 0.024555316178845613],
                                [0.8792047174726808, 0.10997006241983928, 0.010825220107479883],
                                [0.8740460133734987, 0.005158704099182034, 0.12079528252731916],
                                [0.7692346550528416, 0.10481135832065724, 0.1259539866265012],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.10997006241983928, 0.12079528252731916],
                                [0.738272480742333, 0.23827248074233298, 0.023455038515334037],
                                [0.7270951003164218, 0.01117738042591121, 0.261727519257667],
                                [0.5, 0.22709510031642177, 0.27290489968357823],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.23827248074233298, 0.261727519257667],
                                [0.5973402440119852, 0.36657489906482665, 0.03608485692318819],
                                [0.5801441872593449, 0.017196056752640385, 0.4026597559880148],
                                [0.2307653449471585, 0.3493788423121863, 0.4198558127406552],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.36657489906482665, 0.40265975598801484],
                                [0.5011002776635116, 0.45419020063284354, 0.04470952170364484],
                                [0.47979418036525034, 0.021306097298261266, 0.4988997223364884],
                                [0.046910077030668074, 0.43288410333458227, 0.5202058196347497],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.45419020063284354, 0.4988997223364884],
                                [0.9874820364746127, 0.010317408198364065, 0.0022005553270232087],
                                [0.9547032596631122, 0.03277877681150055, 0.012517963525387275],
                                [0.953089922969332, 0.0016133366937801975, 0.04529674033688782],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.03439211350528074, 0.012517963525387275],
                                [0.9384202211161706, 0.05075455877634953, 0.01082522010747989],
                                [0.7771711629893495, 0.1612490581268211, 0.0615797788838294],
                                [0.7692346550528416, 0.007936507936507938, 0.2228288370106505],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.16918556606332902, 0.06157977888382943],
                                [0.8665748990648267, 0.10997006241983931, 0.023455038515334037],
                                [0.5171960567526404, 0.3493788423121863, 0.13342510093517335],
                                [0.5, 0.01719605675264037, 0.48280394324735965],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.36657489906482665, 0.13342510093517335],
                                [0.7947295770134828, 0.16918556606332907, 0.03608485692318819],
                                [0.2572209505159313, 0.5375086264975515, 0.2052704229865172],
                                [0.2307653449471585, 0.026455605568772803, 0.7427790494840687],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.7456677616550407, 0.20962271664131454, 0.04470952170364484],
                                [0.07968885384216862, 0.6659789078128721, 0.2543322383449593],
                                [0.046910077030668074, 0.03277877681150054, 0.9203111461578314],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.6987576846243725, 0.25433223834495944],
                                [0.9874820364746127, 0.010317408198364065, 0.0022005553270232087],
                                [0.96102643090584, 0.026455605568772807, 0.012517963525387275],
                                [0.953089922969332, 0.007936507936507938, 0.03897356909416008],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.03439211350528074, 0.012517963525387275],
                                [0.9384202211161706, 0.05075455877634953, 0.01082522010747989],
                                [0.8082768205655259, 0.13014340055064463, 0.06157977888382943],
                                [0.7692346550528416, 0.039042165512684385, 0.19172317943447406],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.16918556606332902, 0.06157977888382943],
                                [0.8665748990648267, 0.10997006241983931, 0.023455038515334037],
                                [0.5845927830316645, 0.28198211603316214, 0.13342510093517335],
                                [0.5, 0.08459278303166451, 0.4154072169683355],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.36657489906482665, 0.13342510093517335],
                                [0.7947295770134828, 0.16918556606332907, 0.03608485692318819],
                                [0.36090874549780316, 0.43382083151567963, 0.2052704229865172],
                                [0.23076534494715853, 0.13014340055064463, 0.6390912545021968],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.7456677616550407, 0.20962271664131454, 0.04470952170364484],
                                [0.20815913515748918, 0.5375086264975515, 0.2543322383449593],
                                [0.0469100770306681, 0.16124905812682108, 0.7918408648425108],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.6987576846243725, 0.25433223834495944],
                                [0.9874820364746127, 0.010317408198364065, 0.0022005553270232087],
                                [0.9702859797219724, 0.01719605675264037, 0.012517963525387275],
                                [0.953089922969332, 0.01719605675264037, 0.029714020278027647],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.03439211350528074, 0.012517963525387275],
                                [0.9384202211161706, 0.05075455877634953, 0.01082522010747989],
                                [0.853827438084506, 0.08459278303166451, 0.06157977888382943],
                                [0.7692346550528416, 0.08459278303166451, 0.14617256191549394],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.16918556606332902, 0.06157977888382943],
                                [0.8665748990648267, 0.10997006241983931, 0.023455038515334037],
                                [0.6832874495324133, 0.18328744953241333, 0.13342510093517335],
                                [0.49999999999999994, 0.18328744953241333, 0.3167125504675867],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.36657489906482665, 0.13342510093517335],
                                [0.7947295770134828, 0.16918556606332907, 0.03608485692318819],
                                [0.5127474609803206, 0.28198211603316214, 0.2052704229865172],
                                [0.2307653449471585, 0.28198211603316214, 0.48725253901967935],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.7456677616550407, 0.20962271664131454, 0.04470952170364484],
                                [0.39628891934285443, 0.34937884231218624, 0.2543322383449594],
                                [0.04691007703066802, 0.34937884231218624, 0.6037110806571457],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.6987576846243725, 0.25433223834495944],
                                [0.9874820364746127, 0.010317408198364065, 0.0022005553270232087],
                                [0.9795455285381048, 0.007936507936507938, 0.012517963525387274],
                                [0.953089922969332, 0.026455605568772807, 0.02045447146189521],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.03439211350528074, 0.012517963525387275],
                                [0.9384202211161706, 0.05075455877634953, 0.01082522010747989],
                                [0.8993780556034863, 0.039042165512684385, 0.061579778883829414],
                                [0.7692346550528415, 0.13014340055064463, 0.10062194439651381],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.16918556606332902, 0.06157977888382943],
                                [0.8665748990648267, 0.10997006241983931, 0.023455038515334037],
                                [0.7819821160331621, 0.08459278303166451, 0.13342510093517335],
                                [0.5, 0.28198211603316214, 0.21801788396683786],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.36657489906482665, 0.13342510093517335],
                                [0.7947295770134828, 0.16918556606332907, 0.03608485692318819],
                                [0.6645861764628381, 0.13014340055064463, 0.20527042298651724],
                                [0.2307653449471585, 0.43382083151567963, 0.33541382353716187],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.7456677616550407, 0.20962271664131454, 0.04470952170364484],
                                [0.5844187035282195, 0.16124905812682108, 0.25433223834495944],
                                [0.046910077030668074, 0.5375086264975515, 0.41558129647178044],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.6987576846243725, 0.25433223834495944],
                                [0.9874820364746127, 0.010317408198364065, 0.0022005553270232087],
                                [0.9858686997808326, 0.0016133366937802012, 0.012517963525387274],
                                [0.953089922969332, 0.03277877681150054, 0.014131300219167475],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.953089922969332, 0.03439211350528074, 0.012517963525387275],
                                [0.9384202211161706, 0.05075455877634953, 0.01082522010747989],
                                [0.9304837131796627, 0.007936507936507955, 0.06157977888382942],
                                [0.7692346550528415, 0.16124905812682108, 0.06951628682033736],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.16918556606332902, 0.06157977888382943],
                                [0.8665748990648267, 0.10997006241983931, 0.023455038515334037],
                                [0.8493788423121862, 0.01719605675264041, 0.13342510093517335],
                                [0.49999999999999994, 0.34937884231218624, 0.15062115768781376],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.36657489906482665, 0.13342510093517335],
                                [0.7947295770134828, 0.16918556606332907, 0.03608485692318819],
                                [0.7682739714447099, 0.026455605568772862, 0.20527042298651726],
                                [0.2307653449471585, 0.5375086264975514, 0.23172602855529012],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.5639642320663243, 0.2052704229865172],
                                [0.7456677616550407, 0.20962271664131454, 0.04470952170364484],
                                [0.7128889848435399, 0.03277877681150062, 0.25433223834495944],
                                [0.046910077030668074, 0.665978907812872, 0.28711101515646],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.6987576846243725, 0.25433223834495944],
                                [0.9957021175658545, 0.002097327107122303, 0.00220055532702321],
                                [0.9550888643003006, 0.04061325326555382, 0.004297882434145514],
                                [0.953089922969332, 0.0019989413309686862, 0.04491113569969933],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9530899229693319, 0.042612194596522504, 0.004297882434145514],
                                [0.9788573716941561, 0.010317408198364068, 0.010825220107479893],
                                [0.7790680728378635, 0.1997892988562925, 0.021142628305843958],
                                [0.7692346550528415, 0.009833417785021958, 0.2209319271621365],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.2096227166413145, 0.021142628305843958],
                                [0.9541902006328435, 0.02235476085182242, 0.023455038515334037],
                                [0.5213060972982613, 0.43288410333458227, 0.045809799367156456],
                                [0.5, 0.021306097298261252, 0.4786939027017387],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.45419020063284354, 0.045809799367156456],
                                [0.929523029571531, 0.03439211350528077, 0.03608485692318817],
                                [0.26354412175865904, 0.665978907812872, 0.07047697042846901],
                                [0.2307653449471585, 0.03277877681150054, 0.736455878241341],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.6987576846243726, 0.0704769704284689],
                                [0.9126782836998326, 0.04261219459652253, 0.04470952170364487],
                                [0.08752333029622195, 0.8251549534036107, 0.08732171630016738],
                                [0.04691007703066813, 0.04061325326555382, 0.912476669703778],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016738],
                                [0.9957021175658545, 0.002097327107122303, 0.00220055532702321],
                                [0.9629233407543539, 0.03277877681150055, 0.004297882434145514],
                                [0.9530899229693319, 0.009833417785021958, 0.03707665924564606],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9530899229693319, 0.042612194596522504, 0.004297882434145514],
                                [0.9788573716941561, 0.010317408198364068, 0.010825220107479893],
                                [0.8176083135673349, 0.1612490581268211, 0.021142628305843958],
                                [0.7692346550528415, 0.04837365851449339, 0.18239168643266507],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.2096227166413145, 0.021142628305843958],
                                [0.9541902006328435, 0.02235476085182242, 0.023455038515334037],
                                [0.6048113583206572, 0.3493788423121863, 0.045809799367156456],
                                [0.5, 0.10481135832065724, 0.39518864167934276],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.45419020063284354, 0.045809799367156456],
                                [0.929523029571531, 0.03439211350528077, 0.03608485692318817],
                                [0.3920144030739796, 0.5375086264975515, 0.0704769704284689],
                                [0.23076534494715853, 0.16124905812682108, 0.6079855969260204],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.6987576846243726, 0.0704769704284689],
                                [0.9126782836998326, 0.04261219459652253, 0.04470952170364487],
                                [0.24669937588696056, 0.6659789078128721, 0.08732171630016738],
                                [0.046910077030668046, 0.1997892988562925, 0.7533006241130394],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016738],
                                [0.9957021175658545, 0.002097327107122303, 0.00220055532702321],
                                [0.9743960202675932, 0.021306097298261252, 0.004297882434145514],
                                [0.9530899229693319, 0.021306097298261252, 0.025603979732406766],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9530899229693319, 0.042612194596522504, 0.004297882434145514],
                                [0.9788573716941561, 0.010317408198364068, 0.010825220107479893],
                                [0.8740460133734987, 0.10481135832065724, 0.021142628305843958],
                                [0.7692346550528416, 0.10481135832065724, 0.1259539866265012],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.2096227166413145, 0.021142628305843958],
                                [0.9541902006328435, 0.02235476085182242, 0.023455038515334037],
                                [0.7270951003164218, 0.22709510031642177, 0.045809799367156456],
                                [0.5, 0.22709510031642177, 0.27290489968357823],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.45419020063284354, 0.045809799367156456],
                                [0.929523029571531, 0.03439211350528077, 0.03608485692318817],
                                [0.5801441872593448, 0.3493788423121863, 0.0704769704284689],
                                [0.2307653449471585, 0.3493788423121863, 0.4198558127406552],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.6987576846243726, 0.0704769704284689],
                                [0.9126782836998326, 0.04261219459652253, 0.04470952170364487],
                                [0.47979418036525034, 0.43288410333458227, 0.08732171630016738],
                                [0.046910077030668074, 0.43288410333458227, 0.5202058196347497],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016738],
                                [0.9957021175658545, 0.002097327107122303, 0.00220055532702321],
                                [0.9858686997808325, 0.009833417785021958, 0.004297882434145512],
                                [0.953089922969332, 0.03277877681150055, 0.014131300219167468],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9530899229693319, 0.042612194596522504, 0.004297882434145514],
                                [0.9788573716941561, 0.010317408198364068, 0.010825220107479893],
                                [0.9304837131796626, 0.04837365851449339, 0.021142628305843958],
                                [0.7692346550528415, 0.1612490581268211, 0.06951628682033734],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.2096227166413145, 0.021142628305843958],
                                [0.9541902006328435, 0.02235476085182242, 0.023455038515334037],
                                [0.8493788423121863, 0.10481135832065724, 0.045809799367156456],
                                [0.5, 0.3493788423121863, 0.1506211576878137],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.45419020063284354, 0.045809799367156456],
                                [0.929523029571531, 0.03439211350528077, 0.03608485692318817],
                                [0.76827397144471, 0.16124905812682108, 0.07047697042846895],
                                [0.2307653449471585, 0.5375086264975515, 0.23172602855529],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.6987576846243726, 0.0704769704284689],
                                [0.9126782836998326, 0.04261219459652253, 0.04470952170364487],
                                [0.7128889848435401, 0.1997892988562925, 0.08732171630016741],
                                [0.046910077030668074, 0.6659789078128721, 0.28711101515645987],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016738],
                                [0.9957021175658545, 0.002097327107122303, 0.00220055532702321],
                                [0.9937031762348858, 0.001998941330968688, 0.004297882434145513],
                                [0.9530899229693319, 0.04061325326555382, 0.006296823765114201],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9530899229693319, 0.042612194596522504, 0.004297882434145514],
                                [0.9788573716941561, 0.010317408198364068, 0.010825220107479893],
                                [0.969023953909134, 0.009833417785021966, 0.021142628305843958],
                                [0.7692346550528416, 0.1997892988562925, 0.030976046090865933],
                                [0.7692346550528415, 0.21994012483967856, 0.010825220107479883],
                                [0.7692346550528415, 0.2096227166413145, 0.021142628305843958],
                                [0.9541902006328435, 0.02235476085182242, 0.023455038515334037],
                                [0.9328841033345823, 0.021306097298261273, 0.045809799367156456],
                                [0.5, 0.43288410333458227, 0.06711589666541773],
                                [0.5, 0.47654496148466596, 0.023455038515334037],
                                [0.5, 0.45419020063284354, 0.045809799367156456],
                                [0.929523029571531, 0.03439211350528077, 0.03608485692318817],
                                [0.8967442527600306, 0.03277877681150058, 0.07047697042846895],
                                [0.2307653449471585, 0.665978907812872, 0.10325574723996955],
                                [0.2307653449471585, 0.7331497981296533, 0.03608485692318819],
                                [0.2307653449471585, 0.6987576846243726, 0.0704769704284689],
                                [0.9126782836998326, 0.04261219459652253, 0.04470952170364487],
                                [0.8720650304342787, 0.04061325326555386, 0.0873217163001674],
                                [0.046910077030668074, 0.8251549534036107, 0.12793496956572126],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364484],
                                [0.046910077030668074, 0.8657682066691645, 0.08732171630016738],
                            ]
                        ),
                        np.array(
                            [
                                4.4737130719886495e-11,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                1.0758849237179852e-08,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                1.3007469257079052e-07,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                3.9850206675562386e-07,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                3.7520733644405666e-07,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                9.037587014803093e-11,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                2.173452668857425e-08,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                2.627708423888083e-07,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                8.05035335509769e-07,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                7.579764050890087e-07,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                1.0741903174592194e-10,
                                5.039035053760971e-12,
                                5.039035053760971e-12,
                                5.039035053760971e-12,
                                5.039035053760971e-12,
                                2.583324297202811e-08,
                                1.2118394177698019e-09,
                                1.2118394177698019e-09,
                                1.2118394177698019e-09,
                                1.2118394177698019e-09,
                                3.1232440046477424e-07,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                9.56849611738946e-07,
                                4.488588899343874e-08,
                                4.488588899343874e-08,
                                4.488588899343874e-08,
                                4.488588899343874e-08,
                                9.009162665604496e-07,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                9.037587014803093e-11,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                4.2395390303577815e-12,
                                2.173452668857425e-08,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                1.019568321186128e-09,
                                2.627708423888083e-07,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                1.2326600457872522e-08,
                                8.05035335509769e-07,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                3.7764269601172935e-08,
                                7.579764050890087e-07,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                3.555673155015422e-08,
                                4.4737130719886495e-11,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                2.0986222482009402e-12,
                                1.0758849237179852e-08,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                5.046984464774507e-10,
                                1.3007469257079052e-07,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                6.101813848236244e-09,
                                3.9850206675562386e-07,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                1.8693762648386723e-08,
                                3.7520733644405666e-07,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                9.037587014803093e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.173452668857425e-08,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                2.627708423888083e-07,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                8.05035335509769e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                7.579764050890087e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.825731282624035e-10,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.390707964787606e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                5.30837430748842e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.6262949316565377e-06,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                1.5312286697712775e-06,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                2.1700293041326468e-10,
                                5.0076756091361244e-11,
                                5.0076756091361244e-11,
                                5.0076756091361244e-11,
                                5.0076756091361244e-11,
                                5.2187115596680994e-08,
                                1.2042977732465322e-08,
                                1.2042977732465322e-08,
                                1.2042977732465322e-08,
                                1.2042977732465322e-08,
                                6.309432233640947e-07,
                                1.4559983058168736e-07,
                                1.4559983058168736e-07,
                                1.4559983058168736e-07,
                                1.4559983058168736e-07,
                                1.932983069548368e-06,
                                4.460655048213463e-07,
                                4.460655048213463e-07,
                                4.460655048213463e-07,
                                4.460655048213463e-07,
                                1.8199891278392339e-06,
                                4.1999041888589887e-07,
                                4.1999041888589887e-07,
                                4.1999041888589887e-07,
                                4.1999041888589887e-07,
                                1.825731282624035e-10,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.2131550921555346e-11,
                                4.390707964787606e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                1.0132232380564479e-08,
                                5.30837430748842e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.2249888281761987e-07,
                                1.6262949316565377e-06,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                3.752925108895364e-07,
                                1.5312286697712775e-06,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                3.533545121727474e-07,
                                9.037587014803093e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.0855618849609957e-11,
                                2.173452668857425e-08,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                5.015575548552058e-09,
                                2.627708423888083e-07,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                6.063840408590875e-08,
                                8.05035335509769e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                1.8577425689356328e-07,
                                7.579764050890087e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.749146865821722e-07,
                                1.0741903174592191e-10,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                2.5833242972028105e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                3.123244004647742e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                9.568496117389458e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                9.009162665604496e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                2.170029304132646e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                5.218711559668099e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                6.309432233640945e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                1.932983069548368e-06,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                1.8199891278392332e-06,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                2.579255351327695e-10,
                                1.2896276756638474e-10,
                                1.2896276756638474e-10,
                                1.2896276756638474e-10,
                                1.2896276756638474e-10,
                                6.202860805462587e-08,
                                3.1014304027312935e-08,
                                3.1014304027312935e-08,
                                3.1014304027312935e-08,
                                3.1014304027312935e-08,
                                7.499270549695355e-07,
                                3.7496352748476776e-07,
                                3.7496352748476776e-07,
                                3.7496352748476776e-07,
                                3.7496352748476776e-07,
                                2.2975067279799764e-06,
                                1.1487533639899882e-06,
                                1.1487533639899882e-06,
                                1.1487533639899882e-06,
                                1.1487533639899882e-06,
                                2.1632042887152763e-06,
                                1.0816021443576382e-06,
                                1.0816021443576382e-06,
                                1.0816021443576382e-06,
                                1.0816021443576382e-06,
                                2.170029304132646e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                1.085014652066323e-10,
                                5.218711559668099e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                2.6093557798340494e-08,
                                6.309432233640945e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                3.1547161168204726e-07,
                                1.932983069548368e-06,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                9.66491534774184e-07,
                                1.8199891278392332e-06,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                9.099945639196166e-07,
                                1.0741903174592191e-10,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                5.3709515872960955e-11,
                                2.5833242972028105e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                1.2916621486014053e-08,
                                3.123244004647742e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                1.561622002323871e-07,
                                9.568496117389458e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                4.784248058694729e-07,
                                9.009162665604496e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                4.504581332802248e-07,
                                9.037587014803093e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                2.173452668857425e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                2.627708423888083e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                8.05035335509769e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                7.579764050890087e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                1.825731282624035e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                4.390707964787606e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                5.30837430748842e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                1.6262949316565377e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.5312286697712775e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                2.1700293041326468e-10,
                                1.6692617432190342e-10,
                                1.6692617432190342e-10,
                                1.6692617432190342e-10,
                                1.6692617432190342e-10,
                                5.2187115596680994e-08,
                                4.014413786421567e-08,
                                4.014413786421567e-08,
                                4.014413786421567e-08,
                                4.014413786421567e-08,
                                6.309432233640947e-07,
                                4.853433927824073e-07,
                                4.853433927824073e-07,
                                4.853433927824073e-07,
                                4.853433927824073e-07,
                                1.932983069548368e-06,
                                1.4869175647270216e-06,
                                1.4869175647270216e-06,
                                1.4869175647270216e-06,
                                1.4869175647270216e-06,
                                1.8199891278392339e-06,
                                1.3999987089533349e-06,
                                1.3999987089533349e-06,
                                1.3999987089533349e-06,
                                1.3999987089533349e-06,
                                1.825731282624035e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                1.4044157734084815e-10,
                                4.390707964787606e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                3.377484726731158e-08,
                                5.30837430748842e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                4.0833854793122213e-07,
                                1.6262949316565377e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.2510024207670013e-06,
                                1.5312286697712775e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                1.17787415759853e-06,
                                9.037587014803093e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                6.952025129842097e-11,
                                2.173452668857425e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                1.671895114002219e-08,
                                2.627708423888083e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                2.0213243830289954e-07,
                                8.05035335509769e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                6.192610786162057e-07,
                                7.579764050890087e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                5.830617185068365e-07,
                                4.4737130719886495e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                1.0758849237179852e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.3007469257079052e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                3.9850206675562386e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.7520733644405666e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                9.037587014803093e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                2.173452668857425e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.627708423888083e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                8.05035335509769e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.579764050890087e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                1.0741903174592194e-10,
                                1.0237999669216095e-10,
                                1.0237999669216095e-10,
                                1.0237999669216095e-10,
                                1.0237999669216095e-10,
                                2.583324297202811e-08,
                                2.4621403554258304e-08,
                                2.4621403554258304e-08,
                                2.4621403554258304e-08,
                                2.4621403554258304e-08,
                                3.1232440046477424e-07,
                                2.976732387804145e-07,
                                2.976732387804145e-07,
                                2.976732387804145e-07,
                                2.976732387804145e-07,
                                9.56849611738946e-07,
                                9.119637227455072e-07,
                                9.119637227455072e-07,
                                9.119637227455072e-07,
                                9.119637227455072e-07,
                                9.009162665604496e-07,
                                8.58654215097917e-07,
                                8.58654215097917e-07,
                                8.58654215097917e-07,
                                8.58654215097917e-07,
                                9.037587014803093e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                8.613633111767314e-11,
                                2.173452668857425e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.071495836738812e-08,
                                2.627708423888083e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                2.5044424193093573e-07,
                                8.05035335509769e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.67271065908596e-07,
                                7.579764050890087e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                7.224196735388545e-07,
                                4.4737130719886495e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                4.263850847168555e-11,
                                1.0758849237179852e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.0254150790702401e-08,
                                1.3007469257079052e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                1.2397287872255426e-07,
                                3.9850206675562386e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.798083041072371e-07,
                                3.7520733644405666e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                3.576063313889942e-07,
                                2.187063428406109e-09,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                5.259676988607445e-07,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                6.358959515396152e-06,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                1.9481564470518327e-05,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                1.8342755344425562e-05,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                4.418203788006352e-09,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                1.0625354753287109e-06,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                1.2846074171327331e-05,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                3.935575019086795e-05,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                3.705518097583329e-05,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                5.251392569570156e-09,
                                2.4634322995681364e-10,
                                2.4634322995681364e-10,
                                2.4634322995681364e-10,
                                2.4634322995681364e-10,
                                1.262909355877331e-06,
                                5.924317516695693e-08,
                                5.924317516695693e-08,
                                5.924317516695693e-08,
                                5.924317516695693e-08,
                                1.5268598210562768e-05,
                                7.162511182078193e-07,
                                7.162511182078193e-07,
                                7.162511182078193e-07,
                                7.162511182078193e-07,
                                4.677749240159904e-05,
                                2.194335771860499e-06,
                                2.194335771860499e-06,
                                2.194335771860499e-06,
                                2.194335771860499e-06,
                                4.4043079807410766e-05,
                                2.066064266433498e-06,
                                2.066064266433498e-06,
                                2.066064266433498e-06,
                                2.066064266433498e-06,
                                4.418203788006352e-09,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                2.072582800325672e-10,
                                1.0625354753287109e-06,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                4.984362099548728e-08,
                                1.2846074171327331e-05,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                6.026103289186399e-07,
                                3.935575019086795e-05,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                1.846181273053343e-06,
                                3.705518097583329e-05,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                1.7382613939616837e-06,
                                2.187063428406109e-09,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                1.0259531389748745e-10,
                                5.259676988607445e-07,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                2.467318526920072e-08,
                                6.358959515396152e-06,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                2.982992807021328e-07,
                                1.9481564470518327e-05,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                9.138816899899399e-07,
                                1.8342755344425562e-05,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                8.604600661617005e-07,
                                4.418203788006351e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0625354753287109e-06,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                1.284607417132733e-05,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                3.935575019086795e-05,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                3.705518097583328e-05,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.925449741793666e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.146484734285783e-06,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                2.5951041395325284e-05,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                7.950465556449192e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                7.485715266703614e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.060861895536896e-08,
                                2.4481016126486817e-09,
                                2.4481016126486817e-09,
                                2.4481016126486817e-09,
                                2.4481016126486817e-09,
                                2.551270725656244e-06,
                                5.887448690596504e-07,
                                5.887448690596504e-07,
                                5.887448690596504e-07,
                                5.887448690596504e-07,
                                3.084491175485425e-05,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                9.449771389246003e-05,
                                2.1806797543111425e-05,
                                2.1806797543111425e-05,
                                2.1806797543111425e-05,
                                2.1806797543111425e-05,
                                8.89737807843931e-05,
                                2.053206521396333e-05,
                                2.053206521396333e-05,
                                2.053206521396333e-05,
                                2.053206521396333e-05,
                                8.925449741793666e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.0596844884735416e-09,
                                2.146484734285783e-06,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                4.953342901312684e-07,
                                2.5951041395325284e-05,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                5.988601019330227e-06,
                                7.950465556449192e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                1.8346919266244997e-05,
                                7.485715266703614e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                1.7274436656970697e-05,
                                4.418203788006351e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0195683211861276e-09,
                                1.0625354753287109e-06,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                2.451963654828229e-07,
                                1.284607417132733e-05,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                2.964428737363134e-06,
                                3.935575019086795e-05,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                9.081943268449838e-06,
                                3.705518097583328e-05,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                8.55105161996755e-06,
                                5.251392569570155e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                1.2629093558773309e-06,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                1.5268598210562768e-05,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                4.677749240159903e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                4.404307980741076e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                1.060861895536896e-08,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                2.551270725656244e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                3.084491175485425e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                9.449771389246003e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                8.89737807843931e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                1.2609201709268367e-08,
                                6.304600854634184e-09,
                                6.304600854634184e-09,
                                6.304600854634184e-09,
                                6.304600854634184e-09,
                                3.032391617616755e-06,
                                1.5161958088083776e-06,
                                1.5161958088083776e-06,
                                1.5161958088083776e-06,
                                1.5161958088083776e-06,
                                3.6661672519089314e-05,
                                1.8330836259544657e-05,
                                1.8330836259544657e-05,
                                1.8330836259544657e-05,
                                1.8330836259544657e-05,
                                0.00011231817643254387,
                                5.6159088216271936e-05,
                                5.6159088216271936e-05,
                                5.6159088216271936e-05,
                                5.6159088216271936e-05,
                                0.00010575253512888753,
                                5.2876267564443766e-05,
                                5.2876267564443766e-05,
                                5.2876267564443766e-05,
                                5.2876267564443766e-05,
                                1.060861895536896e-08,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                5.30430947768448e-09,
                                2.551270725656244e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                1.275635362828122e-06,
                                3.084491175485425e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                1.5422455877427126e-05,
                                9.449771389246003e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                4.724885694623001e-05,
                                8.89737807843931e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                4.448689039219655e-05,
                                5.251392569570155e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                2.6256962847850774e-09,
                                1.2629093558773309e-06,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                6.314546779386654e-07,
                                1.5268598210562768e-05,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                7.634299105281384e-06,
                                4.677749240159903e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                2.3388746200799515e-05,
                                4.404307980741076e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                2.202153990370538e-05,
                                4.418203788006351e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                1.0625354753287109e-06,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                1.284607417132733e-05,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                3.935575019086795e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.705518097583328e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                8.925449741793666e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                2.146484734285783e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                2.5951041395325284e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                7.950465556449192e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                7.485715266703614e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                1.060861895536896e-08,
                                8.160517342720278e-09,
                                8.160517342720278e-09,
                                8.160517342720278e-09,
                                8.160517342720278e-09,
                                2.551270725656244e-06,
                                1.9625258565965933e-06,
                                1.9625258565965933e-06,
                                1.9625258565965933e-06,
                                1.9625258565965933e-06,
                                3.084491175485425e-05,
                                2.3726975053880647e-05,
                                2.3726975053880647e-05,
                                2.3726975053880647e-05,
                                2.3726975053880647e-05,
                                9.449771389246003e-05,
                                7.26909163493486e-05,
                                7.26909163493486e-05,
                                7.26909163493486e-05,
                                7.26909163493486e-05,
                                8.89737807843931e-05,
                                6.844171557042976e-05,
                                6.844171557042976e-05,
                                6.844171557042976e-05,
                                6.844171557042976e-05,
                                8.925449741793666e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                6.865765253320124e-09,
                                2.146484734285783e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                1.6511504441545145e-06,
                                2.5951041395325284e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                1.9962440375995055e-05,
                                7.950465556449192e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                6.115773629824693e-05,
                                7.485715266703614e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                5.758271601006544e-05,
                                4.418203788006351e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                3.398635466820223e-09,
                                1.0625354753287109e-06,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                8.173391098458878e-07,
                                1.284607417132733e-05,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                9.881645433964195e-06,
                                3.935575019086795e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.0273806922418108e-05,
                                3.705518097583328e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.8504129355865727e-05,
                                2.187063428406109e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                5.259676988607445e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                6.358959515396152e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                1.9481564470518327e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8342755344425562e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                4.418203788006352e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                1.0625354753287109e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.2846074171327331e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                3.935575019086795e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.705518097583329e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                5.251392569570156e-09,
                                5.005049339613342e-09,
                                5.005049339613342e-09,
                                5.005049339613342e-09,
                                5.005049339613342e-09,
                                1.262909355877331e-06,
                                1.203666180710374e-06,
                                1.203666180710374e-06,
                                1.203666180710374e-06,
                                1.203666180710374e-06,
                                1.5268598210562768e-05,
                                1.4552347092354948e-05,
                                1.4552347092354948e-05,
                                1.4552347092354948e-05,
                                1.4552347092354948e-05,
                                4.677749240159904e-05,
                                4.4583156629738534e-05,
                                4.4583156629738534e-05,
                                4.4583156629738534e-05,
                                4.4583156629738534e-05,
                                4.4043079807410766e-05,
                                4.1977015540977266e-05,
                                4.1977015540977266e-05,
                                4.1977015540977266e-05,
                                4.1977015540977266e-05,
                                4.418203788006352e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                4.210945507973784e-09,
                                1.0625354753287109e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.0126918543332236e-06,
                                1.2846074171327331e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                1.224346384240869e-05,
                                3.935575019086795e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.75095689178146e-05,
                                3.705518097583329e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                3.53169195818716e-05,
                                2.187063428406109e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                2.084468114508621e-09,
                                5.259676988607445e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                5.012945135915437e-07,
                                6.358959515396152e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                6.060660234694019e-06,
                                1.9481564470518327e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8567682780528385e-05,
                                1.8342755344425562e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.748229527826386e-05,
                                1.2203627696472485e-08,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                2.9348549721508165e-06,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                3.5482452614275984e-05,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                0.00010870547084054918,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                0.00010235101288945556,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                2.4653200915745038e-08,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                5.928857474726267e-06,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                7.168000000000007e-05,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                0.00021960173482245542,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                0.00020676475450190303,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                2.9302323368719527e-08,
                                1.3745742464041767e-09,
                                1.3745742464041767e-09,
                                1.3745742464041767e-09,
                                1.3745742464041767e-09,
                                7.046926665840167e-06,
                                3.305718727240308e-07,
                                3.305718727240308e-07,
                                3.305718727240308e-07,
                                3.305718727240308e-07,
                                8.519747785482818e-05,
                                3.996620248988623e-06,
                                3.996620248988623e-06,
                                3.996620248988623e-06,
                                3.996620248988623e-06,
                                0.00026101442437804096,
                                1.2244206753689373e-05,
                                1.2244206753689373e-05,
                                1.2244206753689373e-05,
                                1.2244206753689373e-05,
                                0.0002457566349446827,
                                1.1528462676052824e-05,
                                1.1528462676052824e-05,
                                1.1528462676052824e-05,
                                1.1528462676052824e-05,
                                2.4653200915745038e-08,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                1.156483554010135e-09,
                                5.928857474726267e-06,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                2.7812316084326104e-07,
                                7.168000000000007e-05,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                3.3625143215582868e-06,
                                0.00021960173482245542,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                1.0301534296589716e-05,
                                0.00020676475450190303,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                9.699350560911432e-06,
                                1.2203627696472485e-08,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                5.72473115295118e-10,
                                2.9348549721508165e-06,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                1.3767427281743386e-07,
                                3.5482452614275984e-05,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                1.6644845853727142e-06,
                                0.00010870547084054918,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                5.099382010785198e-06,
                                0.00010235101288945556,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                4.801293898811256e-06,
                                2.4653200915745038e-08,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.928857474726267e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                7.168000000000007e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                0.00021960173482245542,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                0.00020676475450190303,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.980324953438016e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1977202038660454e-05,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                0.00014480460118849797,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                0.000443629208025501,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.0004176965376044326,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                5.919519041997532e-08,
                                1.3660198536478334e-08,
                                1.3660198536478334e-08,
                                1.3660198536478334e-08,
                                1.3660198536478334e-08,
                                1.4235873401947208e-05,
                                3.2851462362244253e-06,
                                3.2851462362244253e-06,
                                3.2851462362244253e-06,
                                3.2851462362244253e-06,
                                0.00017211198106911648,
                                3.971748068095347e-05,
                                3.971748068095347e-05,
                                3.971748068095347e-05,
                                3.971748068095347e-05,
                                0.0005272891967983754,
                                0.0001216800733860872,
                                0.0001216800733860872,
                                0.0001216800733860872,
                                0.0001216800733860872,
                                0.0004964661204323662,
                                0.0001145671755361525,
                                0.0001145671755361525,
                                0.0001145671755361525,
                                0.0001145671755361525,
                                4.980324953438016e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1492864058290646e-08,
                                1.1977202038660454e-05,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                2.763923159953289e-06,
                                0.00014480460118849797,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                3.341588374319944e-05,
                                0.000443629208025501,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.00010237424721863945,
                                0.0004176965376044326,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                9.638988558352063e-05,
                                2.4653200915745038e-08,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.689104413373506e-09,
                                5.928857474726267e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                1.3681748402977457e-06,
                                7.168000000000007e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                1.6541259925812336e-05,
                                0.00021960173482245542,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                5.067647008729834e-05,
                                0.00020676475450190303,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                4.771413989554618e-05,
                                2.930232336871953e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                7.046926665840167e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                8.51974778548282e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                0.000261014424378041,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0002457566349446827,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                5.919519041997532e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                1.4235873401947208e-05,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                0.00017211198106911648,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                0.0005272891967983754,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0004964661204323662,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                7.035827183200586e-08,
                                3.517913591600293e-08,
                                3.517913591600293e-08,
                                3.517913591600293e-08,
                                3.517913591600293e-08,
                                1.6920487010414808e-05,
                                8.460243505207404e-06,
                                8.460243505207404e-06,
                                8.460243505207404e-06,
                                8.460243505207404e-06,
                                0.00020456901082152126,
                                0.00010228450541076063,
                                0.00010228450541076063,
                                0.00010228450541076063,
                                0.00010228450541076063,
                                0.0006267258603141696,
                                0.0003133629301570848,
                                0.0003133629301570848,
                                0.0003133629301570848,
                                0.0003133629301570848,
                                0.0005900901409208837,
                                0.00029504507046044186,
                                0.00029504507046044186,
                                0.00029504507046044186,
                                0.00029504507046044186,
                                5.919519041997532e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                2.959759520998766e-08,
                                1.4235873401947208e-05,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                7.117936700973604e-06,
                                0.00017211198106911648,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                8.605599053455824e-05,
                                0.0005272891967983754,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0004964661204323662,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                0.0002482330602161831,
                                2.930232336871953e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                1.4651161684359765e-08,
                                7.046926665840167e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                3.5234633329200834e-06,
                                8.51974778548282e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                4.25987389274141e-05,
                                0.000261014424378041,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0001305072121890205,
                                0.0002457566349446827,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                2.4653200915745038e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                5.928857474726267e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                7.168000000000007e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                0.00021960173482245542,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00020676475450190303,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                4.980324953438016e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                1.1977202038660454e-05,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                0.00014480460118849797,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.000443629208025501,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0004176965376044326,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                5.919519041997532e-08,
                                4.5534991883496985e-08,
                                4.5534991883496985e-08,
                                4.5534991883496985e-08,
                                4.5534991883496985e-08,
                                1.4235873401947208e-05,
                                1.0950727165722781e-05,
                                1.0950727165722781e-05,
                                1.0950727165722781e-05,
                                1.0950727165722781e-05,
                                0.00017211198106911648,
                                0.000132394500388163,
                                0.000132394500388163,
                                0.000132394500388163,
                                0.000132394500388163,
                                0.0005272891967983754,
                                0.0004056091234122881,
                                0.0004056091234122881,
                                0.0004056091234122881,
                                0.0004056091234122881,
                                0.0004964661204323662,
                                0.00038189894489621366,
                                0.00038189894489621366,
                                0.00038189894489621366,
                                0.00038189894489621366,
                                4.980324953438016e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                3.831038547608951e-08,
                                1.1977202038660454e-05,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                9.213278878707163e-06,
                                0.00014480460118849797,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.00011138871744529852,
                                0.000443629208025501,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0003412549608068615,
                                0.0004176965376044326,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                0.00032130665202091197,
                                2.4653200915745038e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                1.896409650237153e-08,
                                5.928857474726267e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                4.560682634428521e-06,
                                7.168000000000007e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                5.513874007418774e-05,
                                0.00021960173482245542,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00016892526473515705,
                                0.00020676475450190303,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                0.00015905061460635682,
                                1.2203627696472485e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                2.9348549721508165e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                3.5482452614275984e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                0.00010870547084054918,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010235101288945556,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                2.4653200915745038e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                5.928857474726267e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                7.168000000000007e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                0.00021960173482245542,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.00020676475450190303,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                2.9302323368719527e-08,
                                2.792774912231535e-08,
                                2.792774912231535e-08,
                                2.792774912231535e-08,
                                2.792774912231535e-08,
                                7.046926665840167e-06,
                                6.716354793116135e-06,
                                6.716354793116135e-06,
                                6.716354793116135e-06,
                                6.716354793116135e-06,
                                8.519747785482818e-05,
                                8.120085760583956e-05,
                                8.120085760583956e-05,
                                8.120085760583956e-05,
                                8.120085760583956e-05,
                                0.00026101442437804096,
                                0.0002487702176243516,
                                0.0002487702176243516,
                                0.0002487702176243516,
                                0.0002487702176243516,
                                0.0002457566349446827,
                                0.00023422817226862984,
                                0.00023422817226862984,
                                0.00023422817226862984,
                                0.00023422817226862984,
                                2.4653200915745038e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                2.34967173617349e-08,
                                5.928857474726267e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                5.650734313883006e-06,
                                7.168000000000007e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                6.831748567844178e-05,
                                0.00021960173482245542,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.0002093002005258657,
                                0.00020676475450190303,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                0.0001970654039409916,
                                1.2203627696472485e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                1.1631154581177366e-08,
                                2.9348549721508165e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                2.7971806993333825e-06,
                                3.5482452614275984e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                3.381796802890327e-05,
                                0.00010870547084054918,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010360608882976398,
                                0.00010235101288945556,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                9.75497189906443e-05,
                                2.430176868084887e-08,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                5.844341405602228e-06,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                7.065819911161038e-05,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                0.00021647130446903043,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                0.00020381731574858664,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                4.909330248333491e-08,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                1.180646660780769e-05,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                0.00014274040657162685,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                0.0004373052582643949,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                0.00041174225896043837,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                5.8351360925562265e-08,
                                2.7372668358624376e-09,
                                2.7372668358624376e-09,
                                2.7372668358624376e-09,
                                2.7372668358624376e-09,
                                1.4032940532400431e-05,
                                6.582863213416877e-07,
                                6.582863213416877e-07,
                                6.582863213416877e-07,
                                6.582863213416877e-07,
                                0.0001696585188040644,
                                7.958694186007699e-06,
                                7.958694186007699e-06,
                                7.958694186007699e-06,
                                7.958694186007699e-06,
                                0.000519772670993034,
                                2.4382576034719288e-05,
                                2.4382576034719288e-05,
                                2.4382576034719288e-05,
                                2.4382576034719288e-05,
                                0.0004893889786506535,
                                2.29572746864621e-05,
                                2.29572746864621e-05,
                                2.29572746864621e-05,
                                2.29572746864621e-05,
                                4.909330248333491e-08,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                2.302970601183126e-09,
                                1.180646660780769e-05,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                5.538422580322684e-07,
                                0.00014274040657162685,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                6.695963467663887e-06,
                                0.0004373052582643949,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                2.0514023351098938e-05,
                                0.00041174225896043837,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                1.9314861084615424e-05,
                                2.430176868084887e-08,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                1.139997840800096e-09,
                                5.844341405602228e-06,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                2.7415850553032314e-07,
                                7.065819911161038e-05,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                3.3145815631739214e-06,
                                0.00021647130446903043,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                1.0154685567571408e-05,
                                0.00020381731574858664,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                9.561085981950184e-06,
                                4.90933024833349e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.180646660780769e-05,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                0.00014274040657162682,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                0.0004373052582643949,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.00041174225896043826,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.917600567976561e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.3850874561787234e-05,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                0.0002883575285587117,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                0.0008834237377317069,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.0008317825558205559,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                1.1787870462656441e-07,
                                2.7202319935073337e-08,
                                2.7202319935073337e-08,
                                2.7202319935073337e-08,
                                2.7202319935073337e-08,
                                2.834869360067174e-05,
                                6.541896057560317e-06,
                                6.541896057560317e-06,
                                6.541896057560317e-06,
                                6.541896057560317e-06,
                                0.00034273624656325056,
                                7.909164816406286e-05,
                                7.909164816406286e-05,
                                7.909164816406286e-05,
                                7.909164816406286e-05,
                                0.0010500205682453482,
                                0.0002423083586327491,
                                0.0002423083586327491,
                                0.0002423083586327491,
                                0.0002423083586327491,
                                0.0009886408465339584,
                                0.00022814404597925966,
                                0.00022814404597925966,
                                0.00022814404597925966,
                                0.00022814404597925966,
                                9.917600567976561e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.2886385161172457e-08,
                                2.3850874561787234e-05,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                5.503955295542238e-06,
                                0.0002883575285587117,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                6.654292454596121e-05,
                                0.0008834237377317069,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.00020386358357216537,
                                0.0008317825558205559,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                0.00019194658841495966,
                                4.90933024833349e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.1329032882161968e-08,
                                1.180646660780769e-05,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                2.7245233393578494e-06,
                                0.00014274040657162682,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                3.2939539160399104e-05,
                                0.0004373052582643949,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.0001009148987705893,
                                0.00041174225896043826,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                9.501584441832778e-05,
                                5.8351360925562245e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                1.4032940532400431e-05,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                0.00016965851880406437,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                0.0005197726709930339,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.0004893889786506532,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                1.1787870462656441e-07,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                2.834869360067174e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                0.00034273624656325056,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.0010500205682453482,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0009886408465339584,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                1.4010837509734297e-07,
                                7.005418754867148e-08,
                                7.005418754867148e-08,
                                7.005418754867148e-08,
                                7.005418754867148e-08,
                                3.369471533561018e-05,
                                1.684735766780509e-05,
                                1.684735766780509e-05,
                                1.684735766780509e-05,
                                1.684735766780509e-05,
                                0.0004073697513479275,
                                0.00020368487567396374,
                                0.00020368487567396374,
                                0.00020368487567396374,
                                0.00020368487567396374,
                                0.0012480343765373474,
                                0.0006240171882686737,
                                0.0006240171882686737,
                                0.0006240171882686737,
                                0.0006240171882686737,
                                0.0011750796125691322,
                                0.0005875398062845661,
                                0.0005875398062845661,
                                0.0005875398062845661,
                                0.0005875398062845661,
                                1.1787870462656441e-07,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                5.8939352313282205e-08,
                                2.834869360067174e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                1.417434680033587e-05,
                                0.00034273624656325056,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.00017136812328162528,
                                0.0010500205682453482,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0005250102841226741,
                                0.0009886408465339584,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                0.0004943204232669792,
                                5.8351360925562245e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                2.9175680462781123e-08,
                                1.4032940532400431e-05,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                7.016470266200216e-06,
                                0.00016965851880406437,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                8.482925940203219e-05,
                                0.0005197726709930339,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.00025988633549651693,
                                0.0004893889786506532,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                0.0002446944893253266,
                                4.90933024833349e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                1.180646660780769e-05,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                0.00014274040657162682,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.0004373052582643949,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.00041174225896043826,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                9.917600567976561e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                2.3850874561787234e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                0.0002883575285587117,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0008834237377317069,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0008317825558205559,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                1.1787870462656441e-07,
                                9.067638469149107e-08,
                                9.067638469149107e-08,
                                9.067638469149107e-08,
                                9.067638469149107e-08,
                                2.834869360067174e-05,
                                2.180679754311142e-05,
                                2.180679754311142e-05,
                                2.180679754311142e-05,
                                2.180679754311142e-05,
                                0.00034273624656325056,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0002636445983991877,
                                0.0010500205682453482,
                                0.000807712209612599,
                                0.000807712209612599,
                                0.000807712209612599,
                                0.000807712209612599,
                                0.0009886408465339584,
                                0.0007604968005546987,
                                0.0007604968005546987,
                                0.0007604968005546987,
                                0.0007604968005546987,
                                9.917600567976561e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                7.628962051859314e-08,
                                2.3850874561787234e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                1.8346919266244994e-05,
                                0.0002883575285587117,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0002218146040127505,
                                0.0008834237377317069,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0006795601541595415,
                                0.0008317825558205559,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                0.0006398359674055962,
                                4.90933024833349e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                3.776426960117293e-08,
                                1.180646660780769e-05,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                9.08194326844984e-06,
                                0.00014274040657162682,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.00010980086741122771,
                                0.0004373052582643949,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.0003363903594938056,
                                0.00041174225896043826,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                0.00031672641454211047,
                                2.430176868084887e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                5.844341405602228e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                7.065819911161038e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                0.00021647130446903043,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.00020381731574858664,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                4.909330248333491e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                1.180646660780769e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                0.00014274040657162685,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.0004373052582643949,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041174225896043837,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                5.8351360925562265e-08,
                                5.5614094089699824e-08,
                                5.5614094089699824e-08,
                                5.5614094089699824e-08,
                                5.5614094089699824e-08,
                                1.4032940532400431e-05,
                                1.3374654211058743e-05,
                                1.3374654211058743e-05,
                                1.3374654211058743e-05,
                                1.3374654211058743e-05,
                                0.0001696585188040644,
                                0.00016169982461805668,
                                0.00016169982461805668,
                                0.00016169982461805668,
                                0.00016169982461805668,
                                0.000519772670993034,
                                0.0004953900949583146,
                                0.0004953900949583146,
                                0.0004953900949583146,
                                0.0004953900949583146,
                                0.0004893889786506535,
                                0.0004664317039641913,
                                0.0004664317039641913,
                                0.0004664317039641913,
                                0.0004664317039641913,
                                4.909330248333491e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                4.679033188215178e-08,
                                1.180646660780769e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                1.125262434977542e-05,
                                0.00014274040657162685,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.00013604444310396296,
                                0.0004373052582643949,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041679123491329597,
                                0.00041174225896043837,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                0.00039242739787582293,
                                2.430176868084887e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                2.3161770840048772e-08,
                                5.844341405602228e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                5.5701829000719045e-06,
                                7.065819911161038e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                6.734361754843646e-05,
                                0.00021647130446903043,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.000206316618901459,
                                0.00020381731574858664,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                0.00019425622976663643,
                                1.8467307890767437e-08,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                4.441209756105985e-06,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                5.369431069556538e-05,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                0.0001645000527182208,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                0.00015488408160041112,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                3.7306796235320555e-08,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                8.971925328228136e-06,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                0.00010847074841465732,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                0.00033231535336703156,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                0.0003128896158844069,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                4.434214489527492e-08,
                                2.0800934327423893e-09,
                                2.0800934327423893e-09,
                                2.0800934327423893e-09,
                                2.0800934327423893e-09,
                                1.0663858949035826e-05,
                                5.002424447434491e-07,
                                5.002424447434491e-07,
                                5.002424447434491e-07,
                                5.002424447434491e-07,
                                0.000128926258174587,
                                6.047940702245669e-06,
                                6.047940702245669e-06,
                                6.047940702245669e-06,
                                6.047940702245669e-06,
                                0.00039498367688765417,
                                1.8528714708656345e-05,
                                1.8528714708656345e-05,
                                1.8528714708656345e-05,
                                1.8528714708656345e-05,
                                0.00037189461663389266,
                                1.7445605113586656e-05,
                                1.7445605113586656e-05,
                                1.7445605113586656e-05,
                                1.7445605113586656e-05,
                                3.7306796235320555e-08,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                1.7500646851663228e-09,
                                8.971925328228136e-06,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                4.208737082605833e-07,
                                0.00010847074841465732,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                5.088371163705786e-06,
                                0.00033231535336703156,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                1.5588938824921115e-05,
                                0.0003128896158844069,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.4677675983233655e-05,
                                1.8467307890767437e-08,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                8.663028357049638e-10,
                                4.441209756105985e-06,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                2.083374917682861e-07,
                                5.369431069556538e-05,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                2.518804250837594e-06,
                                0.0001645000527182208,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                7.716710144560688e-06,
                                0.00015488408160041112,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                7.265624198699557e-06,
                                3.7306796235320555e-08,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.971925328228136e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                0.00010847074841465732,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                0.00033231535336703156,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                0.0003128896158844069,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.536545410820513e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.812466614183953e-05,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                0.00021912755949780044,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                0.0006713280163661793,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.0006320850452589817,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                8.957793816131235e-08,
                                2.0671483799450473e-08,
                                2.0671483799450473e-08,
                                2.0671483799450473e-08,
                                2.0671483799450473e-08,
                                2.1542631727755662e-05,
                                4.9712928417251355e-06,
                                4.9712928417251355e-06,
                                4.9712928417251355e-06,
                                4.9712928417251355e-06,
                                0.0002604508286508981,
                                6.010302531539775e-05,
                                6.010302531539775e-05,
                                6.010302531539775e-05,
                                6.010302531539775e-05,
                                0.0007979276479866523,
                                0.00018413404893051464,
                                0.00018413404893051464,
                                0.00018413404893051464,
                                0.00018413404893051464,
                                0.00075128420264816,
                                0.00017337035817745355,
                                0.00017337035817745355,
                                0.00017337035817745355,
                                0.00017337035817745355,
                                7.536545410820513e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.7391735014379198e-08,
                                1.812466614183953e-05,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                4.182544834273682e-06,
                                0.00021912755949780044,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                5.056704685493891e-05,
                                0.0006713280163661793,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.00015491924126943298,
                                0.0006320850452589817,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                0.00014586332350512916,
                                3.7306796235320555e-08,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.6091157021171e-09,
                                8.971925328228136e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                2.0704094432087137e-06,
                                0.00010847074841465732,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                2.5031289674584837e-05,
                                0.00033231535336703156,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                7.668686715097989e-05,
                                0.0003128896158844069,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                7.220408013994907e-05,
                                4.434214489527491e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                1.0663858949035822e-05,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                0.000128926258174587,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                0.000394983676887654,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.0003718946166338926,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                8.957793816131233e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                2.154263172775566e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                0.000260450828650898,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.0007979276479866523,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.0007512842026481598,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                1.0647062503877745e-07,
                                5.3235312519388725e-08,
                                5.3235312519388725e-08,
                                5.3235312519388725e-08,
                                5.3235312519388725e-08,
                                2.5605160289623042e-05,
                                1.2802580144811521e-05,
                                1.2802580144811521e-05,
                                1.2802580144811521e-05,
                                1.2802580144811521e-05,
                                0.0003095668764823733,
                                0.00015478343824118664,
                                0.00015478343824118664,
                                0.00015478343824118664,
                                0.00015478343824118664,
                                0.0009484015502106288,
                                0.0004742007751053144,
                                0.0004742007751053144,
                                0.0004742007751053144,
                                0.0004742007751053144,
                                0.0008929620426590233,
                                0.00044648102132951165,
                                0.00044648102132951165,
                                0.00044648102132951165,
                                0.00044648102132951165,
                                8.957793816131233e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                4.478896908065616e-08,
                                2.154263172775566e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                1.077131586387783e-05,
                                0.000260450828650898,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.000130225414325449,
                                0.0007979276479866523,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.00039896382399332616,
                                0.0007512842026481598,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                0.0003756421013240799,
                                4.434214489527491e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                2.2171072447637454e-08,
                                1.0663858949035822e-05,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                5.331929474517911e-06,
                                0.000128926258174587,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                6.44631290872935e-05,
                                0.000394983676887654,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.000197491838443827,
                                0.0003718946166338926,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                0.0001859473083169463,
                                3.7306796235320555e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                8.971925328228136e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                0.00010847074841465732,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                0.00033231535336703156,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0003128896158844069,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                7.536545410820513e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                1.812466614183953e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                0.00021912755949780044,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.0006713280163661793,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0006320850452589817,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                8.957793816131235e-08,
                                6.890645436186187e-08,
                                6.890645436186187e-08,
                                6.890645436186187e-08,
                                6.890645436186187e-08,
                                2.1542631727755662e-05,
                                1.6571338886030526e-05,
                                1.6571338886030526e-05,
                                1.6571338886030526e-05,
                                1.6571338886030526e-05,
                                0.0002604508286508981,
                                0.0002003478033355003,
                                0.0002003478033355003,
                                0.0002003478033355003,
                                0.0002003478033355003,
                                0.0007979276479866523,
                                0.0006137935990561377,
                                0.0006137935990561377,
                                0.0006137935990561377,
                                0.0006137935990561377,
                                0.00075128420264816,
                                0.0005779138444707065,
                                0.0005779138444707065,
                                0.0005779138444707065,
                                0.0005779138444707065,
                                7.536545410820513e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                5.797371909382593e-08,
                                1.812466614183953e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                1.3942121307565846e-05,
                                0.00021912755949780044,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.00016856051264286154,
                                0.0006713280163661793,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0005164087750967462,
                                0.0006320850452589817,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                0.0004862217217538525,
                                3.7306796235320555e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                2.8697680533203452e-08,
                                8.971925328228136e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                6.901515885019422e-06,
                                0.00010847074841465732,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                8.343945874007248e-05,
                                0.00033231535336703156,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0002556284862160517,
                                0.0003128896158844069,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                0.0002406855357444578,
                                1.8467307890767437e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                4.441209756105985e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                5.369431069556538e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                0.0001645000527182208,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.00015488408160041112,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                3.7306796235320555e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                8.971925328228136e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                0.00010847074841465732,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00033231535336703156,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003128896158844069,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                4.434214489527492e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                4.226205146253253e-08,
                                1.0663858949035826e-05,
                                1.0163616504292376e-05,
                                1.0163616504292376e-05,
                                1.0163616504292376e-05,
                                1.0163616504292376e-05,
                                0.000128926258174587,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00012287831747234134,
                                0.00039498367688765417,
                                0.0003764549621789978,
                                0.0003764549621789978,
                                0.0003764549621789978,
                                0.0003764549621789978,
                                0.00037189461663389266,
                                0.000354449011520306,
                                0.000354449011520306,
                                0.000354449011520306,
                                0.000354449011520306,
                                3.7306796235320555e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                3.555673155015423e-08,
                                8.971925328228136e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                8.551051619967552e-06,
                                0.00010847074841465732,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00010338237725095153,
                                0.00033231535336703156,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003167264145421104,
                                0.0003128896158844069,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                0.0002982119399011732,
                                1.8467307890767437e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                1.760100505506247e-08,
                                4.441209756105985e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                4.232872264337699e-06,
                                5.369431069556538e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                5.1175506444727786e-05,
                                0.0001645000527182208,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.0001567833425736601,
                                0.00015488408160041112,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                                0.00014761845740171155,
                            ]
                        ),
                    )
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.VertexAdjacentTriangles:
            match order:
                case 1:
                    return (
                        np.array([[0.5, 0.25, 0.25], [0.75, 0.125, 0.125]]),
                        np.array([[0.75, 0.125, 0.125], [0.5, 0.25, 0.25]]),
                        np.array([0.0625, 0.0625]),
                    )
                case 2:
                    return (
                        np.array(
                            [
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.9553418012614796, 0.03522081090086453, 0.009437387837655933],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.9553418012614796, 0.009437387837655936, 0.03522081090086452],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.37799153207185376, 0.4905626121623441, 0.13144585576580217],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.37799153207185376, 0.13144585576580214, 0.4905626121623441],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.9553418012614796, 0.03522081090086453, 0.009437387837655933],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.9553418012614796, 0.009437387837655936, 0.03522081090086452],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.37799153207185376, 0.4905626121623441, 0.13144585576580217],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.37799153207185376, 0.13144585576580214, 0.4905626121623441],
                            ]
                        ),
                        np.array(
                            [
                                [0.9553418012614796, 0.03522081090086453, 0.009437387837655933],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.9553418012614796, 0.009437387837655936, 0.03522081090086452],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.37799153207185376, 0.4905626121623441, 0.13144585576580217],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.7886751345948129, 0.16666666666666669, 0.044658198738520456],
                                [0.37799153207185376, 0.13144585576580214, 0.4905626121623441],
                                [0.21132486540518713, 0.6220084679281461, 0.16666666666666669],
                                [0.9553418012614796, 0.03522081090086453, 0.009437387837655933],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.9553418012614796, 0.009437387837655936, 0.03522081090086452],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.8333333333333334, 0.13144585576580214, 0.03522081090086453],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.37799153207185376, 0.4905626121623441, 0.13144585576580217],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                                [0.8333333333333334, 0.03522081090086451, 0.13144585576580217],
                                [0.7886751345948129, 0.04465819873852045, 0.16666666666666669],
                                [0.37799153207185376, 0.13144585576580214, 0.4905626121623441],
                                [0.21132486540518713, 0.16666666666666663, 0.6220084679281462],
                            ]
                        ),
                        np.array(
                            [
                                0.00012464716966057438,
                                0.00012464716966057438,
                                0.006479254874251524,
                                0.006479254874251524,
                                0.00012464716966057438,
                                0.00012464716966057438,
                                0.006479254874251524,
                                0.006479254874251524,
                                0.00046518957019292144,
                                0.00046518957019292144,
                                0.02418090838589498,
                                0.02418090838589498,
                                0.00046518957019292144,
                                0.00046518957019292144,
                                0.02418090838589498,
                                0.02418090838589498,
                                0.00012464716966057438,
                                0.00012464716966057438,
                                0.006479254874251524,
                                0.006479254874251524,
                                0.00012464716966057438,
                                0.00012464716966057438,
                                0.006479254874251524,
                                0.006479254874251524,
                                0.00046518957019292144,
                                0.00046518957019292144,
                                0.02418090838589498,
                                0.02418090838589498,
                                0.00046518957019292144,
                                0.00046518957019292144,
                                0.02418090838589498,
                                0.02418090838589498,
                            ]
                        ),
                    )
                case 3:
                    return (
                        np.array(
                            [
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.75, 0.125, 0.125],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.5, 0.25, 0.25],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.5, 0.25, 0.25],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.5, 0.25, 0.25],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.5, 0.25, 0.25],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.5, 0.25, 0.25],
                                [0.75, 0.125, 0.125],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.5, 0.25, 0.25],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.5, 0.25, 0.25],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.5, 0.25, 0.25],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.5, 0.25, 0.25],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.75, 0.125, 0.125],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                            ]
                        ),
                        np.array(
                            [
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.8872983346207417, 0.09999999999999999, 0.012701665379258308],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5, 0.44364916731037085, 0.05635083268962915],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                                [0.1127016653792583, 0.7872983346207417, 0.09999999999999999],
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.5, 0.25, 0.25],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.5, 0.25, 0.25],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.5, 0.25, 0.25],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.5, 0.25, 0.25],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.5, 0.25, 0.25],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5, 0.25, 0.25],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5, 0.25, 0.25],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.8872983346207417, 0.05635083268962915, 0.05635083268962915],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5, 0.25, 0.25],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                                [0.1127016653792583, 0.44364916731037085, 0.44364916731037085],
                                [0.9872983346207417, 0.011270166537925829, 0.0014314988413324798],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9872983346207418, 0.006350832689629154, 0.006350832689629154],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9872983346207418, 0.0014314988413324792, 0.011270166537925829],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9436491673103709, 0.049999999999999996, 0.006350832689629154],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.75, 0.22182458365518543, 0.028175416344814574],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9436491673103709, 0.028175416344814574, 0.028175416344814574],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9436491673103709, 0.006350832689629153, 0.049999999999999996],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.75, 0.028175416344814574, 0.22182458365518543],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9, 0.08872983346207416, 0.011270166537925829],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.5563508326896291, 0.39364916731037086, 0.049999999999999996],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.21270166537925828, 0.6985685011586675, 0.08872983346207416],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.8999999999999999, 0.049999999999999996, 0.049999999999999996],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.5563508326896291, 0.22182458365518543, 0.22182458365518543],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.21270166537925833, 0.39364916731037086, 0.39364916731037086],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                                [0.9, 0.011270166537925827, 0.08872983346207416],
                                [0.8872983346207417, 0.012701665379258306, 0.09999999999999999],
                                [0.5563508326896291, 0.04999999999999999, 0.39364916731037086],
                                [0.5, 0.05635083268962915, 0.44364916731037085],
                                [0.21270166537925828, 0.08872983346207419, 0.6985685011586675],
                                [0.1127016653792583, 0.09999999999999998, 0.7872983346207417],
                            ]
                        ),
                        np.array(
                            [
                                9.605308797168476e-07,
                                9.605308797168476e-07,
                                0.0001341993233920829,
                                0.0001341993233920829,
                                0.00046873710099257357,
                                0.00046873710099257357,
                                1.5368494075469555e-06,
                                1.5368494075469555e-06,
                                0.00021471891742733262,
                                0.00021471891742733262,
                                0.0007499793615881174,
                                0.0007499793615881174,
                                9.605308797168476e-07,
                                9.605308797168476e-07,
                                0.0001341993233920829,
                                0.0001341993233920829,
                                0.00046873710099257357,
                                0.00046873710099257357,
                                6.818219599396437e-06,
                                6.818219599396437e-06,
                                0.000952598689224204,
                                0.000952598689224204,
                                0.0033272771926853187,
                                0.0033272771926853187,
                                1.0909151359034296e-05,
                                1.0909151359034296e-05,
                                0.0015241579027587258,
                                0.0015241579027587258,
                                0.0053236435082965085,
                                0.0053236435082965085,
                                6.818219599396437e-06,
                                6.818219599396437e-06,
                                0.000952598689224204,
                                0.000952598689224204,
                                0.0033272771926853187,
                                0.0033272771926853187,
                                7.562243619528701e-06,
                                7.562243619528701e-06,
                                0.0010565490381381725,
                                0.0010565490381381725,
                                0.003690359389864076,
                                0.003690359389864076,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                0.0016904784610210753,
                                0.0016904784610210753,
                                0.00590457502378252,
                                0.00590457502378252,
                                7.562243619528701e-06,
                                7.562243619528701e-06,
                                0.0010565490381381725,
                                0.0010565490381381725,
                                0.003690359389864076,
                                0.003690359389864076,
                                1.5368494075469555e-06,
                                1.5368494075469555e-06,
                                0.00021471891742733262,
                                0.00021471891742733262,
                                0.0007499793615881174,
                                0.0007499793615881174,
                                2.4589590520751282e-06,
                                2.4589590520751282e-06,
                                0.00034355026788373204,
                                0.00034355026788373204,
                                0.0011999669785409876,
                                0.0011999669785409876,
                                1.5368494075469555e-06,
                                1.5368494075469555e-06,
                                0.00021471891742733262,
                                0.00021471891742733262,
                                0.0007499793615881174,
                                0.0007499793615881174,
                                1.0909151359034298e-05,
                                1.0909151359034298e-05,
                                0.001524157902758726,
                                0.001524157902758726,
                                0.0053236435082965085,
                                0.0053236435082965085,
                                1.745464217445487e-05,
                                1.745464217445487e-05,
                                0.002438652644413961,
                                0.002438652644413961,
                                0.008517829613274411,
                                0.008517829613274411,
                                1.0909151359034298e-05,
                                1.0909151359034298e-05,
                                0.001524157902758726,
                                0.001524157902758726,
                                0.0053236435082965085,
                                0.0053236435082965085,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                0.0016904784610210753,
                                0.0016904784610210753,
                                0.00590457502378252,
                                0.00590457502378252,
                                1.9359343665993465e-05,
                                1.9359343665993465e-05,
                                0.0027047655376337197,
                                0.0027047655376337197,
                                0.009447320038052029,
                                0.009447320038052029,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                0.0016904784610210753,
                                0.0016904784610210753,
                                0.00590457502378252,
                                0.00590457502378252,
                                9.605308797168476e-07,
                                9.605308797168476e-07,
                                0.0001341993233920829,
                                0.0001341993233920829,
                                0.00046873710099257357,
                                0.00046873710099257357,
                                1.5368494075469555e-06,
                                1.5368494075469555e-06,
                                0.00021471891742733262,
                                0.00021471891742733262,
                                0.0007499793615881174,
                                0.0007499793615881174,
                                9.605308797168476e-07,
                                9.605308797168476e-07,
                                0.0001341993233920829,
                                0.0001341993233920829,
                                0.00046873710099257357,
                                0.00046873710099257357,
                                6.818219599396437e-06,
                                6.818219599396437e-06,
                                0.000952598689224204,
                                0.000952598689224204,
                                0.0033272771926853187,
                                0.0033272771926853187,
                                1.0909151359034296e-05,
                                1.0909151359034296e-05,
                                0.0015241579027587258,
                                0.0015241579027587258,
                                0.0053236435082965085,
                                0.0053236435082965085,
                                6.818219599396437e-06,
                                6.818219599396437e-06,
                                0.000952598689224204,
                                0.000952598689224204,
                                0.0033272771926853187,
                                0.0033272771926853187,
                                7.562243619528701e-06,
                                7.562243619528701e-06,
                                0.0010565490381381725,
                                0.0010565490381381725,
                                0.003690359389864076,
                                0.003690359389864076,
                                1.2099589791245917e-05,
                                1.2099589791245917e-05,
                                0.0016904784610210753,
                                0.0016904784610210753,
                                0.00590457502378252,
                                0.00590457502378252,
                                7.562243619528701e-06,
                                7.562243619528701e-06,
                                0.0010565490381381725,
                                0.0010565490381381725,
                                0.003690359389864076,
                                0.003690359389864076,
                            ]
                        ),
                    )
                case 4:
                    return (
                        np.array(
                            [
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                            ]
                        ),
                        np.array(
                            [
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970262, 0.0646110632135477, 0.004820780989426014],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.6699905217924282, 0.30709631153115907, 0.02291316667641278],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.33000947820757187, 0.6234718442658672, 0.046518677526560935],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.06943184420297377, 0.8659570925834785, 0.06461106321354769],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970263, 0.046518677526560935, 0.02291316667641278],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.6699905217924281, 0.22110322250073802, 0.10890625570683385],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.33000947820757187, 0.44888729929169013, 0.22110322250073802],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.06943184420297377, 0.6234718442658671, 0.30709631153115907],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970263, 0.02291316667641278, 0.046518677526560935],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.6699905217924281, 0.10890625570683385, 0.22110322250073802],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.33000947820757187, 0.221103222500738, 0.44888729929169013],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.06943184420297377, 0.3070963115311591, 0.6234718442658671],
                                [0.9951792190105739, 0.00448606527483153, 0.0003347157145944845],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9951792190105739, 0.003229877570552553, 0.0015909034188734612],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9951792190105739, 0.001590903418873461, 0.0032298775705525535],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9951792190105739, 0.00033471571459448447, 0.00448606527483153],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9770868333235873, 0.021322263257539317, 0.0015909034188734612],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.8910937442931661, 0.10134469352786775, 0.007561562178966105],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9770868333235873, 0.015351604497446674, 0.007561562178966105],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.8910937442931661, 0.07296615908748122, 0.035940096619352636],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9770868333235873, 0.007561562178966105, 0.015351604497446674],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.8910937442931661, 0.03594009661935263, 0.07296615908748122],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9770868333235873, 0.0015909034188734614, 0.021322263257539317],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.8910937442931662, 0.007561562178966114, 0.10134469352786774],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.953481322473439, 0.04328879995600838, 0.0032298775705525535],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.778896777499262, 0.20575161800329134, 0.015351604497446674],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.5511127007083099, 0.4177202262625759, 0.031167073029114263],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9534813224734391, 0.031167073029114263, 0.015351604497446674],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.7788967774992619, 0.1481370634132568, 0.07296615908748122],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.5511127007083099, 0.3007502358784333, 0.1481370634132568],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9534813224734391, 0.015351604497446675, 0.03116707302911426],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.7788967774992619, 0.07296615908748122, 0.1481370634132568],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.5511127007083099, 0.14813706341325683, 0.3007502358784333],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.953481322473439, 0.0032298775705525556, 0.04328879995600838],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.778896777499262, 0.015351604497446686, 0.20575161800329134],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.5511127007083099, 0.03116707302911431, 0.4177202262625758],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864523, 0.06012499793871616, 0.004486065274831529],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.692903688468841, 0.28577404827361974, 0.021322263257539317],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.3765281557341329, 0.5801830443098588, 0.04328879995600837],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.13404290741652147, 0.8058320946447624, 0.06012499793871617],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864523, 0.04328879995600837, 0.021322263257539314],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.692903688468841, 0.20575161800329134, 0.10134469352786774],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.3765281557341329, 0.41772022626257577, 0.2057516180032913],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.13404290741652147, 0.5801830443098588, 0.28577404827361974],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864524, 0.021322263257539317, 0.04328879995600837],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.6929036884688409, 0.10134469352786774, 0.20575161800329134],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.3765281557341329, 0.20575161800329134, 0.41772022626257577],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.13404290741652147, 0.28577404827361974, 0.5801830443098588],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                                [0.9353889367864523, 0.00448606527483153, 0.06012499793871616],
                                [0.9305681557970262, 0.004820780989426024, 0.06461106321354769],
                                [0.6929036884688409, 0.02132226325753933, 0.28577404827361974],
                                [0.669990521792428, 0.0229131666764128, 0.30709631153115907],
                                [0.3765281557341329, 0.04328879995600843, 0.5801830443098587],
                                [0.33000947820757187, 0.046518677526561025, 0.6234718442658671],
                                [0.13404290741652147, 0.060124997938716174, 0.8058320946447624],
                                [0.06943184420297377, 0.0646110632135477, 0.8659570925834785],
                            ]
                        ),
                        np.array(
                            [
                                2.1267040013685393e-08,
                                2.1267040013685393e-08,
                                4.281110140388254e-06,
                                4.281110140388254e-06,
                                3.582474744517011e-05,
                                3.582474744517011e-05,
                                5.120065373053888e-05,
                                5.120065373053888e-05,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                2.1267040013685393e-08,
                                2.1267040013685393e-08,
                                4.281110140388254e-06,
                                4.281110140388254e-06,
                                3.582474744517011e-05,
                                3.582474744517011e-05,
                                5.120065373053888e-05,
                                5.120065373053888e-05,
                                1.8950513213840648e-07,
                                1.8950513213840648e-07,
                                3.814787306231987e-05,
                                3.814787306231987e-05,
                                0.0003192251246084682,
                                0.0003192251246084682,
                                0.0004562358769501911,
                                0.0004562358769501911,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                1.8950513213840648e-07,
                                1.8950513213840648e-07,
                                3.814787306231987e-05,
                                3.814787306231987e-05,
                                0.0003192251246084682,
                                0.0003192251246084682,
                                0.0004562358769501911,
                                0.0004562358769501911,
                                3.847363507659424e-07,
                                3.847363507659424e-07,
                                7.744842213961772e-05,
                                7.744842213961772e-05,
                                0.0006480959545990797,
                                0.0006480959545990797,
                                0.0009262573757533704,
                                0.0009262573757533704,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                3.847363507659424e-07,
                                3.847363507659424e-07,
                                7.744842213961772e-05,
                                7.744842213961772e-05,
                                0.0006480959545990797,
                                0.0006480959545990797,
                                0.0009262573757533704,
                                0.0009262573757533704,
                                2.8503391249327023e-07,
                                2.8503391249327023e-07,
                                5.737806353607441e-05,
                                5.737806353607441e-05,
                                0.00048014523515304175,
                                0.00048014523515304175,
                                0.000686222560621385,
                                0.000686222560621385,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                2.8503391249327023e-07,
                                2.8503391249327023e-07,
                                5.737806353607441e-05,
                                5.737806353607441e-05,
                                0.00048014523515304175,
                                0.00048014523515304175,
                                0.000686222560621385,
                                0.000686222560621385,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                7.47479830629702e-08,
                                7.47479830629702e-08,
                                1.504696225043671e-05,
                                1.504696225043671e-05,
                                0.00012591444853367326,
                                0.00012591444853367326,
                                0.00017995666512126478,
                                0.00017995666512126478,
                                7.47479830629702e-08,
                                7.47479830629702e-08,
                                1.504696225043671e-05,
                                1.504696225043671e-05,
                                0.00012591444853367326,
                                0.00012591444853367326,
                                0.00017995666512126478,
                                0.00017995666512126478,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                6.660600816245342e-07,
                                6.660600816245342e-07,
                                0.00013407961652000887,
                                0.00013407961652000887,
                                0.0011219913157709503,
                                0.0011219913157709503,
                                0.0016035476296206268,
                                0.0016035476296206268,
                                6.660600816245342e-07,
                                6.660600816245342e-07,
                                0.00013407961652000887,
                                0.00013407961652000887,
                                0.0011219913157709503,
                                0.0011219913157709503,
                                0.0016035476296206268,
                                0.0016035476296206268,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                1.352245832624361e-06,
                                1.352245832624361e-06,
                                0.00027221058231989976,
                                0.00027221058231989976,
                                0.002277884717684161,
                                0.002277884717684161,
                                0.003255548049479884,
                                0.003255548049479884,
                                1.352245832624361e-06,
                                1.352245832624361e-06,
                                0.00027221058231989976,
                                0.00027221058231989976,
                                0.002277884717684161,
                                0.002277884717684161,
                                0.003255548049479884,
                                0.003255548049479884,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                1.0018183089752411e-06,
                                1.0018183089752411e-06,
                                0.0002016686157838892,
                                0.0002016686157838892,
                                0.0016875826575720066,
                                0.0016875826575720066,
                                0.0024118895862211033,
                                0.0024118895862211033,
                                1.0018183089752411e-06,
                                1.0018183089752411e-06,
                                0.0002016686157838892,
                                0.0002016686157838892,
                                0.0016875826575720066,
                                0.0016875826575720066,
                                0.0024118895862211033,
                                0.0024118895862211033,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                7.47479830629702e-08,
                                7.47479830629702e-08,
                                1.504696225043671e-05,
                                1.504696225043671e-05,
                                0.00012591444853367326,
                                0.00012591444853367326,
                                0.00017995666512126478,
                                0.00017995666512126478,
                                7.47479830629702e-08,
                                7.47479830629702e-08,
                                1.504696225043671e-05,
                                1.504696225043671e-05,
                                0.00012591444853367326,
                                0.00012591444853367326,
                                0.00017995666512126478,
                                0.00017995666512126478,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                6.660600816245342e-07,
                                6.660600816245342e-07,
                                0.00013407961652000887,
                                0.00013407961652000887,
                                0.0011219913157709503,
                                0.0011219913157709503,
                                0.0016035476296206268,
                                0.0016035476296206268,
                                6.660600816245342e-07,
                                6.660600816245342e-07,
                                0.00013407961652000887,
                                0.00013407961652000887,
                                0.0011219913157709503,
                                0.0011219913157709503,
                                0.0016035476296206268,
                                0.0016035476296206268,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                1.352245832624361e-06,
                                1.352245832624361e-06,
                                0.00027221058231989976,
                                0.00027221058231989976,
                                0.002277884717684161,
                                0.002277884717684161,
                                0.003255548049479884,
                                0.003255548049479884,
                                1.352245832624361e-06,
                                1.352245832624361e-06,
                                0.00027221058231989976,
                                0.00027221058231989976,
                                0.002277884717684161,
                                0.002277884717684161,
                                0.003255548049479884,
                                0.003255548049479884,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                1.0018183089752411e-06,
                                1.0018183089752411e-06,
                                0.0002016686157838892,
                                0.0002016686157838892,
                                0.0016875826575720066,
                                0.0016875826575720066,
                                0.0024118895862211033,
                                0.0024118895862211033,
                                1.0018183089752411e-06,
                                1.0018183089752411e-06,
                                0.0002016686157838892,
                                0.0002016686157838892,
                                0.0016875826575720066,
                                0.0016875826575720066,
                                0.0024118895862211033,
                                0.0024118895862211033,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                2.1267040013685393e-08,
                                2.1267040013685393e-08,
                                4.281110140388254e-06,
                                4.281110140388254e-06,
                                3.582474744517011e-05,
                                3.582474744517011e-05,
                                5.120065373053888e-05,
                                5.120065373053888e-05,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                3.9870645175899345e-08,
                                3.9870645175899345e-08,
                                8.026063958901888e-06,
                                8.026063958901888e-06,
                                6.716288646579086e-05,
                                6.716288646579086e-05,
                                9.598905613337604e-05,
                                9.598905613337604e-05,
                                2.1267040013685393e-08,
                                2.1267040013685393e-08,
                                4.281110140388254e-06,
                                4.281110140388254e-06,
                                3.582474744517011e-05,
                                3.582474744517011e-05,
                                5.120065373053888e-05,
                                5.120065373053888e-05,
                                1.8950513213840648e-07,
                                1.8950513213840648e-07,
                                3.814787306231987e-05,
                                3.814787306231987e-05,
                                0.0003192251246084682,
                                0.0003192251246084682,
                                0.0004562358769501911,
                                0.0004562358769501911,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                3.552770802913906e-07,
                                3.552770802913906e-07,
                                7.151819482656021e-05,
                                7.151819482656021e-05,
                                0.0005984712337168771,
                                0.0005984712337168771,
                                0.0008553338289997461,
                                0.0008553338289997461,
                                1.8950513213840648e-07,
                                1.8950513213840648e-07,
                                3.814787306231987e-05,
                                3.814787306231987e-05,
                                0.0003192251246084682,
                                0.0003192251246084682,
                                0.0004562358769501911,
                                0.0004562358769501911,
                                3.847363507659424e-07,
                                3.847363507659424e-07,
                                7.744842213961772e-05,
                                7.744842213961772e-05,
                                0.0006480959545990797,
                                0.0006480959545990797,
                                0.0009262573757533704,
                                0.0009262573757533704,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                7.212892117468208e-07,
                                7.212892117468208e-07,
                                0.0001451973832077657,
                                0.0001451973832077657,
                                0.001215025872388803,
                                0.001215025872388803,
                                0.0017365124223426222,
                                0.0017365124223426222,
                                3.847363507659424e-07,
                                3.847363507659424e-07,
                                7.744842213961772e-05,
                                7.744842213961772e-05,
                                0.0006480959545990797,
                                0.0006480959545990797,
                                0.0009262573757533704,
                                0.0009262573757533704,
                                2.8503391249327023e-07,
                                2.8503391249327023e-07,
                                5.737806353607441e-05,
                                5.737806353607441e-05,
                                0.00048014523515304175,
                                0.00048014523515304175,
                                0.000686222560621385,
                                0.000686222560621385,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                5.343708377284495e-07,
                                5.343708377284495e-07,
                                0.0001075702312430357,
                                0.0001075702312430357,
                                0.000900158192741757,
                                0.000900158192741757,
                                0.0012865041965701854,
                                0.0012865041965701854,
                                2.8503391249327023e-07,
                                2.8503391249327023e-07,
                                5.737806353607441e-05,
                                5.737806353607441e-05,
                                0.00048014523515304175,
                                0.00048014523515304175,
                                0.000686222560621385,
                                0.000686222560621385,
                            ]
                        ),
                    )
                case 5:
                    return (
                        np.array(
                            [
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.75, 0.125, 0.125],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.75, 0.125, 0.125],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.5, 0.25, 0.25],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.5, 0.25, 0.25],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.5, 0.25, 0.25],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.5, 0.25, 0.25],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.5, 0.25, 0.25],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.5, 0.25, 0.25],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.5, 0.25, 0.25],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.5, 0.25, 0.25],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.5, 0.25, 0.25],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.5, 0.25, 0.25],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.25, 0.25],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.25, 0.25],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.75, 0.125, 0.125],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.25, 0.25],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.25, 0.25],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.5, 0.25, 0.25],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.5, 0.25, 0.25],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.5, 0.25, 0.25],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.5, 0.25, 0.25],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.5, 0.25, 0.25],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.75, 0.125, 0.125],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.75, 0.125, 0.125],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                            ]
                        ),
                        np.array(
                            [
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.04470952170364481, 0.002200555327023207],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7692346550528415, 0.21994012483967856, 0.01082522010747988],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.5, 0.47654496148466596, 0.02345503851533401],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2307653449471585, 0.7331497981296533, 0.036084856923188136],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.046910077030668074, 0.9083804012656871, 0.04470952170364481],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.036084856923188136, 0.01082522010747988],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7692346550528415, 0.17751270051857743, 0.05325264442858103],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.5, 0.38461732752642075, 0.11538267247357922],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2307653449471585, 0.5917219545342641, 0.1775127005185774],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.046910077030668074, 0.7331497981296533, 0.21994012483967856],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.5, 0.25, 0.25],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.5, 0.25, 0.25],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.5, 0.25, 0.25],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.5, 0.25, 0.25],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.25, 0.25],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.25, 0.25],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.25, 0.25],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.25, 0.25],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.5, 0.25, 0.25],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.5, 0.25, 0.25],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.5, 0.25, 0.25],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.5, 0.25, 0.25],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.5, 0.25, 0.25],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.5, 0.25, 0.25],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.5, 0.25, 0.25],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.5, 0.25, 0.25],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.5, 0.25, 0.25],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.02345503851533401, 0.02345503851533401],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7692346550528415, 0.11538267247357922, 0.11538267247357922],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.5, 0.25, 0.25],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2307653449471585, 0.38461732752642075, 0.38461732752642075],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.046910077030668074, 0.47654496148466596, 0.47654496148466596],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.010825220107479883, 0.036084856923188136],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7692346550528416, 0.05325264442858105, 0.1775127005185774],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.5, 0.11538267247357925, 0.38461732752642075],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2307653449471585, 0.17751270051857748, 0.591721954534264],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.046910077030668074, 0.21994012483967862, 0.7331497981296533],
                                [0.9977994446729768, 0.0020973271071223014, 0.00010322821990090549],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9977994446729768, 0.0016927434179073897, 0.0005078119091158174],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9977994446729768, 0.0011002776635116035, 0.0011002776635116035],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9977994446729768, 0.0005078119091158175, 0.0016927434179073895],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9977994446729768, 0.00010322821990090556, 0.0020973271071223014],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9891747798925201, 0.010317408198364061, 0.0005078119091158175],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.946747355571419, 0.05075455877634952, 0.00249808565223151],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9891747798925201, 0.00832713445524837, 0.00249808565223151],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.946747355571419, 0.04096377956767115, 0.012288864860909876],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9891747798925201, 0.00541261005373994, 0.00541261005373994],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.946747355571419, 0.026626322214290513, 0.026626322214290513],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9891747798925201, 0.0024980856522315107, 0.008327134455248368],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.946747355571419, 0.012288864860909882, 0.040963779567671145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9891747798925201, 0.0005078119091158177, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.946747355571419, 0.002498085652231516, 0.05075455877634951],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.976544961484666, 0.022354760851822406, 0.0011002776635116035],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8846173275264207, 0.10997006241983928, 0.00541261005373994],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.75, 0.23827248074233298, 0.011727519257667005],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.976544961484666, 0.018042428461594068, 0.00541261005373994],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8846173275264207, 0.08875635025928871, 0.026626322214290513],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.75, 0.19230866376321037, 0.05769133623678961],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.976544961484666, 0.011727519257667005, 0.011727519257667005],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8846173275264209, 0.05769133623678961, 0.05769133623678961],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.75, 0.125, 0.125],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.976544961484666, 0.005412610053739941, 0.018042428461594068],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8846173275264207, 0.026626322214290524, 0.0887563502592887],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.75, 0.057691336236789625, 0.19230866376321037],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.976544961484666, 0.0011002776635116035, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8846173275264207, 0.005412610053739941, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.75, 0.011727519257667018, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9639151430768119, 0.03439211350528074, 0.0016927434179073895],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8224872994814226, 0.16918556606332902, 0.008327134455248368],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.6153826724735793, 0.36657489906482665, 0.018042428461594068],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.408278045465736, 0.5639642320663243, 0.027757722467939765],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9639151430768119, 0.02775772246793977, 0.008327134455248368],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8224872994814225, 0.13654892095090626, 0.040963779567671145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.6153826724735791, 0.29586097726713206, 0.0887563502592887],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.408278045465736, 0.4551730335833578, 0.13654892095090623],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9639151430768118, 0.018042428461594068, 0.018042428461594068],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8224872994814225, 0.0887563502592887, 0.0887563502592887],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.6153826724735794, 0.19230866376321037, 0.19230866376321037],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.408278045465736, 0.295860977267132, 0.295860977267132],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9639151430768119, 0.00832713445524837, 0.027757722467939765],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8224872994814226, 0.040963779567671166, 0.13654892095090623],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.6153826724735793, 0.08875635025928874, 0.295860977267132],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.40827804546573604, 0.13654892095090626, 0.45517303358335776],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9639151430768119, 0.0016927434179073927, 0.03439211350528074],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.8224872994814226, 0.00832713445524838, 0.16918556606332902],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.6153826724735793, 0.018042428461594096, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.408278045465736, 0.027757722467939838, 0.5639642320663242],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963552, 0.04261219459652251, 0.002097327107122302],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.7800598751603215, 0.2096227166413145, 0.010317408198364061],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.523455038515334, 0.45419020063284354, 0.022354760851822406],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.2668502018703467, 0.6987576846243726, 0.03439211350528074],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.09161959873431291, 0.8657682066691645, 0.042612194596522504],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963553, 0.03439211350528075, 0.010317408198364061],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.7800598751603215, 0.16918556606332905, 0.05075455877634952],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.523455038515334, 0.36657489906482665, 0.10997006241983928],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.2668502018703467, 0.5639642320663243, 0.16918556606332902],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.09161959873431291, 0.6987576846243726, 0.2096227166413145],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963552, 0.022354760851822406, 0.022354760851822406],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.7800598751603214, 0.10997006241983928, 0.10997006241983928],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.523455038515334, 0.23827248074233298, 0.23827248074233298],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.2668502018703467, 0.36657489906482665, 0.36657489906482665],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.09161959873431291, 0.45419020063284354, 0.45419020063284354],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963553, 0.010317408198364061, 0.03439211350528075],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.7800598751603215, 0.05075455877634952, 0.16918556606332905],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.523455038515334, 0.10997006241983931, 0.36657489906482665],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.2668502018703467, 0.16918556606332902, 0.5639642320663243],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.09161959873431291, 0.2096227166413145, 0.6987576846243726],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                                [0.9552904782963552, 0.002097327107122307, 0.042612194596522504],
                                [0.9530899229693319, 0.002200555327023207, 0.04470952170364481],
                                [0.7800598751603214, 0.010317408198364075, 0.2096227166413145],
                                [0.7692346550528415, 0.010825220107479883, 0.21994012483967856],
                                [0.523455038515334, 0.02235476085182242, 0.45419020063284354],
                                [0.5, 0.023455038515334037, 0.47654496148466596],
                                [0.2668502018703467, 0.03439211350528082, 0.6987576846243725],
                                [0.2307653449471585, 0.03608485692318819, 0.7331497981296533],
                                [0.09161959873431291, 0.042612194596522546, 0.8657682066691645],
                                [0.046910077030668074, 0.04470952170364484, 0.9083804012656871],
                            ]
                        ),
                        np.array(
                            [
                                9.53678474896536e-10,
                                9.53678474896536e-10,
                                2.293504917961684e-07,
                                2.293504917961684e-07,
                                2.772851822130939e-06,
                                2.772851822130939e-06,
                                8.49502051542355e-06,
                                8.49502051542355e-06,
                                7.998437866532609e-06,
                                7.998437866532609e-06,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                2.2898924611804724e-09,
                                2.2898924611804724e-09,
                                5.506970912697355e-07,
                                5.506970912697355e-07,
                                6.6579383414908584e-06,
                                6.6579383414908584e-06,
                                2.03975280431408e-05,
                                2.03975280431408e-05,
                                1.9205175595245023e-05,
                                1.9205175595245023e-05,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                9.53678474896536e-10,
                                9.53678474896536e-10,
                                2.293504917961684e-07,
                                2.293504917961684e-07,
                                2.772851822130939e-06,
                                2.772851822130939e-06,
                                8.49502051542355e-06,
                                8.49502051542355e-06,
                                7.998437866532609e-06,
                                7.998437866532609e-06,
                                9.477434442796908e-09,
                                9.477434442796908e-09,
                                2.2792317407155854e-06,
                                2.2792317407155854e-06,
                                2.7555955236052672e-05,
                                2.7555955236052672e-05,
                                8.442153424284435e-05,
                                8.442153424284435e-05,
                                7.948661159943993e-05,
                                7.948661159943993e-05,
                                1.9145872136988548e-08,
                                1.9145872136988548e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                5.5667258765690645e-05,
                                5.5667258765690645e-05,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.00016057515475002683,
                                0.00016057515475002683,
                                2.275641765349403e-08,
                                2.275641765349403e-08,
                                5.472699361190984e-06,
                                5.472699361190984e-06,
                                6.616503970324934e-05,
                                6.616503970324934e-05,
                                0.00020270588034919338,
                                0.00020270588034919338,
                                0.00019085655958218478,
                                0.00019085655958218478,
                                1.9145872136988548e-08,
                                1.9145872136988548e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                5.5667258765690645e-05,
                                5.5667258765690645e-05,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.00016057515475002683,
                                0.00016057515475002683,
                                9.477434442796908e-09,
                                9.477434442796908e-09,
                                2.2792317407155854e-06,
                                2.2792317407155854e-06,
                                2.7555955236052672e-05,
                                2.7555955236052672e-05,
                                8.442153424284435e-05,
                                8.442153424284435e-05,
                                7.948661159943993e-05,
                                7.948661159943993e-05,
                                2.440725539294497e-08,
                                2.440725539294497e-08,
                                5.869709944301633e-06,
                                5.869709944301633e-06,
                                7.096490522855197e-05,
                                7.096490522855197e-05,
                                0.00021741094168109835,
                                0.00021741094168109835,
                                0.00020470202577891112,
                                0.00020470202577891112,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                5.8604646737439054e-08,
                                5.8604646737439054e-08,
                                1.4093853331680334e-05,
                                1.4093853331680334e-05,
                                0.00017039495570965636,
                                0.00017039495570965636,
                                0.0005220288487560819,
                                0.0005220288487560819,
                                0.0004915132698893654,
                                0.0004915132698893654,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                2.440725539294497e-08,
                                2.440725539294497e-08,
                                5.869709944301633e-06,
                                5.869709944301633e-06,
                                7.096490522855197e-05,
                                7.096490522855197e-05,
                                0.00021741094168109835,
                                0.00021741094168109835,
                                0.00020470202577891112,
                                0.00020470202577891112,
                                3.159213969523967e-08,
                                3.159213969523967e-08,
                                7.597605447457069e-06,
                                7.597605447457069e-06,
                                9.18551948322669e-05,
                                9.18551948322669e-05,
                                0.0002814112742413565,
                                0.0002814112742413565,
                                0.000264961172003601,
                                0.000264961172003601,
                                6.382097083231711e-08,
                                6.382097083231711e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                0.00018556159116599018,
                                0.00018556159116599018,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0005352622327346319,
                                0.0005352622327346319,
                                7.585638600948615e-08,
                                7.585638600948615e-08,
                                1.8242730537714085e-05,
                                1.8242730537714085e-05,
                                0.00022055496029675098,
                                0.00022055496029675098,
                                0.0006757010589406283,
                                0.0006757010589406283,
                                0.0006362024584254275,
                                0.0006362024584254275,
                                6.382097083231711e-08,
                                6.382097083231711e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                0.00018556159116599018,
                                0.00018556159116599018,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0005352622327346319,
                                0.0005352622327346319,
                                3.159213969523967e-08,
                                3.159213969523967e-08,
                                7.597605447457069e-06,
                                7.597605447457069e-06,
                                9.18551948322669e-05,
                                9.18551948322669e-05,
                                0.0002814112742413565,
                                0.0002814112742413565,
                                0.000264961172003601,
                                0.000264961172003601,
                                1.9376249234944087e-08,
                                1.9376249234944087e-08,
                                4.659801398664974e-06,
                                4.659801398664974e-06,
                                5.6337087825125535e-05,
                                5.6337087825125535e-05,
                                0.00017259657116688875,
                                0.00017259657116688875,
                                0.0001625073121304997,
                                0.0001625073121304997,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                4.652461832470948e-08,
                                4.652461832470948e-08,
                                1.1188722797333533e-05,
                                1.1188722797333533e-05,
                                0.0001352718721156131,
                                0.0001352718721156131,
                                0.00041442435531905607,
                                0.00041442435531905607,
                                0.00039019887596257723,
                                0.00039019887596257723,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                1.9376249234944087e-08,
                                1.9376249234944087e-08,
                                4.659801398664974e-06,
                                4.659801398664974e-06,
                                5.6337087825125535e-05,
                                5.6337087825125535e-05,
                                0.00017259657116688875,
                                0.00017259657116688875,
                                0.0001625073121304997,
                                0.0001625073121304997,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                3.891980994681466e-09,
                                3.891980994681466e-09,
                                9.359839596761115e-07,
                                9.359839596761115e-07,
                                1.1316063932314603e-05,
                                1.1316063932314603e-05,
                                3.466834920337752e-05,
                                3.466834920337752e-05,
                                3.2641785447724135e-05,
                                3.2641785447724135e-05,
                                4.625934216040542e-09,
                                4.625934216040542e-09,
                                1.1124926433730444e-06,
                                1.1124926433730444e-06,
                                1.345005728623315e-05,
                                1.345005728623315e-05,
                                4.120613718635886e-05,
                                4.120613718635886e-05,
                                3.879740224364574e-05,
                                3.879740224364574e-05,
                                3.891980994681466e-09,
                                3.891980994681466e-09,
                                9.359839596761115e-07,
                                9.359839596761115e-07,
                                1.1316063932314603e-05,
                                1.1316063932314603e-05,
                                3.466834920337752e-05,
                                3.466834920337752e-05,
                                3.2641785447724135e-05,
                                3.2641785447724135e-05,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                1.9145872136988545e-08,
                                1.9145872136988545e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                5.566725876569064e-05,
                                5.566725876569064e-05,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0001605751547500268,
                                0.0001605751547500268,
                                3.867760015628625e-08,
                                3.867760015628625e-08,
                                9.301590473982536e-06,
                                9.301590473982536e-06,
                                0.00011245640631728155,
                                0.00011245640631728155,
                                0.0003445259754349043,
                                0.0003445259754349043,
                                0.00032438645709206127,
                                0.00032438645709206127,
                                4.597145623316258e-08,
                                4.597145623316258e-08,
                                1.1055692639813157e-05,
                                1.1055692639813157e-05,
                                0.00013366353497279776,
                                0.00013366353497279776,
                                0.0004094969888745578,
                                0.0004094969888745578,
                                0.00038555954233408254,
                                0.00038555954233408254,
                                3.867760015628625e-08,
                                3.867760015628625e-08,
                                9.301590473982536e-06,
                                9.301590473982536e-06,
                                0.00011245640631728155,
                                0.00011245640631728155,
                                0.0003445259754349043,
                                0.0003445259754349043,
                                0.00032438645709206127,
                                0.00032438645709206127,
                                1.9145872136988545e-08,
                                1.9145872136988545e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                5.566725876569064e-05,
                                5.566725876569064e-05,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0001605751547500268,
                                0.0001605751547500268,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                9.960649906876032e-08,
                                9.960649906876032e-08,
                                2.3954404077320908e-05,
                                2.3954404077320908e-05,
                                0.00028960920237699594,
                                0.00028960920237699594,
                                0.000887258416051002,
                                0.000887258416051002,
                                0.0008353930752088652,
                                0.0008353930752088652,
                                1.1839038083995065e-07,
                                1.1839038083995065e-07,
                                2.8471746803894416e-05,
                                2.8471746803894416e-05,
                                0.00034422396213823296,
                                0.00034422396213823296,
                                0.0010545783935967507,
                                0.0010545783935967507,
                                0.0009929322408647324,
                                0.0009929322408647324,
                                9.960649906876032e-08,
                                9.960649906876032e-08,
                                2.3954404077320908e-05,
                                2.3954404077320908e-05,
                                0.00028960920237699594,
                                0.00028960920237699594,
                                0.000887258416051002,
                                0.000887258416051002,
                                0.0008353930752088652,
                                0.0008353930752088652,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                6.38209708323171e-08,
                                6.38209708323171e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                0.00018556159116599015,
                                0.00018556159116599015,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0005352622327346318,
                                0.0005352622327346318,
                                1.289281560942582e-07,
                                1.289281560942582e-07,
                                3.100598030148399e-05,
                                3.100598030148399e-05,
                                0.000374862893480668,
                                0.000374862893480668,
                                0.0011484450576021194,
                                0.0011484450576021194,
                                0.001081311860245581,
                                0.001081311860245581,
                                1.5324154190435804e-07,
                                1.5324154190435804e-07,
                                3.6853115514828654e-05,
                                3.6853115514828654e-05,
                                0.0004455548697811941,
                                0.0004455548697811941,
                                0.001365019843227446,
                                0.001365019843227446,
                                0.0012852266080836479,
                                0.0012852266080836479,
                                1.289281560942582e-07,
                                1.289281560942582e-07,
                                3.100598030148399e-05,
                                3.100598030148399e-05,
                                0.000374862893480668,
                                0.000374862893480668,
                                0.0011484450576021194,
                                0.0011484450576021194,
                                0.001081311860245581,
                                0.001081311860245581,
                                6.38209708323171e-08,
                                6.38209708323171e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                0.00018556159116599015,
                                0.00018556159116599015,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0005352622327346318,
                                0.0005352622327346318,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                7.907486197462419e-08,
                                7.907486197462419e-08,
                                1.9016743021867766e-05,
                                1.9016743021867766e-05,
                                0.0002299127859993662,
                                0.0002299127859993662,
                                0.0007043700706379003,
                                0.0007043700706379003,
                                0.0006631956020369346,
                                0.0006631956020369346,
                                9.398686944693963e-08,
                                9.398686944693963e-08,
                                2.2602937255532027e-05,
                                2.2602937255532027e-05,
                                0.00027326994271376716,
                                0.00027326994271376716,
                                0.0008372008021034628,
                                0.0008372008021034628,
                                0.0007882616157639666,
                                0.0007882616157639666,
                                7.907486197462419e-08,
                                7.907486197462419e-08,
                                1.9016743021867766e-05,
                                1.9016743021867766e-05,
                                0.0002299127859993662,
                                0.0002299127859993662,
                                0.0007043700706379003,
                                0.0007043700706379003,
                                0.0006631956020369346,
                                0.0006631956020369346,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                2.289892461180472e-09,
                                2.289892461180472e-09,
                                5.506970912697354e-07,
                                5.506970912697354e-07,
                                6.657938341490857e-06,
                                6.657938341490857e-06,
                                2.0397528043140793e-05,
                                2.0397528043140793e-05,
                                1.9205175595245023e-05,
                                1.9205175595245023e-05,
                                4.62593421604054e-09,
                                4.62593421604054e-09,
                                1.1124926433730441e-06,
                                1.1124926433730441e-06,
                                1.3450057286233147e-05,
                                1.3450057286233147e-05,
                                4.120613718635886e-05,
                                4.120613718635886e-05,
                                3.879740224364573e-05,
                                3.879740224364573e-05,
                                5.498296985616707e-09,
                                5.498296985616707e-09,
                                1.3222874908961231e-06,
                                1.3222874908961231e-06,
                                1.598648099595449e-05,
                                1.598648099595449e-05,
                                4.897682701475749e-05,
                                4.897682701475749e-05,
                                4.6113850704211296e-05,
                                4.6113850704211296e-05,
                                4.62593421604054e-09,
                                4.62593421604054e-09,
                                1.1124926433730441e-06,
                                1.1124926433730441e-06,
                                1.3450057286233147e-05,
                                1.3450057286233147e-05,
                                4.120613718635886e-05,
                                4.120613718635886e-05,
                                3.879740224364573e-05,
                                3.879740224364573e-05,
                                2.289892461180472e-09,
                                2.289892461180472e-09,
                                5.506970912697354e-07,
                                5.506970912697354e-07,
                                6.657938341490857e-06,
                                6.657938341490857e-06,
                                2.0397528043140793e-05,
                                2.0397528043140793e-05,
                                1.9205175595245023e-05,
                                1.9205175595245023e-05,
                                2.2756417653494025e-08,
                                2.2756417653494025e-08,
                                5.472699361190983e-06,
                                5.472699361190983e-06,
                                6.616503970324934e-05,
                                6.616503970324934e-05,
                                0.00020270588034919336,
                                0.00020270588034919336,
                                0.00019085655958218472,
                                0.00019085655958218472,
                                4.597145623316258e-08,
                                4.597145623316258e-08,
                                1.1055692639813157e-05,
                                1.1055692639813157e-05,
                                0.00013366353497279776,
                                0.00013366353497279776,
                                0.0004094969888745578,
                                0.0004094969888745578,
                                0.00038555954233408254,
                                0.00038555954233408254,
                                5.4640794145913336e-08,
                                5.4640794145913336e-08,
                                1.3140584944897701e-05,
                                1.3140584944897701e-05,
                                0.00015886992272381387,
                                0.00015886992272381387,
                                0.0004867202935443488,
                                0.0004867202935443488,
                                0.00045826870214461,
                                0.00045826870214461,
                                4.597145623316258e-08,
                                4.597145623316258e-08,
                                1.1055692639813157e-05,
                                1.1055692639813157e-05,
                                0.00013366353497279776,
                                0.00013366353497279776,
                                0.0004094969888745578,
                                0.0004094969888745578,
                                0.00038555954233408254,
                                0.00038555954233408254,
                                2.2756417653494025e-08,
                                2.2756417653494025e-08,
                                5.472699361190983e-06,
                                5.472699361190983e-06,
                                6.616503970324934e-05,
                                6.616503970324934e-05,
                                0.00020270588034919336,
                                0.00020270588034919336,
                                0.00019085655958218472,
                                0.00019085655958218472,
                                5.860464673743906e-08,
                                5.860464673743906e-08,
                                1.4093853331680334e-05,
                                1.4093853331680334e-05,
                                0.0001703949557096564,
                                0.0001703949557096564,
                                0.000522028848756082,
                                0.000522028848756082,
                                0.0004915132698893654,
                                0.0004915132698893654,
                                1.1839038083995065e-07,
                                1.1839038083995065e-07,
                                2.8471746803894416e-05,
                                2.8471746803894416e-05,
                                0.00034422396213823296,
                                0.00034422396213823296,
                                0.0010545783935967507,
                                0.0010545783935967507,
                                0.0009929322408647324,
                                0.0009929322408647324,
                                1.4071654366401172e-07,
                                1.4071654366401172e-07,
                                3.3840974020829617e-05,
                                3.3840974020829617e-05,
                                0.0004091380216430425,
                                0.0004091380216430425,
                                0.0012534517206283392,
                                0.0012534517206283392,
                                0.0011801802818417674,
                                0.0011801802818417674,
                                1.1839038083995065e-07,
                                1.1839038083995065e-07,
                                2.8471746803894416e-05,
                                2.8471746803894416e-05,
                                0.00034422396213823296,
                                0.00034422396213823296,
                                0.0010545783935967507,
                                0.0010545783935967507,
                                0.0009929322408647324,
                                0.0009929322408647324,
                                5.860464673743906e-08,
                                5.860464673743906e-08,
                                1.4093853331680334e-05,
                                1.4093853331680334e-05,
                                0.0001703949557096564,
                                0.0001703949557096564,
                                0.000522028848756082,
                                0.000522028848756082,
                                0.0004915132698893654,
                                0.0004915132698893654,
                                7.585638600948612e-08,
                                7.585638600948612e-08,
                                1.8242730537714085e-05,
                                1.8242730537714085e-05,
                                0.00022055496029675095,
                                0.00022055496029675095,
                                0.0006757010589406282,
                                0.0006757010589406282,
                                0.0006362024584254273,
                                0.0006362024584254273,
                                1.5324154190435804e-07,
                                1.5324154190435804e-07,
                                3.6853115514828654e-05,
                                3.6853115514828654e-05,
                                0.0004455548697811941,
                                0.0004455548697811941,
                                0.001365019843227446,
                                0.001365019843227446,
                                0.0012852266080836479,
                                0.0012852266080836479,
                                1.8213996753398794e-07,
                                1.8213996753398794e-07,
                                4.3802908662891124e-05,
                                4.3802908662891124e-05,
                                0.000529578001552652,
                                0.000529578001552652,
                                0.0016224364936491525,
                                0.0016224364936491525,
                                0.0015275957795848547,
                                0.0015275957795848547,
                                1.5324154190435804e-07,
                                1.5324154190435804e-07,
                                3.6853115514828654e-05,
                                3.6853115514828654e-05,
                                0.0004455548697811941,
                                0.0004455548697811941,
                                0.001365019843227446,
                                0.001365019843227446,
                                0.0012852266080836479,
                                0.0012852266080836479,
                                7.585638600948612e-08,
                                7.585638600948612e-08,
                                1.8242730537714085e-05,
                                1.8242730537714085e-05,
                                0.00022055496029675095,
                                0.00022055496029675095,
                                0.0006757010589406282,
                                0.0006757010589406282,
                                0.0006362024584254273,
                                0.0006362024584254273,
                                4.6524618324709464e-08,
                                4.6524618324709464e-08,
                                1.118872279733353e-05,
                                1.118872279733353e-05,
                                0.00013527187211561308,
                                0.00013527187211561308,
                                0.0004144243553190559,
                                0.0004144243553190559,
                                0.0003901988759625772,
                                0.0003901988759625772,
                                9.39868694469396e-08,
                                9.39868694469396e-08,
                                2.2602937255532023e-05,
                                2.2602937255532023e-05,
                                0.0002732699427137671,
                                0.0002732699427137671,
                                0.0008372008021034628,
                                0.0008372008021034628,
                                0.0007882616157639664,
                                0.0007882616157639664,
                                1.117109964892614e-07,
                                1.117109964892614e-07,
                                2.686541917246454e-05,
                                2.686541917246454e-05,
                                0.0003248034304233582,
                                0.0003248034304233582,
                                0.0009950808704974063,
                                0.0009950808704974063,
                                0.0009369126890745194,
                                0.0009369126890745194,
                                9.39868694469396e-08,
                                9.39868694469396e-08,
                                2.2602937255532023e-05,
                                2.2602937255532023e-05,
                                0.0002732699427137671,
                                0.0002732699427137671,
                                0.0008372008021034628,
                                0.0008372008021034628,
                                0.0007882616157639664,
                                0.0007882616157639664,
                                4.6524618324709464e-08,
                                4.6524618324709464e-08,
                                1.118872279733353e-05,
                                1.118872279733353e-05,
                                0.00013527187211561308,
                                0.00013527187211561308,
                                0.0004144243553190559,
                                0.0004144243553190559,
                                0.0003901988759625772,
                                0.0003901988759625772,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                3.891980994681466e-09,
                                3.891980994681466e-09,
                                9.359839596761115e-07,
                                9.359839596761115e-07,
                                1.1316063932314603e-05,
                                1.1316063932314603e-05,
                                3.466834920337752e-05,
                                3.466834920337752e-05,
                                3.2641785447724135e-05,
                                3.2641785447724135e-05,
                                4.625934216040542e-09,
                                4.625934216040542e-09,
                                1.1124926433730444e-06,
                                1.1124926433730444e-06,
                                1.345005728623315e-05,
                                1.345005728623315e-05,
                                4.120613718635886e-05,
                                4.120613718635886e-05,
                                3.879740224364574e-05,
                                3.879740224364574e-05,
                                3.891980994681466e-09,
                                3.891980994681466e-09,
                                9.359839596761115e-07,
                                9.359839596761115e-07,
                                1.1316063932314603e-05,
                                1.1316063932314603e-05,
                                3.466834920337752e-05,
                                3.466834920337752e-05,
                                3.2641785447724135e-05,
                                3.2641785447724135e-05,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                1.9145872136988545e-08,
                                1.9145872136988545e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                5.566725876569064e-05,
                                5.566725876569064e-05,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0001605751547500268,
                                0.0001605751547500268,
                                3.867760015628625e-08,
                                3.867760015628625e-08,
                                9.301590473982536e-06,
                                9.301590473982536e-06,
                                0.00011245640631728155,
                                0.00011245640631728155,
                                0.0003445259754349043,
                                0.0003445259754349043,
                                0.00032438645709206127,
                                0.00032438645709206127,
                                4.597145623316258e-08,
                                4.597145623316258e-08,
                                1.1055692639813157e-05,
                                1.1055692639813157e-05,
                                0.00013366353497279776,
                                0.00013366353497279776,
                                0.0004094969888745578,
                                0.0004094969888745578,
                                0.00038555954233408254,
                                0.00038555954233408254,
                                3.867760015628625e-08,
                                3.867760015628625e-08,
                                9.301590473982536e-06,
                                9.301590473982536e-06,
                                0.00011245640631728155,
                                0.00011245640631728155,
                                0.0003445259754349043,
                                0.0003445259754349043,
                                0.00032438645709206127,
                                0.00032438645709206127,
                                1.9145872136988545e-08,
                                1.9145872136988545e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                5.566725876569064e-05,
                                5.566725876569064e-05,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.0001605751547500268,
                                0.0001605751547500268,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                9.960649906876032e-08,
                                9.960649906876032e-08,
                                2.3954404077320908e-05,
                                2.3954404077320908e-05,
                                0.00028960920237699594,
                                0.00028960920237699594,
                                0.000887258416051002,
                                0.000887258416051002,
                                0.0008353930752088652,
                                0.0008353930752088652,
                                1.1839038083995065e-07,
                                1.1839038083995065e-07,
                                2.8471746803894416e-05,
                                2.8471746803894416e-05,
                                0.00034422396213823296,
                                0.00034422396213823296,
                                0.0010545783935967507,
                                0.0010545783935967507,
                                0.0009929322408647324,
                                0.0009929322408647324,
                                9.960649906876032e-08,
                                9.960649906876032e-08,
                                2.3954404077320908e-05,
                                2.3954404077320908e-05,
                                0.00028960920237699594,
                                0.00028960920237699594,
                                0.000887258416051002,
                                0.000887258416051002,
                                0.0008353930752088652,
                                0.0008353930752088652,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                6.38209708323171e-08,
                                6.38209708323171e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                0.00018556159116599015,
                                0.00018556159116599015,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0005352622327346318,
                                0.0005352622327346318,
                                1.289281560942582e-07,
                                1.289281560942582e-07,
                                3.100598030148399e-05,
                                3.100598030148399e-05,
                                0.000374862893480668,
                                0.000374862893480668,
                                0.0011484450576021194,
                                0.0011484450576021194,
                                0.001081311860245581,
                                0.001081311860245581,
                                1.5324154190435804e-07,
                                1.5324154190435804e-07,
                                3.6853115514828654e-05,
                                3.6853115514828654e-05,
                                0.0004455548697811941,
                                0.0004455548697811941,
                                0.001365019843227446,
                                0.001365019843227446,
                                0.0012852266080836479,
                                0.0012852266080836479,
                                1.289281560942582e-07,
                                1.289281560942582e-07,
                                3.100598030148399e-05,
                                3.100598030148399e-05,
                                0.000374862893480668,
                                0.000374862893480668,
                                0.0011484450576021194,
                                0.0011484450576021194,
                                0.001081311860245581,
                                0.001081311860245581,
                                6.38209708323171e-08,
                                6.38209708323171e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                0.00018556159116599015,
                                0.00018556159116599015,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0005352622327346318,
                                0.0005352622327346318,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                7.907486197462419e-08,
                                7.907486197462419e-08,
                                1.9016743021867766e-05,
                                1.9016743021867766e-05,
                                0.0002299127859993662,
                                0.0002299127859993662,
                                0.0007043700706379003,
                                0.0007043700706379003,
                                0.0006631956020369346,
                                0.0006631956020369346,
                                9.398686944693963e-08,
                                9.398686944693963e-08,
                                2.2602937255532027e-05,
                                2.2602937255532027e-05,
                                0.00027326994271376716,
                                0.00027326994271376716,
                                0.0008372008021034628,
                                0.0008372008021034628,
                                0.0007882616157639666,
                                0.0007882616157639666,
                                7.907486197462419e-08,
                                7.907486197462419e-08,
                                1.9016743021867766e-05,
                                1.9016743021867766e-05,
                                0.0002299127859993662,
                                0.0002299127859993662,
                                0.0007043700706379003,
                                0.0007043700706379003,
                                0.0006631956020369346,
                                0.0006631956020369346,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                9.53678474896536e-10,
                                9.53678474896536e-10,
                                2.293504917961684e-07,
                                2.293504917961684e-07,
                                2.772851822130939e-06,
                                2.772851822130939e-06,
                                8.49502051542355e-06,
                                8.49502051542355e-06,
                                7.998437866532609e-06,
                                7.998437866532609e-06,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                2.2898924611804724e-09,
                                2.2898924611804724e-09,
                                5.506970912697355e-07,
                                5.506970912697355e-07,
                                6.6579383414908584e-06,
                                6.6579383414908584e-06,
                                2.03975280431408e-05,
                                2.03975280431408e-05,
                                1.9205175595245023e-05,
                                1.9205175595245023e-05,
                                1.926576886432027e-09,
                                1.926576886432027e-09,
                                4.633231933165457e-07,
                                4.633231933165457e-07,
                                5.60158624802553e-06,
                                5.60158624802553e-06,
                                1.7161245226339483e-05,
                                1.7161245226339483e-05,
                                1.615807206186152e-05,
                                1.615807206186152e-05,
                                9.53678474896536e-10,
                                9.53678474896536e-10,
                                2.293504917961684e-07,
                                2.293504917961684e-07,
                                2.772851822130939e-06,
                                2.772851822130939e-06,
                                8.49502051542355e-06,
                                8.49502051542355e-06,
                                7.998437866532609e-06,
                                7.998437866532609e-06,
                                9.477434442796908e-09,
                                9.477434442796908e-09,
                                2.2792317407155854e-06,
                                2.2792317407155854e-06,
                                2.7555955236052672e-05,
                                2.7555955236052672e-05,
                                8.442153424284435e-05,
                                8.442153424284435e-05,
                                7.948661159943993e-05,
                                7.948661159943993e-05,
                                1.9145872136988548e-08,
                                1.9145872136988548e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                5.5667258765690645e-05,
                                5.5667258765690645e-05,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.00016057515475002683,
                                0.00016057515475002683,
                                2.275641765349403e-08,
                                2.275641765349403e-08,
                                5.472699361190984e-06,
                                5.472699361190984e-06,
                                6.616503970324934e-05,
                                6.616503970324934e-05,
                                0.00020270588034919338,
                                0.00020270588034919338,
                                0.00019085655958218478,
                                0.00019085655958218478,
                                1.9145872136988548e-08,
                                1.9145872136988548e-08,
                                4.604397924532448e-06,
                                4.604397924532448e-06,
                                5.5667258765690645e-05,
                                5.5667258765690645e-05,
                                0.0001705444558838754,
                                0.0001705444558838754,
                                0.00016057515475002683,
                                0.00016057515475002683,
                                9.477434442796908e-09,
                                9.477434442796908e-09,
                                2.2792317407155854e-06,
                                2.2792317407155854e-06,
                                2.7555955236052672e-05,
                                2.7555955236052672e-05,
                                8.442153424284435e-05,
                                8.442153424284435e-05,
                                7.948661159943993e-05,
                                7.948661159943993e-05,
                                2.440725539294497e-08,
                                2.440725539294497e-08,
                                5.869709944301633e-06,
                                5.869709944301633e-06,
                                7.096490522855197e-05,
                                7.096490522855197e-05,
                                0.00021741094168109835,
                                0.00021741094168109835,
                                0.00020470202577891112,
                                0.00020470202577891112,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                5.8604646737439054e-08,
                                5.8604646737439054e-08,
                                1.4093853331680334e-05,
                                1.4093853331680334e-05,
                                0.00017039495570965636,
                                0.00017039495570965636,
                                0.0005220288487560819,
                                0.0005220288487560819,
                                0.0004915132698893654,
                                0.0004915132698893654,
                                4.9306401831490075e-08,
                                4.9306401831490075e-08,
                                1.1857714949452534e-05,
                                1.1857714949452534e-05,
                                0.00014336000000000015,
                                0.00014336000000000015,
                                0.00043920346964491084,
                                0.00043920346964491084,
                                0.00041352950900380605,
                                0.00041352950900380605,
                                2.440725539294497e-08,
                                2.440725539294497e-08,
                                5.869709944301633e-06,
                                5.869709944301633e-06,
                                7.096490522855197e-05,
                                7.096490522855197e-05,
                                0.00021741094168109835,
                                0.00021741094168109835,
                                0.00020470202577891112,
                                0.00020470202577891112,
                                3.159213969523967e-08,
                                3.159213969523967e-08,
                                7.597605447457069e-06,
                                7.597605447457069e-06,
                                9.18551948322669e-05,
                                9.18551948322669e-05,
                                0.0002814112742413565,
                                0.0002814112742413565,
                                0.000264961172003601,
                                0.000264961172003601,
                                6.382097083231711e-08,
                                6.382097083231711e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                0.00018556159116599018,
                                0.00018556159116599018,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0005352622327346319,
                                0.0005352622327346319,
                                7.585638600948615e-08,
                                7.585638600948615e-08,
                                1.8242730537714085e-05,
                                1.8242730537714085e-05,
                                0.00022055496029675098,
                                0.00022055496029675098,
                                0.0006757010589406283,
                                0.0006757010589406283,
                                0.0006362024584254275,
                                0.0006362024584254275,
                                6.382097083231711e-08,
                                6.382097083231711e-08,
                                1.534832905701143e-05,
                                1.534832905701143e-05,
                                0.00018556159116599018,
                                0.00018556159116599018,
                                0.0005684939639574024,
                                0.0005684939639574024,
                                0.0005352622327346319,
                                0.0005352622327346319,
                                3.159213969523967e-08,
                                3.159213969523967e-08,
                                7.597605447457069e-06,
                                7.597605447457069e-06,
                                9.18551948322669e-05,
                                9.18551948322669e-05,
                                0.0002814112742413565,
                                0.0002814112742413565,
                                0.000264961172003601,
                                0.000264961172003601,
                                1.9376249234944087e-08,
                                1.9376249234944087e-08,
                                4.659801398664974e-06,
                                4.659801398664974e-06,
                                5.6337087825125535e-05,
                                5.6337087825125535e-05,
                                0.00017259657116688875,
                                0.00017259657116688875,
                                0.0001625073121304997,
                                0.0001625073121304997,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                4.652461832470948e-08,
                                4.652461832470948e-08,
                                1.1188722797333533e-05,
                                1.1188722797333533e-05,
                                0.0001352718721156131,
                                0.0001352718721156131,
                                0.00041442435531905607,
                                0.00041442435531905607,
                                0.00039019887596257723,
                                0.00039019887596257723,
                                3.914299725160455e-08,
                                3.914299725160455e-08,
                                9.413513994856108e-06,
                                9.413513994856108e-06,
                                0.00011380956382029405,
                                0.00011380956382029405,
                                0.0003486715632578613,
                                0.0003486715632578613,
                                0.00032828971154117944,
                                0.00032828971154117944,
                                1.9376249234944087e-08,
                                1.9376249234944087e-08,
                                4.659801398664974e-06,
                                4.659801398664974e-06,
                                5.6337087825125535e-05,
                                5.6337087825125535e-05,
                                0.00017259657116688875,
                                0.00017259657116688875,
                                0.0001625073121304997,
                                0.0001625073121304997,
                            ]
                        ),
                    )
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.Hexahedron:
            match order:
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.Tetrahedron:
            match order:
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.SquareBasedPyramid:
            match order:
                case _:
                    raise ValueError(f"Invalid order: {order}")
        case Domain.TriangularPrism:
            match order:
                case _:
                    raise ValueError(f"Invalid order: {order}")
